% Auto-generated chapter 24 for nasai
% Hadiths in this chapter: 467

\hadithdefcmd{nasai}{2619}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ، - وَاسْمُهُ الْمُغِيرَةُ بْنُ سَلَمَةَ - قَالَ حَدَّثَنَا الرَّبِيعُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ فَقَالَ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ فَرَضَ عَلَيْكُمُ الْحَجَّ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ فِي كُلِّ عَامٍ فَسَكَتَ عَنْهُ حَتَّى أَعَادَهُ ثَلاَثًا فَقَالَ ‏"‏ لَوْ قُلْتُ نَعَمْ لَوَجَبَتْ وَلَوْ وَجَبَتْ مَا قُمْتُمْ بِهَا ذَرُونِي مَا تَرَكْتُكُمْ فَإِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ بِكَثْرَةِ سُؤَالِهِمْ وَاخْتِلاَفِهِمْ عَلَى أَنْبِيَائِهِمْ فَإِذَا أَمَرْتُكُمْ بِالشَّىْءِ فَخُذُوا بِهِ مَا اسْتَطَعْتُمْ وَإِذَا نَهَيْتُكُمْ عَنْ شَىْءٍ فَاجْتَنِبُوهُ ‏"‏ ‏.‏\hadithno{2619}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah addressed the people and said: 'Allah, the Mighty and Sublime, has enjoined upon you Hajj.' A man said: 'Every year?' He remained silent until he had repeated it three times. Then he said: 'If I said yes, it would be obligatory, and if it were obligatory you would not be able to do it. Leave me alone so long as I have left you alone. Those who came before you were destroyed because they asked too many questions and differed with their prophets. If I command you to do something then follow it as much as you can, and if I forbid you to do something then avoid it}}
\hadithdefcmd{nasai}{2620}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ أَنْبَأَنَا مُوسَى بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي عَبْدُ الْجَلِيلِ بْنُ حُمَيْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سِنَانٍ الدُّؤَلِيِّ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فَقَالَ ‏"‏ إِنَّ اللَّهَ تَعَالَى كَتَبَ عَلَيْكُمُ الْحَجَّ ‏"‏ ‏.‏ فَقَالَ الأَقْرَعُ بْنُ حَابِسٍ التَّمِيمِيُّ كُلُّ عَامٍ يَا رَسُولَ اللَّهِ فَسَكَتَ فَقَالَ ‏"‏ لَوْ قُلْتُ نَعَمْ لَوَجَبَتْ ثُمَّ إِذًا لاَ تَسْمَعُونَ وَلاَ تُطِيعُونَ وَلَكِنَّهُ حَجَّةٌ وَاحِدَةٌ ‏"‏ ‏.‏\hadithno{2620}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah stood up and said:Allah, Most High, has decreed Hajj for you. Al-Aqra' bin Habis At-Tamimi said: "Every year, O Messenger of Allah?" But he remained silent, then he said: "If I said yes, it would become obligatory, then you would not hear and obey. Rather it is just one Hajj}}
\hadithdefcmd{nasai}{2621}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ سَالِمٍ، قَالَ سَمِعْتُ عَمْرَو بْنَ أَوْسٍ، يُحَدِّثُ عَنْ أَبِي رَزِينٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبِي شَيْخٌ كَبِيرٌ لاَ يَسْتَطِيعُ الْحَجَّ وَلاَ الْعُمْرَةَ وَلاَ الظَّعْنَ ‏.‏ قَالَ ‏ "‏ فَحُجَّ عَنْ أَبِيكَ وَاعْتَمِرْ ‏"‏ ‏.‏\hadithno{2621}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Razin that he said:"O Messenger of Allah, my fater is an old man and he cannot perform Hajj or 'Umrah, nor can he travel." He said: "Perform Hajj and 'Umrah on behalf of your father."(sahih)}}
\hadithdefcmd{nasai}{2622}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الصَّفَّارُ الْبَصْرِيُّ، قَالَ حَدَّثَنَا سُوَيْدٌ، - وَهُوَ ابْنُ عَمْرٍو الْكَلْبِيُّ - عَنْ زُهَيْرٍ، قَالَ حَدَّثَنَا سُهَيْلٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْحَجَّةُ الْمَبْرُورَةُ لَيْسَ لَهَا جَزَاءٌ إِلاَّ الْجَنَّةُ وَالْعُمْرَةُ إِلَى الْعُمْرَةِ كَفَّارَةٌ لِمَا بَيْنَهُمَا ‏"‏ ‏.‏\hadithno{2622}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Hajj al-Mabrur brings no reward other than Paradise, and from one 'Umrah to another is expiation for what came in between." (Shih)}}
\hadithdefcmd{nasai}{2623}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي سُهَيْلٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْحَجَّةُ الْمَبْرُورَةُ لَيْسَ لَهَا ثَوَابٌ إِلاَّ الْجَنَّةُ ‏"‏ ‏.‏ مِثْلَهُ سَوَاءً إِلاَّ أَنَّهُ قَالَ ‏"‏ تُكَفِّرُ مَا بَيْنَهُمَا ‏"‏ ‏.‏\hadithno{2623}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Hajj Al-Mabrur brings no reward other than paradise," the report is the same except that he said, "expiates for what came in between}}
\hadithdefcmd{nasai}{2624}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَأَلَ رَجُلٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏"‏ الإِيمَانُ بِاللَّهِ ‏"‏ ‏.‏ قَالَ ثُمَّ مَاذَا قَالَ ‏"‏ الْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ ثُمَّ مَاذَا قَالَ ‏"‏ ثُمَّ الْحَجُّ الْمَبْرُورُ ‏"‏ ‏.‏\hadithno{2624}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that abu Hurairah said:"A man asked the Prophet 'O Messenger of Allah, which deed is best?' He said: 'Jihad in the cause of Allah.' He said: 'Then what?' He said: 'then Hajj Al-Mabrir}}
\hadithdefcmd{nasai}{2625}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ بْنِ مَثْرُودٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ مَخْرَمَةَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ سُهَيْلَ بْنَ أَبِي صَالِحٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَفْدُ اللَّهِ ثَلاَثَةٌ الْغَازِي وَالْحَاجُّ وَالْمُعْتَمِرُ ‏"‏ ‏.‏\hadithno{2625}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'The guests of Allah are three: The ghazi, the Hajj (pilgrim) and the Mu'tamir}}
\hadithdefcmd{nasai}{2626}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ جِهَادُ الْكَبِيرِ وَالصَّغِيرِ وَالضَّعِيفِ وَالْمَرْأَةِ الْحَجُّ وَالْعُمْرَةُ ‏"‏ ‏.‏\hadithno{2626}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of allah said:"Jihad of the elderly, the young, the weak, and women, is Hajj and 'Umarah."(Sahah)}}
\hadithdefcmd{nasai}{2627}{أَخْبَرَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا الْفُضَيْلُ، - وَهُوَ ابْنُ عِيَاضٍ - عَنْ مَنْصُورٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَجَّ هَذَا الْبَيْتَ فَلَمْ يَرْفُثْ وَلَمْ يَفْسُقْ رَجَعَ كَمَا وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏\hadithno{2627}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever performs pilgrimage to this House, and does not Yarfuth (utter any obscenity or commit sin), will go back as (on the day) his nother bore him.'''(sahih)}}
\hadithdefcmd{nasai}{2628}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ حَبِيبٍ، - وَهُوَ ابْنُ أَبِي عَمْرَةَ - عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، قَالَتْ أَخْبَرَتْنِي أُمُّ الْمُؤْمِنِينَ، عَائِشَةُ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَلاَ نَخْرُجُ فَنُجَاهِدَ مَعَكَ فَإِنِّي لاَ أَرَى عَمَلاً فِي الْقُرْآنِ أَفْضَلَ مِنَ الْجِهَادِ ‏.‏ قَالَ ‏ "‏ لاَ وَلَكُنَّ أَحْسَنُ الْجِهَادِ وَأَجْمَلُهُ حَجُّ الْبَيْتِ حَجٌّ مَبْرُورٌ ‏"‏ ‏.‏\hadithno{2628}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{The Mother of the Believers, 'Aishah, said:"I said: 'O Messenger of allah, shall we not go out and fight in jihad with you, for I do not think there is any deed in the qur'an that is better than jihad.' He said: 'No. the best and most beautiful (type) of jihad is Hajj to the House; Hajj Al-Mabrur. ''(sahih)}}
\hadithdefcmd{nasai}{2629}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَةُ إِلَى الْعُمْرَةِ كَفَّارَةٌ لِمَا بَيْنَهُمَا وَالْحَجُّ الْمَبْرُورُ لَيْسَ لَهُ جَزَاءٌ إِلاَّ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{2629}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that abnu Hurairah said:"The Messenger of Allah said: 'from one 'Umrah to another is an expiation for what comes in between, and Hajj al-Mabrur brings no reward less than Paradise.'''(sahih)}}
\hadithdefcmd{nasai}{2630}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا أَبُو عَتَّابٍ، قَالَ حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَابِعُوا بَيْنَ الْحَجِّ وَالْعُمْرَةِ فَإِنَّهُمَا يَنْفِيَانِ الْفَقْرَ وَالذُّنُوبَ كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ ‏"‏ ‏.‏\hadithno{2630}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'abbas said:"The Messenger of Allah said: 'Perform Hajj and 'Umrah consecutively; for they remove poverty and sin as the bellows removes impurity from iron}}
\hadithdefcmd{nasai}{2631}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَيَّانَ أَبُو خَالِدٍ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ عَاصِمٍ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَابِعُوا بَيْنَ الْحَجِّ وَالْعُمْرَةِ فَإِنَّهُمَا يَنْفِيَانِ الْفَقْرَ وَالذُّنُوبَ كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ وَالذَّهَبِ وَالْفِضَّةِ وَلَيْسَ لِلْحَجِّ الْمَبْرُورِ ثَوَابٌ دُونَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{2631}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah said: 'Perform Hajj and 'Umrah consecutively, for they remove poverty and sin as the bellows removes impurity from iron and gold and silver, and Hajj Al-Mabrur brings no less a reward than Paradise}}
\hadithdefcmd{nasai}{2632}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، نَذَرَتْ أَنْ تَحُجَّ، فَمَاتَتْ فَأَتَى أَخُوهَا النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ عَنْ ذَلِكَ فَقَالَ ‏"‏ أَرَأَيْتَ لَوْ كَانَ عَلَى أُخْتِكَ دَيْنٌ أَكُنْتَ قَاضِيَهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاقْضُوا اللَّهَ فَهُوَ أَحَقُّ بِالْوَفَاءِ ‏"‏ ‏.‏\hadithno{2632}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that:a woman vowed to perform Hajj but she died. Her brother came to the Prophet and asked him about that, he said: 'Do yhou think that if your sister owed a debt you wouold pay it off?' He said: 'Yes.' He said: 'Then fulfill the right of Allah, for He is more deserving that His rights should be fulfilled}}
\hadithdefcmd{nasai}{2633}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا أَبُو التَّيَّاحِ، قَالَ حَدَّثَنِي مُوسَى بْنُ سَلَمَةَ الْهُذَلِيُّ، أَنَّ ابْنَ عَبَّاسٍ، قَالَ أَمَرَتِ امْرَأَةُ سِنَانَ بْنِ سَلَمَةَ الْجُهَنِيِّ أَنْ يَسْأَلَ، رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَّ أُمَّهَا مَاتَتْ وَلَمْ تَحُجَّ أَفَيُجْزِئُ عَنْ أُمِّهَا أَنْ تَحُجَّ عَنْهَا قَالَ ‏ "‏ نَعَمْ لَوْ كَانَ عَلَى أُمِّهَا دَيْنٌ فَقَضَتْهُ عَنْهَا أَلَمْ يَكُنْ يُجْزِئُ عَنْهَا فَلْتَحُجَّ عَنْ أُمِّهَا ‏"‏ ‏.‏\hadithno{2633}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Abbas said:"The wife of sinan bin Salamah Al-Juhani ordered that the question be put to the Messenger of Allah about her mother who had died and had not performed Hajj; would it be good enough if she were to perform Hajj on behalf of her mother? He said: 'Yes. If her mother owed a debt and she paid it off, would that not be good enough? Let her perform Hajj on behalf of her mother}}
\hadithdefcmd{nasai}{2634}{أَخْبَرَنِي عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ حَكِيمٍ الأَوْدِيُّ، قَالَ حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ الرُّؤَاسِيُّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنِ الزُّهْرِيِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم عَنْ أَبِيهَا مَاتَ وَلَمْ يَحُجَّ قَالَ ‏ "‏ حُجِّي عَنْ أَبِيكِ ‏"‏ ‏.‏\hadithno{2634}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:a woman asked the Prophet about her therwho had died and he did not perform Hajj. He said: "Perform Hajj on behalf of your father}}
\hadithdefcmd{nasai}{2635}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، مِنْ خَثْعَمَ سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم غَدَاةَ جَمْعٍ فَقَالَتْ يَا رَسُولَ اللَّهِ فَرِيضَةُ اللَّهِ فِي الْحَجِّ عَلَى عِبَادِهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَمْسِكُ عَلَى الرَّحْلِ أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{2635}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'abbas that:a woman from Khath'am asked the Prophet on the morning of the Day of Sacrifice: "O Messenger of Allah! The command of Allah to His slaves to perform Hajj has come, while my father is an old man and cannot sit firmly in the saddle. Can I perform Hajj on his behalf?" He said: "Yes}}
\hadithdefcmd{nasai}{2636}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو عُبَيْدِ اللَّهِ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، مِثْلَهُ ‏.‏\hadithno{2636}\hadithgrade{Abu Ghuddah: -; Al-Albani: Daif}\hadithtrans{It was narrated from Ibn 'Abbas:(Another chain) with a similar report narrated from Ibn 'Abbas. (sahih)}}
\hadithdefcmd{nasai}{2637}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ أَبِي رَزِينٍ الْعُقَيْلِيِّ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبِي شَيْخٌ كَبِيرٌ لاَ يَسْتَطِيعُ الْحَجَّ وَلاَ الْعُمْرَةَ وَالظَّعْنَ ‏.‏ قَالَ ‏ "‏ حُجَّ عَنْ أَبِيكَ وَاعْتَمِرْ ‏"‏ ‏.‏\hadithno{2637}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was nattated from Abu RAzin Al-'Uqayli that he said:"O Messenger of Allah! My father is an old man who cannot perform Hajj or 'Umrah, nor can he travel." He said "Perform Hajj and 'Umrah on behalf of your father}}
\hadithdefcmd{nasai}{2638}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ يُوسُفَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ جَاءَ رَجُلٌ مِنْ خَثْعَمَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ أَبِي شَيْخٌ كَبِيرٌ لاَ يَسْتَطِيعُ الرُّكُوبَ وَأَدْرَكَتْهُ فَرِيضَةُ اللَّهِ فِي الْحَجِّ فَهَلْ يُجْزِئُ أَنْ أَحُجَّ عَنْهُ قَالَ ‏"‏ آنْتَ أَكْبَرُ وَلَدِهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ أَرَأَيْتَ لَوْ كَانَ عَلَيْهِ دَيْنٌ أَكُنْتَ تَقْضِيهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَحُجَّ عَنْهُ ‏"‏ ‏.‏\hadithno{2638}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Az-Zubair said:"A man from Khath'am came to the Messenger of Allah and said: 'My father is an old man who cannot ride, and the command of Allah to perform Hajj has come. Will it be good enough if I perform Hajj on his behalf?' He said: 'Are you the oldest of his children?' He said: 'Yes.' He said: 'Don't you think that if he owed a debt you would pay it off?, He' said: 'Yes.' He said: 'then perform Hajj on his behalf.'''(Daif)}}
\hadithdefcmd{nasai}{2639}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ النَّسَائِيُّ عَنْ عَبْدِ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنَّ أَبِي مَاتَ وَلَمْ يَحُجَّ أَفَأَحُجُّ عَنْهُ قَالَ ‏"‏ أَرَأَيْتَ لَوْ كَانَ عَلَى أَبِيكَ دَيْنٌ أَكُنْتَ قَاضِيَهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَدَيْنُ اللَّهِ أَحَقُّ ‏"‏ ‏.‏\hadithno{2639}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"A man said: 'O Messenger of Allah! My father has died and he did not perform Hajj; shall I perform Hajj on his behalf?' He said: 'Don't you think that if your father owed a debt you would pay it off?' The man said: 'Yes.' He said: 'The debt owed to Allah is more deserving (of being paid off)}}
\hadithdefcmd{nasai}{2640}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، عَنْ هُشَيْمٍ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم أَنَّ أَبِي أَدْرَكَهُ الْحَجُّ وَهُوَ شَيْخٌ كَبِيرٌ لاَ يَثْبُتُ عَلَى رَاحِلَتِهِ فَإِنْ شَدَدْتُهُ خَشِيتُ أَنْ يَمُوتَ أَفَأَحُجُّ عَنْهُ قَالَ ‏"‏ أَرَأَيْتَ لَوْ كَانَ عَلَيْهِ دَيْنٌ فَقَضَيْتَهُ أَكَانَ مُجْزِئًا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَحُجَّ عَنْ أَبِيكَ ‏"‏ ‏.‏\hadithno{2640}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{(It was narrated from 'Abdullah bin 'Abbas that:a man asked the Prophet "The command of ) Hajj has come while my father is an old man and cannot sit firmly in his saddle; if I tie him (to the saddle) I fear that he will die. Can I perform Hajj on his behalf?" He said: "don't you think that if your father owed a debt and you paid it off, that would be good enough?" He said: "Yes." He said: "Then perform Hajj on behalf of your father}}
\hadithdefcmd{nasai}{2641}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كَانَ الْفَضْلُ بْنُ عَبَّاسٍ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَتْهُ امْرَأَةٌ مِنْ خَثْعَمَ تَسْتَفْتِيهِ وَجَعَلَ الْفَضْلُ يَنْظُرُ إِلَيْهَا وَتَنْظُرُ إِلَيْهِ وَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْرِفُ وَجْهَ الْفَضْلِ إِلَى الشِّقِّ الآخَرِ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ فِي الْحَجِّ عَلَى عِبَادِهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَطِيعُ أَنْ يَثْبُتَ عَلَى الرَّاحِلَةِ أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ وَذَلِكَ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{2641}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas:"Al-Fadl bin 'Abbas was riding behind the Messenger of Allah when a woman from Khath'am came and asked him a question. Al-Fadl started looking at her and she at him, and the Messenger of Allah turned Al-Fadl's face to the other side. She said: 'O Messenger of Allah! The command of Allah has come for His slaves to perform Hajj, but my father is an old man and cannot sit firmly in the saddle; should I perform Hajj on his behalf ?, He said: 'Yes That happened during the Farwell Pilgrimage.''(Shih)}}
\hadithdefcmd{nasai}{2642}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، أَنَّ سُلَيْمَانَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنَّ ابْنَ عَبَّاسٍ أَخْبَرَهُ أَنَّ امْرَأَةً مِنْ خَثْعَمَ اسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ وَالْفَضْلُ بْنُ عَبَّاسٍ رَدِيفُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ فِي الْحَجِّ عَلَى عِبَادِهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَوِي عَلَى الرَّاحِلَةِ فَهَلْ يَقْضِي عَنْهُ أَنْ أَحُجَّ عَنْهُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ ‏"‏ ‏.‏ فَأَخَذَ الْفَضْلُ بْنُ عَبَّاسٍ يَلْتَفِتُ إِلَيْهَا وَكَانَتِ امْرَأَةً حَسْنَاءَ وَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْفَضْلَ فَحَوَّلَ وَجْهَهُ مِنَ الشِّقِّ الآخَرِ ‏.‏\hadithno{2642}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn 'Abbas narrated that:a woman from Khath'am asked the Messenger of Allah a question during the Farewell Pilgrimage, when Al-Fadl bin 'Abbas was riding behing the Messenger of Allah She said: "O Messenger of Allah! The command of Allah has come for His slaves to perform Hajj, but my father is an old man and cannot sit upright in the saddle. Will it be paid off on his behalf if I perform Hajj on his behalf?" The Messenger of Allah said to her: "Yes." And Al-Fadl started to turn toward her, as she was a beautiful woman, but the Messenger of Allah took hold of Al-Fadl's face and turned it to the other side}}
\hadithdefcmd{nasai}{2643}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ هَارُونَ - قَالَ أَنْبَأَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، أَنَّهُ كَانَ رَدِيفَ النَّبِيِّ صلى الله عليه وسلم فَجَاءَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي عَجُوزٌ كَبِيرَةٌ وَإِنْ حَمَلْتُهَا لَمْ تَسْتَمْسِكْ وَإِنْ رَبَطْتُهَا خَشِيتُ أَنْ أَقْتُلَهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرَأَيْتَ لَوْ كَانَ عَلَى أُمِّكَ دَيْنٌ أَكُنْتَ قَاضِيَهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَحُجَّ عَنْ أُمِّكَ ‏"‏ ‏.‏\hadithno{2643}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Fadl bin 'Abbas that:he was riding behind the Messenger of Allah and a man came and said: "O Messenger of Allah! My mother is an old woman and she cannot sit firmly in the saddle. If I tie her I fear that I may kill her." The Messenger of Allah said: "Don't you think that if your mother owed a debt you would pay it off?" He said: "Yes." Her said: "Then perform Hajj on behalf of your mother."(Shih)}}
\hadithdefcmd{nasai}{2644}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ يُوسُفَ، عَنِ ابْنِ الزُّبَيْرِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏ "‏ أَنْتَ أَكْبَرُ وَلَدِ أَبِيكَ فَحُجَّ عَنْهُ ‏"‏ ‏.‏\hadithno{2644}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Az-Zubair that the Prophet said to a man:"You are the oldest son of your father, so perform Hajj on his behalf}}
\hadithdefcmd{nasai}{2645}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، رَفَعَتْ صَبِيًّا لَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ يَا رَسُولَ اللَّهِ أَلِهَذَا حَجٌّ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{2645}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that:a woman helf up a child of hers to the Messenger of Allah and said: "O Messenger of Allah, is there Hajj for this one?" He said: "Yes, and you will be rewarded. (Sahih)}}
\hadithdefcmd{nasai}{2646}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَفَعَتِ امْرَأَةٌ صَبِيًّا لَهَا مِنْ هَوْدَجٍ فَقَالَتْ يَا رَسُولَ اللَّهِ أَلِهَذَا حَجٌّ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{2646}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"A woman lifted up a child of hers from a howdah (litter) and said: 'O Messenger of Allah, is there Hajj for this one?' He said: 'Yes, and you will be rewarded.'''(sahih)}}
\hadithdefcmd{nasai}{2647}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَفَعَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم صَبِيًّا فَقَالَتْ أَلِهَذَا حَجٌّ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{2647}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"A woman lifted a child up to the Messenger of Allah and said: 'Is there Hajj for this one?' He said: 'Yes, and you will be rewarded.'''(sahih)}}
\hadithdefcmd{nasai}{2648}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُقْبَةَ، ح وَحَدَّثَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنْ سُفْيَانَ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَدَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا كَانَ بِالرَّوْحَاءِ لَقِيَ قَوْمًا فَقَالَ ‏"‏ مَنْ أَنْتُمْ ‏"‏ ‏.‏ قَالُوا الْمُسْلِمُونَ ‏.‏ قَالُوا مَنْ أَنْتُمْ قَالُوا رَسُولُ اللَّهِ ‏.‏ قَالَ فَأَخْرَجَتِ امْرَأَةٌ صَبِيًّا مِنَ الْمِحَفَّةِ فَقَالَتْ أَلِهَذَا حَجٌّ قَالَ ‏"‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{2648}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah set out and when he was in Ar-Rawha he met some people and said: 'Who are you?' They said: 'Muslins.' They said: 'Who are you?' They said: 'The Messenger of Allah.' A woman brought a child out of the litter and said: 'Is there Hajj for this one?' He said" "Yes, and you will be rewarded.'''(Shih)}}
\hadithdefcmd{nasai}{2649}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ بْنِ حَمَّادِ بْنِ سَعْدٍ ابْنُ أَخِي، رِشْدِينَ بْنِ سَعْدٍ أَبُو الرَّبِيعِ وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِامْرَأَةٍ وَهِيَ فِي خِدْرِهَا مَعَهَا صَبِيٌّ فَقَالَتْ أَلِهَذَا حَجٌّ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{2649}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:the Messenger of Allah passed by a woman when she was in her seclusion and had a child with her. She said: "Is there Hajj for this one?'' He said: "Yes, and you will be rewarded.''(sahih)}}
\hadithdefcmd{nasai}{2650}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ أَبِي زَائِدَةَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَتْنِي عَمْرَةُ، أَنَّهَا سَمِعَتْ عَائِشَةَ، تَقُولُ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ لاَ نُرَى إِلاَّ الْحَجَّ حَتَّى إِذَا دَنَوْنَا مِنْ مَكَّةَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ إِذَا طَافَ بِالْبَيْتِ أَنْ يَحِلَّ ‏.‏\hadithno{2650}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah said:"We went out with the Messenger of Allah when there were five days left of Dhul-Qa'dah, with no intention other than to perform Hajj. When we were close to Makkah, the Messenger of Allah commanded those who did not have a Hadi (sacrificial animal) with them to exit Ihram after circumambulating the House}}
\hadithdefcmd{nasai}{2651}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَأَهْلُ الشَّامِ مِنَ الْجُحْفَةِ وَأَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ وَبَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏\hadithno{2651}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Messenger of Allah said:"The people of Al-Madinah should enter into Ihram from Dhul-Hulaifah, the people of Ash-sham from Al-Juhfah, the people of Najd from Qarn." 'Abdullah said: "And it was conveyed to me, that the Messenger of Allah said: 'And the people of Yemen should enter into Ihram from Yalamlam}}
\hadithdefcmd{nasai}{2652}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، قَالَ حَدَّثَنَا نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، قَامَ فِي الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ مِنْ أَيْنَ تَأْمُرُنَا أَنْ نُهِلَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَيُهِلُّ أَهْلُ الشَّامِ مِنَ الْجُحْفَةِ وَيُهِلُّ أَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ وَيَزْعُمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏ وَكَانَ ابْنُ عُمَرَ يَقُولُ لَمْ أَفْقَهْ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2652}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that a man stood up in the Masjid and said:"O Messenger of Allah, from where do you command us to enter Ihram?'' The Messenger of Allah Said: "The people of Al-Madinah should enter Ihram from Dhul-Hulaifah, the people of Ash-sham should enter Ihram from Al-Juhfah, the people of Najd should enter Ihram from Qarn.'' Ibn 'Umar said: "And they say that the Messenger of Allah said: 'the people of Yemen should enter into Ihram from Yalamlam.''' And 'Ibn 'Umar used to say: "I did not hear this from the Messenger of Allah}}
\hadithdefcmd{nasai}{2653}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ بَهْرَامَ، قَالَ حَدَّثَنَا الْمُعَافَى، عَنْ أَفْلَحَ بْنِ حُمَيْدٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ وَلأَهْلِ الشَّامِ وَمِصْرَ الْجُحْفَةَ وَلأَهْلِ الْعِرَاقِ ذَاتَ عِرْقٍ وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ ‏.‏\hadithno{2653}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah:That the Messenger of Allah designated Dhul-Hulaifah as the Miqat for the people of Al-Madinah, Al-Juhfah for the people of Ash-sham and Eguypt, Dhat 'Irq fro the people of al-Iraq, and Yalamlam for the people of Yemen}}
\hadithdefcmd{nasai}{2654}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، صَاحِبُ الشَّافِعِيِّ قَالَ حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، قَالَ حَدَّثَنَا وُهَيْبٌ، وَحَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ وَلأَهْلِ الشَّامِ الْجُحْفَةَ وَلأَهْلِ نَجْدٍ قَرْنًا وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ وَقَالَ ‏ "‏ هُنَّ لَهُنَّ وَلِكُلِّ آتٍ أَتَى عَلَيْهِنَّ مِنْ غَيْرِهِنَّ فَمَنْ كَانَ أَهْلُهُ دُونَ الْمِيقَاتِ حَيْثُ يُنْشِئُ حَتَّى يَأْتِيَ ذَلِكَ عَلَى أَهْلِ مَكَّةَ ‏"‏ ‏.‏\hadithno{2654}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that:the Messenger of Allah designated Dhul-Hulaifah as the Miqat for the people of Al-Madinah Al-Juhfah for the people of Najd, and Yalmlam for the people of Yemen. He said: "They are for them, and for anyone who comes to them from elsewhere. If a person's place of residence is within the boundary of the Miqat, then (he should enter into Ihram) from where he starts his journey, and this also applies to the people of Makkah.''(Sihah)}}
\hadithdefcmd{nasai}{2655}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَأَهْلُ الشَّامِ مِنَ الْجُحْفَةِ وَأَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏ ‏.‏ وَذُكِرَ لِي وَلَمْ أَسْمَعْ أَنَّهُ قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏\hadithno{2655}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim, from his father, that the Prophet said:"The people of Al-Madinah should enter into Ihram from Dhul-Hulaifah, the people of Ash-sham from Al-Juhfah, the people of Najd from Qarn." And it was mentioned to me, although I did not hear him say it: "And the people of Yemen should enter into Ihram from Yalamlam.;}}
\hadithdefcmd{nasai}{2656}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ الْمَوْصِلِيُّ، قَالَ حَدَّثَنَا أَبُو هَاشِمٍ، مُحَمَّدُ بْنُ عَلِيٍّ عَنِ الْمُعَافَى، عَنْ أَفْلَحَ بْنِ حُمَيْدٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ وَقَّتَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ وَلأَهْلِ الشَّامِ وَمِصْرَ الْجُحْفَةَ وَلأَهْلِ الْعِرَاقِ ذَاتَ عِرْقٍ وَلأَهْلِ نَجْدٍ قَرْنًا وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ ‏.‏\hadithno{2656}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah designated Dhul-Hulaifah as the Miqat for the people of Al-Madinah, Al-Juhfah for the people Ash-sham and Egypt, Dhat 'Irq for the people Al-'Iraq, Qarn for the people of Najd and Yalamlam for the people of Yemen}}
\hadithdefcmd{nasai}{2657}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا مَعْمَرٌ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ وَقَّتَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ وَلأَهْلِ الشَّامِ الْجُحْفَةَ وَلأَهْلِ نَجْدٍ قَرْنًا وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ قَالَ ‏ "‏ هُنَّ لَهُمْ وَلِمَنْ أَتَى عَلَيْهِنَّ مِمَّنْ سِوَاهُنَّ لِمَنْ أَرَادَ الْحَجَّ وَالْعُمْرَةَ وَمَنْ كَانَ دُونَ ذَلِكَ مِنْ حَيْثُ بَدَأَ حَتَّى يَبْلُغَ ذَلِكَ أَهْلَ مَكَّةَ ‏"‏ ‏.‏\hadithno{2657}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of 'Allah designated Dhul-Hulaifah as the Miqat for the people of Al-Madinah, Al-Juhfah for the people of Ash-sham, Qarn for the people of Najd, and Yalamalam for the people of Yemen. He aid: "They are for them and for those who pass by them who are not of their people who intend to perform Hajj and 'Umrah. If a person's place of residence is within the boundary of the Miqat, then (he should enter into Ihram) from where he starts his journey, and this also applies to the people of Makkah}}
\hadithdefcmd{nasai}{2658}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ وَلأَهْلِ الشَّامِ الْجُحْفَةَ وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ وَلأَهْلِ نَجْدٍ قَرْنًا فَهُنَّ لَهُمْ وَلِمَنْ أَتَى عَلَيْهِنَّ مِنْ غَيْرِ أَهْلِهِنَّ مِمَّنْ كَانَ يُرِيدُ الْحَجَّ وَالْعُمْرَةَ فَمَنْ كَانَ دُونَهُنَّ فَمِنْ أَهْلِهِ حَتَّى أَنَّ أَهْلَ مَكَّةَ يُهِلُّونَ مِنْهَا ‏.‏\hadithno{2658}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet designated Dhul-Hulaifah as the Miqat for the people of Al-Madinah, Al-Juhfah for the people of Ash-shamham, Yalmlam for the people of Yemen, and Qarn for the people of Najd. They are for them and for those who pass by them who are not of their people, intending to perform Hajj or 'Umrah. If a person's place of residence is within the boundary of they Miqat, then (he should enter Ihram) from where he starts his journey, and this also applies to the people of Makkah}}
\hadithdefcmd{nasai}{2659}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ بْنِ مَثْرُودٍ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ أَبَاهُ، قَالَ بَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذِي الْحُلَيْفَةِ بِبَيْدَاءَ وَصَلَّى فِي مَسْجِدِهَا ‏.‏\hadithno{2659}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ubaidullah bin 'Abdullah bin 'Umar narrated that his father said:"The Messenger of Allah stayed overnight in dhul-Hulaifah, where he started his Hajj with this action, and he prayed in the Masjid there.''(sahih)}}
\hadithdefcmd{nasai}{2660}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، عَنْ سُوَيْدٍ، عَنْ زُهَيْرٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ وَهُوَ فِي الْمُعَرَّسِ بِذِي الْحُلَيْفَةِ أُتِيَ فَقِيلَ لَهُ إِنَّكَ بِبَطْحَاءَ مُبَارَكَةٍ ‏.‏\hadithno{2660}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:when the Messenger of Allah was in Dhul-Hulaifah someone came to him and he was told: "You are in a blessed valley.''(sahih)}}
\hadithdefcmd{nasai}{2661}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَاخَ بِالْبَطْحَاءِ الَّتِي بِذِي الْحُلَيْفَةِ وَصَلَّى بِهَا ‏.‏\hadithno{2661}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar:That the Messenger of Allah stopped in the valley that is in Dhul-Hulaifah and prayed there. (sahih)}}
\hadithdefcmd{nasai}{2662}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا النَّضْرُ، - وَهُوَ ابْنُ شُمَيْلٍ - قَالَ حَدَّثَنَا أَشْعَثُ، - وَهُوَ ابْنُ عَبْدِ الْمَلِكِ - عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الظُّهْرَ بِالْبَيْدَاءِ ثُمَّ رَكِبَ وَصَعِدَ جَبَلَ الْبَيْدَاءِ فَأَهَلَّ بِالْحَجِّ وَالْعُمْرَةِ حِينَ صَلَّى الظُّهْرَ ‏.‏\hadithno{2662}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that:the Messenger of Allah prayed Zuhr in Al-Baida then he rode up the mountain of Al-Baida; and began the Talbiyah for Hajj and 'Umrah, when he had prayed Zuhr (Daif)}}
\hadithdefcmd{nasai}{2663}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ عُمَيْسٍ، أَنَّهَا وَلَدَتْ مُحَمَّدَ بْنَ أَبِي بَكْرٍ الصِّدِّيقِ بِالْبَيْدَاءِ فَذَكَرَ أَبُو بَكْرٍ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مُرْهَا فَلْتَغْتَسِلْ ثُمَّ لْتُهِلَّ ‏"‏ ‏.‏\hadithno{2663}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Asma bin 'Umais that:she gave birth to Muhammad bin Abi Bakr As-Siddiq in Al-Baida, Abu Bakr told the Messenger of Allah about that, and he said: "Tell her to perform Gusl then begin the Talbiyah}}
\hadithdefcmd{nasai}{2664}{أَخْبَرَنِي أَحْمَدُ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ النَّسَائِيُّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ حَدَّثَنِي يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ الأَنْصَارِيُّ - قَالَ سَمِعْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ أَبِي بَكْرٍ، أَنَّهُ خَرَجَ حَاجًّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَجَّةَ الْوَدَاعِ وَمَعَهُ امْرَأَتُهُ أَسْمَاءُ بِنْتُ عُمَيْسٍ الْخَثْعَمِيَّةُ فَلَمَّا كَانُوا بِذِي الْحُلَيْفَةِ وَلَدَتْ أَسْمَاءُ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَتَى أَبُو بَكْرٍ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَأْمُرَهَا أَنْ تَغْتَسِلَ ثُمَّ تُهِلَّ بِالْحَجِّ وَتَصْنَعَ مَا يَصْنَعُ النَّاسُ إِلاَّ أَنَّهَا لاَ تَطُوفُ بِالْبَيْتِ ‏.‏\hadithno{2664}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Bakr:That he went out for Hajj with the Messenger of Allah on the Farewell Pilgrimage, and his wife Asma' bint 'Umais Al-Khath'amiyyah was with him. When they were at Dhul-Hulaifah, Asma gave birth to Muhammad bin abi Bakr. Abu Bakr. Came to the Prophet and told him, and the Messenger of Allah told him to tell her to perform Ghusl, then begin the Talbniyah for Hajj, and to do everything that the people do, except that she should not circumambulate the House.(sahih)}}
\hadithdefcmd{nasai}{2665}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، وَالْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّهُمَا اخْتَلَفَا بِالأَبْوَاءِ فَقَالَ ابْنُ عَبَّاسٍ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ ‏.‏ وَقَالَ الْمِسْوَرُ لاَ يَغْسِلُ رَأْسَهُ ‏.‏ فَأَرْسَلَنِي ابْنُ عَبَّاسٍ إِلَى أَبِي أَيُّوبَ الأَنْصَارِيِّ أَسْأَلُهُ عَنْ ذَلِكَ فَوَجَدْتُهُ يَغْتَسِلُ بَيْنَ قَرْنَىِ الْبِئْرِ وَهُوَ مُسْتَتِرٌ بِثَوْبٍ فَسَلَّمْتُ عَلَيْهِ وَقُلْتُ أَرْسَلَنِي إِلَيْكَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ أَسْأَلُكَ كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْسِلُ رَأْسَهُ وَهُوَ مُحْرِمٌ فَوَضَعَ أَبُو أَيُّوبَ يَدَهُ عَلَى الثَّوْبِ فَطَأْطَأَهُ حَتَّى بَدَا رَأْسُهُ ثُمَّ قَالَ لإِنْسَانٍ يَصُبُّ عَلَى رَأْسِهِ ثُمَّ حَرَّكَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ وَقَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ ‏.‏\hadithno{2665}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas and Al-Miswar bin Makhramah that:they had a difference of opinion in al-Abwa. Ibn 'Abbas said: "The Muhrim (Pilgrim in Ihram) may wash his head." Al-Miswar said: "He should not wash his head."Ibn 'Abbas sent me (the narrator) to Abu Ayyub Al-Ansari to ask him about that. I found him performing Ghusl in front of the well, screened with a cloth. I greeted him with Salam and said: "Abdullah bin 'Abbas has sent me to you to ask you how the Messenger of Allah used to wash his head when he was in Ihram." Abu put his hand on the cloth and lowered it, until his head appeared, then he told someone to puor water on his head. Then he rubbed his head with his hands, back and forth, and said: "This is what I saw the Messenger of Allah do}}
\hadithdefcmd{nasai}{2666}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَلْبَسَ الْمُحْرِمُ ثَوْبًا مَصْبُوغًا بِزَعْفَرَانٍ أَوْ بِوَرْسٍ ‏.‏\hadithno{2666}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah forbade the Muhrim to wear clothes dyed with saffron or Wars}}
\hadithdefcmd{nasai}{2667}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ قَالَ ‏ "‏ لاَ يَلْبَسُ الْقَمِيصَ وَلاَ الْبُرْنُسَ وَلاَ السَّرَاوِيلَ وَلاَ الْعِمَامَةَ وَلاَ ثَوْبًا مَسَّهُ وَرْسٌ وَلاَ زَعْفَرَانٌ وَلاَ خُفَّيْنِ إِلاَّ لِمَنْ لاَ يَجِدُ نَعْلَيْنِ فَإِنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَقْطَعْهُمَا حَتَّى يَكُونَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{2667}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that his father said:"The Messenger of Allah was asked what clothes the Muhrim may wear. He said: 'He should not wear a shirt, or a burnous, or pants, or an 'Imamah (turban, or any garment that has been touched by (dyed with) Wars or saffron, or Khuffs except for one who cannot find sandals. If he cannot find sandals, then let him cut them until they come lower than the ankles, (sahih)}}
\hadithdefcmd{nasai}{2668}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ الْقُومَسِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنِي عَطَاءٌ، عَنْ صَفْوَانَ بْنِ يَعْلَى بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لَيْتَنِي أَرَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يُنْزَلُ عَلَيْهِ فَبَيْنَا نَحْنُ بِالْجِعِرَّانَةِ وَالنَّبِيُّ صلى الله عليه وسلم فِي قُبَّةٍ فَأَتَاهُ الْوَحْىُ فَأَشَارَ إِلَىَّ عُمَرُ أَنْ تَعَالَ فَأَدْخَلْتُ رَأْسِي الْقُبَّةَ فَأَتَاهُ رَجُلٌ قَدْ أَحْرَمَ فِي جُبَّةٍ بِعُمْرَةٍ مُتَضَمِّخٌ بِطِيبٍ فَقَالَ يَا رَسُولَ اللَّهِ مَا تَقُولُ فِي رَجُلٍ قَدْ أَحْرَمَ فِي جُبَّةٍ إِذْ أُنْزِلَ عَلَيْهِ الْوَحْىُ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَغِطُّ لِذَلِكَ فَسُرِّيَ عَنْهُ فَقَالَ ‏"‏ أَيْنَ الرَّجُلُ الَّذِي سَأَلَنِي آنِفًا ‏"‏ ‏.‏ فَأُتِيَ بِالرَّجُلِ فَقَالَ ‏"‏ أَمَّا الْجُبَّةُ فَاخْلَعْهَا وَأَمَّا الطِّيبُ فَاغْسِلْهُ ثُمَّ أَحْدِثْ إِحْرَامًا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ ‏"‏ ثُمَّ أَحْدِثْ إِحْرَامًا ‏"‏ ‏.‏ مَا أَعْلَمُ أَحَدًا قَالَهُ غَيْرَ نُوحِ بْنِ حَبِيبٍ وَلاَ أَحْسِبُهُ مَحْفُوظًا وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{2668}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Safwan bin Umayyah, from his father that he said:"I wished that I could see the Messenger of Allah when Revelation was coming down to him. While we were in Al-Jirranah and the Prophet was in a tent, Revelation was coming down to him and 'Umar gestured to me to come. So I put my head into the tent. A man had come to him who had entered Ihram wearing a said: 'O Messenger of Allah, what do you say concerning a man who entered Ihram wearing a Jubbah?'Then (because of this question) the Revelation came. The Prophet started to breath deeply, and when it was over he said: 'Where is the man who asked me just now?' The man was brought to him, and he saidA: 'As for the Jubbah, take it off, and as for the perfume, wash it off, then enter Ihram.'''(Sahih) Chatper 30. The Prohibiton Of Wearing A Shirt In Ihram}}
\hadithdefcmd{nasai}{2669}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْقُمُصَ وَلاَ الْعَمَائِمَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ إِلاَّ أَحَدٌ لاَ يَجِدُ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ تَلْبَسُوا شَيْئًا مَسَّهُ الزَّعْفَرَانُ وَلاَ الْوَرْسُ ‏"‏ ‏.‏\hadithno{2669}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:a man asked the Messenger of Allah "What clothes can the Muhrim wear?" The Messenger of Allah said: "They should not wear shirts nor 'Imamahs, or pants, or burnoues, or Khuffs - unless a person cannot find sandals, in which cause he may wear Khuffs. But he should cut them to come lower than the ankles. And they should not wear anything that has been touched by (dyed with) saffron or Wars}}
\hadithdefcmd{nasai}{2670}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ مَا نَلْبَسُ مِنَ الثِّيَابِ إِذَا أَحْرَمْنَا قَالَ ‏"‏ لاَ تَلْبَسُوا الْقَمِيصَ ‏"‏ ‏.‏ وَقَالَ عَمْرٌو مَرَّةً أُخْرَى ‏"‏ الْقُمُصَ وَلاَ الْعَمَائِمَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْخُفَّيْنِ إِلاَّ أَنْ لاَ يَكُونَ لأَحَدِكُمْ نَعْلاَنِ فَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ ثَوْبًا مَسَّهُ وَرْسٌ وَلاَ زَعْفَرَانٌ ‏"‏ ‏.‏\hadithno{2670}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that a man said:"O Messenger of Allah, what clothes should we wear when we enter Ihram?" He said: "Do not wear a shirt (or shirts), or 'Imamahs, or pants, or Khuffs unless someone Cannot find sandals, in which case he should cut them (the Khuffs) so that they come beneath the ankles or any garment that has been touched by (dyed with ) wars or saffron}}
\hadithdefcmd{nasai}{2671}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ وَهُوَ يَقُولُ ‏ "‏ السَّرَاوِيلُ لِمَنْ لاَ يَجِدُ الإِزَارَ وَالْخُفَّيْنِ لِمَنْ لاَ يَجِدُ النَّعْلَيْنِ ‏"‏ ‏.‏ لِلْمُحْرِمِ ‏.‏\hadithno{2671}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said; "I heard the Prophet delivering a khutbah and he said:'Pants (are allowed) for one who cannot find an Izar, and Khuffs for one who cannot find sandals to wear in Ihram.;;}}
\hadithdefcmd{nasai}{2672}{أَخْبَرَنِي أَيُّوبُ بْنُ مُحَمَّدٍ الْوَزَّانُ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ لَمْ يَجِدْ إِزَارًا فَلْيَلْبَسْ سَرَاوِيلَ وَمَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ ‏"‏ ‏.‏\hadithno{2672}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said; "I heard the Messenger of Allah say:'Whoever cannot find an Izar, let him wear pants, and whoever cannot find sandals, let him wear khuffs}}
\hadithdefcmd{nasai}{2673}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ مَاذَا تَأْمُرُنَا أَنْ نَلْبَسَ مِنَ الثِّيَابِ فِي الإِحْرَامِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْقَمِيصَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْعَمَائِمَ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ إِلاَّ أَنْ يَكُونَ أَحَدٌ لَيْسَتْ لَهُ نَعْلاَنِ فَلْيَلْبَسِ الْخُفَّيْنِ مَا أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ تَلْبَسُوا شَيْئًا مِنَ الثِّيَابِ مَسَّهُ الزَّعْفَرَانُ وَلاَ الْوَرْسُ وَلاَ تَنْتَقِبُ الْمَرْأَةُ الْحَرَامُ وَلاَ تَلْبَسُ الْقُفَّازَيْنِ ‏"‏ ‏.‏\hadithno{2673}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Umar said; "A man stood up and said:'O Messenger of Allah! What garments do you command us to wear in Ihran?' The Messenger of Allah said: 'Do not wear shirts or pants, or 'Imamahs, or burnouses, or Khuffs except if someone does not have sandals, in which case let him wear Khuffs that come below the ankles. And do not wear any garment that has been touched by (dyed with) saffron or Wars. And women should not cover their faces when in Ihram, or wear gloves}}
\hadithdefcmd{nasai}{2674}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْقَمِيصَ وَلاَ الْعَمَائِمَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ إِلاَّ أَحَدٌ لاَ يَجِدُ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ تَلْبَسُوا شَيْئًا مَسَّهُ الزَّعْفَرَانُ وَلاَ الْوَرْسُ ‏"‏ ‏.‏\hadithno{2674}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:a man asked the Messenger of Allah what clothes the Muhrim should wear? The Messenger of Allah said: "Do not wear shirts, or 'Imamahs, or pants, or burnouses, or Khuffs except if someone does not have sandals, in which case let him wear Khuffs, and cut them so that they come below the ankles. And do not wear any garment that has been touched by (dyed with) saffron or Wars}}
\hadithdefcmd{nasai}{2675}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، وَعَمْرُو بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا يَزِيدُ، وَهُوَ ابْنُ هَارُونَ قَالَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ الأَنْصَارِيُّ - عَنْ عُمَرَ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا نَلْبَسُ مِنَ الثِّيَابِ إِذَا أَحْرَمْنَا قَالَ ‏ "‏ لاَ تَلْبَسُوا الْقَمِيصَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْعَمَائِمَ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ إِلاَّ أَنْ يَكُونَ أَحَدٌ لَيْسَتْ لَهُ نَعْلاَنِ فَلْيَلْبَسِ الْخُفَّيْنِ أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ تَلْبَسُوا مِنَ الثِّيَابِ شَيْئًا مَسَّهُ وَرْسٌ وَلاَ زَعْفَرَانٌ ‏"‏ ‏.‏\hadithno{2675}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:a man asked the Messenger of Allah what garments we should wear when we enter Ihram. He said: "Do not wear shirts, or pants, or 'Imamahs, or burnouses, or Khuffs unless someone does not have any sandals, in which case he should wear Khuffs that come beneath the ankles. And do not wear any garment that has been touched by (dyed with) Wars or saffron}}
\hadithdefcmd{nasai}{2676}{أَخْبَرَنَا أَبُو الأَشْعَثِ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَادَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ فَقَالَ مَا نَلْبَسُ إِذَا أَحْرَمْنَا قَالَ ‏ "‏ لاَ تَلْبَسِ الْقَمِيصَ وَلاَ الْعِمَامَةَ وَلاَ السَّرَاوِيلَ وَلاَ الْبُرْنُسَ وَلاَ الْخُفَّيْنِ إِلاَّ أَنْ لاَ تَجِدَ نَعْلَيْنِ فَإِنْ لَمْ تَجِدِ النَّعْلَيْنِ فَمَا دُونَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{2676}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said; "A man came to the Prophet and said:'What should we wear when we enter Ihram?' He said: 'Do not wear a shirt, or an 'Imamah, or pants, or a burnouts, or Khuffs unless you cannot find any sandals. If you cannot find any sandals, then wear something that comes beneath the ankles}}
\hadithdefcmd{nasai}{2677}{أَخْبَرَنَا أَبُو الأَشْعَثِ، أَحْمَدُ بْنُ الْمِقْدَامِ قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَادَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ فَقَالَ مَا نَلْبَسُ إِذَا أَحْرَمْنَا قَالَ ‏ "‏ لاَ تَلْبَسِ الْقَمِيصَ وَلاَ الْعَمَائِمَ وَلاَ الْبَرَانِسَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْخِفَافَ إِلاَّ أَنْ لاَ يَكُونَ نِعَالٌ فَإِنْ لَمْ يَكُنْ نِعَالٌ فَخُفَّيْنِ دُونَ الْكَعْبَيْنِ وَلاَ ثَوْبًا مَصْبُوغًا بِوَرْسٍ أَوْ زَعْفَرَانٍ أَوْ مَسَّهُ وَرْسٌ أَوْ زَعْفَرَانٌ ‏"‏ ‏.‏\hadithno{2677}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"A man came to the Prophet and said: 'What should we wear when we enter Ihram?' He said: 'Do not wear shirts, or 'Imamahs, or burnouses, or pants, or Khuffs unless there are no sandals; if there are no sandals, then wear Khuffs that come beneath the ankles. And (do not wear) any garment that has been dyed with Wars or saffron, or has been touched by Wars or saffron}}
\hadithdefcmd{nasai}{2678}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ أَبِي زَائِدَةَ، قَالَ أَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَلْبَسُوا فِي الإِحْرَامِ الْقَمِيصَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْعَمَائِمَ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ ‏"‏ ‏.‏\hadithno{2678}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"I heard the Prophet say; 'do not wear shirts, or pants, or 'Imamahs, or burnouses, or Khuffs while in Ihram.'''(sahih)}}
\hadithdefcmd{nasai}{2679}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ أَنْبَأَنَا أَيُّوبُ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا لَمْ يَجِدْ إِزَارًا فَلْيَلْبَسِ السَّرَاوِيلَ وَإِذَا لَمْ يَجِدِ النَّعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{2679}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"I heard the Messenger of Allah say; 'If you cannot find an Izar then wear pants, and if you cannot find sandals then wear khuffs, but cut them so that they come lower than the ankles}}
\hadithdefcmd{nasai}{2680}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا لَمْ يَجِدِ الْمُحْرِمُ النَّعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{2680}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar:That the Prophet said "If a Muhrim cannot find sandals then let him wear Khuffs, and cut them, so that they come lower than the ankles}}
\hadithdefcmd{nasai}{2681}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، قَامَ فَقَالَ يَا رَسُولَ اللَّهِ مَاذَا تَأْمُرُنَا أَنْ نَلْبَسَ مِنَ الثِّيَابِ فِي الإِحْرَامِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْقُمُصَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْخِفَافَ إِلاَّ أَنْ يَكُونَ رَجُلٌ لَهُ نَعْلاَنِ فَلْيَلْبَسِ الْخُفَّيْنِ أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ يَلْبَسْ شَيْئًا مِنَ الثِّيَابِ مَسَّهُ الزَّعْفَرَانُ وَلاَ الْوَرْسُ وَلاَ تَنْتَقِبُ الْمَرْأَةُ الْحَرَامُ وَلاَ تَلْبَسُ الْقُفَّازَيْنِ ‏"‏ ‏.‏\hadithno{2681}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that a man stood up and said:"O Messenger of Allah! What garments do you command us to wear in Ihram?" The Messenger of Allah said; "Do not wear shirts, or pants, or Khuffs unless a man does not have any sandals, in which case he may wear Khuffs that come lower than the ankles. And do not wear any garment that has been touched by (dyed with) saffron or Wars. And a woman in Ihram should not cover her face or wear gloves}}
\hadithdefcmd{nasai}{2682}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أُخْتِهِ، حَفْصَةَ قَالَتْ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ مَا شَأْنُ النَّاسِ حَلُّوا وَلَمْ تَحِلَّ مِنْ عُمْرَتِكَ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي وَقَلَّدْتُ هَدْيِي فَلاَ أُحِلُّ حَتَّى أُحِلَّ مِنَ الْحَجِّ ‏"‏ ‏.‏\hadithno{2682}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that his sister, Hafsah, said; "I said to the Prophet;'O Messenger of Allah! Why is it that the people have exited Ihram and you have not exited Ihram following your 'Umrah?'He said:'I have matted my hair and garlanded my Hadi (sacrificial animal), so I will not exit Ihram until I exit Ihram after Hajj}}
\hadithdefcmd{nasai}{2683}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، وَاللَّفْظُ، لَهُ عَنِ ابْنِ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ مُلَبِّدًا ‏.‏\hadithno{2683}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that his father said:"I saw the Messenger of Allah entering Ihram with his hair matted}}
\hadithdefcmd{nasai}{2684}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ سَالِمٍ، عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ إِحْرَامِهِ حِينَ أَرَادَ أَنْ يُحْرِمَ وَعِنْدَ إِحْلاَلِهِ قَبْلَ أَنْ يُحِلَّ بِيَدَىَّ ‏.‏\hadithno{2684}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"I put perfume on the Messenger of Allah when he decided to enter Ihram, and when he exited Ihram, before he exited Ihram, with my own hand}}
\hadithdefcmd{nasai}{2685}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لإِحْرَامِهِ قَبْلَ أَنْ يُحْرِمَ وَلِحِلِّهِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ ‏.‏\hadithno{2685}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"I put perfume on the Messenger of Allah for his Ihram when he entered Ihram, and for his exiting Ihram when he had stoned Jamrat Al-Aqabah, before he circumambulated the House}}
\hadithdefcmd{nasai}{2686}{أَخْبَرَنَا حُسَيْنُ بْنُ مَنْصُورِ بْنِ جَعْفَرٍ النَّيْسَابُورِيُّ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لإِحْرَامِهِ قَبْلَ أَنْ يُحْرِمَ وَلِحِلِّهِ حِينَ أَحَلَّ ‏.‏\hadithno{2686}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"I put perfume on the Messenger of Allah for his Ihram before he entered Ihram, and for his exiting Ihram when he exited Ihram}}
\hadithdefcmd{nasai}{2687}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو عُبَيْدِ اللَّهِ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لِحُرْمِهِ حِينَ أَحْرَمَ وَلِحِلِّهِ بَعْدَ مَا رَمَى جَمْرَةَ الْعَقَبَةِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ ‏.‏\hadithno{2687}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I put perfume on the Messenger of Allah for his Ihram when he entered Ihram, and for his exiting Ihram when he had stoned Jamrat Al-Aqabah, before he circumambulated the House}}
\hadithdefcmd{nasai}{2688}{أَخْبَرَنَا عِيسَى بْنُ مُحَمَّدٍ أَبُو عُمَيْرٍ، عَنْ ضَمْرَةَ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لإِحْلاَلِهِ وَطَيَّبْتُهُ لإِحْرَامِهِ طِيبًا لاَ يُشْبِهُ طِيبَكُمْ هَذَا تَعْنِي لَيْسَ لَهُ بَقَاءٌ ‏.‏\hadithno{2688}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Aishah said:"I put perfume on the Messenger of Allah for his exiting Ihram, and I put perfume on him for his Ihram, perfume which was not like this perfume of yours" she meant that it does not last.(Shah)}}
\hadithdefcmd{nasai}{2689}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ قُلْتُ لِعَائِشَةَ بِأَىِّ شَىْءٍ طَيَّبْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَتْ بِأَطْيَبِ الطِّيبِ عِنْدَ حُرْمِهِ وَحِلِّهِ ‏.‏\hadithno{2689}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Uthman bin 'Urwah narrated that his father said:"I said to 'Aishah: 'What kind of perfume did you put on the Messenger of Allah?' she said: 'The best kind of perfume, when he entered Ihram and when he exited Ihram}}
\hadithdefcmd{nasai}{2690}{أَخْبَرَنَا أَحْمَدُ بْنُ يَحْيَى بْنِ الْوَزِيرِ بْنِ سُلَيْمَانَ، قَالَ أَنْبَأَنَا شُعَيْبُ بْنُ اللَّيْثِ، عَنْ أَبِيهِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُثْمَانَ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ إِحْرَامِهِ بِأَطْيَبِ مَا أَجِدُ ‏.‏\hadithno{2690}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"I used to put perfume on the Messenger of Allah when he entered Ihram, using the best perfume I could find}}
\hadithdefcmd{nasai}{2691}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِأَطْيَبِ مَا أَجِدُ لِحُرْمِهِ وَلِحِلِّهِ وَحِينَ يُرِيدُ أَنْ يَزُورَ الْبَيْتَ ‏.‏\hadithno{2691}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"I used to put perfume on the Messenger of Allah using the best I could find, when he entered Ihram and when he exited Ihram, and when he wanted to visit the House}}
\hadithdefcmd{nasai}{2692}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا مَنْصُورٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ، قَالَ قَالَتْ عَائِشَةُ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَبْلَ أَنْ يُحْرِمَ وَيَوْمَ النَّحْرِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ بِطِيبٍ فِيهِ مِسْكٌ ‏.‏\hadithno{2692}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Al-Qasim said:"'Aishah said: 'I put perfume on the Messenger of Allah (ﷺ) before he entered Ihram and on the Day of Sacrifice before he circumambulated the House, using perfume containing musk}}
\hadithdefcmd{nasai}{2693}{أَخْبَرَنَا أَحْمَدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْوَلِيدِ، - يَعْنِي الْعَدَنِيَّ - عَنْ سُفْيَانَ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ أَنْبَأَنَا إِسْحَاقُ، - يَعْنِي الأَزْرَقَ - قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ وَقَالَ أَحْمَدُ بْنُ نَصْرٍ فِي حَدِيثِهِ وَبِيصِ طِيبِ الْمِسْكِ فِي مَفْرِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2693}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"It is as if I can see the glistening of the perfume on the head of the Messenger of Allah when he is in Ihram." Ahmad bin Nasr (one of the narrators) said in his narration: "The glistening of the perfume of musk in the parting (of the hair) of the Messenger of Allah}}
\hadithdefcmd{nasai}{2694}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، قَالَ قَالَ لِي إِبْرَاهِيمُ حَدَّثَنِي الأَسْوَدُ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ لَقَدْ كَانَ يُرَى وَبِيصُ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2694}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The glistening of the perfume could be seen in the parting (of the hair) of the Messenger of Allah while he was in Ihram}}
\hadithdefcmd{nasai}{2695}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2695}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"It is as if I can see the glistening of the perfume on the head of the Messenger of Allah while he is in Ihram}}
\hadithdefcmd{nasai}{2696}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي أُصُولِ شَعْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2696}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:" I used to see the glistening of the perfume at the roots of the hair of the Messenger of Allah when he was in Ihram.(sahih)}}
\hadithdefcmd{nasai}{2697}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفْرِقِ رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2697}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"It is as if I can see the glistening of the perfume in the parting on the head of the Messenger of Allah when he was in Ihram.(Shah)}}
\hadithdefcmd{nasai}{2698}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ الْعَسْكَرِيُّ، قَالَ أَنْبَأَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ جَعْفَرٍ غُنْدَرٌ - عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُ وَبِيصَ الطِّيبِ فِي رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2698}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I saw the glistening of the perfume on the head of the Messenger of Allah while he was initiating Ihram}}
\hadithdefcmd{nasai}{2699}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُهِلُّ ‏.‏\hadithno{2699}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"It is as if I can see the glistening of the perfume in parting of the Messenger of Allah while he was in Ihram. (sahih)}}
\hadithdefcmd{nasai}{2700}{أَخْبَرَنَا قُتَيْبَةُ، وَهَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم وَقَالَ هَنَّادٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يُحْرِمَ ادَّهَنَ بِأَطْيَبِ مَا يَجِدُهُ حَتَّى أَرَى وَبِيصَهُ فِي رَأْسِهِ وَلِحْيَتِهِ ‏.‏ تَابَعَهُ إِسْرَائِيلُ عَلَى هَذَا الْكَلاَمِ وَقَالَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ عَنْ أَبِيهِ عَنْ عَائِشَةَ ‏.‏\hadithno{2700}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"When the Prophet and (in his narration) Hannad said: "The Messenger of Allah "wanted to enter Ihram, he would daub the best perfume that he could find, until I saw it glistening on his head and in his beard. (sahih)}}
\hadithdefcmd{nasai}{2701}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِأَطْيَبِ مَا كُنْتُ أَجِدُ مِنَ الطِّيبِ حَتَّى أَرَى وَبِيصَ الطِّيبِ فِي رَأْسِهِ وَلِحْيَتِهِ قَبْلَ أَنْ يُحْرِمَ ‏.‏\hadithno{2701}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"I used to put perfume on the Messenger of Allah using the best perfume I could find, until I saw the perfume glistening on his head and in his beard, before he entered Ihram}}
\hadithdefcmd{nasai}{2702}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُ وَبِيصَ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ ثَلاَثٍ ‏.‏\hadithno{2702}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:'I saw the glistening of the perfume in the parting of the Messenger of Allah after three (days)}}
\hadithdefcmd{nasai}{2703}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَرَى وَبِيصَ الطِّيبِ فِي مَفْرِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ ثَلاَثٍ ‏.‏\hadithno{2703}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:'I used to see the glistening of the perfume in the parting of the Messenger of Allah after three (days)}}
\hadithdefcmd{nasai}{2704}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ بِشْرٍ، - يَعْنِي ابْنَ الْمُفَضَّلِ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنِ الطِّيبِ، عِنْدَ الإِحْرَامِ فَقَالَ لأَنْ أَطَّلِيَ بِالْقَطِرَانِ أَحَبُّ إِلَىَّ مِنْ ذَلِكَ ‏.‏ فَذَكَرْتُ ذَلِكَ لِعَائِشَةَ فَقَالَتْ يَرْحَمُ اللَّهُ أَبَا عَبْدِ الرَّحْمَنِ لَقَدْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَيَطُوفُ فِي نِسَائِهِ ثُمَّ يُصْبِحُ يَنْضَحُ طِيبًا ‏.‏\hadithno{2704}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibrahim bin Al-Muntashir that his father said:"I asked Ibn 'Umar about wearing perfume when entering Ihram and he said: 'If I were to be daubed with tar that would be dearer to me than that, I mentioned that to 'Aishah and she said: 'May Allah have mercy on Abu 'Abdur-Rahman. I used to put perfume on the Messenger of Allah then he would go around his wives, then in the morning he would be smelling strongly of perfume}}
\hadithdefcmd{nasai}{2705}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ لأَنْ أُصْبِحَ مُطَّلِيًا بِقَطِرَانٍ أَحَبُّ إِلَىَّ مِنْ أَنْ أُصْبِحَ مُحْرِمًا أَنْضَحُ طِيبًا ‏.‏ فَدَخَلْتُ عَلَى عَائِشَةَ فَأَخْبَرْتُهَا بِقَوْلِهِ فَقَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَطَافَ فِي نِسَائِهِ ثُمَّ أَصْبَحَ مُحْرِمًا ‏.‏\hadithno{2705}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muhammad bin Ibrahim bin Al-Muntashir that his father said:"I heard Ibn 'Umar say: 'If I were to wake up daubed with tar, that would be dearer to me than waking up and entering Ihram smelling strongly of perfume.' I entered upon 'Aishah and told her what he had said. She said: 'I put perfume on the Messenger of Allah and he went around among his wives, then the next morning he entered Ihram}}
\hadithdefcmd{nasai}{2706}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ إِسْمَاعِيلَ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَتَزَعْفَرَ الرَّجُلُ ‏.‏\hadithno{2706}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas Said:"The Prophet forbade men to perfume themselves with saffron. (Shahih)}}
\hadithdefcmd{nasai}{2707}{أَخْبَرَنِي كَثِيرُ بْنُ عُبَيْدٍ، عَنْ بَقِيَّةَ، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّزَعْفُرِ ‏.‏\hadithno{2707}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah forbade perfuming oneself with saffron}}
\hadithdefcmd{nasai}{2708}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ التَّزَعْفُرِ ‏.‏ قَالَ حَمَّادٌ يَعْنِي لِلرِّجَالِ ‏.‏\hadithno{2708}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said that:the Messenger of Allah forbade perfuming oneself with saffron". Hammad said: "Meaning, for men}}
\hadithdefcmd{nasai}{2709}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم وَقَدْ أَهَلَّ بِعُمْرَةٍ وَعَلَيْهِ مُقَطَّعَاتٌ وَهُوَ مُتَضَمِّخٌ بِخَلُوقٍ فَقَالَ أَهْلَلْتُ بِعُمْرَةٍ فَمَا أَصْنَعُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا كُنْتَ صَانِعًا فِي حَجِّكَ ‏"‏ ‏.‏ قَالَ كُنْتُ أَتَّقِي هَذَا وَأَغْسِلُهُ ‏.‏ فَقَالَ ‏"‏ مَا كُنْتَ صَانِعًا فِي حَجِّكَ فَاصْنَعْهُ فِي عُمْرَتِكَ ‏"‏ ‏.‏\hadithno{2709}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Safwan bin Ya'la, from his father, that:a man came to the Prophet who had initiated Ihram for 'Umrah, wearing sewn garments and having put on Khaluq. He said: "I have initiated Ihram for 'Umrah, so what should I do?" The Prophet said: "What would you do if you were doing Hajj?" He said: "I would avoid this and wash it off." He said: "Whatever you would do for Hajj, do it, for 'Umrah," (sahih)}}
\hadithdefcmd{nasai}{2710}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ قَيْسَ بْنَ سَعْدٍ، يُحَدِّثُ عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، قَالَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم رَجُلٌ وَهُوَ بِالْجِعِرَّانَةِ وَعَلَيْهِ جُبَّةٌ وَهُوَ مُصَفِّرٌ لِحْيَتَهُ وَرَأْسَهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَحْرَمْتُ بِعُمْرَةٍ وَأَنَا كَمَا تَرَى فَقَالَ ‏ "‏ انْزِعْ عَنْكَ الْجُبَّةَ وَاغْسِلْ عَنْكَ الصُّفْرَةَ وَمَا كُنْتَ صَانِعًا فِي حَجَّتِكَ فَاصْنَعْهُ فِي عُمْرَتِكَ ‏"‏ ‏.‏\hadithno{2710}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated f rom Safwan bin Ya'la that his father saide:"A man came to the Messenger of Allah when he was in Al-Jirranah wearing a Jubnah, and having applied Khauq to his beard and head. He said: 'O Messenger of Allah! I have entered Ihram for 'Umrah and I am as you see.' He said: 'Take off the Jubbah and wash off the perfume, and whatever you would do for Hajj, do it for 'Umrah}}
\hadithdefcmd{nasai}{2711}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نُبَيْهِ بْنِ وَهْبٍ، عَنْ أَبَانَ بْنِ عُثْمَانَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمُحْرِمِ ‏ "‏ إِذَا اشْتَكَى رَأْسَهُ وَعَيْنَيْهِ أَنْ يُضَمِّدَهُمَا بِصَبِرٍ ‏"‏ ‏.‏\hadithno{2711}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abn bin 'Uthman that his father said:'the messenger of Allah said concerning a Muhrim whose head or yes hurt: 'Let him smudge them with aloes, (sahih):}}
\hadithdefcmd{nasai}{2712}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، أَتَيْنَا جَابِرًا فَسَأَلْنَاهُ عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ لَمْ أَسُقِ الْهَدْىَ وَجَعَلْتُهَا عُمْرَةً فَمَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ فَلْيُحْلِلْ وَلْيَجْعَلْهَا عُمْرَةً ‏"‏ ‏.‏ وَقَدِمَ عَلِيٌّ رضى الله عنه مِنَ الْيَمَنِ بِهَدْىٍ وَسَاقَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ هَدْيًا وَإِذَا فَاطِمَةُ قَدْ لَبِسَتْ ثِيَابًا صَبِيغًا وَاكْتَحَلَتْ ‏.‏ قَالَ فَانْطَلَقْتُ مُحَرِّشًا أَسْتَفْتِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ فَاطِمَةَ لَبِسَتْ ثِيَابًا صَبِيغًا وَاكْتَحَلَتْ وَقَالَتْ أَمَرَنِي بِهِ أَبِي صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ صَدَقَتْ صَدَقَتْ صَدَقَتْ أَنَا أَمَرْتُهَا ‏"‏ ‏.‏\hadithno{2712}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ja'far bin Muhammad said; " My father said:'We came to Jabir and asked him about the Hajj of the Prophet. He told us that the Messenger of Allah said: "Had I known when I set out what I know now, I would have brought the Jadi (sacrificial animal ) with me and I would not have made it 'Umrah. Whoever does not have a Jadi with him, let him exit Ihram and make it 'Umrah," 'Ali may Allah be ;eased with him, came from Yemen with a Hadi, and the Messenger of Allah brought a Hadi from Al-Madinah, Fatimah had put on a dyed garment and applied kohl to her eyes, and he ('Ali) said: "I went to the Prophet to complain about that and find out whether she could do that, I said: 'O Messenger of Allah, Fatima had put on a dyed garment and applied kohl to her eyes, and she said, the Messenger of Allah told me to do that. 'He said: 'She is telling the truth, she is telling the truth, I told her to do that}}
\hadithdefcmd{nasai}{2713}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا بِشْرٍ، يُحَدِّثُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، وَقَعَ عَنْ رَاحِلَتِهِ، فَأَقْعَصَتْهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَيُكَفَّنُ فِي ثَوْبَيْنِ خَارِجًا رَأْسُهُ وَوَجْهُهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏\hadithno{2713}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that:a man fell from his mount and it trampled him. The Messenger of Allah said: "Wash him with water and lotus leaves, and he should be shrouded in two clothes, leaving his head and face bare, for he will be raised on the Day of Resurrection reciting the Talbiyah."(sahih)}}
\hadithdefcmd{nasai}{2714}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الصَّفَّارُ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، - يَعْنِي الْحَفَرِيَّ - عَنْ سُفْيَانَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَاتَ رَجُلٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثِيَابِهِ وَلاَ تُخَمِّرُوا وَجْهَهُ وَرَأْسَهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏\hadithno{2714}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas Said:" A man died, and the Messenger of Allah said: wash him with water and lotus leaves, and shroud him in his cloths, but do not cover his head and face, for he will be raised on the Day of Resurrection reciting the Talbiyah}}
\hadithdefcmd{nasai}{2715}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفْرَدَ الْحَجَّ ‏.‏\hadithno{2715}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Shadh; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that:the Messenger of Allah performed Hajj only (Ifrad)}}
\hadithdefcmd{nasai}{2716}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ ‏.‏\hadithno{2716}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) entered Ihram for Hajj (only)}}
\hadithdefcmd{nasai}{2717}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، عَنْ حَمَّادٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُوَافِينَ لِهِلاَلِ ذِي الْحِجَّةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَاءَ أَنْ يُهِلَّ بِحَجٍّ فَلْيُهِلَّ وَمَنْ شَاءَ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهِلَّ بِعُمْرَةٍ ‏"‏ ‏.‏\hadithno{2717}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"We went out with the Messenger of Allah around the time of the new moon of Dhul-Hijjah, and the Messenger of Allah said: 'Whoever wishes to enter Ihram for Hajj, let him do so , and whoever wishes to enter Ihram for 'Umrah, let him do so}}
\hadithdefcmd{nasai}{2718}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ الطَّبَرَانِيُّ أَبُو بَكْرٍ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي مَنْصُورٌ، وَسُلَيْمَانُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نَرَى إِلاَّ أَنَّهُ الْحَجُّ ‏.‏\hadithno{2718}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"We set out with the Messenger of Allah (ﷺ) thinking that it was for nothing other than Hajj}}
\hadithdefcmd{nasai}{2719}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ الصُّبَىُّ بْنُ مَعْبَدٍ كُنْتُ أَعْرَابِيًّا نَصْرَانِيًّا فَأَسْلَمْتُ فَكُنْتُ حَرِيصًا عَلَى الْجِهَادِ فَوَجَدْتُ الْحَجَّ وَالْعُمْرَةَ مَكْتُوبَيْنِ عَلَىَّ فَأَتَيْتُ رَجُلاً مِنْ عَشِيرَتِي يُقَالُ لَهُ هُذَيْمُ بْنُ عَبْدِ اللَّهِ فَسَأَلْتُهُ فَقَالَ اجْمَعْهُمَا ثُمَّ اذْبَحْ مَا اسْتَيْسَرَ مِنَ الْهَدْىِ فَأَهْلَلْتُ بِهِمَا فَلَمَّا أَتَيْتُ الْعُذَيْبَ لَقِيَنِي سَلْمَانُ بْنُ رَبِيعَةَ وَزَيْدُ بْنُ صُوحَانَ وَأَنَا أُهِلُّ بِهِمَا فَقَالَ أَحَدُهُمَا لِلآخَرِ مَا هَذَا بِأَفْقَهَ مِنْ بَعِيرِهِ ‏.‏ فَأَتَيْتُ عُمَرَ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ إِنِّي أَسْلَمْتُ وَأَنَا حَرِيصٌ عَلَى الْجِهَادِ وَإِنِّي وَجَدْتُ الْحَجَّ وَالْعُمْرَةَ مَكْتُوبَيْنِ عَلَىَّ فَأَتَيْتُ هُذَيْمَ بْنَ عَبْدِ اللَّهِ فَقُلْتُ يَا هَنَّاهُ إِنِّي وَجَدْتُ الْحَجَّ وَالْعُمْرَةَ مَكْتُوبَيْنِ عَلَىَّ ‏.‏ فَقَالَ اجْمَعْهُمَا ثُمَّ اذْبَحْ مَا اسْتَيْسَرَ مِنَ الْهَدْىِ فَأَهْلَلْتُ بِهِمَا فَلَمَّا أَتَيْنَا الْعُذَيْبَ لَقِيَنِي سَلْمَانُ بْنُ رَبِيعَةَ وَزَيْدُ بْنُ صُوحَانَ فَقَالَ أَحَدُهُمَا لِلآخَرِ مَا هَذَا بِأَفْقَهَ مِنْ بَعِيرِهِ ‏.‏ فَقَالَ عُمَرُ هُدِيتَ لِسُنَّةِ نَبِيِّكَ صلى الله عليه وسلم ‏.‏\hadithno{2719}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Wail said:"As-subai bin Mabad said: 'I was a Christian Bedouin, then I became Muslim. I was keen to go for Jihad but I learned that Hajj and "Umrah had been enjoined on me, I went to a man of my clan who was called Huraim bin 'Abdullah and asked him, and he said: "Put them together, then slaughter whatever you can of the Hadi, so I entered Ihram for bother together, and when I came to al-'Udhaib, I was met by Salman bin Rabiah and Zaid bin Suhan, while I was uttering the Talbiyah for bothe. One of them said to the other: "He does not understand more than his camel!: I came to 'Umar and said: "O Commander of the Believers! I have become Muslim and I am keen to go for Jihad, but I learned that Hajj and "Umrah were enjoined on me, so I went to Huraim bin 'Abdullah and said: "Hey you! I have learned that Hajj, and 'Umrah have been enjoined on me. He said: 'Put them together then slaughter whatever you can of the Jade' so I entered Ihram for both together, and when I came to Al-Udhaib I was met by Salman bin Rabiah and Zaid bin Suhan, and one of them said to the other: 'He does not understand more than his camel,''' 'Umar said: "You have been guided to the Sunnah of your Prophet}}
\hadithdefcmd{nasai}{2720}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُصْعَبُ بْنُ الْمِقْدَامِ، عَنْ زَائِدَةَ، عَنْ مَنْصُورٍ، عَنْ شَقِيقٍ، قَالَ أَنْبَأَنَا الصُّبَىُّ، فَذَكَرَ مِثْلَهُ قَالَ فَأَتَيْتُ عُمَرَ فَقَصَصْتُ عَلَيْهِ الْقِصَّةَ إِلاَّ قَوْلَهُ يَا هَنَّاهُ ‏.‏\hadithno{2720}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) that shaqiq said; a "As-Subai told us something similar, and he said:'I came to 'Umar and told him the story, apart from the words: 'Hey you}}
\hadithdefcmd{nasai}{2721}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ أَنْبَأَنَا شُعَيْبٌ، - يَعْنِي ابْنَ إِسْحَاقَ - قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، ح وَأَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي حَسَنُ بْنُ مُسْلِمٍ، عَنْ مُجَاهِدٍ، وَغَيْرِهِ، عَنْ رَجُلٍ، مِنْ أَهْلِ الْعِرَاقِ يُقَالُ لَهُ شَقِيقُ بْنُ سَلَمَةَ أَبُو وَائِلٍ أَنَّ رَجُلاً مِنْ بَنِي تَغْلِبَ يُقَالُ لَهُ الصُّبَىُّ بْنُ مَعْبَدٍ وَكَانَ نَصْرَانِيًّا فَأَسْلَمَ فَأَقْبَلَ فِي أَوَّلِ مَا حَجَّ فَلَبَّى بِحَجٍّ وَعُمْرَةٍ جَمِيعًا فَهُوَ كَذَلِكَ يُلَبِّي بِهِمَا جَمِيعًا فَمَرَّ عَلَى سَلْمَانَ بْنِ رَبِيعَةَ وَزَيْدِ بْنِ صُوحَانَ فَقَالَ أَحَدُهُمَا لأَنْتَ أَضَلُّ مِنْ جَمَلِكَ هَذَا ‏.‏ فَقَالَ الصُّبَىُّ فَلَمْ يَزَلْ فِي نَفْسِي حَتَّى لَقِيتُ عُمَرَ بْنَ الْخَطَّابِ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ هُدِيتَ لِسُنَّةِ نَبِيِّكَ صلى الله عليه وسلم ‏.‏ قَالَ شَقِيقٌ وَكُنْتُ أَخْتَلِفُ أَنَا وَمَسْرُوقُ بْنُ الأَجْدَعِ إِلَى الصُّبَىِّ بْنِ مَعْبَدٍ نَسْتَذْكِرُهُ فَلَقَدِ اخْتَلَفْنَا إِلَيْهِ مِرَارًا أَنَا وَمَسْرُوقُ بْنُ الأَجْدَعِ ‏.‏\hadithno{2721}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Mujahid and others, from a man from the people of Al-Iraq who was called Shaqiq bin Salmah Abu Wail, that:there was a man from Banu Taghlib, who was called As-Subai bin Mabad, who had been a Christian, then became of Muslim.The first time he went for Hajj, he recited the Talbiyah Hajj and "Umrah together, and he continued to recite the Talbiyah for them together, He passed by Salman bin Rabiah and Zaid bin suhan, and one to then said; "You are more lost than this camel of yours." As-Subai" said: "This upset me until I met 'Umar bin Al-Khattab, and I mentioned that to him. He said: 'Yuou have been guided to the sunnah of your Prophet shaqiq said: "Masruq bin Al-Ajda and I often used to visit As-Subai bin Ma'bad and talk with him}}
\hadithdefcmd{nasai}{2722}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا عِيسَى، - وَهُوَ ابْنُ يُونُسَ - قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ مَرْوَانَ بْنِ الْحَكَمِ، قَالَ كُنْتُ جَالِسًا عِنْدَ عُثْمَانَ فَسَمِعَ عَلِيًّا، يُلَبِّي بِعُمْرَةٍ وَحَجَّةٍ فَقَالَ أَلَمْ تَكُنْ تُنْهَى عَنْ هَذَا قَالَ بَلَى وَلَكِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُلَبِّي بِهِمَا جَمِيعًا فَلَمْ أَدَعْ قَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِقَوْلِكَ ‏.‏\hadithno{2722}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Marwan bin Al-Hakam said:"I was sitting with 'Uthan and he heard 'Ali reciting the Talbiyah for "Umrah and Hajj (together). He said 'Were you not forbidden to do this?' He said: 'Yes, but I heard the Messenger of "Allah reciting the Talbiyah for them together, and I will not igore what the Messenger of Allah said in favor of what you say}}
\hadithdefcmd{nasai}{2723}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو عَامِرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ عَلِيَّ بْنَ حُسَيْنٍ، يُحَدِّثُ عَنْ مَرْوَانَ، أَنَّ عُثْمَانَ، نَهَى عَنِ الْمُتْعَةِ، وَأَنْ يَجْمَعَ الرَّجُلُ بَيْنَ الْحَجِّ وَالْعُمْرَةِ فَقَالَ عَلِيٌّ لَبَّيْكَ بِحَجَّةٍ وَعُمْرَةٍ مَعًا ‏.‏ فَقَالَ عُثْمَانُ أَتَفْعَلُهَا وَأَنَا أَنْهَى عَنْهَا فَقَالَ عَلِيٌّ لَمْ أَكُنْ لأَدَعَ سُنَّةَ رَسُولِ اللَّهِ صلى الله عليه وسلم لأَحَدٍ مِنَ النَّاسِ ‏.‏\hadithno{2723}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Hakam said:"I heard 'Ali binHusain narrating from Marwan, that 'Uthman forbade Mut'ah and joining Hajj and "Umrah. 'Ali said; 'Labbaika bi Hajjatin wa 'Umratin ma'an Here I am, (O Allah) for Hajj and "Umrah together. 'Uthman said: 'Are you doing this when I have forbidden it?' 'Ali said; 'I will not give up the Summah of the Messenger of Allah for any of the people}}
\hadithdefcmd{nasai}{2724}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ، عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{2724}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Shu'bah narrated:A similar report was narrated from Shu'bah with the same chain}}
\hadithdefcmd{nasai}{2725}{أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، قَالَ حَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا يُونُسُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كُنْتُ مَعَ عَلِيِّ بْنِ أَبِي طَالِبٍ حِينَ أَمَّرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْيَمَنِ فَلَمَّا قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَ عَلِيٌّ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ صَنَعْتَ ‏"‏ ‏.‏ قُلْتُ أَهْلَلْتُ بِإِهْلاَلِكَ ‏.‏ قَالَ ‏"‏ فَإِنِّي سُقْتُ الْهَدْىَ وَقَرَنْتُ ‏"‏ ‏.‏ قَالَ وَقَالَ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ لَفَعَلْتُ كَمَا فَعَلْتُمْ وَلَكِنِّي سُقْتُ الْهَدْىَ وَقَرَنْتُ ‏"‏ ‏.‏\hadithno{2725}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Al-Bara said:"I was with 'Ali bin Abi Talib when the Messenger of All appointed him as governor of Yemen. When he came to the Messenger of Allah, Ali said: 'I came to the Messenger of and the Messenger of Allah said: "What did you do?" I said; "I entered Ihram for that for which you entered Ihram." He said: "I have brought the Hadi and am performing Qiran" And he said to his companions: "If I had known what I know now, I would have done what you have done, but I brought the Hadi and I am performing Qiran}}
\hadithdefcmd{nasai}{2726}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي حُمَيْدُ بْنُ هِلاَلٍ، قَالَ سَمِعْتُ مُطَرِّفًا، يَقُولُ قَالَ لِي عِمْرَانُ بْنُ حُصَيْنٍ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ حَجٍّ وَعُمْرَةٍ ثُمَّ تُوُفِّيَ قَبْلَ أَنْ يَنْهَى عَنْهَا وَقَبْلَ أَنْ يَنْزِلَ الْقُرْآنُ بِتَحْرِيمِهِ ‏.‏\hadithno{2726}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Imran bin Husain said:"The Messenger of Allah combined Hajj and "Umrah, then he passed away before he could forbid that, and before Qur'an was revealed forbidding it}}
\hadithdefcmd{nasai}{2727}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ بَيْنَ حَجٍّ وَعُمْرَةٍ ثُمَّ لَمْ يَنْزِلْ فِيهَا كِتَابٌ وَلَمْ يَنْهَ عَنْهُمَا النَّبِيُّ صلى الله عليه وسلم قَالَ فِيهِمَا رَجُلٌ بِرَأْيِهِ مَا شَاءَ ‏.‏\hadithno{2727}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Imran:That the Messenger of Allah combined Hajj and "Umrah, then no Qur'an was revealed concerning that, and the Prophet did not forbid it, regardless of what one man may say}}
\hadithdefcmd{nasai}{2728}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ وَاسِعٍ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ لِي عِمْرَانُ بْنُ حُصَيْنٍ تَمَتَّعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ إِسْمَاعِيلُ بْنُ مُسْلِمٍ ثَلاَثَةٌ هَذَا أَحَدُهُمْ لاَ بَأْسَ بِهِ وَإِسْمَاعِيلُ بْنُ مُسْلِمٍ شَيْخٌ يَرْوِي عَنْ أَبِي الطُّفَيْلِ لاَ بَأْسَ بِهِ وَإِسْمَاعِيلُ بْنُ مُسْلِمٍ يَرْوِي عَنِ الزُّهْرِيِّ وَالْحَسَنِ مَتْرُوكُ الْحَدِيثِ ‏.‏\hadithno{2728}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Mutarrif bin `Abdullah said:"`Imran bin Husain said to me: 'We performed Tamattu` with the Messenger of Allah (ﷺ).'" Abu Abdur-Rahman (An-Nasa'i) said: There are three (named) Isma`il bin Muslim; this is one of them, and there is no harm in him. And Shaikh Isma`il bin Muslim who reports from Abu Tufail, there is no harm in him. And Isma`il bin Muslim who reports from Az-Zuhri and Al-Hasan, he is abandoned in Hadith}}
\hadithdefcmd{nasai}{2729}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، عَنْ هُشَيْمٍ، عَنْ يَحْيَى، وَعَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، وَحُمَيْدٍ الطَّوِيلِ، ح وَأَنْبَأَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، وَحُمَيْدٌ الطَّوِيلُ، وَيَحْيَى بْنُ أَبِي إِسْحَاقَ، كُلُّهُمْ عَنْ أَنَسٍ، سَمِعُوهُ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَبَّيْكَ عُمْرَةً وَحَجًّا لَبَّيْكَ عُمْرَةً وَحَجًّا ‏"‏ ‏.‏\hadithno{2729}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"I heard the Messenger of Allah 'Labbaika 'Umratan wa Hajjan ma'an, Iabbaika 'Umratan wa Hajjan ma'an (Here I am (O Allah) for "Umrah and Hajj together, here I am (O Allah) for "Umrah and Hajj together}}
\hadithdefcmd{nasai}{2730}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي أَسْمَاءَ، عَنْ أَنَسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُلَبِّي بِهِمَا ‏.‏\hadithno{2730}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"I heard the Messenger of Allah (ﷺ) reciting the Talbiyah for them both}}
\hadithdefcmd{nasai}{2731}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، قَالَ أَنْبَأَنَا بَكْرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، قَالَ سَمِعْتُ أَنَسًا، يُحَدِّثُ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يُلَبِّي بِالْعُمْرَةِ وَالْحَجِّ جَمِيعًا فَحَدَّثْتُ بِذَلِكَ ابْنَ عُمَرَ فَقَالَ لَبَّى بِالْحَجِّ وَحْدَهُ ‏.‏ فَلَقِيتُ أَنَسًا فَحَدَّثْتُهُ بِقَوْلِ ابْنِ عُمَرَ فَقَالَ أَنَسٌ مَا تَعُدُّونَا إِلاَّ صِبْيَانًا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَبَّيْكَ عُمْرَةً وَحَجًّا مَعًا ‏"‏ ‏.‏\hadithno{2731}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Bakr bin 'Abdullah Al-Muzani said:"Anas said: 'I heard the Prophet reciting the Talbiyah for 'Umrah and Hajj together. I told Ibn 'Umar about that and he said: "He recited the Talbiyah for Hajj only. I met Anas and told him what Ibn 'Umar had said, and Anas said: "do you think of us as no more than children? I heard the Messenger of Allah say: 'Labbaika 'Umratan wa Hajjan ma'an (Here I am (O allah) for 'Umrah and Hajj together) (sahih)}}
\hadithdefcmd{nasai}{2732}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، رضى الله عنهما قَالَ تَمَتَّعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ بِالْعُمْرَةِ إِلَى الْحَجِّ وَأَهْدَى وَسَاقَ مَعَهُ الْهَدْىَ بِذِي الْحُلَيْفَةِ وَبَدَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَهَلَّ بِالْعُمْرَةِ ثُمَّ أَهَلَّ بِالْحَجِّ وَتَمَتَّعَ النَّاسُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْعُمْرَةِ إِلَى الْحَجِّ فَكَانَ مِنَ النَّاسِ مَنْ أَهْدَى فَسَاقَ الْهَدْىَ وَمِنْهُمْ مَنْ لَمْ يُهْدِ فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ قَالَ لِلنَّاسِ ‏ "‏ مَنْ كَانَ مِنْكُمْ أَهْدَى فَإِنَّهُ لاَ يَحِلُّ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى يَقْضِيَ حَجَّهُ وَمَنْ لَمْ يَكُنْ أَهْدَى فَلْيَطُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ وَلْيُقَصِّرْ وَلْيَحْلِلْ ثُمَّ لْيُهِلَّ بِالْحَجِّ ثُمَّ لْيُهْدِ وَمَنْ لَمْ يَجِدْ هَدْيًا فَلْيَصُمْ ثَلاَثَةَ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةً إِذَا رَجَعَ إِلَى أَهْلِهِ ‏"‏ ‏.‏ فَطَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ قَدِمَ مَكَّةَ وَاسْتَلَمَ الرُّكْنَ أَوَّلَ شَىْءٍ ثُمَّ خَبَّ ثَلاَثَةَ أَطْوَافٍ مِنَ السَّبْعِ وَمَشَى أَرْبَعَةَ أَطْوَافٍ ثُمَّ رَكَعَ حِينَ قَضَى طَوَافَهُ بِالْبَيْتِ فَصَلَّى عِنْدَ الْمَقَامِ رَكْعَتَيْنِ ثُمَّ سَلَّمَ فَانْصَرَفَ فَأَتَى الصَّفَا فَطَافَ بِالصَّفَا وَالْمَرْوَةِ سَبْعَةَ أَطْوَافٍ ثُمَّ لَمْ يَحِلَّ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى قَضَى حَجَّهُ وَنَحَرَ هَدْيَهُ يَوْمَ النَّحْرِ وَأَفَاضَ فَطَافَ بِالْبَيْتِ ثُمَّ حَلَّ مِنْ كُلِّ شَىْءٍ حَرُمَ مِنْهُ وَفَعَلَ مِثْلَ مَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ أَهْدَى وَسَاقَ الْهَدْىَ مِنَ النَّاسِ ‏.‏\hadithno{2732}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim bin 'Abdullah that 'Abdullah bin 'Umar said; "during the Farewell Pilgrimage, the Messenger of Allah benefited from performing 'Umrah and then Hajj, and he brought a Hadi (sacrificial animal )with him from dhul-Hulaifah. The Messenger of Allah entered Ihram for 'Umrah frist, them for Hajj, and the people also benefited by entering Ihram for 'Umrah first, then for Hajj. Some of the people brought the Hadi and carried it along with them, and other s did not. When the Messenger of Allah came to Makkah, he said to the people:'Whoever among you has brought a Hadi, nothing is permissible for him that became forbidden when he entered Ihram, until he has finished his Hajj, Whoever did not find a Hadi, let him fast for three days during the Hajj, and for seven when he returns to his family, the Messenger of Allah performed Tawaf when he came to Makkah and touched the corner (where the Black Stone is) first of all, then he walked rapidly during the first three of the seven circles, and walked daring the last four. After he finished circumambulating the House he prayed two Rak'ahs at Maqam Ibrahim. Then he went to As-Safa and walked seven rounds between As-Safa and Al-Marwah. And he did not do any action that was forbidden because of Ihram until he had completed his Hajj and slaughtered his Hadi on the Day of sacrifice. Then he hastened onward (toard Makkah) and circumambulated the House. Then everything that had been forbidden because of Ihram became permissible. And those who had brought the Hadi with them did the same as the Messenger of Allah did}}
\hadithdefcmd{nasai}{2733}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ حَرْمَلَةَ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ حَجَّ عَلِيٌّ وَعُثْمَانُ فَلَمَّا كُنَّا بِبَعْضِ الطَّرِيقِ نَهَى عُثْمَانُ عَنِ التَّمَتُّعِ فَقَالَ عَلِيٌّ إِذَا رَأَيْتُمُوهُ قَدِ ارْتَحَلَ فَارْتَحِلُوا ‏.‏ فَلَبَّى عَلِيٌّ وَأَصْحَابُهُ بِالْعُمْرَةِ فَلَمْ يَنْهَهُمْ عُثْمَانُ فَقَالَ عَلِيٌّ أَلَمْ أُخْبَرْ أَنَّكَ تَنْهَى عَنِ التَّمَتُّعِ قَالَ بَلَى ‏.‏ قَالَ لَهُ عَلِيٌّ أَلَمْ تَسْمَعْ رَسُولَ اللَّهِ صلى الله عليه وسلم تَمَتَّعَ قَالَ بَلَى ‏.‏\hadithno{2733}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'ced bin Al-Musayyab said:"Ali and 'Uthman performed Hajj, and when we were partway there, 'Uthman forbade Tamattu, 'Ali said 'When you see him setting out, set out with him (saying the Talbiyah for 'Umrah)So 'Ali and his companions recited the Talbiyah for 'Umrah, and 'Uthman did not forbid them. 'Ali said: 'Have I not been told that you did.' Ali said to him: 'Did you not hear that the Messenger of Allah did Tamattu? He said: 'Of course}}
\hadithdefcmd{nasai}{2734}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلِ بْنِ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ، أَنَّهُ حَدَّثَهُ أَنَّهُ، سَمِعَ سَعْدَ بْنَ أَبِي وَقَّاصٍ، وَالضَّحَّاكَ بْنَ قَيْسٍ، - عَامَ حَجَّ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ - وَهُمَا يَذْكُرَانِ التَّمَتُّعَ بِالْعُمْرَةِ إِلَى الْحَجِّ فَقَالَ الضَّحَّاكُ لاَ يَصْنَعُ ذَلِكَ إِلاَّ مَنْ جَهِلَ أَمْرَ اللَّهِ تَعَالَى ‏.‏ فَقَالَ سَعْدٌ بِئْسَمَا قُلْتَ يَا ابْنَ أَخِي ‏.‏ قَالَ الضَّحَّاكُ فَإِنَّ عُمَرَ بْنَ الْخَطَّابِ نَهَى عَنْ ذَلِكَ ‏.‏ قَالَ سَعْدٌ قَدْ صَنَعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَنَعْنَاهَا مَعَهُ ‏.‏\hadithno{2734}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Muhammad bin 'Abdullah bin Al-Harith bin Nawfal bin Al-Harith bin 'Abdul-Muttalib that:during the year that Mu'awiyah bin abi sufyan performed Hajj, he heard Sa'd bin Abi Waqqas and Ad-Dahhak bin Qais talking about joining 'Umrah to Hajj (Tamattu) Ad-Dahhak said: "none does that but one who is ignorant of the ruling of Allah." Sa'd said: "What a bad thing to say, O son of my brother!" Ad-Dahhak said: "Umar bin Al-Khattab forbade that." Sa'd daid: "The Messenger of Allah did that and we did it with him}}
\hadithdefcmd{nasai}{2735}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي مُوسَى، عَنْ أَبِي مُوسَى، أَنَّهُ كَانَ يُفْتِي بِالْمُتْعَةِ فَقَالَ لَهُ رَجُلٌ رُوَيْدَكَ بِبَعْضِ فُتْيَاكَ فَإِنَّكَ لاَ تَدْرِي مَا أَحْدَثَ أَمِيرُ الْمُؤْمِنِينَ فِي النُّسُكِ بَعْدُ ‏.‏ حَتَّى لَقِيتُهُ فَسَأَلْتُهُ فَقَالَ عُمَرُ قَدْ عَلِمْتُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ فَعَلَهُ وَلَكِنْ كَرِهْتُ أَنْ يَظَلُّوا مُعَرِّسِينَ بِهِنَّ فِي الأَرَاكِ ثُمَّ يَرُوحُوا بِالْحَجِّ تَقْطُرُ رُءُوسُهُمْ ‏.‏\hadithno{2735}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Musa said that:he used to issue Fatwas concerning Tamattu' Then a man said to him: "Withhold some of your Fatwas ,for you do not know what the commander of the Believers introduced into the rites subsequently." Then when I met him, I asked him. 'Umar said: "I know that the Messenger of Allah and his companions did it, but I did not like that people should lay with their wives in the shade of the Arak trees, and then go out for Hajj with their heads dripping}}
\hadithdefcmd{nasai}{2736}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ أَنْبَأَنَا أَبِي قَالَ، أَنْبَأَنَا أَبُو حَمْزَةَ، عَنْ مُطَرِّفٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ عُمَرَ، يَقُولُ وَاللَّهِ إِنِّي لأَنْهَاكُمْ عَنِ الْمُتْعَةِ، وَإِنَّهَا، لَفِي كِتَابِ اللَّهِ وَلَقَدْ فَعَلَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْنِي الْعُمْرَةَ فِي الْحَجِّ ‏.‏\hadithno{2736}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"I heard 'Umar say" 'By Allah, I forbid you to forbid you to perform Tamattur,' but it is mentioned in the Book of Allah and the Messenger of Allah did it" meaning 'Umrah with Hajj}}
\hadithdefcmd{nasai}{2737}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ حُجَيْرٍ، عَنْ طَاوُسٍ، قَالَ قَالَ مُعَاوِيَةُ لاِبْنِ عَبَّاسٍ أَعَلِمْتَ أَنِّي قَصَّرْتُ مِنْ رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم عِنْدَ الْمَرْوَةِ قَالَ لاَ ‏.‏ يَقُولُ ابْنُ عَبَّاسٍ هَذَا مُعَاوِيَةُ يَنْهَى النَّاسَ عَنِ الْمُتْعَةِ وَقَدْ تَمَتَّعَ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{2737}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Tawus said:"Mu'awiyah saide to Ibmn 'Abbas: "do you know that I cut the hair of the Messenger of Allah at Al-Marwah?" He said: "No." Ibn 'Abbas said: "This Mu'awiyah forbids the people to perform Tamattu' but the Prophet performed Tamattue}}
\hadithdefcmd{nasai}{2738}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ قَيْسٍ، وَهُوَ ابْنُ مُسْلِمٍ عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ بِالْبَطْحَاءِ فَقَالَ ‏"‏ بِمَا أَهْلَلْتَ ‏"‏ ‏.‏ قُلْتُ أَهْلَلْتُ بِإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ هَلْ سُقْتَ مِنْ هَدْىٍ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَطُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ حِلَّ ‏"‏ ‏.‏ فَطُفْتُ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ أَتَيْتُ امْرَأَةً مِنْ قَوْمِي فَمَشَطَتْنِي وَغَسَلَتْ رَأْسِي فَكُنْتُ أُفْتِي النَّاسَ بِذَلِكَ فِي إِمَارَةِ أَبِي بَكْرٍ وَإِمَارَةِ عُمَرَ وَإِنِّي لَقَائِمٌ بِالْمَوْسِمِ إِذْ جَاءَنِي رَجُلٌ فَقَالَ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثَ أَمِيرُ الْمُؤْمِنِينَ فِي شَأْنِ النُّسُكِ ‏.‏ قُلْتُ يَا أَيُّهَا النَّاسُ مَنْ كُنَّا أَفْتَيْنَاهُ بِشَىْءٍ فَلْيَتَّئِدْ فَإِنَّ أَمِيرَ الْمُؤْمِنِينَ قَادِمٌ عَلَيْكُمْ فَائْتَمُّوا بِهِ فَلَمَّا قَدِمَ قُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَا هَذَا الَّذِي أَحْدَثْتَ فِي شَأْنِ النُّسُكِ قَالَ إِنْ نَأْخُذْ بِكِتَابِ اللَّهِ عَزَّ وَجَلَّ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَالَ ‏\{‏ وَأَتِمُّوا الْحَجَّ وَالْعُمْرَةَ لِلَّهِ ‏\}‏ وَإِنْ نَأْخُذْ بِسُنَّةِ نَبِيِّنَا صلى الله عليه وسلم فَإِنَّ نَبِيَّنَا صلى الله عليه وسلم لَمْ يَحِلَّ حَتَّى نَحَرَ الْهَدْىَ ‏.‏\hadithno{2738}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"I came to the Messenger of Allah when he was in Al-Batha', and he said: 'For what have you entered Ihram?' I said: 'I have entered Ihram for that for which the Proper had entered Ihram,' He said: 'Have you brought a hadi (sacrifical animal)?' I said: 'No.' He said: 'Then circumambulate the House and (perform Sa) between As-Safa and Al-Marwah, then exit Ihram, so I circumambulated the House and (performed Sa i) between As-Safa and Al-Marwah, then went to a woman of my people and she combed and washed my hair, I used to issue Fatwas to the people based on that, during the Khilafah of Abu Bakr and 'Umar. Then one day during Hajj season a man came to me and said: 'You do not know what the commander of the Believers has introduced concerning the rites. I said: O people, whoever heard our heard our Fatwa, let him not rush to follow it, for the commander of the Believers! Is coming to you, and you should follow him. When he came, I said: O Commander of the Believers! What is this that you have introduced concerning the rites? He said: If we follow the Book of Allah, then Allah, the Mighty and Sublime, says: 'And complete the Hajj and 'Umrah for Allah. And if we follow the sunnah of our Prophet then our Prophet did not exit Ihram until he had slaughtered the Hadi (sacrificial animal) (sahih)}}
\hadithdefcmd{nasai}{2739}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ، عَنْ مُحَمَّدِ بْنِ وَاسِعٍ، عَنْ مُطَرِّفٍ، قَالَ قَالَ لِي عِمْرَانُ بْنُ حُصَيْنٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ تَمَتَّعَ وَتَمَتَّعْنَا مَعَهُ قَالَ فِيهَا قَائِلٌ بِرَأْيِهِ ‏.‏\hadithno{2739}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Mutarrif said:"Imran bin Husain said to me; 'The Messenger of Allah performed 'Umrah and Hajj together, and we performed 'Umrah and Hajj together with him, and whoever says anything different, that is his own personal opinion}}
\hadithdefcmd{nasai}{2740}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، أَتَيْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَسَأَلْنَاهُ عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَكَثَ بِالْمَدِينَةِ تِسْعَ حِجَجٍ ثُمَّ أُذِّنَ فِي النَّاسِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَاجِّ هَذَا الْعَامِ فَنَزَلَ الْمَدِينَةَ بَشَرٌ كَثِيرٌ كُلُّهُمْ يَلْتَمِسُ أَنْ يَأْتَمَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَيَفْعَلُ مَا يَفْعَلُ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ وَخَرَجْنَا مَعَهُ قَالَ جَابِرٌ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا عَلَيْهِ يَنْزِلُ الْقُرْآنُ وَهُوَ يَعْرِفُ تَأْوِيلَهُ وَمَا عَمِلَ بِهِ مِنْ شَىْءٍ عَمِلْنَا فَخَرَجْنَا لاَ نَنْوِي إِلاَّ الْحَجَّ ‏.‏\hadithno{2740}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ja`far bin Muhammad said:"My father told me: 'We came to Jabir bin `Abdullah and asked him about the Hajj of the Prophet (ﷺ). He told us: The Messenger of Allah (ﷺ) stayed in al-Madinah for nine years of Hajj, then it was announced to the people that the Messenger of Allah (ﷺ) was going to perform Hajj this year. Many people came to al-Madinah, all of them hoping to learn from the Messenger of Allah (ﷺ) and to do as he did. The Messenger of Allah (ﷺ) set out when there were five days left of Dhul-Qa`dah, and we set out with him,: Jabir said; "And the Messenger of Allah was among us; the Qur'an was being revealed to him, and he knew what it meant. Whatever he did based on it (the Qur'an), we did, and we set out with no intention other than Hajj}}
\hadithdefcmd{nasai}{2741}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لِمُحَمَّدٍ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا لاَ نَنْوِي إِلاَّ الْحَجَّ فَلَمَّا كُنَّا بِسَرِفَ حِضْتُ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ أَحِضْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ إِنَّ هَذَا شَىْءٌ كَتَبَهُ اللَّهُ عَزَّ وَجَلَّ عَلَى بَنَاتِ آدَمَ فَاقْضِي مَا يَقْضِي الْمُحْرِمُ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ ‏"‏ ‏.‏\hadithno{2741}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"We set out with no intention other than Hajj. And when we were in Sarif, my menses came. The Messenger of Allah entered upon me while I was weeping, and he said: 'Have your menses come?' I said; 'Yes.' He said; 'That is something that Allah, the Mightily and Sublime, has decreed for the daughters of Adam. Do everything that the pilgrim in Ihram does, but do not circumambulate the House}}
\hadithdefcmd{nasai}{2742}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي قَيْسُ بْنُ مُسْلِمٍ، قَالَ سَمِعْتُ طَارِقَ بْنَ شِهَابٍ، قَالَ قَالَ أَبُو مُوسَى أَقْبَلْتُ مِنَ الْيَمَنِ وَالنَّبِيُّ صلى الله عليه وسلم مُنِيخٌ بِالْبَطْحَاءِ حَيْثُ حَجَّ فَقَالَ ‏"‏ أَحَجَجْتَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ لَبَّيْكَ بِإِهْلاَلٍ كَإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ فَطُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ وَأَحِلَّ ‏"‏ ‏.‏ فَفَعَلْتُ ثُمَّ أَتَيْتُ امْرَأَةً فَفَلَتْ رَأْسِي فَجَعَلْتُ أُفْتِي النَّاسَ بِذَلِكَ حَتَّى كَانَ فِي خِلاَفَةِ عُمَرَ فَقَالَ لَهُ رَجُلٌ يَا أَبَا مُوسَى رُوَيْدَكَ بَعْضَ فُتْيَاكَ فَإِنَّكَ لاَ تَدْرِي مَا أَحْدَثَ أَمِيرُ الْمُؤْمِنِينَ فِي النُّسُكِ بَعْدَكَ ‏.‏ قَالَ أَبُو مُوسَى يَا أَيُّهَا النَّاسُ مَنْ كُنَّا أَفْتَيْنَاهُ فَلْيَتَّئِدْ فَإِنَّ أَمِيرَ الْمُؤْمِنِينَ قَادِمٌ عَلَيْكُمْ فَائْتَمُّوا بِهِ ‏.‏ وَقَالَ عُمَرُ إِنْ نَأْخُذْ بِكِتَابِ اللَّهِ فَإِنَّهُ يَأْمُرُنَا بِالتَّمَامِ وَإِنْ نَأْخُذْ بِسُنَّةِ النَّبِيِّ صلى الله عليه وسلم فَإِنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَحِلَّ حَتَّى بَلَغَ الْهَدْىُ مَحِلَّهُ ‏.‏\hadithno{2742}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Musa said:"I came from Yemen and the Prophet had stopped in Al-Batha at the time to Hajj. He asked: 'Have you performed Hajj?' I said: 'Yes, He said: 'What did you say?' I said; 'Labbaika bi ihlal ka ihlal in-nabiy (Here I am (O Allah, entering Ihram for that for which the Prophet entered Ihram). He said 'Circumambulate the House and (perform Sa) between As-Safa and Al-Marwah, and exit Ihram.' Then I went to a woman who combed my hair. I started to issue Fatwas to the people based on that. Then during the Khilafah of 'Umar, a man said to me: 'O abu Musa, withhold some of our Fatwas from us, for you do not know what the Commander of the Believers has introduced into the rites after you.''' Abu Musa said: "O people, O people, whoever heard our Fatwa,let him not rush to follow it, for the Commander of the Believers is coming to your and you should follow him.: 'Umar said: "If we follow the Book of Allah, then indeed He commands us to complete Hajj and 'Umrah, and the Messenger of Allah did not exit Ihram until the Hadi had reached its place}}
\hadithdefcmd{nasai}{2743}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، أَتَيْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَسَأَلْنَاهُ عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم فَحَدَّثَنَا أَنَّ عَلِيًّا قَدِمَ مِنَ الْيَمَنِ بِهَدْىٍ وَسَاقَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ هَدْيًا قَالَ لِعَلِيٍّ ‏"‏ بِمَا أَهْلَلْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُمَّ إِنِّي أُهِلُّ بِمَا أَهَلَّ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعِيَ الْهَدْىُ ‏.‏ قَالَ ‏"‏ فَلاَ تَحِلَّ ‏"‏ ‏.‏\hadithno{2743}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ja'far bin Muhammad said:"My father told us: 'we came to Jabir bin'Abdullah and asked him about the Hajj of the Prophet, He told us: "Ali came from Yemen with a Hadi, and the Messenger of Allah brought a Hadi from al-Madinah. He said to ail; 'For what have you entered Ihram?' He said: I 'I said: "O Allah, I am entering Ihram for that for which the Messenger of Allah entered Ihram," and I have the Hadi with me.' He said: 'Do not exit Ihram}}
\hadithdefcmd{nasai}{2744}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا شُعَيْبٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ عَطَاءٌ قَالَ جَابِرٌ قَدِمَ عَلِيٌّ مِنْ سِعَايَتِهِ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِمَا أَهْلَلْتَ يَا عَلِيُّ ‏"‏ ‏.‏ قَالَ بِمَا أَهَلَّ بِهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ فَاهْدِ وَامْكُثْ حَرَامًا كَمَا أَنْتَ ‏"‏ ‏.‏ قَالَ وَأَهْدَى عَلِيٌّ لَهُ هَدْيًا ‏.‏\hadithno{2744}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir said:"Ali came from collecting Zakah and the Prophet said to him: "For what have you entered Ihram, O 'Ali?' he said: 'For that for which the Messenger of Allah entered Ihram.' He said: 'Then offer the Hadi and remain in Ihram as you are.' So 'Ali offered a Hadi}}
\hadithdefcmd{nasai}{2745}{أَخْبَرَنِي أَحْمَدُ بْنُ مُحَمَّدِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كُنْتُ مَعَ عَلِيٍّ حِينَ أَمَّرَهُ النَّبِيُّ صلى الله عليه وسلم عَلَى الْيَمَنِ فَأَصَبْتُ مَعَهُ أَوَاقِيَ فَلَمَّا قَدِمَ عَلِيٌّ عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَ عَلِيٌّ وَجَدْتُ فَاطِمَةَ قَدْ نَضَحَتِ الْبَيْتَ بِنَضُوحٍ قَالَ فَتَخَطَّيْتُهُ فَقَالَتْ لِي مَا لَكَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَمَرَ أَصْحَابَهُ فَأَحَلُّوا قَالَ قُلْتُ إِنِّي أَهْلَلْتُ بِإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ لِي ‏"‏ كَيْفَ صَنَعْتَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أَهْلَلْتُ بِمَا أَهْلَلْتَ ‏.‏ قَالَ ‏"‏ فَإِنِّي قَدْ سُقْتُ الْهَدْىَ وَقَرَنْتُ ‏"‏ ‏.‏\hadithno{2745}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Al-Bara' said:"I was with 'Ali when the Messenger of Allah appointed him as governor of Yemen. When 'Ali came to the Messenger of Allah, 'Ali said: 'I found that Fatimah had perfumed the house with perfume.' He said: 'I tried to avoid it, and she said to me: what is the matter with you? The messenger of Allah told his Companions to exit Ihram.' He said: 'I said: I have entered Ihram for that for which the Prophet entered Ihram."" He said: 'So I went to the Prophet and he said to me: "What did you do?" I said: "I entered Ihram for that for which you entered Ihram." He said: "I have brought the Hadi and am performing Qiran}}
\hadithdefcmd{nasai}{2746}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، أَرَادَ الْحَجَّ عَامَ نَزَلَ الْحَجَّاجُ بِابْنِ الزُّبَيْرِ فَقِيلَ لَهُ إِنَّهُ كَائِنٌ بَيْنَهُمْ قِتَالٌ وَأَنَا أَخَافُ أَنْ يَصُدُّوكَ ‏.‏ قَالَ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ إِذًا أَصْنَعَ كَمَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنِّي أُ��ْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ عُمْرَةً ‏.‏ ثُمَّ خَرَجَ حَتَّى إِذَا كَانَ بِظَاهِرِ الْبَيْدَاءِ قَالَ مَا شَأْنُ الْحَجِّ وَالْعُمْرَةِ إِلاَّ وَاحِدٌ أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ حَجًّا مَعَ عُمْرَتِي ‏.‏ وَأَهْدَى هَدْيًا اشْتَرَاهُ بِقُدَيْدٍ ثُمَّ انْطَلَقَ يُهِلُّ بِهِمَا جَمِيعًا حَتَّى قَدِمَ مَكَّةَ فَطَافَ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ وَلَمْ يَزِدْ عَلَى ذَلِكَ وَلَمْ يَنْحَرْ وَلَمْ يَحْلِقْ وَلَمْ يُقَصِّرْ وَلَمْ يَحِلَّ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى كَانَ يَوْمُ النَّحْرِ فَنَحَرَ وَحَلَقَ فَرَأَى أَنْ قَدْ قَضَى طَوَافَ الْحَجِّ وَالْعُمْرَةِ بِطَوَافِهِ الأَوَّلِ وَقَالَ ابْنُ عُمَرَ كَذَلِكَ فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2746}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Nafi that:Ibn 'Umar wanted to perform Hajj in the year when Al-Hajjaj was besieging Ibn Az-Zubair, and it was said to him: "It seems that there will be fighting between them, and I am afraid that you will prevented from performing Hajj." He said: "In the messenger of Allah you have a good example. I am going to do what the Messenger of Allah did. I bear witness to you that I have resolved to perform 'Umrah." Then he set out, and when he was in Zahir Al-Baida, he said: "Hajj and Umrah are the same thing; I bear witness to you that I have resolved to perform Hajj with my 'Umrah." And he brought along a Hadi (sacrificial animal) that he had bought in Qudaid. Then he set out and entered Ihram for them both. When he came to Makkah he circumambulated the House and (did sa'i) between As-Safa and Al-Marwah. Then he did not do any thing more than that, and he did not offer a sacrifice, or shave his head, or cut his hair; he remained in Ihram until the Day of Sacrifice. Then he slaughtered his Hadi and shaved his head, and he thought that he had completed the Tawaf of Hajj and 'Umrah in the first Tawaf. Ibn 'Umar said: "That is what the Messenger of Allah did}}
\hadithdefcmd{nasai}{2747}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ إِنَّ سَالِمًا أَخْبَرَنِي أَنَّ أَبَاهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ يَقُولُ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ وَإِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ كَانَ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْكَعُ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ ثُمَّ إِذَا اسْتَوَتْ بِهِ النَّاقَةُ قَائِمَةً عِنْدَ مَسْجِدِ ذِي الْحُلَيْفَةِ أَهَلَّ بِهَؤُلاَءِ الْكَلِمَاتِ ‏.‏\hadithno{2747}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Shihab said:"Salim told me that his father said: "I heard the Messenger of Allah say the Talbiyah: "Labbaika Allahumma Labbaik, Labbaika La sharika laka Labbaik. Innal-hamda wan-ni'mata laka wal-mulk, la sharika lak (Here I am, O Allah, here I am. Here I am, You have no partner, here I am. Verily all praise and blessings are Yours, and all sovereignty, You have no partner)." 'Abdullah bin 'Umar used to say: "The Messenger of Allah used to pray two Rak'ahs in Dhul-Hulaifah, then when his she-camel stood up straight with him at the Masjid of Dhul-Hulaifah, he would enter Ihram saying these words}}
\hadithdefcmd{nasai}{2748}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ زَيْدًا، وَأَبَا، بَكْرٍ ابْنَىْ مُحَمَّدِ بْنِ زَيْدٍ أَنَّهُمَا سَمِعَا نَافِعًا، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏\hadithno{2748}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Prophet used to say:"Labbaika Allahumma Labbaik, Labbaika la sharika laka labbaik. Innal-hamda wan-ni'mata laka wal-mulk, la sharika lak (Here I am, O Allah, here I am. Here I am, You have no partner, here I am. Verily all praise and blessings are Yours, and all sovereignty, You have no partner)}}
\hadithdefcmd{nasai}{2749}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ تَلْبِيَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏\hadithno{2749}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"The Talbiyah of the Messenger of Allah was: "Labbaika Allahumma Labbaik, Labbaika la sharika laka labbaik. Innal-hamda wan-ni'mata laka wal-mulk, la sharika lak (Here I am, O Allah, here I am. Here I am, You have no partner, here I am. Verily all praise and blessings are Yours, and all sovereignty, You have no partner)}}
\hadithdefcmd{nasai}{2750}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا أَبُو بِشْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ كَانَتْ تَلْبِيَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ وَزَادَ فِيهِ ابْنُ عُمَرَ لَبَّيْكَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ فِي يَدَيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏.‏\hadithno{2750}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah bin 'Umar that his father said:"The Talbiyah of the Messenger of Allah was: "Labbaika Allahumma Labbaik, Labbaika la sharika laka labbaik. Innal-hamda wan-ni'mata laka wal-mulk, la sharika lak (Here I am, O Allah, here I am. Here I am, You have no partner, here I am. Verily all praise and blessings are Yours, and all sovereignty, You have no partner)." And Ibn 'Umar added: "Labbaika Labbaika wasa'daika wal-khayr fi yadika, warraghba' ilaika wal-'aml (Here I am, here I am, and at Your service; all good is in Your hands, seeking Your pleasure and striving for Your sake)}}
\hadithdefcmd{nasai}{2751}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدَةَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبَانَ بْنِ تَغْلِبَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ مِنْ تَلْبِيَةِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ ‏"‏ ‏.‏\hadithno{2751}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Masud said:"Part of the Talbiyah of the Messenger of Allah was 'Labbaika Allahumma labbbaik, Labbaika la sharika laka labbaik, Innal-hamda wan-ni'mata laka wal-mulk, (Here I am, O Allah, here I am. Here I am, You have no partner, here I am. Verily all praise and blessings are Yours)}}
\hadithdefcmd{nasai}{2752}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ مِنْ تَلْبِيَةِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لَبَّيْكَ إِلَهَ الْحَقِّ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ أَعْلَمُ أَحَدًا أَسْنَدَ هَذَا عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ إِلاَّ عَبْدَ الْعَزِيزِ رَوَاهُ إِسْمَاعِيلُ بْنُ أُمَيَّةَ عَنْهُ مُرْسَلاً ‏.‏\hadithno{2752}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"Part of the Talbiyah of the Messenger of Allah was: 'Labbaika ilahal-haqq (Here I am, O God of truth)." (Sahih) Abu 'Abdur-Rahman (An-Nasa'i) said: I do not know of anyone who narrated a chain for this from 'Abdullah bin Al-Fadl except for 'Abdul-Aziz. Ismail bin Umayyah reported it from him in Mursal form}}
\hadithdefcmd{nasai}{2753}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرٍ، عَنْ خَلاَّدِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ جَاءَنِي جِبْرِيلُ فَقَالَ لِي يَا مُحَمَّدُ مُرْ أَصْحَابَكَ أَنْ يَرْفَعُوا أَصْوَاتَهُمْ بِالتَّلْبِيَةِ ‏"‏ ‏.‏\hadithno{2753}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Khallad bin As-Sa'ib, from his father that the Messenger of Allah said:"Jibril came to me and said: 'O Muhammad! Tell your Companions to rise their voices when reciting the Talbiyah}}
\hadithdefcmd{nasai}{2754}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ السَّلاَمِ، عَنْ خُصَيْفٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهَلَّ فِي دُبُرِ الصَّلاَةِ ‏.‏\hadithno{2754}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas:That the Messenger of Allah began the Talbiyah following the prayer}}
\hadithdefcmd{nasai}{2755}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَنْبَأَنَا النَّضْرُ، قَالَ حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الظُّهْرَ بِالْبَيْدَاءِ ثُمَّ رَكِبَ وَصَعِدَ جَبَلَ الْبَيْدَاءِ وَأَهَلَّ بِالْحَجِّ وَالْعُمْرَةِ حِينَ صَلَّى الظُّهْرَ ‏.‏\hadithno{2755}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas:That the Messenger of Allah prayed Zuhr in Al-Baida', then he mounted and rode up the mountain of Al-Baida', and he began the Talbiyah for Hajj and 'Umar when he had prayed Zuhr}}
\hadithdefcmd{nasai}{2756}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ، قَالَ أَنْبَأَنَا شُعَيْبٌ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ جَعْفَرَ بْنَ مُحَمَّدٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ جَابِرٍ، فِي حَجَّةِ النَّبِيِّ صلى الله عليه وسلم فَلَمَّا أَتَى ذَا الْحُلَيْفَةِ صَلَّى وَهُوَ صَامِتٌ حَتَّى أَتَى الْبَيْدَاءَ ‏.‏\hadithno{2756}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir:Concerning the Hajj of the Prophet, that when he came to Dhul-Hulaifah, he prayed and then he remained silent until he came to Al-Baida}}
\hadithdefcmd{nasai}{2757}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ، أَنَّهُ سَمِعَ أَبَاهُ، يَقُولُ بَيْدَاؤُكُمْ هَذِهِ الَّتِي تَكْذِبُونَ فِيهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ مِنْ مَسْجِدِ ذِي الْحُلَيْفَةِ ‏.‏\hadithno{2757}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that he heard his father say:"This baida' of yours where you are telling lies about the Messenger of Allah; the Messenger of Allah never began the Talbiyah except from the Masjid at Dhul-Hulaifah}}
\hadithdefcmd{nasai}{2758}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْكَبُ رَاحِلَتَهُ بِذِي الْحُلَيْفَةِ ثُمَّ يُهِلُّ حِينَ تَسْتَوِي بِهِ قَائِمَةً ‏.‏\hadithno{2758}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Shihab that Salim bin 'Abdullah told him that 'Abdullah bin 'Umar said:"I saw the Messenger of Allah riding his mount in Dhul-Hulaifah, then he began the Talbiyah when it stood up with him}}
\hadithdefcmd{nasai}{2759}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ أَنْبَأَنَا شُعَيْبٌ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي صَالِحُ بْنُ كَيْسَانَ، ح وَأَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْحَاقُ يَعْنِي ابْنَ يُوسُفَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يُخْبِرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَهَلَّ حِينَ اسْتَوَتْ بِهِ رَاحِلَتُهُ ‏.‏\hadithno{2759}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar:That he used to narrate that the Prophet began the Talbiyah when his mount stood up with him}}
\hadithdefcmd{nasai}{2760}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ أَنْبَأَنَا ابْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ، وَابْنِ، جُرَيْجٍ وَابْنِ إِسْحَاقَ وَمَالِكِ بْنِ أَنَسٍ عَنِ الْمَقْبُرِيِّ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَأَيْتُكَ تُهِلُّ إِذَا اسْتَوَتْ بِكَ نَاقَتُكَ ‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُهِلُّ إِذَا اسْتَوَتْ بِهِ نَاقَتُهُ وَانْبَعَثَتْ ‏.‏\hadithno{2760}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ubaid bin Jraij said:"I said to Ibn 'Umar: 'I saw you begin the Talbiyah when your she-camel stood up with you. He said: "The Messenger of Allah used to begin the Talbiyah when his she-camel stood up with him}}
\hadithdefcmd{nasai}{2761}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم تِسْعَ سِنِينَ لَمْ يَحُجَّ ثُمَّ أَذَّنَ فِي النَّاسِ بِالْحَجِّ فَلَمْ يَبْقَ أَحَدٌ يَقْدِرُ أَنْ يَأْتِيَ رَاكِبًا أَوْ رَاجِلاً إِلاَّ قَدِمَ فَتَدَارَكَ النَّاسُ لِيَخْرُجُوا مَعَهُ حَتَّى جَاءَ ذَا الْحُلَيْفَةِ فَوَلَدَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ اغْتَسِلِي وَاسْتَثْفِرِي بِثَوْبٍ ثُمَّ أَهِلِّي ‏"‏ ‏.‏ فَفَعَلَتْ مُخْتَصَرٌ ‏.‏\hadithno{2761}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah stayed for nine years during which he did not perform Hajj. Then it was announced among the people the he was going for Hajj. No one who was able to come riding or on foot stayed behind, and the people rushed to go out with him until he came to Dhul-Hulaifah. Asam' bint 'Umais gave birth to Muhammad bin Abi Bakr and she sent word to the messenger of Allah (Asking what she should do). He said: 'Perform Ghusl and wrap a cloth around your private parts, then begin the Talbiyah.' So she did that." An abridgment}}
\hadithdefcmd{nasai}{2762}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، رضى الله عنه قَالَ نَفَسَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم تَسْأَلُهُ كَيْفَ تَفْعَلُ فَأَمَرَهَا أَنْ تَغْتَسِلَ وَتَسْتَثْفِرَ بِثَوْبِهَا وَتُهِلَّ ‏.‏\hadithno{2762}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"Asma' bint 'Umais gave birth to Muhammad bin Abi Bakr and she sent word to the Messenger of Allah asking him what she should do. He told here to perform Ghusl and wrap her private parts in a cloth, and to begin the talbiyah}}
\hadithdefcmd{nasai}{2763}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَقْبَلْنَا مُهِلِّينَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِحَجٍّ مُفْرَدٍ وَأَقْبَلَتْ عَائِشَةُ مُهِلَّةً بِعُمْرَةٍ حَتَّى إِذَا كُنَّا بِسَرِفَ عَرَكَتْ حَتَّى إِذَا قَدِمْنَا طُفْنَا بِالْكَعْبَةِ وَبِالصَّفَا وَالْمَرْوَةِ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَحِلَّ مِنَّا مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ قَالَ فَقُلْنَا حِلُّ مَاذَا قَالَ ‏"‏ الْحِلُّ كُلُّهُ ‏"‏ ‏.‏ فَوَاقَعْنَا النِّسَاءَ وَتَطَيَّبْنَا بِالطِّيبِ وَلَبِسْنَا ثِيَابَنَا وَلَيْسَ بَيْنَنَا وَبَيْنَ عَرَفَةَ إِلاَّ أَرْبَعُ لَيَالٍ ثُمَّ أَهْلَلْنَا يَوْمَ التَّرْوِيَةِ ثُمَّ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عَائِشَةَ فَوَجَدَهَا تَبْكِي فَقَالَ ‏"‏ مَا شَأْنُكِ ‏"‏ ‏.‏ فَقَالَتْ شَأْنِي أَنِّي قَدْ حِضْتُ وَقَدْ حَلَّ النَّاسُ وَلَمْ أُحْلِلْ وَلَمْ أَطُفْ بِالْبَيْتِ وَالنَّاسُ يَذْهَبُونَ إِلَى الْحَجِّ الآنَ ‏.‏ فَقَالَ ‏"‏ إِنَّ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ فَاغْتَسِلِي ثُمَّ أَهِلِّي بِالْحَجِّ ‏"‏ ‏.‏ فَفَعَلَتْ ‏.‏ وَوَقَفَتِ الْمَوِاقِفَ حَتَّى إِذَا طَهُرَتْ طَافَتْ بِالْكَعْبَةِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ قَالَ ‏"‏ قَدْ حَلَلْتِ مِنْ حَجَّتِكِ وَعُمْرَتِكِ جَمِيعًا ‏"‏ ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أَجِدُ فِي نَفْسِي أَنِّي لَمْ أَطُفْ بِالْبَيْتِ حَتَّى حَجَجْتُ ‏.‏ قَالَ ‏"‏ فَاذْهَبْ بِهَا يَا عَبْدَ الرَّحْمَنِ فَأَعْمِرْهَا مِنَ التَّنْعِيمِ ‏"‏ ‏.‏ وَذَلِكَ لَيْلَةَ الْحَصْبَةِ ‏.‏\hadithno{2763}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"We came in Ihram with the Messenger of Allah for Hajj alone (Mufrad), and 'Aishah came in Ihram for 'Umrah. Then, whe we were in Sarif her menses started. When we came, we circumambulated the Ka'bah and (performed Sa'i) between As-safa and Al-Marwah. Then, the Messenger of Allah commanded those of us who did not have a Hadi to exit Ihram. We said: 'Exit Ihram to what degree?' He said" 'Completely.' So we had intercourse with out, wives put on perfume, and wore only four nights away from 'Arafat. The, we entered Ihram on the day of At-Tarwiyah. The Messenger of Allah entered upon 'Aishah and found here weeping. He said: 'What is the matter with you?' She said: 'I have got my menses and the people exited Ihram, but I did not exit Ihram or did I circumambulate the House, and the people are going for Hajj now.' He said: 'This is something that Allah ahs decreed for the daughters of Adam. Perform Ghusl, then begin the Talbiyah for Hajj.' So she did that and did all the rituals. Then, when she became pure, she circumambulated the House and (Performed Sa'i) between As-Safa and Al-Marwah. Then, he said: 'You have exited Ihram from your Hajj and your 'Umrah at the same time." She said: 'O Messenger of Allah, I feel upset because I only circumambulated the House during my Hajj.' He said: 'Take here, O 'Abdullah, to perform 'Umrah from At-Tan'im.' And that was on the night of Al-Hasbah (the twelfth night of Dhul-Hijjah)}}
\hadithdefcmd{nasai}{2764}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ فَأَهْلَلْنَا بِعُمْرَةٍ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُهْلِلْ بِالْحَجِّ مَعَ الْعُمْرَةِ ثُمَّ لاَ يَحِلُّ حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ ‏.‏ فَقَدِمْتُ مَكَّةَ وَأَنَا حَائِضٌ فَلَمْ أَطُفْ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَشَكَوْتُ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْقُضِي رَأْسَكِ وَامْتَشِطِي وَأَهِلِّي بِالْحَجِّ وَدَعِي الْعُمْرَةَ ‏"‏ ‏.‏ فَفَعَلْتُ فَلَمَّا قَضَيْتُ الْحَجَّ أَرْسَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ إِلَى التَّنْعِيمِ فَاعْتَمَرْتُ قَالَ ‏"‏ هَذِهِ مَكَانُ عُمْرَتِكِ ‏"‏ ‏.‏ فَطَافَ الَّذِينَ أَهَلُّوا بِالْعُمْرَةِ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ حَلُّوا ثُمَّ طَافُوا طَوَافًا آخَرَ بَعْدَ أَنْ رَجَعُوا مِنْ مِنًى لِحَجِّهِمْ وَأَمَّا الَّذِينَ جَمَعُوا الْحَجَّ وَالْعُمْرَةَ فَإِنَّمَا طَافُوا طَوَافًا وَاحِدًا ‏.‏\hadithno{2764}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"We set out with the Messenger of Allah for the Farewell Pligrimage and we entered Ihram for 'Umrah, then the Messenger of Allah said: 'Whoever has a Hadi with him, let him enter Ihram for both Hajj and 'Umrah, then do not exit Ihram until he exits Ihram for them both.' I came to Makkah and I had my menses, so I did not circumambulate the House or (Perform Sa'i) between As-Safa and Al-Marwah. I complained about that to the Messenger of Allah and he said: 'Undo your hair, and comb it, and enter Ihram for Hajj, and leave 'Umrah.' When I had completed Hajj, the Messenger of Allah sent me with 'Abdur-Rahman bin Abi Bakr to At-Tan'im, and I performed 'Umrah. He said: 'This is the place of your 'Umrah.' Then those who had entered Ihram for 'Umar circumambulated the House and (performed Sa'i) between As-Safa and Al-Marwah. Then they exited Ihram, then they performed Tawaf again, after they came back from Mina for their Hajj. As for those who combined Hajj and 'Umrah, they only performed one Tawaf}}
\hadithdefcmd{nasai}{2765}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا حَبِيبٌ، عَنْ عَمْرِو بْنِ هَرِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَعِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ ضُبَاعَةَ، أَرَادَتِ الْحَجَّ فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم أَنْ تَشْتَرِطَ فَفَعَلَتْ عَنْ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2765}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas:That Duba'ah wanted to perform Hajj, so the Prophet Told here to stipulate a condition, and she acted upon the command of the Messenger of Allah}}
\hadithdefcmd{nasai}{2766}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ الأَحْوَلُ، قَالَ حَدَّثَنَا هِلاَلُ بْنُ خَبَّابٍ، قَالَ سَأَلْتُ سَعِيدَ بْنَ جُبَيْرٍ عَنِ الرَّجُلِ، يَحُجُّ يَشْتَرِطُ قَالَ الشَّرْطُ بَيْنَ النَّاسِ فَحَدَّثْتُهُ حَدِيثَهُ - يَعْنِي عِكْرِمَةَ - فَحَدَّثَنِي عَنِ ابْنِ عَبَّاسٍ أَنَّ ضُبَاعَةَ بِنْتَ الزُّبَيْرِ بْنِ عَبْدِ الْمُطَّلِبِ أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ الْحَجَّ فَكَيْفَ أَقُولُ قَالَ ‏ "‏ قُولِي لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ وَمَحِلِّي مِنَ الأَرْضِ حَيْثُ تَحْبِسُنِي فَإِنَّ لَكِ عَلَى رَبِّكِ مَا اسْتَثْنَيْتِ ‏"‏ ‏.‏\hadithno{2766}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hilal bin Khabbab said:"I asked Sa'eed bin Jubair about a man who performs Hajj and stipulates a condition. He said: 'Conditions are something that people do among themselves.' I narrated the Hadith of 'Ikrimah to him, and he narrated to me from Ibn 'Abbas, that Duba'ah bint Az-Zubair bin 'Abdul-Muttalib came to the Prophet, and said: 'O Messenger of Allah, I want to perform Hajj, so what should I say?' He said: 'Say: Labbaik Allahumma! Labbaika wa mahilli min al-ardihayth tahbisuni (Here I am, O Allah, Here I am, and I shall exit Ihram at any place where You decree that I cannot proceed.)" And whatever condition you stipulate will be accepted by your Lord}}
\hadithdefcmd{nasai}{2767}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ، قَالَ أَنْبَأَنَا شُعَيْبٌ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَنْبَأَنَا أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ طَاوُسًا، وَعِكْرِمَةَ، يُخْبِرَانِ عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَتْ ضُبَاعَةُ بِنْتُ الزُّبَيْرِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ ثَقِيلَةٌ وَإِنِّي أُرِيدُ الْحَجَّ فَكَيْفَ تَأْمُرُنِي أَنْ أُهِلَّ قَالَ ‏ "‏ أَهِلِّي وَاشْتَرِطِي إِنَّ مَحِلِّي حَيْثُ حَبَسْتَنِي ‏"‏ ‏.‏\hadithno{2767}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:'Duba'ah bint Az-Zubair bin 'Abdul-Muttalib came to the Messenger of Allah and said: 'I am a heavy woman and I want to go for Hajj. How do I begin the Ihram?' He said: 'Enter Ihram and stipulate the condition that you will exit Ihram from the point where you are prevented (from continuing, if some problem should arise)}}
\hadithdefcmd{nasai}{2768}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، وَعَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ضُبَاعَةَ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي شَاكِيَةٌ وَإِنِّي أُرِيدُ الْحَجَّ ‏.‏ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ حُجِّي وَاشْتَرِطِي إِنَّ مَحِلِّي حَيْثُ تَحْبِسُنِي ‏"‏ ‏.‏ قَالَ إِسْحَاقُ قُلْتُ لِعَبْدِ الرَّزَّاقِ كِلاَهُمَا عَنْ عَائِشَةَ هِشَامٌ وَالزُّهْرِيُّ قَالَ نَعَمْ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ أَعْلَمُ أَحَدًا أَسْنَدَ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ غَيْرَ مَعْمَرٍ وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{2768}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"Duba'ah bint Az-Zubair bin 'Abdul-Muttalib came to the Messenger of Allah and said: 'I am a heavy woman and I want to go for Hajj. How do I begin the Ihram?' He said: 'Enter Ihram and stipulate the condition that you will exit Ihram from the point where you are prevented (from continuing, if some problem should arise)." (Sahih) Ishaq said: I said to 'Abdur-Razzaq: Both from 'Aishah, HIsham and Az-Zuhir? He said: "Yes" Abu 'Abdur-Rahman (An-Nasa'i) said: I do not know of anyone who narrated this chain from Az-Zuhri except Ma'mar. Chpater 61. What Is Done By The One Who Was Prevented During Hajj Without Having Stipulated Condition}}
\hadithdefcmd{nasai}{2769}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، قَالَ كَانَ ابْنُ عُمَرَ يُنْكِرُ الاِشْتِرَاطَ فِي الْحَجِّ وَيَقُولُ أَلَيْسَ حَسْبُكُمْ سُنَّةُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنْ حُبِسَ أَحَدُكُمْ عَنِ الْحَجِّ طَافَ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ حَلَّ مِنْ كُلِّ شَىْءٍ حَتَّى يَحُجَّ عَامًا قَابِلاً وَيُهْدِي وَيَصُومُ إِنْ لَمْ يَجِدْ هَدْيًا ‏.‏\hadithno{2769}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Salim said:"Ibn 'Umar used to denounce stipulating conditions in Hajj, and said: 'Is not the Sunnah of the Messenger of Allah sufficient for you? If one of you is prevented from performing (finishing) Hajj let him circumambulate the House and (perform Sai) between As-Safa and al-Marwah, then exit Ihram completely until he performs Hajj the following year. And let him offer a Hadi or fast if he con not find a Hadi}}
\hadithdefcmd{nasai}{2770}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يُنْكِرُ الاِشْتِرَاطَ فِي الْحَجِّ وَيَقُولُ مَا حَسْبُكُمْ سُنَّةُ نَبِيِّكُمْ صلى الله عليه وسلم إِنَّهُ لَمْ يَشْتَرِطْ فَإِنْ حَبَسَ أَحَدَكُمْ حَابِسٌ فَلْيَأْتِ الْبَيْتَ فَلْيَطُفْ بِهِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ لْيَحْلِقْ أَوْ يُقَصِّرْ ثُمَّ لْيُحْلِلْ وَعَلَيْهِ الْحَجُّ مِنْ قَابِلٍ ‏.‏\hadithno{2770}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salim, from his father, that:he used to denounce stipulating conditions in Hajj and said: "Is not the Sunnah of your Prophet sufficient for you? If one of you is prevented (from completing Hajj) by anything, let him come to the House and circumambulate it, and (perform Sai) between As-Safa and Al-Marwah, then let him shave his head or cut his hair, then exit Ihram; and he has to perform Hajj the next year}}
\hadithdefcmd{nasai}{2771}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم ح وَأَنْبَأَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ قَالَ حَدَّثَنَا مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ وَمَرْوَانَ بْنِ الْحَكَمِ قَالاَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَمَنَ الْحُدَيْبِيَةِ فِي بِضْعَ عَشْرَةَ مِائَةٍ مِنْ أَصْحَابِهِ حَتَّى إِذَا كَانُوا بِذِي الْحُلَيْفَةِ قَلَّدَ الْهَدْىَ وَأَشْعَرَ وَأَحْرَمَ بِالْعُمْرَةِ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{2771}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Al-Miswar bin Makhramah and Marwan bin Al-Hakam said:"The Messenger of Allah went out during the time of Al-Hudabiyah with between one-thousand and three-hundred, and one-thousand and five-hundred of his Companions. Then, when they were in Dhul-Hulaifah, he garlanded and marked the Hadi and began the Talbiyah for 'Umrah (Abridged)}}
\hadithdefcmd{nasai}{2772}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنِي أَفْلَحُ بْنُ حُمَيْدٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَشْعَرَ بُدْنَهُ ‏.‏\hadithno{2772}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aishah:That the Messenger of Allah marked his Budn}}
\hadithdefcmd{nasai}{2773}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، عَنْ هُشَيْمٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ الأَعْرَجِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَشْعَرَ بُدْنَهُ مِنَ الْجَانِبِ الأَيْمَنِ وَسَلَتَ الدَّمَ عَنْهَا وَأَشْعَرَهَا ‏.‏\hadithno{2773}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Abbas:That the Prophet marked his Budn on the right side and the blood flowed down and marked it}}
\hadithdefcmd{nasai}{2774}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ الأَعْرَجِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا كَانَ بِذِي الْحُلَيْفَةِ أَمَرَ بِبَدَنَتِهِ فَأُشْعِرَ فِي سَنَامِهَا مِنَ الشِّقِّ الأَيْمَنِ ثُمَّ سَلَتَ عَنْهَا وَقَلَّدَهَا نَعْلَيْنِ فَلَمَّا اسْتَوَتْ بِهِ عَلَى الْبَيْدَاءِ أَهَلَّ ‏.‏\hadithno{2774}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas:That when the Prophet was in Dhul-Hulaifah he ordered that his Budn be marked on the right side of its hump, then he wiped the blood on it and he garlanded it with two shoes, then when it stood up with him Al-baida; he began the Talbiyah}}
\hadithdefcmd{nasai}{2775}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُهْدِي مِنَ الْمَدِينَةِ فَأَفْتِلُ قَلاَئِدَ هَدْيِهِ ثُمَّ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُهُ الْمُحْرِمُ ‏.‏\hadithno{2775}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Messenger of Allah used to send the Hadi from Al-Madinah, and I would twist the garlands for his Hadi, then he did not avoid anything that the person in Ihram avoids}}
\hadithdefcmd{nasai}{2776}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، قَالَ أَنْبَأَنَا يَزِيدُ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَبْعَثُ بِهَا ثُمَّ يَأْتِي مَا يَأْتِي الْحَلاَلُ قَبْلَ أَنْ يَبْلُغَ الْهَدْىُ مَحِلَّهُ ‏.‏\hadithno{2776}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Aishah said:"I used to twist the garlands for the Hadi of the Messenger of Allah, then he would send them, then he would do whatever the non-Muhrim does before the Hadi reached its place (of sacrifice)}}
\hadithdefcmd{nasai}{2777}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا عَامِرٌ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كُنْتُ لأَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ يُقِيمُ وَلاَ يُحْرِمُ ‏.‏\hadithno{2777}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"I used to twist the garlands of the Hadi of the Messenger of Allah, then he would stay with his family and not enter Ihram}}
\hadithdefcmd{nasai}{2778}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الضَّعِيفُ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْتِلُ الْقَلاَئِدَ لِهَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيُقَلِّدُ هَدْيَهُ ثُمَّ يَبْعَثُ بِهَا ثُمَّ يُقِيمُ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُهُ الْمُحْرِمُ ‏.‏\hadithno{2778}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"I used to twist the garlands of the Hadi of the Messenger of Allah, then he would garland his Hadi, then sent it, they stay (with his family) and not avoid anything that the Muhrim avoids}}
\hadithdefcmd{nasai}{2779}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، عَنْ عَبِيدَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي أَفْتِلُ قَلاَئِدَ الْغَنَمِ لِهَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ يَمْكُثُ حَلاَلاً ‏.‏\hadithno{2779}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"I remember twisting the garlands for the sheep, the Hadi of the Messenger of Allah, then he stayed as a non-Muhrim}}
\hadithdefcmd{nasai}{2780}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، قَالَ حَدَّثَنَا حُسَيْنٌ، - يَعْنِي ابْنَ حَسَنٍ - عَنِ ابْنِ عَوْنٍ، عَنِ الْقَاسِمِ، عَنْ أُمِّ الْمُؤْمِنِينَ، قَالَتْ أَنَا فَتَلْتُ، تِلْكَ الْقَلاَئِدَ مِنْ عِهْنٍ كَانَ عِنْدَنَا ثُمَّ أَصْبَحَ فِينَا فَيَأْتِي مَا يَأْتِي الْحَلاَلُ مِنْ أَهْلِهِ وَمَا يَأْتِي الرَّجُلُ مِنْ أَهْلِهِ ‏.‏\hadithno{2780}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Al-Qasim that the Mother of the Believers said:"I twisted those garlands from wool that we had, then the following morning he did what any non-Muhrim does with his wife, what any man does with his wife}}
\hadithdefcmd{nasai}{2781}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ حَفْصَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ مَا شَأْنُ النَّاسِ قَدْ حَلُّوا بِعُمْرَةٍ وَلَمْ تَحْلِلْ أَنْتَ مِنْ عُمْرَتِكَ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي وَقَلَّدْتُ هَدْيِي فَلاَ أَحِلُّ حَتَّى أَنْحَرَ ‏"‏ ‏.‏\hadithno{2781}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hafsah, the wife of the Prophet, that she said: "O Messenger of Allah, why is it that the people have exited Ihram for Umrah but you have not exited your Ihram for Umrah? He said: "I have matted my hair and garlanded my Hadi, so I will not exit Ihram until I have offered the sacrifice}}
\hadithdefcmd{nasai}{2782}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُعَاذٌ، قَالَ حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ الأَعْرَجِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم لَمَّا أَتَى ذَا الْحُلَيْفَةِ أَشْعَرَ الْهَدْىَ فِي جَانِبِ السَّنَامِ الأَيْمَنِ ثُمَّ أَمَاطَ عَنْهُ الدَّمَ وَقَلَّدَهُ نَعْلَيْنِ ثُمَّ رَكِبَ نَاقَتَهُ فَلَمَّا اسْتَوَتْ بِهِ الْبَيْدَاءَ لَبَّى وَأَحْرَمَ عِنْدَ الظُّهْرِ وَأَهَلَّ بِالْحَجِّ ‏.‏\hadithno{2782}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Abbas:That when the Prophet of Allah came to Dhul-Hulaifah he marked the Hadi on the right side of its hump, the he removed the blood and garlanded it with two shoes, then he mounted his she-camel and when it stood up with him Al-Baida, he recited the Talbiyah and entered Ihram at noon and enter Ihram for Hajj}}
\hadithdefcmd{nasai}{2783}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا قَاسِمٌ، - وَهُوَ ابْنُ يَزِيدَ - قَالَ حَدَّثَنَا أَفْلَحُ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ فَتَلْتُ قَلاَئِدَ بُدْنِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ ثُمَّ قَلَّدَهَا وَأَشْعَرَهَا وَوَجَّهَهَا إِلَى الْبَيْتِ وَبَعَثَ بِهَا وَأَقَامَ فَمَا حَرُمَ عَلَيْهِ شَىْءٌ كَانَ لَهُ حَلاَلاً ‏.‏\hadithno{2783}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"I twisted the garlands of the Budn of the Messenger of Allah with my own hands, then he garlanded it and marked it, and directed it toward the House and sent it. But he stayed with his family, and nothing became forbidden for him that was allowed}}
\hadithdefcmd{nasai}{2784}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ فَتَلْتُ قَلاَئِدَ بُدْنِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ لَمْ يُحْرِمْ وَلَمْ يَتْرُكْ شَيْئًا مِنَ الثِّيَابِ ‏.‏\hadithno{2784}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"I twisted the garlands for the Budn of the Messenger of Allah, then he did not enter at state of Ihram or abandon any kind of regular clothing}}
\hadithdefcmd{nasai}{2785}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ سَمِعْتُ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم غَنَمًا ‏.‏\hadithno{2785}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"I used to twist the garlands for the sacrificial sheep of the Messenger of Allah}}
\hadithdefcmd{nasai}{2786}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُهْدِي الْغَنَمَ ‏.‏\hadithno{2786}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aishah:That the Messenger of Allah used to send sheep as a Hadi}}
\hadithdefcmd{nasai}{2787}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهْدَى مَرَّةً غَنَمًا وَقَلَّدَهَا ‏.‏\hadithno{2787}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Aishah:That on one occasion the Messenger of Allah sent sheep as a Hadi and garlanded them}}
\hadithdefcmd{nasai}{2788}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم غَنَمًا ثُمَّ لاَ يُحْرِمُ ‏.‏\hadithno{2788}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"I sued to twist the garlands of the sacrificial sheep of the Messenger of Allah. Then he did not enter a state of Ihram}}
\hadithdefcmd{nasai}{2789}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم غَنَمًا ثُمَّ لاَ يُحْرِمُ ‏.‏\hadithno{2789}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"I used to twist the garlands of sacrificial sheep of the Messenger of Allah. Then he did not enter a state of Ihram}}
\hadithdefcmd{nasai}{2790}{أَخْبَرَنَا الْحُسَيْنُ بْنُ عِيسَى، - ثِقَةٌ - قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنِي أَبِي، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، ح وَأَنْبَأَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنِي أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ جُحَادَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنَّا نُقَلِّدُ الشَّاةَ فَيُرْسِلُ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَلاَلاً لَمْ يُحْرِمْ مِنْ شَىْءٍ ‏.‏\hadithno{2790}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aishah said:"We used to garland the sheep, then the Messenger of Allah would send it, and he would not enter a state of Ihram}}
\hadithdefcmd{nasai}{2791}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ الأَعْرَجِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا أَتَى ذَا الْحُلَيْفَةِ أَشْعَرَ الْهَدْىَ مِنْ جَانِبِ السَّنَامِ الأَيْمَنِ ثُمَّ أَمَاطَ عَنْهُ الدَّمَ ثُمَّ قَلَّدَهُ نَعْلَيْنِ ثُمَّ رَكِبَ نَاقَتَهُ فَلَمَّا اسْتَوَتْ بِهِ الْبَيْدَاءَ أَحْرَمَ بِالْحَجِّ وَأَحْرَمَ عِنْدَ الظُّهْرِ وَأَهَلَّ بِالْحَجِّ ‏.‏\hadithno{2791}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas:That when the Messenger of Allah came to Dhul-Huaifah he marked the Hadi on the right side of its hump, then removed the blood from it, then he garlanded it with two shoes and mounted his she-camel. When it stood up with him in Al-Baida, he began the Talbiyah for Hajj and he entered Ihram at noon}}
\hadithdefcmd{nasai}{2792}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُمْ كَانُوا إِذَا كَانُوا حَاضِرِينَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ بَعَثَ بِالْهَدْىِ فَمَنْ شَاءَ أَحْرَمَ وَمَنْ شَاءَ تَرَكَ ‏.‏\hadithno{2792}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir:That when they were present with the Messenger of Allah in Al-Madinah, he sent the Hadi, and whoever wanted to enter Ihram did so, and whoever did not want to, did not}}
\hadithdefcmd{nasai}{2793}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ ثُمَّ يُقَلِّدُهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ ثُمَّ يَبْعَثُ بِهَا مَعَ أَبِي فَلاَ يَدَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا أَحَلَّهُ اللَّهُ عَزَّ وَجَلَّ لَهُ حَتَّى يَنْحَرَ الْهَدْىَ ‏.‏\hadithno{2793}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"I used to twist the garlands for the Hadi of the Messenger of Allah with my own hands, then the Messenger of Allah would garland them with his own hand. Then he would send them with my father and the Messenger of Allah would refrain from anything that Allah, the Might and sublime, has permitted until the Hadi was sacrificed}}
\hadithdefcmd{nasai}{2794}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَقُتَيْبَةُ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُهُ الْمُحْرِمُ ‏.‏\hadithno{2794}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aishah said:"I used to twist the garlands for the Hadi of the Messenger of Allah. Then he would not avoid anything that the Muhrim avoids}}
\hadithdefcmd{nasai}{2795}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ قَالَتْ عَائِشَةُ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلاَ يَجْتَنِبُ شَيْئًا وَلاَ نَعْلَمُ الْحَجَّ يُحِلُّهُ إِلاَّ الطَّوَافُ بِالْبَيْتِ ‏.‏\hadithno{2795}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Aishah said:"I used to twist the garlands for the Hadi of the Messenger of Allah. Then he would not avoid anything." She said "We do not know that the pilgrim may exit Ihram fully except by performing Tawaf}}
\hadithdefcmd{nasai}{2796}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كُنْتُ لأَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَيُخْرَجُ بِالْهَدْىِ مُقَلَّدًا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُقِيمٌ مَا يَمْتَنِعُ مِنْ نِسَائِهِ ‏.‏\hadithno{2796}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Aishah said:"I used to twist the garlands fro the Hadi of the Messenger of Allah and the Hadi would be taken out garlanded, and the Messenger of Allah would stay (with his family) his wives}}
\hadithdefcmd{nasai}{2797}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْغَنَمِ فَيَبْعَثُ بِهَا ثُمَّ يُقِيمُ فِينَا حَلاَلاً ‏.‏\hadithno{2797}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"I remember twisting the garlands for the sacrificial sheep of the Messenger of Allah, then he sent them and stayed with us as a non-Muhrim (not in a state of Ihram)}}
\hadithdefcmd{nasai}{2798}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ أَنْبَأَنَا شُعَيْبُ بْنُ إِسْحَاقَ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، سَمِعَهُ يُحَدِّثُ، عَنْ جَابِرٍ، أَنَّهُ سَمِعَهُ يُحَدِّثُ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَاقَ هَدْيًا فِي حَجِّهِ ‏.‏\hadithno{2798}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:That the Prophet drove a Hadi during his Hajj}}
\hadithdefcmd{nasai}{2799}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً قَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّهَا بَدَنَةٌ قَالَ ‏"‏ ارْكَبْهَا وَيْلَكَ ‏"‏ ‏.‏ فِي الثَّانِيَةِ أَوْ فِي الثَّالِثَةِ ‏.‏\hadithno{2799}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah saw a man driving a Badanah (Sacrificial camel) and said: "Ride it." He said: "O Messenger of Allah, it is a Badanah." He said: "Ride it, woe to you!" the second or third time}}
\hadithdefcmd{nasai}{2800}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً ‏.‏ فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ إِنَّهَا بَدَنَةٌ ‏.‏ قَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ إِنَّهَا بَدَنَةٌ قَالَ فِي الرَّابِعَةِ ‏"‏ ارْكَبْهَا وَيْلَكَ ‏"‏ ‏.‏\hadithno{2800}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:the Messenger of Allah saw a man driving a Badanah and said: "Ride it." He said: "It is Badanah." He said: "Ride it." He said: "It is a Badanah." The fourth time he said: Ride it, woe to you}}
\hadithdefcmd{nasai}{2801}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً وَقَدْ جَهَدَهُ الْمَشْىُ قَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ إِنَّهَا بَدَنَةٌ ‏.‏ قَالَ ‏"‏ ارْكَبْهَا وَإِنْ كَانَتْ بَدَنَةً ‏"‏ ‏.‏\hadithno{2801}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Prophet saw a man driving a Badanah and he was exhausted from walking. He said:"Ride it." He said: "It "It is Badanah." He said: "Ride it even if it is a Badanah}}
\hadithdefcmd{nasai}{2802}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يُسْأَلُ عَنْ رُكُوبِ الْبَدَنَةِ، فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ ارْكَبْهَا بِالْمَعْرُوفِ إِذَا أُلْجِئْتَ إِلَيْهَا حَتَّى تَجِدَ ظَهْرًا ‏"‏ ‏.‏\hadithno{2802}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Az-Zuhair said:"I heard Jabir bin Abdullah being asked about riding a Badanah. He said about riding a Badanah. He said: "I heard the Messenger of Allah say: Ride it in a reasonable manner if necessary, until you find another mount}}
\hadithdefcmd{nasai}{2803}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ نُرَى إِلاَّ الْحَجَّ فَلَمَّا قَدِمْنَا مَكَّةَ طُفْنَا بِالْبَيْتِ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ أَنْ يَحِلَّ فَحَلَّ مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ وَنِسَاؤُهُ لَمْ يَسُقْنَ فَأَحْلَلْنَ ‏.‏ قَالَتْ عَائِشَةُ فَحِضْتُ فَلَمْ أَطُفْ بِالْبَيْتِ فَلَمَّا كَانَتْ لَيْلَةُ الْحَصْبَةِ قُلْتُ يَا رَسُولَ اللَّهِ يَرْجِعُ النَّاسُ بِعُمْرَةٍ وَحَجَّةٍ وَأَرْجِعُ أَنَا بِحَجَّةٍ ‏.‏ قَالَ ‏"‏ أَوَمَا كُنْتِ طُفْتِ لَيَالِيَ قَدِمْنَا مَكَّةَ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَاذْهَبِي مَعَ أَخِيكِ إِلَى التَّنْعِيمِ فَأَهِلِّي بِعُمْرَةٍ ثُمَّ مَوْعِدُكِ مَكَانُ كَذَا وَكَذَا ‏"‏ ‏.‏\hadithno{2803}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"We went out with the Messenger of Allah not thinking of anything but Hajj. When we came to Makkah we circumambulated the house, then the Messenger of Allah told those who have not brought a Hadi to exit Ihram. So those who have not brought a Hadi exited Ihram. His wives had not brought a HIad so They exited Ihram too." Aishah said: "My menses came so I did not circumambulate the Hous. On the night of Al-Hasbab (the twelfth night of Dhul-Hajjah) I said" "O Messenger of Allah, the people are going back having done Umrah and Hajj, But I am going back having done only Hajj. He said: 'Did you not perform Tawaf when we came to Makkah?' I said: 'No.' He said: 'Then go with your brother to At-Tanim and enter Ihram for Umrah then we will meet you and such and such a place}}
\hadithdefcmd{nasai}{2804}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ يَحْيَى، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نُرَى إِلاَّ أَنَّهُ الْحَجُّ فَلَمَّا دَنَوْنَا مِنْ مَكَّةَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ كَانَ مَعَهُ هَدْىٌ أَنْ يُقِيمَ عَلَى إِحْرَامِهِ وَمَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ أَنْ يَحِلَّ ‏.‏\hadithno{2804}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"We went out with the Messenger of Allah not thinking of anything but Hajj. When we drew close to Makkah, the Messenger of Allah ordered: 'Whoever has a Hadi with him should remain in Ihram, and whoever does not have a Hadi with him, he should exit Ihram}}
\hadithdefcmd{nasai}{2805}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرٍ، قَالَ أَهْلَلْنَا أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم بِالْحَجِّ خَالِصًا لَيْسَ مَعَهُ غَيْرُهُ خَالِصًا وَحْدَهُ فَقَدِمْنَا مَكَّةَ صَبِيحَةَ رَابِعَةٍ مَضَتْ مِنْ ذِي الْحِجَّةِ فَأَمَرَنَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَحِلُّوا وَاجْعَلُوهَا عُمْرَةً ‏"‏ ‏.‏ فَبَلَغَهُ عَنَّا أَنَّا نَقُولُ لَمَّا لَمْ يَكُنْ بَيْنَنَا وَبَيْنَ عَرَفَةَ إِلاَّ خَمْسٌ أَمَرَنَا أَنْ نَحِلَّ فَنَرُوحَ إِلَى مِنًى وَمَذَاكِيرُنَا تَقْطُرُ مِنَ الْمَنِيِّ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَخَطَبَنَا فَقَالَ ‏"‏ قَدْ بَلَغَنِي الَّذِي قُلْتُمْ وَإِنِّي لأَبَرُّكُمْ وَأَتْقَاكُمْ وَلَوْلاَ الْهَدْىُ لَحَلَلْتُ وَلَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا أَهْدَيْتُ ‏"‏ ‏.‏ قَالَ وَقَدِمَ عَلِيٌّ مِنَ الْيَمَنِ فَقَالَ ‏"‏ بِمَا أَهْلَلْتَ ‏"‏ ‏.‏ قَالَ بِمَا أَهَلَّ بِهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ فَأَهْدِ وَامْكُثْ حَرَامًا كَمَا أَنْتَ ‏"‏ ‏.‏ قَالَ وَقَالَ سُرَاقَةُ بْنُ مَالِكِ بْنِ جُعْشُمٍ يَا رَسُولَ اللَّهِ أَرَأَيْتَ عُمْرَتَنَا هَذِهِ لِعَامِنَا هَذَا أَوْ لِلأَبَدِ قَالَ ‏"‏ هِيَ لِلأَبَدِ ‏"‏ ‏.‏\hadithno{2805}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir said:"We, the Companions of the Prophet, entered Ihram for Hajj only, and nothing else. We came to Makkah on the morning of the fourth of Dhul-Hajjah, and the Prophet commanded us: "Exit Ihram and make it Umrah. He heard that we were saying: 'when there are only five days between us and 'Arafat he commands us to exit Ihram and we will go out to Mina with our male members dripping with semen (because of recent intimacy with our wives)?' the Prophet stood up and addressed us, saying: 'I have heard what you said. I am the most righteous and the most pious of you, and were it not for the Hadi I would have exited Ihram. If I had known what I know now, I would not have from Yemen and he said: 'for what did you enter Ihram?' He said: 'For that for which the Messenger of Allah entered Ihram.' Suraq bin Malik bin Jushum said: 'O Messenger of Allah, do you think that this Umrah of ours is for this year only or for all time?' He said: 'It is for all time}}
\hadithdefcmd{nasai}{2806}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ طَاوُسٍ، عَنْ سُرَاقَةَ بْنِ مَالِكِ بْنِ جُعْشُمٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ عُمْرَتَنَا هَذِهِ لِعَامِنَا أَمْ لأَبَدٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هِيَ لأَبَدٍ ‏"‏ ‏.‏\hadithno{2806}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Surqah bin Malik bin Jushum said :"O Messenger of Allah, do you think that this Umrah of ours is for this year only, or for all time?" The Messenger of Allah said: "It is for all time}}
\hadithdefcmd{nasai}{2807}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدَةَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ مَالِكِ بْنِ دِينَارٍ، عَنْ عَطَاءٍ، قَالَ قَالَ سُرَاقَةُ تَمَتَّعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَمَتَّعْنَا مَعَهُ فَقُلْنَا أَلَنَا خَاصَّةً أَمْ لأَبَدٍ قَالَ ‏ "‏ بَلْ لأَبَدٍ ‏"‏ ‏.‏\hadithno{2807}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Surqah said:'The Messenger of Allah joined Hajj and Umrah and we did so with him. We said: "Is it just for us, or for all time?" He said: "No, it is for all time}}
\hadithdefcmd{nasai}{2808}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الْعَزِيزِ، - وَهُوَ الدَّرَاوَرْدِيُّ - عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْحَارِثِ بْنِ بِلاَلٍ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَفَسْخُ الْحَجِّ لَنَا خَاصَّةً أَمْ لِلنَّاسِ عَامَّةً قَالَ ‏ "‏ بَلْ لَنَا خَاصَّةً ‏"‏ ‏.‏\hadithno{2808}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Harith bin Bilal that his father said:"I said: 'O Messenger of Allah, is this annulment of Hajj just for us or is it for all the people?' He said: 'No, it is just for us." (Daif)}}
\hadithdefcmd{nasai}{2809}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، وَعَيَّاشٍ الْعَامِرِيِّ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، فِي مُتْعَةِ الْحَجِّ قَالَ كَانَتْ لَنَا رُخْصَةً ‏.‏\hadithno{2809}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Dharr said concerning Tamattu" in Hajj:it was only for us}}
\hadithdefcmd{nasai}{2810}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَبْدَ الْوَارِثِ بْنَ أَبِي حَنِيفَةَ، قَالَ سَمِعْتُ إِبْرَاهِيمَ التَّيْمِيَّ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ فِي مُتْعَةِ الْحَجِّ لَيْسَتْ لَكُمْ وَلَسْتُمْ مِنْهَا فِي شَىْءٍ إِنَّمَا كَانَتْ رُخْصَةً لَنَا أَصْحَابَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏\hadithno{2810}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Dharr said concerning Tamattu' in Hajj:it is not for you, and you have nothing to do with it; it was only for us, the Companions of Muhammad}}
\hadithdefcmd{nasai}{2811}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ أَنْبَأَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ كَانَتِ الْمُتْعَةُ رُخْصَةً لَنَا ‏.‏\hadithno{2811}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Dharr said:Tamattu was just for us}}
\hadithdefcmd{nasai}{2812}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا مُفَضَّلُ بْنُ مُهَلْهَلٍ، عَنْ بَيَانٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الشَّعْثَاءِ، قَالَ كُنْتُ مَعَ إِبْرَاهِيمَ النَّخَعِيِّ وَإِبْرَاهِيمَ التَّيْمِيِّ فَقُلْتُ لَقَدْ هَمَمْتُ أَنْ أَجْمَعَ الْعَامَ الْحَجَّ وَالْعُمْرَةَ ‏.‏ فَقَالَ إِبْرَاهِيمُ لَوْ كَانَ أَبُوكَ لَمْ يَهُمَّ بِذَلِكَ ‏.‏ قَالَ وَقَالَ إِبْرَاهِيمُ التَّيْمِيُّ عَنْ أَبِيهِ عَنْ أَبِي ذَرٍّ قَالَ إِنَّمَا كَانَتِ الْمُتْعَةُ لَنَا خَاصَّةً ‏.‏\hadithno{2812}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abdur-Rahman bin Abi Ash-Shatha Said:"I was with Ibrahm An-Nakha'i and Ibrahim At-taimi, and I said: 'I wanted to combine Hajj and 'Umrah this year,' but Ibrahim said: 'If you father were alive, he would not do that.' And Ibrahim At-Taimi said, (narrating) from his father, that Abu Dharr said: 'Tamattu' was only for us". (Sahib)}}
\hadithdefcmd{nasai}{2813}{أَخْبَرَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ وُهَيْبِ بْنِ خَالِدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانُوا يُرَوْنَ أَنَّ الْعُمْرَةَ، فِي أَشْهُرِ الْحَجِّ مِنْ أَفْجَرِ الْفُجُورِ فِي الأَرْضِ وَيَجْعَلُونَ الْمُحَرَّمَ صَفَرَ وَيَقُولُونَ إِذَا بَرَأَ الدَّبَرْ وَعَفَا الْوَبَرْ وَانْسَلَخَ صَفَرْ - أَوْ قَالَ دَخَلَ صَفَرْ - فَقَدْ حَلَّتِ الْعُمْرَةُ لِمَنِ اعْتَمَرْ فَقَدِمَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ صَبِيحَةَ رَابِعَةٍ مُهِلِّينَ بِالْحَجِّ فَأَمَرَهُمْ أَنْ يَجْعَلُوهَا عُمْرَةً فَتَعَاظَمَ ذَلِكَ عِنْدَهُمْ فَقَالُوا يَا رَسُولَ اللَّهِ أَىُّ الْحِلِّ قَالَ ‏ "‏ الْحِلُّ كُلُّهُ ‏"‏ ‏.‏\hadithno{2813}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:"They used to think that performing 'Umrah during the months of Hajj was one of the worst of evil actions on Earth, and they used to call Muharram 'Safar,' and say: 'When the sore on the backs of the camels have healed and when their hair grows back and when Safar is over' - or he said: 'When Safar beings - then 'Umrah becomes permissible for whoever wants to do it.' Then the Prophet and his companions came on the morning of the fourth of Dhul-Hijjah, reciting the Talbiyah for Hajj, He told them to make it 'Umrah, and they found it too difficult to do that. They said: 'O Messenger of Allah, to what degree should we exit Ihram?' He said: 'Completely}}
\hadithdefcmd{nasai}{2814}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مُسْلِمٍ، - وَهُوَ الْقُرِّيُّ - قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْعُمْرَةِ وَأَهَلَّ أَصْحَابُهُ بِالْحَجِّ وَأَمَرَ مَنْ لَمْ يَكُنْ مَعَهُ الْهَدْىُ أَنْ يَحِلَّ وَكَانَ فِيمَنْ لَمْ يَكُنْ مَعَهُ الْهَدْىُ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ وَرَجُلٌ آخَرُ فَأَحَلاَّ ‏.‏\hadithno{2814}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Abbas said:"The Messenger of Allah enter Ihram for 'Umrah and his companions enter Ihrahm for Hajj. He told those who did not have a Hadi with them to exit Ihram. Among those who did not have a Hadi with them was Tallah bin 'Ubaidullah and another man, so they exited Ihram}}
\hadithdefcmd{nasai}{2815}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ هَذِهِ عُمْرَةٌ اسْتَمْتَعْنَاهَا فَمَنْ لَمْ يَكُنْ عِنْدَهُ هَدْىٌ فَلْيَحِلَّ الْحِلَّ كُلَّهُ فَقَدْ دَخَلَتِ الْعُمْرَةُ فِي الْحَجِّ ‏"‏ ‏.‏\hadithno{2815}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Abbas that the Prophet said:This is 'Umrah that we have benefited from. Whoever does not have a Hadi with him, let him exit Ihram completely. Now 'Umrah is permissible during the months of Hajj}}
\hadithdefcmd{nasai}{2816}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِبَعْضِ طَرِيقِ مَكَّةَ تَخَلَّفَ مَعَ أَصْحَابٍ لَهُ مُحْرِمِينَ وَهُوَ غَيْرُ مُحْرِمٍ وَرَأَى حِمَارًا وَحْشِيًّا فَاسْتَوَى عَلَى فَرَسِهِ ثُمَّ سَأَلَ أَصْحَابَهُ أَنْ يُنَاوِلُوهُ سَوْطَهُ فَأَبَوْا فَسَأَلَهُمْ رُمْحَهُ فَأَبَوْا فَأَخَذَهُ ثُمَّ شَدَّ عَلَى الْحِمَارِ فَقَتَلَهُ فَأَكَلَ مِنْهُ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَأَبَى بَعْضُهُمْ فَأَدْرَكُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلُوهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّمَا هِيَ طُعْمَةٌ أَطْعَمَكُمُوهَا اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2816}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Qatadah that:he was with Messenger of Allah. When they were partway to Makkah, he lagged behind with some companions of his whowere in Ihram, but he was not in Ihram. He saw an onager, so he mounted his horse, then he asked his companions to hand him his whip, but they refused. He asked them to hand him his spear, but they refused. He took it, then chased the onager and killed it. Some of the Companions of the Messenger of Allah ate from it but others refused. The caught up with the Messenger of Allah and asked him about that, and he said: "That is food that Allah, the Might and Sublime, gave to you}}
\hadithdefcmd{nasai}{2817}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ مُعَاذِ بْنِ عَبْدِ الرَّحْمَنِ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ وَنَحْنُ مُحْرِمُونَ فَأُهْدِيَ لَهُ طَيْرٌ وَهُوَ رَاقِدٌ فَأَكَلَ بَعْضُنَا وَتَوَرَّعَ بَعْضُنَا فَاسْتَيْقَظَ طَلْحَةُ فَوَفَّقَ مَنْ أَكَلَهُ وَقَالَ أَكَلْنَاهُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2817}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Mu'adh bin Abdur-Rahman At-Taimi that his father said:"we were with Talhah bin Ubaidullah and we were Ihram. A birth was given to him when he was asleep, and some of us at from it and others refrained. Talhah woke up and agreed with those who had eaten it, and said: 'We ate it with Messenger of Allah}}
\hadithdefcmd{nasai}{2818}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عُمَيْرِ بْنِ سَلَمَةَ الضَّمْرِيِّ، أَنَّهُ أَخْبَرَهُ عَنِ الْبَهْزِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يُرِيدُ مَكَّةَ وَهُوَ مُحْرِمٌ حَتَّى إِذَا كَانُوا بِالرَّوْحَاءِ إِذَا حِمَارُ وَحْشٍ عَقِيرٌ فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ دَعُوهُ فَإِنَّهُ يُوشِكُ أَنْ يَأْتِيَ صَاحِبُهُ ‏"‏ ‏.‏ فَجَاءَ الْبَهْزِيُّ وَهُوَ صَاحِبُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ صلى الله عليه وسلم شَأْنَكُمْ بِهَذَا الْحِمَارِ ‏.‏ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا بَكْرٍ فَقَسَّمَهُ بَيْنَ الرِّفَاقِ ثُمَّ مَضَى حَتَّى إِذَا كَانَ بِالأُثَايَةِ بَيْنَ الرُّوَيْثَةِ وَالْعَرْجِ إِذَا ظَبْىٌ حَاقِفٌ فِي ظِلٍّ وَفِيهِ سَهْمٌ فَزَعَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ رَجُلاً يَقِفُ عِنْدَهُ لاَ يُرِيبُهُ أَحَدٌ مِنَ النَّاسِ حَتَّى يُجَاوِزَهُ ‏.‏\hadithno{2818}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Al-Bahzi that:the Messenger of Allah set out for Makkah and was in Ihram. When they were in Ar-Rawha, they saw a wounded onager. Mention of that was made to the messenger of Allah and he said: "Leave it, for soon its owner will come." Then Al-Bahzi, who was its owner, came to the Messenger of Allah, it is up to you what you want to do with this onager." The Messenger of Allah Commanded Abu Bakr to share it out among the company then he moved on, and when he was in Al-Uthayah, between Ar-Ruwaythah and Al-Arj, They was a gazelle sleeping in the Shade with an arrow in it. It was said that the Messenger of Allah told a man to stand by it and not let anyone disturb it until everyone had passed by}}
\hadithdefcmd{nasai}{2819}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ، أَنَّهُ أَهْدَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِمَارَ وَحْشٍ وَهُوَ بِالأَبْوَاءِ أَوْ بِوَدَّانَ فَرَدَّهُ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَا فِي وَجْهِي قَالَ ‏ "‏ أَمَّا إِنَّهُ لَمْ نَرُدَّهُ عَلَيْكَ إِلاَّ أَنَّا حُرُمٌ ‏"‏ ‏.‏\hadithno{2819}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from As-Sab bin Jaththamah that:he gave the Messenger of Allah an onager when he was in Al-Abwa or in Waddan, but the Messenger of Allah gave it back to him. "And when the Messenger of Allah saw the expression on my face he said: "We only gave it back to you because we are in Ihram}}
\hadithdefcmd{nasai}{2820}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَقْبَلَ حَتَّى إِذَا كَانَ بِوَدَّانَ رَأَى حِمَارَ وَحْشٍ فَرَدَّهُ عَلَيْهِ وَقَالَ ‏ "‏ إِنَّا حُرُمٌ لاَ نَأْكُلُ الصَّيْدَ ‏"‏ ‏.‏\hadithno{2820}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from As-Sab bin Jaththamah that:the Prophet came, and when he was in Waddan, he saw an onager, but he gave it back to him and said: "'We are in Ihram, we cannot eat game}}
\hadithdefcmd{nasai}{2821}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا قَيْسُ بْنُ سَعْدٍ، عَنْ عَطَاءٍ، أَنَّ ابْنَ عَبَّاسٍ، قَالَ لِزَيْدِ بْنِ أَرْقَمَ مَا عَلِمْتَ أَنَّ النَّبِيَّ صلى الله عليه وسلم أُهْدِيَ لَهُ عُضْوُ صَيْدٍ وَهُوَ مُحْرِمٌ فَلَمْ يَقْبَلْهُ قَالَ نَعَمْ ‏.‏\hadithno{2821}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ata' that Ibn 'Abbas said to Zaid bin Arqam:"Do you not know that the Prophet was given a piece of game meant when he was in Ihram and he did not accept it?" He said: "Yes}}
\hadithdefcmd{nasai}{2821p2}{أَخْبَرَنِي عَمْرُو بْنُ عَلِيٍّ، قَالَ سَمِعْتُ يَحْيَى، وَسَمِعْتُ أَبَا عَاصِمٍ، قَالاَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ زَيْدُ بْنُ أَرْقَمَ فَقَالَ لَهُ ابْنُ عَبَّاسٍ يَسْتَذْكِرُهُ كَيْفَ أَخْبَرْتَنِي عَنْ لَحْمِ، صَيْدٍ أُهْدِيَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ حَرَامٌ قَالَ نَعَمْ أَهْدَى لَهُ رَجُلٌ عُضْوًا مِنْ لَحْمِ صَيْدٍ فَرَدَّهُ وَقَالَ ‏ "‏ إِنَّا لاَ نَأْكُلُ إِنَّا حُرُمٌ ‏"‏ ‏.‏\hadithno{2821.2}\hadithtrans{It was narrated that Ibn 'Abbas said:"Zaid bin Arqam came and Ibn Abbas said to him, reminding him: "What did you tell me about the game meat that was given to the Messenger of Allah when he was in Ihram?" He said: "Yes, a man gave him a piece of game meat but he returned it and said: 'We cannot eat it, we are in Ihram}}
\hadithdefcmd{nasai}{2822}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَهْدَى الصَّعْبُ بْنُ جَثَّامَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم رِجْلَ حِمَارِ وَحْشٍ تَقْطُرُ دَمًا وَهُوَ مُحْرِمٌ وَهُوَ بِقُدَيْدٍ فَرَدَّهَا عَلَيْهِ ‏.‏\hadithno{2822}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Abbas said:"As-Sab bin Jaththamah gave the Messenger of Allah the leg of an onager that was dripping with blood when he was in Ihram, at Qudaid, and he returned it to him}}
\hadithdefcmd{nasai}{2823}{أَخْبَرَنَا يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ حَبِيبٍ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، وَحَبِيبٍ، - وَهُوَ ابْنُ أَبِي ثَابِتٍ - عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ الصَّعْبَ بْنَ جَثَّامَةَ، أَهْدَى لِلنَّبِيِّ صلى الله عليه وسلم حِمَارًا وَهُوَ مُحْرِمٌ فَرَدَّهُ عَلَيْهِ ‏.‏\hadithno{2823}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas:That As-Sab bin Jaththamah gave the Prophet some onager (meat) when he was in Ihram and he returned it to him}}
\hadithdefcmd{nasai}{2824}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، قَالَ انْطَلَقَ أَبِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ فَأَحْرَمَ أَصْحَابُهُ وَلَمْ يُحْرِمْ فَبَيْنَمَا أَنَا مَعَ أَصْحَابِي ضَحِكَ بَعْضُهُمْ إِلَى بَعْضٍ فَنَظَرْتُ فَإِذَا حِمَارُ وَحْشٍ فَطَعَنْتُهُ فَاسْتَعَنْتُهُمْ فَأَبَوْا أَنْ يُعِينُونِي فَأَكَلْنَا مِنْ لَحْمِهِ وَخَشِينَا أَنْ نُقْتَطَعَ فَطَلَبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أُرَفِّعُ فَرَسِي شَأْوًا وَأَسِيرُ شَأْوًا فَلَقِيتُ رَجُلاً مِنْ غِفَارٍ فِي جَوْفِ اللَّيْلِ فَقُلْتُ أَيْنَ تَرَكْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ تَرَكْتُهُ وَهُوَ قَائِلٌ بِالسُّقْيَا ‏.‏ فَلَحِقْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَصْحَابَكَ يَقْرَءُونَ عَلَيْكَ السَّلاَمَ وَرَحْمَةَ اللَّهِ وَإِنَّهُمْ قَدْ خَشُوا أَنْ يُقْتَطَعُوا دُونَكَ فَانْتَظِرْهُمْ فَانْتَظَرَهُمْ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ حِمَارَ وَحْشٍ وَعِنْدِي مِنْهُ فَقَالَ لِلْقَوْمِ ‏ "‏ كُلُوا ‏"‏ ‏.‏ وَهُمْ مُحْرِمُونَ ‏.‏\hadithno{2824}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abdullah bin Abi Qatadah said:"My father set out with the Messenger of Allah in the year of Al-Hudaybiyah, and his companions entered Ihram, but he did not. (He said:) 'While I was with my companions, some of them laughed at others. I looked and saw an onager. I stabbed it then asked them to help, but they refused to help me. We ate from its meat, and we were afraid that we would be intercepted (by the enemy) so I followed the Messenger of Allah, sometimes making my horse gallop and sometimes traveling at a regular place. I met a man from Ghifar at midnight and said: Where did you leave the Messenger of Allah? He said: I left him when he was napping in As-Suqya. I caught up with him and said: O messenger of Allah! Your Companions convey their greetings of Salam to you, and the mercy of Allah and His blessings. They were afraid that they may be intercepted and cut off from you, so wait for them. Then I said: O Messenger of Allah, I caught an onager and I have some of it. He said to the People: Eat, and they were I Ihram}}
\hadithdefcmd{nasai}{2825}{أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ النَّسَائِيُّ، قَالَ أَنْبَأَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ الْمُبَارَكِ الصُّورِيُّ - قَالَ حَدَّثَنَا مُعَاوِيَةُ، - وَهُوَ ابْنُ سَلاَّمٍ - عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّهُ، غَزَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَزْوَةَ الْحُدَيْبِيَةِ - قَالَ - فَأَهَلُّوا بِعُمْرَةٍ غَيْرِي فَاصْطَدْتُ حِمَارَ وَحْشٍ فَأَطْعَمْتُ أَصْحَابِي مِنْهُ وَهُمْ مُحْرِمُونَ ثُمَّ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَنْبَأْتُهُ أَنَّ عِنْدَنَا مِنْ لَحْمِهِ فَاضِلَةً فَقَالَ ‏ "‏ كُلُوهُ ‏"‏ ‏.‏ وَهُمْ مُحْرِمُونَ ‏.‏\hadithno{2825}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Yahya bin Abi Kathir said:"Abdullah bin Abu Qatadah said that his father told him, that he went out with the Messenger of Allah on the campaign of Al-Hudaybiyah. He said: 'They entered Ihram for 'Umrah apart from me. I hunted an onager and fed my companions with it, when they were in Ihram. Then, I went to the Messenger of Allah and told him that we had some of it meat left over. HE said: Eat, and they were in Ihram}}
\hadithdefcmd{nasai}{2826}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عُثْمَانُ بْنُ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي قَتَادَةَ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّهُمْ كَانُوا فِي مَسِيرٍ لَهُمْ بَعْضُهُمْ مُحْرِمٌ وَبَعْضُهُمْ لَيْسَ بِمُحْرِمٍ - قَالَ - فَرَأَيْتُ حِمَارَ وَحْشٍ فَرَكِبْتُ فَرَسِي وَأَخَذْتُ الرُّمْحَ فَاسْتَعَنْتُهُمْ فَأَبَوْا أَنْ يُعِينُونِي فَاخْتَلَسْتُ سَوْطًا مِنْ بَعْضِهِمْ فَشَدَدْتُ عَلَى الْحِمَارِ فَأَصَبْتُهُ فَأَكَلُوا مِنْهُ فَأَشْفَقُوا - قَالَ - فَسُئِلَ عَنْ ذَلِكَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ هَلْ أَشَرْتُمْ أَوْ أَعَنْتُمْ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَكُلُوا ‏"‏ ‏.‏\hadithno{2826}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Abi Qatadah narrated from his father that:they were on a march, somr of them in Ihram and some not in Ihram. He said: "I saw an onager so I mounted my horse and picked up a spear. I asked them to help me but they refused to help me. I snatched a whip from one of them and chased the onager and caught it. They ate of it but they were scared. The prophet was asked about that and he said: 'Did you pint (at it) or help him?' They said, 'No.' He said: Then eat}}
\hadithdefcmd{nasai}{2827}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ - عَنْ عَمْرٍو، عَنِ الْمُطَّلِبِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ صَيْدُ الْبَرِّ لَكُمْ حَلاَلٌ مَا لَمْ تَصِيدُوهُ أَوْ يُصَادَ لَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عَمْرُو بْنُ أَبِي عَمْرٍو لَيْسَ بِالْقَوِيِّ فِي الْحَدِيثِ وَإِنْ كَانَ قَدْ رَوَى عَنْهُ مَالِكٌ ‏.‏\hadithno{2827}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"I heard that Messenger of Allah say: 'Land game is permissible for you so long as you do not hunt it, and it is not hunted for you.'" (Daif) Abu Abdur Rahman (An-Nasai) said: 'Amar bin Abi Amr Is not strong in Hadith, even they Malik reported from him}}
\hadithdefcmd{nasai}{2828}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ خَمْسٌ لَيْسَ عَلَى الْمُحْرِمِ فِي قَتْلِهِنَّ جُنَاحٌ الْغُرَابُ وَالْحِدَأَةُ وَالْعَقْرَبُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ ‏.‏\hadithno{2828}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Umar that the Messenger of Allah said:"There are five (animals) for which there is no sin on the Muhrim if he kills them: Crows, kites, scorpions, mice and vicious dogs}}
\hadithdefcmd{nasai}{2829}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ يَقْتُلُهُنَّ الْمُحْرِمُ الْحَيَّةُ وَالْفَأْرَةُ وَالْحِدَأَةُ وَالْغُرَابُ الأَبْقَعُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2829}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Aishah that the Prophet said:"There are five which the Muhrim may kill: snakes, mice, kites, speckled crows and vicious dogs}}
\hadithdefcmd{nasai}{2830}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَذِنَ فِي قَتْلِ خَمْسٍ مِنَ الدَّوَابِّ لِلْمُحْرِمِ الْغُرَابُ وَالْحِدَأَةُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ وَالْعَقْرَبُ ‏.‏\hadithno{2830}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Umar that the Messenger of Allah gave permission fro the Muhrim to kill five kinds of animals:crows, kites, mice and vicious dogs}}
\hadithdefcmd{nasai}{2831}{أَخْبَرَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ عَرْعَرَةَ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ امْرَأَةً، دَخَلَتْ عَلَى عَائِشَةَ وَبِيَدِهَا عُكَّازٌ فَقَالَتْ مَا هَذَا فَقَالَتْ لِهَذِهِ الْوَزَغِ لأَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم حَدَّثَنَا ‏ "‏ أَنَّهُ لَمْ يَكُنْ شَىْءٌ إِلاَّ يُطْفِئُ عَلَى إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ إِلاَّ هَذِهِ الدَّابَّةُ ‏"‏ ‏.‏ فَأَمَرَنَا بِقَتْلِهَا وَنَهَى عَنْ قَتْلِ الْجِنَّانِ إِلاَّ ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يُطْمِسَانِ الْبَصَرَ وَيُسْقِطَانِ مَا فِي بُطُونِ النِّسَاءِ ‏.‏\hadithno{2831}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Saeed bin Al-Musayyab that:a woman enter upon Aishah, and in her hand was an iron-footed stick. She said: "What is this?" she (Aishah) Said: "It is for these geckos, because the Prophet of Allah told us, that there was nothing that did not try to extinguish the fire for Ihram except for this animals, so he told us to kill it. And he forbade us to kill harmless snakes, except for the snake with two lines on its back, and the snake with a short tail, for the snatch away the eyesight and cause tat which is in women's wombs to be miscarried}}
\hadithdefcmd{nasai}{2832}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ أَبُو قُدَامَةَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ لاَ جُنَاحَ عَلَى مَنْ قَتَلَهُنَّ - أَوْ فِي قَتْلِهِنَّ - وَهُوَ حَرَامٌ الْحِدَأَةُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ وَالْعَقْرَبُ وَالْغُرَابُ ‏"‏ ‏.‏\hadithno{2832}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Umar that:the Prophet said "There are five kinds of animals for which there is no sin on the one who kills them when he is in a state of Ihram: Kites, mice, vicious dogs, scorpions and crows." (Sahih) Chpater 87. Killing Kites}}
\hadithdefcmd{nasai}{2833}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ أَنْبَأَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ مَا نَقْتُلُ مِنَ الدَّوَابِّ إِذَا أَحْرَمْنَا قَالَ ‏ "‏ خَمْسٌ لاَ جُنَاحَ عَلَى مَنْ قَتَلَهُنَّ الْحِدَأَةُ وَالْغُرَابُ وَالْفَأْرَةُ وَالْعَقْرَبُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2833}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Umar said:"A man said: "O Messenger of Allah, what animals may we kill when we are in Ihram?' He said: "there are five for which there is no sin in killing them: Kites, crows, mice, scorpions and vicious dogs}}
\hadithdefcmd{nasai}{2834}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ مَا يَقْتُلُ الْمُحْرِمُ قَالَ ‏ "‏ يَقْتُلُ الْعَقْرَبَ وَالْفُوَيْسِقَةَ وَالْحِدَأَةَ وَالْغُرَابَ وَالْكَلْبَ الْعَقُورَ ‏"‏ ‏.‏\hadithno{2834}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Umar that:the Prophet was asked what the Muhrim may kill. He said: "He may kill scorpions the evil creature (mice), Kites, crows and vicious dogs}}
\hadithdefcmd{nasai}{2835}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ لاَ جُنَاحَ فِي قَتْلِهِنَّ عَلَى مَنْ قَتَلَهُنَّ فِي الْحَرَمِ وَالإِحْرَامِ الْفَأْرَةُ وَالْحِدَأَةُ وَالْغُرَابُ وَالْعَقْرَبُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2835}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim that his father said:"The Prophet said: 'There are five kinds of animals for which there is no sin on the one who kills them, whether he is in Ihram or not: Mice, kites, crows, scorpions and vicious dogs.'" (Sahih) Chpater 89. What The Muhrim May Not Kill}}
\hadithdefcmd{nasai}{2836}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنِ ابْنِ أَبِي عَمَّارٍ، قَالَ سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ عَنِ الضَّبُعِ، فَأَمَرَنِي بِأَكْلِهَا ‏.‏ قُلْتُ أَصَيْدٌ هِيَ قَالَ نَعَمْ ‏.‏ قُلْتُ أَسَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏\hadithno{2836}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Ibn Abi ammar said:"I asked Jabir bin Abdulla about hyenas, and he told me to eat them. I said: "Is it not game? He said: 'Yes' I said: 'Did you hear that from the Messenger of Allah?' He said: 'Yes}}
\hadithdefcmd{nasai}{2837}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا دَاوُدُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ - عَنْ عَمْرٍو، - وَهُوَ ابْنُ دِينَارٍ - قَالَ سَمِعْتُ أَبَا الشَّعْثَاءِ، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، قَالَ تَزَوَّجَ النَّبِيُّ صلى الله عليه وسلم مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2837}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Abbas said:"The Prophet married Maimunah when he was in Ihram}}
\hadithdefcmd{nasai}{2838}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، أَنَّ أَبَا الشَّعْثَاءِ، حَدَّثَهُ عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَكَحَ حَرَامًا ‏.‏\hadithno{2838}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas:That the Messenger of Allah got married when in Ihram}}
\hadithdefcmd{nasai}{2839}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يُونُسَ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُمَا مُحْرِمَانِ ‏.‏\hadithno{2839}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Abbas:That the Messenger of Allah married Maimunah when they were both in Ihram}}
\hadithdefcmd{nasai}{2840}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الصَّاغَانِيُّ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2840}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abbas:That the Messenger of Allah married Maimunah when he was in Ihram}}
\hadithdefcmd{nasai}{2841}{أَخْبَرَنِي شُعَيْبُ بْنُ شُعَيْبِ بْنِ إِسْحَاقَ، وَصَفْوَانُ بْنُ عَمْرٍو الْحِمْصِيُّ، قَالاَ حَدَّثَنَا أَبُو الْمُغِيرَةِ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2841}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn Abbas:That the Prophet married Maimunah when he was in Ihram}}
\hadithdefcmd{nasai}{2842}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، أَنَّ أَبَانَ بْنَ عُثْمَانَ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْكِحُ الْمُحْرِمُ وَلاَ يَخْطُبُ وَلاَ يُنْكِحُ ‏"‏ ‏.‏\hadithno{2842}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Uthman bin Affan said:"The Messenger of Allah said: 'The Muhrim should not get married, or propose marriage, or arrange a marriage for some else}}
\hadithdefcmd{nasai}{2843}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، أَخْبَرَنِي نَافِعٌ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، عَنْ أَبَانَ بْنِ عُثْمَانَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ يَنْكِحَ الْمُحْرِمُ أَوْ يُنْكِحَ أَوْ يَخْطُبَ ‏.‏\hadithno{2843}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Aban bin Uthamn, from his father:That the Prophet forbade the Muhrim to get married, arrange a marriage for anyone else, or propose marriage}}
\hadithdefcmd{nasai}{2844}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ سُفْيَانَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نُبَيْهِ بْنِ وَهْبٍ، قَالَ أَرْسَلَ عُمَرُ بْنُ عُبَيْدِ اللَّهِ بْنِ مَعْمَرٍ إِلَى أَبَانَ بْنِ عُثْمَانَ يَسْأَلُهُ أَيَنْكِحُ الْمُحْرِمُ فَقَالَ أَبَانُ إِنَّ عُثْمَانَ بْنَ عَفَّانَ حَدَّثَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْكِحُ الْمُحْرِمُ وَلاَ يَخْطُبُ ‏"‏ ‏.‏\hadithno{2844}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Uthaman bin Affan narrated that the Prohet said:"The Muhrim should not get or propose marriage}}
\hadithdefcmd{nasai}{2845}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2845}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Abbas:That the Messenger of Allah was treated by means of cupping when he was in Ihram}}
\hadithdefcmd{nasai}{2846}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، وَعَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2846}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Abbas that:The Prophet was treated by means of cupping when he was Ihram}}
\hadithdefcmd{nasai}{2847}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ أَنْبَأَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ عَطَاءً، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏ ثُمَّ قَالَ بَعْدُ أَخْبَرَنِي طَاوُسٌ عَنِ ابْنِ عَبَّاسٍ يَقُولُ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2847}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abbas said:"Prophet was treated by means of cupping when he was in Ihram." (Diaf) Chpater 93. Cupping To Treat The Muhrim For A Disease he Is Suffering From}}
\hadithdefcmd{nasai}{2848}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ مِنْ وَثْءٍ كَانَ بِهِ ‏.‏\hadithno{2848}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir:That the Prophet was treated by means of cupping when he was in Ihram for a contusion that he had suffered. (Diaf)}}
\hadithdefcmd{nasai}{2849}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ عَلَى ظَهْرِ الْقَدَمِ مِنْ وَثْءٍ كَانَ بِهِ ‏.‏\hadithno{2849}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas:That the Messenger of Allah was treated by means of cupping when he was in Ihram on the top of the foot for contusion that he had suffered. (Daif)}}
\hadithdefcmd{nasai}{2850}{أَخْبَرَنِي هِلاَلُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، - وَهُوَ ابْنُ عَثْمَةَ - قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ قَالَ عَلْقَمَةُ بْنُ أَبِي عَلْقَمَةَ أَنَّهُ سَمِعَ الأَعْرَجَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ ابْنَ بُحَيْنَةَ، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَسَطَ رَأْسِهِ وَهُوَ مُحْرِمٌ بِلَحْىِ جَمَلٍ مِنْ طَرِيقِ مَكَّةَ ‏.‏\hadithno{2850}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Buhayanah narrated:That the Messenger of Allah was treated by means of cupping in the middle of his head, when he was in Ihram, in Lahi Jamal, on the road to Makkah}}
\hadithdefcmd{nasai}{2851}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الْكَرِيمِ بْنِ مَالِكٍ الْجَزَرِيِّ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُحْرِمًا فَآذَاهُ الْقَمْلُ فِي رَأْسِهِ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَحْلِقَ رَأْسَهُ وَقَالَ ‏ "‏ صُمْ ثَلاَثَةَ أَيَّامٍ أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ مُدَّيْنِ مُدَّيْنِ أَوِ انْسُكْ شَاةً أَىَّ ذَلِكَ فَعَلْتَ أَجْزَأَ عَنْكَ ‏"‏ ‏.‏\hadithno{2851}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Kab bin Ujra:That he was with the Messenger of Allah in Ihram and he suffered an infestation of head lice. The Messenger of Allah commanded him to shave his head and told him: "Fast for three days, or fed six poor persons two Mudds earch, or sacrifice a sheep. Whichever one of these you do will be sufficient for you}}
\hadithdefcmd{nasai}{2852}{أَخْبَرَنِي أَحْمَدُ بْنُ سَعِيدٍ الرِّبَاطِيُّ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ، - وَهُوَ الدَّشْتَكِيُّ - قَالَ أَنْبَأَنَا عَمْرٌو، - وَهُوَ ابْنُ أَبِي قَيْسٍ - عَنِ الزُّبَيْرِ، - وَهُوَ ابْنُ عَدِيٍّ - عَنْ أَبِي وَائِلٍ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ أَحْرَمْتُ فَكَثُرَ قَمْلُ رَأْسِي فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَأَتَانِي وَأَنَا أَطْبُخُ قِدْرًا لأَصْحَابِي فَمَسَّ رَأْسِي بِأُصْبُعِهِ فَقَالَ ‏ "‏ انْطَلِقْ فَاحْلِقْهُ وَتَصَدَّقْ عَلَى سِتَّةِ مَسَاكِينَ ‏"‏ ‏.‏\hadithno{2852}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Kab bin Ujrah said:"I entered Ihram, then I had a severe infestation of head lice. News of that reached Prophet, and he came to me when I was cooking something in a pot for my companions, he touched my head with his finger and said: 'Go and shave it, and give charity to six poor persions}}
\hadithdefcmd{nasai}{2853}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، كَانَ مَعَ النَّبِيِّ صلى الله عليه وسلم فَوَقَصَتْهُ نَاقَتُهُ وَهُوَ مُحْرِمٌ فَمَاتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْهِ وَلاَ تُمِسُّوهُ بِطِيبٍ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏\hadithno{2853}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas:That a man was with the Messenger of Allah, and his she-camel broke his neck when he was in Ihra, and he died. The Messenger of all said, Wash him with water and lote leaves, and shroud him in his two garments, and do not put any perfume on him or cover his head, for he will be raised on the Day of Resurrection reciting the Talbiyah}}
\hadithdefcmd{nasai}{2854}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، مُحْرِمًا صُرِعَ عَنْ نَاقَتِهِ، فَأُوقِصَ ذُكِرَ أَنَّهُ قَدْ مَاتَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْنِ ‏"‏ ‏.‏ ثُمَّ قَالَ عَلَى إِثْرِهِ ‏"‏ خَارِجًا رَأْسُهُ ‏"‏ ‏.‏ قَالَ ‏"‏ وَلاَ تُمِسُّوهُ طِيبًا فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏ قَالَ شُعْبَةُ فَسَأَلْتُهُ بَعْدَ عَشْرِ سِنِينَ فَجَاءَ بِالْحَدِيثِ كَمَا كَانَ يَجِيءُ بِهِ إِلاَّ أَنَّهُ قَالَ ‏"‏ وَلاَ تُخَمِّرُوا وَجْهَهُ وَرَأْسَهُ ‏"‏ ‏.‏\hadithno{2854}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas:That a man in Ihram was thrown by his she-camel and his neck was broken. It was said that he had died, so the Prophet said: "Wash him with water and lotus leaves, and shroud him in two cloths." Then he said: "Do not put any perfume on him for he will be raised on the Day of Resurrection reciting the Talbiyah." Shubah said: "Ten years later, I asked him (the narrator Abu Bishr) anbut that, and he narrated the Hadith as he had the first time, except that he said: 'And do not cover his face and head}}
\hadithdefcmd{nasai}{2855}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَيْنَا رَجُلٌ وَاقِفٌ بِعَرَفَةَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ وَقَعَ مِنْ رَاحِلَتِهِ فَأَقْعَصَهُ - أَوْ قَالَ فَأَقْعَصَتْهُ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْنِ وَلاَ تُحَنِّطُوهُ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏\hadithno{2855}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:"While a man was standing in Arafat with the Messenger of Allah, he fell from his mount and it killed him. The Messenger of Allah said: 'Wash him with water and lotus leaves, and shroud him in two cloths. Do not apply aromatics to him or cover his head, for Allah, the Might and Sublime, wil raise him on the Day of Resurrection reciting the Talbiyah}}
\hadithdefcmd{nasai}{2856}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ وَقَصَتْ رَجُلاً مُحْرِمًا نَاقَتُهُ فَقَتَلَتْهُ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ اغْسِلُوهُ وَكَفِّنُوهُ وَلاَ تُغَطُّوا رَأْسَهُ وَلاَ تُقَرِّبُوهُ طِيبًا فَإِنَّهُ يُبْعَثُ يُهِلُّ ‏"‏ ‏.‏\hadithno{2856}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn Abbas said:"The she-Camel of a ma in Ihram broke his neck and killed him. He was brought to the Messenger of Allah and he said 'Wash him and shroud him, and do not cover his head, or bring any perfume near him, for he will be raisd reciting Talbiyah.'" (Sahih) Dies}}
\hadithdefcmd{nasai}{2857}{أَخْبَرَنَا مُحَمَّدُ بْنُ مُعَاوِيَةَ، قَالَ حَدَّثَنَا خَلَفٌ، - يَعْنِي ابْنَ خَلِيفَةَ - عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، كَانَ حَاجًّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَّهُ لَفَظَهُ بَعِيرُهُ فَمَاتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُغَسَّلُ وَيُكَفَّنُ فِي ثَوْبَيْنِ وَلاَ يُغَطَّى رَأْسُهُ وَوَجْهُهُ فَإِنَّهُ يَقُومُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏\hadithno{2857}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas that:a man was performing Hajj with the Messenger of Allah and his she-camel threw him and he died. The Messenger of Allah said: "Wash him and shroud him in two garments, and do not cover his head of his face, for he will be raised on the Day of Resurrection reciting Talbiyah}}
\hadithdefcmd{nasai}{2858}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّ سَعِيدَ بْنَ جُبَيْرٍ، أَخْبَرَهُ أَنَّ ابْنَ عَبَّاسٍ أَخْبَرَهُ قَالَ أَقْبَلَ رَجُلٌ حَرَامًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَّ مِنْ فَوْقِ بَعِيرِهِ فَوُقِصَ وَقْصًا فَمَاتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَأَلْبِسُوهُ ثَوْبَيْهِ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّهُ يَأْتِي يَوْمَ الْقِيَامَةِ يُلَبِّي ‏"‏ ‏.‏\hadithno{2858}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abbas said:"A man in Ihram came with the Messenger of Allah and fell from atop his camel, breaking his neck, and he died. The Messenger of Allah said: 'Wash him with water and lotus leaves, and wrap him in his two garments. But do not cover his head, for he will be raised on the Day of Resurrection reciting the Talbiyah}}
\hadithdefcmd{nasai}{2859}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَاهُ أَنَّهُمَا، كَلَّمَا عَبْدَ اللَّهِ بْنَ عُمَرَ لَمَّا نَزَلَ الْجَيْشُ بِابْنِ الزُّبَيْرِ قَبْلَ أَنْ يُقْتَلَ فَقَالاَ لاَ يَضُرُّكَ أَنْ لاَ تَحُجَّ الْعَامَ إِنَّا نَخَافُ أَنْ يُحَالَ بَيْنَكَ وَبَيْنَ الْبَيْتِ ‏.‏ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَحَالَ كُفَّارُ قُرَيْشٍ دُونَ الْبَيْتِ فَنَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَدْيَهُ وَحَلَقَ رَأْسَهُ وَأُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ عُمْرَةً إِنْ شَاءَ اللَّهُ أَنْطَلِقُ فَإِنْ خُلِّيَ بَيْنِي وَبَيْنَ الْبَيْتِ طُفْتُ وَإِنْ حِيلَ بَيْنِي وَبَيْنَ الْبَيْتِ فَعَلْتُ مَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَعَهُ ‏.‏ ثُمَّ سَارَ سَاعَةً ثُمَّ قَالَ فَإِنَّمَا شَأْنُهُمَا وَاحِدٌ أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ حَجَّةً مَعَ عُمْرَتِي ‏.‏ فَلَمْ يَحْلِلْ مِنْهُمَا حَتَّى أَحَلَّ يَوْمَ النَّحْرِ وَأَهْدَى ‏.‏\hadithno{2859}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Nafi that:Abdulla bin Abdullah and salim bin Abdullah bin Umar when the army besiged Ibn Az-Zubair before he was killed. They said: "It does not matter if you do not perform Hajj this year; we are afraid lest we are prevented from reaching the House." He Sadi: we went out with the Messenger of Allah and the disbelievers of the Quraish prevented us from reaching the House. So the Messenger of Allah slaughtered his Hadi and shave his head. I ask you to bear witness that I have resolved to peform Umrah. If Allah wills I will set out and if I am allowed to reach the House I will circumambulate it, and if I am prevented from reaching the House I will do what the Messenger of Allah did when I was with him." Then he traveled for a while, then he said: "They are both the same. I ask you to bear witness that I have resolved to perform Hajj as well as Umrah. And he did not exit Ihram for either until he exited Ihram on the Day of Sacrifice and offered his Hadi}}
\hadithdefcmd{nasai}{2860}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ الْبَصْرِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، - وَهُوَ ابْنُ حَبِيبٍ - عَنِ الْحَجَّاجِ الصَّوَّافِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنِ الْحَجَّاجِ بْنِ عَمْرٍو الأَنْصَارِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ عَرِجَ أَوْ كُسِرَ فَقَدْ حَلَّ وَعَلَيْهِ حَجَّةٌ أُخْرَى ‏"‏ ‏.‏ فَسَأَلْتُ ابْنَ عَبَّاسٍ وَأَبَا هُرَيْرَةَ عَنْ ذَلِكَ فَقَالاَ صَدَقَ ‏.‏\hadithno{2860}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ikrimah, from Al-Hajjaj bin Amr Al-Ansari that:he heard the Messenger of Allah say "Whoever suffers a leg injury of breaks his leg, he has exited Ihram, but he has to perform another Hajj." I asked Ibn Abbas and Abu Hurarirah about that and he said "He spoke the truth}}
\hadithdefcmd{nasai}{2861}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حَجَّاجِ بْنِ الصَّوَّافِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنِ الْحَجَّاجِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كُسِرَ أَوْ عَرِجَ فَقَدْ حَلَّ وَعَلَيْهِ حَجَّةٌ أُخْرَى ‏"‏ ‏.‏ وَسَأَلْتُ ابْنَ عَبَّاسٍ وَأَبَا هُرَيْرَةَ فَقَالاَ صَدَقَ ‏.‏ وَقَالَ شُعَيْبٌ فِي حَدِيثِهِ وَعَلَيْهِ الْحَجُّ مِنْ قَابِلٍ ‏.‏\hadithno{2861}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ikramah, from Al-Hajja bin Amr that the Prophet said:"Whoever breaks his leg or suffers a leg injury, then he has exited Ihram, but he has to perform another Hajj." I asked Ibn 'Abbas and Abu Hurairah and the said: "He spoke the thurth." And in his narration (one of the narrators) shuaib said: "He has to perfom Hajj the following year}}
\hadithdefcmd{nasai}{2862}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالَ أَنْبَأَنَا سُوَيْدٌ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، قَالَ حَدَّثَنِي نَافِعٌ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَنْزِلُ بِذِي طُوًى يَبِيتُ بِهِ حَتَّى يُصَلِّيَ صَلاَةَ الصُّبْحِ حِينَ يَقْدَمُ إِلَى مَكَّةَ وَمُصَلَّى رَسُولِ اللَّهِ صلى الله عليه وسلم ذَلِكَ عَلَى أَكَمَةٍ غَلِيظَةٍ لَيْسَ فِي الْمَسْجِدِ الَّذِي بُنِيَ ثَمَّ وَلَكِنْ أَسْفَلَ مِنْ ذَلِكَ عَلَى أَكَمَةٍ خَشِنَةٍ غَلِيظَةٍ ‏.‏\hadithno{2862}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Umar narrated that:the Messenger of Allah used to dismount at Dhu Tuwa and stay there overnight unitl he prayed Subh when he was approaching Makkah. The place where the Messenger of Allah prayed was on top of the big hillock and not in the Masjid that was built later on, but it was lower than that, on top of the big hillock}}
\hadithdefcmd{nasai}{2863}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ، عَنْ شُعَيْبٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي مُزَاحِمُ بْنُ أَبِي مُزَاحِمٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عَبْدِ اللَّهِ، عَنْ مُحَرِّشٍ الْكَعْبِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ لَيْلاً مِنَ الْجِعِرَّانَةِ حِينَ مَشَى مُعْتَمِرًا فَأَصْبَحَ بِالْجِعِرَّانَةِ كَبَائِتٍ حَتَّى إِذَا زَالَتِ الشَّمْسُ خَرَجَ عَنِ الْجِعِرَّانَةِ فِي بَطْنِ سَرِفَ حَتَّى جَامَعَ الطَّرِيقَ طَرِيقَ الْمَدِينَةِ مِنْ سَرِفَ ‏.‏\hadithno{2863}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Muhaarish Al-Kabi, that:the Prophet went out a night from Al-Jirranah when he set out for Umrah, and came back to Al-Jirranah when he set out for Umrah, and came back to Al-Jirranah in the morning, as if he had stayed there. Then, when the sun had passed its zenith he went out from Al-Jirranah in the valley of Sarif until the road joined the road to Al-Madinah from Sarif}}
\hadithdefcmd{nasai}{2864}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ سُفْيَانَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ مُزَاحِمٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عَبْدِ اللَّهِ بْنِ خَالِدِ بْنِ أَسِيدٍ، عَنْ مُحَرِّشٍ الْكَعْبِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ مِنَ الْجِعِرَّانَةِ لَيْلاً كَأَنَّهُ سَبِيكَةُ فِضَّةٍ فَاعْتَمَرَ ثُمَّ أَصْبَحَ بِهَا كَبَائِتٍ ‏.‏\hadithno{2864}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muharrish Al-Kabi that:the Prophet set out from Al-Jirranah at night as if he were an ingot of silver (i.e., in whiteness and purity) and perfomed Umrah, then he came back in the mooring as if he had stayed there overnight}}
\hadithdefcmd{nasai}{2865}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ مَكَّةَ مِنَ الثَّنِيَّةِ الْعُلْيَا الَّتِي بِالْبَطْحَاءِ وَخَرَجَ مِنَ الثَّنِيَّةِ السُّفْلَى ‏.‏\hadithno{2865}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Umar that:the Messenger of Allah entered Makkah from the upper valley which is in Al-Batha and he left from the lower valley}}
\hadithdefcmd{nasai}{2866}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ عَمَّارٍ الدُّهْنِيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ وَلِوَاؤُهُ أَبْيَضُ ‏.‏\hadithno{2866}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:the Prophet enter Makkah and his standard was white}}
\hadithdefcmd{nasai}{2867}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ وَعَلَيْهِ الْمِغْفَرُ فَقِيلَ ابْنُ خَطَلٍ مُتَعَلِّقٌ بِأَسْتَارِ الْكَعْبَةِ ‏.‏ فَقَالَ ‏ "‏ اقْتُلُوهُ ‏"‏ ‏.‏\hadithno{2867}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ansas that the Prophet entered Makkah wearing a helmet. It was said that Ibn Katal was haging on to the drapes of the Kabah and he said:"Kill him}}
\hadithdefcmd{nasai}{2868}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ عَامَ الْفَتْحِ وَعَلَى رَأْسِهِ الْمِغْفَرُ ‏.‏\hadithno{2868}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that:the Prophet entered Makkah in the year of the Conquest wearing a helmet on his heard}}
\hadithdefcmd{nasai}{2869}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنِي أَبُو الزُّبَيْرِ الْمَكِّيُّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ يَوْمَ فَتْحِ مَكَّةَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ بِغَيْرِ إِحْرَامٍ ‏.‏\hadithno{2869}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin Abdulla that the Prophet entered on the day of the Conquest of Makkah wearing a back Imamah, without being in Ihram}}
\hadithdefcmd{nasai}{2870}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الْعَالِيَةِ الْبَرَّاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ لِصُبْحِ رَابِعَةٍ وَهُمْ يُلَبُّونَ بِالْحَجِّ فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَحِلُّوا ‏.‏\hadithno{2870}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allah and his Companions came on the morning of the fourth day (of Dhul-Hijjah), reciting the Talbiyah for Hajj, and the Messenger of commanded them to exit Ihram}}
\hadithdefcmd{nasai}{2871}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ يَحْيَى بْنِ كَثِيرٍ أَبُو غَسَّانَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَيُّوبَ، عَنْ أَبِي الْعَالِيَةِ الْبَرَّاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَرْبَعٍ مَضَيْنَ مِنْ ذِي الْحِجَّةِ وَقَدْ أَهَلَّ بِالْحَجِّ فَصَلَّى الصُّبْحَ بِالْبَطْحَاءِ وَقَالَ ‏ "‏ مَنْ شَاءَ أَنْ يَجْعَلَهَا عُمْرَةً فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{2871}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allah came on the fourth day of Dhul-Hijjah having entered Ihram for Hajj. He prayed Subh in Al-Batha and said: 'Whoever wants to make it Umrah, let him do so}}
\hadithdefcmd{nasai}{2872}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ أَنْبَأَنَا شُعَيْبٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ عَطَاءٌ قَالَ جَابِرٌ قَدِمَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ صَبِيحَةَ رَابِعَةٍ مَضَتْ مِنْ ذِي الْحِجَّةِ ‏.‏\hadithno{2872}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir said:"The Prophet came to Makkah on the morning of the fourth of Dhul-Hijjah}}
\hadithdefcmd{nasai}{2873}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ فِي عُمْرَةِ الْقَضَاءِ وَعَبْدُ اللَّهِ بْنُ رَوَاحَةَ يَمْشِي بَيْنَ يَدَيْهِ وَهُوَ يَقُولُ خَلُّوا بَنِي الْكُفَّارِ عَنْ سَبِيلِهِ الْيَوْمَ نَضْرِبْكُمْ عَلَى تَنْزِيلِهِ ضَرْبًا يُزِيلُ الْهَامَ عَنْ مَقِيلِهِ وَيُذْهِلُ الْخَلِيلَ عَنْ خَلِيلِهِ فَقَالَ لَهُ عُمَرُ يَا ابْنَ رَوَاحَةَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي حَرَمِ اللَّهِ عَزَّ وَجَلَّ تَقُولُ الشِّعْرَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خَلِّ عَنْهُ فَلَهُوَ أَسْرَعُ فِيهِمْ مِنْ نَضْحِ النَّبْلِ ‏"‏ ‏.‏\hadithno{2873}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Anas that:the Prophet entered Makkah during the Umratul-Qada, and Abdullah bin Rawahah was walking in front of him and saying: Get out of his way, you unbelievers, make way. Today we will fight about its revelation With blows that will remove beads from shoulders And make friend unmindful of friends. Umar said to him: "O Ibn Rawahah! In front of the Messenger of Allah and in the Sancturary of Allah, the Might and Sublime, you recite poetry?" The Prophet said: "Let him do so, for what he is saying is more effective than shooting arrows at them}}
\hadithdefcmd{nasai}{2874}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ ‏"‏ هَذَا الْبَلَدُ حَرَّمَهُ اللَّهُ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ فَهُوَ حَرَامٌ بِحُرْمَةِ اللَّهِ إِلَى يَوْمِ الْقِيَامَةِ لاَ يُعْضَدُ شَوْكُهُ وَلاَ يُنَفَّرُ صَيْدُهُ وَلاَ يَلْتَقِطُ لُقَطَتَهُ إِلاَّ مَنْ عَرَّفَهَا وَلاَ يُخْتَلَى خَلاَهُ ‏"‏ ‏.‏ قَالَ الْعَبَّاسُ يَا رَسُولَ اللَّهِ إِلاَّ الإِذْخِرَ ‏.‏ فَذَكَرَ كَلِمَةً مَعْنَاهَا ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏ ‏.‏\hadithno{2874}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allah said on the day of the conquest: 'Allah made this land sacred the day He created the Heavens and the Earth, so it is sacred by the Decree of Allah until the day of Resurrection. Its thorny shrubs are not to be cut, or its game disturbed, or its lost property to be picked up, except by the one who will announce it publicly, or is its green grass to be uprooted or cut.' Al-Abbas said: O Messenger of Allah! Except Ikhkhir.'" And he said something that meant: "Except Ikhkhir}}
\hadithdefcmd{nasai}{2875}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا مُفَضَّلٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ ‏ "‏ إِنَّ هَذَا الْبَلَدَ حَرَامٌ حَرَّمَهُ اللَّهُ عَزَّ وَجَلَّ لَمْ يَحِلَّ فِيهِ الْقِتَالُ لأَحَدٍ قَبْلِي وَأُحِلَّ لِي سَاعَةً مِنْ نَهَارٍ فَهُوَ حَرَامٌ بِحُرْمَةِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2875}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allah said on the day of the conquest of Makkah: 'Allah, the Might and Sublime, has made this land sacred, and it was not permissible to fight therein for anyone before me. It was permitted for me for a few hours of a day, and it is sacred by the decree of Allah, the Might and Sublime}}
\hadithdefcmd{nasai}{2876}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي شُرَيْحٍ، أَنَّهُ قَالَ لِعَمْرِو بْنِ سَعِيدٍ وَهُوَ يَبْعَثُ الْبُعُوثَ إِلَى مَكَّةَ ائْذَنْ لِي أَيُّهَا الأَمِيرُ أُحَدِّثْكَ قَوْلاً قَامَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الْغَدَ مِنْ يَوْمِ الْفَتْحِ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي وَأَبْصَرَتْهُ عَيْنَاىَ حِينَ تَكَلَّمَ بِهِ حَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ إِنَّ مَكَّةَ حَرَّمَهَا اللَّهُ وَلَمْ يُحَرِّمْهَا النَّاسُ وَلاَ يَحِلُّ لاِمْرِئٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَسْفِكَ بِهَا دَمًا وَلاَ يَعْضِدَ بِهَا شَجَرًا فَإِنْ تَرَخَّصَ أَحَدٌ لِقِتَالِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهَا فَقُولُوا لَهُ إِنَّ اللَّهَ أَذِنَ لِرَسُولِهِ وَلَمْ يَأْذَنْ لَكُمْ وَإِنَّمَا أَذِنَ لِي فِيهَا سَاعَةً مِنْ نَهَارٍ وَقَدْ عَادَتْ حُرْمَتُهَا الْيَوْمَ كَحُرْمَتِهَا بِالأَمْسِ وَلْيُبَلِّغِ الشَّاهِدُ الْغَائِبَ ‏"‏ ‏.‏\hadithno{2876}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Shuraih, that he said to Amr bin Sad when he was sending troops in batches to Makkah:"O Commander! Permit me to tell you of a statement that the Messenger of Allah said the day after the Conquest of Makkah, which my ears heard, my hear understood, and my eyes saw, when he said it. He (the Prophet) praised Allah, then he said: 'Makkah has been made sacred by Allah, not by the people. It is not permissible for any man who believes in Allah and the Last Day to shed blood in it, or to cut its trees. If any one seeks permission to fight in it because the Messenger of Allah fought in it, say to him: Allah allowed his Messenger (to fight therein) but He did not allow you. Rather permission was given to me (to fight therein) for a short period one day, and now its sanctity has been restored as it as before. Let those who are present convey (this mews) to those who are absent}}
\hadithdefcmd{nasai}{2877}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا بِشْرٌ، أَخْبَرَنِي أَبِي، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سُحَيْمٌ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَغْزُو هَذَا الْبَيْتَ جَيْشٌ فَيُخْسَفُ بِهِمْ بِالْبَيْدَاءِ ‏"‏ ‏.‏\hadithno{2877}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: This Hosue will be attacked by an army, and they will be swallowed up by the earth in Al-Baida}}
\hadithdefcmd{nasai}{2878}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِدْرِيسَ أَبُو حَاتِمٍ الرَّازِيُّ، قَالَ حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ مِسْعَرٍ، قَالَ أَخْبَرَنِي طَلْحَةُ بْنُ مُصَرِّفٍ، عَنْ أَبِي مُسْلِمٍ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنْتَهِي الْبُعُوثُ عَنْ غَزْوِ هَذَا الْبَيْتِ حَتَّى يُخْسَفَ بِجَيْشٍ مِنْهُمْ ‏"‏ ‏.‏\hadithno{2878}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Troops will not cease to attack this House until an army of them are swallowed up by the earth}}
\hadithdefcmd{nasai}{2879}{أَخْبَرَنِي مُحَمَّدُ بْنُ دَاوُدَ الْمِصِّيصِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدِ بْنِ سَابِقٍ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا عَبْدُ السَّلاَمِ، عَنِ الدَّالاَنِيِّ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَخِيهِ، قَالَ حَدَّثَنِي ابْنُ أَبِي رَبِيعَةَ، عَنْ حَفْصَةَ بِنْتِ عُمَرَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُبْعَثُ جُنْدٌ إِلَى هَذَا الْحَرَمِ فَإِذَا كَانُوا بِبَيْدَاءَ مِنَ الأَرْضِ خُسِفَ بِأَوَّلِهِمْ وَآخِرِهِمْ وَلَمْ يَنْجُ أَوْسَطُهُمْ ‏"‏ ‏.‏ قُلْتُ أَرَأَيْتَ إِنْ كَانَ فِيهِمْ مُؤْمِنُونَ قَالَ ‏"‏ تَكُونُ لَهُمْ قُبُورًا ‏"‏ ‏.‏\hadithno{2879}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Hafshah bint Umar said:"The Messenger of Allah sadi: 'An army will be sent toward this House, and when they are in Al-Baida, they first and the last of them will be swallowed up by the earth, and those in the middle will be saved.' I said: "What if there are believers among them?" He said: 'It will be graves for them.'" (Daif)}}
\hadithdefcmd{nasai}{2880}{أَخْبَرَنَا الْحُسَيْنُ بْنُ عِيسَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أُمَيَّةَ بْنِ صَفْوَانَ بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، سَمِعَ جَدَّهُ، يَقُولُ حَدَّثَتْنِي حَفْصَةُ، أَنَّهُ قَالَ صلى الله عليه وسلم ‏ "‏ لَيَؤُمَّنَّ هَذَا الْبَيْتَ جَيْشٌ يَغْزُونَهُ حَتَّى إِذَا كَانُوا بِبَيْدَاءَ مِنَ الأَرْضِ خُسِفَ بِأَوْسَطِهِمْ فَيُنَادِي أَوَّلُهُمْ وَآخِرُهُمْ فَيُخْسَفُ بِهِمْ جَمِيعًا وَلاَ يَنْجُو إِلاَّ الشَّرِيدُ الَّذِي يُخْبِرُ عَنْهُمْ ‏"‏ ‏.‏ فَقَالَ لَهُ رَجُلٌ أَشْهَدُ عَلَيْكَ أَنَّكَ مَا كَذَبْتَ عَلَى جَدِّكَ وَأَشْهَدُ عَلَى جَدِّكَ أَنَّهُ مَا كَذَبَ عَلَى حَفْصَةَ وَأَشْهَدُ عَلَى حَفْصَةَ أَنَّهَا لَمْ تَكْذِبْ عَلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2880}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Hafsah narrated that he said:An invading army will come toward this House until when they are in Al-Baida, the middle of them will be swallowed up by the earth. The first of them will call out to the last of them, and they will be wallowed up, until there is no one left of them except a fugitive who will tell of what happened to them." A man (hearing the narration) said: "I bear witness that you did not attribute a lie to your grandfather, and I bear witness that your grandfather did not attribute a lie to Hafsah, and I bear witness that Hafsh, did not attribute a lie to the Prophet}}
\hadithdefcmd{nasai}{2881}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسُ فَوَاسِقَ يُقْتَلْنَ فِي الْحِلِّ وَالْحَرَمِ الْغُرَابُ وَالْحِدَأَةُ وَالْكَلْبُ الْعَقُورُ وَالْعَقْرَبُ وَالْفَأْرَةُ ‏"‏ ‏.‏\hadithno{2881}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Aishah that the Messenger of Allah said:"There are five kinds of vermin which may be killed out and inside the Haram: Crows, kites, vicious dogs, scorpions and mice}}
\hadithdefcmd{nasai}{2882}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَا��َ أَنْبَأَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يُحَدِّثُ عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسُ فَوَاسِقَ يُقْتَلْنَ فِي الْحِلِّ وَالْحَرَمِ الْحَيَّةُ وَالْكَلْبُ الْعَقُورُ وَالْغُرَابُ الأَبْقَعُ وَالْحِدَأَةُ وَالْفَأْرَةُ ‏"‏ ‏.‏\hadithno{2882}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Aishah that the Messenger of Allah said:"There are five kinds of vermin which may be killed out and inside the Haram: Snakes, vicious dogs, speckled Crows, kites, and mice}}
\hadithdefcmd{nasai}{2883}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ حَفْصِ بْنِ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْخَيْفِ مِنْ مِنًى حَتَّى نَزَلَتْ ‏\{‏ وَالْمُرْسَلاَتِ عُرْفًا ‏\}‏ فَخَرَجَتْ حَيَّةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْتُلُوهَا ‏"‏ ‏.‏ فَابْتَدَرْنَاهَا فَدَخَلَتْ فِي جُحْرِهَا ‏.‏\hadithno{2883}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abdullah said:"We were with the Messenger of Allah in Al-Khaif, which is in Mina, when the following was revealed: 'By the winds sent forth one after another.' A snake came out, and the Messenger of Allah said: 'Kill it.' So they rushed to kill, but it went back into its hole}}
\hadithdefcmd{nasai}{2884}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ مُجَاهِدٍ، عَنْ أَبِي عُبَيْدَةَ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةَ عَرَفَةَ الَّتِي قَبْلَ يَوْمِ عَرَفَةَ فَإِذَا حِسُّ الْحَيَّةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْتُلُوهَا ‏"‏ ‏.‏ فَدَخَلَتْ شَقَّ جُحْرٍ فَأَدْخَلْنَا عُودًا فَقَلَعْنَا بَعْضَ الْجُحْرِ فَأَخَذْنَا سَعَفَةً فَأَضْرَمْنَا فِيهَا نَارًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَقَاهَا اللَّهُ شَرَّكُمْ وَوَقَاكُمْ شَرَّهَا ‏"‏ ‏.‏\hadithno{2884}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Ubaidah that his father said:"We were with the Messenger of Allah on the night of Arafat which is before Arafat, when he heard a snake. The Messenger of Allah said: 'Kill it.' It went into a crack in a rock, and we put a stick in and broke part of the hole, then we took some palm tree leave and set them ablaze in the hole. The Messenger of Allah: 'Allah protected it from your evil and protected you from its evil}}
\hadithdefcmd{nasai}{2885}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ جُبَيْرِ بْنِ شَيْبَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ شَرِيكٍ، قَالَتْ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الأَوْزَاغِ ‏.‏\hadithno{2885}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Saeed bin Al-Musayyab that Umm Sharik said:"The Messenger of Allah told me to kill geckos}}
\hadithdefcmd{nasai}{2886}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَالِكٌ، وَيُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْوَزَغُ الْفُوَيْسِقُ ‏"‏ ‏.‏\hadithno{2886}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aishah that the Messenger of Allah said:"Geckos are vermin}}
\hadithdefcmd{nasai}{2887}{أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ الرَّقِّيُّ الْقَطَّانُ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبَانُ بْنُ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ، أَخْبَرَهُ أَنَّ عَائِشَةَ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ كُلُّهُنَّ فَاسِقٌ يُقْتَلْنَ فِي الْحِلِّ وَالْحَرَمِ الْكَلْبُ الْعَقُورُ وَالْغُرَابُ وَالْحِدَأَةُ وَالْعَقْرَبُ وَالْفَأْرَةُ ‏"‏ ‏.‏\hadithno{2887}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Prophet said: "There are five animals all of which are vermin, and may killed outside and inside the sanctuary: Vicious dogs, crows, kites, scorpions and mice}}
\hadithdefcmd{nasai}{2888}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ كُلُّهَا فَاسِقٌ يُقْتَلْنَ فِي الْحَرَمِ الْغُرَابُ وَالْحِدَأَةُ وَالْكَلْبُ الْعَقُورُ وَالْفَأْرَةُ وَالْعَقْرَبُ ‏"‏ ‏.‏\hadithno{2888}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Urwah that Aishah said:"The Messenger of Allah said: "There are five animals all of which are vermin and may be killed inside the sanctuary: Crow, kites, vicious dogs, mice and scorpions}}
\hadithdefcmd{nasai}{2889}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ قَالَتْ حَفْصَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ لاَ حَرَجَ عَلَى مَنْ قَتَلَهُنَّ الْعَقْرَبُ وَالْغُرَابُ وَالْحِدَأَةُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2889}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Umar said:"Hafsha the wife of the Prophet said: 'The Messenger of Allah said: Thee are five animals for which there is no sin on the one who kill them: Scorpions, crows, kites, mice and vicious dogs}}
\hadithdefcmd{nasai}{2890}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسُ فَوَاسِقَ يُقْتَلْنَ فِي الْحِلِّ وَالْحَرَمِ الْحِدَأَةُ وَالْغُرَابُ وَالْفَأْرَةُ وَالْعَقْرَبُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ وَذَكَرَ بَعْضُ أَصْحَابِنَا أَنَّ مَعْمَرًا كَانَ يَذْكُرُهُ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ وَعَنْ عُرْوَةَ عَنْ عَائِشَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{2890}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aishah that:the Messenger of Allah said "There are five vermin that may be killed outside and inside the Haram: Kities, cros, mice, scorpions, and vicious dogs." (One of the narratos Abdur-Razzaq said: "Some of our companions mentioned that Mamar would mention it from Az-Zuhri, from Salim, from his father, and from Urwah, from Aishah, from the Prophet)}}
\hadithdefcmd{nasai}{2891}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدَةَ، قَالَ أَنْبَأَنَا حَمَّادٌ، قَالَ حَدَّثَنَا هِشَامٌ، - وَهُوَ ابْنُ عُرْوَةَ - عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسُ فَوَاسِقَ يُقْتَلْنَ فِي الْحَرَمِ الْعَقْرَبُ وَالْفَأْرَةُ وَالْغُرَابُ وَالْكَلْبُ الْعَقُورُ وَالْحِدَأَةُ ‏"‏ ‏.‏\hadithno{2891}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aishah said:"The Messenger of Allah said: 'There are five kinds of vermin that may be killed in the Haram: Scorpions, mice, crows, vicious dogs, and kites." (Sahih) Chaper 120. The Prohibition Of Disturbing The Game Of The Haram}}
\hadithdefcmd{nasai}{2892}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ هَذِهِ مَكَّةُ حَرَّمَهَا اللَّهُ عَزَّ وَجَلَّ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ لَمْ تَحِلَّ لأَحَدٍ قَبْلِي وَلاَ لأَحَدٍ بَعْدِي وَإِنَّمَا أُحِلَّتْ لِي سَاعَةً مِنْ نَهَارٍ وَهِيَ سَاعَتِي هَذِهِ حَرَامٌ بِحَرَامِ اللَّهِ إِلَى يَوْمِ الْقِيَامَةِ لاَ يُخْتَلَى خَلاَهَا وَلاَ يُعْضَدُ شَجَرُهَا وَلاَ يُنَفَّرُ صَيْدُهَا وَلاَ تَحِلُّ لُقَطَتُهَا إِلاَّ لِمُنْشِدٍ ‏"‏ ‏.‏ فَقَامَ الْعَبَّاسُ وَكَانَ رَجُلاً مُجَرِّبًا فَقَالَ إِلاَّ الإِذْخِرَ فَإِنَّهُ لِبُيُوتِنَا وَقُبُورِنَا ‏.‏ فَقَالَ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏ ‏.‏\hadithno{2892}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn Abbas that the Messenger of Allah said:"This Makkah was made sacred by Allah, the Mighty and Sublime, the day He created the heavens and the Earth. Fighting therein was not permitted for any one before me or after me rather it was permitted for me for a short part of a day. At this moment it is a sanctuary that is sacred by the decree of Allah until the Day of Resurrection. Its green grass is not to be uprooted or cut, its trees are not to be cut and its game is not to be distributed. IT is not permissible to pick up its lost property except by one who will announce it publicly." Al-Abbas who was a man of experience, stood up and said: "Except Idkhair, for we use it for our raves and houses." He said: "Except Idhkhir}}
\hadithdefcmd{nasai}{2893}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ زَنْجُويَهْ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ فِي عُمْرَةِ الْقَضَاءِ وَابْنُ رَوَاحَةَ بَيْنَ يَدَيْهِ يَقُولُ خَلُّوا بَنِي الْكُفَّارِ عَنْ سَبِيلِهِ الْيَوْمَ نَضْرِبْكُمْ عَلَى تَأْوِيلِهِ ضَرْبًا يُزِيلُ الْهَامَ عَنْ مَقِيلِهِ وَيُذْهِلُ الْخَلِيلَ عَنْ خَلِيلِهِ قَالَ عُمَرُ يَا ابْنَ رَوَاحَةَ فِي حَرَمِ اللَّهِ وَبَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم تَقُولُ هَذَا الشِّعْرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خَلِّ عَنْهُ فَوَالَّذِي نَفْسِي بِيَدِهِ لَكَلاَمُهُ أَشَدُّ عَلَيْهِمْ مِنْ وَقْعِ النَّبْلِ ‏"‏ ‏.‏\hadithno{2893}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"The Prophet entered Makkah during Umratul-Qada' and Ibn Rawahah went before him, saying: Get out of his way, you unbelievers, make way. Today we will fight about its revelation With blows that will remove heads from shoulders And make friend unmindful of friend. Umar said to him: "O Ibn Rawahah! In the Sanctuary of Allah and in front of the Messenger of Allah you recite poetry?" The Prophet said: "Let him do that, for by the one in whose hand is my soul, his words are harder for them than being shot with arrows}}
\hadithdefcmd{nasai}{2894}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا قَدِمَ مَكَّةَ اسْتَقْبَلَهُ أُغَيْلِمَةُ بَنِي هَاشِمٍ - قَالَ - فَحَمَلَ وَاحِدًا بَيْنَ يَدَيْهِ وَآخَرَ خَلْفَهُ ‏.‏\hadithno{2894}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn Abbas that:when the Prophet came to Makkah, he was welcomed by the boys of Banu Hashim, and he carried one of them in front of him (on his mount) and one behind him}}
\hadithdefcmd{nasai}{2895}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا قَزَعَةَ الْبَاهِلِيَّ، يُحَدِّثُ عَنِ الْمُهَاجِرِ الْمَكِّيِّ، قَالَ سُئِلَ جَابِرُ بْنُ عَبْدِ اللَّهِ عَنِ الرَّجُلِ، يَرَى الْبَيْتَ أَيَرْفَعُ يَدَيْهِ قَالَ مَا كُنْتُ أَظُنُّ أَحَدًا يَفْعَلُ هَذَا إِلاَّ الْيَهُودَ حَجَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ نَكُنْ نَفْعَلُهُ ‏.‏\hadithno{2895}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Muhajir Al-Makki said:"Jabir bin Abdullah was asked whether a man should raise his hands when he sees the House. He said: "I do not think that anyone does that except the Jews. We performed Hajj with the Messenger of Allah and we did not do that." (Daif)}}
\hadithdefcmd{nasai}{2896}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ طَارِقِ بْنِ عَلْقَمَةَ، أَخْبَرَهُ عَنْ أُمِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا جَاءَ مَكَانًا فِي دَارِ يَعْلَى اسْتَقْبَلَ الْقِبْلَةَ وَدَعَا ‏.‏\hadithno{2896}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdur-Rahman bin Tariq bin Alqamah narrated from his mother, that:when the Prophet came to a place in Dar Yala he turned to face the Qiblah and supplicated. (Daif)}}
\hadithdefcmd{nasai}{2897}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُوسَى بْنِ عَبْدِ اللَّهِ الْجُهَنِيِّ، قَالَ سَمِعْتُ نَافِعًا، يَقُولُ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ أَعْلَمُ أَحَدًا رَوَى هَذَا الْحَدِيثَ عَنْ نَافِعٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ غَيْرَ مُوسَى الْجُهَنِيِّ ‏.‏ وَخَالَفَهُ ابْنُ جُرَيْجٍ وَغَيْرُهُ ‏.‏\hadithno{2897}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Umar said:"I heard the Messenger of Allah say: "One prayer in my Masjid is better than a thousand prayers anywhere else, except Al-Masjid Al-Haram.'" Abu Abdur-Rahman said: "I do not know of any one who reported this Hadith from Nafi, from Abdullah bin Umar, other than Musa Al-Juhani; he was contradicted by Ibn Juraij and others}}
\hadithdefcmd{nasai}{2898}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالَ إِسْحَاقُ أَنْبَأَنَا وَقَالَ، مُحَمَّدٌ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ نَافِعًا، يَقُولُ حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ عَبَّاسٍ، حَدَّثَهُ أَنَّ مَيْمُونَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ الْمَسْجِدَ الْكَعْبَةَ ‏"‏ ‏.‏\hadithno{2898}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Maimunah, the wife of the Prophet said:"I heard the Messenger of Allah say: 'One prayer in this Masjid of mine is better than a thousand prayers in any other Masjid except Al-Masjid Al-Haram}}
\hadithdefcmd{nasai}{2899}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، قَالَ سَأَلْتُ الأَغَرَّ عَنْ هَذَا الْحَدِيثِ، فَحَدَّثَ الأَغَرُّ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ الْكَعْبَةَ ‏"‏ ‏.‏\hadithno{2899}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Prophet said:"One prayer in this Masjid of mine is better than a thousand prayers in any other Masjid except Al-Masjid Al-Kabah}}
\hadithdefcmd{nasai}{2900}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، أَخْبَرَ عَبْدَ اللَّهِ بْنَ عُمَرَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلَمْ تَرَىْ أَنَّ قَوْمَكِ حِينَ بَنَوُا الْكَعْبَةَ اقْتَصَرُوا عَنْ قَوَاعِدِ إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ أَلاَ تَرُدُّهَا عَلَى قَوَاعِدِ إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ قَالَ ‏"‏ لَوْلاَ حِدْثَانُ قَوْمِكِ بِالْكُفْرِ ‏"‏ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لَئِنْ كَانَتْ عَائِشَةُ سَمِعَتْ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أُرَى تَرْكَ اسْتِلاَمِ الرُّكْنَيْنِ اللَّذَيْنِ يَلِيَانِ الْحِجْرَ إِلاَّ أَنَّ الْبَيْتَ لَمْ يُتَمَّمْ عَلَى قَوَاعِدِ إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ ‏.‏\hadithno{2900}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aishah that the Messenger of Allah said:"Don't you see that when your people (re)built the Kabah, they did not build it on all the foundations laid by Ibrahim, peace be upon him?" I said: "O Messenger of Allah, why do you not rebuild it on the foundation of Ihrahim, peace be upon him?" He said: "Were it not for the fact that your people have recently left disbelief (I would have done so)." Abdullah bin Umar said: "Aishah heard this from the Messenger of Allah, for I see that he would not touch the two corners facing Al-Hijr because the House not built on the foundations of Ihrahim, peace be upon him?}}
\hadithdefcmd{nasai}{2901}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ، وَأَبُو مُعَاوِيَةَ قَالاَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ حَدَاثَةُ عَهْدِ قَوْمِكِ بِالْكُفْرِ لَنَقَضْتُ الْبَيْتَ فَبَنَيْتُهُ عَلَى أَسَاسِ إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ وَجَعَلْتُ لَهُ خَلْفًا فَإِنَّ قُرَيْشًا لَمَّا بَنَتِ الْبَيْتَ اسْتَقْصَرَتْ ‏"‏ ‏.‏\hadithno{2901}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Messenger of Allah said: "Were it not for the fact that your people have recently left disbelief, I would have knocked down the House and rebuilt it on the foundation of Ibrahim, peace be upon him, and I would have given it a back door. For when the Quraish built the House, they made it too small}}
\hadithdefcmd{nasai}{2902}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، عَنْ خَالِدٍ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، أَنَّ أُمَّ الْمُؤْمِنِينَ، قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنَّ قَوْمِي - وَفِي حَدِيثِ مُحَمَّدٍ قَوْمَكِ - حَدِيثُ عَهْدِ بِجَاهِلِيَّةٍ لَهَدَمْتُ الْكَعْبَةَ وَجَعَلْتُ لَهَا بَابَيْنِ ‏"‏ ‏.‏ فَلَمَّا مَلَكَ ابْنُ الزُّبَيْرِ جَعَلَ لَهَا بَابَيْنِ ‏.‏\hadithno{2902}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Al-Aswad that the Mother of the Believers said:"The Messenger of Allah said: "Were it not for the fact that my people' - according to the narration of Muhammad he said: 'Your people' - 'have recently left Jailiyyah, I would have knocked down the House and given it two doors.'" When Ibn Az-Zubair was in power, he gave it two doors}}
\hadithdefcmd{nasai}{2903}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ يَا عَائِشَةُ لَوْلاَ أَنَّ قَوْمَكِ حَدِيثُ عَهْدٍ بِجَاهِلِيَّةٍ لأَمَرْتُ بِالْبَيْتِ فَهُدِمَ فَأَدْخَلْتُ فِيهِ مَا أُخْرِجَ مِنْهُ وَأَلْزَقْتُهُ بِالأَرْضِ وَجَعَلْتُ لَهُ بَابَيْنِ بَابًا شَرْقِيًّا وَبَابًا غَرْبِيًّا فَإِنَّهُمْ قَدْ عَجَزُوا عَنْ بِنَائِهِ فَبَلَغْتُ بِهِ أَسَاسَ إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ قَالَ فَذَلِكَ الَّذِي حَمَلَ ابْنَ الزُّبَيْرِ عَلَى هَدْمِهِ ‏.‏ قَالَ يَزِيدُ وَقَدْ شَهِدْتُ ابْنَ الزُّبَيْرِ حِينَ هَدَمَهُ وَبَنَاهُ وَأَدْخَلَ فِيهِ مِنَ الْحِجْرِ وَقَدْ رَأَيْتُ أَسَاسَ إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ حِجَارَةً كَأَسْنِمَةِ الإِبِلِ مُتَلاَحِكَةً ‏.‏\hadithno{2903}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Aisha that the Messenger of Allah said to her:"O Aishah, were if not for the fact that your people have recently left Jahiliyyah, I would have commanded that the House be knocked down, and I would have incorporated into it what was left out of it. I would have made its (door) in level with the ground and I would have given it two doors, an eastern door and a western door. For they built it too small, and by doing this, it would have been built on the foundation of Ibrahim, peace be upon him." He (one of the narrators said: "This is what motivated Ibn Az-Zubair to knock it down." Yazid said: "I saw Ibn Az-Zubair when he knocked it down and rebuilt it, and included part of the Hijr in it. And I saw the foundation of Ibrahim, peace be upon him, stones like the humps of camels joined to one another)}}
\hadithdefcmd{nasai}{2904}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُخَرِّبُ الْكَعْبَةَ ذُو السُّوَيْقَتَيْنِ مِنَ الْحَبَشَةِ ‏"‏ ‏.‏\hadithno{2904}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The Kabah will be destroyed by Dhul-Suwaiqatan (one with thin legs) from Ethiopia}}
\hadithdefcmd{nasai}{2905}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ انْتَهَى إِلَى الْكَعْبَةِ وَقَدْ دَخَلَهَا النَّبِيُّ صلى الله عليه وسلم وَبِلاَلٌ وَأُسَامَةُ بْنُ زَيْدٍ وَأَجَافَ عَلَيْهِمْ عُثْمَانُ بْنُ طَلْحَةَ الْبَابَ فَمَكَثُوا فِيهَا مَلِيًّا ثُمَّ فَتَحَ الْبَابَ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم وَرَكِبْتُ الدَّرَجَةَ وَدَخَلْتُ الْبَيْتَ فَقُلْتُ أَيْنَ صَلَّى النَّبِيُّ صلى الله عليه وسلم قَالُوا هَا هُنَا ‏.‏ وَنَسِيتُ أَنْ أَسْأَلَهُمْ كَمْ صَلَّى النَّبِيُّ صلى الله عليه وسلم فِي الْبَيْتِ ‏.‏\hadithno{2905}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abdullah bin Umar that:he came to the Kabah when the Prophet, Bilal and Usamah bin Zaid had enter it, and Uthman bin Talhah had shut the door. They stayed there for a while, then he opened the door and the Prophet came out. I (Ibn Umar) Climed the steps and entered the House and said: "Where did the Prophet pray?" They said: "Here." And I forgot to ask them how many (Rakahs) the Prophet had prayed inside the House}}
\hadithdefcmd{nasai}{2906}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْتَ وَمَعَهُ الْفَضْلُ بْنُ عَبَّاسٍ وَأُسَامَةُ بْنُ زَيْدٍ وَعُثْمَانُ بْنُ طَلْحَةَ وَبِلاَلٌ فَأَجَافُوا عَلَيْهِمُ الْبَابَ فَمَكَثَ فِيهِ مَا شَاءَ اللَّهُ ثُمَّ خَرَجَ ‏.‏ قَالَ ابْنُ عُمَرَ كَانَ أَوَّلُ مَنْ لَقِيتُ بِلاَلاً قُلْتُ أَيْنَ صَلَّى النَّبِيُّ صلى الله عليه وسلم قَالَ مَا بَيْنَ الأُسْطُوَانَتَيْنِ ‏.‏\hadithno{2906}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Umar said:"The Messenger of Allah entered the House, accompanied by Al-Fadl bin abbas, Usmah bin Zaid,. Uthman bin Talhah and Bilal. They shut the door, and he stayed there for as long as Allah willed, then he coame out." Ibn Umar said: "The first one whom I met was Bilal, and I said: "Where did the Prophet pray?' He said: "Between the two columns}}
\hadithdefcmd{nasai}{2907}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا السَّائِبُ بْنُ عُمَرَ، قَالَ حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، أَنَّ ابْنَ عُمَرَ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْكَعْبَةَ وَدَنَا خُرُوجُهُ وَوَجَدْتُ شَيْئًا فَذَهَبْتُ وَجِئْتُ سَرِيعًا فَوَجَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم خَارِجًا فَسَأَلْتُ بِلاَلاً أَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْكَعْبَةِ قَالَ نَعَمْ رَكْعَتَيْنِ بَيْنَ السَّارِيَتَيْنِ ‏.‏\hadithno{2907}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Umar said:"The Messenger of Allah entered the Kabah, and was about to come out, when I thought of something, so I came quickly and I found the Messenger of Allah coming out. I asked Bilal: Did the Messenger of Allah prayed inside the Kabah?' He said: 'Yes, two Rakahs between the two columns}}
\hadithdefcmd{nasai}{2908}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سَيْفُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ أُتِيَ ابْنُ عُمَرَ فِي مَنْزِلِهِ فَقِيلَ هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ دَخَلَ الْكَعْبَةَ فَأَقْبَلْتُ فَأَجِدُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ خَرَجَ وَأَجِدُ بِلاَلاً عَلَى الْبَابِ قَائِمًا فَقُلْتُ يَا بِلاَلُ أَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْكَعْبَةِ قَالَ نَعَمْ ‏.‏ قُلْتُ أَيْنَ قَالَ مَا بَيْنَ هَاتَيْنِ الأُسْطُوَانَتَيْنِ رَكْعَتَيْنِ ثُمَّ خَرَجَ فَصَلَّى رَكْعَتَيْنِ فِي وَجْهِ الْكَعْبَةِ ‏.‏\hadithno{2908}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Some one came to Ibn Umar in his house and said:The Messenger of Allah has entered the Kabah." So Ibn Umar said, I (Ibn Umar) came and found that the Messenger of Allah had come out, and I found Bilal standing at the door. I said: "O Bilal, did the Messenger of Allah pray inside the Kabah?' He said: "Ues." I said: "Where>" He said: "Between these two columns, two Rakahs. Then he came out and prayed two Rakahs in front of the Kabah}}
\hadithdefcmd{nasai}{2909}{أَخْبَرَنَا حَاجِبُ بْنُ سُلَيْمَانَ الْمَنْبِجِيُّ، عَنِ ابْنِ أَبِي رَوَّادٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْكَعْبَةَ فَسَبَّحَ فِي نَوَاحِيهَا وَكَبَّرَ وَلَمْ يُصَلِّ ثُمَّ خَرَجَ فَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ ثُمَّ قَالَ ‏ "‏ هَذِهِ الْقِبْلَةُ ‏"‏ ‏.‏\hadithno{2909}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Usmah bin Zaid said:"The Messenger of Allah entered the Kabah and recited the Tasbih and the Takbir in its corners, but he did not pray. Then he came out and prayed two Rakahs behind the Maqam, then he said: 'This is Qiblah}}
\hadithdefcmd{nasai}{2910}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ أَبِي زَائِدَةَ، قَالَ حَدَّثَنَا ابْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، قَالَ ابْنُ الزُّبَيْرِ سَمِعْتُ عَائِشَةَ، تَقُولُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنَّ النَّاسَ حَدِيثٌ عَهْدُهُمْ بِكُفْرٍ وَلَيْسَ عِنْدِي مِنَ النَّفَقَةِ مَا يُقَوِّي عَلَى بِنَائِهِ لَكُنْتُ أَدْخَلْتُ فِيهِ مِنَ الْحِجْرِ خَمْسَةَ أَذْرُعٍ وَجَعَلْتُ لَهُ بَابًا يَدْخُلُ النَّاسُ مِنْهُ وَبَابًا يَخْرُجُونَ مِنْهُ ‏"‏ ‏.‏\hadithno{2910}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{Aishah said:"The Prophet said: 'Were it not for the fact that the people have recently left disbelief, and that I do not have enough funds to enable me to build it. I would have incorporated five cubits of the Hijr in it, and given it a door through which the people could enter, and another door through which they exit}}
\hadithdefcmd{nasai}{2911}{أَخْبَرَنَا أَحْمَدُ بْنُ سَعِيدٍ الرِّبَاطِيُّ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جُبَيْرٍ، عَنْ عَمَّتِهِ، صَفِيَّةَ بِنْتِ شَيْبَةَ قَالَتْ حَدَّثَتْنَا عَائِشَةُ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَلاَ أَدْخُلُ الْبَيْتَ قَالَ ‏ "‏ ادْخُلِي الْحِجْرَ فَإِنَّهُ مِنَ الْبَيْتِ ‏"‏ ‏.‏\hadithno{2911}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aisha said:"I said: 'O Messenger of Allah! Can I not enter the House?' He said: 'Enter the Hijr for it is part of the House}}
\hadithdefcmd{nasai}{2912}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَلْقَمَةُ بْنُ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُحِبُّ أَنْ أَدْخُلَ، الْبَيْتَ فَأُصَلِّيَ فِيهِ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِي فَأَدْخَلَنِي الْحِجْرَ فَقَالَ ‏ "‏ إِذَا أَرَدْتِ دُخُولَ الْبَيْتِ فَصَلِّي هَا هُنَا فَإِنَّمَا هُوَ قِطْعَةٌ مِنَ الْبَيْتِ وَلَكِنَّ قَوْمَكِ اقْتَصَرُوا حَيْثُ بَنَوْهُ ‏"‏ ‏.‏\hadithno{2912}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Aishah said:"I wanted to enter the House and pray therein, so the Messenger of Allah took me by the hand and took me into the Hijr and said: 'If you want to enter the House, then pray here, for it is part of the House, but your people made it too small when they built it.'" (Sahih) Chatper 130. Reciting The Takbir In the Corners Of the Kabah}}
\hadithdefcmd{nasai}{2913}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، أَنَّ ابْنَ عَبَّاسٍ، قَالَ لَمْ يُصَلِّ النَّبِيُّ صلى الله عليه وسلم فِي الْكَعْبَةِ وَلَكِنَّهُ كَبَّرَ فِي نَوَاحِيهِ ‏.‏\hadithno{2913}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Abbas said:"The Prophet did not pray inside the Kabah, but he recited the Takbir in its corners." (Sahih) Chatper 131. Dhikr And Supplication Inside The House}}
\hadithdefcmd{nasai}{2914}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، قَالَ حَدَّثَنَا عَطَاءٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ دَخَلَ هُوَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْتَ فَأَمَرَ بِلاَلاً فَأَجَافَ الْبَابَ - وَالْبَيْتُ إِذْ ذَاكَ عَلَى سِتَّةِ أَعْمِدَةٍ - فَمَضَى حَتَّى إِذَا كَانَ بَيْنَ الأُسْطُوَانَتَيْنِ اللَّتَيْنِ تَلِيَانِ بَابَ الْكَعْبَةِ جَلَسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَسَأَلَهُ وَاسْتَغْفَرَهُ ثُمَّ قَامَ حَتَّى أَتَى مَا اسْتَقْبَلَ مِنْ دُبُرِ الْكَعْبَةِ فَوَضَعَ وَجْهَهُ وَخَدَّهُ عَلَيْهِ وَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَسَأَلَهُ وَاسْتَغْفَرَهُ ثُمَّ انْصَرَفَ إِلَى كُلِّ رُكْنٍ مِنْ أَرْكَانِ الْكَعْبَةِ فَاسْتَقْبَلَهُ بِالتَّكْبِيرِ وَالتَّهْلِيلِ وَالتَّسْبِيحِ وَالثَّنَاءِ عَلَى اللَّهِ وَالْمَسْأَلَةِ وَالاِسْتَغْفَارِ ثُمَّ خَرَجَ فَصَلَّى رَكْعَتَيْنِ مُسْتَقْبِلَ وَجْهِ الْكَعْبَةِ ثُمَّ انْصَرَفَ فَقَالَ ‏ "‏ هَذِهِ الْقِبْلَةُ هَذِهِ الْقِبْلَةُ ‏"‏ ‏.‏\hadithno{2914}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Usmah bin Zaid that:he and the Messenger of Allah entered the House, and he told Bilal to shut the door. At that time the House was built on six pillars. He waled forward until, when he was between the two columns that are on the either side of the door of the Kabah, he sat down, praised Allah, asked of him, and prayed for forgiveness. Then he god up, and went to the back wall of the Kabah, placed his face and cheek against it and praised Allah, asked of Him, and prayed for forgiveness. Then he went to each corner of the Kabah and fced it, reciting the Takbir, the Tahlil and Tasbih, praising Allah, asking of Him and praying for forgiveness. Then he came out and prayed two Rakahs facing the front of the Kabah, then he moved away and said: "This is the Qiblah, this is the Qiblah}}
\hadithdefcmd{nasai}{2915}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ دَخَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْبَيْتَ فَجَلَسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَكَبَّرَ وَهَلَّلَ ثُمَّ مَالَ إِلَى مَا بَيْنَ يَدَيْهِ مِنَ الْبَيْتِ فَوَضَعَ صَدْرَهُ عَلَيْهِ وَخَدَّهُ وَيَدَيْهِ ثُمَّ كَبَّرَ وَهَلَّلَ وَدَعَا فَعَلَ ذَلِكَ بِالأَرْكَانِ كُلِّهَا ثُمَّ خَرَجَ فَأَقْبَلَ عَلَى الْقِبْلَةِ وَهُوَ عَلَى الْبَابِ فَقَالَ ‏ "‏ هَذِهِ الْقِبْلَةُ هَذِهِ الْقِبْلَةُ ‏"‏ ‏.‏\hadithno{2915}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated the Usmah bin Zaid said:"I entered the House with the Messenger of Allah. He sat and praised Allah, and recited the Takbir, and the Tahlil. Then he went to the wall of the House that was in front of him, and placed his chest, cheek and hands on it, then he recited the Takbir, and the Tahlil, and supplicated. And he did that in all the corners, then he came out, and turned to face the Qiblah while he was in front of the door, and he said: 'This is the Qiblah, this is the Qiblah}}
\hadithdefcmd{nasai}{2916}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ أُسَامَةَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْبَيْتِ صَلَّى رَكْعَتَيْنِ فِي قُبُلِ الْكَعْبَةِ ثُمَّ قَالَ ‏ "‏ هَذِهِ الْقِبْلَةُ ‏"‏ ‏.‏\hadithno{2916}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Usmah said:"The Messenger of Allah came out of the House and prayed two Rakahs in front of the Kabah, then he said: 'This is the Qiblah}}
\hadithdefcmd{nasai}{2917}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ النَّسَائِيُّ قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ الْبَيْتَ فَدَعَا فِي نَوَاحِيهِ كُلِّهَا وَلَمْ يُصَلِّ فِيهِ حَتَّى خَرَجَ مِنْهُ فَلَمَّا خَرَجَ رَكَعَ رَكْعَتَيْنِ فِي قُبُلِ الْكَعْبَةِ ‏.‏\hadithno{2917}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ata said:"I head Ibn Abbas sya: 'Usmah bin Zaid told me that the Prophet entered the YHouse, and supplicated in all its corner, but he did not pray inside unitl he came out; when he came out he prayed two Rakahs in front of the Kabah}}
\hadithdefcmd{nasai}{2918}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا السَّائِبُ بْنُ عُمَرَ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُودُ ابْنَ عَبَّاسٍ وَيُقِيمُهُ عِنْدَ الشُّقَّةِ الثَّالِثَةِ مِمَّا يَلِي الرُّكْنَ الَّذِي يَلِي الْحَجَرَ مِمَّا يَلِي الْبَابَ فَقَالَ ابْنُ عَبَّاسٍ أَمَا أُنْبِئْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي هَا هُنَا فَيَقُولُ نَعَمْ فَيَتَقَدَّمُ فَيُصَلِّي ‏.‏\hadithno{2918}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muhammad bin Abdullah bin As-Saib narrated from his father that:he used to lead Ib Abbas and make him stand at the third side (of the Kabah next to the corner that is next to the stone, in between the stone and the door. Ibn Abbas said: "Have you head that the Messenger of Allah used to pray here?" He said: "Yes." So he went forward and prayed. (Daif) Chaper 134. The Virtue Of Circumambulationg The House, Which Is From The Book Al-Mujtaba About Hajj}}
\hadithdefcmd{nasai}{2919}{حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ، أَحْمَدُ بْنُ شُعَيْبٍ مِنْ لَفْظِهِ قَالَ أَنْبَأَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، أَنَّ رَجُلاً، قَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ مَا أَرَاكَ تَسْتَلِمُ إِلاَّ هَذَيْنِ الرُّكْنَيْنِ قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ مَسْحَهُمَا يَحُطَّانِ الْخَطِيئَةَ ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ مَنْ طَافَ سَبْعًا فَهُوَ كَعِدْلِ رَقَبَةٍ ‏"‏ ‏.‏\hadithno{2919}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abdullah bin Ubaid bin Umair that a man said:"O Abu abdur-Rahman, why do I only see you touching these two corners?" He said: "I heard the Messenger of Allah say: 'Touching them erases sins.' And I head him say: 'whoever circumambulates seven times, it is like freeing a slave}}
\hadithdefcmd{nasai}{2920}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي سُلَيْمَانُ الأَحْوَلُ، أَنَّ طَاوُسًا، أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ وَهُوَ يَطُوفُ بِالْكَعْبَةِ بِإِنْسَانٍ يَقُودُهُ إِنْسَانٌ بِخِزَامَةٍ فِي أَنْفِهِ فَقَطَعَهُ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ ثُمَّ أَمَرَهُ أَنْ يَقُودَهُ بِيَدِهِ ‏.‏\hadithno{2920}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn Abbas:That the Prophet passed by while he was circumambulating the Kabah with a man who was leading another with a ring in his nose. The Messenger of Allah stopped him with his hand then told him to lead him by his hand}}
\hadithdefcmd{nasai}{2921}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنِي سُلَيْمَانُ الأَحْوَلُ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَجُلٍ يَقُودُهُ رَجُلٌ بِشَىْءٍ ذَكَرَهُ فِي نَذْرٍ فَتَنَاوَلَهُ النَّبِيُّ صلى الله عليه وسلم فَقَطَعَهُ قَالَ إِنَّهُ نَذْرٌ ‏.‏\hadithno{2921}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allab passed by a man who was leading another man with something that he had stipulated in a vow. The Prophet took it and broke it, and he said: 'It is a vow.'" (Sahih) Chatper 136. It Is Permissible To Speak During Tawaf}}
\hadithdefcmd{nasai}{2922}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، ح وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، أَخْبَرَنِي ابْنُ جُرَيْجٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنْ رَجُلٍ، أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الطَّوَافُ بِالْبَيْتِ صَلاَةٌ فَأَقِلُّوا مِنَ الْكَلاَمِ ‏"‏ ‏.‏ اللَّفْظُ لِيُوسُفَ ‏.‏ خَالَفَهُ حَنْظَلَةُ بْنُ أَبِي سُفْيَانَ ‏.‏\hadithno{2922}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Tawus from a man who met the Prophet, that he said:"Tawaf of the House is a form of Salah, so speak little." (Sahih Mawquf) This is the wording of Yu8saf, which was contradicted by Hanzalah bin Abi sufyan:}}
\hadithdefcmd{nasai}{2923}{أَخْبَرَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، قَالَ أَنْبَأَنَا السِّينَانِيُّ، عَنْ حَنْظَلَةَ بْنِ أَبِي سُفْيَانَ، عَنْ طَاوُسٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ أَقِلُّوا الْكَلاَمَ فِي الطَّوَافِ فَإِنَّمَا أَنْتُمْ فِي الصَّلاَةِ ‏.‏\hadithno{2923}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Umar said:"Speak little when you are perfoming Tawaf for you are in a state of Salah". (Sahih Mawquf)}}
\hadithdefcmd{nasai}{2924}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَاهْ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَا بَنِي عَبْدِ مَنَافٍ لاَ تَمْنَعُنَّ أَحَدًا طَافَ بِهَذَا الْبَيْتِ وَصَلَّى أَىَّ سَاعَةٍ شَاءَ مِنْ لَيْلٍ أَوْ نَهَارٍ ‏"‏ ‏.‏\hadithno{2924}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jubair bin Mutim that the Prophet said:"O Banu Abd Manaf, do not prevent anyone from circumambulating this House of praying at any time of the night or day he wishes}}
\hadithdefcmd{nasai}{2925}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ شَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم إِنِّي أَشْتَكِي فَقَالَ ‏"‏ طُوفِي مِنْ وَرَاءِ النَّاسِ وَأَنْتِ رَاكِبَةٌ ‏"‏ ‏.‏ فَطُفْتُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي إِلَى جَنْبِ الْبَيْتِ يَقْرَأُ بِـ ‏\{‏ الطُّورِ * وَكِتَابٍ مَسْطُورٍ ‏\}‏ ‏.‏\hadithno{2925}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Zainab bint Abi Salamah that Umm Salamah said:"I complained to the Messenger of Allah that I was sick, and he said: 'Perform Tawaf behind the people while you are riding.' So I performed Tawaf while the Messenger of Allah was praying beside the House, and reciting: 'The Tur (Mount), and by the Book Inscribed}}
\hadithdefcmd{nasai}{2926}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ يا رَسُولَ اللَّهِ وَاللَّهِ مَا طُفْتُ طَوَافَ الْخُرُوجِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَطُوفِي عَلَى بَعِيرِكِ مِنْ وَرَاءِ النَّاسِ ‏"‏ ‏.‏ عُرْوَةُ لَمْ يَسْمَعْهُ مِنْ أُمِّ سَلَمَةَ ‏.‏\hadithno{2926}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from HIsham bin Urwah, from his father, from Umm Salamah, that she said:"O Messenger of Allah, by Allah! I have not performed the Farewell Tawaf." The Prophet said: "When the Iqamah is said for prayer, perform Tawaf on your camel behind the people." Urwah did not hear from Umm Salamah}}
\hadithdefcmd{nasai}{2927}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّهَا قَدِمَتْ مَكَّةَ وَهِيَ مَرِيضَةٌ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ طُوفِي مِنْ وَرَاءِ الْمُصَلِّينَ وَأَنْتِ رَاكِبَةٌ ‏"‏ ‏.‏ قَالَتْ فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ عِنْدَ الْكَعْبَةِ يَقْرَأُ ‏\{‏ وَالطُّورِ ‏\}‏ ‏.‏\hadithno{2927}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Urwah from Zainab bint Umm Salamab, from Umm Salamah, that:she came to Makkah when she was sick. She mentioned that to the Messenger of Allah and he said: "Perform Tawaf behind those who are praying while you are riding." She said: "And I heard the Messenger of Allah, at the Kabah, reciting 'By the Tur (Mount)}}
\hadithdefcmd{nasai}{2928}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا شُعَيْبٌ، - وَهُوَ ابْنُ إِسْحَاقَ - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ طَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ حَوْلَ الْكَعْبَةِ عَلَى بَعِيرٍ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنِهِ ‏.‏\hadithno{2928}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aishah said:"The Messenger of Allah performed Tawaf around the Kabah during the farewell pilgrimeage on a camel, touching the Corner with his crooked-ended stick." (Sahih) Chpater 141. Tawaf For The One Who Is Performing Hajj Al-Ifrad}}
\hadithdefcmd{nasai}{2929}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُوَيْدٌ، - وَهُوَ ابْنُ عَمْرٍو الْكَلْبِيُّ - عَنْ زُهَيْرٍ، قَالَ حَدَّثَنَا بَيَانٌ، أَنَّ وَبَرَةَ، حَدَّثَهُ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، وَسَأَلَهُ، رَجُلٌ أَطُوفُ بِالْبَيْتِ وَقَدْ أَحْرَمْتُ بِالْحَجِّ قَالَ وَمَا يَمْنَعُكَ قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ يَنْهَى عَنْ ذَلِكَ وَأَنْتَ أَعْجَبُ إِلَيْنَا مِنْهُ ‏.‏ قَالَ رَأَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم أَحْرَمَ بِالْحَجِّ فَطَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏\hadithno{2929}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Wabarah said:"I heard Abdullah bin Umar say, when a man asked him wether he could perform Tawaf around the House when he had entered Ihram for Hajj: 'What is stopping you?' He said: 'I saw Abdullah bin Abbas forbidding that, but you are telling us something different.' He said: 'We saw the Messenger of Allah enter Ihram for Hajj, then circumambulate the House then perform between As-Safa and Al-Marwah}}
\hadithdefcmd{nasai}{2930}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ ابْنَ عُمَرَ، وَسَأَلْنَاهُ، عَنْ رَجُلٍ، قَدِمَ مُعْتَمِرًا فَطَافَ بِالْبَيْتِ وَلَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ أَيَأْتِي أَهْلَهُ قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَافَ سَبْعًا وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ وَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ ‏.‏\hadithno{2930}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Amr said:"I head Ibn Umar say - When we asked him about a man who came for Umrah, and perfomed Tawaf around the House, but did not perform Sai betwwen As-Safa and al-Marwah, could he be intimate with his wife? He said: 'When the Messenger of Allah came, he circumambulated seven times, and prayed two Rakahs behind the Maqam, and performed Sai between As-Safa and Al-Marwah. And you have the best examples in the Messenger of Allah.'" (Sahih) Chpater 143. What Should A Person Do If He Enters Ihram For Hajj and Umrah But he Has Not Brought A Hadi}}
\hadithdefcmd{nasai}{2931}{أَخْبَرَنَا أَحْمَدُ بْنُ الأَزْهَرِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَنَسٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَخَرَجْنَا مَعَهُ فَلَمَّا بَلَغَ ذَا الْحُلَيْفَةِ صَلَّى الظُّهْرَ ثُمَّ رَكِبَ رَاحِلَتَهُ فَلَمَّا اسْتَوَتْ بِهِ عَلَى الْبَيْدَاءِ أَهَلَّ بِالْحَجِّ وَالْعُمْرَةِ جَمِيعًا فَأَهْلَلْنَا مَعَهُ فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ وَطُفْنَا أَمَرَ النَّاسَ أَنْ يَحِلُّوا فَهَابَ الْقَوْمُ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ أَنَّ مَعِي الْهَدْىَ لأَحْلَلْتُ ‏"‏ ‏.‏ فَحَلَّ الْقَوْمُ حَتَّى حَلُّوا إِلَى النِّسَاءِ وَلَمْ يَحِلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَمْ يُقَصِّرْ إِلَى يَوْمِ النَّحْرِ ‏.‏\hadithno{2931}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah set out and we set out with him. When he reached Dhul-Hulaifah he prayed Zuhr, then he rode his mount, and when it stood up with him at Al-Baida, he initiated Ihram for Hajj and Umrah together, and we initiated Ihram with him. When the Messenger of Allah came to Makkah and we had performed Tawaf, he told the people to exit Ihram but they hesitated. The Messenger of Allah said to them: 'Were it not for the fact that I have the Hadi with me, I would have exited Ihra.' So the people exited Ihram completely, such that intimacy with their wives became permissible. But the Messenger of Allahd did not exit Ihram, and he did not cut his hair until the Day of Sacrifice}}
\hadithdefcmd{nasai}{2932}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَرَنَ الْحَجَّ وَالْعُمْرَةَ فَطَافَ طَوَافًا وَاحِدًا وَقَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ ‏.‏\hadithno{2932}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Umar joined Hajj and Umrah (Qiran) and he performd on Tawaf and said:"This is what I saw the Messenger of Allah doing}}
\hadithdefcmd{nasai}{2933}{أَخْبَرَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، وَأَيُّوبَ بْنِ مُوسَى، وَإِسْمَاعِيلَ بْنِ أُمَيَّةَ، وَعُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، قَالَ خَرَجَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَلَمَّا أَتَى ذَا الْحُلَيْفَةِ أَهَلَّ بِالْعُمْرَةِ فَسَارَ قَلِيلاً فَخَشِيَ أَنْ يُصَدَّ عَنِ الْبَيْتِ فَقَالَ إِنْ صُدِدْتُ صَنَعْتُ كَمَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ وَاللَّهِ مَا سَبِيلُ الْحَجِّ إِلاَّ سَبِيلُ الْعُمْرَةِ أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ مَعَ عُمْرَتِي حَجًّا ‏.‏ فَسَارَ حَتَّى أَتَى قُدَيْدًا فَاشْتَرَى مِنْهَا هَدْيًا ثُمَّ قَدِمَ مَكَّةَ فَطَافَ بِالْبَيْتِ سَبْعًا وَبَيْنَ الصَّفَا وَالْمَرْوَةِ وَقَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ ‏.‏\hadithno{2933}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Nafi said:"Abdullah bin Umar went out and he came to Dhul-Hulaifah he entered Ihram for Umrah. Then he traveled a short distance. Then he was afraid that he might be prevented from reaching the House. He said: 'If I am prevented I will do what the Messenger of Allah did.' He said: 'By Allah, Hajj is jut like Umrah; I ask you to bear witness that I have resolved to do Hajj with my Umrah.' He traveled on until he reached Qudaid, where he bought a Hadi. Then he came to Makkah, and circumambulated the House seven times, and performed Sai between As-Safa and Al-Marwah and said: 'This is what I saw the Messenger of Allah doing}}
\hadithdefcmd{nasai}{2934}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ، أَخْبَرَنِي هَانِئُ بْنُ أَيُّوبَ، عَنْ طَاوُسٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم طَافَ طَوَافًا وَاحِدًا ‏.‏\hadithno{2934}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir bin Abdullah that:the Prophet performed one Tawaf}}
\hadithdefcmd{nasai}{2935}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا مُوسَى بْنُ دَاوُدَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحَجَرُ الأَسْوَدُ مِنَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{2935}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Abbas that the Prophet said:"The Black Stone is from Paradise}}
\hadithdefcmd{nasai}{2936}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الأَعْلَى، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، أَنَّ عُمَرَ، قَبَّلَ الْحَجَرَ وَالْتَزَمَهُ وَقَالَ رَأَيْتُ أَبَا الْقَاسِمِ صلى الله عليه وسلم بِكَ حَفِيًّا ‏.‏\hadithno{2936}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Suwaid bin Ghafalah that Umar kissed the Black Stone and touched it, and said:"I saw Abdu Al-Qasim paying attention to you}}
\hadithdefcmd{nasai}{2937}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، وَجَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَابِسِ بْنِ رَبِيعَةَ، قَالَ رَأَيْتُ عُمَرَ جَاءَ إِلَى الْحَجَرِ فَقَالَ إِنِّي لأَعْلَمُ أَنَّكَ حَجَرٌ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُبِّلُكَ مَا قَبَّلْتُكَ ‏.‏ ثُمَّ دَنَا مِنْهُ فَقَبَّلَهُ ‏.‏\hadithno{2937}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated Abbas bin Rabiah said:"I saw Umar coming to the Stone and saying: 'I know that you are just a stone; had I not seen the Messenger of Allah kiss you I would not have kissed you.' Then he came close to it and kissed it." (Sahih) Chpater 148. How to Kiss It}}
\hadithdefcmd{nasai}{2938}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنْ حَنْظَلَةَ، قَالَ رَأَيْتُ طَاوُسًا يَمُرُّ بِالرُّكْنِ فَإِنْ وَجَدَ عَلَيْهِ زِحَامًا مَرَّ وَلَمْ يُزَاحِمْ وَإِنْ رَآهُ خَالِيًا قَبَّلَهُ ثَلاَثًا ثُمَّ قَالَ رَأَيْتُ ابْنَ عَبَّاسٍ فَعَلَ مِثْلَ ذَلِكَ وَقَالَ ابْنُ عَبَّاسٍ رَأَيْتُ عُمَرَ بْنَ الْخَطَّابِ فَعَلَ مِثْلَ ذَلِكَ ثُمَّ قَالَ إِنَّكَ حَجَرٌ لاَ تَنْفَعُ وَلاَ تَضُرُّ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَبَّلَكَ مَا قَبَّلْتُكَ ثُمَّ قَالَ عُمَرُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ مِثْلَ ذَلِكَ ‏.‏\hadithno{2938}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Hanzalah said:"I saw tawus pass by the Corner. If he saw it crowded, he would pass by and he would not push his way in. And if he way it was free, he would kiss it three times, then he said: 'I saw Ibn Abbas doing that. Ibn Abbas said: 'I saw Umar bin Al-Khattab doing that, then he said: You are just a stone that can neither cause harm or bring benefit; were it not that I saw the Messenger ofAllah kissing you I would not have kissed you.' Then Umar said:b 'I saw the Messenger of Allah doing that}}
\hadithdefcmd{nasai}{2939}{أَخْبَرَنِي عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ دَخَلَ الْمَسْجِدَ فَاسْتَلَمَ الْحَجَرَ ثُمَّ مَضَى عَلَى يَمِينِهِ فَرَمَلَ ثَلاَثًا وَمَشَى أَرْبَعًا ثُمَّ أَتَى الْمَقَامَ فَقَالَ ‏"‏ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏\}‏ ‏"‏ ‏.‏ فَصَلَّى رَكْعَتَيْنِ وَالْمَقَامُ بَيْنَهُ وَبَيْنَ الْبَيْتِ ثُمَّ أَتَى الْبَيْتَ بَعْدَ الرَّكْعَتَيْنِ فَاسْتَلَمَ الْحَجَرَ ثُمَّ خَرَجَ إِلَى الصَّفَا ‏.‏\hadithno{2939}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"When the Messenger of Allah came to Makkah he entered the Masjid and touched the Stone, then he moved to his right and walked rapidly for three (rounds) and then walked (at a regular pace) for four. Then he came to the Maqam and said: 'And take you (people) the Maqam (place) of Ibrahim as a place of prayer and prayed two Rakahs with the Maqam between him and the House. Then he came to the Hosue after praying those two Rakahs and touched the Stone, then he went out to As-Safa." (Sahih) Chpater 150. In How Many Rounds Should Be Quick?}}
\hadithdefcmd{nasai}{2940}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَرْمُلُ الثَّلاَثَ وَيَمْشِي الأَرْبَعَ وَيَزْعُمُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{2940}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Nafi that:Abdulla bin Umar used to walk rapidly for three (rounds), and walk for four, and he said that the Messenger of Allah used to do that}}
\hadithdefcmd{nasai}{2941}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَعْقُوبُ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا طَافَ فِي الْحَجِّ وَالْعُمْرَةِ أَوَّلَ مَا يَقْدَمُ فَإِنَّهُ يَسْعَى ثَلاَثَةَ أَطْوَافٍ وَيَمْشِي أَرْبَعًا ثُمَّ يُصَلِّي سَجْدَتَيْنِ ثُمَّ يَطُوفُ بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏\hadithno{2941}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Umar, that:when the Messenger of Allah performed Tawaf in Hajj and Umarah- as he first arrived (in Makkah), he would hasten in three rounds, and walk (at a regular pace) in four. Then he prayed two Rakahs, then he performed sai between As-Safa and Al-Marwah}}
\hadithdefcmd{nasai}{2942}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرٍو، وَسُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ يَقْدَمُ مَكَّةَ يَسْتَلِمُ الرُّكْنَ الأَسْوَدَ أَوَّلَ مَا يَطُوفُ يَخُبُّ ثَلاَثَةَ أَطْوَافٍ مِنَ السَّبْعِ ‏.‏\hadithno{2942}\hadithgrade{Abu Ghuddah: -; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that his father said:"When the Messenger of Allah came to Makkah, he touched the Black Stone and at the beginning of his Tawaf, he walked rapidly in (the first) three of the seven rounds}}
\hadithdefcmd{nasai}{2943}{أَخْبَرَنِي مُحَمَّدٌ، وَعَبْدُ الرَّحْمَنِ، ابْنَا عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ قَالاَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، عَنْ أَبِيهِ، عَنْ كَثِيرِ بْنِ فَرْقَدٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَخُبُّ فِي طَوَافِهِ حِينَ يَقْدَمُ فِي حَجٍّ أَوْ عُمْرَةٍ ثَلاَثًا وَيَمْشِي أَرْبَعًا قَالَ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَفْعَلُ ذَلِكَ ‏.‏\hadithno{2943}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Nafi' that:Abdullah bin Umar used to walk rapidly in three rounds of his Tawaf when he came for Hajj or Umrah, and walk (at a normal pace) in four. He said: "The Messenger of Allah used to do that}}
\hadithdefcmd{nasai}{2944}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَلَ مِنَ الْحَجَرِ إِلَى الْحَجَرِ حَتَّى انْتَهَى إِلَيْهِ ثَلاَثَةَ أَطْوَافٍ ‏.‏\hadithno{2944}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Abdullah said:"I saw the Messenger of Allah walking rapidly from the Stone to the Stone, until he had finished three circuits}}
\hadithdefcmd{nasai}{2945}{أَخْبَرَنِي مُحَمَّدُ بْنُ سُلَيْمَانَ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ أَيُّوبَ، عَنِ ابْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ مَكَّةَ قَالَ الْمُشْرِكُونَ وَهَنَتْهُمْ حُمَّى يَثْرِبَ وَلَقَوْا مِنْهَا شَرًّا فَأَطْلَعَ اللَّهُ نَبِيَّهُ عَلَيْهِ الصَّلاَةُ وَالسَّلاَمُ عَلَى ذَلِكَ فَأَمَرَ أَصْحَابَهُ أَنْ يَرْمُلُوا وَأَنْ يَمْشُوا مَا بَيْنَ الرُّكْنَيْنِ وَكَانَ الْمُشْرِكُونَ مِنَ نَاحِيَةِ الْحِجْرِ فَقَالُوا لَهَؤُلاَءِ أَجْلَدُ مِنْ كَذَا ‏.‏\hadithno{2945}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:"When the Prophet and his Companions came to Makkah, the idolaters said: 'The fever of Yathrib has weakened them, and they have suffered a great deal because of it.' Allah informed His Prophet about that, so he told his Companions to walk rapidly, and to walk (at a normal pace) between the two corners, and the idolaters were on the side of the Stone. They said: 'They are stronger than such and such}}
\hadithdefcmd{nasai}{2946}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنِ الزُّبَيْرِ بْنِ عَرَبِيٍّ، قَالَ سَأَلَ رَجُلٌ ابْنَ عُمَرَ عَنِ اسْتِلاَمِ الْحَجَرِ، فَقَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُهُ وَيُقَبِّلُهُ ‏.‏ فَقَالَ الرَّجُلُ أَرَأَيْتَ إِنْ زُحِمْتُ عَلَيْهِ أَوْ غُلِبْتُ عَلَيْهِ فَقَالَ ابْنُ عُمَرَ رضى الله عنهما اجْعَلْ أَرَأَيْتَ بِالْيَمَنِ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُهُ وَيُقَبِّلُهُ ‏.‏\hadithno{2946}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Az-Zubair bin Adiyy said:"A man asked Ibn Umar about touching the Black Stone and he said: 'I saw the Messenger of Allah touching it and kissing it.' The man said: 'What if it is too crowded and I am overwhelmed?' Ibn Umar, may Allah be pleased with him, said: 'Leave your "what if" in Yemen! I saw the Messenger of Allah touching it and kissing it}}
\hadithdefcmd{nasai}{2947}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَسْتَلِمُ الرُّكْنَ الْيَمَانِيَ وَالْحَجَرَ فِي كُلِّ طَوَافٍ ‏.‏\hadithno{2947}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Umar that:the Prophet used to touch the Yemeni Corner and the Stone in earch Tawaf}}
\hadithdefcmd{nasai}{2948}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَسْتَلِمُ إِلاَّ الْحَجَرَ وَالرُّكْنَ الْيَمَانِيَ ‏.‏\hadithno{2948}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Umar:The Prophet used to touch only the Stone and the Yemeni Corner. (Sahih) Chatper 157. Touching The Two Yemeni Corners}}
\hadithdefcmd{nasai}{2949}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ مِنَ الْبَيْتِ إِلاَّ الرُّكْنَيْنِ الْيَمَانِيَيْنِ ‏.‏\hadithno{2949}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that his father said:"I did not see the Messenger of Allah touching any part of the House except the two Yemeni Corners}}
\hadithdefcmd{nasai}{2950}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ أَنْبَأَنَا ابْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ، وَابْنِ، جُرَيْجٍ وَمَالِكٍ عَنِ الْمَقْبُرِيِّ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَأَيْتُكَ لاَ تَسْتَلِمُ مِنَ الأَرْكَانِ إِلاَّ هَذَيْنِ الرُّكْنَيْنِ الْيَمَانِيَيْنِ ‏.‏ قَالَ لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُ إِلاَّ هَذَيْنِ الرُّكْنَيْنِ مُخْتَصَرٌ ‏.‏\hadithno{2950}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ubaid bin Juraij said:"I said to Ibn Umar: 'I see that you only touch these two Yemeni corners.' He said: 'I only saw the Messenger of Allah touch these two corners.'" This is an abridgement of it}}
\hadithdefcmd{nasai}{2951}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرٍو، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُ مِنْ أَرْكَانِ الْبَيْتِ إِلاَّ الرُّكْنَ الأَسْوَدَ وَالَّذِي يَلِيهِ مِنْ نَحْوِ دُورِ الْجُمَحِيِّينَ ‏.‏\hadithno{2951}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim that his father said:"The Messenger of Allah did not touch any of the corner of the House except the Black Corner and the one that is next to it, in the direction of the houses of Al-Jumahiyyain}}
\hadithdefcmd{nasai}{2952}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، قَالَ قَالَ عَبْدُ اللَّهِ رَضِيَ اللَّهُ عَنْهُ مَا تَرَكْتُ اسْتِلاَمَ هَذَيْنِ الرُّكْنَيْنِ مُنْذُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُهُمَا الْيَمَانِيَ وَالْحَجَرَ فِي شِدَّةٍ وَلاَ رَخَاءٍ ‏.‏\hadithno{2952}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Nafi said:"Abdullah, may Allah be pleased with him, said: "I have not failed to touch these two corners since I saw the Messenger of Allah touching them, the Yemeni Corner and Black Stone, either when it is difficult or when it is easy}}
\hadithdefcmd{nasai}{2953}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَا تَرَكْتُ اسْتِلاَمَ الْحَجَرِ فِي رَخَاءٍ وَلاَ شِدَّةٍ مُنْذُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُهُ ‏.‏\hadithno{2953}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Umar said:"Since I saw the Messenger of Allah touch it, I did not fail to touching the Stone whether it was easy or difficult}}
\hadithdefcmd{nasai}{2954}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، وَسُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ فِي حَجَّةِ الْوَدَاعِ عَلَى بَعِيرٍ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ ‏.‏\hadithno{2954}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abdullah bin Abbas that:the Messenger of Allah circumambulated (the Kabah) during the Farewell Pilgrimage on a camel, touching the Corner with a crook-ended stick}}
\hadithdefcmd{nasai}{2955}{أَخْبَرَنَا بِشْرُ بْنُ هِلاَلٍ، قَالَ أَنْبَأَنَا عَبْدُ الْوَارِثِ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَطُوفُ بِالْبَيْتِ عَلَى رَاحِلَتِهِ فَإِذَا انْتَهَى إِلَى الرُّكْنِ أَشَارَ إِلَيْهِ ‏.‏\hadithno{2955}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abdullah bin Abbas that:the Messenger of Allah used to circumambulate the House on his mount, and when he reached the Corner be pointed to it." (Sahih) Chpater 161. They Saying Of Allah, The Mighty And Sublimse: "Take Your Adornment To Every Masjid}}
\hadithdefcmd{nasai}{2956}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، قَالَ سَمِعْتُ مُسْلِمًا الْبَطِينَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتِ الْمَرْأَةُ تَطُوفُ بِالْبَيْتِ وَهِيَ عُرْيَانَةٌ تَقُولُ الْيَوْمَ يَبْدُو بَعْضُهُ أَوْ كُلُّهُ وَمَا بَدَا مِنْهُ فَلاَ أُحِلُّهُ قَالَ فَنَزَلَتْ ‏\{‏ يَا بَنِي آدَمَ خُذُوا زِينَتَكُمْ عِنْدَ كُلِّ مَسْجِدٍ ‏\}‏ ‏.‏\hadithno{2956}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Saeed bin Jubair that Ibn Abbas said:"Women used to circumambulate the Kabah naked, saying: 'Today some, or all of it will appear And whatever appers I don't make is permissible.' Then the following was revealed: 'O Children of Adam! Take your adornment to every Masjid}}
\hadithdefcmd{nasai}{2957}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ أَخْبَرَهُ أَنَّ أَبَا بَكْرٍ بَعَثَهُ فِي الْحَجَّةِ الَّتِي أَمَّرَهُ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ حَجَّةِ الْوَدَاعِ فِي رَهْطٍ يُؤَذِّنُ فِي النَّاسِ ‏ "‏ أَلاَ لاَ يَحُجَّنَّ بَعْدَ الْعَامِ مُشْرِكٌ وَلاَ يَطُوفُ بِالْبَيْتِ عُرْيَانٌ ‏"‏ ‏.‏\hadithno{2957}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:Abu Bakr sent him, during the Hajj that the Messenger of Allah appointed him to lead before the Farewell Pilgrimage, with a group of other to announce to the people: "No idolater is to perform Hajj after this year, and no one is to circumambulate the House naked}}
\hadithdefcmd{nasai}{2958}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، وَعُثْمَانُ بْنُ عُمَرَ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ، عَنِ الشَّعْبِيِّ، عَنِ الْمُحَرَّرِ بْنِ أَبِي هُرَيْرَةَ، عَنْ أَبِيهِ، قَالَ جِئْتُ مَعَ عَلِيِّ بْنِ أَبِي طَالِبٍ حِينَ بَعَثَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أَهْلِ مَكَّةَ بِبَرَاءَةَ قَالَ ‏"‏ مَا كُنْتُمْ تُنَادُونَ ‏"‏ ‏.‏ قَالَ كُنَّا نُنَادِي ‏"‏ إِنَّهُ لاَ يَدْخُلُ الْجَنَّةَ إِلاَّ نَفْسٌ مُؤْمِنَةٌ وَلاَ يَطُوفُ بِالْبَيْتِ عُرْيَانٌ وَمَنْ كَانَ بَيْنَهُ وَبَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَهْدٌ فَأَجَلُهُ أَوْ أَمَدُهُ إِلَى أَرْبَعَةِ أَشْهُرٍ فَإِذَا مَضَتِ الأَرْبَعَةُ أَشْهُرٍ فَإِنَّ اللَّهَ بَرِيءٌ مِنَ الْمُشْرِكِينَ وَرَسُولُهُ وَلاَ يَحُجُّ بَعْدَ الْعَامِ مُشْرِكٌ ‏"‏ ‏.‏ فَكُنْتُ أُنَادِي حَتَّى صَحِلَ صَوْتِي ‏.‏\hadithno{2958}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muharrar bin Abi Hurairah that his father said:"I came with Ali bin Abi Talib when the Messenger of Allah sent him to the people of Makkah with news of the dissolution of treaty obligations." He said: "How did you announced that no one would enter Paradise but a believing soul, no one was to circumambulate the House naked: whoever had a treaty with the Messenger of Allah, then for its period, or, it extended to four months, and when four months had passed, and that Allah is free from (all) obligations to the idolaters and so is His Messenger. No idolater was to perform Hajj after this year. I kept on announcing it until my vice grew hoarse}}
\hadithdefcmd{nasai}{2959}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، عَنْ كَثِيرِ بْنِ كَثِيرٍ، عَنْ أَبِيهِ، عَنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم حِينَ فَرَغَ مِنْ سُبُعِهِ جَاءَ حَاشِيَةَ الْمَطَافِ فَصَلَّى رَكْعَتَيْنِ وَلَيْسَ بَيْنَهُ وَبَيْنَ الطَّوَّافِينَ أَحَدٌ ‏.‏\hadithno{2959}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Al-Muttalib bin Wadaah said:"I saw the Prophet when he had completed his seven (circuits of Tawaf); he came to the edge of the Mataf and prayed two Rakahs, with nothing in between him and people who were circumambulating." (Daif)}}
\hadithdefcmd{nasai}{2960}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ يَعْنِي ابْنَ عُمَرَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ وَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَقَالَ ‏\{‏ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ ‏\}‏ ‏.‏\hadithno{2960}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Amr - meaning, bin Umar - said:"The Messenger of Allah came and circumambulated the House seven times, then he prayed two Rakahs behind the Maqam and performed Sai between As-Safa and Al-Marwah, and he said: 'Indeed in the Messenger of Allah you have a good example to follow}}
\hadithdefcmd{nasai}{2961}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ طَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْبَيْتِ سَبْعًا رَمَلَ مِنْهَا ثَلاَثًا وَمَشَى أَرْبَعًا ثُمَّ قَامَ عِنْدَ الْمَقَامِ فَصَلَّى رَكْعَتَيْنِ ثُمَّ قَرَأَ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏\}‏ وَرَفَعَ صَوْتَهُ يُسْمِعُ النَّاسَ ثُمَّ انْصَرَفَ فَاسْتَلَمَ ثُمَّ ذَهَبَ فَقَالَ ‏"‏ نَبْدَأُ بِمَا بَدَأَ اللَّهُ ‏"‏ ‏.‏ فَبَدَأَ بِالصَّفَا فَرَقِيَ عَلَيْهَا حَتَّى بَدَا لَهُ الْبَيْتُ فَقَالَ ثَلاَثَ مَرَّاتٍ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ فَكَبَّرَ اللَّهَ وَحَمِدَهُ ثُمَّ دَعَا بِمَا قُدِّرَ لَهُ ثُمَّ نَزَلَ مَاشِيًا حَتَّى تَصَوَّبَتْ قَدَمَاهُ فِي بَطْنِ الْمَسِيلِ فَسَعَى حَتَّى صَعِدَتْ قَدَمَاهُ ثُمَّ مَشَى حَتَّى أَتَى الْمَرْوَةَ فَصَعِدَ فِيهَا ثُمَّ بَدَا لَهُ الْبَيْتُ فَقَالَ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ قَالَ ذَلِكَ ثَلاَثَ مَرَّاتٍ ثُمَّ ذَكَرَ اللَّهَ وَسَبَّحَهُ وَحَمِدَهُ ثُمَّ دَعَا عَلَيْهَا بِمَا شَاءَ اللَّهُ فَعَلَ هَذَا حَتَّى فَرَغَ مِنَ الطَّوَافِ ‏.‏\hadithno{2961}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Bajir said:"The Messenger of Allah circumambulated the House seven times, walking rapidly (Raml) in the three, and walking (at a regular pace) for four. Then he stood near the Maqam and prayed two Rakahs. Then he recited: 'And take you the Maqam (Place) of Ibrahim as a place of prayer, raising his voice, so that the people would hear. Then he went (to perform Sai) and said: 'We will start with that with which Allah started.' So he started with As-Safa, climbing up, until he could see the House, and he said three times: 'La ilaha illallah, Wahdahu la sharika lah, lahul-mulku wa lahul-hamdu, yuhyi wa yumitu, wa huwaala kulli shayin qadir (There is none worthy of worship except Allah alone with no partner or associate, His is the dominion and to Him be praise, He gives life and death, and He has power over all things).' Then exclaimed Allah's greatness, then he supplicated as much as was decreed for him. Then he came down walking until he reached level ground at the bottom of the valley. Then he hastened until the ground began to rise. Then he walked until he came to Al-Marwah and clime dup it, and when he could see the House he said: 'La ilaha illallah, Wahdahu la sharika lah, lahul-mulku wa lahul-hamdu, yuhyi wa yumitu, wa huwaala kulli shayin qadir (There is none worthy of worship except Allah alone with no partner or associate, His is the dominion and to Him be praise, He gives life and death, and He has power over all things).' He said that three times, then he remembered Allah and glorified and praised Him, then he supplicated there for as long as Allah willed. And he did that until he finished Sai}}
\hadithdefcmd{nasai}{2962}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ سَبْعًا رَمَلَ ثَلاَثًا وَمَشَى أَرْبَعًا ثُمَّ قَرَأَ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏\}‏ فَصَلَّى سَجْدَتَيْنِ وَجَعَلَ الْمَقَامَ بَيْنَهُ وَبَيْنَ الْكَعْبَةِ ثُمَّ اسْتَلَمَ الرُّكْنَ ثُمَّ خَرَجَ فَقَالَ ‏"‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَابْدَءُوا بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏\hadithno{2962}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that the Messenger of Allah performed Tawaf, walking rapidly (Raml) for three circuits, and walking at a normal pace for four. Then he recited:"And take you the Maqam (place) of Ibrahim as a place of prayer." And prayed two Rak`ahs with the Maqam between him and the Ka`bah. Then he touched the Corner, then he went out and said: 'As-Safa and Al-Marwah are two of the symbols of Allah. We will start with that with which Allah started}}
\hadithdefcmd{nasai}{2963}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، عَنِ الْوَلِيدِ، عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا انْتَهَى إِلَى مَقَامِ إِبْرَاهِيمَ قَرَأَ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏\}‏ فَصَلَّى رَكْعَتَيْنِ فَقَرَأَ فَاتِحَةَ الْكِتَابِ وَ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏\}‏ وَ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ ثُمَّ عَادَ إِلَى الرُّكْنِ فَاسْتَلَمَهُ ثُمَّ خَرَجَ إِلَى الصَّفَا ‏.‏\hadithno{2963}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir bin Abdullah that when the Messenger of Allah came to Maqam Ibrahim he recited:"And take you the Maqam (place) of Ihrahim as a place of prayer." Then he prayed two Rakahs reciting the Opening of the Book (Al-Fatihah) said: "Say: O you disbelievers" and "Say: He is Allah, (the) One." Then he went back to the Corner and touched it, then he went out to As-Safa}}
\hadithdefcmd{nasai}{2964}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا عَاصِمٌ، وَمُغِيرَةُ، ح وَأَنْبَأَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا عَاصِمٌ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شَرِبَ مِنْ مَاءِ زَمْزَمَ وَهُوَ قَائِمٌ ‏.‏\hadithno{2964}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Abbas that:the Messenger of Allah drank from the water of Zamzam while standing}}
\hadithdefcmd{nasai}{2965}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَقَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ زَمْزَمَ فَشَرِبَهُ وَهُوَ قَائِمٌ ‏.‏\hadithno{2965}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abbas said:"I gave the Messenger of Allah some Zamzam to drink and he drank it while standing}}
\hadithdefcmd{nasai}{2966}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ طَافَ بِالْبَيْتِ سَبْعًا ثُمَّ صَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ ثُمَّ خَرَجَ إِلَى الصَّفَا مِنَ الْبَابِ الَّذِي يُخْرَجُ مِنْهُ فَطَافَ بِالصَّفَا وَالْمَرْوَةِ ‏.‏ قَالَ شُعْبَةُ وَأَخْبَرَنِي أَيُّوبُ عَنْ عَمْرِو بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ أَنَّهُ قَالَ سُنَّةٌ ‏.‏\hadithno{2966}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar said:"When the Messenger of Allah arrived in Makkah he circumambulated the House seven times, then he prayed two Rakahs behind the Maqam. Then, he went out to As-Safa through the gate that is usually used to exit, and performed Sai between As-Safa and Al-Marwah." (One of the narrators Shubah said: Ayub informed me from Amr bin Dinar from Ibn Umar that he said: "A Sunnah)}}
\hadithdefcmd{nasai}{2967}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ قَرَأْتُ عَلَى عَائِشَةَ ‏\{‏ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا ‏\}‏ قُلْتُ مَا أُبَالِي أَنْ لاَ أَطُوفَ بَيْنَهُمَا ‏.‏ فَقَالَتْ بِئْسَمَا قُلْتَ إِنَّمَا كَانَ نَاسٌ مِنْ أَهْلِ الْجَاهِلِيَّةِ لاَ يَطُوفُونَ بَيْنَهُمَا فَلَمَّا كَانَ الإِسْلاَمُ وَنَزَلَ الْقُرْآنُ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ ‏\}‏ الآيَةَ فَطَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَطُفْنَا مَعَهُ فَكَانَتْ سُنَّةً ‏.‏\hadithno{2967}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Urwah said:"I recited to Aishah: 'So it is not a sin on him who performs Hajj or Umrah (Pilgrimage) of the House to Perform the going Tawaf) between them (as-Safa and Al-Marwah) "I said: 'I do not care if I do not go between tham?' She said: 'What a bad thing you have said!' People at the time of the Jahiliyyah used not to go between them, but when Islam came and the Quran was revealed: 'Verily, As-Safa and Al-Marwah are of the symols of Allah, the Messenger of Allah went between them, and we did that with him, and thus it became part of Hajj}}
\hadithdefcmd{nasai}{2968}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا أَبِي، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ قَوْلِ اللَّهِ، عَزَّ وَجَلَّ ‏\{‏ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا ‏\}‏ فَوَاللَّهِ مَا عَلَى أَحَدٍ جُنَاحٌ أَنْ لاَ يَطُوفَ بِالصَّفَا وَالْمَرْوَةِ ‏.‏ قَالَتْ عَائِشَةُ بِئْسَمَا قُلْتَ يَا ابْنَ أُخْتِي إِنَّ هَذِهِ الآيَةَ لَوْ كَانَتَ كَمَا أَوَّلْتَهَا كَانَتْ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا وَلَكِنَّهَا نَزَلَتْ فِي الأَنْصَارِ قَبْلَ أَنْ يُسْلِمُوا كَانُوا يُهِلُّونَ لِمَنَاةَ الطَّاغِيَةِ الَّتِي كَانُوا يَعْبُدُونَ عِنْدَ الْمُشَلَّلِ وَكَانَ مَنْ أَهَلَّ لَهَا يَتَحَرَّجُ أَنْ يَطُوفَ بِالصَّفَا وَالْمَرْوَةِ فَلَمَّا سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا ‏\}‏ ثُمَّ قَدْ سَنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم الطَّوَافَ بَيْنَهُمَا فَلَيْسَ لأَحَدٍ أَنْ يَتْرُكَ الطَّوَافَ بِهِمَا ‏.‏\hadithno{2968}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Urwah said:"I asked Aishah about the words of Allah, the Mighty and Sublime: 'So it sin not a sin on him who perform Hajj or Umrah (Pilgrimage) of the House (the Kabah at Makkah) to perform the going (Tawaf) between them (as-Safa and Al-Marwah) and (I said): 'By Allah, there is no sin on anyone if he does not go between As-Safa and Al-Marwa.' Aishah said: 'What a bad thing you said, O son of my brother! If this Ayah was as you have interpreted it, there would be no sin on a person if he did not go between them. But it was revealed concering the Ansar. Before they accepted Islam, they sued to enter Ihram for the false goddess Manat whom they used to worship at Al-Mushallal. Whoever enter Ihram for her would refrain from going between As-Safa and Al-Marwah. When they asked the Messenger of Allah about that, Allah, the Might and Sublime, revealed: 'Verily As-Safa and Al-Marwah (Two mountains in Makkah) are of the Symbols of Allah. So it is not a sin on him who performs Hajj or Urmrah (Pilgrimage) of the House (the Kabah at Makkah) to perform the going (Tawaf) between them (As-Safa and Al-Marwah). Then the Messenger of Allah enjoined going between them so no one has the right to refrain from going between them}}
\hadithdefcmd{nasai}{2969}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ خَرَجَ مِنَ الْمَسْجِدِ وَهُوَ يُرِيدُ الصَّفَا وَهُوَ يَقُولُ ‏ "‏ نَبْدَأُ بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏\hadithno{2969}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir said:"When he went tout the Masjid heading for As-Safa, I heard the Messenger of Allah say: We will start with that with which Allah started}}
\hadithdefcmd{nasai}{2970}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا جَابِرٌ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الصَّفَا وَقَالَ ‏"‏ نَبْدَأُ بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏"‏ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ ‏\}‏ ‏"‏ ‏.‏\hadithno{2970}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir said:"Messenger of Allah went out to As-Safa and said.We will start with that with which Allah started. Then he recited: 'Verifly, as-Safa and Al-Marwah (two Mountains in Makkah) are of the symbols of Allah.'" (Sahih) Chpater 169. Where To Stand On As-Safa}}
\hadithdefcmd{nasai}{2971}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا جَابِرٌ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَقِيَ عَلَى الصَّفَا حَتَّى إِذَا نَظَرَ إِلَى الْبَيْتِ كَبَّرَ ‏.‏\hadithno{2971}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jabir narrated that:the Messenger of Allah climed up As-Safa until he could see the House, then he said Takbir}}
\hadithdefcmd{nasai}{2972}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا وَقَفَ عَلَى الصَّفَا يُكَبِّرُ ثَلاَثًا وَيَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ يَصْنَعُ ذَلِكَ ثَلاَثَ مَرَّاتٍ وَيَدْعُو وَيَصْنَعُ عَلَى الْمَرْوَةِ مِثْلَ ذَلِكَ ‏.‏\hadithno{2972}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir that:when the Messenger of Allah stood on top of As-Safa, he recited the Takbir three times and said: "La ilaha illallah, Wahdahu la sharika lah, lahul-mulku wa lahul-hamdu, yuhyi wa yumitu, wa huwaala kulli shayin qadir (There is none worthy of worship except Allah alone with no partner or associate, His is the dominion and to Him be praise, He gives life and death, and He has power over all things)." He did three times, and supplicated, and did the same a top Al-Marwah}}
\hadithdefcmd{nasai}{2973}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ أَنْبَأَنَا شُعَيْبٌ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي جَعْفَرُ بْنُ مُحَمَّدٍ، أَنَّهُ سَمِعَ أَبَاهُ، يُحَدِّثُ أَنَّهُ سَمِعَ جَابِرًا، عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم ثُمَّ وَقَفَ النَّبِيُّ صلى الله عليه وسلم عَلَى الصَّفَا يُهَلِّلُ اللَّهَ عَزَّ وَجَلَّ وَيَدْعُو بَيْنَ ذَلِكَ ‏.‏\hadithno{2973}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jafar bin Muhammad narrated, that he heard his father narrate, that he heard Jabir, speak of the Pilgrimage of the Prophet:"The Prophet stood atop as-Safa proclaiming the Tahlil of Allah (saying Lal ilaha illallah) and supplicating in between that}}
\hadithdefcmd{nasai}{2974}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ، ‏\{‏ عَبْدِ ‏\}‏ الْحَكَمِ عَنْ شُعَيْبٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ طَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْبَيْتِ سَبْعًا رَمَلَ مِنْهَا ثَلاَثًا وَمَشَى أَرْبَعًا ثُمَّ قَامَ عِنْدَ الْمَقَامِ فَصَلَّى رَكْعَتَيْنِ وَقَرَأَ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏\}‏ وَرَفَعَ صَوْتَهُ يُسْمِعُ النَّاسَ ثُمَّ انْصَرَفَ فَاسْتَلَمَ ثُمَّ ذَهَبَ فَقَالَ ‏"‏ نَبْدَأُ بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏ فَبَدَأَ بِالصَّفَا فَرَقِيَ عَلَيْهَا حَتَّى بَدَا لَهُ الْبَيْتُ وَقَالَ ثَلاَثَ مَرَّاتٍ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ وَكَبَّرَ اللَّهَ وَحَمِدَهُ ثُمَّ دَعَا بِمَا قُدِّرَ لَهُ ثُمَّ نَزَلَ مَاشِيًا حَتَّى تَصَوَّبَتْ قَدَمَاهُ فِي بَطْنِ الْمَسِيلِ فَسَعَى حَتَّى صَعِدَتْ قَدَمَاهُ ثُمَّ مَشَى حَتَّى أَتَى الْمَرْوَةَ فَصَعِدَ فِيهَا ثُمَّ بَدَا لَهُ الْبَيْتُ فَقَالَ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ قَالَ ذَلِكَ ثَلاَثَ مَرَّاتٍ ثُمَّ ذَكَرَ اللَّهَ وَسَبَّحَهُ وَحَمِدَهُ ثُمَّ دَعَا عَلَيْهَا بِمَا شَاءَ اللَّهُ فَعَلَ هَذَا حَتَّى فَرَغَ مِنَ الطَّوَافِ ‏.‏\hadithno{2974}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah circumambulated the House seven times, walking rapidly in three circuits and walking (at a normal pace)b in three. Then he stood at the Maqam (place) of Ibrahim as a place of prayer, raising his voice so that the people could hear. Then he went and touched the Black Stone and went (to perform Sai) and said: 'We will start with that with which Allah started.' So he started with As-Safa, climbing up until he could see the House and he said three times: ''La ilaha illallah, Wahdahu la sharika lah, lahul-mulku wa lahul-hamdu, yuhyi wa yumitu, wa huwaala kulli shayin qadir (There is none worthy of worship except Allah alone with no partner or associate, His is the dominion and to Him be praise, He gives life and death, and He has power over all things).' Then exclaimed Allah's greatness and praised Him, then he supplicated as much as was decreed for him. Then he came down walking, until he reached level ground at the bottom of the valley. Then he hastened until the ground began to rise. Then he walked until he came to Al-Marwah and climbed up it, and when he could see the house he said: 'La ilaha illallah, Wahdahu la sharika lah, lahul-mulku wa lahul-hamdu, yuhyi wa yumitu, wa huwaala kulli shayin qadir (There is none worthy of worship except Allah alone with no partner or associate, His is the dominion and to Him be praise, He gives life and death, and He has power over all things).' He said that three times, then he remembered Allah, and glorified and praised Him, then he supplicated there for as long as Allah willed. And he did that until he had finished Sai}}
\hadithdefcmd{nasai}{2975}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ، قَالَ أَنْبَأَنَا شُعَيْبٌ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ طَافَ النَّبِيُّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ عَلَى رَاحِلَتِهِ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ لِيَرَاهُ النَّاسُ وَلِيُشْرِفَ وَلِيَسْأَلُوهُ إِنَّ النَّاسَ غَشُوهُ ‏.‏\hadithno{2975}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Az-Zubair narrated that he heard Jabir bin Abdullah say:During the Farewell Pilgrimage the Prophet circumambulated the House and went between As-Safa and Al-Marwah on his mount so that the people could see him and he could see them, and they could ask him questions, and the people crowded around him}}
\hadithdefcmd{nasai}{2976}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ كَثِيرِ بْنِ جُمْهَانَ، قَالَ رَأَيْتُ ابْنَ عُمَرَ يَمْشِي بَيْنَ الصَّفَا وَالْمَرْوَةِ فَقَالَ إِنْ أَمْشِي فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْشِي وَإِنْ أَسْعَى فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْعَى ‏.‏\hadithno{2976}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Kathir bin Jumhan said:"I saw Ibn Umar walking between As-Safa and Al-Marwah. He said: 'I am walking because I saw the Messenger of Allah Walking, and I hasten because I saw the Messenger of Allah hasten}}
\hadithdefcmd{nasai}{2977}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا الثَّوْرِيُّ، عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ رَأَيْتُ ابْنَ عُمَرَ وَذَكَرَ نَحْوَهُ إِلاَّ أَنَّهُ قَالَ وَأَنَا شَيْخٌ، كَبِيرٌ ‏.‏\hadithno{2977}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Saeed bin Jubair said:"I saw Ibn Umar and he mentioned something similar, except he said: "and I am an old man}}
\hadithdefcmd{nasai}{2978}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا صَدَقَةُ بْنُ يَسَارٍ، عَنِ الزُّهْرِيِّ، قَالَ سَأَلُوا ابْنَ عُمَرَ هَلْ رَأَيْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَلَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَقَالَ كَانَ فِي جَمَاعَةٍ مِنَ النَّاسِ فَرَمَلُوا فَلاَ أُرَاهُمْ رَمَلُوا إِلاَّ بِرَمَلِهِ ‏.‏\hadithno{2978}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Az-Zubair said:"They asked Ibn Umar: 'Did you see the Messenger of Allah walk rapidly between As-Safa and Al-Marwah?' He said: 'He was among a group of people and they walked rapidly, and I think they went at the same pace as him.'" (Daif)}}
\hadithdefcmd{nasai}{2979}{أَخْبَرَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّمَا سَعَى النَّبِيُّ صلى الله عليه وسلم بَيْنَ الصَّفَا وَالْمَرْوَةِ لِيُرِيَ الْمُشْرِكِينَ قُوَّتَهُ ‏.‏\hadithno{2979}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:"The Prophet walked rapidly betwwne As-Safa and Al-Marwah to show the idolaters that he was strong}}
\hadithdefcmd{nasai}{2980}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ بُدَيْلٍ، عَنِ الْمُغِيرَةِ بْنِ حَكِيمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنِ امْرَأَةٍ، قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْعَى فِي بَطْنِ الْمَسِيلِ وَيَقُولُ ‏ "‏ لاَ يُقْطَعُ الْوَادِي إِلاَّ شَدًّا ‏"‏ ‏.‏\hadithno{2980}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Safiyyah bint Shaimah that a woman said:I saw the Messenger of Allah hastening at the bottom of the valley and he said: "The river bed should not be crossed except with vigor." (Sahih) Chpater 178. The Place Where One Should Walk}}
\hadithdefcmd{nasai}{2981}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا نَزَلَ مِنَ الصَّفَا مَشَى حَتَّى إِذَا انْصَبَّتْ قَدَمَاهُ فِي بَطْنِ الْوَادِي سَعَى حَتَّى يَخْرُجَ مِنْهُ ‏.‏\hadithno{2981}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin Abdullah, may Allah be pleased with him, that:when the Messenger of Allah came down from As-Safa he would walk until he reached the bottom of the valley, then he would hasten until he came out of it}}
\hadithdefcmd{nasai}{2982}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ سُفْيَانَ، عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ لَمَّا تَصَوَّبَتْ قَدَمَا رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَطْنِ الْوَادِي رَمَلَ حَتَّى خَرَجَ مِنْهُ ‏.‏\hadithno{2982}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"When the Messenger of Allah reached level ground at the bottom of the valley, he would hasten until he came out of it}}
\hadithdefcmd{nasai}{2983}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا جَابِرٌ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَزَلَ - يَعْنِي - عَنِ الصَّفَا حَتَّى إِذَا انْصَبَّتْ قَدَمَاهُ فِي الْوَادِي رَمَلَ حَتَّى إِذَا صَعِدَ مَشَى ‏.‏\hadithno{2983}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jabir narrated that:the Messenger of Allah came down from As-Safa until he reached level round in the valley, then he hastened (Ramel) until (the ground) rouse, then he walked}}
\hadithdefcmd{nasai}{2984}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَرْوَةَ فَصَعِدَ فِيهَا ثُمَّ بَدَا لَهُ الْبَيْتُ فَقَالَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ قَالَ ذَلِكَ ثَلاَثَ مَرَّاتٍ ثُمَّ ذَكَرَ اللَّهَ وَسَبَّحَهُ وَحَمِدَهُ ثُمَّ دَعَا بِمَا شَاءَ اللَّهُ فَعَلَ هَذَا حَتَّى فَرَغَ مِنَ الطَّوَافِ ‏.‏\hadithno{2984}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir bin Abdullah that:the Messenger of Allah came to Al-Marwah and climbed up until he could see the House, then he said: "La ilaha illallah, Wahdahu la sharika lah, lahul-mulku wa lahul-hamdu, yuhyi wa yumitu, wa huwaala kulli shayin qadir (There is none worthy of worship except Allah alone with no partner or associate, His is the dominion and to Him be praise, He gives life and death, and He has power over all things)." He said that three times, then he remembered Allah, and glorified and praised Him, then he supplicated there for as long as Allah willed. And he did that until he had finished Sai}}
\hadithdefcmd{nasai}{2985}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ أَنْبَأَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَهَبَ إِلَى الصَّفَا فَرَقِيَ عَلَيْهَا حَتَّى بَدَا لَهُ الْبَيْتُ ثُمَّ وَحَّدَ اللَّهَ عَزَّ وَجَلَّ وَكَبَّرَهُ وَقَالَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ ثُمَّ مَشَى حَتَّى إِذَا انْصَبَّتْ قَدَمَاهُ سَعَى حَتَّى إِذَا صَعِدَتْ قَدَمَاهُ مَشَى حَتَّى أَتَى الْمَرْوَةَ فَفَعَلَ عَلَيْهَا كَمَا فَعَلَ عَلَى الصَّفَا حَتَّى قَضَى طَوَافَهُ ‏.‏\hadithno{2985}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that the Messenger of Allah went to As-Safa and climbed up it and said:"La ilaha illallah, Wahdahu la sharika lah, lahul-mulku wa lahul-hamdu, yuhyi wa yumitu, wa huwaala kulli shayin qadir (There is none worthy of worship except Allah alone with no partner or associate, His is the dominion and to Him be praise, He gives life and death, and He has power over all things)." Then he walked until he reached level ground, then he hastened until the ground began to rise. Then he walked until he came to Al-Marwah, and he did the same there as he had at As-Safa, until he had finished his Sai}}
\hadithdefcmd{nasai}{2986}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ لَمْ يَطُفِ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ بَيْنَ الصَّفَا وَالْمَرْوَةِ إِلاَّ طَوَافًا وَاحِدًا ‏.‏\hadithno{2986}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir said:"The Prophet and his Companions only performed Sai between As-Safa and Al-Marwah once}}
\hadithdefcmd{nasai}{2987}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، أَنَّ طَاوُسًا، أَخْبَرَهُ أَنَّ ابْنَ عَبَّاسٍ أَخْبَرَهُ عَنْ مُعَاوِيَةَ، أَنَّهُ قَصَّرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِشْقَصٍ فِي عُمْرَةٍ عَلَى الْمَرْوَةِ ‏.‏\hadithno{2987}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muawiyah that:he cut the hair of the Prophet with the edge of an arrow during his Umrah at Al-Marwah}}
\hadithdefcmd{nasai}{2988}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مُعَاوِيَةَ، قَالَ قَصَّرْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى الْمَرْوَةِ بِمِشْقَصِ أَعْرَابِيٍّ ‏.‏\hadithno{2988}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Muawiyah said:"I cut the hair of the Messenger of Allah at Al-Marwah with the edge of a Bedouin arrow}}
\hadithdefcmd{nasai}{2989}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ عَطَاءٍ، عَنْ مُعَاوِيَةَ، قَالَ أَخَذْتُ مِنْ أَطْرَافِ شَعْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِشْقَصٍ كَانَ مَعِي بَعْدَ مَا طَافَ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ فِي أَيَّامِ الْعَشْرِ ‏.‏ قَالَ قَيْسٌ وَالنَّاسُ يُنْكِرُونَ هَذَا عَلَى مُعَاوِيَةَ ‏.‏\hadithno{2989}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Muawiyah said:"I cut a little from the ends of the hair of the Messenger of Allah with the eduge of an arrow that I had with me, after he had circumambulated the House, and performed Sai between As-Safa and Al-Marwah, during the ten days." Qais said: "The people rebuked Muawiyah for that}}
\hadithdefcmd{nasai}{2990}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، عَنْ يَحْيَى، - وَهُوَ ابْنُ آدَمَ - عَنْ سُفْيَانَ، - وَهُوَ ابْنُ عُيَيْنَةَ - قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نُرَى إِلاَّ الْحَجَّ - قَالَتْ - فَلَمَّا أَنْ طَافَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ قَالَ ‏ "‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُقِمْ عَلَى إِحْرَامِهِ وَمَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ فَلْيَحْلِلْ ‏"‏ ‏.‏\hadithno{2990}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Aishah said:"We went out with the Messenger of Allah with no intention but Hajj. When he had circumambulated the Hosue and performed Sai between As-Safa and Al-Marwah, he said: 'Whoever has a Hadi with him, let him remain in Ihram, and whoever does not have a Hadi with him, let him exit Ihram}}
\hadithdefcmd{nasai}{2991}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ فَمِنَّا مَنْ أَهَلَّ بِالْحَجِّ وَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ وَأَهْدَى فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَهَلَّ بِعُمْرَةٍ وَلَمْ يُهْدِ فَلْيَحْلِلْ وَمَنْ أَهَلَّ بِعُمْرَةٍ فَأَهْدَى فَلاَ يَحِلَّ وَمَنْ أَهَلَّ بِحَجَّةٍ فَلْيُتِمَّ حَجَّهُ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ وَكُنْتُ مِمَّنْ أَهَلَّ بِعُمْرَةٍ ‏.‏\hadithno{2991}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"We set out with the Messenger of Allah for the Farewell Pilgrimage. Some of us entered Ihram for Hajj and some of us entered Ihram for Umrah and brought along a Hadi. The Messenger of Allah said: 'Whoever entered Ihram for Umrah and did not bring Hadi, let him exit Ihram. And whoever entered Ihram for Umrah and did bring a Hadi, let him not exit Ihra. Whoever entered Ihram for Hajj let him complete his Hajj.'" Aishah said "And I was one of those who had entered Ihram for Umrah}}
\hadithdefcmd{nasai}{2992}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ، قَالَ حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، عَنْ مَنْصُورِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ قَدِمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُهِلِّينَ بِالْحَجِّ فَلَمَّا دَنَوْنَا مِنْ مَكَّةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ فَلْيَحْلِلْ وَمَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُقِمْ عَلَى إِحْرَامِهِ ‏"‏ ‏.‏ قَالَتْ وَكَانَ مَعَ الزُّبَيْرِ هَدْىٌ فَأَقَامَ عَلَى إِحْرَامِهِ وَلَمْ يَكُنْ مَعِي هَدْىٌ فَأَحْلَلْتُ فَلَبِسْتُ ثِيَابِي وَتَطَيَّبْتُ مِنْ طِيبِي ثُمَّ جَلَسْتُ إِلَى الزُّبَيْرِ فَقَالَ اسْتَأْخِرِي عَنِّي ‏.‏ فَقُلْتُ أَتَخْشَى أَنْ أَثِبَ عَلَيْكَ\hadithno{2992}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Asma bint Abi Bakr who said:"We came with the Messenger of Allah reciting the Talbiyah for Hajj. When we drew close to Makkah, the Messenger of Alla said: 'Whoever does not have a Hadi with him, let him exit Ihram. Whoever has a Hadi with him, let him remain in Ihram.' Az-Zubair had a Hadi with him so he remained in Ihram, but I did not have a Hadi with me so I exited Ihram, put on my some of my perfume. Then I sat down with As-Zubair and he said: "Go away from me.' I said: 'Are you afraid that I am going to jump on you?}}
\hadithdefcmd{nasai}{2993}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ قَرَأْتُ عَلَى أَبِي قُرَّةَ مُوسَى بْنِ طَارِقٍ عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حِينَ رَجَعَ مِنْ عُمْرَةِ الْجِعِرَّانَةِ بَعَثَ أَبَا بَكْرٍ عَلَى الْحَجِّ فَأَقْبَلْنَا مَعَهُ حَتَّى إِذَا كَانَ بِالْعَرْجِ ثَوَّبَ بِالصُّبْحِ ثُمَّ اسْتَوَى لِيُكَبِّرَ فَسَمِعَ الرُّغْوَةَ خَلْفَ ظَهْرِهِ فَوَقَفَ عَلَى التَّكْبِيرِ فَقَالَ هَذِهِ رُغْوَةُ نَاقَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم الْجَدْعَاءِ لَقَدْ بَدَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْحَجِّ فَلَعَلَّهُ أَنْ يَكُونَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنُصَلِّيَ مَعَهُ فَإِذَا عَلِيٌّ عَلَيْهَا فَقَالَ لَهُ أَبُو بَكْرٍ أَمِيرٌ أَمْ رَسُولٌ قَالَ لاَ بَلْ رَسُولٌ أَرْسَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِبَرَاءَةَ أَقْرَؤُهَا عَلَى النَّاسِ فِي مَوَاقِفِ الْحَجِّ ‏.‏ فَقَدِمْنَا مَكَّةَ فَلَمَّا كَانَ قَبْلَ التَّرْوِيَةِ بِيَوْمٍ قَامَ أَبُو بَكْرٍ رضى الله عنه فَخَطَبَ النَّاسَ فَحَدَّثَهُمْ عَنْ مَنَاسِكِهِمْ حَتَّى إِذَا فَرَغَ قَامَ عَلِيٌّ رضى الله عنه فَقَرَأَ عَلَى النَّاسِ بَرَاءَةَ حَتَّى خَتَمَهَا ثُمَّ خَرَجْنَا مَعَهُ حَتَّى إِذَا كَانَ يَوْمُ عَرَفَةَ قَامَ أَبُو بَكْرٍ فَخَطَبَ النَّاسَ فَحَدَّثَهُمْ عَنْ مَنَاسِكِهِمْ حَتَّى إِذَا فَرَغَ قَامَ عَلِيٌّ فَقَرَأَ عَلَى النَّاسِ بَرَاءَةَ حَتَّى خَتَمَهَا ثُمَّ كَانَ يَوْمُ النَّحْرِ فَأَفَضْنَا فَلَمَّا رَجَعَ أَبُو بَكْرٍ خَطَبَ النَّاسَ فَحَدَّثَهُمْ عَنْ إِفَاضَتِهِمْ وَعَنْ نَحْرِهِمْ وَعَنْ مَنَاسِكِهِمْ فَلَمَّا فَرَغَ قَامَ عَلِيٌّ فَقَرَأَ عَلَى النَّاسِ بَرَاءَةَ حَتَّى خَتَمَهَا فَلَمَّا كَانَ يَوْمُ النَّفْرِ الأَوَّلُ قَامَ أَبُو بَكْرٍ فَخَطَبَ النَّاسَ فَحَدَّثَهُمْ كَيْفَ يَنْفِرُونَ وَكَيْفَ يَرْمُونَ فَعَلَّمَهُمْ مَنَاسِكَهُمْ فَلَمَّا فَرَغَ قَامَ عَلِيٌّ فَقَرَأَ بَرَاءَةَ عَلَى النَّاسِ حَتَّى خَتَمَهَا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ بْنُ خُثَيْمٍ لَيْسَ بِالْقَوِيِّ فِي الْحَدِيثِ وَإِنَّمَا أَخْرَجْتُ هَذَا لِئَلاَّ يُجْعَلَ ابْنُ جُرَيْجٍ عَنْ أَبِي الزُّبَيْرِ وَمَا كَتَبْنَاهُ إِلاَّ عَنْ إِسْحَاقَ بْنِ إِبْرَاهِيمَ وَيَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ لَمْ يَتْرُكْ حَدِيثَ ابْنِ خُثَيْمٍ وَلاَ عَبْدِ الرَّحْمَنِ إِلاَّ أَنَّ عَلِيَّ بْنَ الْمَدِينِيِّ قَالَ ابْنُ خُثَيْمٍ مُنْكَرُ الْحَدِيثِ وَكَأَنَّ عَلِيَّ بْنَ الْمَدِينِيِّ خُلِقَ لِلْحَدِيثِ ‏.‏\hadithno{2993}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that:when the Prophet came back from the Umrah of Al-Jirranah, he sent Abu Bakr to lead the Hajj. We wnet the him until, when he was in Al-Urj, the Iqamah for Subh was said, and he stood up to say the Takbir while he heard the grunting of a camel behind him, and he did not say the Takbir. He said: "This is the grunting of the camel of the Messenger of Allah has had second thoughts about the Hajj, and may be he is here, and we will pray with him." But it was 'Ali on the camel. Abu Bakr said to him: "(Have you come) as a leader or as messenger?" He said: "No, as a messenger, sent by the Messenger of Allah with a declaration of innocence to recite it to the people in the stations of Hajj. So we came to makkah and one day before the day of At-Tarwiyah Abu Bakr, may Allah be pleased with him, stood up and addressed the people telling them about their rituals. When he finished, Ali, may Allah be pleased with him, stood up and recited the declaration of innocence to the people until he finished it. Then we went out with hm and on the day of Arafat. Abu Bakr stood up and addressed people, telling them about rituals. When he finished, Ali, may Allah be pleased with him, stood up and recited the declaration of innocence to the people until he finished it. Then on the day of Sacrifice, we departed (Ifadah) and when Abu Bakr came back, eh addressed the people, telling them about their departure (Ifadah), sacrifice and rituals. When he finished, Ali, may Allah be pleased with him, stood up and recited the declaration of innocence to the people until he finished it. On the first day of An-Nafr (The 12th of Dhul-Hijjah), Abu Bakr stood up and addressed the people, telling them how to offer their sacrifice and how to stone the Jamrat, and teaching them their rituals. When he had finished, "Ali, may Allah be pleased with him, stood up and recited the declaration of innocence to the people until he finished it. (Daif) Abu Abdur-Rahman (An-Nasai) said: Ibn Khuthaim is not strong in Hadith, and I only narrated this so it would not be considered to be from Ibn Juraij from Abu Az-Zubai. And we did not write it except from Ishaq bin Rahuyah bin Ibrahm. And yahya bin Saeed Al-Qattan did not abandon the narrations of Ibn Khuthaim, or dod Abdur-Rahamn. However, Ali bin Al-Madini said: "Ibn Khuthaim is Munkar in Hadith," and Ali bin Al-Madini is more knowledgeable of Hadith}}
\hadithdefcmd{nasai}{2994}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ قَدِمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لأَرْبَعٍ مَضَيْنَ مِنْ ذِي الْحِجَّةِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَحِلُّوا وَاجْعَلُوهَا عُمْرَةً ‏"‏ ‏.‏ فَضَاقَتْ بِذَلِكَ صُدُورُنَا وَكَبُرَ عَلَيْنَا فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ أَحِلُّوا فَلَوْلاَ الْهَدْىُ الَّذِي مَعِي لَفَعَلْتُ مِثْلَ الَّذِي تَفْعَلُونَ ‏"‏ ‏.‏ فَأَحْلَلْنَا حَتَّى وَطِئْنَا النِّسَاءَ وَفَعَلْنَا مَا يَفْعَلُ الْحَلاَلُ حَتَّى إِذَا كَانَ يَوْمُ التَّرْوِيَةِ وَجَعَلْنَا مَكَّةَ بِظَهْرٍ لَبَّيْنَا بِالْحَجِّ ‏.‏\hadithno{2994}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jabir said:"We came with the Messenger of Allah on the fourth day of Dhul-Hijjah. The prophet said: 'Exit Ihram and make it Umrah.' We were distressed and upset by that. News of that reached the Messenger of Allah and he said: 'O people, exit Ihram. Were if not for the Hadi that I brought with me, I would have done what you are doing.' So we exited Ihram, and had intercourse with our wives, ad we did everything that the non-Muhrim does until the day of At-Tarwiyah, when we put Makkah behind us (When we headed for Mina) and entered Ihram for Hajj}}
\hadithdefcmd{nasai}{2995}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ الدُّؤَلِيِّ، عَنْ مُحَمَّدِ بْنِ عِمْرَانَ الأَنْصَارِيِّ، عَنْ أَبِيهِ، قَالَ عَدَلَ إِلَىَّ عَبْدُ اللَّهِ بْنُ عُمَرَ وَأَنَا نَازِلٌ، تَحْتَ سَرْحَةٍ بِطَرِيقِ مَكَّةَ فَقَالَ مَا أَنْزَلَكَ تَحْتَ هَذِهِ الشَّجَرَةِ فَقُلْتُ أَنْزَلَنِي ظِلُّهَا ‏.‏ قَالَ عَبْدُ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كُنْتَ بَيْنَ الأَخْشَبَيْنِ مِنْ مِنًى وَنَفَخَ - بِيَدِهِ نَحْوَ الْمَشْرِقِ - فَإِنَّ هُنَاكَ وَادِيًا يُقَالُ لَهُ السُّرَّبَةُ - وَفِي حَدِيثِ الْحَارِثِ يُقَالُ لَهُ السُّرَرُ - بِهِ سَرْحَةٌ سُرَّ تَحْتَهَا سَبْعُونَ نَبِيًّا ‏"‏ ‏.‏\hadithno{2995}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Muhammad bn Imran Al-Ansari that his father said:"Abdullah bin Umar came to me when I had stopped beneath a large tree on the way to Makkah. He said: 'Why did you stop beneath this tree?' I said: 'Because of its shade.' Abdullah said: 'The Messenger of Allah said: If you are between the two mountains of Mina - and he pointed with his hand toward the east - there is a valley there called As-Surrabah according to the narration of Al-Harith: Called As-Surar - in which there is large tree beneath which seventy prophets were born." (Daif)}}
\hadithdefcmd{nasai}{2996}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ نُعَيْمٍ، قَالَ أَنْبَأَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَبْدِ الْوَارِثِ، - ثِقَةٌ - قَالَ حَدَّثَنَا حُمَيْدٌ الأَعْرَجُ، عَنْ مُحَمَّدِ بْنُ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ رَجُلٍ، مِنْهُمْ يُقَالُ لَهُ عَبْدُ الرَّحْمَنِ بْنُ مُعَاذٍ قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِنًى فَفَتَحَ اللَّهُ أَسْمَاعَنَا حَتَّى إِنْ كُنَّا لَنَسْمَعُ مَا يَقُولُ وَنَحْنُ فِي مَنَازِلِنَا فَطَفِقَ النَّبِيُّ صلى الله عليه وسلم يُعَلِّمُهُمْ مَنَاسِكَهُمْ حَتَّى بَلَغَ الْجِمَارَ فَقَالَ بِحَصَى الْخَذْفِ وَأَمَرَ الْمُهَاجِرِينَ أَنْ يَنْزِلُوا فِي مُقَدَّمِ الْمَسْجِدِ وَأَمَرَ الأَنْصَارَ أَنْ يَنْزِلُوا فِي مُؤَخَّرِ الْمَسْجِدِ ‏.‏\hadithno{2996}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Muhammad bin Ibrahim At-Taimi that a man amonth them who was called Abdulr-Rahman bin Muadh said:The Messenger of Allah addressed us in Mina, and Allah enabled us to hear hwat he said when we were in our encampments. The Prophet started to teach them their rituals until he reached the Himar (Stoning the pillars), and he said: look for pebbles the size of date stones or fingertips. And he told the Muhajirun to camp in front of the Masjid and the Ansar to camp behind the Masjid}}
\hadithdefcmd{nasai}{2997}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، وَعَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالاَ حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ فَقُلْتُ أَخْبِرْنِي بِشَىْءٍ، عَقَلْتَهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَيْنَ صَلَّى الظُّهْرَ يَوْمَ التَّرْوِيَةِ قَالَ بِمِنًى ‏.‏ فَقُلْتُ أَيْنَ صَلَّى الْعَصْرَ يَوْمَ النَّفْرِ قَالَ بِالأَبْطَحِ ‏.‏\hadithno{2997}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abdul-Aziz bin Rafi said:"I asked anas bin Malik: 'Tell me of something that you learned from the Messenger of Allah; where did he pray Zuhr on the day of At-Tarwiyah?' He said: 'In Mina.' I said: 'Where did he pray Asr on the day of An-Nafr?' He said: 'In Al-Abtah}}
\hadithdefcmd{nasai}{2998}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، قَالَ غَدَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ مِنًى إِلَى عَرَفَةَ فَمِنَّا الْمُلَبِّي وَمِنَّا الْمُكَبِّرُ ‏.‏\hadithno{2998}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Umar said:"We left Mina with the Messenger of Allah for AArafat, and some of us were reciting the Talbiyah and some reciting the Takbir}}
\hadithdefcmd{nasai}{2999}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، قَالَ غَدَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى عَرَفَاتٍ فَمِنَّا الْمُلَبِّي وَمِنَّا الْمُكَبِّرُ ‏.‏\hadithno{2999}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Umar said:"We left for Arafat with the Messenger of Allah, and some of us were reciting the Talbiyah and some reciting the Takbir}}
\hadithdefcmd{nasai}{3000}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمُلاَئِيُّ، - يَعْنِي أَبَا نُعَيْمٍ الْفَضْلَ بْنَ دُكَيْنٍ - قَالَ حَدَّثَنَا مَالِكٌ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ الثَّقَفِيُّ، قَالَ قُلْتُ لأَنَسٍ وَنَحْنُ غَادِيَانِ مِنْ مِنًى إِلَى عَرَفَاتٍ مَا كُنْتُمْ تَصْنَعُونَ فِي التَّلْبِيَةِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي هَذَا الْيَوْمِ قَالَ كَانَ الْمُلَبِّي يُلَبِّي فَلاَ يُنْكَرُ عَلَيْهِ وَيُكَبِّرُ الْمُكَبِّرُ فَلاَ يُنْكَرُ عَلَيْهِ ‏.‏\hadithno{3000}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Muhammad bin Abi Bakr Ath-Thaqafi narrated:"When we were leaving Mina for Arafat, I said to Anas: 'What did you do for the Talbiyah with the Messenger of Allah on this day?' He said 'Those who recited the Talbiyah did so, and no one criticized them, and those who recited the Takbir did so, and no one criticized them}}
\hadithdefcmd{nasai}{3001}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، - وَهُوَ الثَّقَفِيُّ - قَالَ قُلْتُ لأَنَسٍ غَدَاةَ عَرَفَةَ مَا تَقُولُ فِي التَّلْبِيَةِ فِي هَذَا الْيَوْمِ قَالَ سِرْتُ هَذَا الْمَسِيرَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَصْحَابِهِ وَكَانَ مِنْهُمُ الْمُهِلُّ وَمِنْهُمُ الْمُكَبِّرُ فَلاَ يُنْكِرُ أَحَدٌ مِنْهُمْ عَلَى صَاحِبِهِ ‏.‏\hadithno{3001}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Muhmmad bin Abi Abkr - Ath-Thaqafi - said:"I said to Anas on the morning of Arafat: 'What do you say about the Talbiyah on this day?' I said: 'I walked this path with the Messenger of Allah and his Companions. Some of them recited the Talbiyah and some recited the Takbir, and none of them denounced any other}}
\hadithdefcmd{nasai}{3002}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ أَبِيهِ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، قَالَ قَالَ يَهُودِيٌّ لِعُمَرَ لَوْ عَلَيْنَا نَزَلَتْ هَذِهِ الآيَةُ لاَتَّخَذْنَاهُ عِيدًا ‏\{‏ الْيَوْمَ أَكْمَلْتُ لَكُمْ دِينَكُمْ ‏\}‏ قَالَ عُمَرُ قَدْ عَلِمْتُ الْيَوْمَ الَّذِي أُنْزِلَتْ فِيهِ وَاللَّيْلَةَ الَّتِي أُنْزِلَتْ لَيْلَةَ الْجُمُعَةِ وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَرَفَاتٍ ‏.‏\hadithno{3002}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Tariq bin Shihab said:A Jew said to `Umar: "If this Verse had been revealed to us, we would have taken it as a festival (Eid): 'This day, I have perfected your religion for you.'" Umar said: "I know the day when it was revealed and the night on which it was revealed: a Friday night when we were with Messenger of Allah in Arafat}}
\hadithdefcmd{nasai}{3003}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ يُونُسَ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ يَوْمٍ أَكْثَرَ مِنْ أَنْ يَعْتِقَ اللَّهُ عَزَّ وَجَلَّ فِيهِ عَبْدًا أَوْ أَمَةً مِنَ النَّارِ مِنْ يَوْمِ عَرَفَةَ إِنَّهُ لَيَدْنُو ثُمَّ يُبَاهِي بِهِمُ الْمَلاَئِكَةَ وَيَقُولُ مَا أَرَادَ هَؤُلاَءِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ يُشْبِهُ أَنْ يَكُونَ يُونُسَ بْنَ يُوسُفَ الَّذِي رَوَى عَنْهُ مَالِكٌ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{3003}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that from Aishah that the Messenger of Allah said:"There is no day on which Allah, the Mighty and Sublime, frees more of his slaves, male and female, from the fire, than the day of Arafah. He comes close, then he boasts to the angels about them and say: 'What do these people want?'" (Sahih) Abdu Abdur-Rhamn (An-Nasai) said: It appears that Yunus bin Yusuf is the one who reported it from Malik and Allah, most High, Knows best}}
\hadithdefcmd{nasai}{3004}{أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، - وَهُوَ ابْنُ يَزِيدَ الْمُقْرِئُ - قَالَ حَدَّثَنَا مُوسَى بْنُ عُلَىٍّ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ يَوْمَ عَرَفَةَ وَيَوْمَ النَّحْرِ وَأَيَّامَ التَّشْرِيقِ عِيدُنَا أَهْلَ الإِسْلاَمِ وَهِيَ أَيَّامُ أَكْلٍ وَشُرْبٍ ‏"‏ ‏.‏\hadithno{3004}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Uqbah bin Amir that the Messenger of Allah said:"The day of Arafat and the day of sacrifice and the day of At-Tashriq are our Id, the people of Islam, and they are days of eating and drinking}}
\hadithdefcmd{nasai}{3005}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَخْبَرَنِي أَشْهَبُ، قَالَ أَخْبَرَنِي مَالِكٌ، أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، قَالَ كَتَبَ عَبْدُ الْمَلِكِ بْنُ مَرْوَانَ إِلَى الْحَجَّاجِ بْنِ يُوسُفَ يَأْمُرُهُ أَنْ لاَ، يُخَالِفَ ابْنَ عُمَرَ فِي أَمْرِ الْحَجِّ فَلَمَّا كَانَ يَوْمُ عَرَفَةَ جَاءَهُ ابْنُ عُمَرَ حِينَ زَالَتِ الشَّمْسُ وَأَنَا مَعَهُ فَصَاحَ عِنْدَ سُرَادِقِهِ أَيْنَ هَذَا فَخَرَجَ إِلَيْهِ الْحَجَّاجُ وَعَلَيْهِ مِلْحَفَةٌ مُعَصْفَرَةٌ فَقَالَ لَهُ مَا لَكَ يَا أَبَا عَبْدِ الرَّحْمَنِ قَالَ الرَّوَاحَ إِنْ كُنْتَ تُرِيدُ السُّنَّةَ ‏.‏ فَقَالَ لَهُ هَذِهِ السَّاعَةَ فَقَالَ لَهُ نَعَمْ ‏.‏ فَقَالَ أُفِيضُ عَلَىَّ مَاءً ثُمَّ أَخْرُجُ إِلَيْكَ ‏.‏ فَانْتَظَرَهُ حَتَّى خَرَجَ فَسَارَ بَيْنِي وَبَيْنَ أَبِي فَقُلْتُ إِنْ كُنْتَ تُرِيدُ أَنْ تُصِيبَ السُّنَّةَ فَاقْصُرِ الْخُطْبَةَ وَعَجِّلِ الْوُقُوفَ ‏.‏ فَجَعَلَ يَنْظُرُ إِلَى ابْنِ عُمَرَ كَيْمَا يَسْمَعَ ذَلِكَ مِنْهُ فَلَمَّا رَأَى ذَلِكَ ابْنُ عُمَرَ قَالَ صَدَقَ ‏.‏\hadithno{3005}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Salim Bin Abdullah said:"Abdul Malik bin Marwan wrote to Al-Hajjaj bin Yusuf telling him not to go against Ibn Umar with regard to the Hajj. On the day of Arafat, Ibn Umar came to him when the sun had passed its zenith, and I was with him, and shouted near his cotton tent: 'Where is he?' Al-Hajjaj came out to him, wearing a wrap dyed with safflower. He said: 'What is the matter, O Abu Abdur Rahman?' He said: 'We have to move on if you want to follow Sunnah.' He said to him: 'At this hour?' He said: 'Yes.' He said: 'I will pour some water over my self (have a bath) then I will come out to you.' So he waited until he came, then he walked between my father and me, I said: 'If you want to follow the Sunnah, then deliver a short Khutbah and hasten to stand (in Arafat).' He started to look at Ibn Umar so that he could hear that, and when Ibn Umar noticed that he said: 'He is speaking the truth}}
\hadithdefcmd{nasai}{3006}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ الأَوْدِيُّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ صَالِحٍ، عَنْ مَيْسَرَةَ بْنِ حَبِيبٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ كُنْتُ مَعَ ابْنِ عَبَّاسٍ بِعَرَفَاتٍ فَقَالَ مَا لِي لاَ أَسْمَعُ النَّاسَ يُلَبُّونَ قُلْتُ يَخَافُونَ مِنْ مُعَاوِيَةَ ‏.‏ فَخَرَجَ ابْنُ عَبَّاسٍ مِنْ فُسْطَاطِهِ فَقَالَ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ فَإِنَّهُمْ قَدْ تَرَكُوا السُّنَّةَ مِنْ بُغْضِ عَلِيٍّ ‏.‏\hadithno{3006}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Saeed bin Jubair said:"I was with Ibn Abbas in Arafat and he said: 'Why do I not hear the people reciting Talbiyah?' I said: They are afraid of Muawiyah.' So Ibn Abbas went out of his tent and said: "Labbaik Allahumma Labbaik, Labbaik! They are only forsaking the Sunnah out of hatred for Ali}}
\hadithdefcmd{nasai}{3007}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ بْنِ نُبَيْطٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ عَلَى جَمَلٍ أَحْمَرَ بِعَرَفَةَ قَبْلَ الصَّلاَةِ ‏.‏\hadithno{3007}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salamah bin Nubait, that his father said:"I saw the Messenger of Allah delivering a Khutab atop a red camel in Arafat, before the Salah." (Daif)}}
\hadithdefcmd{nasai}{3008}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ سَلَمَةَ بْنِ نُبَيْطٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ يَوْمَ عَرَفَةَ عَلَى جَمَلٍ أَحْمَرَ ‏.‏\hadithno{3008}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salamah bin Nubait that his father said:"I saw the Messenger of Allah delivering a Khutbah on the day of Arafat atop a red camel." (Hasan) Chpater 200. Delivering A Short Khutbah In 'Arafat}}
\hadithdefcmd{nasai}{3009}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، جَاءَ إِلَى الْحَجَّاجِ بْنِ يُوسُفَ يَوْمَ عَرَفَةَ حِينَ زَالَتِ الشَّمْسُ وَأَنَا مَعَهُ، فَقَالَ الرَّوَاحَ إِنْ كُنْتَ تُرِيدُ السُّنَّةَ ‏.‏ فَقَالَ هَذِهِ السَّاعَةَ قَالَ نَعَمْ ‏.‏ قَالَ سَالِمٌ فَقُلْتُ لِلْحَجَّاجِ إِنْ كُنْتَ تُرِيدُ أَنْ تُصِيبَ الْيَوْمَ السُّنَّةَ فَاقْصُرِ الْخُطْبَةَ وَعَجِّلِ الصَّلاَةَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ صَدَقَ ‏.‏\hadithno{3009}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salim bin Abdullah that:Abdullah bin Umar came to Al-Hajjaj bin Yusuf on the day of Arafat when the sun has passed its zenith, and I was with him. He said: "We have to move on if you want to follow Sunnah." He said to him: "At this hours?" He said: Yes." Salim said: "I said to Al-Hajjaj: 'If you want to follow the Sunnah, then deliver a short Khutbah and hasten to pray.' Abdullah bin Umar said: 'He is telling the truth}}
\hadithdefcmd{nasai}{3010}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ خَالِدٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الصَّلاَةَ لِوَقْتِهَا إِلاَّ بِجَمْعٍ وَعَرَفَاتٍ ‏.‏\hadithno{3010}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abdullah said:"The Messenger of Allah used to offer prayers at their proper time except in Jam (Al-Muzdalifah) and Arafat}}
\hadithdefcmd{nasai}{3011}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ هُشَيْمٍ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، قَالَ قَالَ أُسَامَةُ بْنُ زَيْدٍ كُنْتُ رَدِيفَ النَّبِيِّ صلى الله عليه وسلم بِعَرَفَاتٍ فَرَفَعَ يَدَيْهِ يَدْعُو فَمَالَتْ بِهِ نَاقَتُهُ فَسَقَطَ خِطَامُهَا فَتَنَاوَلَ الْخِطَامَ بِإِحْدَى يَدَيْهِ وَهُوَ رَافِعٌ يَدَهُ الأُخْرَى ‏.‏\hadithno{3011}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Usamah bin Zaid said:"I was a companion rider with the Prophet at Arafat. He raised his hands in supplication, so his she-camel began leaning and he dropped her halter, so he took the halter with one of his hands while he was raising the other hand}}
\hadithdefcmd{nasai}{3012}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ قُرَيْشٌ تَقِفُ بِالْمُزْدَلِفَةِ وَيُسَمَّوْنَ الْحُمْسَ وَسَائِرُ الْعَرَبِ تَقِفُ بِعَرَفَةَ فَأَمَرَ اللَّهُ تَبَارَكَ وَتَعَالَى نَبِيَّهُ صلى الله عليه وسلم أَنْ يَقِفَ بِعَرَفَةَ ثُمَّ يَدْفَعُ مِنْهَا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ ‏\}‏ ‏.‏\hadithno{3012}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Quraish used to stand in Al-Muzdalifah and they called themselves Al-Hums, and the rest of Arabs stood in Arafat. Then Allah, Blessed and Most High, commanded his Prophet to stand in Arafat, and then move on from there. Allah, the Mighty and Sublime, revealed: 'Then depart from the place whence all the people depart}}
\hadithdefcmd{nasai}{3013}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ أَضْلَلْتُ بَعِيرًا لِي فَذَهَبْتُ أَطْلُبُهُ بِعَرَفَةَ يَوْمَ عَرَفَةَ فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَاقِفًا فَقُلْتُ مَا شَأْنُ هَذَا إِنَّمَا هَذَا مِنَ الْحُمْسِ ‏.‏\hadithno{3013}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Muhammad bin Jubir bin Mutim that his father:"I lost a camel of mine, so I went to look for it in Arafat on the day of Arafat. I saw the Prophet standing there and said: 'what is he doing here?' He is one of the Hums}}
\hadithdefcmd{nasai}{3014}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، أَنَّ يَزِيدَ بْنَ شَيْبَانَ، قَالَ كُنَّا وُقُوفًا بِعَرَفَةَ مَكَانًا بَعِيدًا مِنَ الْمَوْقِفِ فَأَتَانَا ابْنُ مِرْبَعٍ الأَنْصَارِيُّ فَقَالَ إِنِّي رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَيْكُمْ يَقُولُ ‏ "‏ كُونُوا عَلَى مَشَاعِرِكُمْ فَإِنَّكُمْ عَلَى إِرْثٍ مِنْ إِرْثِ أَبِيكُمْ إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{3014}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Amr bin Abdullah bin Safwan that Yazid bin Shaiban said:"We were standing in Arafat in a place far from the place of standing, and Ibn Mirba Al-Ansari came and said: 'I am the messenger of Messenger of Allah to you; he says: 'Stay where you are (for it is a place of ritual), for you are following the legacy of you father Ibrahim, peace be upon him}}
\hadithdefcmd{nasai}{3015}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، أَتَيْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَسَأَلْنَاهُ عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم فَحَدَّثَنَا أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَرَفَةُ كُلُّهَا مَوْقِفٌ ‏"‏ ‏.‏\hadithno{3015}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ja`far bin Muhammad said:"My father told me: 'We came to Jabir bin `Abdullah and asked him about the Hajj of the Prophet. He told us that the Prophet said: "All of Arafat is the place of standing}}
\hadithdefcmd{nasai}{3016}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ بُكَيْرِ بْنِ عَطَاءٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَعْمَرَ، قَالَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَتَاهُ نَاسٌ فَسَأَلُوهُ عَنِ الْحَجِّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْحَجُّ عَرَفَةُ فَمَنْ أَدْرَكَ لَيْلَةَ عَرَفَةَ قَبْلَ طُلُوعِ الْفَجْرِ مِنْ لَيْلَةِ جَمْعٍ فَقَدْ تَمَّ حَجُّهُ ‏"‏ ‏.‏\hadithno{3016}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abdur-Rahman bin Yamur said:"I saw the Messenger of Allah when people came to him and asked him about Hajj. The Messenger of Allah said: 'Hajj is Arafat. Whoever catches up with the night of Arafat before dawn comes on the night of Jam (Al-Muzdalifah), his Hajj is complete}}
\hadithdefcmd{nasai}{3017}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، قَالَ أَفَاضَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَاتٍ وَرِدْفُهُ أُسَامَةُ بْنُ زَيْدٍ فَجَالَتْ بِهِ النَّاقَةُ وَهُوَ رَافِعٌ يَدَيْهِ لاَ تُجَاوِزَانِ رَأْسَهُ فَمَا زَالَ يَسِيرُ عَلَى هِينَتِهِ حَتَّى انْتَهَى إِلَى جَمْعٍ ‏.‏\hadithno{3017}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Abbas that Al-Fadl bin Abbas said:"The Messenger of Allah departed from Arafat and Usmah bin Zaid rode behind him. His camel bolted and he was raising his hands (to rein it in) but not above his head. He carried on like that until he reached Jam (Al-Muzdalifah)}}
\hadithdefcmd{nasai}{3018}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يُونُسَ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَمَّادٌ، عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ أُسَامَةَ بْنَ زَيْدٍ، قَالَ أَفَاضَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَةَ وَأَنَا رَدِيفُهُ فَجَعَلَ يَكْبَحُ رَاحِلَتَهُ حَتَّى أَنَّ ذِفْرَاهَا لَيَكَادُ يُصِيبُ قَادِمَةَ الرَّحْلِ وَهُوَ يَقُولُ ‏ "‏ يَا أَيُّهَا النَّاسُ عَلَيْكُمْ بِالسَّكِينَةِ وَالْوَقَارِ فَإِنَّ الْبِرَّ لَيْسَ فِي إِيضَاعِ الإِبِلِ ‏"‏ ‏.‏\hadithno{3018}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Abbas that Usmah bin Zaid said:"The Messneger of Allah departed from Arafat and I was riding behind him. He started trying to rein in his camel until its ears nearly touched the front of the saddle, and he was saying: 'O people, you must be tranquil and dignified, for righteousness does not come by making camels hurry}}
\hadithdefcmd{nasai}{3019}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ حَرْبٍ، قَالَ حَدَّثَنَا مُحْرِزُ بْنُ الْوَضَّاحِ، عَنْ إِسْمَاعِيلَ، - يَعْنِي ابْنَ أُمَيَّةَ - عَنْ أَبِي غَطَفَانَ بْنِ طَرِيفٍ، حَدَّثَهُ أَنَّهُ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ لَمَّا دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَنَقَ نَاقَتَهُ حَتَّى أَنَّ رَأْسَهَا لَيَمَسُّ وَاسِطَةَ رَحْلِهِ وَهُوَ يَقُولُ لِلنَّاسِ ‏ "‏ السَّكِينَةَ السَّكِينَةَ ‏"‏ ‏.‏ عَشِيَّةَ عَرَفَةَ ‏.‏\hadithno{3019}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Ghaftan bin Tarif that he heard Ibn Abbas say:"When the Messenger of Allah departed he reined in his she-camel until its head touched the middle of his saddle, and he was saying to the people: 'Be tranquil be tranquil,' on the evening of Arafat}}
\hadithdefcmd{nasai}{3020}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ أَبِي مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، وَكَانَ، رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي عَشِيَّةِ عَرَفَةَ وَغَدَاةِ جَمْعٍ لِلنَّاسِ حِينَ دَفَعُوا ‏"‏ عَلَيْكُمُ السَّكِينَةَ ‏"‏ ‏.‏ وَهُوَ كَافٌّ نَاقَتَهُ حَتَّى إِذَا دَخَلَ مُحَسِّرًا وَهُوَ مِنْ مِنًى قَالَ ‏"‏ عَلَيْكُمْ بِحَصَى الْخَذْفِ الَّذِي يُرْمَى بِهِ ‏"‏ ‏.‏ فَلَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم يُلَبِّي حَتَّى رَمَى الْجَمْرَةَ ‏.‏\hadithno{3020}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Al-Fadl bin Abbas, who rode behind the Messenger of Allah, that:on the eveing of Arafat and on the morning of Jam (Al-Muzdalifah), when they departed, the Messenger of Allah said to the people: "You must be tranquil," and was reining in his she-came. Then, when he was in Muhassir, which is part of Mina, he said: "You have to look for pebbles the size of date stones of fingertips," with which to stone the Jamrat. And the Messenger of Allah continued to recite the Talbiyah until he stoned Jamrat Al-Aqabah}}
\hadithdefcmd{nasai}{3021}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَفَاضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ السَّكِينَةُ وَأَمَرَهُمْ بِالسَّكِينَةِ وَأَوْضَعَ فِي وَادِي مُحَسِّرٍ وَأَمَرَهُمْ أَنْ يَرْمُوا الْجَمْرَةَ بِمِثْلِ حَصَى الْخَذْفِ ‏.‏\hadithno{3021}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah departed (From Arafat) in a tranquil manner, and he enjoined them to be tranquil. He hurried in the valley of Muhassir and told them to stone the Jamrat with (pebbles like date stones or fingertips. (Daif)}}
\hadithdefcmd{nasai}{3022}{أَخْبَرَنِي أَبُو دَاوُدَ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَفَاضَ مِنْ عَرَفَةَ وَجَعَلَ يَقُولُ ‏ "‏ السَّكِينَةَ عِبَادَ اللَّهِ ‏"‏ ‏.‏ يَقُولُ بِيَدِهِ هَكَذَا وَأَشَارَ أَيُّوبُ بِبَاطِنِ كَفِّهِ إِلَى السَّمَاءِ ‏.‏\hadithno{3022}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that the Prophet departed from Arafat and started saying:"Be tranquil, O slaves of Allah!" gesturing with his hand like this - and Ayyub gested with his palm uppermost}}
\hadithdefcmd{nasai}{3023}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ سُئِلَ عَنْ مَسِيرِ النَّبِيِّ، صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ قَالَ كَانَ يَسِيرُ الْعَنَقَ فَإِذَا وَجَدَ فَجْوَةً نَصَّ وَالنَّصُّ فَوْقَ الْعَنَقِ ‏.‏\hadithno{3023}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Usmah bin Zaid that he was asked how the Prophet traveled during the Farewell pilgrimage. He said:"He used to ride at a moderately fast pace, and when he came upon some open space he would gallop}}
\hadithdefcmd{nasai}{3024}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حَيْثُ أَفَاضَ مِنْ عَرَفَةَ مَالَ إِلَى الشِّعْبِ قَالَ فَقُلْتُ لَهُ أَتُصَلِّي الْمَغْرِبَ قَالَ ‏ "‏ الْمُصَلَّى أَمَامَكَ ‏"‏ ‏.‏\hadithno{3024}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Usmah bin Zaid that when the Prophet departed from Arafat he turned toward the mountain pass. I said to him:"Are you going to pray Magrib?" He said: "The prayer place is still ahead of you}}
\hadithdefcmd{nasai}{3025}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَزَلَ الشِّعْبَ الَّذِي يَنْزِلُهُ الأُمَرَاءُ فَبَالَ ثُمَّ تَوَضَّأَ وُضُوءًا خَفِيفًا فَقُلْتُ يَا رَسُولَ اللَّهِ الصَّلاَةَ ‏.‏ قَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ فَلَمَّا أَتَيْنَا الْمُزْدَلِفَةَ لَمْ يَحُلَّ آخِرُ النَّاسِ حَتَّى صَلَّى ‏.‏\hadithno{3025}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Usmah bin Zaid said:"The Messenger of allah stopped in the mountain pass where the rulers stop now, and urinated, then he performed a light Wudu and I said: 'O Messenger of Allah (isit time for ) prayer?' He said: 'The prayer is still ahead of you.' When we came to Al-Muzdalifah the people did not unload their camles until he had prayed}}
\hadithdefcmd{nasai}{3026}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، عَنْ حَمَّادٍ، عَنْ يَحْيَى، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ أَبِي أَيُّوبَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ ‏.‏\hadithno{3026}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Ayyub that:the Messenger of Allah joined Maghrib and Isha in Jam (Al-Muzdalifah)}}
\hadithdefcmd{nasai}{3027}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا، قَالَ حَدَّثَنَا مُصْعَبُ بْنُ الْمِقْدَامِ، عَنْ دَاوُدَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنِ ابْنِ مَسْعُودٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ ‏.‏\hadithno{3027}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Masud that:the Prophet joined Maghrib and Isha in Jam (Al-Muzdalifah)}}
\hadithdefcmd{nasai}{3028}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ أَبِي ذِئْبٍ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ بِإِقَامَةٍ وَاحِدَةٍ لَمْ يُسَبِّحْ بَيْنَهُمَا وَلاَ عَلَى إِثْرِ كُلِّ وَاحِدَةٍ مِنْهُمَا ‏.‏\hadithno{3028}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salim, from his father, that:the Messenger of Allah joined Maghrib and Isha; in Jam (Al-Muzdalifah), with one Iqamah, and he did not offer any voluntary prayers in between or after either of them}}
\hadithdefcmd{nasai}{3029}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ أَبَاهُ قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ لَيْسَ بَيْنَهُمَا سَجْدَةٌ صَلَّى الْمَغْرِبَ ثَلاَثَ رَكَعَاتٍ وَالْعِشَاءَ رَكْعَتَيْنِ ‏.‏ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَجْمَعُ كَذَلِكَ حَتَّى لَحِقَ بِاللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{3029}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Shihab that Ubaidullah bin Abdullah told him that his father said:"The Messenger of Allah joined Maghrib and Isha with no (Voluntary) prayer in between them. He prayed Maghrib with three Rakahs and Isha with two." And Abdullah bin Umar used to join them in like manner until he met Allahm, The Mighty and Sublime}}
\hadithdefcmd{nasai}{3030}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَغْرِبَ وَالْعِشَاءَ بِجَمْعٍ بِإِقَامَةٍ وَاحِدَةٍ ‏.‏\hadithno{3030}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Umar said:"The Messenger of Allah prayed Maghrib and Isha in Jam (Al-Muzdalifah) with one Iqamah}}
\hadithdefcmd{nasai}{3031}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، أَنَّ كُرَيْبًا، قَالَ سَأَلْتُ أُسَامَةَ بْنَ زَيْدٍ - وَكَانَ رِدْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَشِيَّةَ عَرَفَةَ - فَقُلْتُ كَيْفَ فَعَلْتُمْ قَالَ أَقْبَلْنَا نَسِيرُ حَتَّى بَلَغْنَا الْمُزْدَلِفَةَ فَأَنَاخَ فَصَلَّى الْمَغْرِبَ ثُمَّ بَعَثَ إِلَى الْقَوْمِ فَأَنَاخُوا فِي مَنَازِلِهِمْ فَلَمْ يَحِلُّوا حَتَّى صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْعِشَاءَ الآخِرَةَ ثُمَّ حَلَّ النَّاسُ فَنَزَلُوا فَلَمَّا أَصْبَحْنَا انْطَلَقْتُ عَلَى رِجْلِي فِي سُبَّاقِ قُرَيْشٍ وَرَدِفَهُ الْفَضْلُ ‏.‏\hadithno{3031}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibrahim bin Uqbah that Kuraib said:"I asked usamah bin Zaid, who rode behind the Messenger of Allah one the evening of Arafat. I said: "What did you do?' He said: 'We started traveling until we reached Al-Muzadalifah, then he stopped and prayed Maghrib. Then he sent word to the people to stay in their camps, and they did not unload their camels until the Messenger of Allah had prayed the later Isah. Then the people unloaded their camels and made camp. When morning came I set out on foot amonth those of the Quraish who got there first, and Al-Fadl rode behind the Prophet}}
\hadithdefcmd{nasai}{3032}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَنَا مِمَّنْ، قَدَّمَ النَّبِيُّ صلى الله عليه وسلم لَيْلَةَ الْمُزْدَلِفَةِ فِي ضَعَفَةِ أَهْلِهِ ‏.‏\hadithno{3032}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ubaidullah bin Abu Yazeed said:I heard Ibn Abbas say: I was one of those whom the Prophet sent ahead amongh the weak ones of his family}}
\hadithdefcmd{nasai}{3033}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ فِيمَنْ قَدَّمَ النَّبِيُّ صلى الله عليه وسلم لَيْلَةَ الْمُزْدَلِفَةِ فِي ضَعَفَةِ أَهْلِهِ ‏.‏\hadithno{3033}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated Abbas said:"I was one those whom the Prophet sent ahead on the night of Al-Muzdalifah among the weak ones of his family}}
\hadithdefcmd{nasai}{3034}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، وَعَفَّانُ، وَسُلَيْمَانُ، عَنْ شُعْبَةَ، عَنْ مُشَاشٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ ضَعَفَةَ بَنِي هَاشِمٍ أَنْ يَنْفِرُوا مِنْ جَمْعٍ بِلَيْلٍ ‏.‏\hadithno{3034}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Abbas, from Al-Fadl, that:the Prophet commanded the weak ones among Banu Hashim to move on from Jam' (Al-Muzadalifah) at night}}
\hadithdefcmd{nasai}{3035}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنَا عَطَاءٌ، عَنْ سَالِمِ بْنِ شَوَّالٍ، أَنَّ أُمَّ حَبِيبَةَ، أَخْبَرَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهَا أَنْ تُغَلِّسَ مِنْ جَمْعٍ إِلَى مِنًى ‏.‏\hadithno{3035}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim bin Shawwal that:Umm Habibah told him that the Prophet told her to leave Jam (Al-Muzdalifah) for Mina at the end of the night}}
\hadithdefcmd{nasai}{3036}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ سَالِمِ بْنِ شَوَّالٍ، عَنْ أُمِّ حَبِيبَةَ، قَالَتْ كُنَّا نُغَلِّسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْمُزْدَلِفَةِ إِلَى مِنًى ‏.‏\hadithno{3036}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Habibah said:"We used to leave Jam Al-Muzdalifah for Mina at the end of the night, during the time of the Messenger of Allah}}
\hadithdefcmd{nasai}{3037}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا مَنْصُورٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّمَا أَذِنَ النَّبِيُّ صلى الله عليه وسلم لِسَوْدَةَ فِي الإِفَاضَةِ قَبْلَ الصُّبْحِ مِنْ جَمْعٍ لأَنَّهَا كَانَتِ امْرَأَةً ثَبِطَةً ‏.‏\hadithno{3037}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Prophet allowed Sawdah to leave Jam (Al-Muzdalifah) before dawn because she was a heavyset woman}}
\hadithdefcmd{nasai}{3038}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى صَلاَةً قَطُّ إِلاَّ لِمِيقَاتِهَا إِلاَّ صَلاَةَ الْمَغْرِبِ وَالْعِشَاءِ صَلاَّهُمَا بِجَمْعٍ وَصَلاَةَ الْفَجْرِ يَوْمَئِذٍ قَبْلَ مِيقَاتِهَا ‏.‏\hadithno{3038}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abdullah said:"I never saw the Messenger of Allah offer any prayer except at the proper time, apart from Maghrib and Isha in Jam (Al-Muzdalifah) and Fajir on that day, which he offered before the usual time}}
\hadithdefcmd{nasai}{3039}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ، وَدَاوُدَ، وَزَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ مُضَرِّسٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَاقِفًا بِالْمُزْدَلِفَةِ فَقَالَ ‏ "‏ مَنْ صَلَّى مَعَنَا صَلاَتَنَا هَذِهِ هَا هُنَا ثُمَّ أَقَامَ مَعَنَا وَقَدْ وَقَفَ قَبْلَ ذَلِكَ بِعَرَفَةَ لَيْلاً أَوْ نَهَارًا فَقَدْ تَمَّ حَجُّهُ ‏"‏ ‏.‏\hadithno{3039}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Urwah bin Mudarris said:"I saw the Messenger of Allah stading in Al-Muzdalifah and he said: 'Whoever offers this prayer whith us here then stands with us and stood before that in Arafat by nightor by day, his Hajj is complete}}
\hadithdefcmd{nasai}{3040}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنِي جَرِيرٌ، عَنْ مُطَرِّفٍ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ مُضَرِّسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَدْرَكَ جَمْعًا مَعَ الإِمَامِ وَالنَّاسِ حَتَّى يُفِيضَ مِنْهَا فَقَدْ أَدْرَكَ الْحَجَّ وَمَنْ لَمْ يُدْرِكْ مَعَ النَّاسِ وَالإِمَامِ فَلَمْ يُدْرِكْ ‏"‏ ‏.‏\hadithno{3040}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Urwah bin Mudarris said:The Messenger of allah said: "Whoever catches up (with Fajir prayer) in Jam (Al-Muzdalifah) with the Imam and the people (and stays there) until they move on, the he has caught up with Hajj. Whoever does not catuch up with the people and the Imam, then has not caught it (Hajj)}}
\hadithdefcmd{nasai}{3041}{أَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ، قَالَ حَدَّثَنَا أُمَيَّةُ، عَنْ شُعْبَةَ، عَنْ سَيَّارٍ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ مُضَرِّسٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِجَمْعٍ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَقْبَلْتُ مِنْ جَبَلَىْ طَيِّئٍ لَمْ أَدَعْ حَبْلاً إِلاَّ وَقَفْتُ عَلَيْهِ فَهَلْ لِي مِنْ حَجٍّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى هَذِهِ الصَّلاَةَ مَعَنَا وَقَدْ وَقَفَ قَبْلَ ذَلِكَ بِعَرَفَةَ لَيْلاً أَوْ نَهَارًا فَقَدْ تَمَّ حَجُّهُ وَقَضَى تَفَثَهُ ‏"‏ ‏.‏\hadithno{3041}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Urwah bin Mudarris said:"I came to the Prohet in Jam (Al-Muzdalifah) and said: 'O Messenger of Allah, I have come from the two mountains of Tai and I did not leave any mountain but I stood on it; is there Hajj for me?' The Messenger of Allah said: 'Whoever offers this prayer with us, and stood before that in Arafatat by night or by day, his Hajj is complete, and he has completed the prescribed duties}}
\hadithdefcmd{nasai}{3042}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، قَالَ سَمِعْتُ الشَّعْبِيَّ، يَقُولُ حَدَّثَنِي عُرْوَةُ بْنُ مُضَرِّسِ بْنِ أَوْسِ بْنِ حَارِثَةَ بْنِ لأْمٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِجَمْعٍ فَقُلْتُ هَلْ لِي مِنْ حَجٍّ فَقَالَ ‏ "‏ مَنْ صَلَّى هَذِهِ الصَّلاَةَ مَعَنَا وَوَقَفَ هَذَا الْمَوْقِفَ حَتَّى يُفِيضَ وَأَفَاضَ قَبْلَ ذَلِكَ مِنْ عَرَفَاتٍ لَيْلاً أَوْ نَهَارًا فَقَدْ تَمَّ حَجُّهُ وَقَضَى تَفَثَهُ ‏"‏ ‏.‏\hadithno{3042}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Urwah bin Mudarris bin Aws bin Harithah bin La'm said:"I came to the Prophet in Jam (Al-Muzdalifah) and said: 'Is there Hajj for me?' He said: 'Whoever offers this prayer with us and observed this standing until he departed, and he departed before that from Arafat by night or by day, then his Hajj is complete. And he has completed the prescribed duties}}
\hadithdefcmd{nasai}{3043}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ أَخْبَرَنِي عَامِرٌ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ مُضَرِّسٍ الطَّائِيُّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ أَتَيْتُكَ مِنْ جَبَلَىْ طَيِّئٍ أَكْلَلْتُ مَطِيَّتِي وَأَتْعَبْتُ نَفْسِي مَا بَقِيَ مِنْ حَبْلٍ إِلاَّ وَقَفْتُ عَلَيْهِ فَهَلْ لِي مِنْ حَجٍّ فَقَالَ ‏ "‏ مَنْ صَلَّى صَلاَةَ الْغَدَاةِ هَا هُنَا مَعَنَا وَقَدْ أَتَى عَرَفَةَ قَبْلَ ذَلِكَ فَقَدْ قَضَى تَفَثَهُ وَتَمَّ حَجُّهُ ‏"‏ ‏.‏\hadithno{3043}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Urwah bin Mudarris at Tai said:"I came to the Messenger of Allah and said: "I have come to you from the two mountains of Tai and I have exhausted my camel, and exhausted myself; is there Hajj for me?' He said: 'Whoever offeres this morning prayer with us here, and came to Arafat before that, then he has completed the prescribed duties and his Hajj is complete}}
\hadithdefcmd{nasai}{3044}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي بُكَيْرُ بْنُ عَطَاءٍ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَعْمَرَ الدِّيلِيَّ، قَالَ شَهِدْتُ النَّبِيَّ صلى الله عليه وسلم بِعَرَفَةَ وَأَتَاهُ نَاسٌ مِنْ نَجْدٍ فَأَمَرُوا رَجُلاً فَسَأَلَهُ عَنِ الْحَجِّ فَقَالَ ‏"‏ الْحَجُّ عَرَفَةُ مَنْ جَاءَ لَيْلَةَ جَمْعٍ قَبْلَ صَلاَةِ الصُّبْحِ فَقَدْ أَدْرَكَ حَجَّهُ أَيَّامُ مِنًى ثَلاَثَةُ أَيَّامٍ ‏\{‏ مَنْ تَعَجَّلَ فِي يَوْمَيْنِ فَلاَ إِثْمَ عَلَيْهِ وَمَنْ تَأَخَّرَ فَلاَ إِثْمَ عَلَيْهِ ‏\}‏ ‏"‏ ‏.‏ ثُمَّ أَرْدَفَ رَجُلاً فَجَعَلَ يُنَادِي بِهَا فِي النَّاسِ ‏.‏\hadithno{3044}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur Rahman bin Yamur Ad-Daili said:"I saw the prophet in Arafat when some people from Najd coame to him. They told a man to ask him about Hajj. He said: "Hajj is Arafat. Whoever comes on the night of Jam (Al-Muzdalifah) before Subh prayer, then he has caought up with Hajj. And the days of Mina are three days. But whoever hastens to leave in two days, there is no sion on him, and whoever stays on, there is no sino on him.' Then he made a man ride behind him, and he started proclaiming it to the people}}
\hadithdefcmd{nasai}{3045}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، أَتَيْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُزْدَلِفَةُ كُلُّهَا مَوْقِفٌ ‏"‏ ‏.‏\hadithno{3045}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jafar bin Muahammad narrated that his father said:"We came to Jabir bin Abdullah and he told us that the Messenger of Allah said: 'All of Al Muzdalifah is a place for (the pilgrims) to stand}}
\hadithdefcmd{nasai}{3046}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، فِي حَدِيثِهِ عَنْ أَبِي الأَحْوَصِ، عَنْ حُصَيْنٍ، عَنْ كَثِيرٍ، - وَهُوَ ابْنُ مُدْرِكٍ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ قَالَ ابْنُ مَسْعُودٍ وَنَحْنُ بِجَمْعٍ سَمِعْتُ الَّذِي، أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ يَقُولُ فِي هَذَا الْمَكَانِ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ ‏"‏ ‏.‏\hadithno{3046}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abdur-Rahman bin Yazid said:"When we were in Jam (Al-Muzadalifah), Ibn Masud said: 'I heard the one to whoem surat Al-Baqarah was revealed say, in this place: Labbaik Allahumma Labbaik}}
\hadithdefcmd{nasai}{3047}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ سَمِعْتُهُ يَقُولُ شَهِدْتُ عُمَرَ بِجَمْعٍ فَقَالَ إِنَّ أَهْلَ الْجَاهِلِيَّةِ كَانُوا لاَ يُفِيضُونَ حَتَّى تَطْلُعَ الشَّمْسُ وَيَقُولُونَ أَشْرِقْ ثَبِيرُ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَالَفَهُمْ ثُمَّ أَفَاضَ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ ‏.‏\hadithno{3047}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Amr bin Maimun aid:"I head him say 'I saw 'Umar in Al-Muzdalifah and he said: The people of the Jahiliyyah would not depart until the sun had risen, and they would say: Shine, O Thabir! The Messenger of Allah differed from them and departed before the sun had risen}}
\hadithdefcmd{nasai}{3048}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ أَشْهَبَ، أَنَّ دَاوُدَ بْنَ عَبْدِ الرَّحْمَنِ، حَدَّثَهُمْ أَنَّ عَمْرَو بْنَ دِينَارٍ حَدَّثَهُ أَنَّ عَطَاءَ بْنَ أَبِي رَبَاحٍ حَدَّثَهُمْ أَنَّهُ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ أَرْسَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ضَعَفَةِ أَهْلِهِ فَصَلَّيْنَا الصُّبْحَ بِمِنًى وَرَمَيْنَا الْجَمْرَةَ ‏.‏\hadithno{3048}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ata bin Abi Rabah told them that he heard Ibn Abbas say:"The Messenger of Allah sent me with the weak ones of his family to pray Subh in Mina and stone the Jamrah}}
\hadithdefcmd{nasai}{3049}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ بْنِ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ أُمِّ الْمُؤْمِنِينَ، عَائِشَةَ قَالَتْ وَدِدْتُ أَنِّي اسْتَأْذَنْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا اسْتَأْذَنَتْهُ سَوْدَةُ فَصَلَّيْتُ الْفَجْرَ بِمِنًى قَبْلَ أَنْ يَأْتِيَ النَّاسُ وَكَانَتْ سَوْدَةُ امْرَأَةً ثَقِيلَةً ثَبِطَةً فَاسْتَأْذَنَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَذِنَ لَهَا فَصَلَّتِ الْفَجْرَ بِمِنًى وَرَمَتْ قَبْلَ أَنْ يَأْتِيَ النَّاسُ ‏.‏\hadithno{3049}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that the Mother of the Belivers Aishah said:"I wished that I had asked the Messenger of Allah for permission as Sawdha did, so that I could pray Fajir in Mina before the people came. Sawdah was heavyset woman, so she asked the Messenger of Allah for permission, and he gave her permission to pray Fajir in Mina and stone the before the people came}}
\hadithdefcmd{nasai}{3050}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّ مَوْلًى، لأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ أَخْبَرَهُ قَالَ جِئْتُ مَعَ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ مِنًى بِغَلَسٍ فَقُلْتُ لَهَا لَقَدْ جِئْنَا مِنًى بِغَلَسٍ ‏.‏ فَقَالَتْ قَدْ كُنَّا نَصْنَعُ هَذَا مَعَ مَنْ هُوَ خَيْرٌ مِنْكَ ‏.‏\hadithno{3050}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ata bin Abi Rabah that a freed slave of Asma bin Abi Bakr told him:"I came with Asma bint Abi Bakr to Mina at the end of the night and I said to her: 'We have come to Mina at the end of the night.' She said: 'We sued to do this one who was better than you}}
\hadithdefcmd{nasai}{3051}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةُ، عَنْ أَبِيهِ، قَالَ سُئِلَ أُسَامَةُ بْنُ زَيْدٍ وَأَنَا جَالِسٌ، مَعَهُ كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسِيرُ فِي حَجَّةِ الْوَدَاعِ حِينَ دَفَعَ قَالَ كَانَ يُسَيِّرُ نَاقَتَهُ فَإِذَا وَجَدَ فَجْوَةً نَصَّ ‏.‏\hadithno{3051}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated form Hisham bin Urwah that his father said:"Usamah bin Zaid was asked - while I was sitting with him: 'How did the Messenger of Allah travel during the Farewell Pilgrimage when he moved on?' He said: 'He rode at a moderate pace, and if he found some open space, he would gallop}}
\hadithdefcmd{nasai}{3052}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ أَبِي مَعْبَدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلنَّاسِ حِينَ دَفَعُوا عَشِيَّةَ عَرَفَةَ وَغَدَاةَ جَمْعٍ ‏"‏ عَلَيْكُمْ بِالسَّكِينَةِ ‏"‏ ‏.‏ وَهُوَ كَافٌّ نَاقَتَهُ حَتَّى إِذَا دَخَلَ مِنًى فَهَبَطَ حِينَ هَبَطَ مُحَسِّرًا قَالَ ‏"‏ عَلَيْكُمْ بِحَصَى الْخَذْفِ الَّذِي يُرْمَى بِهِ الْجَمْرَةُ ‏"‏ ‏.‏ وَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يُشِيرُ بِيَدِهِ كَمَا يَخْذِفُ الإِنْسَانُ ‏.‏\hadithno{3052}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Al-Fadl bin Abbas said:"The Messenger of Allah said to the people when they moved on the evening of Arafat and the morning of Jam' (assembly at Al-Muzdalifah): 'You must have tranquility.' He was reining in his camel, and when he entered Mina, he came down to Muhassir and said: 'You have to pick up pebbles the size of date stones of fingertips with which to stone the Jamrat.' And he (Al-Fadl) said: 'And the Prophet gestured with his hand like a man throwing a pebble}}
\hadithdefcmd{nasai}{3053}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَوْضَعَ فِي وَادِي مُحَسِّرٍ ‏.‏\hadithno{3053}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:the Prophet hurried in the valley of Muhassir}}
\hadithdefcmd{nasai}{3054}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، قَالَ دَخَلْنَا عَلَى جَابِرِ بْنِ عَبْدِ اللَّهِ فَقُلْتُ أَخْبِرْنِي عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم ‏.‏ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَفَعَ مِنَ الْمُزْدَلِفَةِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ وَأَرْدَفَ الْفَضْلَ بْنَ الْعَبَّاسِ حَتَّى أَتَى مُحَسِّرًا حَرَّكَ قَلِيلاً ثُمَّ سَلَكَ الطَّرِيقَ الْوُسْطَى الَّتِي تُخْرِجُكَ عَلَى الْجَمْرَةِ الْكُبْرَى حَتَّى أَتَى الْجَمْرَةَ الَّتِي عِنْدَ الشَّجَرَةِ فَرَمَى بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ مِنْهَا حَصَى الْخَذْفِ رَمَى مِنْ بَطْنِ الْوَادِي ‏.‏\hadithno{3054}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jafar bin Muhamad narrated that hi father said:"We enterd upon Jabir bin Abdullah and I said: "Tell me about the Hajj of the Prophet.' He said: 'The Messenger of Allah moved on from Al-Muzadalifah before the sun rose, and Al-Fadl bin Abbas rode behind him. When he came to Muhassir he sped up a little, then he follwed the middle road that brings you out at the largest Jamrat. When he came to the Jamrat whichis by the tree, he threw seven pebbles, saying the Takbir with each one, (using) pebbles the size of the date stones of fingertips, and he threw from the bottom of the valley}}
\hadithdefcmd{nasai}{3055}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ، - وَهُوَ ابْنُ حَبِيبٍ - عَنْ عَبْدِ الْمَلِكِ بْنِ جُرَيْجٍ، وَعَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، أَنَّهُ كَانَ رَدِيفَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَزَلْ يُلَبِّي حَتَّى رَمَى الْجَمْرَةَ ‏.‏\hadithno{3055}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Al-Fadl bin abbas that:he was riding behind the Prophet and he continued to recite the Talbiyah until he stoned the Jamrat}}
\hadithdefcmd{nasai}{3056}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَبَّى حَتَّى رَمَى الْجَمْرَةَ ‏.‏\hadithno{3056}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abbas that:the Messenger of Allah recited the Talbiyah unitl he stoned the Jamrat}}
\hadithdefcmd{nasai}{3057}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا عَوْفٌ، قَالَ حَدَّثَنَا زِيَادُ بْنُ حُصَيْنٍ، عَنْ أَبِي الْعَالِيَةِ، قَالَ قَالَ ابْنُ عَبَّاسٍ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم غَدَاةَ الْعَقَبَةِ وَهُوَ عَلَى رَاحِلَتِهِ ‏"‏ هَاتِ الْقُطْ لِي ‏"‏ ‏.‏ فَلَقَطْتُ لَهُ حَصَيَاتٍ هُنَّ حَصَى الْخَذْفِ فَلَمَّا وَضَعْتُهُنَّ فِي يَدِهِ قَالَ بِأَمْثَالِ هَؤُلاَءِ ‏"‏ وَإِيَّاكُمْ وَالْغُلُوَّ فِي الدِّينِ فَإِنَّمَا أَهْلَكَ مَنْ كَانَ قَبْلَكُمُ الْغُلُوُّ فِي الدِّينِ ‏"‏ ‏.‏\hadithno{3057}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Al-Aliyah said:"Ibn Abbas said: "On the morning of Al-Aqabah, while he was on his mount, the Messenger of Allah said to me: "Pick up (some pebbles) for me." So I picked up some pebbles for him that were the size of date stones or fingertips, and when I placed them in his hand he said: "Like these. And beware of going to extremes in religious matters, for those who came before you were destroyed because of going to extremes in religious matters}}
\hadithdefcmd{nasai}{3058}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ أَبِي مَعْبَدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلنَّاسِ حِينَ دَفَعُوا عَشِيَّةَ عَرَفَةَ وَغَدَاةَ جَمْعٍ ‏"‏ عَلَيْكُمْ بِالسَّكِينَةِ ‏"‏ ‏.‏ وَهُوَ كَافٌّ نَاقَتَهُ حَتَّى إِذَا دَخَلَ مِنًى فَهَبَطَ حِينَ هَبَطَ مُحَسِّرًا قَالَ ‏"‏ عَلَيْكُمْ بِحَصَى الْخَذْفِ الَّذِي تُرْمَى بِهِ الْجَمْرَةُ ‏"‏ ‏.‏ قَالَ وَالنَّبِيُّ صلى الله عليه وسلم يُشِيرُ بِيَدِهِ كَمَا يَخْذِفُ الإِنْسَانُ ‏.‏\hadithno{3058}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Fadl bin Abbas said:"The Messenger of Allah said to the people when they moved on the evening of Arafat and the morning of Jam' (assembly at Al-Muzdalifah): 'You must have tranquility.' He was reining in his camel, and when he entered Mina, he came down to Muhassir and said: 'You have to pick up pebbles the size of date stones of fingertips with which to stone the Jamrat.' And he (Al-Fadl) said: 'And the Prophet gestured with his hand like a man throwing a pebble}}
\hadithdefcmd{nasai}{3059}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عَوْفٌ، قَالَ حَدَّثَنَا زِيَادُ بْنُ حُصَيْنٍ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَدَاةَ الْعَقَبَةِ وَهُوَ وَاقِفٌ عَلَى رَاحِلَتِهِ ‏ "‏ هَاتِ الْقُطْ لِي ‏"‏ ‏.‏ فَلَقَطْتُ لَهُ حَصَيَاتٍ هُنَّ حَصَى الْخَذْفِ فَوَضَعْتُهُنَّ فِي يَدِهِ وَجَعَلَ يَقُولُ بِهِنَّ فِي يَدِهِ وَوَصَفَ يَحْيَى تَحْرِيكَهُنَّ فِي يَدِهِ بِأَمْثَالِ هَؤُلاَءِ ‏.‏\hadithno{3059}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abbas said:"On the morning of Al-Aqabah, while he was on his mount, the Messenger of Allh said: 'Pick up (some pebbles) for me.' So P picked up some pebbles for him that were the size of date stones of fingertips, and placed them in his hand. He started to do this with his hand." Yahya described him shaking them in his hand like this}}
\hadithdefcmd{nasai}{3060}{أَخْبَرَنِي عَمْرُو بْنُ هِشَامٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ يَحْيَى بْنِ الْحُصَيْنِ، عَنْ جَدَّتِهِ أُمِّ حُصَيْنٍ، قَالَتْ حَجَجْتُ فِي حَجَّةِ النَّبِيِّ صلى الله عليه وسلم فَرَأَيْتُ بِلاَلاً يَقُودُ بِخِطَامِ رَاحِلَتِهِ وَأُسَامَةَ بْنَ زَيْدٍ رَافِعٌ عَلَيْهِ ثَوْبَهُ يُظِلُّهُ مِنَ الْحَرِّ وَهُوَ مُحْرِمٌ حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ ثُمَّ خَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَذَكَرَ قَوْلاً كَثِيرًا ‏.‏\hadithno{3060}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Yajya bin Al-Husain that his grandmother, Umm Husain said:"I perfomed Hajj during the Hajj of the Prophet. I saw Bilal hodling on the reins of his she-camel, and Usmah bin Zaid hodling his garment ouver him to shade him from the heat, while he was in Ihram, until he had stoned Jamratual Aqabah. Then he addressed the people and praised Allahy, and mentioned many things}}
\hadithdefcmd{nasai}{3061}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا أَيْمَنُ بْنُ نَابِلٍ، عَنْ قُدَامَةَ بْنِ عَبْدِ اللَّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْمِي جَمْرَةَ الْعَقَبَةِ يَوْمَ النَّحْرِ عَلَى نَاقَةٍ لَهُ صَهْبَاءَ لاَ ضَرْبَ وَلاَ طَرْدَ وَلاَ إِلَيْكَ إِلَيْكَ ‏.‏\hadithno{3061}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Qudamah bin Abdullah said:"I saw the Messenger of Allah stoning JamratualAqabah on the Day of Sacrifice on the reddish-brown camel of his, without beating anyone or driving them off}}
\hadithdefcmd{nasai}{3062}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْمِي الْجَمْرَةَ وَهُوَ عَلَى بَعِيرِهِ وَهُوَ يَقُولُ ‏ "‏ يَا أَيُّهَا النَّاسُ خُذُوا مَنَاسِكَكُمْ فَإِنِّي لاَ أَدْرِي لَعَلِّي لاَ أَحُجُّ بَعْدَ عَامِي هَذَا ‏"‏ ‏.‏\hadithno{3062}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Az-Zubair narrated that he heard Jabir bin Abdullah say:"I saw the Messneger of Allah stone the Jamrat while on his camel saying: "O people, learn your rituals (of Hajj) for I do not know whether I will perform Hajj again after this year}}
\hadithdefcmd{nasai}{3063}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ بْنِ إِبْرَاهِيمَ الثَّقَفِيُّ الْمَرْوَزِيُّ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ رَمَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْجَمْرَةَ يَوْمَ النَّحْرِ ضُحًى وَرَمَى بَعْدَ يَوْمِ النَّحْرِ إِذَا زَالَتِ الشَّمْسُ ‏.‏\hadithno{3063}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah stoned the Jamrat on the Day of Sacrifice in the forenoon, and after the Day of Sacrifice he stoned (the Jamarat) When the sun had passed its zenith}}
\hadithdefcmd{nasai}{3064}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنِ الْحَسَنِ الْعُرَنِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أُغَيْلِمَةَ بَنِي عَبْدِ الْمُطَّلِبِ عَلَى حُمُرَاتٍ يَلْطَحُ أَفْخَاذَنَا وَيَقُولُ ‏ "‏ أُبَيْنِيَّ لاَ تَرْمُوا جَمْرَةَ الْعَقَبَةِ حَتَّى تَطْلُعَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{3064}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger ofAllah sent us young boys of Banu Abdul-Muttalib on donkeys, stalping our things and saying "O my sons, do not stone Jamratulal Aqabah until the sun has risen. (Daif)}}
\hadithdefcmd{nasai}{3065}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدَّمَ أَهْلَهُ وَأَمَرَهُمْ أَنْ لاَ يَرْمُوا الْجَمْرَةَ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏\hadithno{3065}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas that:the Prophet sent his family ahead, and told them not to stone the Jamrah until the sun had risen. (Daif)}}
\hadithdefcmd{nasai}{3066}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الطَّائِفِيُّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، قَالَ حَدَّثَتْنِي عَائِشَةُ بِنْتُ طَلْحَةَ، عَنْ خَالَتِهَا، عَائِشَةَ أُمِّ الْمُؤْمِنِينَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ إِحْدَى نِسَائِهِ أَنْ تَنْفِرَ مِنْ جَمْعٍ لَيْلَةَ جَمْعٍ فَتَأْتِيَ جَمْرَةَ الْعَقَبَةِ فَتَرْمِيَهَا وَتُصْبِحَ فِي مَنْزِلِهَا ‏.‏ وَكَانَ عَطَاءٌ يَفْعَلُهُ حَتَّى مَاتَ ‏.‏\hadithno{3066}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah bint Tallah narrated from her maternal aunt Aishah the Mother of the Believers that:the Messenger of Allah told one of his wives to depart from Jam (Al-Muzadalifah) on the night of Jam, to go to Jamratual Aqabah and stone it, then come back to her camp before morning. And Ata used to do that until he died}}
\hadithdefcmd{nasai}{3067}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسْأَلُ أَيَّامَ مِنًى فَيَقُولُ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏ فَسَأَلَهُ رَجُلٌ فَقَالَ حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ رَمَيْتُ بَعْدَ مَا أَمْسَيْتُ ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3067}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn abbas said:"The Mesenger of Allah was asked questions during the days of Mina and he said: 'There is no harm.' A man said: 'I shaved my head before offering the sacrifice.' He said: 'There is no harm.' Another man said: 'I stoned (the Majarat) after evening came.' He said: "There is no harm}}
\hadithdefcmd{nasai}{3068}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي الْبَدَّاحِ بْنِ عَدِيٍّ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ لِلرُّعَاةِ أَنْ يَرْمُوا يَوْمًا وَيَدَعُوا يَوْمًا ‏.‏\hadithno{3068}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu al-Baddah bin'Adiyy, from father, that:the Prophet granted the camel herders a concession allowing them to stone the Jamrat on one day an not another}}
\hadithdefcmd{nasai}{3069}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا مَالِكٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي الْبَدَّاحِ بْنِ عَاصِمِ بْنِ عَدِيٍّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ لِلرُّعَاةِ فِي الْبَيْتُوتَةِ يَرْمُونَ يَوْمَ النَّحْرِ وَالْيَوْمَيْنِ اللَّذَيْنِ بَعْدَهُ يَجْمَعُونَهُمَا فِي أَحَدِهِمَا ‏.‏\hadithno{3069}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from al-Baddah bin Asim bin Adiyy from his father, that:the Messenger of Allah granted a concession to some camel herders, allowing them to not stay overnight in Mina, and allowing them to stone the Jimar on the Day of Sacrifice, then to combine the stoning of two days after sacrifice, so that they could do it on one of the two days}}
\hadithdefcmd{nasai}{3070}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُحَيَّاةَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عَبْدِ الرَّحْمَنِ، - يَعْنِي ابْنَ يَزِيدَ - قَالَ قِيلَ لِعَبْدِ اللَّهِ بْنِ مَسْعُودٍ إِنَّ نَاسًا يَرْمُونَ الْجَمْرَةَ مِنْ فَوْقِ الْعَقَبَةِ ‏.‏ قَالَ فَرَمَى عَبْدُ اللَّهِ مِنْ بَطْنِ الْوَادِي ثُمَّ قَالَ مِنْ هَا هُنَا وَالَّذِي لاَ إِلَهَ غَيْرُهُ رَمَى الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏\hadithno{3070}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abdur-Rahman - meaning bin Yazid - said:"It was said to Abdullah bin Masud that some people were stoning the Jamart from above al-Aqabah." He said: "So Abdullah stoned it from the bottom of the valley, then he said: 'From here - by the One beside Whom there is no other God - did the one to whom surat Al-Baqarah was revealed, stone it}}
\hadithdefcmd{nasai}{3071}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، وَمَالِكُ بْنُ الْخَلِيلِ، قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، وَمَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ رَمَى عَبْدُ اللَّهِ الْجَمْرَةَ بِسَبْعِ حَصَيَاتٍ جَعَلَ الْبَيْتَ عَنْ يَسَارِهِ وَعَرَفَةَ عَنْ يَمِينِهِ وَقَالَ هَا هُنَا مَقَامُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ مَا أَعْلَمُ أَحَدًا قَالَ فِي هَذَا الْحَدِيثِ مَنْصُورٌ غَيْرَ ابْنِ أَبِي عَدِيٍّ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{3071}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abdullah bin Yazid said:"Abdullah stoned the Jamrat with seven pebbles, with the House on his left and Arafat on his right. And he said: 'This is the place where the one to whom Surat al-Baqrah was revealed stood.'" (Sahih) Abu Abdur-Rahman (An-Nisai) said: I do not know of anyone who said: Mansur in this narration except Ibn Abi adi, and Allah most High knows best}}
\hadithdefcmd{nasai}{3072}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، عَنْ هُشَيْمٍ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ، قَالَ رَأَيْتُ ابْنَ مَسْعُودٍ رَمَى جَمْرَةَ الْعَقَبَةِ مِنْ بَطْنِ الْوَادِي ثُمَّ قَالَ هَا هُنَا وَالَّذِي لاَ إِلَهَ غَيْرُهُ مَقَامُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏\hadithno{3072}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur-Rahman bin Yazid said:"I sqa Ibn Masud stone Jamratul 'Aqabah from the bottom of the valley, then he said: ;This - by the One beside Whom there is no other God-is the place where the one to whom Surat Al-Baqarah was revealed stood}}
\hadithdefcmd{nasai}{3073}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا ابْنُ أَبِي زَائِدَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، سَمِعْتُ الْحَجَّاجَ، يَقُولُ لاَ تَقُولُوا سُورَةُ الْبَقَرَةِ قُولُوا السُّورَةُ الَّتِي يُذْكَرُ فِيهَا الْبَقَرَةُ ‏.‏ فَذَكَرْتُ ذَلِكَ لإِبْرَاهِيمَ فَقَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ أَنَّهُ كَانَ مَعَ عَبْدِ اللَّهِ حِينَ رَمَى جَمْرَةَ الْعَقَبَةِ فَاسْتَبْطَنَ الْوَادِيَ وَاسْتَعْرَضَهَا يَعْنِي الْجَمْرَةَ فَرَمَاهَا بِسَبْعِ حَصَيَاتٍ وَكَبَّرَ مَعَ كُلِّ حَصَاةٍ فَقُلْتُ إِنَّ أُنَاسًا يَصْعَدُونَ الْجَبَلَ ‏.‏ فَقَالَ هَا هُنَا وَالَّذِي لاَ إِلَهَ غَيْرُهُ رَأَيْتُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ رَمَى ‏.‏\hadithno{3073}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Al-A 'mash said :"I head Al-Hajjaj say: 'Do not say Surat Al-Baqarah, say: 'The Surah in which the cow (Al-Baqarah) is mentioned."' I mentioned that to Ibrahim, and he said: "Abdur-Rahman bi Yazdi told me, that he was with 'Abdullah when he stoned Jamratul 'Aqabah. He went down the middle of the valley, stood opposite it - meaning the Jamrah - and throew seven pebbiles at it, saying the Takbir with each pebble. I said; "Some people climbed the mountain." He said: "Here - by the One beside Whom there is no other God - is the place where the one to whom Surat Al-Baqarah was revelated stoned}}
\hadithdefcmd{nasai}{3074}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدِ الرَّحِيمِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، وَذَكَرَ، آخَرَ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَى الْجَمْرَةَ بِمِثْلِ حَصَى الْخَذْفِ ‏.‏\hadithno{3074}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir:That the Messenger of Allah stoned the Jamarat with pebbles like date sones or fingertips}}
\hadithdefcmd{nasai}{3075}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْمِي الْجِمَارَ بِمِثْلِ حَصَى الْخَذْفِ ‏.‏\hadithno{3075}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah stoned the Jamarat with pebbles like date sones or fingertips}}
\hadithdefcmd{nasai}{3076}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدِ بْنِ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ أَبِيهِ، قَالَ دَخَلْنَا عَلَى جَابِرِ بْنِ عَبْدِ اللَّهِ فَقُلْتُ أَخْبِرْنِي عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم ‏.‏ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَى الْجَمْرَةَ الَّتِي عِنْدَ الشَّجَرَةِ بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ مِنْهَا حَصَى الْخَذْفِ رَمَى مِنْ بَطْنِ الْوَادِي ثُمَّ انْصَرَفَ إِلَى الْمَنْحَرِ فَنَحَرَ ‏.‏\hadithno{3076}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jafar bin Muhammad bin 'Ali bin Husain narrated that his father said:"We entered upon Jabir bin 'Abdullah and I said: 'Tell me about the Hajj of the Prophet. He said: 'The Messenger of Allah stoned the Jamart which is by the tree, with seven pebbles, saying the Takbir with eeach pebble - pebbles that were the size of data stones or fingertips. And he threw them for the bottom of the valley, then he went to the place of sacrifice in Mina}}
\hadithdefcmd{nasai}{3077}{أَخْبَرَنِي يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، قَالَ قَالَ مُجَاهِدٌ قَالَ سَعْدٌ رَجَعْنَا فِي الْحَجَّةِ مَعَ النَّبِيِّ صلى الله عليه وسلم وَبَعْضُنَا يَقُولُ رَمَيْتُ بِسَبْعِ حَصَيَاتٍ وَبَعْضُنَا يَقُولُ رَمَيْتُ بِسِتٍّ فَلَمْ يَعِبْ بَعْضُهُمْ عَلَى بَعْضٍ ‏.‏\hadithno{3077}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Sad said:"We returned during the Hajj with the Prophet and some of us said that they had stoned (the Jamarat) with seven stones, and other said that they had done so with six, and no one denounced anyone else}}
\hadithdefcmd{nasai}{3078}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا مِجْلَزٍ، يَقُولُ سَأَلْتُ ابْنَ عَبَّاسٍ عَنْ شَىْءٍ، مِنْ أَمْرِ الْجِمَارِ فَقَالَ مَا أَدْرِي رَمَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسِتٍّ أَوْ بِسَبْعٍ ‏.‏\hadithno{3078}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated the Qatadah said:"I heard Abu Mijlaz say: 'I asked Ibn 'Abbas something about the Jimar, and he said: I do not know, the Messenger of Allah stoned it with six or seven}}
\hadithdefcmd{nasai}{3079}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ الْكُوفِيُّ، قَالَ حَدَّثَنَا حَفْصٌ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَخِيهِ الْفَضْلِ بْنِ عَبَّاسٍ، قَالَ كُنْتُ رِدْفَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَزَلْ يُلَبِّي حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ فَرَمَاهَا بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ ‏.‏\hadithno{3079}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that his brother Al-Fadl bin 'Abbas said:"I was riding behind the Prophet and he continued to recite the Talbiyah until he stoned Jamratul'Aqabah. He stoned it with seven pebbles, saying the Takbir with each throw}}
\hadithdefcmd{nasai}{3080}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ خُصَيْفٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ الْفَضْلُ بْنُ عَبَّاسٍ كُنْتُ رِدْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَا زِلْتُ أَسْمَعُهُ يُلَبِّي حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ فَلَمَّا رَمَى قَطَعَ التَّلْبِيَةَ ‏.‏\hadithno{3080}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Fadl bin 'Abbas said:"I was riding behind the Messenger of Allah and he continued to hear him reciting the Talbiyah until he stoned Jamratul 'Aqabah, then when he soned (the Jamrah) he stopped reciting the Talbiyah}}
\hadithdefcmd{nasai}{3081}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ بْنِ هِلاَلٍ، قَالَ حَدَّثَنَا حُسَيْنٌ، قَالَ حَدَّثَنَا أَبُو خَيْثَمَةَ، قَالَ حَدَّثَنَا خُصَيْفٌ، عَنْ مُجَاهِدٍ، وَعَطَاءٍ، وَسَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ الْفَضْلَ، أَخْبَرَهُ أَنَّهُ، كَانَ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَّهُ لَمْ يَزَلْ يُلَبِّي حَتَّى رَمَى الْجَمْرَةَ ‏.‏\hadithno{3081}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:Al-Fadl to him that he roed behind the Messenger of Allah and he continued to recited the Talbiyah until eh stoned the Jamrat}}
\hadithdefcmd{nasai}{3082}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ عَنْ عَلِيِّ بْنِ مَعْبَدٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ الْعَبَّاسِ، أَنَّهُ كَانَ رَدِيفَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَزَلْ يُلَبِّي حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ ‏.‏\hadithno{3082}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Al-Fadl bin 'Abbas that:he was riding behind the Prophet and he continued recite the Talbiyah until he stoned Jamratul Aqabah}}
\hadithdefcmd{nasai}{3083}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ أَنْبَأَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا رَمَى الْجَمْرَةَ الَّتِي تَلِي الْمَنْحَرَ مَنْحَرَ مِنًى رَمَاهَا بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ كُلَّمَا رَمَى بِحَصَاةٍ ثُمَّ تَقَدَّمَ أَمَامَهَا فَوَقَفَ مُسْتَقْبِلَ الْقِبْلَةِ رَافِعًا يَدَيْهِ يَدْعُو يُطِيلُ الْوُقُوفَ ثُمَّ يَأْتِي الْجَمْرَةَ الثَّانِيَةَ فَيَرْمِيهَا بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ كُلَّمَا رَمَى بِحَصَاةٍ ثُمَّ يَنْحَدِرُ ذَاتَ الشِّمَالِ فَيَقِفُ مُسْتَقْبِلَ الْبَيْتِ رَافِعًا يَدَيْهِ يَدْعُو ثُمَّ يَأْتِي الْجَمْرَةَ الَّتِي عِنْدَ الْعَقَبَةِ فَيَرْمِيهَا بِسَبْعِ حَصَيَاتٍ وَلاَ يَقِفُ عِنْدَهَا ‏.‏ قَالَ الزُّهْرِيُّ سَمِعْتُ سَالِمًا يُحَدِّثُ بِهَذَا عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَانَ ابْنُ عُمَرَ يَفْعَلُهُ ‏.‏\hadithno{3083}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Az-Zuhri said:"We heard that when the Messenger of Allah stoned the Jamrah he stoned it with seven pebbles, saying the Takbir every time he threw a pebble. Then he came in front of it ans stood facing the Qiblah, raising his hands and supplicating fro a long time. Then he came to the second Jamrah and stoned it stoned it with seven pebbles, saying the Takbir every time he threw a pebble. Then he moved to the left and stood facing the Qiblah, raising his hands and supplicating for a long time. Then he came to the Jamrat that is at al 'Aqabah and stoned ti with seven pebbles, but he did not stand there." Az-Zuhri said: "I heard Salim narrted this from his father, from the Prophetk and Ibn'Umar used to do that}}
\hadithdefcmd{nasai}{3084}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنِ الْحَسَنِ الْعُرَنِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِذَا رَمَى الْجَمْرَةَ فَقَدْ حَلَّ لَهُ كُلُّ شَىْءٍ إِلاَّ النِّسَاءَ ‏.‏ قِيلَ وَالطِّيبُ قَالَ أَمَّا أَنَا فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَضَمَّخُ بِالْمِسْكِ أَفَطِيبٌ هُوَ\hadithno{3084}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ib 'Abbas said:"When (the pilgrim) has stoned hthe Jamrat, everything becomes permissible for him except (intimacy with) women," It was said: "And perfume?" he said; "I saw the Messenger of Allah smelling strongly of musk - is it not a perfume?}}
