% Auto-generated chapter 42 for abudawud
% Hadiths in this chapter: 177

\hadithdefcmd{abudawud}{4596}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ افْتَرَقَتِ الْيَهُودُ عَلَى إِحْدَى أَوْ ثِنْتَيْنِ وَسَبْعِينَ فِرْقَةً وَتَفَرَّقَتِ النَّصَارَى عَلَى إِحْدَى أَوْ ثِنْتَيْنِ وَسَبْعِينَ فِرْقَةً وَتَفْتَرِقُ أُمَّتِي عَلَى ثَلاَثٍ وَسَبْعِينَ فِرْقَةً ‏"‏ ‏.‏\hadithno{4596}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The Jews were split up into seventy-one or seventy-two sects; and the Christians were split up into seventy one or seventy-two sects; and my community will be split up into seventy-three sects}}
\hadithdefcmd{abudawud}{4597}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا صَفْوَانُ، ح وَحَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنِي صَفْوَانُ، نَحْوَهُ قَالَ حَدَّثَنِي أَزْهَرُ بْنُ عَبْدِ اللَّهِ الْحَرَازِيُّ، عَنْ أَبِي عَامِرٍ الْهَوْزَنِيِّ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، أَنَّهُ قَامَ فِينَا فَقَالَ أَلاَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فِينَا فَقَالَ ‏"‏ أَلاَ إِنَّ مَنْ قَبْلَكُمْ مِنْ أَهْلِ الْكِتَابِ افْتَرَقُوا عَلَى ثِنْتَيْنِ وَسَبْعِينَ مِلَّةً وَإِنَّ هَذِهِ الْمِلَّةَ سَتَفْتَرِقُ عَلَى ثَلاَثٍ وَسَبْعِينَ ثِنْتَانِ وَسَبْعُونَ فِي النَّارِ وَوَاحِدَةٌ فِي الْجَنَّةِ وَهِيَ الْجَمَاعَةُ ‏"‏ ‏.‏ زَادَ ابْنُ يَحْيَى وَعَمْرٌو فِي حَدِيثَيْهِمَا ‏"‏ وَإِنَّهُ سَيَخْرُجُ مِنْ أُمَّتِي أَقْوَامٌ تَجَارَى بِهِمْ تِلْكَ الأَهْوَاءُ كَمَا يَتَجَارَى الْكَلْبُ لِصَاحِبِهِ ‏"‏ ‏.‏ وَقَالَ عَمْرٌو ‏"‏ الْكَلْبُ بِصَاحِبِهِ لاَ يَبْقَى مِنْهُ عِرْقٌ وَلاَ مَفْصِلٌ إِلاَّ دَخَلَهُ ‏"‏ ‏.‏\hadithno{4597}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu `Amir al-Hawdhani said:Mu`awiyah b. Abi Sufiyan stood among us and said: Beware! The Apostle of Allah (ﷺ) stood among us and said: Beware! The people of the Book before were split up into seventy two sects, and this community will be split into seventy three: seventy two of them will go to Hell and one of them will go to Paradise, and it is the majority group. Ibn Yahya and `Amr added in their version : “ There will appear among my community people who will be dominated by desires like rabies which penetrates its patient”, `Amr’s version has: “penetrates its patient. There remains no vein and no joint but it penetrates it.”}}
\hadithdefcmd{abudawud}{4598}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا يَزِيدُ بْنُ إِبْرَاهِيمَ التُّسْتَرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَذِهِ الآيَةَ ‏\{‏ هُوَ الَّذِي أَنْزَلَ عَلَيْكَ الْكِتَابَ مِنْهُ آيَاتٌ مُحْكَمَاتٌ ‏\}‏ إِلَى ‏\{‏ أُولُو الأَلْبَابِ ‏\}‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِذَا رَأَيْتُمُ الَّذِينَ يَتَّبِعُونَ مَا تَشَابَهَ مِنْهُ فَأُولَئِكَ الَّذِينَ سَمَّى اللَّهُ فَاحْذَرُوهُمْ ‏"‏ ‏.‏\hadithno{4598}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4547) Sahih Muslim (2665)}\hadithtrans{‘A’ishah said:The Messenger of Allah (ﷺ) recited this verse: “He it is who has sent down to thee the Book: in it are verses basic or fundamental . . . .” Up to “men of understanding”. She said: The Messenger of Allah (ﷺ) then said: When you see those people who follow that which is allegorical in the Quran, those are the people whom Allah has named (in the Quran). So avoid them}}
\hadithdefcmd{abudawud}{4599}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ رَجُلٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الأَعْمَالِ الْحُبُّ فِي اللَّهِ وَالْبُغْضُ فِي اللَّهِ ‏"‏ ‏.‏\hadithno{4599}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuDharr: The Prophet (ﷺ) said: The best of the actions is to love for the sake of Allah and to hate for the sake of Allah}}
\hadithdefcmd{abudawud}{4600}{حَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ فَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، - وَكَانَ قَائِدَ كَعْبٍ مِنْ بَنِيهِ حِينَ عَمِيَ - قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، - وَذَكَرَ ابْنُ السَّرْحِ قِصَّةَ تَخَلُّفِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ - قَالَ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُسْلِمِينَ عَنْ كَلاَمِنَا أَيُّهَا الثَّلاَثَةُ حَتَّى إِذَا طَالَ عَلَىَّ تَسَوَّرْتُ جِدَارَ حَائِطِ أَبِي قَتَادَةَ وَهُوَ ابْنُ عَمِّي فَسَلَّمْتُ عَلَيْهِ فَوَاللَّهِ مَا رَدَّ عَلَىَّ السَّلاَمَ ‏.‏ ثُمَّ سَاقَ خَبَرَ تَنْزِيلِ تَوْبَتِهِ ‏.‏\hadithno{4600}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4676) Sahih Muslim (2769)}\hadithtrans{‘Abd Allah b. Ka`b b. Malik who used to lead his father from among his sons when he became blind, said:I heard Ka`b b. Malik - the transmitter Ibn al-Sarh then narrated the story of his remaining behind from the Prophet (ﷺ) during the campaign of Tabuk - say: The Messenger of Allah (ﷺ) forbade the Muslims to speak to any of us three. When (in this state) abundant time passed on me, I ascended the wall of the garden of Abu Qatadah who was my cousin. I saluted him, but, I swear by Allah, he did not return salute to me. He then narrated the story of the revelation of the Qur’anic verses relating to his repentance}}
\hadithdefcmd{abudawud}{4601}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَطَاءٌ الْخُرَاسَانِيُّ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، قَالَ قَدِمْتُ عَلَى أَهْلِي وَقَدْ تَشَقَّقَتْ يَدَاىَ فَخَلَّقُونِي بِزَعْفَرَانٍ فَغَدَوْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ فَلَمْ يَرُدَّ عَلَىَّ وَقَالَ ‏ "‏ اذْهَبْ فَاغْسِلْ هَذَا عَنْكَ ‏"‏ ‏.‏\hadithno{4601}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{‘Ammar b. Yasir said:I came to my family when my hands had cracks. They dyed me with saffron. I then went to Prophet (ﷺ) and saluted him, but he did not return me salutation. He said: Go and wash it away from you}}
\hadithdefcmd{abudawud}{4602}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ سُمَيَّةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّهُ اعْتَلَّ بَعِيرٌ لِصَفِيَّةَ بِنْتِ حُيَىٍّ وَعِنْدَ زَيْنَبَ فَضْلُ ظَهْرٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِزَيْنَبَ ‏ "‏ أَعْطِيهَا بَعِيرًا ‏"‏ ‏.‏ فَقَالَتْ أَنَا أُعْطِي تِلْكَ الْيَهُودِيَّةَ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَهَجَرَهَا ذَا الْحِجَّةَ وَالْمُحَرَّمَ وَبَعْضَ صَفَرٍ ‏.‏\hadithno{4602}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘A’ishah said:The camel of Safiyyah daughter of Huyayy was fatigued, and Zainab had a surplus mount. The Messenger of Allah (ﷺ) said to Zainab : Give her the camel. She said: Should I give to that Jewess? Thereupon the Messenger of Allah (ﷺ) became angry and kept away from her during Dhu al-Hijjah, Muharram, and a part of Safar}}
\hadithdefcmd{abudawud}{4603}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ هَارُونَ - أَخْبَرَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمِرَاءُ فِي الْقُرْآنِ كُفْرٌ ‏"‏ ‏.‏\hadithno{4603}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Controverting about the Qur'an is disbelief}}
\hadithdefcmd{abudawud}{4604}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا أَبُو عَمْرِو بْنُ كَثِيرِ بْنِ دِينَارٍ، عَنْ حَرِيزِ بْنِ عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَوْفٍ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ أَلاَ إِنِّي أُوتِيتُ الْكِتَابَ وَمِثْلَهُ مَعَهُ أَلاَ يُوشِكُ رَجُلٌ شَبْعَانُ عَلَى أَرِيكَتِهِ يَقُولُ عَلَيْكُمْ بِهَذَا الْقُرْآنِ فَمَا وَجَدْتُمْ فِيهِ مِنْ حَلاَلٍ فَأَحِلُّوهُ وَمَا وَجَدْتُمْ فِيهِ مِنْ حَرَامٍ فَحَرِّمُوهُ أَلاَ لاَ يَحِلُّ لَكُمْ لَحْمُ الْحِمَارِ الأَهْلِيِّ وَلاَ كُلُّ ذِي نَابٍ مِنَ السَّبُعِ وَلاَ لُقَطَةُ مُعَاهِدٍ إِلاَّ أَنْ يَسْتَغْنِيَ عَنْهَا صَاحِبُهَا وَمَنْ نَزَلَ بِقَوْمٍ فَعَلَيْهِمْ أَنْ يَقْرُوهُ فَإِنْ لَمْ يَقْرُوهُ فَلَهُ أَنْ يُعْقِبَهُمْ بِمِثْلِ قِرَاهُ ‏"‏ ‏.‏\hadithno{4604}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Miqdam ibn Ma'dikarib: The Prophet (ﷺ) said: Beware! I have been given the Qur'an and something like it, yet the time is coming when a man replete on his couch will say: Keep to the Qur'an; what you find in it to be permissible treat as permissible, and what you find in it to be prohibited treat as prohibited. Beware! The domestic ass, beasts of prey with fangs, a find belonging to confederate, unless its owner does not want it, are not permissible to you If anyone comes to some people, they must entertain him, but if they do not, he has a right to mulct them to an amount equivalent to his entertainment}}
\hadithdefcmd{abudawud}{4605}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي النَّضْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ مُتَّكِئًا عَلَى أَرِيكَتِهِ يَأْتِيهِ الأَمْرُ مِنْ أَمْرِي مِمَّا أَمَرْتُ بِهِ أَوْ نَهَيْتُ عَنْهُ فَيَقُولُ لاَ نَدْرِي مَا وَجَدْنَا فِي كِتَابِ اللَّهِ اتَّبَعْنَاهُ ‏"‏ ‏.‏\hadithno{4605}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuRafi': The Prophet (ﷺ) said: Let me not find one of you reclining on his couch when he hears something regarding me which I have commanded or forbidden and saying: We do not know. What we found in Allah's Book we have followed}}
\hadithdefcmd{abudawud}{4606}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمَخْرَمِيُّ، وَإِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَحْدَثَ فِي أَمْرِنَا هَذَا مَا لَيْسَ فِيهِ فَهُوَ رَدٌّ ‏"‏ ‏.‏ قَالَ ابْنُ عِيسَى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ صَنَعَ أَمْرًا عَلَى غَيْرِ أَمْرِنَا فَهُوَ رَدٌّ ‏"‏ ‏.‏\hadithno{4606}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2697) Sahih Muslim (1718)}\hadithtrans{A'ishah reported the Messenger of Allah (ﷺ) as saying:If any one introduces into this affair of ours anything which does not belong to it, it is rejected. Ibn `Isa said: The Prophet (ﷺ) said: If anyone practices any action in a way other than our practice, it is rejected}}
\hadithdefcmd{abudawud}{4607}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، قَالَ حَدَّثَنِي خَالِدُ بْنُ مَعْدَانَ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو السُّلَمِيُّ، وَحُجْرُ بْنُ حُجْرٍ، قَالاَ أَتَيْنَا الْعِرْبَاضَ بْنَ سَارِيَةَ وَهُوَ مِمَّنْ نَزَلَ فِيهِ ‏\{‏ وَلاَ عَلَى الَّذِينَ إِذَا مَا أَتَوْكَ لِتَحْمِلَهُمْ قُلْتَ لاَ أَجِدُ مَا أَحْمِلُكُمْ عَلَيْهِ ‏\}‏ فَسَلَّمْنَا وَقُلْنَا أَتَيْنَاكَ زَائِرِينَ وَعَائِدِينَ وَمُقْتَبِسِينَ ‏.‏ فَقَالَ الْعِرْبَاضُ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ ثُمَّ أَقْبَلَ عَلَيْنَا فَوَعَظَنَا مَوْعِظَةً بَلِيغَةً ذَرَفَتْ مِنْهَا الْعُيُونُ وَوَجِلَتْ مِنْهَا الْقُلُوبُ فَقَالَ قَائِلٌ يَا رَسُولَ اللَّهِ كَأَنَّ هَذِهِ مَوْعِظَةُ مُوَدِّعٍ فَمَاذَا تَعْهَدُ إِلَيْنَا فَقَالَ ‏"‏ أُوصِيكُمْ بِتَقْوَى اللَّهِ وَالسَّمْعِ وَالطَّاعَةِ وَإِنْ عَبْدًا حَبَشِيًّا فَإِنَّهُ مَنْ يَعِشْ مِنْكُمْ بَعْدِي فَسَيَرَى اخْتِلاَفًا كَثِيرًا فَعَلَيْكُمْ بِسُنَّتِي وَسُنَّةِ الْخُلَفَاءِ الْمَهْدِيِّينَ الرَّاشِدِينَ تَمَسَّكُوا بِهَا وَعَضُّوا عَلَيْهَا بِالنَّوَاجِذِ وَإِيَّاكُمْ وَمُحْدَثَاتِ الأُمُورِ فَإِنَّ كُلَّ مُحْدَثَةٍ بِدْعَةٌ وَكُلَّ بِدْعَةٍ ضَلاَلَةٌ ‏"‏ ‏.‏\hadithno{4607}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Irbad ibn Sariyah: AbdurRahman ibn Amr as-Sulami and Hujr ibn Hujr said: We came to Irbad ibn Sariyah who was among those about whom the following verse was revealed: "Nor (is there blame) on those who come to thee to be provided with mounts, and when thou saidst: "I can find no mounts for you." We greeted him and said: We have come to see you to give healing and obtain benefit from you. Al-Irbad said: One day the Messenger of Allah (ﷺ) led us in prayer, then faced us and gave us a lengthy exhortation at which the eyes shed tears and the hearts were afraid. A man said: Messenger of Allah! It seems as if it were a farewell exhortation, so what injunction do you give us? He then said: I enjoin you to fear Allah, and to hear and obey even if it be an Abyssinian slave, for those of you who live after me will see great disagreement. You must then follow my sunnah and that of the rightly-guided caliphs. Hold to it and stick fast to it. Avoid novelties, for every novelty is an innovation, and every innovation is an error}}
\hadithdefcmd{abudawud}{4608}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي سُلَيْمَانُ، - يَعْنِي ابْنَ عَتِيقٍ - عَنْ طَلْقِ بْنِ حَبِيبٍ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ هَلَكَ الْمُتَنَطِّعُونَ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{4608}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2670)}\hadithtrans{‘Abd Allah b. Mas’ud reported the Prophet (ﷺ) as saying:"Beware! The extremists perished," saying it three times}}
\hadithdefcmd{abudawud}{4609}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - قَالَ أَخْبَرَنِي الْعَلاَءُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ دَعَا إِلَى هُدًى كَانَ لَهُ مِنَ الأَجْرِ مِثْلُ أُجُورِ مَنْ تَبِعَهُ لاَ يَنْقُصُ ذَلِكَ مِنْ أُجُورِهِمْ شَيْئًا وَمَنْ دَعَا إِلَى ضَلاَلَةٍ كَانَ عَلَيْهِ مِنَ الإِثْمِ مِثْلُ آثَامِ مَنْ تَبِعَهُ لاَ يَنْقُصُ ذَلِكَ مِنْ آثَامِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{4609}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2674)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:If anyone summons other to follow right guidance, his reward will be equivalent to that of the people who follow him, without their rewards being diminished in any respect on that account; and if anyone summons others to follow error the sin of which sins being diminished in any respect on that account}}
\hadithdefcmd{abudawud}{4610}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَعْظَمَ الْمُسْلِمِينَ فِي الْمُسْلِمِينَ جُرْمًا مَنْ سَأَلَ عَنْ أَمْرٍ لَمْ يُحَرَّمْ فَحُرِّمَ عَلَى النَّاسِ مِنْ أَجْلِ مَسْأَلَتِهِ ‏"‏ ‏.‏\hadithno{4610}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7289) Sahih Muslim (2358)}\hadithtrans{‘Amir b. sa’id on his father’s authority reported the Messenger of Allah (ﷺ) as saying:The Muslim who offends most against the Muslims is he who enquires about something which has not been forbidden to men, and it is declared forbidden because of his enquiry}}
\hadithdefcmd{abudawud}{4611}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا إِدْرِيسَ الْخَوْلاَنِيَّ، عَائِذَ اللَّهِ أَخْبَرَهُ أَنَّ يَزِيدَ بْنَ عُمَيْرَةَ وَكَانَ مِنْ أَصْحَابِ مُعَاذِ بْنِ جَبَلٍ أَخْبَرَهُ قَالَ كَانَ لاَ يَجْلِسُ مَجْلِسًا لِلذِّكْرِ حِينَ يَجْلِسُ إِلاَّ قَالَ اللَّهُ حَكَمٌ قِسْطٌ هَلَكَ الْمُرْتَابُونَ فَقَالَ مُعَاذُ بْنُ جَبَلٍ يَوْمًا إِنَّ مِنْ وَرَائِكُمْ فِتَنًا يَكْثُرُ فِيهَا الْمَالُ وَيُفْتَحُ فِيهَا الْقُرْآنُ حَتَّى يَأْخُذَهُ الْمُؤْمِنُ وَالْمُنَافِقُ وَالرَّجُلُ وَالْمَرْأَةُ وَالصَّغِيرُ وَالْكَبِيرُ وَالْعَبْدُ وَالْحُرُّ فَيُوشِكُ قَائِلٌ أَنْ يَقُولَ مَا لِلنَّاسِ لاَ يَتَّبِعُونِي وَقَدْ قَرَأْتُ الْقُرْآنَ مَا هُمْ بِمُتَّبِعِيَّ حَتَّى أَبْتَدِعَ لَهُمْ غَيْرَهُ فَإِيَّاكُمْ وَمَا ابْتُدِعَ فَإِنَّ مَا ابْتُدِعَ ضَلاَلَةٌ وَأُحَذِّرُكُمْ زَيْغَةَ الْحَكِيمِ فَإِنَّ الشَّيْطَانَ قَدْ يَقُولُ كَلِمَةَ الضَّلاَلَةِ عَلَى لِسَانِ الْحَكِيمِ وَقَدْ يَقُولُ الْمُنَافِقُ كَلِمَةَ الْحَقِّ ‏.‏ قَالَ قُلْتُ لِمُعَاذٍ مَا يُدْرِينِي رَحِمَكَ اللَّهُ أَنَّ الْحَكِيمَ قَدْ يَقُولُ كَلِمَةَ الضَّلاَلَةِ وَأَنَّ الْمُنَافِقَ قَدْ يَقُولُ كَلِمَةَ الْحَقِّ قَالَ بَلَى اجْتَنِبْ مِنْ كَلاَمِ الْحَكِيمِ الْمُشْتَهِرَاتِ الَّتِي يُقَالُ لَهَا مَا هَذِهِ وَلاَ يُثْنِيَنَّكَ ذَلِكَ عَنْهُ فَإِنَّهُ لَعَلَّهُ أَنْ يُرَاجِعَ وَتَلَقَّ الْحَقَّ إِذَا سَمِعْتَهُ فَإِنَّ عَلَى الْحَقِّ نُورًا ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مَعْمَرٌ عَنِ الزُّهْرِيِّ فِي هَذَا وَلاَ يُنْئِيَنَّكَ ذَلِكَ عَنْهُ مَكَانَ يُثْنِيَنَّكَ ‏.‏ وَقَالَ صَالِحُ بْنُ كَيْسَانَ عَنِ الزُّهْرِيِّ فِي هَذَا الْمُشَبَّهَاتِ مَكَانَ الْمُشْتَهِرَاتِ وَقَالَ لاَ يُثْنِيَنَّكَ كَمَا قَالَ عُقَيْلٌ ‏.‏ وَقَالَ ابْنُ إِسْحَاقَ عَنِ الزُّهْرِيِّ قَالَ بَلَى مَا تَشَابَهَ عَلَيْكَ مِنْ قَوْلِ الْحَكِيمِ حَتَّى تَقُولَ مَا أَرَادَ بِهَذِهِ الْكَلِمَةِ ‏.‏\hadithno{4611}\hadithgrade{Al-Albani: Sahih Isnaad Mauquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Yazid b. ‘Umairah, who was one of the companions of Mu’adh b. Jabal said:Whenever he (mu’adh b. jabal) sat in a meeting for preaching, he would say: Allah is a just arbiter; those who doubt would perish. One day Mu’adh b. jabal said: In the times after you there would be trails in which riches would be abundant. During these trails the Quran would be easy so much so that every believer, hypocrite, man, woman, young, grown up, slave and free man will learn it. Then a man might say: What happened with the people that they do not follow me while I read the Quran? They are not going to follow me until I introduce a novelty for them other than it. So avoid that which is innovated (in religion), for whichever is innovated is an error. I warn you of the deviation of a scholar from right guidance, for sometimes Satan utters a word of error through the tongue of a scholar; and sometimes a hypocrites may speak a word of truth. I said to Mu’adh b. jabal: I am at a loss to understand may Allah have mercy on you that a learned man sometimes may speak a word of error and a hypocrite may speak a word of truth. He replied: Yes, avoid the speech of a learned man on distract you from him (the learned), for it is possible that he may withdraw (from these well-known things), and you get the truth when you hear it, for truth has light. Abu Dawud said: In this tradition Ma’mar on the authority of al-Zuhrl said: The words “wa la yun iyannaka” instead of “wa la yuthniyannaka,” with the same meaning: “it may not distract you” salih b. Kaisan on the authority of al-Zurhrl said in this tradition the words “al-mushtaharat” (well-know things). He also said the word “La yuthniyannaka” as ‘Uqail mentioned. Ibn ishaq, on the authority of al-Zuhri, said: Yes, if you are doubtful about the speech of a scholar until you say: WHAT did he mean by this word?}}
\hadithdefcmd{abudawud}{4612}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ كَتَبَ رَجُلٌ إِلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ يَسْأَلُهُ عَنِ الْقَدَرِ، ح وَحَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ الْمُؤَذِّنُ، قَالَ حَدَّثَنَا أَسَدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا حَمَّادُ بْنُ دُلَيْلٍ، قَالَ سَمِعْتُ سُفْيَانَ الثَّوْرِيَّ، يُحَدِّثُنَا عَنِ النَّضْرِ، ح وَحَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ قَبِيصَةَ، قَالَ حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ أَبِي الصَّلْتِ، - وَهَذَا لَفْظُ حَدِيثِ ابْنِ كَثِيرٍ وَمَعْنَاهُمْ - قَالَ كَتَبَ رَجُلٌ إِلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ يَسْأَلُهُ عَنِ الْقَدَرِ فَكَتَبَ أَمَّا بَعْدُ أُوصِيكَ بِتَقْوَى اللَّهِ وَالاِقْتِصَادِ فِي أَمْرِهِ وَاتِّبَاعِ سُنَّةِ نَبِيِّهِ صلى الله عليه وسلم وَتَرْكِ مَا أَحْدَثَ الْمُحْدِثُونَ بَعْدَ مَا جَرَتْ بِهِ سُنَّتُهُ وَكُفُوا مُؤْنَتَهُ فَعَلَيْكَ بِلُزُومِ السُّنَّةِ فَإِنَّهَا لَكَ بِإِذْنِ اللَّهِ عِصْمَةٌ ثُمَّ اعْلَمْ أَنَّهُ لَمْ يَبْتَدِعِ النَّاسُ بِدْعَةً إِلاَّ قَدْ مَضَى قَبْلَهَا مَا هُوَ دَلِيلٌ عَلَيْهَا أَوْ عِبْرَةٌ فِيهَا فَإِنَّ السُّنَّةَ إِنَّمَا سَنَّهَا مَنْ قَدْ عَلِمَ مَا فِي خِلاَفِهَا وَلَمْ يَقُلِ ابْنُ كَثِيرٍ مَنْ قَدْ عَلِمَ ‏.‏ مِنَ الْخَطَإِ وَالزَّلَلِ وَالْحُمْقِ وَالتَّعَمُّقِ فَارْضَ لِنَفْسِكَ مَا رَضِيَ بِهِ الْقَوْمُ لأَنْفُسِهِمْ فَإِنَّهُمْ عَلَى عِلْمٍ وَقَفُوا وَبِبَصَرٍ نَافِذٍ كَفَوْا وَلَهُمْ عَلَى كَشْفِ الأُمُورِ كَانُوا أَقْوَى وَبِفَضْلِ مَا كَانُوا فِيهِ أَوْلَى فَإِنْ كَانَ الْهُدَى مَا أَنْتُمْ عَلَيْهِ لَقَدْ سَبَقْتُمُوهُمْ إِلَيْهِ وَلَئِنْ قُلْتُمْ إِنَّمَا حَدَثَ بَعْدَهُمْ ‏.‏ مَا أَحْدَثَهُ إِلاَّ مَنِ اتَّبَعَ غَيْرَ سَبِيلِهِمْ وَرَغِبَ بِنَفْسِهِ عَنْهُمْ فَإِنَّهُمْ هُمُ السَّابِقُونَ فَقَدْ تَكَلَّمُوا فِيهِ بِمَا يَكْفِي وَوَصَفُوا مِنْهُ مَا يَشْفِي فَمَا دُونَهُمْ مِنْ مَقْصَرٍ وَمَا فَوْقَهُمْ مِنْ مَحْسَرٍ وَقَدْ قَصَّرَ قَوْمٌ دُونَهُمْ فَجَفَوْا وَطَمَحَ عَنْهُمْ أَقْوَامٌ فَغَلَوْا وَإِنَّهُمْ بَيْنَ ذَلِكَ لَعَلَى هُدًى مُسْتَقِيمٍ كَتَبْتَ تَسْأَلُ عَنِ الإِقْرَارِ بِالْقَدَرِ فَعَلَى الْخَبِيرِ بِإِذْنِ اللَّهِ وَقَعْتَ مَا أَعْلَمُ مَا أَحْدَثَ النَّاسُ مِنْ مُحْدَثَةٍ وَلاَ ابْتَدَعُوا مِنْ بِدْعَةٍ هِيَ أَبْيَنُ أَثَرًا وَلاَ أَثْبَتُ أَمْرًا مِنَ الإِقْرَارِ بِالْقَدَرِ لَقَدْ كَانَ ذَكَرَهُ فِي الْجَاهِلِيَّةِ الْجُهَلاَءُ يَتَكَلَّمُونَ بِهِ فِي كَلاَمِهِمْ وَفِي شِعْرِهِمْ يُعَزُّونَ بِهِ أَنْفُسَهُمْ عَلَى مَا فَاتَهُمْ ثُمَّ لَمْ يَزِدْهُ الإِسْلاَمُ بَعْدُ إِلاَّ شِدَّةً وَلَقَدْ ذَكَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي غَيْرِ حَدِيثٍ وَلاَ حَدِيثَيْنِ وَقَدْ سَمِعَهُ مِنْهُ الْمُسْلِمُونَ فَتَكَلَّمُوا بِهِ فِي حَيَاتِهِ وَبَعْدَ وَفَاتِهِ يَقِينًا وَتَسْلِيمًا لِرَبِّهِمْ وَتَضْعِيفًا لأَنْفُسِهِمْ أَنْ يَكُونَ شَىْءٌ لَمْ يُحِطْ بِهِ عِلْمُهُ وَلَمْ يُحْصِهِ كِتَابُهُ وَلَمْ يَمْضِ فِيهِ قَدَرُهُ وَإِنَّهُ مَعَ ذَلِكَ لَفِي مُحْكَمِ كِتَابِهِ مِنْهُ اقْتَبَسُوهُ وَمِنْهُ تَعَلَّمُوهُ وَلَئِنْ قُلْتُمْ لِمَ أَنْزَلَ اللَّهُ آيَةَ كَذَا وَلِمَ قَالَ كَذَا ‏.‏ لَقَدْ قَرَءُوْا مِنْهُ مَا قَرَأْتُمْ وَعَلِمُوا مِنْ تَأْوِيلِهِ مَا جَهِلْتُمْ وَقَالُوا بَعْدَ ذَلِكَ كُلِّهِ بِكِتَابٍ وَقَدَرٍ وَكُتِبَتِ الشَّقَاوَةُ وَمَا يُقَدَّرْ يَكُنْ وَمَا شَاءَ اللَّهُ كَانَ وَمَا لَمْ يَشَأْ لَمْ يَكُنْ وَلاَ نَمْلِكُ لأَنْفُسِنَا ضَرًّا وَلاَ نَفْعًا ثُمَّ رَغَبُوا بَعْدَ ذَلِكَ وَرَهِبُوا ‏.‏\hadithno{4612}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Sufyan said (according to one chain), and Abu al-Salit said (according to another chain):A man wrote to 'Umar b. 'Abd al-Aziz asking him about Divine decree. He wrote to him: To begin with, I enjoin upon you to fear Allah, to be moderate in (obeying) His Command, to follow the sunnah (practice) of His Prophet (ﷺ) and to abandon the novelties which the innovators introduced after his Sunnah has been established and they were saved from its trouble (i.e. novelty or innovation) ; so stick to Sunnah, for it is for you, if Allah chooses, a protection ; then you should know that any innovation which the people introduced was refuted long before it on the basis of some authority or there was some lesson in it, for the Sunnah was introduced by the people who were conscious of the error, slip, foolishness, and extremism in case of (the sunnah) was opposed. So accept for yourself what the people (in the past) had accepted for themselves, for they had complete knowledge of whatever they were informed, and by penetrating insight they forbade (to do prohibited acts); they had more strength (than us) to disclose the matters (of religion), and they were far better (than us) by virtue of their merits. If right guidance is what you are following, then you outstriped them to it. And if you say whatever the novelty occurred after them was introduced by those who followed the way other then theirs and disliked them. It is they who actually outstripped, and talked about it sufficiently, and gave a satisfactory explanation for it. Below them there is no place for exhaustiveness, and above them there is no place for elaborating things. Some people shortened the matter more than they had done, and thus they turned away (from them), and some people raised the matter more than they had done, and thus they exaggerated. They were on right guidance between that. You have written (to me) asking about confession of Divine decree, you have indeed approached a person who is well informed of it, with the will of Allah. I know what whatever novelty people have brought in, and whatever innovation people have introduced are not more manifest and more established than confession of Divine decree. The ignorant people (i.e. the Arabs before Islam) in pre-Islamic times have mentioned it ; they talked about it in their speeches and in their poetry. They would console themselves for what they lost, and Islam then strengthened it (i.e. belief in Divine decree). The Messenger of Allah (ﷺ) did not mention it in one or two traditions, but the Muslims heard it from him, and they talked of it from him, and they talked of it during his lifetime and after his death. They did so out of belief and submission to their Lord and thinking themselves weak. There is nothing which is not surrounded by His knowledge, and not counted by His register and not destined by His decree. Despite that, it has been strongly mentioned in His Book: from it they have derived it, and from it they have and so ? they also read in it what you read, and they knew its interpretation of which you are ignorant. After that they said: All this is by writing and decreeing. Distress has been written down, and what has been destined will occur ; what Allah wills will surely happen, and what He does not will will not happen. We have no power to harm or benefit ourselves. Then after that they showed interest (in good works) and were afraid (of bad deeds)}}
\hadithdefcmd{abudawud}{4613}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا سَعِيدٌ، - يَعْنِي ابْنَ أَبِي أَيُّوبَ - قَالَ أَخْبَرَنِي أَبُو صَخْرٍ، عَنْ نَافِعٍ، قَالَ كَانَ لاِبْنِ عُمَرَ صَدِيقٌ مِنْ أَهْلِ الشَّامِ يُكَاتِبُهُ فَكَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ عُمَرَ إِنَّهُ بَلَغَنِي أَنَّكَ تَكَلَّمْتَ فِي شَىْءٍ مِنَ الْقَدَرِ فَإِيَّاكَ أَنْ تَكْتُبَ إِلَىَّ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّهُ سَيَكُونُ فِي أُمَّتِي أَقْوَامٌ يُكَذِّبُونَ بِالْقَدَرِ ‏"‏ ‏.‏\hadithno{4613}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Nafi said:Ibn ‘Umar had a friend from the people of Syria who used to correspond with him. ‘Abd Allah b. ‘Umar wrote to him: I have been informed that you have talked something about Divine decree. You should write it to me, for I heard the Messenger of Allah (ﷺ) say: Among my community there will be people who will falsify Divine decree}}
\hadithdefcmd{abudawud}{4614}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ خَالِدٍ الْحَذَّاءِ، قَالَ قُلْتُ لِلْحَسَنِ يَا أَبَا سَعِيدٍ أَخْبِرْنِي عَنْ آدَمَ، لِلسَّمَاءِ خُلِقَ أَمْ لِلأَرْضِ قَالَ لاَ بَلْ لِلأَرْضِ ‏.‏ قُلْتُ أَرَأَيْتَ لَوِ اعْتَصَمَ فَلَمْ يَأْكُلْ مِنَ الشَّجَرَةِ قَالَ لَمْ يَكُنْ لَهُ مِنْهُ بُدٌّ ‏.‏ قُلْتُ أَخْبِرْنِي عَنْ قَوْلِهِ تَعَالَى ‏\{‏ مَا أَنْتُمْ عَلَيْهِ بِفَاتِنِينَ * إِلاَّ مَنْ هُوَ صَالِ الْجَحِيمِ ‏\}‏ قَالَ إِنَّ الشَّيَاطِينَ لاَ يَفْتِنُونَ بِضَلاَلَتِهِمْ إِلاَّ مَنْ أَوْجَبَ اللَّهُ عَلَيْهِ الْجَحِيمَ ‏.‏\hadithno{4614}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Khalid al-Hadhdha said:I said to al-Hasan: Abu Sa’id, tell me about Adam. Was he created for the heaven or the earth? He said: No, for the earth. I said: It was unavoidable for him. I said: Tell me about the following verse of the Quran: ”can lead (any) into temptation concerning Allah, except such as are (themselves) going to blazing fire.” He said: The devils do not lead anyone astray by their temptation except the one whom Allah destined to go to Hell}}
\hadithdefcmd{abudawud}{4615}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنِ الْحَسَنِ، فِي قَوْلِهِ تَعَالَى ‏\{‏ وَلِذَلِكَ خَلَقَهُمْ ‏\}‏ قَالَ خَلَقَ هَؤُلاَءِ لِهَذِهِ وَهَؤُلاَءِ لِهَذِهِ ‏.‏\hadithno{4615}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Khalid al-Hadhdha, asked al-Hasan about the Quranic verse:“And for this did He create them.” He said: He created these for this and those for that}}
\hadithdefcmd{abudawud}{4616}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، قَالَ قُلْتُ لِلْحَسَنِ ‏\{‏ مَا أَنْتُمْ عَلَيْهِ بِفَاتِنِينَ * إِلاَّ مَنْ هُوَ صَالِ الْجَحِيمِ ‏\}‏ قَالَ إِلاَّ مَنْ أَوْجَبَ اللَّهُ تَعَالَى عَلَيْهِ أَنَّهُ يَصْلَى الْجَحِيمَ ‏.‏\hadithno{4616}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Khalid al-Hadhdha asked al-Hasan about the Quranic verse:“Can lead (any) into temptation concerning Allah, except such as are (themselves) going to the blazing fire.” He said: Except the one whom Allah destined that he should go to Hell}}
\hadithdefcmd{abudawud}{4617}{حَدَّثَنَا هِلاَلُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ أَخْبَرَنِي حُمَيْدٌ، قَالَ كَانَ الْحَسَنُ يَقُولُ لأَنْ يُسْقَطَ مِنَ السَّمَاءِ إِلَى الأَرْضِ أَحَبُّ إِلَيْهِ مِنْ أَنْ يَقُولَ الأَمْرُ بِيَدِي ‏.‏\hadithno{4617}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Humaid said:Al-Hasan used to say that his fall from the heaven on the earth is dearer to him than uttering: The matter is in my hand}}
\hadithdefcmd{abudawud}{4618}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا حُمَيْدٌ، قَالَ قَدِمَ عَلَيْنَا الْحَسَنُ مَكَّةَ فَكَلَّمَنِي فُقَهَاءُ أَهْلِ مَكَّةَ أَنْ أُكَلِّمَهُ فِي أَنْ يَجْلِسَ لَهُمْ يَوْمًا يَعِظُهُمْ فِيهِ ‏.‏ فَقَالَ نَعَمْ ‏.‏ فَاجْتَمَعُوا فَخَطَبَهُمْ فَمَا رَأَيْتُ أَخْطَبَ مِنْهُ فَقَالَ رَجُلٌ يَا أَبَا سَعِيدٍ مَنْ خَلَقَ الشَّيْطَانَ فَقَالَ سُبْحَانَ اللَّهِ هَلْ مِنْ خَالِقٍ غَيْرُ اللَّهِ خَلَقَ اللَّهُ الشَّيْطَانَ وَخَلَقَ الْخَيْرَ وَخَلَقَ الشَّرَّ ‏.‏ قَالَ الرَّجُلُ قَاتَلَهُمُ اللَّهُ كَيْفَ يَكْذِبُونَ عَلَى هَذَا الشَّيْخِ ‏.‏\hadithno{4618}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Humaid said:Al-Hasan came to us. The jurists of Mecca told me that I should speak to him that some day he should hold a meeting for them and preach to them. He said: Yes. So they gathered and he addressed them. I did not see anyone on orator greater than him. A man said: Abu Sa’id, who created Satan? He replied: Glory be to Allah! Is there any creator other than Allah? Allah created Satan, and he created good and created evil. The man said: May Allah ruin them! How do they lie to this old man}}
\hadithdefcmd{abudawud}{4619}{حَدَّثَنَا ابْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنِ الْحَسَنِ، ‏\{‏ كَذَلِكَ نَسْلُكُهُ فِي قُلُوبِ الْمُجْرِمِينَ ‏\}‏ قَالَ الشِّرْكُ ‏.‏\hadithno{4619}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Humaid al-Tawil asked al-Hasan about the verse:“Even so do We let it creep into the hearts of the sinners.” He said: Polytheism}}
\hadithdefcmd{abudawud}{4620}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنْ رَجُلٍ، قَدْ سَمَّاهُ غَيْرِ ابْنِ كَثِيرٍ عَنْ سُفْيَانَ، عَنْ عُبَيْدٍ الصِّيدِ، عَنِ الْحَسَنِ، فِي قَوْلِ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ وَحِيلَ بَيْنَهُمْ وَبَيْنَ مَا يَشْتَهُونَ ‏\}‏ قَالَ بَيْنَهُمْ وَبَيْنَ الإِيمَانِ ‏.‏\hadithno{4620}\hadithgrade{Al-Albani: Daif Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Explaining the Quranic verse; “And between them and their desire is placed a barrier.” Al-Hasan said:Between them and their faith}}
\hadithdefcmd{abudawud}{4621}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا سُلَيْمٌ، عَنِ ابْنِ عَوْنٍ، قَالَ كُنْتُ أَسِيرُ بِالشَّامِ فَنَادَانِي رَجُلٌ مِنْ خَلْفِي فَالْتَفَتُّ فَإِذَا رَجَاءُ بْنُ حَيْوَةَ فَقَالَ يَا أَبَا عَوْنٍ مَا هَذَا الَّذِي يَذْكُرُونَ عَنِ الْحَسَنِ قَالَ قُلْتُ إِنَّهُمْ يَكْذِبُونَ عَلَى الْحَسَنِ كَثِيرًا ‏.‏\hadithno{4621}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Awn said:I was a prisoner in Syria. A man called me from behind. I turned towards him and suddenly found that it was Raja b. Haiwah. He said: Abu ‘Awn, what is this that the people are telling about al-Hasan? I said: They are much lying to al-Hasan}}
\hadithdefcmd{abudawud}{4622}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ سَمِعْتُ أَيُّوبَ، يَقُولُ كَذَبَ عَلَى الْحَسَنِ ضَرْبَانِ مِنَ النَّاسِ قَوْمٌ الْقَدَرُ رَأْيُهُمْ وَهُمْ يُرِيدُونَ أَنْ يُنَفِّقُوا بِذَلِكَ رَأْيَهُمْ وَقَوْمٌ لَهُ فِي قُلُوبِهِمْ شَنَآنٌ وَبُغْضٌ يَقُولُونَ أَلَيْسَ مِنْ قَوْلِهِ كَذَا أَلَيْسَ مِنْ قَوْلِهِ كَذَا\hadithno{4622}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hammad said:I heard Ayyub say: Two kinds of people have lied to al-Hasan: people who believed in free will and they intended that they publicise their belief by it; and people who had enmity with and hostility (for al-Hasan), saying: Did he not say so and so? Did he not say so and so?}}
\hadithdefcmd{abudawud}{4623}{حَدَّثَنَا ابْنُ الْمُثَنَّى، أَنَّ يَحْيَى بْنَ كَثِيرٍ الْعَنْبَرِيَّ، حَدَّثَهُمْ قَالَ كَانَ قُرَّةُ بْنُ خَالِدٍ يَقُولُ لَنَا يَا فِتْيَانُ لاَ تُغْلَبُوا عَلَى الْحَسَنِ فَإِنَّهُ كَانَ رَأْيُهُ السُّنَّةَ وَالصَّوَابَ ‏.‏\hadithno{4623}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Yahya b. Kathir al-‘Anbari said:Qurrah b. Khalid used to tell us: O young people! Do not think that al-Hasan denied predestination, for his opinion (i.e., belief) was sunnah and sight}}
\hadithdefcmd{abudawud}{4624}{حَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُؤَمَّلُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ ابْنِ عَوْنٍ، قَالَ لَوْ عَلِمْنَا أَنَّ كَلِمَةَ، الْحَسَنِ تَبْلُغُ مَا بَلَغَتْ لَكَتَبْنَا بِرُجُوعِهِ كِتَابًا وَأَشْهَدْنَا عَلَيْهِ شُهُودًا وَلَكِنَّا قُلْنَا كَلِمَةٌ خَرَجَتْ لاَ تُحْمَلُ ‏.‏\hadithno{4624}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Awn said:If we learnt that the remark of al-Hasan would reach the extent that it has reached, we would write a book for his withdrawal and call witnesses to him; but we said: This is a remark that surprisingly came out (from him) and it will not be transmitted to others}}
\hadithdefcmd{abudawud}{4625}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، قَالَ قَالَ لِيَ الْحَسَنُ مَا أَنَا بِعَائِدٍ، إِلَى شَىْءٍ مِنْهُ أَبَدًا ‏.‏\hadithno{4625}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ayyub said:Al-Hasan said: I will never return to it}}
\hadithdefcmd{abudawud}{4626}{حَدَّثَنَا هِلاَلُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُثْمَانَ، عَنْ عُثْمَانَ الْبَتِّيِّ، قَالَ مَا فَسَّرَ الْحَسَنُ آيَةً قَطُّ إِلاَّ عَلَى الإِثْبَاتِ ‏.‏\hadithno{4626}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Uthman al-Batti said:Al-Hasan never interpreted any Quranic verse but to establish (Divine decree)}}
\hadithdefcmd{abudawud}{4627}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نَقُولُ فِي زَمَنِ النَّبِيِّ صلى الله عليه وسلم لاَ نَعْدِلُ بِأَبِي بَكْرٍ أَحَدًا ثُمَّ عُمَرَ ثُمَّ عُثْمَانَ ثُمَّ نَتْرُكُ أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم لاَ تَفَاضُلَ بَيْنَهُمْ ‏.‏\hadithno{4627}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3698)}\hadithtrans{Ibn ‘Umar said:We used to say in the times of the Prophet (ﷺ): We do not compare anyone with Abu Bakr. ’Umar came next and then ‘Uthman. We then would leave (rest of) the companions of the Prophet (ﷺ) without treating any as superior to other}}
\hadithdefcmd{abudawud}{4628}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ سَالِمُ بْنُ عَبْدِ اللَّهِ إِنَّ ابْنَ عُمَرَ قَالَ كُنَّا نَقُولُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حَىٌّ أَفْضَلُ أُمَّةِ النَّبِيِّ صلى الله عليه وسلم بَعْدَهُ أَبُو بَكْرٍ ثُمَّ عُمَرُ ثُمَّ عُثْمَانُ رضى الله عنهم أَجْمَعِينَ ‏.‏\hadithno{4628}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn ‘Umar said:When the Messenger of Allah (ﷺ) was alive, we used to say: The most excellent member of the community of the Prophet (ﷺ) after himself is Abu Bakr, then ‘Umar, then 'Uthman}}
\hadithdefcmd{abudawud}{4629}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا جَامِعُ بْنُ أَبِي رَاشِدٍ، حَدَّثَنَا أَبُو يَعْلَى، عَنْ مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ، قَالَ قُلْتُ لأَبِي أَىُّ النَّاسِ خَيْرٌ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو بَكْرٍ ‏.‏ قَالَ قُلْتُ ثُمَّ مَنْ قَالَ ثُمَّ عُمَرُ ‏.‏ قَالَ ثُمَّ خَشِيتُ أَنْ أَقُولَ ثُمَّ مَنْ فَيَقُولَ عُثْمَانُ فَقُلْتُ ثُمَّ أَنْتَ يَا أَبَةِ قَالَ مَا أَنَا إِلاَّ رَجُلٌ مِنَ الْمُسْلِمِينَ ‏.‏\hadithno{4629}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3671)}\hadithtrans{Muhammad b. al-Hanafiyyah said:I said to my father: Which of the people after the Messenger of Allah (ﷺ) is best? He replied: Abu Bakr. I then asked: Who comes next? He said: ‘Umar. I was then afraid of asking him who came next, and he might mention ‘Uthman, so I said: You came next, O my father? He said: I am only a man among the Muslims}}
\hadithdefcmd{abudawud}{4630}{حَدَّثَنَا مُحَمَّدُ بْنُ مِسْكِينٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي الْفِرْيَابِيَّ - قَالَ سَمِعْتُ سُفْيَانَ، يَقُولُ مَنْ زَعَمَ أَنَّ عَلِيًّا، عَلَيْهِ السَّلاَمُ كَانَ أَحَقَّ بِالْوِلاَيَةِ مِنْهُمَا فَقَدْ خَطَّأَ أَبَا بَكْرٍ وَعُمَرَ وَالْمُهَاجِرِينَ وَالأَنْصَارَ وَمَا أُرَاهُ يَرْتَفِعُ لَهُ مَعَ هَذَا عَمَلٌ إِلَى السَّمَاءِ ‏.‏\hadithno{4630}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad al-Firyabl said:I heard Sufyan say: If anyone thinks that ‘All (Allah be pleased with him) was more deserving for the Caliphate than both of them, he imputed error to Abu Bakr, ‘Umar, the Muhajirun (Immigrants), and the Ansar (Helpers) Allah be pleased with all of them. I think that with this (belief) none of his action will rise to the heaven}}
\hadithdefcmd{abudawud}{4631}{حَدَّثَنَا مُحَمَّدُ بْنُ فَارِسٍ، حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا عَبَّادٌ السَّمَّاكُ، قَالَ سَمِعْتُ سُفْيَانَ الثَّوْرِيَّ، يَقُولُ الْخُلَفَاءُ خَمْسَةٌ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَعُمَرُ بْنُ عَبْدِ الْعَزِيزِ رضى الله عنهم ‏.‏\hadithno{4631}\hadithgrade{Al-Albani: Daif Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad Maqtu; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sufyan al-Thawri said:The Caliphs are five: Abu Bakr, ‘Umar, ‘Uthman, ‘All and ‘Umar b. ‘Abd al-Aziz}}
\hadithdefcmd{abudawud}{4632}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - قَالَ مُحَمَّدٌ كَتَبْتُهُ مِنْ كِتَابِهِ - قَالَ أَخْبَرَنَا مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ قَالَ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُ أَنَّ رَجُلاً أَتَى إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي أَرَى اللَّيْلَةَ ظُلَّةً يَنْطِفُ مِنْهَا السَّمْنُ وَالْعَسَلُ فَأَرَى النَّاسَ يَتَكَفَّفُونَ بِأَيْدِيهِمْ فَالْمُسْتَكْثِرُ وَالْمُسْتَقِلُّ وَأَرَى سَبَبًا وَاصِلاً مِنَ السَّمَاءِ إِلَى الأَرْضِ فَأَرَاكَ يَا رَسُولَ اللَّهِ أَخَذْتَ بِهِ فَعَلَوْتَ بِهِ ثُمَّ أَخَذَ بِهِ رَجُلٌ آخَرُ فَعَلاَ بِهِ ثُمَّ أَخَذَ بِهِ رَجُلٌ آخَرُ فَعَلاَ بِهِ ثُمَّ أَخَذَ بِهِ رَجُلٌ آخَرُ فَانْقَطَعَ ثُمَّ وُصِلَ فَعَلاَ بِهِ ‏.‏ قَالَ أَبُو بَكْرٍ بِأَبِي وَأُمِّي لَتَدَعَنِّي فَلأَعْبُرَنَّهَا ‏.‏ فَقَالَ ‏"‏ اعْبُرْهَا ‏"‏ ‏.‏ قَالَ أَمَّا الظُّلَّةُ فَظُلَّةُ الإِسْلاَمِ وَأَمَّا مَا يَنْطِفُ مِنَ السَّمْنِ وَالْعَسَلِ فَهُوَ الْقُرْآنُ لِينُهُ وَحَلاَوَتُهُ وَأَمَّا الْمُسْتَكْثِرُ وَالْمُسْتَقِلُّ فَهُوَ الْمُسْتَكْثِرُ مِنَ الْقُرْآنِ وَالْمُسْتَقِلُّ مِنْهُ وَأَمَّا السَّبَبُ الْوَاصِلُ مِنَ السَّمَاءِ إِلَى الأَرْضِ فَهُوَ الْحَقُّ الَّذِي أَنْتَ عَلَيْهِ تَأْخُذُ بِهِ فَيُعْلِيكَ اللَّهُ ثُمَّ يَأْخُذُ بِهِ بَعْدَكَ رَجُلٌ فَيَعْلُو بِهِ ثُمَّ يَأْخُذُ بِهِ رَجُلٌ آخَرُ فَيَعْلُو بِهِ ثُمَّ يَأْخُذُ بِهِ رَجُلٌ آخَرُ فَيَنْقَطِعُ ثُمَّ يُوصَلُ لَهُ فَيَعْلُو بِهِ أَىْ رَسُولَ اللَّهِ لَتُحَدِّثَنِّي أَصَبْتُ أَمْ أَخْطَأْتُ ‏.‏ فَقَالَ ‏"‏ أَصَبْتَ بَعْضًا وَأَخْطَأْتَ بَعْضًا ‏"‏ ‏.‏ فَقَالَ أَقْسَمْتُ يَا رَسُولَ اللَّهِ لَتُحَدِّثَنِّي مَا الَّذِي أَخْطَأْتُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تُقْسِمْ ‏"‏ ‏.‏\hadithno{4632}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7046) Sahih Muslim (2269)}\hadithtrans{Ibn 'Abbas said:Abu Hurairah said that a man came to the Messenger of Allah (ﷺ) and said: I saw (in my dream) a piece of cloud from which ghee and honey were dropping. I saw the people spreading their hands. Some of them took much and some a little. I also saw a rope hanging from Heaven to Earth. I saw, Messenger of Allah, that you caught hold of it and ascended by it. Then another man caught hold of it and ascended it. Then another man caught hold of it and ascended it. Then another man caught hold of it, but it broke, and then it was joined and he ascended it. AbuBakr said: May my parents be sacrificed for you, if you allow, I shall interpret it. He said: Interpret it. He said: The piece of cloud is the cloud of Islam; the ghee and honey that were dropping from it are the Qur'an, which contains softness and sweetness. Those who received much or little of it are those who learn much or little of the Qur'an. The rope hanging from Heaven to Earth is the truth which you are following. You catch hold of it and then Allah will raise you to Him. Then another man will catch hold of it and ascend it, Then another man will catch hold of it and it will break. But it will be joined and he will ascend it. Tell me. Messenger of Allah, whether I am right or wrong. He said: You are partly right and partly wrong. He said: I adjure you by Allah, you should tell me where I am wrong. The Prophet (ﷺ) said: Do not take an oath}}
\hadithdefcmd{abudawud}{4633}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذِهِ الْقِصَّةِ قَالَ فَأَبَى أَنْ يُخْبِرَهُ ‏.‏\hadithno{4633}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn ‘abbas through a different chain of narrators. This version adds:He refused to tell him (his mistake)}}
\hadithdefcmd{abudawud}{4634}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا الأَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ذَاتَ يَوْمٍ ‏ "‏ مَنْ رَأَى مِنْكُمْ رُؤْيَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَنَا رَأَيْتُ كَأَنَّ مِيزَانًا نَزَلَ مِنَ السَّمَاءِ فَوُزِنْتَ أَنْتَ وَأَبُو بَكْرٍ فَرُجِحْتَ أَنْتَ بِأَبِي بَكْرٍ وَوُزِنَ عُمَرُ وَأَبُو بَكْرٍ فَرُجِحَ أَبُو بَكْرٍ وَوُزِنَ عُمَرُ وَعُثْمَانُ فَرُجِحَ عُمَرُ ثُمَّ رُفِعَ الْمِيزَانُ فَرَأَيْنَا الْكَرَاهِيَةَ فِي وَجْهِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4634}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuBakrah: One day the Prophet (ﷺ) said: Which of you had dream? A man said: It is I. I saw as though a scale descended from the sky. You and AbuBakr were weighed and you were heavier; AbuBakr and Umar were weighed and AbuBakr was heavier: Umar and Uthman were weighed and Umar was heavier; than the scale was taken up. we saw signs of dislike on the face of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{4635}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ذَاتَ يَوْمٍ ‏"‏ أَيُّكُمْ رَأَى رُؤْيَا ‏"‏ ‏.‏ فَذَكَرَ مَعْنَاهُ وَلَمْ يَذْكُرِ الْكَرَاهِيَةَ ‏.‏ قَالَ فَاسْتَاءَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْنِي فَسَاءَهُ ذَلِكَ فَقَالَ ‏"‏ خِلاَفَةُ نُبُوَّةٍ ثُمَّ يُؤْتِي اللَّهُ الْمُلْكَ مَنْ يَشَاءُ ‏"‏ ‏.‏\hadithno{4635}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Bakrah said:One day the Prophet (ﷺ) asked: Which of you had a dream? He then mentioned the rest of the tradition to the same effect, but he did not mention the word “disliked”. Instead, he said: The Messenger of Allah (ﷺ) was grieved about that. He then said: There will be a caliphate on the model of prophecy, then Allah will give the kingdom to whom he wills}}
\hadithdefcmd{abudawud}{4636}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرِو بْنِ أَبَانَ بْنِ عُثْمَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُرِيَ اللَّيْلَةَ رَجُلٌ صَالِحٌ أَنَّ أَبَا بَكْرٍ نِيطَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَنِيطَ عُمَرُ بِأَبِي بَكْرٍ وَنِيطَ عُثْمَانُ بِعُمَرَ ‏"‏ ‏.‏ قَالَ جَابِرٌ فَلَمَّا قُمْنَا مِنْ عِنْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قُلْنَا أَمَّا الرَّجُلُ الصَّالِحُ فَرَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَّا تَنَوُّطُ بَعْضِهِمْ بِبَعْضٍ فَهُمْ وُلاَةُ هَذَا الأَمْرِ الَّذِي بَعَثَ اللَّهُ بِهِ نَبِيَّهُ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ يُونُسُ وَشُعَيْبٌ لَمْ يَذْكُرَا عَمْرًا ‏.‏\hadithno{4636}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir b. ‘Abd Allah reported the Messenger of Allah (ﷺ) as saying:Last night a good man had a vision in which Abu Bakr seemed to be joined to the Messenger of Allah (ﷺ). ‘Umar to Abu Bakr, and ‘Uthman to ‘Umar. Jabir said: When we got up and left the Messenger of Allah (ﷺ), we said: The good man is the Messenger of Allah (ﷺ), and that their being joined together means that they are the rulers over this matter with which Allah has sent His Prophet (ﷺ). Abu Dawud said: It has been transmitted by Yunus and Shu’aib, but they did not mention ‘Amr b. Aban}}
\hadithdefcmd{abudawud}{4637}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَشْعَثَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنِّي رَأَيْتُ كَأَنَّ دَلْوًا دُلِّيَ مِنَ السَّمَاءِ فَجَاءَ أَبُو بَكْرٍ فَأَخَذَ بِعَرَاقِيهَا فَشَرِبَ شُرْبًا ضَعِيفًا ثُمَّ جَاءَ عُمَرُ فَأَخَذَ بِعَرَاقِيهَا فَشَرِبَ حَتَّى تَضَلَّعَ ثُمَّ جَاءَ عُثْمَانُ فَأَخَذَ بِعَرَاقِيهَا فَشَرِبَ حَتَّى تَضَلَّعَ ثُمَّ جَاءَ عَلِيٌّ فَأَخَذَ بِعَرَاقِيهَا فَانْتَشَطَتْ وَانْتَضَحَ عَلَيْهِ مِنْهَا شَىْءٌ ‏.‏\hadithno{4637}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Samurah b. Jundub told that a man said:Messenger of Allah (ﷺ)! I saw (in a dream) that a bucket was hung from the sky. Abu Bakr came, caught hold of both ends of its wooden handle, and drank a little of it. Next came ‘Umar who caught hold of both ends of its wooden handle and drank of it to his fill. Next came ‘Uthman who caught hold of both ends of its handle and drank of it to his fill. Next came ‘All. He caught hold of both ends of its handle, but it became upset and some (water) from it was sprinkled on him}}
\hadithdefcmd{abudawud}{4638}{حَدَّثَنَا عَلِيُّ بْنُ سَهْلٍ الرَّمْلِيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ مَكْحُولٍ، قَالَ لَتَمْخُرَنَّ الرُّومُ الشَّامَ أَرْبَعِينَ صَبَاحًا لاَ يَمْتَنِعُ مِنْهَا إِلاَّ دِمَشْقُ وَعَمَّانُ ‏.‏\hadithno{4638}\hadithgrade{Al-Albani: Daif Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad Maqtu; Shuaib Al Arnaut: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Makhul said:The Romans will enter the Levant and stay there for forty days, and no place will be saved from them but Damascus and 'Uman}}
\hadithdefcmd{abudawud}{4639}{حَدَّثَنَا مُوسَى بْنُ عَامِرٍ الْمُرِّيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، أَنَّهُ سَمِعَ أَبَا الأَعْيَسِ عَبْدَ الرَّحْمَنِ بْنَ سَلْمَانَ، يَقُولُ سَيَأْتِي مَلِكٌ مِنْ مُلُوكِ الْعَجَمِ يَظْهَرُ عَلَى الْمَدَائِنِ كُلِّهَا إِلاَّ دِمَشْقَ ‏.‏\hadithno{4639}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Shuaib Al Arnaut: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Abu al-A’yas ‘Abd al-Rahman b. Salam said:A king of the foreigners will come and prevail over all the cities except Damascus}}
\hadithdefcmd{abudawud}{4640}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا بُرْدٌ أَبُو الْعَلاَءِ، عَنْ مَكْحُولٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَوْضِعُ فُسْطَاطِ الْمُسْلِمِينَ فِي الْمَلاَحِمِ أَرْضٌ يُقَالُ لَهَا الْغُوطَةُ ‏"‏ ‏.‏\hadithno{4640}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Makhul reported the Messenger of Allah (ﷺ) as saying:The place of the assembly of Muslims at the time of war will be in a land called al-Ghutah}}
\hadithdefcmd{abudawud}{4641}{حَدَّثَنَا أَبُو ظَفَرٍ عَبْدُ السَّلاَمِ، حَدَّثَنَا جَعْفَرٌ، عَنْ عَوْفٍ، قَالَ سَمِعْتُ الْحَجَّاجَ، يَخْطُبُ وَهُوَ يَقُولُ إِنَّ مَثَلَ عُثْمَانَ عِنْدَ اللَّهِ كَمَثَلِ عِيسَى ابْنِ مَرْيَمَ ثُمَّ قَرَأَ هَذِهِ الآيَةَ يَقْرَؤُهَا وَيَفُسِّرُهَا ‏\{‏ إِذْ قَالَ اللَّهُ يَا عِيسَى إِنِّي مُتَوَفِّيكَ وَرَافِعُكَ إِلَىَّ وَمُطَهِّرُكَ مِنَ الَّذِينَ كَفَرُوا ‏\}‏ يُشِيرُ إِلَيْنَا بِيَدِهِ وَإِلَى أَهْلِ الشَّامِ ‏.‏\hadithno{4641}\hadithgrade{Al-Albani: Daif Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Awf said:I heard al-Hajjaj addressing the people say: The similitude of ‘Uthman with Allah is like the similitude of Jesus son of Mary. He then recited the following verse and explained it: “Behold! Allah said: O Jesus! I will take thee and raise thee to Myself and clear thee (of the falsehood) of those who blaspheme.” He was making a sign with his hand to us and to the people of Syria}}
\hadithdefcmd{abudawud}{4642}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ الطَّالْقَانِيُّ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الْمُغِيرَةِ، عَنِ الرَّبِيعِ بْنِ خَالِدٍ الضَّبِّيِّ، قَالَ سَمِعْتُ الْحَجَّاجَ، يَخْطُبُ فَقَالَ فِي خُطْبَتِهِ رَسُولُ أَحَدِكُمْ فِي حَاجَتِهِ أَكْرَمُ عَلَيْهِ أَمْ خَلِيفَتُهُ فِي أَهْلِهِ فَقُلْتُ فِي نَفْسِي لِلَّهِ عَلَىَّ أَلاَّ أُصَلِّيَ خَلْفَكَ صَلاَةً أَبَدًا وَإِنْ وَجَدْتُ قَوْمًا يُجَاهِدُونَكَ لأُجَاهِدَنَّكَ مَعَهُمْ ‏.‏ زَادَ إِسْحَاقُ فِي حَدِيثِهِ قَالَ فَقَاتَلَ فِي الْجَمَاجِمِ حَتَّى قُتِلَ ‏.‏\hadithno{4642}\hadithgrade{Al-Albani: Daif Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Al-Rabi’ b. Khalid al-Dabbi said:I heard al-Hajjaj say in his address: Is the messenger of one of you sent for some need is more respectable with him or his successor among his people? I thought in my mind: I make a vow for Allah that I shall never pray behind you. If I find people who fight against you, I shall fight against you along with them. Ishaq added in his version: He fought in the battle of al-Jamajim until he was killed}}
\hadithdefcmd{abudawud}{4643}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ عَاصِمٍ، قَالَ سَمِعْتُ الْحَجَّاجَ، وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ اتَّقُوا اللَّهَ مَا اسْتَطَعْتُمْ لَيْسَ فِيهَا مَثْنَوِيَّةٌ وَاسْمَعُوا وَأَطِيعُوا لَيْسَ فِيهَا مَثْنَوِيَّةٌ لأَمِيرِ الْمُؤْمِنِينَ عَبْدِ الْمَلِكِ وَاللَّهِ لَوْ أَمَرْتُ النَّاسَ أَنْ يَخْرُجُوا مِنْ بَابٍ مِنْ أَبْوَابِ الْمَسْجِدِ فَخَرَجُوا مِنْ بَابٍ آخَرَ لَحَلَّتْ لِي دِمَاؤُهُمْ وَأَمْوَالُهُمْ وَاللَّهِ لَوْ أَخَذْتُ رَبِيعَةَ بِمُضَرَ لَكَانَ ذَلِكَ لِي مِنَ اللَّهِ حَلاَلاً وَيَا عَذِيرِي مِنْ عَبْدِ هُذَيْلٍ يَزْعُمُ أَنَّ قِرَاءَتَهُ مِنْ عِنْدِ اللَّهِ وَاللَّهِ مَا هِيَ إِلاَّ رَجَزٌ مِنْ رَجَزِ الأَعْرَابِ مَا أَنْزَلَهَا اللَّهُ عَلَى نَبِيِّهِ عَلَيْهِ السَّلاَمُ وَعَذِيرِي مِنْ هَذِهِ الْحَمْرَاءِ يَزْعُمُ أَحَدُهُمْ أَنَّهُ يَرْمِي بِالْحَجَرِ فَيَقُولُ إِلَى أَنْ يَقَعَ الْحَجَرُ قَدْ حَدَثَ أَمْرٌ فَوَاللَّهِ لأَدَعَنَّهُمْ كَالأَمْسِ الدَّابِرِ ‏.‏ قَالَ فَذَكَرْتُهُ لِلأَعْمَشِ فَقَالَ أَنَا وَاللَّهِ سَمِعْتُهُ مِنْهُ ‏.‏\hadithno{4643}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Asim said:I heard al-Hajjaj say on the pulpit: Fear Allah as much as possible; there is no exception in it. Hear and obey the Commander of the Faithful ‘Abd al-Malik; there is no exception in it. I swear by Allah, if order people to come but from a certain gate of the mosque, and they come out from another gate, their blood and their properties will be lawful for me. I swear by Allah, if I seize the tribe of Rabi’ah for the tribe of Mudar, it is lawful for me from Allah. Who will apologies to me for the slave of Hudhail (i.e. ‘Abd Allah b. Mas’ud) who thinks that his reading of the Quran is from Allah. I swear by Allah, it is a rhymed prose of the Bedouins. Allah did not reveal it to his Prophet (ﷺ). Who will apologies to me for these clients (non-Arab). One of them thinks that he will throw a stone and when it falls (on the ground) he says: Something new has happened. I swear by Allah, I shall leave them (ruined and perished) like the day that passes away. He said: I mentioned it to al-A’mash. He said: I swear by Allah, I heard it from him}}
\hadithdefcmd{abudawud}{4644}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ الْحَجَّاجَ، يَقُولُ عَلَى الْمِنْبَرِ هَذِهِ الْحَمْرَاءُ هَبْرٌ هَبْرٌ أَمَا وَاللَّهِ لَقَدْ قَرَعْتُ عَصًا بِعَصًا لأَذَرَنَّهُمْ كَالأَمْسِ الذَّاهِبِ يَعْنِي الْمَوَالِي ‏.‏\hadithno{4644}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-A’mash said:These clients (i.e., non-Arabs) are to be struck and cut off. I swear by Allah, if I strike a stick with a stick, I would annihilate them like the day that passed away. Al-hamra means clients or non-Arabs}}
\hadithdefcmd{abudawud}{4645}{حَدَّثَنَا قَطَنُ بْنُ نُسَيْرٍ، حَدَّثَنَا جَعْفَرٌ يَعْنِي ابْنَ سُلَيْمَانَ، ح حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنْ شَرِيكٍ، عَنْ سُلَيْمَانَ الأَعْمَشِ، قَالَ جَمَّعْتُ مَعَ الْحَجَّاجِ فَخَطَبَ فَذَكَرَ حَدِيثَ أَبِي بَكْرِ بْنِ عَيَّاشٍ قَالَ فِيهَا فَاسْمَعُوا وَأَطِيعُوا لِخَلِيفَةِ اللَّهِ وَصَفِيِّهِ عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ ‏.‏ وَسَاقَ الْحَدِيثَ قَالَ وَلَوْ أَخَذْتُ رَبِيعَةَ بِمُضَرَ وَلَمْ يَذْكُرْ قِصَّةَ الْحَمْرَاءِ ‏.‏\hadithno{4645}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sulaiman al-A’mash said:I prayed the Friday prayer with al-Hajjaj and he addressed. He then transmitted the tradition of Abu Bakr b. ‘Ayyash. He said in it: Hear and obey the caliph of Allah and his select ‘Abd al-Malik bin Marwan. He then transmitted the rest of the tradition, and said: If I seized Rabi’ah for Mudar. But he did not mention the story of the clients (i.e. non Arabs)}}
\hadithdefcmd{abudawud}{4646}{حَدَّثَنَا سَوَّارُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ سَعِيدِ بْنِ جُمْهَانَ، عَنْ سَفِينَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خِلاَفَةُ النُّبُوَّةِ ثَلاَثُونَ سَنَةً ثُمَّ يُؤْتِي اللَّهُ الْمُلْكَ - أَوْ مُلْكَهُ - مَنْ يَشَاءُ ‏"‏ ‏.‏ قَالَ سَعِيدٌ قَالَ لِي سَفِينَةُ أَمْسِكْ عَلَيْكَ أَبَا بَكْرٍ سَنَتَيْنِ وَعُمَرَ عَشْرًا وَعُثْمَانَ اثْنَتَىْ عَشْرَةَ وَعَلِيٌّ كَذَا ‏.‏ قَالَ سَعِيدٌ قُلْتُ لِسَفِينَةَ إِنَّ هَؤُلاَءِ يَزْعُمُونَ أَنَّ عَلِيًّا عَلَيْهِ السَّلاَمُ لَمْ يَكُنْ بِخَلِيفَةٍ ‏.‏ قَالَ كَذَبَتْ أَسْتَاهُ بَنِي الزَّرْقَاءِ يَعْنِي بَنِي مَرْوَانَ ‏.‏\hadithno{4646}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Safinah: The Prophet (ﷺ) said: The Caliphate of Prophecy will last thirty years; then Allah will give the Kingdom of His Kingdom to anyone He wills. Sa'id told that Safinah said to him: Calculate Abu Bakr's caliphate as two years, 'Umar's as ten, 'Uthman's as twelve and 'Ali so and so. Sa'id said: I said to Safinah: They conceive that 'Ali was not a caliph. He replied: The buttocks of Marwan told a lie}}
\hadithdefcmd{abudawud}{4647}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا هُشَيْمٌ، عَنِ الْعَوَّامِ بْنِ حَوْشَبٍ، عَنْ سَعِيدِ بْنِ جُمْهَانَ، عَنْ سَفِينَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خِلاَفَةُ النُّبُوَّةِ ثَلاَثُونَ سَنَةً ثُمَّ يُؤْتِي اللَّهُ الْمُلْكَ مَنْ يَشَاءُ - أَوْ مُلْكَهُ مَنْ يَشَاءُ - ‏"‏ ‏.‏\hadithno{4647}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Safinah reported the Messenger of Allah (ﷺ) as saying:The caliphate of Prophecy will last thirty years; then Allah will give the Kingdom to whom he wishes; or his kingdom to whom he wishes}}
\hadithdefcmd{abudawud}{4648}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، عَنِ ابْنِ إِدْرِيسَ، أَخْبَرَنَا حُصَيْنٌ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ عَبْدِ اللَّهِ بْنِ ظَالِمٍ، وَسُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ عَبْدِ اللَّهِ بْنِ ظَالِمٍ الْمَازِنِيِّ، قَالَ ذَكَرَ سُفْيَانُ رَجُلاً فِيمَا بَيْنَهُ وَبَيْنَ عَبْدِ اللَّهِ بْنِ ظَالِمٍ الْمَازِنِيِّ قَالَ سَمِعْتُ سَعِيدَ بْنَ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ قَالَ لَمَّا قَدِمَ فُلاَنٌ الْكُوفَةَ أَقَامَ فُلاَنٌ خَطِيبًا فَأَخَذَ بِيَدِي سَعِيدُ بْنُ زَيْدٍ فَقَالَ أَلاَ تَرَى إِلَى هَذَا الظَّالِمِ فَأَشْهَدُ عَلَى التِّسْعَةِ إِنَّهُمْ فِي الْجَنَّةِ وَلَوْ شَهِدْتُ عَلَى الْعَاشِرِ لَمْ إِيثَمْ - قَالَ ابْنُ إِدْرِيسَ وَالْعَرَبُ تَقُولُ آثَمْ - قُلْتُ وَمَنِ التِّسْعَةُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى حِرَاءٍ ‏ "‏ اثْبُتْ حِرَاءُ إِنَّهُ لَيْسَ عَلَيْكَ إِلاَّ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدٌ ‏"‏ ‏.‏ قُلْتُ وَمَنِ التِّسْعَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَطَلْحَةُ وَالزُّبَيْرُ وَسَعْدُ بْنُ أَبِي وَقَّاصٍ وَعَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ ‏.‏ قُلْتُ وَمَنِ الْعَاشِرُ فَتَلَكَّأَ هُنَيَّةً ثُمَّ قَالَ أَنَا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الأَشْجَعِيُّ عَنْ سُفْيَانَ عَنْ مَنْصُورٍ عَنْ هِلاَلِ بْنِ يِسَافٍ عَنِ ابْنِ حَيَّانَ عَنْ عَبْدِ اللَّهِ بْنِ ظَالِمٍ بِإِسْنَادِهِ ‏.‏\hadithno{4648}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sa'id ibn Zayd ibn Amr ibn Nufayl: Abdullah ibn Zalim al-Mazini said: I heard Sa'id ibn Zayd ibn Amr ibn Nufayl say: When so and so came to Kufah, and made so and so stand to address the people, Sa'id ibn Zayd caught hold of my hand and said: Are you seeing this tyrant? I bear witness to the nine people that they will go to Paradise. If I testify to the tenth too, I shall not be sinful. I asked: Who are the nine? He said: The Messenger of Allah (ﷺ) said when he was on Hira': Be still, Hira', for only a Prophet, or an ever-truthful, or a martyr is on you. I asked: Who are those nine? He said: The Messenger of Allah, AbuBakr, Umar, Uthman, Ali, Talhah, az-Zubayr, Sa'd ibn AbuWaqqas and AbdurRahman ibn Awf. I asked: Who is the tenth? He paused a moment and said: it is I. Abu Dawud said: This tradition has been transmitted by al-Ashja'i, from Sufyan, from Mansur, from Hilal b. Yasaf, from Ibn Hayyan on the authority of 'Abd Allah b. Zalim through his different chain of narrators in a a similar manner}}
\hadithdefcmd{abudawud}{4649}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحُرِّ بْنِ الصَّيَّاحِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَخْنَسِ، أَنَّهُ كَانَ فِي الْمَسْجِدِ فَذَكَرَ رَجُلٌ عَلِيًّا عَلَيْهِ السَّلاَمُ فَقَامَ سَعِيدُ بْنُ زَيْدٍ فَقَالَ أَشْهَدُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِّي سَمِعْتُهُ وَهُوَ يَقُولُ ‏ "‏ عَشْرَةٌ فِي الْجَنَّةِ النَّبِيُّ فِي الْجَنَّةِ وَأَبُو بَكْرٍ فِي الْجَنَّةِ وَعُمَرُ فِي الْجَنَّةِ وَعُثْمَانُ فِي الْجَنَّةِ وَعَلِيٌّ فِي الْجَنَّةِ وَطَلْحَةُ فِي الْجَنَّةِ وَالزُّبَيْرُ بْنُ الْعَوَّامِ فِي الْجَنَّةِ وَسَعْدُ بْنُ مَالِكٍ فِي الْجَنَّةِ وَعَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ فِي الْجَنَّةِ ‏"‏ ‏.‏ وَلَوْ شِئْتَ لَسَمَّيْتُ الْعَاشِرَ ‏.‏ قَالَ فَقَالُوا مَنْ هُوَ فَسَكَتَ قَالَ فَقَالُوا مَنْ هُوَ فَقَالَ هُوَ سَعِيدُ بْنُ زَيْدٍ ‏.‏\hadithno{4649}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sa'id ibn Zayd: AbdurRahman ibn al-Akhnas said that when he was in the mosque, a man mentioned Ali (may Allah be pleased with him). So Sa'id ibn Zayd got up and said: I bear witness to the Messenger of Allah (ﷺ) that I heard him say: Ten persons will go to Paradise: The Prophet (ﷺ) will go to Paradise, AbuBakr will go to Paradise, Umar will go to Paradise, Uthman will go to Paradise, Ali will go to Paradise, Talhah will go to Paradise: az-Zubayr ibn al-Awwam will go to paradise, Sa'd ibn Malik will go to Paradise, and AbdurRahman ibn Awf will go to Paradise. If I wish, I can mention the tenth. The People asked: Who is he: So he kept silence. The again asked: Who is he: He replied: He is Sa'id ibn Zayd}}
\hadithdefcmd{abudawud}{4650}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا صَدَقَةُ بْنُ الْمُثَنَّى النَّخَعِيُّ، حَدَّثَنِي جَدِّي، رِيَاحُ بْنُ الْحَارِثِ قَالَ كُنْتُ قَاعِدًا عِنْدَ فُلاَنٍ فِي مَسْجِدِ الْكُوفَةِ وَعِنْدَهُ أَهْلُ الْكُوفَةِ فَجَاءَ سَعِيدُ بْنُ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ فَرَحَّبَ بِهِ وَحَيَّاهُ وَأَقْعَدَهُ عِنْدَ رِجْلِهِ عَلَى السَّرِيرِ فَجَاءَ رَجُلٌ مِنْ أَهْلِ الْكُوفَةِ يُقَالُ لَهُ قَيْسُ بْنُ عَلْقَمَةَ فَاسْتَقْبَلَهُ فَسَبَّ وَسَبَّ فَقَالَ سَعِيدٌ مَنْ يَسُبُّ هَذَا الرَّجُلُ قَالَ يَسُبُّ عَلِيًّا ‏.‏ قَالَ أَلاَ أَرَى أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم يُسَبُّونَ عِنْدَكَ ثُمَّ لاَ تُنْكِرُ وَلاَ تُغَيِّرُ أَنَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَإِنِّي لَغَنِيٌّ أَنْ أَقُولَ عَلَيْهِ مَا لَمْ يَقُلْ فَيَسْأَلُنِي عَنْهُ غَدًا إِذَا لَقِيتُهُ ‏ "‏ أَبُو بَكْرٍ فِي الْجَنَّةِ وَعُمَرُ فِي الْجَنَّةِ ‏"‏ ‏.‏ وَسَاقَ مَعْنَاهُ ثُمَّ قَالَ لَمَشْهَدُ رَجُلٍ مِنْهُمْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَغْبَرُّ فِيهِ وَجْهُهُ خَيْرٌ مِنْ عَمَلِ أَحَدِكُمْ عُمْرَهُ وَلَوْ عُمِّرَ عُمْرَ نُوحٍ ‏.‏\hadithno{4650}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Rabah ibn al-Harith said:I was sitting with someone in the mosque of Kufah while the people of Kufah were with him. Then Sa'id ibn Zayd ibn Amr ibn Nufayl came and he welcomed him, greeted him, and seated him near his foot on the throne. Then a man of the inhabitants of Kufah, called Qays ibn Alqamah, came. He received him and began to abuse him. Sa'id asked: Whom is this man abusing? He replied: He is abusing Ali. He said: Don't I see that the companions of the Messenger of Allah (ﷺ) are being abused, but you neither stop it nor do anything about it? I heard the Messenger of Allah (ﷺ) say--and I need not say for him anything which he did not say, and then he would ask me tomorrow when I see him --AbuBakr will go to Paradise and Umar will go to Paradise. He then mentioned the rest of the tradition to the same effect (as in No. 4632). He then said: The company of one of their man whose face has been covered with dust by the Messenger of Allah (ﷺ) is better than the actions of one of you for a whole life time even if he is granted the life-span of Noah}}
\hadithdefcmd{abudawud}{4651}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، - الْمَعْنَى - قَالاَ حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم صَعِدَ أُحُدًا فَتَبِعَهُ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ فَرَجَفَ بِهِمْ فَضَرَبَهُ نَبِيُّ اللَّهِ صلى الله عليه وسلم بِرِجْلِهِ وَقَالَ ‏ "‏ اثْبُتْ أُحُدُ نَبِيٌّ وَصِدِّيقٌ وَشَهِيدَانِ ‏"‏ ‏.‏\hadithno{4651}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (3697)}\hadithtrans{Anas b. malik said:The prophet of Allah (ﷺ) ascended Uhud, and Abu Bakr, ’Umar and 'Uthman followed him. It began to shake with them. The prophet of Allah (ﷺ) struck it with his foot and said: Be still, for only a prophet, an ever-truthful and two martyrs are on you}}
\hadithdefcmd{abudawud}{4652}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُحَمَّدٍ الْمُحَارِبِيِّ، عَنْ عَبْدِ السَّلاَمِ بْنِ حَرْبٍ، عَنْ أَبِي خَالِدٍ الدَّالاَنِيِّ، عَنْ أَبِي خَالِدٍ، مَوْلَى آلِ جَعْدَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَانِي جِبْرِيلُ فَأَخَذَ بِيَدِي فَأَرَانِي بَابَ الْجَنَّةِ الَّذِي تَدْخُلُ مِنْهُ أُمَّتِي ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ وَدِدْتُ أَنِّي كُنْتُ مَعَكَ حَتَّى أَنْظُرَ إِلَيْهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا إِنَّكَ يَا أَبَا بَكْرٍ أَوَّلُ مَنْ يَدْخُلُ الْجَنَّةَ مِنْ أُمَّتِي ‏"‏ ‏.‏\hadithno{4652}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Gabriel came and taking me by the hand showed the gate of Paradise by which my people will enter. AbuBakr then said: Messenger of Allah! I wish I had been with you so that I might have looked at it. The Messenger of Allah (ﷺ) then said: You, AbuBakr, will be the first of my people to enter Paradise}}
\hadithdefcmd{abudawud}{4653}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ خَالِدٍ الرَّمْلِيُّ، أَنَّ اللَّيْثَ، حَدَّثَهُمْ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَدْخُلُ النَّارَ أَحَدٌ مِمَّنْ بَايَعَ تَحْتَ الشَّجَرَةِ ‏"‏ ‏.‏\hadithno{4653}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir reported the Messenger of Allah (ﷺ) as saying:No one of those who took the oath of allegiance under the tree will go to hell}}
\hadithdefcmd{abudawud}{4654}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَاصِمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ مُوسَى ‏"‏ فَلَعَلَّ اللَّهَ ‏"‏ ‏.‏ وَقَالَ ابْنُ سِنَانٍ ‏"‏ اطَّلَعَ اللَّهُ عَلَى أَهْلِ بَدْرٍ فَقَالَ اعْمَلُوا مَا شِئْتُمْ فَقَدْ غَفَرْتُ لَكُمْ ‏"‏ ‏.‏\hadithno{4654}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying – will be according to the version of Musa :Perhaps Allah, and Ibn Sinan’s version has : Allah looked at the participants of the battle of Badr (with mercy) and said : Do whatever you wish ; I have forgiven you}}
\hadithdefcmd{abudawud}{4655}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، أَنَّ مُحَمَّدَ بْنَ ثَوْرٍ، حَدَّثَهُمْ عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم زَمَنَ الْحُدَيْبِيَةِ فَذَكَرَ الْحَدِيثَ ‏.‏ قَالَ فَأَتَاهُ - يَعْنِي عُرْوَةَ بْنَ مَسْعُودٍ - فَجَعَلَ يُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم فَكُلَّمَا كَلَّمَهُ أَخَذَ بِلِحْيَتِهِ وَالْمُغِيرَةُ بْنُ شُعْبَةَ قَائِمٌ عَلَى رَأْسِ النَّبِيِّ صلى الله عليه وسلم وَمَعَهُ السَّيْفُ وَعَلَيْهِ الْمِغْفَرُ فَضَرَبَ يَدَهُ بِنَعْلِ السَّيْفِ وَقَالَ أَخِّرْ يَدَكَ عَنْ لِحْيَتِهِ ‏.‏ فَرَفَعَ عُرْوَةُ رَأْسَهُ فَقَالَ مَنْ هَذَا قَالُوا الْمُغِيرَةُ بْنُ شُعْبَةَ ‏.‏\hadithno{4655}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Al-Miswar b. Makhramah said :The prophet (ﷺ) went out during the time of (treaty of) al-Hudaibiyyah. He then mentioned the rest of the tradition. He said : ‘Urwah b. Mas’ud then came to him and began to speak to the Prophet (ﷺ). Whenever he talk to him, he caught his beard ; and al-Mughirah b. Shu’bah was standing near the head of the Prophet (ﷺ) with a sword with him and a helmet on him. He then struck his hand with the handle of the sword, saying : Keep away your hand from his beard. ‘Urwah then raised his head and said : Who is this ? The prophet said : Al-Mughirah b. Shu’bah}}
\hadithdefcmd{abudawud}{4656}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ أَبُو عُمَرَ الضَّرِيرُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَنَّ سَعِيدَ بْنَ إِيَاسٍ الْجُرَيْرِيَّ، أَخْبَرَهُمْ عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ الْعُقَيْلِيِّ، عَنِ الأَقْرَعِ، مُؤَذِّنِ عُمَرَ بْنِ الْخَطَّابِ قَالَ بَعَثَنِي عُمَرُ إِلَى الأُسْقُفِّ فَدَعَوْتُهُ فَقَالَ لَهُ عُمَرُ وَهَلْ تَجِدُنِي فِي الْكِتَابِ قَالَ نَعَمْ ‏.‏ قَالَ كَيْفَ تَجِدُنِي قَالَ أَجِدُكَ قَرْنًا ‏.‏ فَرَفَعَ عَلَيْهِ الدِّرَّةَ فَقَالَ قَرْنُ مَهْ فَقَالَ قَرْنٌ حَدِيدٌ أَمِينٌ شَدِيدٌ ‏.‏ قَالَ كَيْفَ تَجِدُ الَّذِي يَجِيءُ مِنْ بَعْدِي فَقَالَ أَجِدُهُ خَلِيفَةً صَالِحًا غَيْرَ أَنَّهُ يُؤْثِرُ قَرَابَتَهُ ‏.‏ قَالَ عُمَرُ يَرْحَمُ اللَّهُ عُثْمَانَ ثَلاَثًا فَقَالَ كَيْفَ تَجِدُ الَّذِي بَعْدَهُ قَالَ أَجِدُهُ صَدَأَ حَدِيدٍ فَوَضَعَ عُمَرُ يَدَهُ عَلَى رَأْسِهِ فَقَالَ يَا دَفْرَاهُ يَا دَفْرَاهُ ‏.‏ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّهُ خَلِيفَةٌ صَالِحٌ وَلَكِنَّهُ يُسْتَخْلَفُ حِينَ يُسْتَخْلَفُ وَالسَّيْفُ مَسْلُولٌ وَالدَّمُ مُهْرَاقٌ ‏.‏ قَالَ أَبُو دَاوُدَ الدَّفْرُ النَّتْنُ ‏.‏\hadithno{4656}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umar ibn al-Khattab: Al-Aqra', the mu'adhdhin (announcer) of Umar ibn al-Khattab said: Umar sent me to a bishop and I called him. Umar said to him: Do you find me in the Book? He said: Yes. He asked: How do you find me? He said: I find you (like a) castle. Then he raised a whip to him, saying: What do you mean by castle? He replied: An iron castle and severely trustworthy. He asked: How do you find the one who will come after me? He said: I find him a pious caliph, except that he will prefer his relatives. Umar said: May Allah have mercy on Uthman: He said it three times. He then asked: How do you find the one who will come after him? He replied: I find him like rusty iron. Umar then put his hand on his head, and said: O filthy! O filthy! He said: Commander of the Faithful! He is a pious caliph, but when he is made caliph, the sword will be unsheathed and blood will be shed. Abu Dawud said: Al-dafr means filth or evil smell}}
\hadithdefcmd{abudawud}{4657}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ أَنْبَأَنَا ح، وَحَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ أُمَّتِي الْقَرْنُ الَّذِينَ بُعِثْتُ فِيهِمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ وَاللَّهُ أَعْلَمُ أَذَكَرَ الثَّالِثَ أَمْ لاَ ‏"‏ ثُمَّ يَظْهَرُ قَوْمٌ يَشْهَدُونَ وَلاَ يُسْتَشْهَدُونَ وَيَنْذِرُونَ وَلاَ يُوفُونَ وَيَخُونُونَ وَلاَ يُؤْتَمَنُونَ وَيَفْشُو فِيهِمُ السِّمَنُ ‏"‏ ‏.‏\hadithno{4657}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2535)}\hadithtrans{‘Imran b. Husain reported the Messenger of Allah (ﷺ) as saying :the best of my people is the generation in which I have been sent, then their immediate followers, then their immediate followers. Allah knows best whether he mentioned the third or not. After them will be people who will give testimony without being asked, who will make vows which they do not fulfill, who will be treacherous and not to be trusted, among whom fatness will appear}}
\hadithdefcmd{abudawud}{4658}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا أَصْحَابِي فَوَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَنْفَقَ أَحَدُكُمْ مِثْلَ أُحُدٍ ذَهَبًا مَا بَلَغَ مُدَّ أَحَدِهِمْ وَلاَ نَصِيفَهُ ‏"‏ ‏.‏\hadithno{4658}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3673) Sahih Muslim (2541)}\hadithtrans{Abu Sa’id (al-Khudri) reported the Messenger of Allah (May peace be upon him) as saying :Do not revile my Companions; by him in whose hand my soul is, if one of you contributed the amount of gold equivalent to Uhud, it would not amount to as much as the mudd of one of them, or half of it}}
\hadithdefcmd{abudawud}{4659}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زَائِدَةُ بْنُ قُدَامَةَ الثَّقَفِيُّ، حَدَّثَنَا عُمَرُ بْنُ قَيْسٍ الْمَاصِرُ، عَنْ عَمْرِو بْنِ أَبِي قُرَّةَ، قَالَ كَانَ حُذَيْفَةُ بِالْمَدَائِنِ فَكَانَ يَذْكُرُ أَشْيَاءَ قَالَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لأُنَاسٍ مِنْ أَصْحَابِهِ فِي الْغَضَبِ فَيَنْطَلِقُ نَاسٌ مِمَّنْ سَمِعَ ذَلِكَ مِنْ حُذَيْفَةَ فَيَأْتُونَ سَلْمَانَ فَيَذْكُرُونَ لَهُ قَوْلَ حُذَيْفَةَ فَيَقُولُ سَلْمَانُ حُذَيْفَةُ أَعْلَمُ بِمَا يَقُولُ فَيَرْجِعُونَ إِلَى حُذَيْفَةَ فَيَقُولُونَ لَهُ قَدْ ذَكَرْنَا قَوْلَكَ لِسَلْمَانَ فَمَا صَدَّقَكَ وَلاَ كَذَّبَكَ ‏.‏ فَأَتَى حُذَيْفَةُ سَلْمَانَ وَهُوَ فِي مَبْقَلَةٍ فَقَالَ يَا سَلْمَانُ مَا يَمْنَعُكَ أَنْ تُصَدِّقَنِي بِمَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ سَلْمَانُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْضَبُ فَيَقُولُ فِي الْغَضَبِ لِنَاسٍ مِنْ أَصْحَابِهِ وَيَرْضَى فَيَقُولُ فِي الرِّضَا لِنَاسٍ مِنْ أَصْحَابِهِ أَمَا تَنْتَهِي حَتَّى تُوَرِّثَ رِجَالاً حُبَّ رِجَالٍ وَرِجَالاً بُغْضَ رِجَالٍ وَحَتَّى تُوقِعَ اخْتِلاَفًا وَفُرْقَةً وَلَقَدْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ فَقَالَ ‏ "‏ أَيُّمَا رَجُلٍ مِنْ أُمَّتِي سَبَبْتُهُ سَبَّةً أَوْ لَعَنْتُهُ لَعْنَةً فِي غَضَبِي - فَإِنَّمَا أَنَا مِنْ وَلَدِ آدَمَ أَغْضَبُ كَمَا يَغْضَبُونَ وَإِنَّمَا بَعَثَنِي رَحْمَةً لِلْعَالَمِينَ - فَاجْعَلْهَا عَلَيْهِمْ صَلاَةً يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَاللَّهِ لَتَنْتَهِيَنَّ أَوْ لأَكْتُبَنَّ إِلَى عُمَرَ ‏.‏\hadithno{4659}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Amr b. Abl Qurrah said :Hudhaifah was in al-Mada’in. He used to mention things which the Messenger of Allah (May peace be upon him) said to some people from among his Companions in anger. The people who heard from Hudhaifah would go to Salman and tell him what Hudhaifah said. Salman would say: Hudhaifah knows best what he says. Then they would come to Hudhaifah and tell him: We mentioned Salman what you said, but he neither testified you nor falsified you. So Hudhaifah came to salman who was in his vegetable farm, and said : Salman, what prevents you from testifying me of what I heard from the Messenger of Allah (May peace be upon him) ? Salman said: The Messenger of Allah (May peace be upon him) sometimes would be angry, and said in anger something to some of his Companions; he would be sometimes pleased and said in pleasure something to some of his Companions. Would you not stop until you create love of some people in the hearts of some people, and hatred of some people in the hearts of some people, and until you generate disagreement and dissension? You know that the Messenger of Allah (May peace be upon him) addressed, saying : If I abused any person of my people, or cursed him in my anger. I am one of the children of Adam : I become angry as they become angry. He (Allah) has sent me as a mercy for all worlds. (O Allah!) make them (Abuse or curse) blessing for them on the day of judgment! I swear by Allah. You should stop (mentioning these traditions), otherwise I shall writ to ‘Umar}}
\hadithdefcmd{abudawud}{4660}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، حَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، قَالَ لَمَّا اسْتُعِزَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا عِنْدَهُ فِي نَفَرٍ مِنَ الْمُسْلِمِينَ دَعَاهُ بِلاَلٌ إِلَى الصَّلاَةِ فَقَالَ مُرُوا مَنْ يُصَلِّي لِلنَّاسِ ‏.‏ فَخَرَجَ عَبْدُ اللَّهِ بْنُ زَمَعَةَ فَإِذَا عُمَرُ فِي النَّاسِ وَكَانَ أَبُو بَكْرٍ غَائِبًا فَقُلْتُ يَا عُمَرُ قُمْ فَصَلِّ بِالنَّاسِ فَتَقَدَّمَ فَكَبَّرَ فَلَمَّا سَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَوْتَهُ وَكَانَ عُمَرُ رَجُلاً مُجْهِرًا قَالَ ‏ "‏ فَأَيْنَ أَبُو بَكْرٍ يَأْبَى اللَّهُ ذَلِكَ وَالْمُسْلِمُونَ يَأْبَى اللَّهُ ذَلِكَ وَالْمُسْلِمُونَ ‏"‏ ‏.‏ فَبَعَثَ إِلَى أَبِي بَكْرٍ فَجَاءَ بَعْدَ أَنْ صَلَّى عُمَرُ تِلْكَ الصَّلاَةَ فَصَلَّى بِالنَّاسِ ‏.‏\hadithno{4660}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Zam'ah: When the illness of the Messenger of Allah (ﷺ) became serious while I was with him among a group of people, Bilal called him for prayer. He said: Ask someone to lead the people in prayer. So Abdullah ibn Zam'ah went out and found that Umar was present among the people and AbuBakr was not there. I said: Umar, get up and lead the people in prayer. So he came forward and uttered "Allah is Most Great". When the Messenger of Allah (ﷺ) heard his voice, as Umar had a loud voice, he said: Where is AbuBakr? Allah does not allow that, and the Muslims too; Allah does not allow that, and the Muslims too. So he sent for AbuBakr. He came after Umar had led the people in that prayer. He then led the people in prayer}}
\hadithdefcmd{abudawud}{4661}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، قَالَ حَدَّثَنِي مُوسَى بْنُ يَعْقُوبَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ زَمْعَةَ، أَخْبَرَهُ بِهَذَا الْخَبَرِ، قَالَ لَمَّا سَمِعَ النَّبِيُّ صلى الله عليه وسلم صَوْتَ عُمَرَ قَالَ ابْنُ زَمَعَةَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم حَتَّى أَطْلَعَ رَأْسَهُ مِنْ حُجْرَتِهِ ثُمَّ قَالَ ‏ "‏ لاَ لاَ لاَ لِيُصَلِّ لِلنَّاسِ ابْنُ أَبِي قُحَافَةَ ‏"‏ ‏.‏ يَقُولُ ذَلِكَ مُغْضَبًا ‏.‏\hadithno{4661}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by ‘Abd Allah b. Zam’ah through a different chain. He said:When the Prophet (May peace be upon him) heard ‘Umar’s voice, Ibn Zam’ah said: The Prophet (May peace be upon him) came out until he took out his head of his apartment. He then said : No, no, no; the son of Abu Quhafah should lead the people in prayer. He said it angrily}}
\hadithdefcmd{abudawud}{4662}{حَدَّثَنَا مُسَدَّدٌ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، قَالَ حَدَّثَنِي الأَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْحَسَنِ بْنِ عَلِيٍّ ‏"‏ إِنَّ ابْنِي هَذَا سَيِّدٌ وَإِنِّي أَرْجُو أَنْ يُصْلِحَ اللَّهُ بِهِ بَيْنَ فِئَتَيْنِ مِنْ أُمَّتِي ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِ حَمَّادٍ ‏"‏ وَلَعَلَّ اللَّهَ أَنْ يُصْلِحَ بِهِ بَيْنَ فِئَتَيْنِ مِنَ الْمُسْلِمِينَ عَظِيمَتَيْنِ ‏"‏ ‏.‏\hadithno{4662}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuBakrah: The Messenger of Allah (ﷺ) said to al-Hasan ibn Ali. This son of mine is a Sayyid (chief), and I hope Allah may reconcile two parties of my community by means of him. Hammad's version has: And perhaps Allah may reconcile two large parties of Muslims by means of him}}
\hadithdefcmd{abudawud}{4663}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ، أَخْبَرَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، قَالَ قَالَ حُذَيْفَةُ مَا أَحَدٌ مِنَ النَّاسِ تُدْرِكُهُ الْفِتْنَةُ إِلاَّ أَنَا أَخَافُهَا عَلَيْهِ إِلاَّ مُحَمَّدُ بْنُ مَسْلَمَةَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَضُرُّكَ الْفِتْنَةُ ‏"‏ ‏.‏\hadithno{4663}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hudhayfah: There is no one who will be overtaken by trial regarding whom I do not fear except Muhammad ibn Maslamah, for I heard the Messenger of Allah (ﷺ) say: Trial will not harm you}}
\hadithdefcmd{abudawud}{4664}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنِ الأَشْعَثِ بْنِ سُلَيْمٍ، عَنْ أَبِي بُرْدَةَ، عَنْ ثَعْلَبَةَ بْنِ ضُبَيْعَةَ، قَالَ دَخَلْنَا عَلَى حُذَيْفَةَ فَقَالَ إِنِّي لأَعْرِفُ رَجُلاً لاَ تَضُرُّهُ الْفِتَنُ شَيْئًا ‏.‏ قَالَ فَخَرَجْنَا فَإِذَا فُسْطَاطٌ مَضْرُوبٌ فَدَخَلْنَا فَإِذَا فِيهِ مُحَمَّدُ بْنُ مَسْلَمَةَ فَسَأَلْنَاهُ عَنْ ذَلِكَ فَقَالَ مَا أُرِيدُ أَنْ يَشْتَمِلَ عَلَىَّ شَىْءٌ مِنْ أَمْصَارِكُمْ حَتَّى تَنْجَلِيَ عَمَّا انْجَلَتْ ‏.‏\hadithno{4664}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Tha’labah b. Dubai’ah said:We entered upon Hudhaifah. He said: I know a man whom the trails will not harm. We came out and found that a tent was pitched. We entered and found in it Muhammad b. Maslamah. We asked him about it. He said : I do not intent that any place of your towns should occupy me until that which is prevailing is removed}}
\hadithdefcmd{abudawud}{4665}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَشْعَثَ بْنِ سُلَيْمٍ، عَنْ أَبِي بُرْدَةَ، عَنْ ضُبَيْعَةَ بْنِ حُصَيْنٍ الثَّعْلَبِيِّ، بِمَعْنَاهُ ‏.‏\hadithno{4665}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Dubai’ah b. Husain al-Tha’labi through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{4666}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الْهُذَلِيُّ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ قَيْسِ بْنِ عُبَادٍ، قَالَ قُلْتُ لِعَلِيٍّ رضى الله عنه أَخْبِرْنَا عَنْ مَسِيرِكَ هَذَا أَعَهْدٌ عَهِدَهُ إِلَيْكَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَمْ رَأْىٌ رَأَيْتَهُ فَقَالَ مَا عَهِدَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَىْءٍ وَلَكِنَّهُ رَأْىٌ رَأَيْتُهُ ‏.‏\hadithno{4666}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Qais b. ‘Abbad said :I said to ‘All (Allah be pleased with him) : Tell me about this march of yours. Is this an order that the Messenger of Allah (May peace be upon him) had given you, or is this your opinion that you have? He said: The Messenger of Allah (May peace be upon him) did not give me any order; but this is an opinion that I have}}
\hadithdefcmd{abudawud}{4667}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْقَاسِمُ بْنُ الْفَضْلِ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَمْرُقُ مَارِقَةٌ عِنْدَ فُرْقَةٍ مِنَ الْمُسْلِمِينَ يَقْتُلُهَا أَوْلَى الطَّائِفَتَيْنِ بِالْحَقِّ ‏"‏ ‏.‏\hadithno{4667}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1065)}\hadithtrans{Abu Sa’id reported the Messenger of Allah (May peace be upon him) as saying:In the event of the dissension among Muslims an emerging sect will emerge ; one of the two parties that is nearer to the truth will kill it}}
\hadithdefcmd{abudawud}{4668}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرٌو، - يَعْنِي ابْنَ يَحْيَى - عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُخَيِّرُوا بَيْنَ الأَنْبِيَاءِ ‏"‏ ‏.‏\hadithno{4668}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2412) Sahih Muslim (2374)}\hadithtrans{Abu Sa’id al-Khudri reported the Messenger of Allah (May peace be upon him) as saying :Do not distinguish between the Prophets}}
\hadithdefcmd{abudawud}{4669}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ إِنِّي خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏ ‏.‏\hadithno{4669}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3413) Sahih Muslim (2377)}\hadithtrans{Ibn ‘Abbas reported the Prophet (May peace be upon him) as saying :It is not fitting for a servent to say that I (The Prophet) is better than Jonah son of Matta}}
\hadithdefcmd{abudawud}{4670}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا يَنْبَغِي لِنَبِيٍّ أَنْ يَقُولَ إِنِّي خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏ ‏.‏\hadithno{4670}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{‘Abd Allah b. Ja’far reported the Messenger of Allah (May peace be upon him) as saying:It is not fitting for a prophet to say : I am better than Jonah son of matta}}
\hadithdefcmd{abudawud}{4671}{حَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ، وَمُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَعَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَجُلٌ مِنَ الْيَهُودِ وَالَّذِي اصْطَفَى مُوسَى ‏.‏ فَرَفَعَ الْمُسْلِمُ يَدَهُ فَلَطَمَ وَجْهَ الْيَهُودِيِّ فَذَهَبَ الْيَهُودِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُخَيِّرُونِي عَلَى مُوسَى فَإِنَّ النَّاسَ يُصْعَقُونَ فَأَكُونُ أَوَّلَ مَنْ يُفِيقُ فَإِذَا مُوسَى بَاطِشٌ فِي جَانِبِ الْعَرْشِ فَلاَ أَدْرِي أَكَانَ مِمَّنْ صَعِقَ فَأَفَاقَ قَبْلِي أَوْ كَانَ مِمَّنِ اسْتَثْنَى اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ ابْنِ يَحْيَى أَتَمُّ ‏.‏\hadithno{4671}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2411) Sahih Muslim (2377)}\hadithtrans{‘Abu Hurairah said :A man from among the Jews said : By him who chose Moses above the universe. So a Muslim raised his hand and slapped the Jew on his face. The Jew went to the Messenger of Allah (May peace be upon him) and informed him. The Prophet (May peace be upon him) said: Do not make me superior to Moses, for mankind (on the Day of Resurrection) will swoon and I will be the know whether he was among those who swooned and had recovered before me, or he was among those of whom Allah had made an exception. Abu Dawud said : The tradition of Ibn yahya is more perfect}}
\hadithdefcmd{abudawud}{4672}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُخْتَارِ بْنِ فُلْفُلٍ، يَذْكُرُ عَنْ أَنَسٍ، قَالَ قَالَ رَجُلٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا خَيْرَ الْبَرِيَّةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ذَاكَ إِبْرَاهِيمُ ‏"‏ ‏.‏\hadithno{4672}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2369)}\hadithtrans{Anas said:A man said to the Messenger of Allah (May peace be upon him): O best of all creatures! The Messenger of Allah (May peace be upon him) said : That was Abraham (peace be upon him)}}
\hadithdefcmd{abudawud}{4673}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنْ أَبِي عَمَّارٍ، عَنْ عَبْدِ اللَّهِ بْنِ فَرُّوخَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا سَيِّدُ وَلَدِ آدَمَ وَأَوَّلُ مَنْ تَنْشَقُّ عَنْهُ الأَرْضُ وَأَوَّلُ شَافِعٍ وَأَوَّلُ مُشَفَّعٍ ‏"‏ ‏.‏\hadithno{4673}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2278)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :I shall be pre-eminent among the descendants of Adam, the first from whom the earth will be cleft open the first intercessor, and the first whose intercession will be accepted}}
\hadithdefcmd{abudawud}{4674}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، وَمَخْلَدُ بْنُ خَالِدٍ الشَّعِيرِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَدْرِي أَتُبَّعٌ لَعِينٌ هُوَ أَمْ لاَ وَمَا أَدْرِي أَعُزَيْرٌ نَبِيٌّ هُوَ أَمْ لاَ ‏"‏ ‏.‏\hadithno{4674}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :I do not know whether Tubba was accursed or not, and ‘Uzair (Azra was a prophet or not)}}
\hadithdefcmd{abudawud}{4675}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا أَوْلَى النَّاسِ بِابْنِ مَرْيَمَ الأَنْبِيَاءُ أَوْلاَدُ عَلاَّتٍ وَلَيْسَ بَيْنِي وَبَيْنَهُ نَبِيٌّ ‏"‏ ‏.‏\hadithno{4675}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3442) Sahih Muslim (2365)}\hadithtrans{Abu Hurairah said :I heard the Messenger of Allah (May peace be upon him) say : I am the nearest of kin among the people to (Jesus) son of Mary. The Prophet are brothers, sons of one father by co-wives. There is no Prophet between me and him}}
\hadithdefcmd{abudawud}{4676}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الإِيمَانُ بِضْعٌ وَسَبْعُونَ أَفْضَلُهَا قَوْلُ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَدْنَاهَا إِمَاطَةُ الْعَظْمِ عَنِ الطَّرِيقِ وَالْحَيَاءُ شُعْبَةٌ مِنَ الإِيمَانِ ‏"‏ ‏.‏\hadithno{4676}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (35)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :Faith has over seventy branches, the most excellent of which is the declaration that there is no god but Allah, and the humblest of which is the removal of a bone from the road. And modesty is a branch of faith}}
\hadithdefcmd{abudawud}{4677}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، حَدَّثَنِي أَبُو جَمْرَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، قَالَ إِنَّ وَفْدَ عَبْدِ الْقَيْسِ لَمَّا قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَمَرَهُمْ بِالإِيمَانِ بِاللَّهِ قَالَ ‏"‏ أَتَدْرُونَ مَا الإِيمَانُ بِاللَّهِ ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ قَالَ ‏"‏ شَهَادَةُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ وَإِقَامُ الصَّلاَةِ وَإِيتَاءُ الزَّكَاةِ وَصَوْمُ رَمَضَانَ وَأَنْ تُعْطُوا الْخُمُسَ مِنَ الْمَغْنَمِ ‏"‏ ‏.‏\hadithno{4677}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (53) Sahih Muslim (17)}\hadithtrans{Ibn ‘Abbas said :When the deputation of ‘Abd al-Qais came to the Messenger of Allah (May peace be upon him), he commanded them to believe in Allah. He asked : Do you know what faith in Allah is? They replied : Allah and his Apostle know best. He said: It includes the testimony that there is no god but Allah, and that Muhammad is Allah’s Apostle, the observance of the prayer, the payment of zakat, the fasts of Ramadan, and your giving a fifth of the booty}}
\hadithdefcmd{abudawud}{4678}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَ الْعَبْدِ وَبَيْنَ الْكُفْرِ تَرْكُ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{4678}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir reported the Messenger of Allah (May peace be upon him) as saying :Between a servant and unbelief there is the abandonment of prayer}}
\hadithdefcmd{abudawud}{4679}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ بَكْرِ بْنِ مُضَرَ، عَنِ ابْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا رَأَيْتُ مِنْ نَاقِصَاتِ عَقْلٍ وَلاَ دِينٍ أَغْلَبَ لِذِي لُبٍّ مِنْكُنَّ ‏"‏ ‏.‏ قَالَتْ وَمَا نُقْصَانُ الْعَقْلِ وَالدِّينِ قَالَ ‏"‏ أَمَّا نُقْصَانُ الْعَقْلِ فَشَهَادَةُ امْرَأَتَيْنِ شَهَادَةُ رَجُلٍ وَأَمَّا نُقْصَانُ الدِّينِ فَإِنَّ إِحْدَاكُنَّ تُفْطِرُ رَمَضَانَ وَتُقِيمُ أَيَّامًا لاَ تُصَلِّي ‏"‏ ‏.‏\hadithno{4679}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (79)}\hadithtrans{Abd Allah b. 'Umar reported the Messenger of Allah (ﷺ) as saying:I did not see more defective in respect of reason and religion than the wise of you (women). A woman asked: What is the defect of reason and religion ? He replied: The defect of reason is the testimony of two women for one man, and the defect of faith is that one of you does not fast during Ramadan (when one is menstruating), and keep away from prayer for some days}}
\hadithdefcmd{abudawud}{4680}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا تَوَجَّهَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْكَعْبَةِ قَالُوا يَا رَسُولَ اللَّهِ فَكَيْفَ الَّذِينَ مَاتُوا وَهُمْ يُصَلُّونَ إِلَى بَيْتِ الْمَقْدِسِ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ وَمَا كَانَ اللَّهُ لِيُضِيعَ إِيمَانَكُمْ ‏\}‏ ‏.‏\hadithno{4680}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn ‘Abbas said:when the Prophet (May peace be upon him) turned towards the Ka’bah (in prayer), the people asked : Messenger of Allah (May peace be upon him)! what will happen with those who died while they prayed with their faces towards Jerusalem ? Allah the Exalted, then revealed : “And never would Allah make your faith of no effect.”}}
\hadithdefcmd{abudawud}{4681}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبِ بْنِ شَابُورٍ، عَنْ يَحْيَى بْنِ الْحَارِثِ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ أَحَبَّ لِلَّهِ وَأَبْغَضَ لِلَّهِ وَأَعْطَى لِلَّهِ وَمَنَعَ لِلَّهِ فَقَدِ اسْتَكْمَلَ الإِيمَانَ ‏"‏ ‏.‏\hadithno{4681}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuUmamah: The Prophet (ﷺ) said: If anyone loves for Allah's sake, hates for Allah's sake, gives for Allah's sake and withholds for Allah's sake, he will have perfect faith}}
\hadithdefcmd{abudawud}{4682}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَكْمَلُ الْمُؤْمِنِينَ إِيمَانًا أَحْسَنُهُمْ خُلُقًا ‏"‏ ‏.‏\hadithno{4682}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The most perfect believer in respect of faith is he who is best of them in manners}}
\hadithdefcmd{abudawud}{4683}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، قَالَ وَأَخْبَرَنِي الزُّهْرِيُّ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، قَالَ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم رِجَالاً وَلَمْ يُعْطِ رَجُلاً مِنْهُمْ شَيْئًا فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ أَعْطَيْتَ فُلاَنًا وَفُلاَنًا وَلَمْ تُعْطِ فُلاَنًا شَيْئًا وَهُوَ مُؤْمِنٌ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَوْ مُسْلِمٌ ‏"‏ ‏.‏ حَتَّى أَعَادَهَا سَعْدٌ ثَلاَثًا وَالنَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ أَوْ مُسْلِمٌ ‏"‏ ‏.‏ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي أُعْطِي رِجَالاً وَأَدَعُ مَنْ هُوَ أَحَبُّ إِلَىَّ مِنْهُمْ لاَ أُعْطِيهِ شَيْئًا مَخَافَةَ أَنْ يُكَبُّوا فِي النَّارِ عَلَى وُجُوهِهِمْ ‏"‏ ‏.‏\hadithno{4683}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (27) Sahih Muslim (150)}\hadithtrans{Sa’d b. Abi Waqqas said :The Prophet (May peace be upon him) gave some people and did not give anything to a man of them. Sa’d said : Messenger of Allah! You gave so and so, so and so, but did not give anything to so and so while he is a believer. The Prophet (May peace be upon him) said : Or he is a Muslim. Sa’d repeated it thrice and the Prophet (May peace be upon him) then said : I give some people and leave him who is dearer to me than them. I do not give him anything fearing lest he should fall into Hell on his face}}
\hadithdefcmd{abudawud}{4684}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا ابْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، قَالَ وَقَالَ الزُّهْرِيُّ ‏\{‏ قُلْ لَمْ تُؤْمِنُوا وَلَكِنْ قُولُوا أَسْلَمْنَا ‏\}‏ قَالَ نَرَى أَنَّ الإِسْلاَمَ الْكَلِمَةُ وَالإِيمَانَ الْعَمَلُ ‏.‏\hadithno{4684}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Shuaib Al Arnaut: Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Explaining the verse, “say ; You have no faith, but you only say :We have submitted our wills to Allah”, Al-Zuhri said : We think that ISLAM is a word, and faith is an action}}
\hadithdefcmd{abudawud}{4685}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ بَشَّارٍ، حَدَّثَنَا سُفْيَانُ، - الْمَعْنَى - قَالاَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَسَّمَ بَيْنَ النَّاسِ قَسْمًا فَقُلْتُ أَعْطِ فُلاَنًا فَإِنَّهُ مُؤْمِنٌ ‏.‏ قَالَ ‏ "‏ أَوْ مُسْلِمٌ إِنِّي لأُعْطِي الرَّجُلَ الْعَطَاءَ وَغَيْرُهُ أَحَبُّ إِلَىَّ مِنْهُ مَخَافَةَ أَنْ يُكَبَّ عَلَى وَجْهِهِ ‏"‏ ‏.‏\hadithno{4685}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (27) Sahih Muslim (150)}\hadithtrans{Sa’d said :The Prophet (May peace be upon him) distributed (spoils) among the people I said to him : Give so and so for he is a believer. He said : Or he is a Muslim. I give a man something while another man is dearer to me than him, fearing that he may fall into Hell on his face}}
\hadithdefcmd{abudawud}{4686}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، قَالَ وَاقِدُ بْنُ عَبْدِ اللَّهِ أَخْبَرَنِي عَنْ أَبِيهِ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏ ‏.‏\hadithno{4686}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6868) Sahih Muslim (66)}\hadithtrans{Ibn ‘Umar reported the Prophet (May peace be upon him) as saying :Do not turn unbelievers after me ; one of you may strike the neck of the other}}
\hadithdefcmd{abudawud}{4687}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ فُضَيْلِ بْنِ غَزْوَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا رَجُلٍ مُسْلِمٍ أَكْفَرَ رَجُلاً مُسْلِمًا فَإِنْ كَانَ كَافِرًا وَإِلاَّ كَانَ هُوَ الْكَافِرَ ‏"‏ ‏.‏\hadithno{4687}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn ‘Umar reported the Messenger of Allah (May peace be upon him) as saying :If any believing man calls another believing man an unbeliever, if he is actually an infidel, it is all right ; if not, he will become an infidel}}
\hadithdefcmd{abudawud}{4688}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْبَعٌ مَنْ كُنَّ فِيهِ فَهُوَ مُنَافِقٌ خَالِصٌ وَمَنْ كَانَتْ فِيهِ خَلَّةٌ مِنْهُنَّ كَانَ فِيهِ خَلَّةٌ مِنْ نِفَاقٍ حَتَّى يَدَعَهَا إِذَا حَدَّثَ كَذَبَ وَإِذَا وَعَدَ أَخْلَفَ وَإِذَا عَاهَدَ غَدَرَ وَإِذَا خَاصَمَ فَجَرَ ‏"‏ ‏.‏\hadithno{4688}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (34) Sahih Muslim (58)}\hadithtrans{‘Abd Allah b. ‘Amr reported the Messenger of Allah (May peace be upon him) as saying:Four characteristics constitute anyone who possesses them a sheer hypocrite, and anyone who possesses one of them possesses a characteristics of hypocrisy till he abandons it : when he talks he lies, when he makes a promise he violates it, when he makes a covenant he acts treacherously, and when he quarrels, he deviates from the Truth}}
\hadithdefcmd{abudawud}{4689}{حَدَّثَنَا أَبُو صَالِحٍ الأَنْطَاكِيُّ، أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهُوَ مُؤْمِنٌ وَلاَ يَسْرِقُ حِينَ يَسْرِقُ وَهُوَ مُؤْمِنٌ وَلاَ يَشْرَبُ الْخَمْرَ حِينَ يَشْرَبُهَا وَهُوَ مُؤْمِنٌ وَالتَّوْبَةُ مَعْرُوضَةٌ بَعْدُ ‏"‏ ‏.‏\hadithno{4689}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6810) Sahih Muslim (57)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :When one commits fornication, one is not a believer ; when one steals, one is not a believer ; when one drinks, one is not a believer ; and repentance is placed before him}}
\hadithdefcmd{abudawud}{4690}{حَدَّثَنَا إِسْحَاقُ بْنُ سُوَيْدٍ الرَّمْلِيُّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا نَافِعٌ، - يَعْنِي ابْنَ يَزِيدَ - قَالَ حَدَّثَنِي ابْنُ الْهَادِ، أَنَّ سَعِيدَ بْنَ أَبِي سَعِيدٍ الْمَقْبُرِيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا زَنَى الرَّجُلُ خَرَجَ مِنْهُ الإِيمَانُ كَانَ عَلَيْهِ كَالظُّلَّةِ فَإِذَا انْقَطَعَ رَجَعَ إِلَيْهِ الإِيمَانُ ‏"‏ ‏.‏\hadithno{4690}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When a man commits fornication, faith departs from him and there is something like a canvas roof over his head; and when he quits that action, faith returns to him}}
\hadithdefcmd{abudawud}{4691}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، قَالَ حَدَّثَنِي بِمِنًى، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْقَدَرِيَّةُ مَجُوسُ هَذِهِ الأُمَّةِ إِنْ مَرِضُوا فَلاَ تَعُودُوهُمْ وَإِنْ مَاتُوا فَلاَ تَشْهَدُوهُمْ ‏"‏ ‏.‏\hadithno{4691}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: The Qadariyyah are the Magians of this community. If they are ill, do not pay a sick visit to them, and if they die, do not attend their funerals}}
\hadithdefcmd{abudawud}{4692}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عُمَرَ بْنِ مُحَمَّدٍ، عَنْ عُمَرَ، مَوْلَى غُفْرَةَ عَنْ رَجُلٍ، مِنَ الأَنْصَارِ عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِكُلِّ أُمَّةٍ مَجُوسٌ وَمَجُوسُ هَذِهِ الأُمَّةِ الَّذِينَ يَقُولُونَ لاَ قَدَرَ مَنْ مَاتَ مِنْهُمْ فَلاَ تَشْهَدُوا جَنَازَتَهُ وَمَنْ مَرِضَ مِنْهُمْ فَلاَ تَعُودُوهُمْ وَهُمْ شِيعَةُ الدَّجَّالِ وَحَقٌّ عَلَى اللَّهِ أَنْ يُلْحِقَهُمْ بِالدَّجَّالِ ‏"‏ ‏.‏\hadithno{4692}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Hudhaifah reported the Messenger of Allah (ﷺ) as saying:Every people have Magians, and the Magians of this community are those who declare that there is no destination by Allah. If any one of them dies, do not attend his funeral, and if any one of them is ill, do not pay a sick visit to him. They are the partisans of the Antichrist (Dajjal), and Allah will surely join them with the Antichrist}}
\hadithdefcmd{abudawud}{4693}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ يَزِيدَ بْنَ زُرَيْعٍ، وَيَحْيَى بْنَ سَعِيدٍ، حَدَّثَاهُمْ قَالاَ، حَدَّثَنَا عَوْفٌ، قَالَ حَدَّثَنَا قَسَامَةُ بْنُ زُهَيْرٍ، قَالَ حَدَّثَنَا أَبُو مُوسَى الأَشْعَرِيُّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ خَلَقَ آدَمَ مِنْ قَبْضَةٍ قَبَضَهَا مِنْ جَمِيعِ الأَرْضِ فَجَاءَ بَنُو آدَمَ عَلَى قَدْرِ الأَرْضِ جَاءَ مِنْهُمُ الأَحْمَرُ وَالأَبْيَضُ وَالأَسْوَدُ وَبَيْنَ ذَلِكَ وَالسَّهْلُ وَالْحَزْنُ وَالْخَبِيثُ وَالطَّيِّبُ ‏"‏ ‏.‏ زَادَ فِي حَدِيثِ يَحْيَى ‏"‏ وَبَيْنَ ذَلِكَ ‏"‏ ‏.‏ وَالإِخْبَارُ فِي حَدِيثِ يَزِيدَ ‏.‏\hadithno{4693}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Musa al-Ash’ari reported the Messenger of Allah (May peace be upon him) as saying :Allah created Adam from a handful which he took from the whole of the earth ; so the children of Adam are in accordance with the earth : some red, some white, some black, some a mixture, also smooth and rough, bad and good}}
\hadithdefcmd{abudawud}{4694}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ مَنْصُورَ بْنَ الْمُعْتَمِرِ، يُحَدِّثُ عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ حَبِيبٍ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ قَالَ كُنَّا فِي جَنَازَةٍ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِبَقِيعِ الْغَرْقَدِ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَلَسَ وَمَعَهُ مِخْصَرَةٌ فَجَعَلَ يَنْكُتُ بِالْمِخْصَرَةِ فِي الأَرْضِ ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ مَا مِنْ نَفْسٍ مَنْفُوسَةٍ إِلاَّ قَدْ كَتَبَ اللَّهُ مَكَانَهَا مِنَ النَّارِ أَوْ مِنَ الْجَنَّةِ إِلاَّ قَدْ كُتِبَتْ شَقِيَّةً أَوْ سَعِيدَةً ‏"‏ ‏.‏ قَالَ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ يَا نَبِيَّ اللَّهِ أَفَلاَ نَمْكُثُ عَلَى كِتَابِنَا وَنَدَعُ الْعَمَلَ فَمَنْ كَانَ مِنْ أَهْلِ السَّعَادَةِ لَيَكُونَنَّ إِلَى السَّعَادَةِ وَمَنْ كَانَ مِنْ أَهْلِ الشِّقْوَةِ لَيَكُونَنَّ إِلَى الشِّقْوَةِ قَالَ ‏"‏ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ أَمَّا أَهْلُ السَّعَادَةِ فَيُيَسَّرُونَ لِلسَّعَادَةِ وَأَمَّا أَهْلُ الشِّقْوَةِ فَيُيَسَّرُونَ لِلشِّقْوَةِ ‏"‏ ‏.‏ ثُمَّ قَالَ نَبِيُّ اللَّهِ ‏"‏ ‏\{‏ فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى * فَسَنُيَسِّرُهُ لِلْيُسْرَى * وَأَمَّا مَنْ بَخِلَ وَاسْتَغْنَى * وَكَذَّبَ بِالْحُسْنَى * ‏.‏ فَسَنُيَسِّرُهُ لِلْعُسْرَى ‏\}‏ ‏"‏ ‏.‏\hadithno{4694}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1362) Sahih Muslim (2647)}\hadithtrans{‘Ali said:We attended a funeral at Baql’ al-Gharqad which was also attended by the Messenger of Allah (May peace be upon him). The Messenger of Allah (May peace be upon him) came and sat down. He had a stick (in his hand) by which he began to scratch up the ground. He then raised his head and said : The place which every one of you and every soul of you will occupy in Hell or in Paradise has been recorded, and destined wicked or blesses. A man from among the people asked : Prophet of Allah! Should we not then trust simply in what has been recorded for us and abandon (doing good) deeds? Those who are among the number of the blessed will be inclined to blessing, and those of us who are among the number of the wicked will be inclined to wickedness. He replied : Go on doing good actions, for everyone is helped to do that for which he was created. Those who are among the number of wicked will be helped to do wicked deeds. The Prophet of Allah (May peace be upon him) then recited: “So he who gives (in charity) and fears (Allah), and in all sincerity testifies to the best, we will indeed make smooth for him the path to bliss. But he who is a greedy miser and thinks himself self-sufficient, and gives the lie to the best, We will indeed make smooth for him the path of misery.”}}
\hadithdefcmd{abudawud}{4695}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا كَهْمَسٌ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، قَالَ كَانَ أَوَّلَ مَنْ تَكَلَّمَ فِي الْقَدَرِ بِالْبَصْرَةِ مَعْبَدٌ الْجُهَنِيُّ فَانْطَلَقْتُ أَنَا وَحُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيُّ حَاجَّيْنِ أَوْ مُعْتَمِرَيْنِ فَقُلْنَا لَوْ لَقِينَا أَحَدًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلْنَاهُ عَمَّا يَقُولُ هَؤُلاَءِ فِي الْقَدَرِ ‏.‏ فَوَفَّقَ اللَّهُ لَنَا عَبْدَ اللَّهِ بْنَ عُمَرَ دَاخِلاً فِي الْمَسْجِدِ فَاكْتَنَفْتُهُ أَنَا وَصَاحِبِي فَظَنَنْتُ أَنَّ صَاحِبِي سَيَكِلُ الْكَلاَمَ إِلَىَّ فَقُلْتُ أَبَا عَبْدِ الرَّحْمَنِ إِنَّهُ قَدْ ظَهَرَ قِبَلَنَا نَاسٌ يَقْرَءُونَ الْقُرْآنَ وَيَتَفَقَّرُونَ الْعِلْمَ يَزْعُمُونَ أَنْ لاَ قَدَرَ وَالأَمْرُ أُنُفٌ ‏.‏ فَقَالَ إِذَا لَقِيتَ أُولَئِكَ فَأَخْبِرْهُمْ أَنِّي بَرِيءٌ مِنْهُمْ وَهُمْ بُرَآءُ مِنِّي وَالَّذِي يَحْلِفُ بِهِ عَبْدُ اللَّهِ بْنُ عُمَرَ لَوْ أَنَّ لأَحَدِهِمْ مِثْلَ أُحُدٍ ذَهَبًا فَأَنْفَقَهُ مَا قَبِلَهُ اللَّهُ مِنْهُ حَتَّى يُؤْمِنَ بِالْقَدَرِ ثُمَّ قَالَ حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ قَالَ بَيْنَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ طَلَعَ عَلَيْنَا رَجُلٌ شَدِيدُ بَيَاضِ الثِّيَابِ شَدِيدُ سَوَادِ الشَّعْرِ لاَ يُرَى عَلَيْهِ أَثَرُ السَّفَرِ وَلاَ نَعْرِفُهُ حَتَّى جَلَسَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَسْنَدَ رُكْبَتَيْهِ إِلَى رُكْبَتَيْهِ وَوَضَعَ كَفَّيْهِ عَلَى فَخِذَيْهِ وَقَالَ يَا مُحَمَّدُ أَخْبِرْنِي عَنِ الإِسْلاَمِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الإِسْلاَمُ أَنْ تَشْهَدَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ وَتُقِيمَ الصَّلاَةَ وَتُؤْتِيَ الزَّكَاةَ وَتَصُومَ رَمَضَانَ وَتَحُجَّ الْبَيْتَ إِنِ اسْتَطَعْتَ إِلَيْهِ سَبِيلاً ‏"‏ ‏.‏ قَالَ صَدَقْتَ ‏.‏ قَالَ فَعَجِبْنَا لَهُ يَسْأَلُهُ وَيُصَدِّقُهُ ‏.‏ قَالَ فَأَخْبِرْنِي عَنِ الإِيمَانِ ‏.‏ قَالَ ‏"‏ أَنْ تُؤْمِنَ بِاللَّهِ وَمَلاَئِكَتِهِ وَكُتُبِهِ وَرُسُلِهِ وَالْيَوْمِ الآخِرِ وَتُؤْمِنَ بِالْقَدَرِ خَيْرِهِ وَشَرِّهِ ‏"‏ ‏.‏ قَالَ صَدَقْتَ ‏.‏ قَالَ فَأَخْبِرْنِي عَنِ الإِحْسَانِ قَالَ ‏"‏ أَنْ تَعْبُدَ اللَّهَ كَأَنَّكَ تَرَاهُ فَإِنْ لَمْ تَكُنْ تَرَاهُ فَإِنَّهُ يَرَاكَ ‏"‏ ‏.‏ قَالَ فَأَخْبِرْنِي عَنِ السَّاعَةِ ‏.‏ قَالَ ‏"‏ مَا الْمَسْئُولُ عَنْهَا بِأَعْلَمَ مِنَ السَّائِلِ ‏"‏ ‏.‏ قَالَ فَأَخْبِرْنِي عَنْ أَمَارَاتِهَا ‏.‏ قَالَ ‏"‏ أَنْ تَلِدَ الأَمَةُ رَبَّتَهَا وَأَنْ تَرَى الْحُفَاةَ الْعُرَاةَ الْعَالَةَ رِعَاءَ الشَّاءِ يَتَطَاوَلُونَ فِي الْبُنْيَانِ ‏"‏ ‏.‏ قَالَ ثُمَّ انْطَلَقَ فَلَبِثْتُ ثَلاَثًا ثُمَّ قَالَ ‏"‏ يَا عُمَرُ هَلْ تَدْرِي مَنِ السَّائِلُ ‏"‏ ‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ فَإِنَّهُ جِبْرِيلُ أَتَاكُمْ يُعَلِّمُكُمْ دِينَكُمْ ‏"‏ ‏.‏\hadithno{4695}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (8)}\hadithtrans{Yahya b. Ya`mur said :The first to speak on Divine decree in al-Basrah was Ma`bad al Juhani. I and Humaid b. `Abd al-Rahman al-Himyari proceeded to perform Hajj or `Umrah. We said : would that we meet any of the Companions of the Messenger of Allah (ﷺ) so that we could ask him about what they say with regard to divine decree. So Allah helped us to meet `Abd Allah b. `Umar who was entering the mosque. So I and my companion surrounded him, and I thought that my companion would entrust me the task of speaking to him. Then I said : Abu ‘Abd al-Rahman, there appeared on our side some people who recite the Qur'an and are engaged in the hair-splitting of knowledge. They conceive that there is no Divine decree and everything happens freely without predestination. He said : When you meet those people, tell them that I am free from them, and they are free from me. By Him by Whom swears ‘Abd Allah b. ‘Umar, if one of them has gold equivalent to Uhud and he spends it, Allah will not accept it from him until he believes in Divine decree. He then said : ‘Umar b. Khattab transmitted to me a tradition, saying : One day when we were with the Messenger of Allah (ﷺ) a man with very white clothing and very black hair came up to us. No mark of travel was visible on him, and we did not recognize him. Sitting down beside the Messenger of Allah (ﷺ), leaning his knees against his and placing his hands on his thighs, he said : tell me, Muhammad, about Islam. The Messenger of Allah (ﷺ) said : Islam means that you should testify that there is no god but Allah, and Muhammad is Allah’s Apostle, that you should observe prayer, pay Zakat, fast during Ramadan, and perform Hajj to the house (i.e., Ka`bah), If you have the means to go. He said : You have spoken the truth. We were surprised at his questioning him and then declaring that he spoke the truth. He said : Now tell me about faith. He replied : It means that you should believe in Allah, his angels, his Books, his Apostles and the last day, and that you should believe in the decreeing both of good and evil. He said : You have spoken the truth. He said : now tell me about doing good (ihsan). He replied: It means that you should worship Allah as though you are seeing him; if you are not seeing him, he is seeing you. He said: Now tell me about the hour. He replied : The one who is asked about it is no better informed than the one who is asking. He said : Then tell me about its signs. He replied : That a maidservant should beget her mistress, and that you should see barefooted, naked, poor men and shepherds exalting themselves in buildings. ‘Umar said : He then went away, and I waited for three days, then he said : Do you know who the questioner was, `Umar? I replied : Allah and his Apostle know best. He said : He was Gabriel who came to you to teach you your religion}}
\hadithdefcmd{abudawud}{4696}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُثْمَانَ بْنِ غِيَاثٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، وَحُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ لَقِينَا عَبْدَ اللَّهِ بْنَ عُمَرَ فَذَكَرْنَا لَهُ الْقَدَرَ وَمَا يَقُولُونَ فِيهِ فَذَكَرَ نَحْوَهُ زَادَ قَالَ وَسَأَلَهُ رَجُلٌ مِنْ مُزَيْنَةَ أَوْ جُهَيْنَةَ فَقَالَ يَا رَسُولَ اللَّهِ فِيمَا نَعْمَلُ أَفِي شَىْءٍ قَدْ خَلاَ أَوْ مَضَى أَوْ شَىْءٍ يُسْتَأْنَفُ الآنَ قَالَ ‏"‏ فِي شَىْءٍ قَدْ خَلاَ وَمَضَى ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَوْ بَعْضُ الْقَوْمِ فَفِيمَ الْعَمَلُ قَالَ ‏"‏ إِنَّ أَهْلَ الْجَنَّةِ يُيَسَّرُونَ لِعَمَلِ أَهْلِ الْجَنَّةِ وَإِنَّ أَهْلَ النَّارِ يُيَسَّرُونَ لِعَمَلِ أَهْلِ النَّارِ ‏"‏ ‏.‏\hadithno{4696}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Yahya b. Yamur and Humaid b. ‘Abd al-Rahman through a different chain of narrators. This version has :we met ‘Abd Allah b. ‘Umar. We told him about divine decree and what they said about it. He then mentioned something similar to it. He added : A man of Muzainah or juhainah asked : What is the good in doing anything, Messenger of Allah ? should we think that a thing has passed and gone or a thing that has happened now (without predestination)? He replied : About a thing that has passed and gone (i.e. predestined). A man or some people asked: Then, why action? He replied: Those who are among the number of those who go to Paradise will be helped to do the deeds of the people who will go to Paradise, and those who are among the number of those who go to Hell will be helped to do the deeds of those who will go to Hell}}
\hadithdefcmd{abudawud}{4697}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا الْفِرْيَابِيُّ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا عَلْقَمَةُ بْنُ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنِ ابْنِ يَعْمَرَ، بِهَذَا الْحَدِيثِ يَزِيدُ وَيَنْقُصُ قَالَ فَمَا الإِسْلاَمُ قَالَ ‏ "‏ إِقَامُ الصَّلاَةِ وَإِيتَاءُ الزَّكَاةِ وَحَجُّ الْبَيْتِ وَصَوْمُ شَهْرِ رَمَضَانَ وَالاِغْتِسَالُ مِنَ الْجَنَابَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ عَلْقَمَةُ مُرْجِئٌ ‏.‏\hadithno{4697}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn Ya’mur, with additions and omissions, through a different chain of narrators. This version adds; He asked :What is Islam? He replied : It means saying prayer, payment of zakat, performing HAJJ, fasting during RAMADAN, and taking a bath on account of sexual defilement. Abu Dawud said: 'Alqamah was a Murji'i}}
\hadithdefcmd{abudawud}{4698}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ أَبِي فَرْوَةَ الْهَمْدَانِيِّ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي ذَرٍّ، وَأَبِي، هُرَيْرَةَ قَالاَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجْلِسُ بَيْنَ ظَهْرَىْ أَصْحَابِهِ فَيَجِيءُ الْغَرِيبُ فَلاَ يَدْرِي أَيُّهُمْ هُوَ حَتَّى يَسْأَلَ فَطَلَبْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ نَجْعَلَ لَهُ مَجْلِسًا يَعْرِفُهُ الْغَرِيبُ إِذَا أَتَاهُ - قَالَ - فَبَنَيْنَا لَهُ دُكَّانًا مِنْ طِينٍ فَجَلَسَ عَلَيْهِ وَكُنَّا نَجْلِسُ بِجَنْبَتَيْهِ وَذَكَرَ نَحْوَ هَذَا الْخَبَرِ فَأَقْبَلَ رَجُلٌ فَذَكَرَ هَيْئَتَهُ حَتَّى سَلَّمَ مِنْ طَرْفِ السِّمَاطِ فَقَالَ السَّلاَمُ عَلَيْكَ يَا مُحَمَّدُ ‏.‏ قَالَ فَرَدَّ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4698}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuDharr and AbuHurayrah: The Messenger of Allah (ﷺ) used to sit among his Companions. A stranger would come and not recognize him (the Prophet) until he asked (about him). So we asked the Messenger of Allah (ﷺ) to make a place where he might take his seat so that when a stranger came, he might recognise him. So we built a terrace of soil on which he would take his seat, and we would sit beside him. He then mentioned something similar to this Hadith saying: A man came, and he described his appearance. He saluted from the side of the assembly, saying: Peace be upon you, Muhammad. The Prophet (ﷺ) then responded to him}}
\hadithdefcmd{abudawud}{4699}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي سِنَانٍ، عَنْ وَهْبِ بْنِ خَالِدٍ الْحِمْصِيِّ، عَنِ ابْنِ الدَّيْلَمِيِّ، قَالَ أَتَيْتُ أُبَىَّ بْنَ كَعْبٍ فَقُلْتُ لَهُ وَقَعَ فِي نَفْسِي شَىْءٌ مِنَ الْقَدَرِ فَحَدِّثْنِي بِشَىْءٍ لَعَلَّ اللَّهَ أَنْ يُذْهِبَهُ مِنْ قَلْبِي ‏.‏ فَقَالَ لَوْ أَنَّ اللَّهَ عَذَّبَ أَهْلَ سَمَوَاتِهِ وَأَهْلَ أَرْضِهِ عَذَّبَهُمْ وَهُوَ غَيْرُ ظَالِمٍ لَهُمْ وَلَوْ رَحِمَهُمْ كَانَتْ رَحْمَتُهُ خَيْرًا لَهُمْ مِنْ أَعْمَالِهِمْ وَلَوْ أَنْفَقْتَ مِثْلَ أُحُدٍ ذَهَبًا فِي سَبِيلِ اللَّهِ مَا قَبِلَهُ اللَّهُ مِنْكَ حَتَّى تُؤْمِنَ بِالْقَدَرِ وَتَعْلَمَ أَنَّ مَا أَصَابَكَ لَمْ يَكُنْ لِيُخْطِئَكَ وَأَنَّ مَا أَخْطَأَكَ لَمْ يَكُنْ لِيُصِيبَكَ وَلَوْ مُتَّ عَلَى غَيْرِ هَذَا لَدَخَلْتَ النَّارَ ‏.‏ قَالَ ثُمَّ أَتَيْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ فَقَالَ مِثْلَ ذَلِكَ - قَالَ - ثُمَّ أَتَيْتُ حُذَيْفَةَ بْنَ الْيَمَانِ فَقَالَ مِثْلَ ذَلِكَ - قَالَ - ثُمَّ أَتَيْتُ زَيْدَ بْنَ ثَابِتٍ فَحَدَّثَنِي عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ ذَلِكَ ‏.‏\hadithno{4699}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn al-Dailami said :I went to Ubayy b. Ka’b and said him : I am confused about Divine decree, so tell me something by means of which Allah may remove the confusion from my mind. He replied : were Allah to punish everyone in the heavens and in the earth. He would do so without being unjust to them, and were he to show mercy to them his mercy would be much better than their actions merited. Were you to spend in support of Allah’s cause an amount of gold equivalent to Uhud, Allah would not accept it from you till you believed in divine decree and knew that what has come to you could not miss you and that what has missed you could not come to you. Were you to die believing anything else you would enter Hell. He said : I then went to ‘Abd Allah b. MAs’ud and he said something to the same effect. I next went to Hudhaifah b. al-Yaman and he said something to the same effect. I next went to Zaid b. Thabit who told me something from the Prophet (May peace be upon him) to the same effect}}
\hadithdefcmd{abudawud}{4700}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ الْهُذَلِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا الْوَلِيدُ بْنُ رَبَاحٍ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي عَبْلَةَ، عَنْ أَبِي حَفْصَةَ، قَالَ قَالَ عُبَادَةُ بْنُ الصَّامِتِ لاِبْنِهِ يَا بُنَىَّ إِنَّكَ لَنْ تَجِدَ طَعْمَ حَقِيقَةِ الإِيمَانِ حَتَّى تَعْلَمَ أَنَّ مَا أَصَابَكَ لَمْ يَكُنْ لِيُخْطِئَكَ وَمَا أَخْطَأَكَ لَمْ يَكُنْ لِيُصِيبَكَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ أَوَّلَ مَا خَلَقَ اللَّهُ الْقَلَمَ فَقَالَ لَهُ اكْتُبْ ‏.‏ قَالَ رَبِّ وَمَاذَا أَكْتُبُ قَالَ اكْتُبْ مَقَادِيرَ كُلِّ شَىْءٍ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏ يَا بُنَىَّ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ مَاتَ عَلَى غَيْرِ هَذَا فَلَيْسَ مِنِّي ‏"‏ ‏.‏\hadithno{4700}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ubadah b. al Samit said to his son :Son! You will not get the taste of the reality of faith until you know that what has come to you could not miss you, and that what has missed you could not come to you. I heard the Messenger of Allah (ﷺ) say: The first thing Allah created was the pen. He said to it: Write. It asked: What should I write, my Lord? He said: Write what was decreed about everything till the Last Hour comes. Son! I heard the Messenger of Allah (ﷺ) say : He who dies on something other than this does not belong to me}}
\hadithdefcmd{abudawud}{4701}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، - الْمَعْنَى - قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، سَمِعَ طَاوُسًا، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يُخْبِرُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ احْتَجَّ آدَمُ وَمُوسَى فَقَالَ مُوسَى يَا آدَمُ أَنْتَ أَبُونَا خَيَّبْتَنَا وَأَخْرَجْتَنَا مِنَ الْجَنَّةِ ‏.‏ فَقَالَ آدَمُ أَنْتَ مُوسَى اصْطَفَاكَ اللَّهُ بِكَلاَمِهِ وَخَطَّ لَكَ التَّوْرَاةَ بِيَدِهِ تَلُومُنِي عَلَى أَمْرٍ قَدَّرَهُ عَلَىَّ قَبْلَ أَنْ يَخْلُقَنِي بِأَرْبَعِينَ سَنَةً فَحَجَّ آدَمُ مُوسَى ‏"‏ ‏.‏ قَالَ أَحْمَدُ بْنُ صَالِحٍ عَنْ عَمْرٍو عَنْ طَاوُسٍ سَمِعَ أَبَا هُرَيْرَةَ ‏.‏\hadithno{4701}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4614) Sahih Muslim (2652)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :Adam and Moses held a disputation. Moses said : Adam you are our father. You deprived us and caused us to come out from Paradise. Adam said : You are Moses Allah chose you for his speech and wrote the Torah for you with his hand. Do you blame me for doing a deed which Allah had decreed that I should do forty year before he created me? So Adam got the better of Moses in argument. Ahmad b. Salih said from 'Amr from Tawus who heard Abu Hurairah}}
\hadithdefcmd{abudawud}{4702}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مُوسَى قَالَ يَا رَبِّ أَرِنَا آدَمَ الَّذِي أَخْرَجَنَا وَنَفْسَهُ مِنَ الْجَنَّةِ فَأَرَاهُ اللَّهُ آدَمَ فَقَالَ أَنْتَ أَبُونَا آدَمُ فَقَالَ لَهُ آدَمُ نَعَمْ ‏.‏ قَالَ أَنْتَ الَّذِي نَفَخَ اللَّهُ فِيكَ مِنْ رُوحِهِ وَعَلَّمَكَ الأَسْمَاءَ كُلَّهَا وَأَمَرَ الْمَلاَئِكَةَ فَسَجَدُوا لَكَ قَالَ نَعَمْ ‏.‏ قَالَ فَمَا حَمَلَكَ عَلَى أَنْ أَخْرَجْتَنَا وَنَفْسَكَ مِنَ الْجَنَّةِ فَقَالَ لَهُ آدَمُ وَمَنْ أَنْتَ قَالَ أَنَا مُوسَى ‏.‏ قَالَ أَنْتَ نَبِيُّ بَنِي إِسْرَائِيلَ الَّذِي كَلَّمَكَ اللَّهُ مِنْ وَرَاءِ الْحِجَابِ لَمْ يَجْعَلْ بَيْنَكَ وَبَيْنَهُ رَسُولاً مِنْ خَلْقِهِ قَالَ نَعَمْ ‏.‏ قَالَ أَفَمَا وَجَدْتَ أَنَّ ذَلِكَ كَانَ فِي كِتَابِ اللَّهِ قَبْلَ أَنْ أُخْلَقَ قَالَ نَعَمْ ‏.‏ قَالَ فَفِيمَ تَلُومُنِي فِي شَىْءٍ سَبَقَ مِنَ اللَّهِ تَعَالَى فِيهِ الْقَضَاءُ قَبْلِي ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ فَحَجَّ آدَمُ مُوسَى فَحَجَّ آدَمُ مُوسَى ‏"‏ ‏.‏\hadithno{4702}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Umar b. al-Khattab reported the Messenger of Allah (May peace be upon him) as saying :Moses said : My lord, show us Adam who caused us and himself to come out from Paradise. So Allah showed him Adam. He asked : Are you our father, Adam? Adam said to him : Yes. He said : Are you the one into whom Allah breathed of his spirit, taught you all the names, and commanded angels (to prostrate) and they prostrated to you? He replied : Yes. He asked : Then what moved you to cause us and yourself to come out from paradise? Adam asked him : And who are you? He said : Yes. He asked : Did you not find that was decreed in the book (records) of Allah before I was created? He replied : Yes. He asked : Then why do you blame me about a thing for which Divine decree had already passed before me ? The Messenger of Allah (May peace be upon him) said : So Adam got the better of Moses in argument (peace be upon him)}}
\hadithdefcmd{abudawud}{4703}{حَدَّثَنَا عَبْدُ اللَّهِ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، أَنَّ عَبْدَ الْحَمِيدِ بْنَ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ، أَخْبَرَهُ عَنْ مُسْلِمِ بْنِ يَسَارٍ الْجُهَنِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، سُئِلَ عَنْ هَذِهِ الآيَةِ، ‏\{‏ وَإِذْ أَخَذَ رَبُّكَ مِنْ بَنِي آدَمَ مِنْ ظُهُورِهِمْ ‏\}‏ قَالَ قَرَأَ الْقَعْنَبِيُّ الآيَةَ ‏.‏ فَقَالَ عُمَرُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ خَلَقَ آدَمَ ثُمَّ مَسَحَ ظَهْرَهُ بِيَمِينِهِ فَاسْتَخْرَجَ مِنْهُ ذُرِّيَّةً فَقَالَ خَلَقْتُ هَؤُلاَءِ لِلْجَنَّةِ وَبِعَمَلِ أَهْلِ الْجَنَّةِ يَعْمَلُونَ ثُمَّ مَسَحَ ظَهْرَهُ فَاسْتَخْرَجَ مِنْهُ ذُرِّيَّةً فَقَالَ خَلَقْتُ هَؤُلاَءِ لِلنَّارِ وَبِعَمَلِ أَهْلِ النَّارِ يَعْمَلُونَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ فَفِيمَ الْعَمَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ إِذَا خَلَقَ الْعَبْدَ لِلْجَنَّةِ اسْتَعْمَلَهُ بِعَمَلِ أَهْلِ الْجَنَّةِ حَتَّى يَمُوتَ عَلَى عَمَلٍ مِنْ أَعْمَالِ أَهْلِ الْجَنَّةِ فَيُدْخِلَهُ بِهِ الْجَنَّةَ وَإِذَا خَلَقَ الْعَبْدَ لِلنَّارِ اسْتَعْمَلَهُ بِعَمَلِ أَهْلِ النَّارِ حَتَّى يَمُوتَ عَلَى عَمَلٍ مِنْ أَعْمَالِ أَهْلِ النَّارِ فَيُدْخِلَهُ بِهِ النَّارَ ‏"‏ ‏.‏\hadithno{4703}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: Muslim ibn Yasar al-Juhani said: When Umar ibn al-Khattab was asked about the verse "When your Lord took their offspring from the backs of the children of Adam" - al-Qa'nabi recited the verse--he said: I heard the Messenger of Allah (ﷺ) say when he was questioned about it: Allah created Adam, then passed His right hand over his back, and brought forth from it his offspring, saying: I have these for Paradise and these will do the deeds of those who go to Paradise. He then passed His hand over his back and brought forth from it his offspring, saying: I have created these for Hell, and they will do the deeds of those who go to Hell. A man asked: What is the good of doing anything, Messenger of Allah? The Messenger of Allah (ﷺ) said: When Allah creates a servant for Paradise, He employs him in doing the deeds of those who will go to Paradise, so that his final action before death is one of the deeds of those who go to Paradise, for which He will bring him into Paradise. But when He creates a servant for Hell, He employs him in doing the deeds of those who will go to Hell, so that his final action before death is one of the deeds of those who go to Hell, for which He will bring him into Hell}}
\hadithdefcmd{abudawud}{4704}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنِي عُمَرُ بْنُ جُعْثُمَ الْقُرَشِيُّ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مُسْلِمِ بْنِ يَسَارٍ، عَنْ نُعَيْمِ بْنِ رَبِيعَةَ، قَالَ كُنْتُ عِنْدَ عُمَرَ بْنِ الْخَطَّابِ بِهَذَا الْحَدِيثِ وَحَدِيثُ مَالِكٍ أَتَمُّ ‏.‏\hadithno{4704}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Nu’aim b. Rabl’ah said :I was with ‘Umar b. al-Khattab when he transmitted this tradition. The tradition of Malik is more perfect}}
\hadithdefcmd{abudawud}{4705}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، عَنْ رَقَبَةَ بْنِ مَصْقَلَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْغُلاَمُ الَّذِي قَتَلَهُ الْخَضِرُ طُبِعَ كَافِرًا وَلَوْ عَاشَ لأَرْهَقَ أَبَوَيْهِ طُغْيَانًا وَكُفْرًا ‏"‏ ‏.‏\hadithno{4705}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (2661)}\hadithtrans{Ubayy b. Ka’b said :The boy whom al-Khidr had killed was created an infidel. Had he lived, he would have moved his parents to rebellion and unbelief}}
\hadithdefcmd{abudawud}{4706}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا الْفِرْيَابِيُّ، عَنْ إِسْرَائِيلَ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَنَا أُبَىُّ بْنُ كَعْبٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي قَوْلِهِ ‏\{‏ وَأَمَّا الْغُلاَمُ فَكَانَ أَبَوَاهُ مُؤْمِنَيْنِ ‏\}‏ ‏"‏ وَكَانَ طُبِعَ يَوْمَ طُبِعَ كَافِرًا ‏"‏ ‏.‏\hadithno{4706}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ubayy b. Ka’b said :I heard the Messenger of Allah (May peace be upon him) explaining the verse “As for the youth his parents were people of Faith,” he was created infidel the day when he was created}}
\hadithdefcmd{abudawud}{4707}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ حَدَّثَنِي أُبَىُّ بْنُ كَعْبٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَبْصَرَ الْخَضِرُ غُلاَمًا يَلْعَبُ مَعَ الصِّبْيَانِ فَتَنَاوَلَ رَأْسَهُ فَقَلَعَهُ فَقَالَ مُوسَى ‏\{‏ أَقَتَلْتَ نَفْسًا زَكِيَّةً ‏\}‏ ‏"‏ ‏.‏ الآيَةَ ‏.‏\hadithno{4707}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (122) Sahih Muslim (2380)}\hadithtrans{Ibn ‘Abbas said :Ubayy b. Ka’b told me that the Messenger of Allah (May peace be upon him) said : Al-khidr saw a youth playing with boys. He took him by his head and uprooted it. Moses then said : Hast thou slain an innocent person who had slain none}}
\hadithdefcmd{abudawud}{4708}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، - الْمَعْنَى وَاحِدٌ وَالإِخْبَارُ فِي حَدِيثِ سُفْيَانَ - عَنِ الأَعْمَشِ قَالَ حَدَّثَنَا زَيْدُ بْنُ وَهْبٍ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْعُودٍ قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ الصَّادِقُ الْمَصْدُوقُ ‏ "‏ إِنَّ خَلْقَ أَحَدِكُمْ يُجْمَعُ فِي بَطْنِ أُمِّهِ أَرْبَعِينَ يَوْمًا ثُمَّ يَكُونُ عَلَقَةً مِثْلَ ذَلِكَ ثُمَّ يَكُونُ مُضْغَةً مِثْلَ ذَلِكَ ثُمَّ يُبْعَثُ إِلَيْهِ مَلَكٌ فَيُؤْمَرُ بِأَرْبَعِ كَلِمَاتٍ فَيُكْتَبُ رِزْقُهُ وَأَجَلُهُ وَعَمَلُهُ ثُمَّ يُكْتَبُ شَقِيٌّ أَوْ سَعِيدٌ ثُمَّ يُنْفَخُ فِيهِ الرُّوحُ فَإِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ حَتَّى مَا يَكُونَ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ أَوْ قِيدُ ذِرَاعٍ فَيَسْبِقُ عَلَيْهِ الْكِتَابُ فَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ فَيَدْخُلُهَا وَإِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ حَتَّى مَا يَكُونَ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ أَوْ قِيدُ ذِرَاعٍ فَيَسْبِقُ عَلَيْهِ الْكِتَابُ فَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ فَيَدْخُلُهَا ‏"‏ ‏.‏\hadithno{4708}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6594) Sahih Muslim (2643)}\hadithtrans{‘Abd Allah b. Mas’ud said :The Messenger of Allah (May peace be upon him) who spoke the truth and whose word was belief told us the following : The constituents of one of you are collected for forty days in his mother’s womb, then they become a piece of congealed blood for a similar period, then they become a lump of flesh for a similar period. Then Allah sends to him an angel with four words who records his provision the period of his life, his deeds, and whether he will be miserable or blessed ; thereafter he breathes the spirit into him. One of you will do the deeds of those who go to Paradise so that there will be only a cubit between him and it or will be within a cubit, then what is decreed will overcome him so that he will do the deeds of those who go to Hell and will enter it; and one of you will do the deeds of those who go to hell, so that there will be only a cubit between him and it or will be within a cubit, then what is decreed will overcome him, so that he will do the deeds of those who go to Paradise and will enter it}}
\hadithdefcmd{abudawud}{4709}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَزِيدَ الرِّشْكِ، قَالَ حَدَّثَنَا مُطَرِّفٌ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ أَعُلِمَ أَهْلُ الْجَنَّةِ مِنْ أَهْلِ النَّارِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَفِيمَ يَعْمَلُ الْعَامِلُونَ قَالَ ‏"‏ كُلٌّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ ‏"‏ ‏.‏\hadithno{4709}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6556) Sahih Muslim (2649)}\hadithtrans{‘Imran b. Husain said :The Messenger of Allah (May peace be upon him) was asked : Is it known who are those who will go to paradise and those who will go to hell? He said : Yes. He asked : Then what is the good of doing anything by those who act? He replied : Everyone is helped to do for which he has been created}}
\hadithdefcmd{abudawud}{4710}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ أَبُو عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ دِينَارٍ، عَنْ حَكِيمِ بْنِ شَرِيكٍ الْهُذَلِيِّ، عَنْ يَحْيَى بْنِ مَيْمُونٍ الْحَضْرَمِيِّ، عَنْ رَبِيعَةَ الْجُرَشِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُجَالِسُوا أَهْلَ الْقَدَرِ وَلاَ تُفَاتِحُوهُمْ ‏"‏ ‏.‏\hadithno{4710}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Umar reported the Prophet (May peace be upon him) was asked :Do not sit which those who believe in free will and do not address them before they address you}}
\hadithdefcmd{abudawud}{4711}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنْ أَوْلاَدِ الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{4711}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1383) Sahih Muslim (2660)}\hadithtrans{Ibn ‘Abbas reported that when the Prophet (May peace be upon him) was questioned about the offspring of polytheists, he said :Allah knows best about what they were doing}}
\hadithdefcmd{abudawud}{4712}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا بَقِيَّةُ، ح وَحَدَّثَنَا مُوسَى بْنُ مَرْوَانَ الرَّقِّيُّ، وَكَثِيرُ بْنُ عُبَيْدٍ الْمَذْحِجِيُّ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، - الْمَعْنَى - عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ ذَرَارِيُّ الْمُؤْمِنِينَ فَقَالَ ‏"‏ هُمْ مِنْ آبَائِهِمْ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ بِلاَ عَمَلٍ قَالَ ‏"‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ فَذَرَارِيُّ الْمُشْرِكِينَ قَالَ ‏"‏ مِنْ آبَائِهِمْ ‏"‏ ‏.‏ قُلْتُ بِلاَ عَمَلٍ قَالَ ‏"‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{4712}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘A’ishah said :I said : Messenger of Allah (May peace be upon him) what happens to the offspring of believers ? He replied : They are joined to their parents. I asked : Messenger of Allah! Although they have done nothing ? He replied : Allah knows best what they were doing. I asked : what happens to the offspring of polytheists, Messenger of Allah ? he replied! They are joined to their parents. I asked : Although they have done nothing? He replied : Allah knows best what they were doing}}
\hadithdefcmd{abudawud}{4713}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِصَبِيٍّ مِنَ الأَنْصَارِ يُصَلِّي عَلَيْهِ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ طُوبَى لِهَذَا لَمْ يَعْمَلْ شَرًّا وَلَمْ يَدْرِ بِهِ ‏.‏ فَقَالَ ‏ "‏ أَوَغَيْرَ ذَلِكَ يَا عَائِشَةُ إِنَّ اللَّهَ خَلَقَ الْجَنَّةَ وَخَلَقَ لَهَا أَهْلاً وَخَلَقَهَا لَهُمْ وَهُمْ فِي أَصْلاَبِ آبَائِهِمْ وَخَلَقَ النَّارَ وَخَلَقَ لَهَا أَهْلاً وَخَلَقَهَا لَهُمْ وَهُمْ فِي أَصْلاَبِ آبَائِهِمْ ‏"‏ ‏.‏\hadithno{4713}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2662)}\hadithtrans{‘A’ishah, mother of the believers, said :The Prophet (May peace be upon him) was invited to the funeral of a boy who belonged to the ANSAR and I said; Messenger of Allah! This one is blessed, for he has done no evil, nor has he known it. He replied : It may be otherwise, ‘A’ishah, for Allah created Paradise and created those who will go to it, and He created it for them when they were still in their father’s loins; and he created hell and created those who will go to it, and created it for them when they were still in their father’s loins}}
\hadithdefcmd{abudawud}{4714}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ مَوْلُودٍ يُولَدُ عَلَى الْفِطْرَةِ فَأَبَوَاهُ يُهَوِّدَانِهِ وَيُنَصِّرَانِهِ كَمَا تَنَاتَجُ الإِبِلُ مِنْ بَهِيمَةٍ جَمْعَاءَ هَلْ تُحِسُّ مِنْ جَدْعَاءَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَفَرَأَيْتَ مَنْ يَمُوتُ وَهُوَ صَغِيرٌ قَالَ ‏"‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{4714}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2659)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :Every child is born on Islam, but his parents make him a Jew and a Christian, just as a beast is born whole. Do you find some among them (born) maimed? The people asked : Messenger of Allah! What do you think about the one who died while he was young? He replied : Allah knows best what he was going to do}}
\hadithdefcmd{abudawud}{4715}{قَالَ أَبُو دَاوُدَ قُرِئَ عَلَى الْحَارِثِ بْنِ مِسْكِينٍ وَأَنَا أَسْمَعُ، أَخْبَرَكَ يُوسُفُ بْنُ عَمْرٍو، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ سَمِعْتُ مَالِكًا، قِيلَ لَهُ إِنَّ أَهْلَ الأَهْوَاءِ يَحْتَجُّونَ عَلَيْنَا بِهَذَا الْحَدِيثِ ‏.‏ قَالَ مَالِكٌ احْتَجَّ عَلَيْهِمْ بِآخِرِهِ ‏.‏ قَالُوا أَرَأَيْتَ مَنْ يَمُوتُ وَهُوَ صَغِيرٌ قَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{4715}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Dawud said :Malik was asked : The heretics argue from this tradition against us. Malik said : Argue against them from its last part which goes. The people asked : What do you think about the one who died while he was young? He replied : Allah knows best what he was going to do}}
\hadithdefcmd{abudawud}{4716}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا حَجَّاجُ بْنُ الْمِنْهَالِ، قَالَ سَمِعْتُ حَمَّادَ بْنَ سَلَمَةَ، يُفَسِّرُ حَدِيثَ ‏"‏ كُلُّ مَوْلُودٍ يُولَدُ عَلَى الْفِطْرَةِ ‏"‏ ‏.‏ قَالَ هَذَا عِنْدَنَا حَيْثُ أَخَذَ اللَّهُ عَلَيْهِمُ الْعَهْدَ فِي أَصْلاَبِ آبَائِهِمْ حَيْثُ قَالَ ‏\{‏ أَلَسْتُ بِرَبِّكُمْ قَالُوا بَلَى ‏\}‏ ‏.‏\hadithno{4716}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Explaining the tradition “Every child is a born on Islam”, Hammad b. Salamah said :In our opinion it means that covenant which Allah had taken in the loins of their fathers when He said : “Am I not your Lord? They said: Yes}}
\hadithdefcmd{abudawud}{4717}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوَائِدَةُ وَالْمَوْءُودَةُ فِي النَّارِ ‏"‏ ‏.‏ قَالَ يَحْيَى بْنُ زَكَرِيَّا قَالَ أَبِي فَحَدَّثَنِي أَبُو إِسْحَاقَ أَنَّ عَامِرًا حَدَّثَهُ بِذَلِكَ عَنْ عَلْقَمَةَ عَنِ ابْنِ مَسْعُودٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4717}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Amir reported the Messenger of Allah (May peace be upon him) as saying :The woman who buries alive her new-born girl and the girl who is buried alive both will go to Hell. This tradition has also been transmitted by Ibn Mas’ud from the Prophet (May peace be upon him) to the same effect through a different chain of narrators}}
\hadithdefcmd{abudawud}{4718}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ أَيْنَ أَبِي قَالَ ‏"‏ أَبُوكَ فِي النَّارِ ‏"‏ ‏.‏ فَلَمَّا قَفَّى قَالَ ‏"‏ إِنَّ أَبِي وَأَبَاكَ فِي النَّارِ ‏"‏ ‏.‏\hadithno{4718}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (203)}\hadithtrans{Anas said :A man asked : where is my father, Messenger of Allah? He replied! Your father is in Hell. When he turned his back, he said : My father and your father are in Hell}}
\hadithdefcmd{abudawud}{4719}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنِ ابْنِ آدَمَ مَجْرَى الدَّمِ ‏"‏ ‏.‏\hadithno{4719}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2174)}\hadithtrans{Anas b. Malik reported the Messenger of Allah (May peace be upon him) as saying :The devil flows in a man like his blood}}
\hadithdefcmd{abudawud}{4720}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي ابْنُ لَهِيعَةَ، وَعَمْرُو بْنُ الْحَارِثِ، وَسَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ عَطَاءِ بْنِ دِينَارٍ، عَنْ حَكِيمِ بْنِ شَرِيكٍ الْهُذَلِيِّ، عَنْ يَحْيَى بْنِ مَيْمُونٍ، عَنْ رَبِيعَةَ الْجُرَشِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُجَالِسُوا أَهْلَ الْقَدَرِ وَلاَ تُفَاتِحُوهُمُ الْحَدِيثَ ‏"‏ ‏.‏\hadithno{4720}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Umar b. al-Khattab reported the Messenger of Allah (May peace be upon him) as saying :Do not sit with those who believe in free will and do not address them before they address you}}
\hadithdefcmd{abudawud}{4721}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ النَّاسُ يَتَسَاءَلُونَ حَتَّى يُقَالَ هَذَا خَلَقَ اللَّهُ الْخَلْقَ فَمَنْ خَلَقَ اللَّهَ فَمَنْ وَجَدَ مِنْ ذَلِكَ شَيْئًا فَلْيَقُلْ آمَنْتُ بِاللَّهِ ‏"‏ ‏.‏\hadithno{4721}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3276) Sahih Muslim (134)}\hadithtrans{Abu Hurairah reported to the Messenger of Allah( may peace be upon him) as sayings:People will continue to ask one another(questions) till this is pronounced: Allah created all things, but who created Allah ? Whoever comes across anything of that, he should say: I believe in Allah}}
\hadithdefcmd{abudawud}{4722}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ الْفَضْلِ - قَالَ حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ إِسْحَاقَ - قَالَ حَدَّثَنِي عُتْبَةُ بْنُ مُسْلِمٍ، مَوْلَى بَنِي تَيْمٍ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فَذَكَرَ نَحْوَهُ قَالَ ‏"‏ فَإِذَا قَالُوا ذَلِكَ فَقُولُوا ‏\{‏ اللَّهُ أَحَدٌ * اللَّهُ الصَّمَدُ * لَمْ يَلِدْ وَلَمْ يُولَدْ * وَلَمْ يَكُنْ لَهُ كُفُوًا أَحَدٌ ‏\}‏ ثُمَّ لْيَتْفُلْ عَنْ يَسَارِهِ ثَلاَثًا وَلْيَسْتَعِذْ مِنَ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{4722}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: I heard the Messenger of Allah (ﷺ) say: He then mentioned a tradition like it. This version adds: When they propound that, say: "Say Allah is one. Allah is He to Whom men repair. He has not begotten and He has not been begotten, and no one is equal to Him." Then one should spit three times on his left side and seek refuge in Allah from Satan}}
\hadithdefcmd{abudawud}{4723}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا الْوَلِيدُ بْنُ أَبِي ثَوْرٍ، عَنْ سِمَاكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمِيرَةَ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، قَالَ كُنْتُ فِي الْبَطْحَاءِ فِي عِصَابَةٍ فِيهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَمَرَّتْ بِهِمْ سَحَابَةٌ فَنَظَرَ إِلَيْهَا فَقَالَ ‏"‏ مَا تُسَمُّونَ هَذِهِ ‏"‏ ‏.‏ قَالُوا السَّحَابَ ‏.‏ قَالَ ‏"‏ وَالْمُزْنَ ‏"‏ ‏.‏ قَالُوا وَالْمُزْنَ ‏.‏ قَالَ ‏"‏ وَالْعَنَانَ ‏"‏ ‏.‏ قَالُوا وَالْعَنَانَ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ أُتْقِنِ الْعَنَانَ جَيِّدًا قَالَ ‏"‏ هَلْ تَدْرُونَ مَا بُعْدُ مَا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏"‏ ‏.‏ قَالُوا لاَ نَدْرِي ‏.‏ قَالَ ‏"‏ إِنَّ بُعْدَ مَا بَيْنَهُمَا إِمَّا وَاحِدَةٌ أَوِ اثْنَتَانِ أَوْ ثَلاَثٌ وَسَبْعُونَ سَنَةً ثُمَّ السَّمَاءُ فَوْقَهَا كَذَلِكَ ‏"‏ ‏.‏ حَتَّى عَدَّ سَبْعَ سَمَوَاتٍ ‏"‏ ثُمَّ فَوْقَ السَّابِعَةِ بَحْرٌ بَيْنَ أَسْفَلِهِ وَأَعْلاَهُ مِثْلُ مَا بَيْنَ سَمَاءٍ إِلَى سَمَاءٍ ثُمَّ فَوْقَ ذَلِكَ ثَمَانِيَةُ أَوْعَالٍ بَيْنَ أَظْلاَفِهِمْ وَرُكَبِهِمْ مِثْلُ مَا بَيْنَ سَمَاءٍ إِلَى سَمَاءٍ ثُمَّ عَلَى ظُهُورِهِمُ الْعَرْشُ بَيْنَ أَسْفَلِهِ وَأَعْلاَهُ مِثْلُ مَا بَيْنَ سَمَاءٍ إِلَى سَمَاءٍ ثُمَّ اللَّهُ تَبَارَكَ وَتَعَالَى فَوْقَ ذَلِكَ ‏"‏ ‏.‏\hadithno{4723}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Abbas ibn AbdulMuttalib: I was sitting in al-Batha with a company among whom the Messenger of Allah (ﷺ) was sitting, when a cloud passed above them. The Messenger of Allah (ﷺ) looked at it and said: What do you call this? They said: Sahab. He said: And muzn? They said: And muzn. He said: And anan? They said: And anan. AbuDawud said: I am not quite confident about the word anan. He asked: Do you know the distance between Heaven and Earth? They replied: We do not know. He then said: The distance between them is seventy-one, seventy-two, or seventy-three years. The heaven which is above it is at a similar distance (going on till he counted seven heavens). Above the seventh heaven there is a sea, the distance between whose surface and bottom is like that between one heaven and the next. Above that there are eight mountain goats the distance between whose hoofs and haunches is like the distance between one heaven and the next. Then Allah, the Blessed and the Exalted, is above that}}
\hadithdefcmd{abudawud}{4724}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي سُرَيْجٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ سَعْدٍ، وَمُحَمَّدُ بْنُ سَعِيدٍ، قَالاَ أَخْبَرَنَا عَمْرُو بْنُ أَبِي قَيْسٍ، عَنْ سِمَاكٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏\hadithno{4724}\hadithgrade{Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Simak through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{4725}{حَدَّثَنَا أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ سِمَاكٍ، بِإِسْنَادِهِ وَمَعْنَى هَذَا الْحَدِيثِ الطَّوِيلِ ‏.‏\hadithno{4725}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has again been transmitted by Simak through a different chain of narrators and to the same effect as this lengthy tradition}}
\hadithdefcmd{abudawud}{4726}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، وَأَحْمَدُ بْنُ سَعِيدٍ الرِّبَاطِيُّ، قَالُوا حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، - قَالَ أَحْمَدُ كَتَبْنَاهُ مِنْ نُسْخَتِهِ وَهَذَا لَفْظُهُ - قَالَ حَدَّثَنَا أَبِي قَالَ سَمِعْتُ مُحَمَّدَ بْنَ إِسْحَاقَ يُحَدِّثُ عَنْ يَعْقُوبَ بْنِ عُتْبَةَ عَنْ جُبَيْرِ بْنِ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ عَنْ أَبِيهِ عَنْ جَدِّهِ قَالَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ جُهِدَتِ الأَنْفُسُ وَضَاعَتِ الْعِيَالُ وَنُهِكَتِ الأَمْوَالُ وَهَلَكَتِ الأَنْعَامُ فَاسْتَسْقِ اللَّهَ لَنَا فَإِنَّا نَسْتَشْفِعُ بِكَ عَلَى اللَّهِ وَنَسْتَشْفِعُ بِاللَّهِ عَلَيْكَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَيْحَكَ أَتَدْرِي مَا تَقُولُ ‏"‏ وَسَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَمَا زَالَ يُسَبِّحُ حَتَّى عُرِفَ ذَلِكَ فِي وُجُوهِ أَصْحَابِهِ ثُمَّ قَالَ ‏"‏ وَيْحَكَ إِنَّهُ لاَ يُسْتَشْفَعُ بِاللَّهِ عَلَى أَحَدٍ مِنْ خَلْقِهِ شَأْنُ اللَّهِ أَعْظَمُ مِنْ ذَلِكَ وَيْحَكَ أَتَدْرِي مَا اللَّهُ إِنَّ عَرْشَهُ عَلَى سَمَوَاتِهِ لَهَكَذَا ‏"‏ ‏.‏ وَقَالَ بِأَصَابِعِهِ مِثْلَ الْقُبَّةِ عَلَيْهِ ‏"‏ وَإِنَّهُ لَيَئِطُّ بِهِ أَطِيطَ الرَّحْلِ بِالرَّاكِبِ ‏"‏ ‏.‏ قَالَ ابْنُ بَشَّارٍ فِي حَدِيثِهِ ‏"‏ إِنَّ اللَّهَ فَوْقَ عَرْشِهِ وَعَرْشُهُ فَوْقَ سَمَوَاتِهِ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ وَقَالَ عَبْدُ الأَعْلَى وَابْنُ الْمُثَنَّى وَابْنُ بَشَّارٍ عَنْ يَعْقُوبَ بْنِ عُتْبَةَ وَجُبَيْرِ بْنِ مُحَمَّدِ بْنِ جُبَيْرٍ عَنْ أَبِيهِ عَنْ جَدِّهِ قَالَ أَبُو دَاوُدَ وَالْحَدِيثُ بِإِسْنَادِ أَحْمَدَ بْنِ سَعِيدٍ هُوَ الصَّحِيحُ وَافَقَهُ عَلَيْهِ جَمَاعَةٌ مِنْهُمْ يَحْيَى بْنُ مَعِينٍ وَعَلِيُّ بْنُ الْمَدِينِيِّ وَرَوَاهُ جَمَاعَةٌ عَنِ ابْنِ إِسْحَاقَ كَمَا قَالَ أَحْمَدُ أَيْضًا وَكَانَ سَمَاعُ عَبْدِ الأَعْلَى وَابْنِ الْمُثَنَّى وَابْنِ بَشَّارٍ مِنْ نُسْخَةٍ وَاحِدَةٍ فِيمَا بَلَغَنِي ‏.‏\hadithno{4726}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muhammad b. Jubair b. Mut’im said from his father on the authority of his grandfather:An A’rab(a nomadic Arab) came to the Messenger of Allah(ﷺ) and said: People suffering distress, the children are hungry, the crops are withered, and the animals are perished, so ask Allah to grant us rain, for we seek you as our intercessor with Allah, and Allah as intercessor with you. The Messenger of Allah(ﷺ) said: Woe to you: Do you know what you are saying? Then the Messenger of Allah(ﷺ) declared Allah’s glory and he continued declaring His glory till the effect of that was apparent in the faces of his Companions. He then said: Woe to you: Allah is not to be sought as intercessor with anyone. Allah’s state is greater than that. Woe to you! Do you know how great Allah is? His throne is above the heavens thus(indicating with his fingers like a dome over him), and it groans on account of Him as a saddle does because of the rider. Ibn Bashshar said in his version: Allah is above the throne, and the throne is above the heavens. He then mentioned the rest of the tradition. ‘Abd al-A’la, Ibn al- Muthana and Ibn Bashshar transmitted it from Ya’qub b. ‘Utbah and Jubair b. Muhammad b. Jubair from his father on the authority of his grandfather. Abu Dawud said: This tradition with the chain of Ahmad b. Sa’ad is sound. It has been approved by the body (of traditionists) , which includes Yahya b. Ma’in and ‘Ali b. al-Madani, and a group has transmitted it from Ibn Ishaq, as Ahmad also said. And so far as I have been informed ‘Abd al-A’la, Ibn al-Muthanna, and Ibn Bashshar had heard from the same copy(of the collection of tradition)}}
\hadithdefcmd{abudawud}{4727}{حَدَّثَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أُذِنَ لِي أَنْ أُحَدِّثَ عَنْ مَلَكٍ مِنْ مَلاَئِكَةِ اللَّهِ مِنْ حَمَلَةِ الْعَرْشِ إِنَّ مَا بَيْنَ شَحْمَةِ أُذُنِهِ إِلَى عَاتِقِهِ مَسِيرَةُ سَبْعِمِائَةِ عَامٍ ‏"‏ ‏.‏\hadithno{4727}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir b. ‘Abd Allah reported the Prophet (May peace be upon him) as saying :I have been permitted to tell about one of Allah’s angels who bears the throne that the distance between the lobe of his ear and his shoulder is a journey of seven hundred years}}
\hadithdefcmd{abudawud}{4728}{حَدَّثَنَا عَلِيُّ بْنُ نَصْرٍ، وَمُحَمَّدُ بْنُ يُونُسَ النَّسَائِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا حَرْمَلَةُ، - يَعْنِي ابْنَ عِمْرَانَ - حَدَّثَنِي أَبُو يُونُسَ، سُلَيْمُ بْنُ جُبَيْرٍ مَوْلَى أَبِي هُرَيْرَةَ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقْرَأُ هَذِهِ الآيَةَ ‏\{‏ إِنَّ اللَّهَ يَأْمُرُكُمْ أَنْ تُؤَدُّوا الأَمَانَاتِ إِلَى أَهْلِهَا ‏\}‏ إِلَى قَوْلِهِ تَعَالَى ‏\{‏ سَمِيعًا بَصِيرًا ‏\}‏ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَضَعُ إِبْهَامَهُ عَلَى أُذُنِهِ وَالَّتِي تَلِيهَا عَلَى عَيْنِهِ قَالَ أَبُو هُرَيْرَةَ ‏.‏ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَؤُهَا وَيَضَعُ إِصْبَعَيْهِ قَالَ ابْنُ يُونُسَ قَالَ الْمُقْرِئُ يَعْنِي ‏\{‏ إِنَّ اللَّهَ سَمِيعٌ بَصِيرٌ ‏\}‏ يَعْنِي أَنَّ لِلَّهِ سَمْعًا وَبَصَرًا ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا رَدٌّ عَلَى الْجَهْمِيَّةِ ‏.‏\hadithno{4728}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Yunus Sulaim b. Jubair, client of Abu Hurairah, said :I heard Abu Hurairah recite this verse : “Allah doth command you to render back your trusts to those to whom they are due” up to “For Allah is he who heareth and seeth all things”. He said : I saw the Messenger of Allah (May peace be upon him) putting his thumb on his ear and finger on his eye. Abu Hurairah said : I saw the Messenger of Allah (May peace be upon him) reciting this verse and putting his fingers. Ibn Yunus said that al-Muqri said. “Allah hears and sees” means that Allah has the power of hearing and seeing. Abu Dawud said: This is a refutation of the Jahmiyyah}}
\hadithdefcmd{abudawud}{4729}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، وَوَكِيعٌ، وَأَبُو أُسَامَةَ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم جُلُوسًا فَنَظَرَ إِلَى الْقَمَرِ لَيْلَةَ الْبَدْرِ لَيْلَةَ أَرْبَعَ عَشْرَةَ فَقَالَ ‏"‏ إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ كَمَا تَرَوْنَ هَذَا لاَ تُضَامُّونَ فِي رُؤْيَتِهِ فَإِنِ اسْتَطَعْتُمْ أَنْ لاَ تُغْلَبُوا عَلَى صَلاَةٍ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا فَافْعَلُوا ‏"‏ ‏.‏ ثُمَّ قَرَأَ هَذِهِ الآيَةَ ‏\{‏ فَسَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا ‏\}‏\hadithno{4729}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4851) Sahih Muslim (633)}\hadithtrans{Jarir b. ‘Abd Allah said :When we are were sitting with the Messenger of Allah (May peace be upon him) he looked at the moon on the night when it was full, that is, fourteenth, and said : You will see your Lord as you see this (moon) and have no doubts about seeing him. If, therefore, you can keep from being prevented from prayer before the sun rises and before it sets, do so. He then recited :”Celebrate the praise of your Lord before the rising of the sun and before its setting”}}
\hadithdefcmd{abudawud}{4730}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَهُ يُحَدِّثُ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ نَاسٌ يَا رَسُولَ اللَّهِ أَنَرَى رَبَّنَا يَوْمَ الْقِيَامَةِ قَالَ ‏"‏ هَلْ تُضَارُّونَ فِي رُؤْيَةِ الشَّمْسِ فِي الظَّهِيرَةِ لَيْسَتْ فِي سَحَابَةٍ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ هَلْ تُضَارُّونَ فِي رُؤْيَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ لَيْسَ فِي سَحَابَةٍ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تُضَارُّونَ فِي رُؤْيَتِهِ إِلاَّ كَمَا تُضَارُّونَ فِي رُؤْيَةِ أَحَدِهِمَا ‏"‏ ‏.‏\hadithno{4730}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2968)}\hadithtrans{Abu Hurairah said :The people asked : Messenger of Allah! Shall we see our lord, the Exalted, on the Day of resurrection? He replied : Do you feel any trouble in seeing the sun at noon when it is not in the cloud? They said: No. He asked : Do you feel any trouble in seeing the moon on the night when it is full and not in the cloud? They replied: No. He said: By him in whose hand my soul is, you will not feel any trouble in seeing him except as much as you feel in seeing any of them}}
\hadithdefcmd{abudawud}{4731}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، - الْمَعْنَى - عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ وَكِيعٍ، - قَالَ مُوسَى - ابْنُ عُدُسٍ عَنْ أَبِي رَزِينٍ، - قَالَ مُوسَى الْعُقَيْلِيُّ - قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَكُلُّنَا يَرَى رَبَّهُ قَالَ ابْنُ مُعَاذٍ مُخْلِيًا بِهِ يَوْمَ الْقِيَامَةِ وَمَا آيَةُ ذَلِكَ فِي خَلْقِهِ قَالَ ‏"‏ يَا أَبَا رَزِينٍ أَلَيْسَ كُلُّكُمْ يَرَى الْقَمَرَ ‏"‏ ‏.‏ قَالَ ابْنُ مُعَاذٍ ‏"‏ لَيْلَةَ الْبَدْرِ مُخْلِيًا بِهِ ‏"‏ ‏.‏ ثُمَّ اتَّفَقَا قُلْتُ بَلَى ‏.‏ قَالَ ‏"‏ فَاللَّهُ أَعْظَمُ ‏"‏ ‏.‏ قَالَ ابْنُ مُعَاذٍ قَالَ ‏"‏ فَإِنَّمَا هُوَ خَلْقٌ مِنْ خَلْقِ اللَّهِ فَاللَّهُ أَجَلُّ وَأَعْظَمُ ‏"‏ ‏.‏\hadithno{4731}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuRazin al-Uqayli: I asked: Messenger of Allah! will each one of us see his Lord? Ibn Mu'adh's version has: "being alone with Him, on the Day of Resurrection? And what sign is there is His creation?" He replied: AbuRazin! does each one of you not see the moon? Ibn Mu'adh's version has: "on the night when it is full, being alone with it?" Then the agreed version goes: I said: Yes. He said: Allah is more great. Ibn Mu'adh's version has: It is only part of Allah's creation, but Allah is more glorious and greater}}
\hadithdefcmd{abudawud}{4732}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، أَنَّ أَبَا أُسَامَةَ، أَخْبَرَهُمْ عَنْ عُمَرَ بْنِ حَمْزَةَ، قَالَ قَالَ سَالِمٌ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَطْوِي اللَّهُ السَّمَوَاتِ يَوْمَ الْقِيَامَةِ ثُمَّ يَأْخُذُهُنَّ بِيَدِهِ الْيُمْنَى ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَيْنَ الْجَبَّارُونَ أَيْنَ الْمُتَكَبِّرُونَ ثُمَّ يَطْوِي الأَرَضِينَ ثُمَّ يَأْخُذُهُنَّ ‏"‏ ‏.‏ قَالَ ابْنُ الْعَلاَءِ ‏"‏ بِيَدِهِ الأُخْرَى ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَيْنَ الْجَبَّارُونَ أَيْنَ الْمُتَكَبِّرُونَ ‏"‏ ‏.‏\hadithno{4732}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2778)}\hadithtrans{‘Abd Allah b. ‘Umar reported the Messenger of Allah (May peace be upon him) as saying:Allah will fold the heavens an the day of Resurrection, then seizing them in His right hand he will say: I am the king. Where are the mighty men? Where are the proud men? He will then fold the earths and take them in his other hand (According to the version of Ibn al-Ala), and then say ; I am the King. Where are the mighty men? Where are the proud men?}}
\hadithdefcmd{abudawud}{4733}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَعَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَنْزِلُ رَبُّنَا كُلَّ لَيْلَةٍ إِلَى سَمَاءِ الدُّنْيَا حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرِ فَيَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ مَنْ يَسْأَلُنِي فَأُعْطِيَهُ مَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ ‏"‏ ‏.‏\hadithno{4733}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1145) Sahih Muslim (758)}\hadithtrans{Abu Hurairah reported the Prophet (May peace be upon him) as saying; Our lord gets down every night to the heaven of this world when a third night remains and says :(Is there anyone) who prays to Me so that I may accept his prayer? (Is there anyone) who asks of Me so that I may give him? (Is there anyone) who asks for my forgiveness so that I may forgive him?}}
\hadithdefcmd{abudawud}{4734}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا إِسْرَائِيلُ، حَدَّثَنَا عُثْمَانُ بْنُ الْمُغِيرَةِ، عَنْ سَالِمٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْرِضُ نَفْسَهُ عَلَى النَّاسِ فِي الْمَوْقِفِ فَقَالَ ‏ "‏ أَلاَ رَجُلٌ يَحْمِلُنِي إِلَى قَوْمِهِ فَإِنَّ قُرَيْشًا قَدْ مَنَعُونِي أَنْ أُبَلِّغَ كَلاَمَ رَبِّي ‏"‏ ‏.‏\hadithno{4734}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) presented himself to the people at Arafat, saying: Is there any man who takes me to his people? The Quraysh have prevented me from preaching the word of my Lord}}
\hadithdefcmd{abudawud}{4735}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، وَعَلْقَمَةُ بْنُ وَقَّاصٍ، وَعُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنْ حَدِيثِ، عَائِشَةَ وَكُلٌّ حَدَّثَنِي طَائِفَةً، مِنَ الْحَدِيثِ قَالَتْ وَلَشَأْنِي فِي نَفْسِي كَانَ أَحْقَرَ مِنْ أَنْ يَتَكَلَّمَ اللَّهُ فِيَّ بِأَمْرٍ يُتْلَى ‏.‏\hadithno{4735}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘A’ishah said:I thought in my mind that my affair was far inferior to the speaking of Allah about me with a command that will be recited}}
\hadithdefcmd{abudawud}{4736}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عُمَرَ، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مُجَالِدٍ، عَنْ عَامِرٍ، - يَعْنِي الشَّعْبِيَّ - عَنْ عَامِرِ بْنِ شَهْرٍ، قَالَ ‏:‏ كُنْتُ عِنْدَ النَّجَاشِيِّ فَقَرَأَ ابْنٌ لَهُ آيَةً مِنَ الإِنْجِيلِ فَضَحِكْتُ فَقَالَ ‏:‏ أَتَضْحَكُ مِنْ كَلاَمِ اللَّهِ\hadithno{4736}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Amir b. Shahr said :I was with the Negus when his son recited a verse of the Gospel. So I laughed. Thereupon he said : Do you laugh at the word of Allah, the Exalted?}}
\hadithdefcmd{abudawud}{4737}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعَوِّذُ الْحَسَنَ وَالْحُسَيْنَ ‏:‏ ‏"‏ أُعِيذُكُمَا بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ كُلِّ شَيْطَانٍ وَهَامَّةٍ وَمِنْ كُلِّ عَيْنٍ لاَمَّةٍ ‏"‏ ‏.‏ ثُمَّ يَقُولُ ‏:‏ ‏"‏ كَانَ أَبُوكُمْ يُعَوِّذُ بِهِمَا إِسْمَاعِيلَ وَإِسْحَاقَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ هَذَا دَلِيلٌ عَلَى أَنَّ الْقُرْآنَ لَيْسَ بِمَخْلُوقٍ ‏.‏\hadithno{4737}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3371)}\hadithtrans{Ibn ‘abbas said :The Prophet (May peace be upon him) used to seek refuge in Allah for al-Hasan and al-husain, saying ; I seek refuge for both of you in the perfect words of Allah from every devil and every poisonous thing and from the evil eye which influences. He would then say; your father sought refuge in Allah by them for Ismail and Ishaq. Abu Dawud said; this is a proof of the fact that the Quran is not created}}
\hadithdefcmd{abudawud}{4738}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي سُرَيْجٍ الرَّازِيُّ، وَعَلِيُّ بْنُ الْحُسَيْنِ بْنِ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ مُسْلِمٍ، قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ إِذَا تَكَلَّمَ اللَّهُ بِالْوَحْىِ سَمِعَ أَهْلُ السَّمَاءِ لِلسَّمَاءِ صَلْصَلَةً كَجَرِّ السِّلْسِلَةِ عَلَى الصَّفَا فَيُصْعَقُونَ، فَلاَ يَزَالُونَ كَذَلِكَ حَتَّى يَأْتِيَهُمْ جِبْرِيلُ حَتَّى إِذَا جَاءَهُمْ جِبْرِيلُ فُزِّعَ عَنْ قُلُوبِهِمْ ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ فَيَقُولُونَ ‏:‏ يَا جِبْرِيلُ مَاذَا قَالَ رَبُّكَ فَيَقُولُ ‏:‏ الْحَقَّ فَيَقُولُونَ ‏:‏ الْحَقَّ الْحَقَّ ‏"‏ ‏.‏\hadithno{4738}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Abd Allah (b. Mas’ud) reported the Messenger of Allah (ﷺ) as saying:"When Allah, the exalted, speaks to send revelation, the inhabitants of heaven hear the clanging of a bell from the heavens like a chain being dragged across a rock, and they swoon. They continue to remain like that until Jibril comes to them. When he comes to them, they recover and say: 'O Jibril, what did your Lord say?' He would say: 'The truth,' and they would say: 'The truth, the truth}}
\hadithdefcmd{abudawud}{4739}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا بِسْطَامُ بْنُ حُرَيْثٍ، عَنْ أَشْعَثَ الْحُدَّانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ شَفَاعَتِي لأَهْلِ الْكَبَائِرِ مِنْ أُمَّتِي ‏"‏ ‏.‏\hadithno{4739}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: My intercession will be for those of my people who have committed major sins}}
\hadithdefcmd{abudawud}{4740}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ الْحَسَنِ بْنِ ذَكْوَانَ، حَدَّثَنَا أَبُو رَجَاءٍ، قَالَ حَدَّثَنِي عِمْرَانُ بْنُ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ يَخْرُجُ قَوْمٌ مِنَ النَّارِ بِشَفَاعَةِ مُحَمَّدٍ فَيَدْخُلُونَ الْجَنَّةَ وَيُسَمَّوْنَ الْجَهَنَّمِيِّينَ ‏"‏ ‏.‏\hadithno{4740}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Bukhari (6566)}\hadithtrans{‘Imran b. Husain reported the Prophet(ﷺ) as saying:People will come forth from Hell by Muhammad’s intercession, will enter paradise and be named Jahannamis}}
\hadithdefcmd{abudawud}{4741}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏ "‏ إِنَّ أَهْلَ الْجَنَّةِ يَأْكُلُونَ فِيهَا وَيَشْرَبُونَ ‏"‏ ‏.‏\hadithno{4741}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2835)}\hadithtrans{Jabir said:I heard the Prophet(ﷺ) say: Those who go to Paradise will eat in it and drink}}
\hadithdefcmd{abudawud}{4742}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنَا أَسْلَمُ، عَنْ بِشْرِ بْنِ شَغَافٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ الصُّورُ قَرْنٌ يُنْفَخُ فِيهِ ‏"‏ ‏.‏\hadithno{4742}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: The trumpet (sur) which will be blown}}
\hadithdefcmd{abudawud}{4743}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ كُلَّ ابْنِ آدَمَ تَأْكُلُ الأَرْضُ إِلاَّ عَجْبَ الذَّنَبِ، مِنْهُ خُلِقَ وَفِيهِ يُرَكَّبُ ‏"‏ ‏.‏\hadithno{4743}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported the Apostle of AllSah(ﷺ) as saying:Every son of Adam will be devoured by the earth with the exception of the tail-bone from which he was created and from which he will be reconstituted}}
\hadithdefcmd{abudawud}{4744}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ لَمَّا خَلَقَ اللَّهُ الْجَنَّةَ قَالَ لِجِبْرِيلَ ‏:‏ اذْهَبْ فَانْظُرْ إِلَيْهَا ‏.‏ فَذَهَبَ فَنَظَرَ إِلَيْهَا ثُمَّ جَاءَ فَقَالَ ‏:‏ أَىْ رَبِّ وَعِزَّتِكَ لاَ يَسْمَعُ بِهَا أَحَدٌ إِلاَّ دَخَلَهَا ثُمَّ حَفَّهَا بِالْمَكَارِهِ ثُمَّ قَالَ ‏:‏ يَا جِبْرِيلُ اذْهَبْ فَانْظُرْ إِلَيْهَا فَذَهَبَ فَنَظَرَ إِلَيْهَا ثُمَّ جَاءَ فَقَالَ ‏:‏ أَىْ رَبِّ وَعِزَّتِكَ لَقَدْ خَشِيتُ أَنْ لاَ يَدْخُلَهَا أَحَدٌ ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ فَلَمَّا خَلَقَ اللَّهُ النَّارَ قَالَ ‏:‏ يَا جِبْرِيلُ اذْهَبْ فَانْظُرْ إِلَيْهَا ‏.‏ فَذَهَبَ فَنَظَرَ إِلَيْهَا ثُمَّ جَاءَ فَقَالَ ‏:‏ أَىْ رَبِّ وَعِزَّتِكَ لاَ يَسْمَعُ بِهَا أَحَدٌ فَيَدْخُلُهَا فَحَفَّهَا بِالشَّهَوَاتِ ثُمَّ قَالَ ‏:‏ يَا جِبْرِيلُ اذْهَبْ فَانْظُرْ إِلَيْهَا ‏.‏ فَذَهَبَ فَنَظَرَ إِلَيْهَا ثُمَّ جَاءَ فَقَالَ ‏:‏ أَىْ رَبِّ وَعِزَّتِكَ لَقَدْ خَشِيتُ أَنْ لاَ يَبْقَى أَحَدٌ إِلاَّ دَخَلَهَا ‏"‏ ‏.‏\hadithno{4744}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) said: When Allah created Paradise, He said to Gabriel: Go and look at it. He went and looked at it, then came and said: O my Lord! By Thy might, no one who hears of it will fail to enter it. He then surrounded it with disagreeable things, and said: Go and look at it, Gabriel. He went and looked at it, then came and said: O my Lord! By Thy might, I am afraid that no one will enter it. When Allah created Hell, He said: Go and look at it, Gabriel. He went and looked at it, then came and said: O my Lord! By Thy might, no one who hears of it will enter it. He then surrounded it with desirable things and said: Go and look at it, Gabriel. He went, looked at it, then came and said: O my Lord! By Thy might and power, I am afraid that no one will remain who does not enter it}}
\hadithdefcmd{abudawud}{4745}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ إِنَّ أَمَامَكُمْ حَوْضًا مَا بَيْنَ نَاحِيَتَيْهِ كَمَا بَيْنَ جَرْبَاءَ وَأَذْرُحَ ‏"‏ ‏.‏\hadithno{4745}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2299)}\hadithtrans{Ibn ‘Umar reported the Messenger of Allah(ﷺ) as saying:Before you there will be a pond the distance between whose sides is like that between Jarbah and Adhruh}}
\hadithdefcmd{abudawud}{4746}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي حَمْزَةَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ ‏:‏ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَزَلْنَا مَنْزِلاً فَقَالَ ‏:‏ ‏ "‏ مَا أَنْتُمْ جُزْءٌ مِنْ مِائَةِ أَلْفِ جُزْءٍ مِمَّنْ يَرِدُ عَلَىَّ الْحَوْضَ ‏"‏ ‏.‏ قَالَ قُلْتُ ‏:‏ كَمْ كُنْتُمْ يَوْمَئِذٍ قَالَ ‏:‏ سَبْعَمِائَةٍ أَوْ ثَمَانَمِائَةٍ ‏.‏\hadithno{4746}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Zayd ibn Arqam: We were with the Messenger of Allah (ﷺ). He said when we arrived at a halting place: You are not a hundred thousandth part of those who will come down to me at the pond. I (the narrator AbuHamzah) asked: What was your number that day? He replied: Seven or eight hundred}}
\hadithdefcmd{abudawud}{4747}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الْمُخْتَارِ بْنِ فُلْفُلٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ ‏:‏ أَغْفَى رَسُولُ اللَّهِ صلى الله عليه وسلم إِغْفَاءَةً فَرَفَعَ رَأْسَهُ مُتَبَسِّمًا، فَإِمَّا قَالَ لَهُمْ وَإِمَّا قَالُوا لَهُ ‏:‏ يَا رَسُولَ اللَّهِ لِمَ ضَحِكْتَ فَقَالَ ‏:‏ ‏"‏ إِنَّهُ أُنْزِلَتْ عَلَىَّ آنِفًا سُورَةٌ ‏"‏ ‏.‏ فَقَرَأَ ‏‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ \{إِنَّا أَعْطَيْنَاكَ الْكَوْثَرَ\} ‏‏ حَتَّى خَتَمَهَا فَلَمَّا قَرَأَهَا قَالَ ‏:‏ ‏"‏ هَلْ تَدْرُونَ مَا الْكَوْثَرُ ‏"‏ ‏.‏ قَالُوا ‏:‏ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏:‏ ‏"‏ فَإِنَّهُ نَهْرٌ وَعَدَنِيهِ رَبِّي عَزَّ وَجَلَّ فِي الْجَنَّةِ، وَعَلَيْهِ خَيْرٌ كَثِيرٌ عَلَيْهِ حَوْضٌ تَرِدُ عَلَيْهِ أُمَّتِي يَوْمَ الْقِيَامَةِ آنِيَتُهُ عَدَدُ الْكَوَاكِبِ ‏"‏ ‏.‏\hadithno{4747}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih Muslim (400)}\hadithtrans{Anas b. Malik said:The Messenger of Allah(ﷺ) dozed for a short while and raised his smiling. He either said to them(people) or they said to him: Messenger of Allah! Why did you laugh? He said: A surah has been revealed to me just now, and then he recited: “In the name of Allah, Most Gracious. Most Merciful. To thee We have granted the fount (of abundance)” up to the end. When he recited, he asked: Do you know what al-kauthar is? They replied: Allah and his Apostle know best. He said: It is a river which my Lord, the Exalted, has promised me( to grant) in Paradise: there is abundance of good and upon it there is a pond which my people will approach on the Day of Resurrection. There are vessels as numerous as stars(in the sky)}}
\hadithdefcmd{abudawud}{4748}{حَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ ‏:‏ لَمَّا عُرِجَ بِنَبِيِّ اللَّهِ صلى الله عليه وسلم فِي الْجَنَّةِ - أَوْ كَمَا قَالَ - عُرِضَ لَهُ نَهْرٌ حَافَتَاهُ الْيَاقُوتُ الْمُجَيَّبُ أَوْ قَالَ الْمُجَوَّفُ، فَضَرَبَ الْمَلَكُ الَّذِي مَعَهُ يَدَهُ فَاسْتَخْرَجَ مِسْكًا فَقَالَ مُحَمَّدٌ صلى الله عليه وسلم لِلْمَلَكِ الَّذِي مَعَهُ ‏:‏ ‏ "‏ مَا هَذَا ‏"‏ ‏.‏ قَالَ ‏:‏ هَذَا الْكَوْثَرُ الَّذِي أَعْطَاكَ اللَّهُ عَزَّ وَجَلَّ ‏.‏\hadithno{4748}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4964)}\hadithtrans{Narrated Anas ibn Malik: When the Prophet of Allah (ﷺ) was lifted to the heavens (for travelling) in Paradise, or as he said, a river whose banks were of transparent or hollowed pearls was presented to him. The angel who was with him struck it with his hand and took out musk. Muhammad (ﷺ) then asked the angel who was with him: What is this? He replied: It is al-Kawthar which Allah has given you}}
\hadithdefcmd{abudawud}{4749}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ أَبِي حَازِمٍ أَبُو طَالُوتَ، قَالَ شَهِدْتُ أَبَا بَرْزَةَ دَخَلَ عَلَى عُبَيْدِ اللَّهِ بْنِ زِيَادٍ فَحَدَّثَنِي فُلاَنٌ، سَمَّاهُ مُسْلِمٌ وَكَانَ فِي السِّمَاطِ فَلَمَّا رَآهُ عُبَيْدُ اللَّهِ قَالَ ‏:‏ إِنَّ مُحَمَّدِيَّكُمْ هَذَا الدَّحْدَاحُ، فَفَهِمَهَا الشَّيْخُ فَقَالَ مَا كُنْتُ أَحْسِبُ أَنِّي أَبْقَى فِي قَوْمٍ يُعَيِّرُونِي بِصُحْبَةِ مُحَمَّدٍ صلى الله عليه وسلم فَقَالَ لَهُ عُبَيْدُ اللَّهِ إِنَّ صُحْبَةَ مُحَمَّدٍ صلى الله عليه وسلم لَكَ زَيْنٌ غَيْرُ شَيْنٍ ثُمَّ قَالَ ‏:‏ إِنَّمَا بُعِثْتُ إِلَيْكَ لأَسْأَلَكَ عَنِ الْحَوْضِ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ فِيهِ شَيْئًا فَقَالَ أَبُو بَرْزَةَ ‏:‏ نَعَمْ لاَ مَرَّةً وَلاَ ثِنْتَيْنِ وَلاَ ثَلاَثًا وَلاَ أَرْبَعًا وَلاَ خَمْسًا، فَمَنْ كَذَّبَ بِهِ فَلاَ سَقَاهُ اللَّهُ مِنْهُ ثُمَّ خَرَجَ مُغْضَبًا ‏.‏\hadithno{4749}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{AbdusSalam ibn AbuHazim AbuTalut said:I saw AbuBarzah who came to visit Ubaydullah ibn Ziyad. Then a man named Muslim who was there in the company mentioned it to me. When Ubaydullah saw him, he said: This Muhammadan [i.e. Companion of Muhammad (ﷺ)] of yours is short and fat. The old man (i.e. AbuBarzah) understood it. So he said: I did not think I would remain amongst a people who would criticize me for having had the company of Muhammad (ﷺ). Thereupon Ubaydullah said to him: The company of Muhammad (ﷺ) is a honour for you, not a disgrace. He added: I called for you to ask about the Haud (reservoir or cistern). Did you hear the Messenger of Allah (ﷺ) say anything about it? AbuBarzah said: Yes, not once, twice, thrice, four times or five times. Whoever disbelieves in it, may Allah not supply him with water from it. He then went away angrily}}
\hadithdefcmd{abudawud}{4750}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ إِنَّ الْمُسْلِمَ إِذَا سُئِلَ فِي الْقَبْرِ فَشَهِدَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَلِكَ قَوْلُ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ ‏\}‏ ‏.‏\hadithno{4750}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4699) Sahih Muslim (2871)}\hadithtrans{Al-Bara’ b. ‘Azib reported the Messenger of Allah(ﷺ) as saying:When a Muslim is questioned in the grave he testifies that there is no god but Allah and that Muhammad is Allah’s Apostle. That is verified by Allah’s words: “Allah establishes those who believe with the word that stands firm.”}}
\hadithdefcmd{abudawud}{4751}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ الْخَفَّافُ أَبُو نَصْرٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ ‏:‏ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم دَخَلَ نَخْلاً لِبَنِي النَّجَّارِ فَسَمِعَ صَوْتًا فَفَزِعَ فَقَالَ ‏:‏ ‏"‏ مَنْ أَصْحَابُ هَذِهِ الْقُبُورِ ‏"‏ ‏.‏ قَالُوا ‏:‏ يَا رَسُولَ اللَّهِ نَاسٌ مَاتُوا فِي الْجَاهِلِيَّةِ ‏.‏ فَقَالَ ‏:‏ ‏"‏ تَعَوَّذُوا بِاللَّهِ مِنْ عَذَابِ النَّارِ وَمِنْ فِتْنَةِ الدَّجَّالِ ‏"‏ ‏.‏ قَالُوا ‏:‏ وَمِمَّ ذَاكَ يَا رَسُولَ اللَّهِ قَالَ ‏:‏ ‏"‏ إِنَّ الْمُؤْمِنَ إِذَا وُضِعَ فِي قَبْرِهِ أَتَاهُ مَلَكٌ فَيَقُولُ لَهُ ‏:‏ مَا كُنْتَ تَعْبُدُ فَإِنِ اللَّهُ هَدَاهُ قَالَ ‏:‏ كُنْتُ أَعْبُدُ اللَّهَ ‏.‏ فَيُقَالُ لَهُ ‏:‏ مَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ فَيَقُولُ ‏:‏ هُوَ عَبْدُ اللَّهِ وَرَسُولُهُ فَمَا يُسْأَلُ عَنْ شَىْءٍ غَيْرَهَا فَيُنْطَلَقُ بِهِ إِلَى بَيْتٍ كَانَ لَهُ فِي النَّارِ، فَيُقَالُ لَهُ ‏:‏ هَذَا بَيْتُكَ كَانَ لَكَ فِي النَّارِ وَلَكِنَّ اللَّهَ عَصَمَكَ وَرَحِمَكَ فَأَبْدَلَكَ بِهِ بَيْتًا فِي الْجَنَّةِ فَيَقُولُ ‏:‏ دَعُونِي حَتَّى أَذْهَبَ فَأُبَشِّرَ أَهْلِي ‏.‏ فَيُقَالُ لَهُ ‏:‏ اسْكُنْ ‏.‏ وَإِنَّ الْكَافِرَ إِذَا وُضِعَ فِي قَبْرِهِ أَتَاهُ مَلَكٌ فَيَنْتَهِرُهُ فَيَقُولُ لَهُ ‏:‏ مَا كُنْتَ تَعْبُدُ فَيَقُولُ ‏:‏ لاَ أَدْرِي ‏.‏ فَيُقَالُ لَهُ ‏:‏ لاَ دَرَيْتَ وَلاَ تَلَيْتَ ‏.‏ فَيُقَالُ لَهُ ‏:‏ فَمَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ فَيَقُولُ ‏:‏ كُنْتُ أَقُولُ مَا يَقُولُ النَّاسُ ‏.‏ فَيَضْرِبُهُ بِمِطْرَاقٍ مِنْ حَدِيدٍ بَيْنَ أُذُنَيْهِ فَيَصِيحُ صَيْحَةً يَسْمَعُهَا الْخَلْقُ غَيْرَ الثَّقَلَيْنِ ‏"‏ ‏.‏\hadithno{4751}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1338) Sahih Muslim (2870)}\hadithtrans{Anas b. Malik said:The Messenger of Allah(ﷺ) entered the garden of the palm trees of Banu al-Najjar. He heard a voice and was terrified. He asked: Who are the people buried in these graves? The people replied: Messenger of Allah! These are some people who died in the pre-Islamic times. He said: Seek refuge in Allah from the punishment of the fire, and the trail of Antichrist. They asked: Why is it that, Messenger of Allah? He said: When a man is placed in his grave, an angel comes to him and says to him: Whom did you worship? Allah then guides him and he says: I worshiped Allah. He is then asked: What was your opinion of this man? He replies: He is Allah’s servant and His Apostle. He will not then be asked about anything else. He will then be taken to his abode in Hell and will be told: This was your abode in Hell, but Allah protected you and had mercy on you substituted for you an abode in Paradise for it. He will say: Leave me so that I may go and give glad tidings to my family. He will be told: Dwell. When an infidel is placed in his grave, an angel comes to him, reprimands him and asks him: Whom did you worship? He replies: I do not know. He will be told: You neither knew nor did you follow(the believers). He is then asked: What was your opinion on this man? He replies: I held the opinion that the other people held. He will then give him a blow between his ears with an iron hammer and will utter a shout which will be heard by all the creatures(near him) with the exception of men and jinn}}
\hadithdefcmd{abudawud}{4752}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، بِمِثْلِ هَذَا الإِسْنَادِ نَحْوَهُ قَالَ ‏:‏ ‏"‏ إِنَّ الْعَبْدَ إِذَا وُضِعَ فِي قَبْرِهِ وَتَوَلَّى عَنْهُ أَصْحَابُهُ إِنَّهُ لَيَسْمَعُ قَرْعَ نِعَالِهِمْ، فَيَأْتِيهِ مَلَكَانِ فَيَقُولاَنِ لَهُ ‏"‏ ‏.‏ فَذَكَرَ قَرِيبًا مِنْ حَدِيثِ الأَوَّلِ قَالَ فِيهِ ‏:‏ ‏"‏ وَأَمَّا الْكَافِرُ وَالْمُنَافِقُ فَيَقُولاَنِ لَهُ ‏"‏ ‏.‏ زَادَ ‏:‏ ‏"‏ الْمُنَافِقُ ‏"‏ ‏.‏ وَقَالَ ‏:‏ ‏"‏ يَسْمَعُهَا مَنْ يَلِيهِ غَيْرَ الثَّقَلَيْنِ ‏"‏ ‏.‏\hadithno{4752}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1338) Sahih Muslim (2870)}\hadithtrans{The tradition mentioned above has also transmitted by ‘Abd al-Wahhab through a different chain of narrators in a similar manner. This version has :When a man is placed in his grave and his friends leave him, he hears the beat of their sandals. Then two angles come and speak to him. He then mentioned the rest of the tradition nearly similar to the previous one. It goes : As for the infidel and hypocrite they say to them. This version adds the word “hypocrite”. And he said : those who are near him will hear (his shout) with the exception of men and jinn}}
\hadithdefcmd{abudawud}{4753}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، - وَهَذَا لَفْظُ هَنَّادٍ - عَنِ الأَعْمَشِ، عَنِ الْمِنْهَالِ، عَنْ زَاذَانَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ ‏:‏ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي جَنَازَةِ رَجُلٍ مِنَ الأَنْصَارِ، فَانْتَهَيْنَا إِلَى الْقَبْرِ وَلَمَّا يُلْحَدْ، فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجَلَسْنَا حَوْلَهُ كَأَنَّمَا عَلَى رُءُوسِنَا الطَّيْرُ، وَفِي يَدِهِ عُودٌ يَنْكُتُ بِهِ فِي الأَرْضِ، فَرَفَعَ رَأْسَهُ فَقَالَ ‏:‏ ‏"‏ اسْتَعِيذُوا بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا - زَادَ فِي حَدِيثِ جَرِيرٍ هَا هُنَا - وَقَالَ ‏:‏ ‏"‏ وَإِنَّهُ لَيَسْمَعُ خَفْقَ نِعَالِهِمْ إِذَا وَلَّوْا مُدْبِرِينَ حِينَ يُقَالُ لَهُ ‏:‏ يَا هَذَا مَنْ رَبُّكَ وَمَا دِينُكَ وَمَنْ نَبِيُّكَ ‏"‏ ‏.‏ قَالَ هَنَّادٌ قَالَ ‏:‏ ‏"‏ وَيَأْتِيهِ مَلَكَانِ فَيُجْلِسَانِهِ فَيَقُولاَنِ لَهُ ‏:‏ مَنْ رَبُّكَ فَيَقُولُ ‏:‏ رَبِّيَ اللَّهُ ‏.‏ فَيَقُولاَنِ لَهُ ‏:‏ مَا دِينُكَ فَيَقُولُ ‏:‏ دِينِي الإِسْلاَمُ ‏.‏ فَيَقُولاَنِ لَهُ ‏:‏ مَا هَذَا الرَّجُلُ الَّذِي بُعِثَ فِيكُمْ قَالَ فَيَقُولُ ‏:‏ هُوَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَيَقُولاَنِ ‏:‏ وَمَا يُدْرِيكَ فَيَقُولُ ‏:‏ قَرَأْتُ كِتَابَ اللَّهِ فَآمَنْتُ بِهِ وَصَدَّقْتُ ‏"‏ ‏.‏ زَادَ فِي حَدِيثِ جَرِيرٍ ‏:‏ ‏"‏ فَذَلِكَ قَوْلُ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا ‏\}‏ ‏"‏ ‏.‏ الآيَةَ ‏.‏ ثُمَّ اتَّفَقَا قَالَ ‏:‏ ‏"‏ فَيُنَادِي مُنَادٍ مِنَ السَّمَاءِ ‏:‏ أَنْ قَدْ صَدَقَ عَبْدِي فَأَفْرِشُوهُ مِنَ الْجَنَّةِ، وَافْتَحُوا لَهُ بَابًا إِلَى الْجَنَّةِ وَأَلْبِسُوهُ مِنَ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ فَيَأْتِيهِ مِنْ رَوْحِهَا وَطِيبِهَا ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ وَيُفْتَحُ لَهُ فِيهَا مَدَّ بَصَرِهِ ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ وَإِنَّ الْكَافِرَ ‏"‏ ‏.‏ فَذَكَرَ مَوْتَهُ قَالَ ‏:‏ ‏"‏ وَتُعَادُ رُوحُهُ فِي جَسَدِهِ وَيَأْتِيهِ مَلَكَانِ فَيُجْلِسَانِهِ فَيَقُولاَنِ ‏:‏ مَنْ رَبُّكَ فَيَقُولُ ‏:‏ هَاهْ هَاهْ هَاهْ لاَ أَدْرِي ‏.‏ فَيَقُولاَنِ لَهُ ‏:‏ مَا دِينُكَ فَيَقُولُ ‏:‏ هَاهْ هَاهْ لاَ أَدْرِي ‏.‏ فَيَقُولاَنِ ‏:‏ مَا هَذَا الرَّجُلُ الَّذِي بُعِثَ فِيكُمْ فَيَقُولُ ‏:‏ هَاهْ هَاهْ لاَ أَدْرِي ‏.‏ فَيُنَادِي مُنَادٍ مِنَ السَّمَاءِ ‏:‏ أَنْ كَذَبَ فَأَفْرِشُوهُ مِنَ النَّارِ وَأَلْبِسُوهُ مِنَ النَّارِ، وَافْتَحُوا لَهُ بَابًا إِلَى النَّارِ ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ فَيَأْتِيهِ مِنْ حَرِّهَا وَسَمُومِهَا ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ وَيُضَيَّقُ عَلَيْهِ قَبْرُهُ حَتَّى تَخْتَلِفَ فِيهِ أَضْلاَعُهُ ‏"‏ ‏.‏ زَادَ فِي حَدِيثِ جَرِيرٍ قَالَ ‏:‏ ‏"‏ ثُمَّ يُقَيَّضُ لَهُ أَعْمَى أَبْكَمُ مَعَهُ مِرْزَبَّةٌ مِنْ حَدِيدٍ، لَوْ ضُرِبَ بِهَا جَبَلٌ لَصَارَ تُرَابًا ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ فَيَضْرِبُهُ بِهَا ضَرْبَةً يَسْمَعُهَا مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ إِلاَّ الثَّقَلَيْنِ فَيَصِيرُ تُرَابًا ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ ثُمَّ تُعَادُ فِيهِ الرُّوحُ ‏"‏ ‏.‏\hadithno{4753}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Bara' ibn Azib: We went out with the Messenger of Allah (ﷺ) accompanying the bier of a man of the Ansar. When we reached his grave, it was not yet dug. So the Messenger of Allah (ﷺ) sat down and we also sat down around him as if birds were over our heads. He had in his hand a stick with which he was scratching the ground. He then raised his head and said: Seek refuge with Allah from the punishment in the grave. He said it twice or thrice. The version of Jabir adds here: He hears the beat of their sandals when they go back, and at that moment he is asked: O so and so! Who is your Lord, what is your religion, and who is your Prophet? Hannad's version says: Two angels will come to him, make him sit up and ask him: Who is your Lord? He will reply: My Lord is Allah. They will ask him: What is your religion? He will reply: My religion is Islam. They will ask him: What is your opinion about the man who was sent on a mission among you? He will reply: He is the Messenger of Allah (ﷺ). They will ask: Who made you aware of this? He will reply: I read Allah's Book, believed in it, and considered it true; which is verified by Allah's words: "Allah's Book, believed in it, and considered it true, which is verified by Allah's words: "Allah establishes those who believe with the word that stands firm in this world and the next." The agreed version reads: Then a crier will call from Heaven: My servant has spoken the truth, so spread a bed for him from Paradise, clothe him from Paradise, and open a door for him into Paradise. So some of its air and perfume will come to him, and a space will be made for him as far as the eye can see. He also mentioned the death of the infidel, saying: His spirit will be restored to his body, two angels will come to him, make him sit up and ask him: Who is your Lord? He will reply: Alas, alas! I do not know. They will ask him: What is your religion? He will reply: Alas, alas! I do not know. They will ask: Who was the man who was sent on a mission among you? He will reply: Alas, alas! I do not know. Then a crier will call from Heaven: He has lied, so spread a bed for him from Hell, clothe him from Hell, and open for him a door into Hell. Then some of its heat and pestilential wind will come to him, and his grave will be compressed, so that his ribs will be crushed together. Jabir's version adds: One who is blind and dumb will then be placed in charge of him, having a sledge-hammer such that if a mountain were struck with it, it would become dust. He will give him a blow with it which will be heard by everything between the east and the west except by men and jinn, and he will become dust. Then his spirit will be restored to him}}
\hadithdefcmd{abudawud}{4754}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا الْمِنْهَالُ، عَنْ أَبِي عُمَرَ، ‏:‏ زَاذَانَ قَالَ سَمِعْتُ الْبَرَاءَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{4754}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Al-Bara’ (b. ‘Azib) from the prophet (May peace be upon him) through a different chain of narrators is a similar way}}
\hadithdefcmd{abudawud}{4755}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، أَنَّ إِسْمَاعِيلَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُمْ قَالَ أَخْبَرَنَا يُونُسُ، عَنِ الْحَسَنِ، عَنْ عَائِشَةَ، ‏:‏ أَنَّهَا ذَكَرَتِ النَّارَ فَبَكَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ مَا يُبْكِيكِ ‏"‏ ‏.‏ قَالَتْ ‏:‏ ذَكَرْتُ النَّارَ فَبَكَيْتُ، فَهَلْ تَذْكُرُونَ أَهْلِيكُمْ يَوْمَ الْقِيَامَةِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ أَمَّا فِي ثَلاَثَةِ مَوَاطِنَ فَلاَ يَذْكُرُ أَحَدٌ أَحَدًا ‏:‏ عِنْدَ الْمِيزَانِ حَتَّى يَعْلَمَ أَيَخِفُّ مِيزَانُهُ أَوْ يَثْقُلُ، وَعِنْدَ الْكِتَابِ حِينَ يُقَالُ ‏\{‏ هَاؤُمُ اقْرَءُوا كِتَابِيَهْ ‏\}‏ حَتَّى يَعْلَمَ أَيْنَ يَقَعُ كِتَابُهُ أَفِي يَمِينِهِ أَمْ فِي شِمَالِهِ أَمْ مِنْ وَرَاءِ ظَهْرِهِ، وَعِنْدَ الصِّرَاطِ إِذَا وُضِعَ بَيْنَ ظَهْرَىْ جَهَنَّمَ ‏"‏ ‏.‏ قَالَ يَعْقُوبُ ‏:‏ عَنْ يُونُسَ وَهَذَا لَفْظُ حَدِيثِهِ ‏.‏\hadithno{4755}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘A’ishah said that she thought of Hell and wept. The Messenger of Allah (May peace be upon him) asked her :What makes you weep ? She replied : I thought of Hell and wept. Will you remember your family on the 4th Day of resurrection ? the Messenger of Allah (May peace be upon him) said : There are three places where no one will remember anyone: at the scale until one knows whether his weight is light or heavy; at (the examination of) the book when one is commanded : Take and read Allah’s record, until he knows whether his book will be put into his right hand, or into his left hand, or behind his back ; and the path when it is placed across JAHANNAM}}
\hadithdefcmd{abudawud}{4756}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ سُرَاقَةَ، عَنْ أَبِي عُبَيْدَةَ بْنِ الْجَرَّاحِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏"‏ إِنَّهُ لَمْ يَكُنْ نَبِيٌّ بَعْدَ نُوحٍ إِلاَّ وَقَدْ أَنْذَرَ الدَّجَّالَ قَوْمَهُ، وَإِنِّي أُنْذِرُكُمُوهُ ‏"‏ ‏.‏ فَوَصَفَهُ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏:‏ ‏"‏ لَعَلَّهُ سَيُدْرِكُهُ مَنْ قَدْ رَآنِي وَسَمِعَ كَلاَمِي ‏"‏ ‏.‏ قَالُوا ‏:‏ يَا رَسُولَ اللَّهِ كَيْفَ قُلُوبُنَا يَوْمَئِذٍ أَمِثْلُهَا الْيَوْمَ قَالَ ‏:‏ ‏"‏ أَوْ خَيْرٌ ‏"‏ ‏.‏\hadithno{4756}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuUbaydah ibn al-Jarrah: I heard the Prophet (ﷺ) say: There has been no Prophet after Noah who has not warned his people about the antichrist (Dajjal), and I warn you of him. The Messenger of Allah (ﷺ) described him to us, saying: Perhaps some who have seen me and heard my words will live till his time. The people asked: Messenger of Allah! what will be the condition of our hearts on that day? Like what we are today? He replied: Or better}}
\hadithdefcmd{abudawud}{4757}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ ‏:‏ قَامَ النَّبِيُّ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، فَذَكَرَ الدَّجَّالَ فَقَالَ ‏:‏ ‏ "‏ إِنِّي لأُنْذِرُكُمُوهُ، وَمَا مِنْ نَبِيٍّ إِلاَّ قَدْ أَنْذَرَهُ قَوْمَهُ، لَقَدْ أَنْذَرَهُ نُوحٌ قَوْمَهُ، وَلَكِنِّي سَأَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ ‏:‏ إِنَّهُ أَعْوَرُ وَإِنَّ اللَّهَ لَيْسَ بِأَعْوَرَ ‏"‏ ‏.‏\hadithno{4757}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3055) Sahih Muslim (2930)}\hadithtrans{Ibn Umar reported:The Messenger of Allah (May peace be upon him) stood among the people and praised Allah in a way which is worthy of him, and mentioned the Antichrist (Dajjal), saying : I warn you of him, and there has been no prophet who has not warned his people about him, and Noah also warned his people about him. But I tell you about him a word which no Prophet had told his people : you should know that he will be blind in one eye, and Allah is not blind is one eye}}
\hadithdefcmd{abudawud}{4758}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، وَأَبُو بَكْرِ بْنُ عَيَّاشٍ وَمَنْدَلٌ عَنْ مُطَرِّفٍ، عَنْ أَبِي جَهْمٍ، عَنْ خَالِدِ بْنِ وَهْبَانَ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ مَنْ فَارَقَ الْجَمَاعَةَ شِبْرًا فَقَدْ خَلَعَ رِبْقَةَ الإِسْلاَمِ مِنْ عُنُقِهِ ‏"‏ ‏.‏\hadithno{4758}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuDharr: The Prophet (ﷺ) said: He who separates from the community within a span takes off the noose of Islam from his neck}}
\hadithdefcmd{abudawud}{4759}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُطَرِّفُ بْنُ طَرِيفٍ، عَنْ أَبِي الْجَهْمِ، عَنْ خَالِدِ بْنِ وَهْبَانَ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ كَيْفَ أَنْتُمْ وَأَئِمَّةٌ مِنْ بَعْدِي يَسْتَأْثِرُونَ بِهَذَا الْفَىْءِ ‏"‏ ‏.‏ قُلْتُ ‏:‏ إِذًا وَالَّذِي بَعَثَكَ بِالْحَقِّ أَضَعُ سَيْفِي عَلَى عَاتِقِي، ثُمَّ أَضْرِبُ بِهِ حَتَّى أَلْقَاكَ أَوْ أَلْحَقَكَ ‏.‏ قَالَ ‏:‏ ‏"‏ أَوَلاَ أَدُلُّكَ عَلَى خَيْرٍ مِنْ ذَلِكَ تَصْبِرُ حَتَّى تَلْقَانِي ‏"‏ ‏.‏\hadithno{4759}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Dharr reported the Messenger of Allah (May peace be upon him) as saying :How will you deal with the rulers (imams) who appropriate to themselves this booty? I said : I swear by him who sent you with the truth that at that time I shall put my sword on my shoulder and smite with it till I meet you, or I join you. He said: shall I not guide you to something better than that? You must show endurance till you meet me}}
\hadithdefcmd{abudawud}{4760}{حَدَّثَنَا مُسَدَّدٌ، وَسُلَيْمَانُ بْنُ دَاوُدَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ الْمُعَلَّى بْنِ زِيَادٍ، وَهِشَامِ بْنِ حَسَّانَ، عَنِ الْحَسَنِ، عَنْ ضَبَّةَ بْنِ مِحْصَنٍ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ سَتَكُونُ عَلَيْكُمْ أَئِمَّةٌ تَعْرِفُونَ مِنْهُمْ وَتُنْكِرُونَ فَمَنْ أَنْكَرَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ هِشَامٌ ‏:‏ ‏"‏ بِلِسَانِهِ فَقَدْ بَرِئَ، وَمَنْ كَرِهَ بِقَلْبِهِ فَقَدْ سَلِمَ وَلَكِنْ مَنْ رَضِيَ وَتَابَعَ ‏"‏ ‏.‏ فَقِيلَ ‏:‏ يَا رَسُولَ اللَّهِ أَفَلاَ نَقْتُلُهُمْ قَالَ ابْنُ دَاوُدَ ‏:‏ ‏"‏ أَفَلاَ نُقَاتِلُهُمْ ‏"‏ ‏.‏ قَالَ ‏:‏ ‏"‏ لاَ مَا صَلَّوْا ‏"‏ ‏.‏\hadithno{4760}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1854)}\hadithtrans{Umm Salamah, wife of the Prophet (May peace be upon him) is reported to have said:The Messenger of Allah (May peace be upon him) said: You will have commanders some of whom you will approve and some of whom you will disapprove. He who expresses disapproval with his tongue (Abu Dawud said : This is Hisham’s version) is guiltless; and he who feels disapproval in his heart, is safe, but he who is pleased and follows them. He was asked; shall we not kill them, Messenger of Allah? Abu Dawud’s version has : Shall we not fight with them? He replied : No, so long as they pray}}
\hadithdefcmd{abudawud}{4761}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، قَالَ حَدَّثَنَا الْحَسَنُ، عَنْ ضَبَّةَ بْنِ مِحْصَنٍ الْعَنَزِيِّ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ ‏:‏ ‏ "‏ فَمَنْ كَرِهَ فَقَدْ بَرِئَ، وَمَنْ أَنْكَرَ فَقَدْ سَلِمَ ‏"‏ ‏.‏ قَالَ قَتَادَةُ ‏:‏ يَعْنِي مَنْ أَنْكَرَ بِقَلْبِهِ، وَمَنْ كَرِهَ بِقَلْبِهِ ‏.‏\hadithno{4761}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Umm Salamah through a different chain of narrators to the same effect. This version has :He who disapproves is guiltless, and he who disapproves is safe. Qatadah said : it means one who feels its disapproval in his heart, and one who expresses disapproval in his heart}}
\hadithdefcmd{abudawud}{4762}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ زِيَادِ بْنِ عَلاَقَةَ، عَنْ عَرْفَجَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏ "‏ سَتَكُونُ فِي أُمَّتِي هَنَاتٌ وَهَنَاتٌ وَهَنَاتٌ، فَمَنْ أَرَادَ أَنْ يُفَرِّقَ أَمْرَ الْمُسْلِمِينَ وَهُمْ جَمِيعٌ فَاضْرِبُوهُ بِالسَّيْفِ كَائِنًا مَنْ كَانَ ‏"‏ ‏.‏\hadithno{4762}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1852)}\hadithtrans{‘Arfajah told that he heard the Messenger of Allah (May peace be upon him) as saying :various corruptions will arise in my community, so strike with sword the one who tries to cause separation in the matter of Muslims when they are united, whoever he be}}
\hadithdefcmd{abudawud}{4763}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، وَمُحَمَّدُ بْنُ عِيسَى، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، ‏:‏ أَنَّ عَلِيًّا، ذَكَرَ أَهْلَ النَّهْرَوَانِ فَقَالَ ‏:‏ فِيهِمْ رَجُلٌ مُودَنُ الْيَدِ أَوْ مُخْدَجُ الْيَدِ، أَوْ مَثْدُونُ الْيَدِ لَوْلاَ أَنْ تَبْطَرُوا لَنَبَّأْتُكُمْ مَا وَعَدَ اللَّهُ الَّذِينَ يَقْتُلُونَهُمْ عَلَى لِسَانِ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏ قَالَ قُلْتُ ‏:‏ أَنْتَ سَمِعْتَ هَذَا مِنْهُ قَالَ ‏:‏ إِي وَرَبِّ الْكَعْبَةِ ‏.‏\hadithno{4763}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1066)}\hadithtrans{‘Ubaidah (al-salman) said :‘Ali mentioned about the people of al Nahrawan, saying: Among them there will be a man with a defective hand or with a small hand. if you were not to overjoy. I would inform you of what Allah has promised (the reward for) those who will kill them at the tongue of Muhammad (May peace be upon him). I asked : Have you heard this from him? He replied : Yes, by the lord of the Ka’bah}}
\hadithdefcmd{abudawud}{4764}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ ‏:‏ بَعَثَ عَلِيٌّ عَلَيْهِ السَّلاَمُ إِلَى النَّبِيِّ صلى الله عليه وسلم بِذُهَيْبَةٍ فِي تُرْبَتِهَا، فَقَسَّمَهَا بَيْنَ أَرْبَعَةٍ بَيْنَ ‏:‏ الأَقْرَعِ بْنِ حَابِسٍ الْحَنْظَلِيِّ ثُمَّ الْمُجَاشِعِيِّ، وَبَيْنَ عُيَيْنَةَ بْنِ بَدْرٍ الْفَزَارِيِّ وَبَيْنَ زَيْدِ الْخَيْلِ الطَّائِيِّ ثُمَّ أَحَدِ بَنِي نَبْهَانَ وَبَيْنَ عَلْقَمَةَ بْنِ عُلاَثَةَ الْعَامِرِيِّ ثُمَّ أَحَدِ بَنِي كِلاَبٍ قَالَ فَغَضِبَتْ قُرَيْشٌ وَالأَنْصَارُ وَقَالَتْ ‏:‏ يُعْطِي صَنَادِيدَ أَهْلِ نَجْدٍ وَيَدَعُنَا ‏.‏ فَقَالَ ‏:‏ ‏"‏ إِنَّمَا أَتَأَلَّفُهُمْ ‏"‏ ‏.‏ قَالَ ‏:‏ فَأَقْبَلَ رَجُلٌ غَائِرُ الْعَيْنَيْنِ مُشْرِفُ الْوَجْنَتَيْنِ نَاتِئُ الْجَبِينِ كَثُّ اللِّحْيَةِ مَحْلُوقٌ قَالَ ‏:‏ اتَّقِ اللَّهَ يَا مُحَمَّدُ ‏.‏ فَقَالَ ‏:‏ ‏"‏ مَنْ يُطِعِ اللَّهَ إِذَا عَصَيْتُهُ أَيَأْمَنُنِي اللَّهُ عَلَى أَهْلِ الأَرْضِ وَلاَ تَأْمَنُونِي ‏"‏ ‏.‏ قَالَ ‏:‏ فَسَأَلَ رَجُلٌ قَتْلَهُ أَحْسِبُهُ خَالِدَ بْنَ الْوَلِيدِ - قَالَ - فَمَنَعَهُ ‏.‏ قَالَ ‏:‏ فَلَمَّا وَلَّى قَالَ ‏:‏ ‏"‏ إِنَّ مِنْ ضِئْضِئِ هَذَا أَوْ فِي عَقِبِ هَذَا قَوْمًا يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَنَاجِرَهُمْ يَمْرُقُونَ مِنَ الإِسْلاَمِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ، يَقْتُلُونَ أَهْلَ الإِسْلاَمِ وَيَدَعُونَ أَهْلَ الأَوْثَانِ لَئِنْ أَنَا أَدْرَكْتُهُمْ قَتَلْتُهُمْ قَتْلَ عَادٍ ‏"‏ ‏.‏\hadithno{4764}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3344) Sahih Muslim (1064)}\hadithtrans{Abu sa’id al-khudri said :‘Ali sent some gold-mixed dust to the prophet (May peace be upon him). He divided it among the four : al-Aqra b. Habis al-Hanzall and then al-Mujashi, uyainah b. Badr al-fazari, zaid al-khail al-Ta’l, next to one of Banu nabhan, and ‘Alqamah b. ‘Ulathat al-Amiri (in general), next to one of Banu kulaib. The Quraish and the ansar became angry and said : He is giving to the chiefs of the people of Najd and leaving us. He said : I am giving them for reconciliation of their hearts. Then a man with deep-seated eyes, high cheek-bones, a projecting brow, a thick beard and a shaven head came forward and said: For Allah, Muhammad! He said : Who will obey Allah if I disobey Him? Allah entrusts me with power over the inhabitants of the earth, but you do not. A man asked to be allowed to kill him and I think he was Khalid b. al-Walid but he prevented him. Then when the man turned away, he said: From this one’s stock there will be people who recite the Quran, but it will not pass down their throats. They will sever from Islam and leave the worshippers of Idols alone; but if I live up to their time I shall certainly kill them as 'Ad were killed}}
\hadithdefcmd{abudawud}{4765}{حَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ الأَنْطَاكِيُّ، حَدَّثَنَا الْوَلِيدُ، وَمُبَشِّرٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ الْحَلَبِيَّ عَنْ أَبِي عَمْرٍو، قَالَ - يَعْنِي الْوَلِيدَ - حَدَّثَنَا أَبُو عَمْرٍو، قَالَ حَدَّثَنِي قَتَادَةُ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَأَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ سَيَكُونُ فِي أُمَّتِي اخْتِلاَفٌ وَفُرْقَةٌ، قَوْمٌ يُحْسِنُونَ الْقِيلَ وَيُسِيئُونَ الْفِعْلَ وَيَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ، يَمْرُقُونَ مِنَ الدِّينِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ لاَ يَرْجِعُونَ حَتَّى يَرْتَدَّ عَلَى فُوقِهِ هُمْ شَرُّ الْخَلْقِ وَالْخَلِيقَةِ طُوبَى لِمَنْ قَتَلَهُمْ وَقَتَلُوهُ، يَدْعُونَ إِلَى كِتَابِ اللَّهِ وَلَيْسُوا مِنْهُ فِي شَىْءٍ، مَنْ قَاتَلَهُمْ كَانَ أَوْلَى بِاللَّهِ مِنْهُمْ ‏"‏ ‏.‏ قَالُوا ‏:‏ يَا رَسُولَ اللَّهِ مَا سِيمَاهُمْ قَالَ ‏:‏ ‏"‏ التَّحْلِيقُ ‏"‏ ‏.‏\hadithno{4765}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri ; Anas ibn Malik: The Prophet (ﷺ) said: Soon there will appear disagreement and dissension in my people; there will be people who will be good in speech and bad in work. They recite the Qur'an, but it does not pass their collar-bones. They will swerve from the religion as an animal goes through the animal shot at. They will not return to it till the arrow comes back to its notch. They are worst of the people and animals. Happy is the one who kills them and they kill him. They call to the book of Allah, but they have nothing to do with it. He who fights against them will be nearer to Allah than them (the rest of the people). The people asked: What is their sign? He replied: They shave the head}}
\hadithdefcmd{abudawud}{4766}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَحْوَهُ قَالَ ‏:‏ ‏ "‏ سِيمَاهُمُ التَّحْلِيقُ وَالتَّسْبِيدُ، فَإِذَا رَأَيْتُمُوهُمْ فَأَنِيمُوهُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ التَّسْبِيدُ اسْتِئْصَالُ الشَّعْرِ ‏.‏\hadithno{4766}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Anas through a different chain of narrators in a similar manner. This version adds; Their sign is shaving the head and eliminating the hair. If you see them, kill them. Abu Dawud said:Tasmid means uprooting the hair}}
\hadithdefcmd{abudawud}{4767}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا الأَعْمَشُ، عَنْ خَيْثَمَةَ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ قَالَ عَلِيٌّ ‏:‏ إِذَا حَدَّثْتُكُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا فَلأَنْ أَخِرَّ مِنَ السَّمَاءِ أَحَبُّ إِلَىَّ مِنْ أَنْ أَكْذِبَ عَلَيْهِ وَإِذَا حَدَّثْتُكُمْ فِيمَا بَيْنِي وَبَيْنَكُمْ فَإِنَّمَا الْحَرْبُ خُدْعَةٌ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏ "‏ يَأْتِي فِي آخِرِ الزَّمَانِ قَوْمٌ حُدَثَاءُ الأَسْنَانِ سُفَهَاءُ الأَحْلاَمِ، يَقُولُونَ مِنْ قَوْلِ خَيْرِ الْبَرِيَّةِ يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، لاَ يُجَاوِزُ إِيمَانُهُمْ حَنَاجِرَهُمْ، فَأَيْنَمَا لَقِيتُمُوهُمْ فَاقْتُلُوهُمْ، فَإِنَّ قَتْلَهُمْ أَجْرٌ لِمَنْ قَتَلَهُمْ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4767}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3611) Sahih Muslim (1066)}\hadithtrans{‘Ali said:When I mention a tradition to you from the Messenger of Allah (May peace be upon him), it is dearer to me that I fall from the heaven than I lie on him. But when I talk to you about matters between me and you, then war is a deception. I heard the Messenger of Allah (May peace be upon him) say: Towards the end of the time there will be people who are young in age and from Islam as an arrow goes through the animal aimed at, and their faith will not pass their throats. Wherever you meet them kill them, for their killing will bring a reward for him who kills them on the day of Resurrection}}
\hadithdefcmd{abudawud}{4768}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ أَخْبَرَنِي زَيْدُ بْنُ وَهْبٍ الْجُهَنِيُّ، ‏:‏ أَنَّهُ كَانَ فِي الْجَيْشِ الَّذِينَ كَانُوا مَعَ عَلِيٍّ عَلَيْهِ السَّلاَمُ الَّذِينَ سَارُوا إِلَى الْخَوَارِجِ فَقَالَ عَلِيٌّ عَلَيْهِ السَّلاَمُ ‏:‏ أَيُّهَا النَّاسُ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏ "‏ يَخْرُجُ قَوْمٌ مِنْ أُمَّتِي يَقْرَءُونَ الْقُرْآنَ لَيْسَتْ قِرَاءَتُكُمْ إِلَى قِرَاءَتِهِمْ شَيْئًا وَلاَ صَلاَتُكُمْ إِلَى صَلاَتِهِمْ شَيْئًا وَلاَ صِيَامُكُمْ إِلَى صِيَامِهِمْ شَيْئًا، يَقْرَءُونَ الْقُرْآنَ يَحْسَبُونَ أَنَّهُ لَهُمْ وَهُوَ عَلَيْهِمْ، لاَ تُجَاوِزُ صَلاَتُهُمْ تَرَاقِيَهُمْ يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، لَوْ يَعْلَمُ الْجَيْشُ الَّذِينَ يُصِيبُونَهُمْ مَا قُضِيَ لَهُمْ عَلَى لِسَانِ نَبِيِّهِمْ صلى الله عليه وسلم لَنَكَلُوا عَلَى الْعَمَلِ، وَآيَةُ ذَلِكَ أَنَّ فِيهِمْ رَجُلاً لَهُ عَضُدٌ وَلَيْسَتْ لَهُ ذِرَاعٌ، عَلَى عَضُدِهِ مِثْلُ حَلَمَةِ الثَّدْىِ عَلَيْهِ شَعَرَاتٌ بِيضٌ ‏"‏ ‏.‏ أَفَتَذْهَبُونَ إِلَى مُعَاوِيَةَ وَأَهْلِ الشَّامِ وَتَتْرُكُونَ هَؤُلاَءِ يَخْلُفُونَكُمْ فِي ذَرَارِيِّكُمْ وَأَمْوَالِكُمْ وَاللَّهِ إِنِّي لأَرْجُو أَنْ يَكُونُوا هَؤُلاَءِ الْقَوْمَ، فَإِنَّهُمْ قَدْ سَفَكُوا الدَّمَ الْحَرَامَ، وَأَغَارُوا فِي سَرْحِ النَّاسِ فَسِيرُوا عَلَى اسْمِ اللَّهِ ‏.‏ قَالَ ‏:‏ سَلَمَةُ بْنُ كُهَيْلٍ ‏:‏ فَنَزَّلَنِي زَيْدُ بْنُ وَهْبٍ مَنْزِلاً مَنْزِلاً حَتَّى مَرَّ بِنَا عَلَى قَنْطَرَةٍ قَالَ فَلَمَّا الْتَقَيْنَا وَعَلَى الْخَوَارِجِ عَبْدُ اللَّهِ بْنُ وَهْبٍ الرَّاسِبِيُّ فَقَالَ لَهُمْ ‏:‏ أَلْقُوا الرِّمَاحَ وَسُلُّوا السُّيُوفَ مِنْ جُفُونِهَا، فَإِنِّي أَخَافُ أَنْ يُنَاشِدُوكُمْ كَمَا نَاشَدُوكُمْ يَوْمَ حَرُورَاءَ قَالَ ‏:‏ فَوَحَّشُوا بِرِمَاحِهِمْ وَاسْتَلُّوا السُّيُوفَ وَشَجَرَهُمُ النَّاسُ بِرِمَاحِهِمْ - قَالَ - وَقَتَلُوا بَعْضَهُمْ عَلَى بَعْضِهِمْ ‏.‏ قَالَ ‏:‏ وَمَا أُصِيبَ مِنَ النَّاسِ يَوْمَئِذٍ إِلاَّ رَجُلاَنِ فَقَالَ عَلِيٌّ عَلَيْهِ السَّلاَمُ ‏:‏ الْتَمِسُوا فِيهِمُ الْمُخْدَجَ فَلَمْ يَجِدُوا قَالَ ‏:‏ فَقَامَ عَلِيٌّ رضى الله عنه بِنَفْسِهِ حَتَّى أَتَى نَاسًا قَدْ قُتِلَ بَعْضُهُمْ عَلَى بَعْضٍ فَقَالَ ‏:‏ أَخْرِجُوهُمْ فَوَجَدُوهُ مِمَّا يَلِي الأَرْضَ فَكَبَّرَ وَقَالَ ‏:‏ صَدَقَ اللَّهُ وَبَلَّغَ رَسُولُهُ ‏.‏ فَقَامَ إِلَيْهِ عَبِيدَةُ السَّلْمَانِيُّ فَقَالَ ‏:‏ يَا أَمِيرَ الْمُؤْمِنِينَ وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ لَقَدْ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏:‏ إِي وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ حَتَّى اسْتَحْلَفَهُ ثَلاَثًا وَهُوَ يَحْلِفُ ‏.‏\hadithno{4768}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1066)}\hadithtrans{Salamah b. Kuhail said:Zaid b. Wahb al-Juhani told us that he was in the army which proceeded to (fight with) the Khawarij in the company of `Ali. `Ali then said: O people! I heard the Messenger of Allah (ﷺ) say: there will appear from among my community people who recite the Qur'an, and your recitation has no comparison with their recitation, and your prayer has no comparison with their prayer, and your fasts have no comparison with their fasts. They will recite the Qur'an thinking that it is beneficial for them, while it is harmful for them. Their prayer will not pass their collar-bones. They will swerve from Islam as an arrow goes through the animal shot at. If the army that is approaching them knows what (reward) has been decided for them at the tongue of their Prophet (ﷺ), they would leave (other good) activities. The sign of that is that among them there will be a man who has an upper arm, but not hand; on his upper arm there will be something like the nipple of a female breast, having white hair thereon. Will you go to Mu`awiyah and the people of Syria, and leave them behind among your children and property? I swear by Allah, I hope these are the same people, for they shed the blood unlawfully, and attacked the cattle of the people so go on in the name of Allah. Salamah b. Kuhail said: Zaid b. Wahb then informed me of all the halting places one by one, (saying): Until we passed a bridge. When we fought with each other, `Abd Allah b. Wahb al-Rasibi, who was the leader of the Khawarij, said to them: Throw away the lances and pull out the swords from their sheaths, for I am afraid they will adjure you as they had adjured on the day of Harura. So they threw away their lances and pulled out their swords, and the people pierced them with their lances. They were killed (lying one on the other). On that day only two persons of the partisans (of `Ali) were afflicted. `Ali said: Search for the man with the crippled hand. But they could not find him. Then `Ali got up himself and went to the people who had been killed and were lying on one another. He said: Take them out. They found him just near the ground. So he shouted: Allah is Most Great! He said: Allah spoke the truth, and His Apostle has conveyed. `Ubaidat al-Salmani stood up to him, saying: Commander of the Faithful! Have you heard it from the Messenger of Allah (ﷺ)? He said: Yes, by him, there is no God but He. He put to swear thrice and he swore}}
\hadithdefcmd{abudawud}{4769}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ جَمِيلِ بْنِ مُرَّةَ، قَالَ حَدَّثَنَا أَبُو الْوَضِيءِ، قَالَ قَالَ عَلِيٌّ عَلَيْهِ السَّلاَمُ ‏:‏ اطْلُبُوا الْمُخْدَجَ ‏.‏ فَذَكَرَ الْحَدِيثَ فَاسْتَخْرَجُوهُ مِنْ تَحْتِ الْقَتْلَى فِي طِينٍ، قَالَ أَبُو الْوَضِيءِ ‏:‏ فَكَأَنِّي أَنْظُرُ إِلَيْهِ حَبَشِيٌّ عَلَيْهِ قُرَيْطَقٌ لَهُ إِحْدَى يَدَيْنِ مِثْلُ ثَدْىِ الْمَرْأَةِ عَلَيْهَا شُعَيْرَاتٌ مِثْلُ شُعَيْرَاتِ الَّتِي تَكُونُ عَلَى ذَنَبِ الْيَرْبُوعِ ‏.‏\hadithno{4769}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Ali said:Search for the man with crippled hand. He then mentioned the rest of the tradition. This version has: They took him out from beneath the slain in the dust. Abu al-wadi said: As if I am looking at an Abyssinian with a shirt on him. He had one of his hands like the nipple of the female breast, having hair on it like the hair on the tail of the jerboa}}
\hadithdefcmd{abudawud}{4770}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، عَنْ نُعَيْمِ بْنِ حَكِيمٍ، عَنْ أَبِي مَرْيَمَ، قَالَ ‏:‏ إِنْ كَانَ ذَلِكَ الْمُخْدَجَ لَمَعَنَا يَوْمَئِذٍ فِي الْمَسْجِدِ نُجَالِسُهُ بِاللَّيْلِ وَالنَّهَارِ، وَكَانَ فَقِيرًا وَرَأَيْتُهُ مَعَ الْمَسَاكِينِ يَشْهَدُ طَعَامَ عَلِيٍّ عَلَيْهِ السَّلاَمُ مَعَ النَّاسِ وَقَدْ كَسَوْتُهُ بُرْنُسًا لِي ‏.‏ قَالَ أَبُو مَرْيَمَ ‏:‏ وَكَانَ الْمُخْدَجُ يُسَمَّى نَافِعًا ذَا الثُّدَيَّةِ، وَكَانَ فِي يَدِهِ مِثْلُ ثَدْىِ الْمَرْأَةِ عَلَى رَأْسِهِ حَلَمَةٌ مِثْلُ حَلَمَةِ الثَّدْىِ عَلَيْهِ شُعَيْرَاتٌ مِثْلُ سِبَالَةِ السِّنَّوْرِ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ وَهُوَ عِنْدَ النَّاسِ اسْمُهُ حَرْقُوسُ ‏.‏\hadithno{4770}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Maryam said:This man with the crippled hand was on that day with us in the mosque. We would sit with him by day and by night, and he was a poor man. I saw him attending the meals of ‘Ali (ra) which he took with the people, and I clothed him with a cloak of mine. Abu Maryam said: The man with the crippled hand was called Nafi` Dhu al-Thadyah (Nafi`, man of nipple). He had in his hand something like a female breast with a nipple at it ends like the nipple of the female breast. If had some hair on it like the whiskers of cat. Abu Dawud said: He was known among the people by the name of Harqus}}
\hadithdefcmd{abudawud}{4771}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ حَسَنٍ، قَالَ حَدَّثَنِي عَمِّي، إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ طَلْحَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ مَنْ أُرِيدَ مَالُهُ بِغَيْرِ حَقٍّ فَقَاتَلَ فَقُتِلَ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4771}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: If the property of anyone is designed to be taken away without any right and he fights and is killed, he is a martyr}}
\hadithdefcmd{abudawud}{4772}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، وَسُلَيْمَانُ بْنُ دَاوُدَ، - يَعْنِي أَبَا أَيُّوبَ الْهَاشِمِيَّ - عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي عُبَيْدَةَ بْنِ مُحَمَّدِ بْنِ عَمَّارِ بْنِ يَاسِرٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ، وَمَنْ قُتِلَ دُونَ أَهْلِهِ أَوْ دُونَ دَمِهِ أَوْ دُونَ دِينِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4772}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Sa'id ibn Zayd: The Prophet (ﷺ) said: He who is killed while protecting his property is a martyr, and he who is killed while defending his family, or his blood, or his religion is a martyr}}
