% Auto-generated chapter 25 for ibnmajah
% Hadiths in this chapter: 238

\hadithdefcmd{ibnmajah}{2882}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَأَبُو مُصْعَبٍ الزُّهْرِيُّ وَسُوَيْدُ بْنُ سَعِيدٍ قَالُوا حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ السَّفَرُ قِطْعَةٌ مِنَ الْعَذَابِ يَمْنَعُ أَحَدَكُمْ نَوْمَهُ وَطَعَامَهُ وَشَرَابَهُ فَإِذَا قَضَى أَحَدُكُمْ نَهْمَتَهُ مِنْ سَفَرِهِ فَلْيُعَجِّلِ الرُّجُوعَ إِلَى أَهْلِهِ ‏"‏ ‏.‏ حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{2882}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Traveling is a kind of torment, it keeps anyone of you from his sleep, food and drink. When anyone of you has fulfilled the purpose for which he travled, let him hasten to return to his family.” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{2883}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ أَبُو إِسْرَائِيلَ، عَنْ فُضَيْلِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ، - أَوْ أَحَدِهِمَا عَنِ الآخَرِ، - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَرَادَ الْحَجَّ فَلْيَتَعَجَّلْ فَإِنَّهُ قَدْ يَمْرَضُ الْمَرِيضُ وَتَضِلُّ الضَّالَّةُ وَتَعْرِضُ الْحَاجَةُ ‏"‏ ‏.‏\hadithno{2883}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that Fadl said – or vice verse:“The Messenger of Allah (ﷺ) said: ‘Whoever intends to perform Hajj, let him hasten to do so, for he may fall sick, lose his mount, or be faced with some need.’”}}
\hadithdefcmd{ibnmajah}{2884}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا مَنْصُورُ بْنُ وَرْدَانَ، حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ الأَعْلَى، عَنْ أَبِيهِ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ عَلِيٍّ، قَالَ لَمَّا نَزَلَتْ ‏\{‏وَلِلَّهِ عَلَى النَّاسِ حِجُّ الْبَيْتِ مَنِ اسْتَطَاعَ إِلَيْهِ سَبِيلاً‏\}‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ الْحَجُّ فِي كُلِّ عَامٍ فَسَكَتَ ثُمَّ قَالُوا أَفِي كُلِّ عَامٍ فَقَالَ ‏"‏ لاَ وَلَوْ قُلْتُ نَعَمْ لَوَجَبَتْ ‏"‏ ‏.‏ فَنَزَلَتْ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَسْأَلُوا عَنْ أَشْيَاءَ إِنْ تُبْدَ لَكُمْ تَسُؤْكُمْ ‏\}‏‏.‏\hadithno{2884}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“When the following was revealed: “And Hajj (pilgrimage to Makkah) to the House (Ka’bah) is a duty that mankind owes to Allah, for whoever can bear the way.” [3:97] They asked: ‘O Messenger of Allah, is Hajj every year?’ He remained silent. They asked: ‘Is it every year?’ He said: ‘No. If I had said yes, it would have become obligatory.’ Then the following was revealed: “O you who believe! Ask not about things which, if made plain to you, may cause you trouble.’” [5:]}}
\hadithdefcmd{ibnmajah}{2885}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُبَيْدَةَ، عَنْ أَبِيهِ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ الْحَجُّ فِي كُلِّ عَامٍ قَالَ ‏ "‏ لَوْ قُلْتُ نَعَمْ لَوَجَبَتْ وَلَوْ وَجَبَتْ لَمْ تَقُومُوا بِهَا وَلَوْ لَمْ تَقُومُوا بِهَا عُذِّبْتُمْ ‏"‏ ‏.‏\hadithno{2885}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“They said: ‘O Messenger of Allah, is Hajj (required) every year?’ He said: ‘If I were to say yes, it would have become obligatory, and if it were to become obligatory, you would not (be able to) do it, and if you did not do it you would be punished.’”}}
\hadithdefcmd{ibnmajah}{2886}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا سُفْيَانُ بْنُ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سِنَانٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ الأَقْرَعَ بْنَ حَابِسٍ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ الْحَجُّ فِي كُلِّ سَنَةٍ أَوْ مَرَّةً وَاحِدَةً قَالَ ‏ "‏ بَلْ مَرَّةً وَاحِدَةً فَمَنِ اسْتَطَاعَ فَتَطَوُّعٌ ‏"‏ ‏.‏\hadithno{2886}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that Aqra’ bin Habis asked the Prophet (ﷺ):“O Messenger of Allah, is Hajj (required) every year, or just once” He said: “Rather it is just once. And whoever can perform Hajj voluntarily, let him do so.”}}
\hadithdefcmd{ibnmajah}{2887}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرٍ، عَنْ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَابِعُوا بَيْنَ الْحَجِّ وَالْعُمْرَةِ فَإِنَّ الْمُتَابَعَةَ بَيْنَهُمَا تَنْفِي الْفَقْرَ وَالذُّنُوبَ كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{2887}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Umar that the Prophet (ﷺ) said:“Perform Hajj and ‘Umrah, one after the other, for performing them one after the other removes poverty and sin as the bellows removes impurity from iron.” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{2888}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ سُمَىٍّ، - مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ - عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْعُمْرَةُ إِلَى الْعُمْرَةِ كَفَّارَةُ مَا بَيْنَهُمَا وَالْحَجُّ الْمَبْرُورُ لَيْسَ لَهُ جَزَاءٌ إِلاَّ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{2888}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“From one ‘Umrah to another is an expiation for the sins that came in between them, and Hajj Mabrur (an accepted Hajj) brings no less a reward than Paradise.”}}
\hadithdefcmd{ibnmajah}{2889}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ حَجَّ هَذَا الْبَيْتَ فَلَمْ يَرْفُثْ وَلَمْ يَفْسُقْ رَجَعَ كَمَا وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏\hadithno{2889}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever performs Hajj to this House, and does not have sexual relations nor commit any disobedience, will go back like the day his mother bore him.”}}
\hadithdefcmd{ibnmajah}{2890}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الرَّبِيعِ بْنِ صَبِيحٍ، عَنْ يَزِيدَ بْنِ أَبَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ حَجَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَلَى رَحْلٍ رَثٍّ وَقَطِيفَةٍ تُسَاوِي أَرْبَعَةَ دَرَاهِمَ أَوْ لاَ تُسَاوِي ثُمَّ قَالَ ‏ "‏ اللَّهُمَّ حِجَّةٌ لاَ رِيَاءَ فِيهَا وَلاَ سُمْعَةَ ‏"‏ ‏.‏\hadithno{2890}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Prophet (ﷺ) performed Hajj on an old saddle, wearing a cloak that was worth four Dirham or less. Then he said: ‘O Allah, a Hajj in which there is no showing off nor reputation sought.’”}}
\hadithdefcmd{ibnmajah}{2891}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بَيْنَ مَكَّةَ وَالْمَدِينَةِ فَمَرَرْنَا بِوَادٍ فَقَالَ ‏"‏ أَىُّ وَادٍ هَذَا ‏"‏ ‏.‏ قَالُوا وَادِي الأَزْرَقِ ‏.‏ قَالَ ‏"‏ كَأَنِّي أَنْظُرُ إِلَى مُوسَى ـ صلى الله عليه وسلم ـ - فَذَكَرَ مِنْ طُولِ شَعَرِهِ شَيْئًا لاَ يَحْفَظُهُ دَاوُدُ - وَاضِعًا إِصْبَعَيْهِ فِي أُذُنَيْهِ لَهُ جُؤَارٌ إِلَى اللَّهِ بِالتَّلْبِيَةِ مَارًّا بِهَذَا الْوَادِي ‏"‏ ‏.‏ قَالَ ثُمَّ سِرْنَا حَتَّى أَتَيْنَا عَلَى ثَنِيَّةٍ فَقَالَ ‏"‏ أَىُّ ثَنِيَّةٍ هَذِهِ ‏"‏ ‏.‏ قَالُوا ثَنِيَّةُ هَرْشَى أَوْ لَفْتٍ ‏.‏ قَالَ ‏"‏ كَأَنِّي أَنْظُرُ إِلَى يُونُسَ عَلَى نَاقَةٍ حَمْرَاءَ عَلَيْهِ جُبَّةُ صُوفٍ وَخِطَامُ نَاقَتِهِ خُلْبَةٌ مَارًّا بِهَذَا الْوَادِي مُلَبِّيًا ‏"‏ ‏.‏\hadithno{2891}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“We were with the Messenger of Allah (ﷺ) between Makkah and Al-Madinah, and we passed through a valley. He said: ‘What valley is this?’ They said: ‘Azraq Valley.’ He said: ‘It is as if I can see Musa (as) – and he mentioned something about the length of his hair, which Dawud (one of the narrators) did not remember – ‘putting his fingers in his ears and raising his voice to Allah reciting the Talbiyah, passing through this valley.’ Then we traveled on until we came to a narrow pass, and he said: ‘What pass is this?’ They said: ‘Thaniyyat Harsha’ or ‘Laft.’ He said: ‘It is as if I can see Yunus, on a red she-camel, wearing a woollen cloak and holding the reins of his she-camel, woven from palm fibres, passing through this valley, reciting the Talbiyah.’”}}
\hadithdefcmd{ibnmajah}{2892}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ بْنِ صَالِحٍ، - مَوْلَى بَنِي عَامِرٍ - حَدَّثَنِي يَعْقُوبُ بْنُ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ الْحُجَّاجُ وَالْعُمَّارُ وَفْدُ اللَّهِ إِنْ دَعَوْهُ أَجَابَهُمْ وَإِنِ اسْتَغْفَرُوهُ غَفَرَ لَهُمْ ‏"‏ ‏.‏\hadithno{2892}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The pilgrims performing Hajj and ‘Umrah are a delegation to Allah. If they call upon Him, He will answer them; and if they ask for His forgiveness, He will forgive them.”}}
\hadithdefcmd{ibnmajah}{2893}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا عِمْرَانُ بْنُ عُيَيْنَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْغَازِي فِي سَبِيلِ اللَّهِ وَالْحَاجُّ وَالْمُعْتَمِرُ وَفْدُ اللَّهِ دَعَاهُمْ فَأَجَابُوهُ وَسَأَلُوهُ فَأَعْطَاهُمْ ‏"‏ ‏.‏\hadithno{2893}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) said:“The one who fights in the cause of Allah, and the pilgrim performing Hajj and ‘Umrah are a delegation to Allah. He invited them, so they responded to Him, and they ask Him and He gives to them.”}}
\hadithdefcmd{ibnmajah}{2894}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، أَنَّهُ اسْتَأْذَنَ النَّبِيَّ ـ صلى الله عليه وسلم ـ فِي الْعُمْرَةِ فَأَذِنَ لَهُ وَقَالَ ‏ "‏ يَا أُخَىَّ أَشْرِكْنَا فِي شَىْءٍ مِنْ دُعَائِكَ وَلاَ تَنْسَنَا ‏"‏ ‏.‏\hadithno{2894}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar (from ‘Umar) that he asked the Prophet (ﷺ) for permission to perform ‘Umrah, and he gave him permission and said to him:“O younger brother, give us a share of your supplication, and do not forget us.”}}
\hadithdefcmd{ibnmajah}{2895}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ صَفْوَانَ بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، قَالَ وَكَانَتْ تَحْتَهُ ابْنَةُ أَبِي الدَّرْدَاءِ فَأَتَاهَا فَوَجَدَ أُمَّ الدَّرْدَاءِ وَلَمْ يَجِدْ أَبَا الدَّرْدَاءِ فَقَالَتْ لَهُ تُرِيدُ الْحَجَّ الْعَامَ قَالَ نَعَمْ ‏.‏ قَالَتْ فَادْعُ اللَّهَ لَنَا بِخَيْرٍ فَإِنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ ‏ "‏ دَعْوَةُ الْمَرْءِ مُسْتَجَابَةٌ لأَخِيهِ بِظَهْرِ الْغَيْبِ عِنْدَ رَأْسِهِ مَلَكٌ يُؤَمِّنُ عَلَى دُعَائِهِ كُلَّمَا دَعَا لَهُ بِخَيْرٍ قَالَ آمِينَ وَلَكَ بِمِثْلِهِ ‏"‏ ‏.‏ قَالَ ثُمَّ خَرَجْتُ إِلَى السُّوقِ فَلَقِيتُ أَبَا الدَّرْدَاءِ فَحَدَّثَنِي عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِمِثْلِ ذَلِكَ ‏.‏\hadithno{2895}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Safwan bin ‘Abdullah bin Safwan said that he was married to a daughter of Abu Darda’. He came to her and found Umm Darda’ there, but he did not find Abu Darda’. She said to him:“Do you intend to perform Hajj this year?” He said: “Yes.” She said: “Pray to Allah for us to grant us goodness, for the Prophet (ﷺ) used to say: ‘The supplication of a man for his brother in his absence will be answered. By his head there is an angel who says Amin to his supplication, and every time he prays for his brother, he says: “Amin, and the same for you.’” He said: “Then I went out to the marketplace where I met Abu Darda’, and he told me something similar from the Prophet (ﷺ).”}}
\hadithdefcmd{ibnmajah}{2896}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَزِيدَ الْمَكِّيُّ، عَنْ مُحَمَّدِ بْنِ عَبَّادِ بْنِ جَعْفَرٍ الْمَخْزُومِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ قَامَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ مَا يُوجِبُ الْحَجَّ قَالَ ‏"‏ الزَّادُ وَالرَّاحِلَةُ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ فَمَا الْحَاجُّ قَالَ ‏"‏ الشَّعِثُ التَّفِلُ ‏"‏ ‏.‏ وَقَامَ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ وَمَا الْحَجُّ قَالَ ‏"‏ الْعَجُّ وَالثَّجُّ ‏"‏ ‏.‏ قَالَ وَكِيعٌ يَعْنِي بِالْعَجِّ الْعَجِيجَ بِالتَّلْبِيَةِ وَالثَّجُّ نَحْرُ الْبُدْنِ ‏.‏\hadithno{2896}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“A man stood up and said to the Prophet (ﷺ): ‘O Messenger of Allah! What makes Hajj obligatory?’ He said: ‘Provision and a mount.’ He said: ‘O Messenger of Allah, what is the (real) Hajj?’ He said: ‘The one with dishevelled hair and no perfume.’ Another (man) stood up and said: ‘O Messenger of Allah, what is the (real) Hajj?’ He said: ‘Raising one’s voice and slaughtering the sacrificial animal.’”}}
\hadithdefcmd{ibnmajah}{2897}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا هِشَامُ بْنُ سُلَيْمَانَ الْقُرَشِيُّ، عَنِ ابْنِ جُرَيْجٍ، قَالَ وَأَخْبَرَنِيهِ أَيْضًا، عَنِ ابْنِ عَطَاءٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ الزَّادُ وَالرَّاحِلَةُ ‏"‏ ‏.‏ يَعْنِي قَوْلَهُ ‏\{‏ مَنِ اسْتَطَاعَ إِلَيْهِ سَبِيلاً ‏\}‏ ‏.‏\hadithno{2897}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Provision and a mount,” meaning, about Allah’s saying: “Whoever can bear the way.” [3:]}}
\hadithdefcmd{ibnmajah}{2898}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُسَافِرُ الْمَرْأَةُ سَفَرَ ثَلاَثَةِ أَيَّامٍ فَصَاعِدًا إِلاَّ مَعَ أَبِيهَا أَوْ أَخِيهَا أَوِ ابْنِهَا أَوْ زَوْجِهَا أَوْ ذِي مَحْرَمٍ ‏"‏ ‏.‏\hadithno{2898}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“No woman should travel the distance of three days or more, unless she is with her father, brother, son, husband or a Mahram.”}}
\hadithdefcmd{ibnmajah}{2899}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُسَافِرَ مَسِيرَةَ يَوْمٍ وَاحِدٍ لَيْسَ لَهَا ذُو حُرْمَةٍ ‏"‏ ‏.‏\hadithno{2899}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“It is not permissible for a woman who believes in Allah and the Last Day to travel for more than one day’s distance without a Mahram.”}}
\hadithdefcmd{ibnmajah}{2900}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ أَبَا مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ إِنِّي اكْتُتِبْتُ فِي غَزْوَةِ كَذَا وَكَذَا وَامْرَأَتِي حَاجَّةٌ ‏.‏ قَالَ ‏ "‏ فَارْجِعْ مَعَهَا ‏"‏ ‏.‏\hadithno{2900}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A Bedouin came to the Prophet (ﷺ) and said: ‘I have enlisted for such and such a military campaign and my wife is going for Hajj.’ He said: ‘Go back with her.’”}}
\hadithdefcmd{ibnmajah}{2901}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حَبِيبِ بْنِ أَبِي عَمْرَةَ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ عَلَى النِّسَاءِ جِهَادٌ قَالَ ‏ "‏ نَعَمْ عَلَيْهِنَّ جِهَادٌ لاَ قِتَالَ فِيهِ الْحَجُّ وَالْعُمْرَةُ ‏"‏ ‏.‏\hadithno{2901}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that ‘Aishah said:“I said: ‘O Messenger of Allah, is Jihad obligatory for women?’ He said: “Yes: Upon them is a Jihad in which there is no fighting: Al-Hajj and Al-‘Umrah.”}}
\hadithdefcmd{ibnmajah}{2902}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنِ الْقَاسِمِ بْنِ الْفَضْلِ الْحُدَّانِيِّ، عَنْ أَبِي جَعْفَرٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْحَجُّ جِهَادُ كُلِّ ضَعِيفٍ ‏"‏ ‏.‏\hadithno{2902}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Umm Salamah that the Messenger of Allah (ﷺ) said:“Hajj is the Jihad of every weak person.”}}
\hadithdefcmd{ibnmajah}{2903}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سَمِعَ رَجُلاً يَقُولُ لَبَّيْكَ عَنْ شُبْرُمَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ شُبْرُمَةُ ‏"‏ ‏.‏ قَالَ قَرِيبٌ لِي ‏.‏ قَالَ ‏"‏ هَلْ حَجَجْتَ قَطُّ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَاجْعَلْ هَذِهِ عَنْ نَفْسِكَ ثُمَّ احْجُجْ عَنْ شُبْرُمَةَ ‏"‏ ‏.‏\hadithno{2903}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) heard a man saying:“Labbaik ‘an Shubrumah (Here I am (O Allah) on behalf of Shubrumah.” The Messenger of Allah (ﷺ) said: “Who is Shubrumah?” He said: “A relative of mine.” He said: “Have you ever performed Hajj?” He said: “No.” He said: “Then make this for yourself, then perform Hajj on behalf of Shubrumah.”}}
\hadithdefcmd{ibnmajah}{2904}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ سُلَيْمَانَ الشَّيْبَانِيِّ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ أَحُجُّ عَنْ أَبِي قَالَ ‏ "‏ نَعَمْ حُجَّ عَنْ أَبِيكَ فَإِنْ لَمْ تَزِدْهُ خَيْرًا لَمْ تَزِدْهُ شَرًّا ‏"‏ ‏.‏\hadithno{2904}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A man came to the Prophet (ﷺ) and said: ‘Shall I perform Hajj on behalf of my father?’ He said: ‘Yes, perform Hajj on behalf of your father, for if you cannot add any good to his record (at least) you will not add anything bad.’”}}
\hadithdefcmd{ibnmajah}{2905}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عُثْمَانُ بْنُ عَطَاءٍ، عَنْ أَبِيهِ، عَنْ أَبِي الْغَوْثِ بْنِ حُصَيْنٍ، - رَجُلٌ مِنَ الْفُرْعِ - أَنَّهُ اسْتَفْتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ عَنْ حِجَّةٍ كَانَتْ عَلَى أَبِيهِ مَاتَ وَلَمْ يَحُجَّ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ حُجَّ عَنْ أَبِيكَ ‏"‏ ‏.‏ وَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ وَكَذَلِكَ الصِّيَامُ فِي النَّذْرِ يُقْضَى عَنْهُ ‏"‏ ‏.‏\hadithno{2905}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Ghawth bin Husain – a man from Furu’ – that he consulted the Prophet (ﷺ) about a Hajj that his father owed, but he had died and had not gone for Hajj. The Prophet (ﷺ) said:“Perform Hajj on behalf of your father.” And the Prophet (ﷺ) said: “The same applies to fasting in fulfillment of a vow – it should be made up for.”}}
\hadithdefcmd{ibnmajah}{2906}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ أَبِي رَزِينٍ الْعُقَيْلِيِّ، أَنَّهُ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبِي شَيْخٌ كَبِيرٌ لاَ يَسْتَطِيعُ الْحَجَّ وَلاَ الْعُمْرَةَ وَلاَ الظَّعَنَ ‏.‏ قَالَ ‏ "‏ حُجَّ عَنْ أَبِيكَ وَاعْتَمِرْ ‏"‏ ‏.‏\hadithno{2906}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Razin Al-‘Uqaili that he came to the Prophet (ﷺ) and said:“O Messenger of Allah, my father is an old man and he cannot perform Hajj or ‘Umrah, and he is not able to ride the mount (due to old age).” He said: “Perform Hajj and ‘Umrah on behalf of your father.”}}
\hadithdefcmd{ibnmajah}{2907}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ الدَّرَاوَرْدِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ الْمَخْزُومِيِّ، عَنْ حَكِيمِ بْنِ حَكِيمِ بْنِ عَبَّادِ بْنِ حُنَيْفٍ الأَنْصَارِيِّ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، مِنْ خَثْعَمٍ جَاءَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبِي شَيْخٌ كَبِيرٌ قَدْ أَفْنَدَ وَأَدْرَكَتْهُ فَرِيضَةُ اللَّهِ عَلَى عِبَادِهِ فِي الْحَجِّ وَلاَ يَسْتَطِيعُ أَدَاءَهَا فَهَلْ يُجْزِئُ عَنْهُ أَنْ أُؤَدِّيَهَا عَنْهُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{2907}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Fouad Abd al-Baqi: Hasan Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Abbas that a woman from Khath’am came to the Prophet (ﷺ) and said:“O Messenger of Allah, my father is an old man who has become weak, and now the command of Allah has come for His slaves to perform Hajj, but he cannot do it. Will it discharge his duty if I perform it on his behalf?” The Messenger of Allah (ﷺ) said: “Yes.”}}
\hadithdefcmd{ibnmajah}{2908}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، حَدَّثَنَا مُحَمَّدُ بْنُ كُرَيْبٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَخْبَرَنِي حُصَيْنُ بْنُ عَوْفٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبِي أَدْرَكَهُ الْحَجُّ وَلاَ يَسْتَطِيعُ أَنْ يَحُجَّ إِلاَّ مُعْتَرِضًا ‏.‏ فَصَمَتَ سَاعَةً ثُمَّ قَالَ ‏ "‏ حُجَّ عَنْ أَبِيكَ ‏"‏ ‏.‏\hadithno{2908}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:Husain bin ‘Awf told me: I said: “O Messenger of Allah, the command for Hajj has come but my father cannot perform Hajj unless he is tied to a saddle.” Some time passed, then he said: “Perform Hajj on behalf of your father.”}}
\hadithdefcmd{ibnmajah}{2909}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَخِيهِ الْفَضْلِ، أَنَّهُ كَانَ رِدْفَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ غَدَاةَ النَّحْرِ فَأَتَتْهُ امْرَأَةٌ مِنْ خَثْعَمٍ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ فِي الْحَجِّ عَلَى عِبَادِهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَطِيعُ أَنْ يَرْكَبَ أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ فَإِنَّهُ لَوْ كَانَ عَلَى أَبِيكِ دَيْنٌ قَضَيْتِيهِ ‏"‏ ‏.‏\hadithno{2909}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Abbas that his brother Fadl was riding behind the Messenger of Allah (ﷺ) in the morning of sacrifice (i.e., the 10th of Dhul-Hijjah), when a woman from Khath’am came and said:“O Messenger of Allah, the command of Allah has come for His slaves to perform Hajj, but my father is an old man and cannot ride. May I perform Hajj on his behalf?” He said: “Yes, because if your father owed a debt you would pay it off.”}}
\hadithdefcmd{ibnmajah}{2910}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ طَرِيفٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنِي مُحَمَّدُ بْنُ سُوقَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ رَفَعَتِ امْرَأَةٌ صَبِيًّا لَهَا إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي حَجَّتِهِ فَقَالَتْ يَا رَسُولَ اللَّهِ أَلِهَذَا حَجٌّ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{2910}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“A woman held up a child of hers to the Prophet (ﷺ) during Hajj and said: ‘O Messenger of Allah, is there Hajj for this one?’ He said: ‘Yes, and you will be rewarded.’”}}
\hadithdefcmd{ibnmajah}{2911}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ نُفِسَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ بِالشَّجَرَةِ فَأَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَبَا بَكْرٍ أَنْ يَأْمُرَهَا أَنْ تَغْتَسِلَ وَتُهِلَّ ‏.‏\hadithno{2911}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“Asma’ bint ‘Umais gave birth at Shajarah, and the Messenger of Allah (ﷺ) told Abu Bakr to tell her to take a bath and begin the Talbiyah.”}}
\hadithdefcmd{ibnmajah}{2912}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، أَنَّهُ سَمِعَ الْقَاسِمَ بْنَ مُحَمَّدٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ أَبِي بَكْرٍ، أَنَّهُ خَرَجَ حَاجًّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَمَعَهُ أَسْمَاءُ بِنْتُ عُمَيْسٍ فَوَلَدَتْ بِالشَّجَرَةِ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَتَى أَبُو بَكْرٍ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَخْبَرَهُ فَأَمَرَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَأْمُرَهَا أَنْ تَغْتَسِلَ ثُمَّ تُهِلَّ بِالْحَجِّ وَتَصْنَعَ مَا يَصْنَعُ النَّاسُ إِلاَّ أَنَّهَا لاَ تَطُوفُ بِالْبَيْتِ ‏.‏\hadithno{2912}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Bakr that he went out for Hajj with the Messenger of Allah (ﷺ), and Asma’ bint ‘Umais was with him. She gave birth, at Shajarah, to Muhammad bin Abu Bakr. Abu Bakr came to the Prophet (ﷺ) and told him about that, and the Messenger of Allah (ﷺ) told him to tell her to take a bath, then begin the Talbiyah for Hajj, and to do everything that the people did, apart from circumambulating the House (Tawaf)}}
\hadithdefcmd{ibnmajah}{2913}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ نُفِسَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ بِمُحَمَّدِ بْنِ أَبِي بَكْرٍ فَأَرْسَلَتْ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَمَرَهَا أَنْ تَغْتَسِلَ وَتَسْتَثْفِرَ بِثَوْبٍ وَتُهِلَّ ‏.‏\hadithno{2913}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“Asma’ bint ‘Umais gave birth to Muhammad bin Abi Bakr and sent word to the Prophet (ﷺ). He told her to take a bath, fasten a cloth around her private part and begin the Talbiyah.”}}
\hadithdefcmd{ibnmajah}{2914}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَأَهْلُ الشَّامِ مِنَ الْجُحْفَةِ وَأَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏ ‏.‏ فَقَالَ عَبْدُ اللَّهِ أَمَّا هَذِهِ الثَّلاَثَةُ فَقَدْ سَمِعْتُهَا مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَبَلَغَنِي أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏\hadithno{2914}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“The people of Al-Madinah should begin the Talbiyah from Dhul- Hulaifah, the people of Sham from Juhfah, and the people of Najd from Qarn.” ‘Abdullah said: “As for these three, I heard them from the Messenger of Allah (ﷺ). And it reached me that the Messenger of Allah (ﷺ) said: ‘And the people of Yemen should enter Ihram from Yalamlam.’”}}
\hadithdefcmd{ibnmajah}{2915}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَزِيدَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ مُهَلُّ أَهْلِ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَمُهَلُّ أَهْلِ الشَّامِ مِنَ الْجُحْفَةِ وَمُهَلُّ أَهْلِ الْيَمَنِ مِنْ يَلَمْلَمَ وَمُهَلُّ أَهْلِ نَجْدٍ مِنْ قَرْنٍ وَمُهَلُّ أَهْلِ الْمَشْرِقِ مِنْ ذَاتِ عِرْقٍ ‏"‏ ‏.‏ ثُمَّ أَقْبَلَ بِوَجْهِهِ لِلأُفُقِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ أَقْبِلْ بِقُلُوبِهِمْ ‏"‏ ‏.‏\hadithno{2915}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) addressed us and said: ‘The Talbiyah of the people of Al-Madinah begins at Dhul-Hulaifah. The Talbiyah of the people of Sham begins at Juhfah. The Talbiyah of the people of Yemen begins at Yalamlam. The Talbiyah of the people of Najd begins at Qarn. The Talbiyah of the people of the east begins at Dhat ‘Irq.’ Then he turned to face the (eastern) horizon and said: ‘O Allah, make their hearts steadfast.’”}}
\hadithdefcmd{ibnmajah}{2916}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أَدْخَلَ رِجْلَهُ فِي الْغَرْزِ وَاسْتَوَتْ بِهِ رَاحِلَتُهُ أَهَلَّ مِنْ عِنْدِ مَسْجِدِ ذِي الْحُلَيْفَةِ ‏.‏\hadithno{2916}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Umar that when the Messenger of Allah (ﷺ) put his foot in the stirrup and his riding beast rose up with him, he would say the Talbiyah from the mosque of Dhul-Hulaifah}}
\hadithdefcmd{ibnmajah}{2917}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، وَعُمَرُ بْنُ عَبْدِ الْوَاحِدِ، قَالاَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ إِنِّي عِنْدَ ثَفِنَاتِ نَاقَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عِنْدَ الشَّجَرَةِ فَلَمَّا اسْتَوَتْ بِهِ قَائِمَةً قَالَ ‏ "‏ لَبَّيْكَ بِعُمْرَةٍ وَحَجَّةٍ مَعًا ‏"‏ ‏.‏ وَذَلِكَ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{2917}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“I was by the knees of the she-camel of the Messenger of Allah (ﷺ), at Shajarah. When it rose up with him, he said: ‘Labbaika bi ‘Umrah wa Hajjah ma’an [Here I am (O Allah) for ‘Umrah and Hajj together].’ That was during the Farewell Pilgrimage.”}}
\hadithdefcmd{ibnmajah}{2918}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَأَبُو أُسَامَةَ وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ تَلَقَّفْتُ التَّلْبِيَةَ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ يَقُولُ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ قَالَ وَكَانَ ابْنُ عُمَرَ يَزِيدُ فِيهَا لَبَّيْكَ لَبَّيْكَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ فِي يَدَيْكَ لَبَّيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏.‏\hadithno{2918}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Nafi’, that Ibn ‘Umar said:“I learned the Talbiyah from the Messenger of Allah (ﷺ) who said: Labbaika Allahumma labbaik, labbaika la sharika laka labbaik. Innal-hamda wan- ni’mata laka, wal-mulk. La sharika laka (Here I am, O Allah, here I am. Here I am, You have no partner, here I am. Verily all praise and blessings are Yours, and all sovereignty, You have no partner).” He said: “And Ibn ‘Umar used to add: Labbaika labbaika labbaika wa sa’daika wal-khairu fi yadaika, labbaika war-raghba’u ilaika wal-‘amal (Here I am, here I am, here I am, and at Your service; all good is in Your Hands, here I am, seeking Your pleasure and striving for Your sake).”}}
\hadithdefcmd{ibnmajah}{2919}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ، حَدَّثَنَا مُؤَمَّلُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ كَانَتْ تَلْبِيَةُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏\hadithno{2919}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:“The Talbiyah of the Messenger of Allah (ﷺ) was: ‘Labbaika Allahumma labbaik, (labbaika) la sharika laka labbaik. Innal-hamd wan-ni’mata laka, wal-mulk. La sharika laka (Here I am, O Allah, here I am. Here I am, You have no partner, here I am. Verily all praise and blessings are Yours, and all sovereignty, You have no partner).’”}}
\hadithdefcmd{ibnmajah}{2920}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ فِي تَلْبِيَتِهِ ‏ "‏ لَبَّيْكَ إِلَهَ الْحَقِّ لَبَّيْكَ ‏"‏ ‏.‏\hadithno{2920}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) used to say in his Talbiyah:“Labbaika ilahal-haqq, labbaika (Here I am, O god of Truth, here I am).”}}
\hadithdefcmd{ibnmajah}{2921}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ الأَنْصَارِيُّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا مِنْ مُلَبٍّ يُلَبِّي إِلاَّ لَبَّى مَا عَنْ يَمِينِهِ وَشِمَالِهِ مِنْ حَجَرٍ أَوْ شَجَرٍ أَوْ مَدَرٍ حَتَّى تَنْقَطِعَ الأَرْضُ مِنْ هَا هُنَا وَهَا هُنَا ‏"‏ ‏.‏\hadithno{2921}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sahl bin Sa’d As-Sa’idi that the Messenger of Allah (ﷺ) said:“There is no (pilgrim) who recites the Talbiyah but that which is to his right and left also recites it, rocks and trees and hills, to the farthest ends of the earth in each direction, from here and from there.”}}
\hadithdefcmd{ibnmajah}{2922}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، حَدَّثَهُ عَنْ خَلاَّدِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَتَانِي جِبْرِيلُ فَأَمَرَنِي أَنْ آمُرَ أَصْحَابِي أَنْ يَرْفَعُوا أَصْوَاتَهُمْ بِالإِهْلاَلِ ‏"‏ ‏.‏\hadithno{2922}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Khallad bin Sa’ib, from his father, that the Messenger of Allah (ﷺ) said:“Jibra’il came to me and told me to command my Companions to raise their voices when reciting the Talbiyah.”}}
\hadithdefcmd{ibnmajah}{2923}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي لَبِيدٍ، عَنِ الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ، عَنْ خَلاَّدِ بْنِ السَّائِبِ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ جَاءَنِي جِبْرِيلُ فَقَالَ يَا مُحَمَّدُ مُرْ أَصْحَابَكَ فَلْيَرْفَعُوا أَصْوَاتَهُمْ بِالتَّلْبِيَةِ فَإِنَّهَا مِنْ شِعَارِ الْحَجِّ ‏"‏ ‏.‏\hadithno{2923}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Zaid bin Khalid Al-Juhani that the Messenger of Allah (ﷺ) said:“Jibril came to me and said: ‘O Muhammad! Tell your Companions to raise their voices when reciting the Talbiyah, for it is one of the symbols of Hajj.’”}}
\hadithdefcmd{ibnmajah}{2924}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَرْبُوعٍ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سُئِلَ أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏ "‏ الْعَجُّ وَالثَّجُّ ‏"‏ ‏.‏\hadithno{2924}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Bakr As-Siddiq that the Messenger of Allah (ﷺ) was asked:“Which actions are best?” He said: “Raising one’s voice and slaughtering the sacrificial animal.”}}
\hadithdefcmd{ibnmajah}{2925}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، وَعَبْدُ اللَّهِ بْنُ وَهْبٍ، وَمُحَمَّدُ بْنُ فُلَيْحٍ، قَالُوا حَدَّثَنَا عَاصِمُ بْنُ عُمَرَ بْنِ حَفْصٍ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ مُحْرِمٍ يَضْحَى لِلَّهِ يَوْمَهُ يُلَبِّي حَتَّى تَغِيبَ الشَّمْسُ إِلاَّ غَابَتْ بِذُنُوبِهِ فَعَادَ كَمَا وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏\hadithno{2925}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“There is no Muhrim (pilgrim in Ihram) who exposes himself to the sun all day for the sake of Allah, reciting the Talbiyah until the sun goes down, but his sins will disappear and he will go back like on the day his mother bore him.”}}
\hadithdefcmd{ibnmajah}{2926}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، جَمِيعًا عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ لإِحْرَامِهِ قَبْلَ أَنْ يُحْرِمَ وَلِحِلِّهِ قَبْلَ أَنْ يُفِيضَ - قَالَ سُفْيَانُ - بِيَدَىَّ هَاتَيْنِ ‏.‏\hadithno{2926}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that ‘Aishah said:“I put perfume on the Messenger of Allah (ﷺ) for his Ihram before he entered into it, and when he exited Ihram before he returned.”}}
\hadithdefcmd{ibnmajah}{2927}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ يُلَبِّي ‏.‏\hadithno{2927}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“It is as if I can see the races of perfume in the parting (of hair) of the Messenger of Allah (ﷺ), while he is reciting the Talbiyah.”}}
\hadithdefcmd{ibnmajah}{2928}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَرَى وَبِيصَ الطِّيبِ فِي مَفْرِقِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بَعْدَ ثَلاَثَةٍ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2928}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“It is as if I can see the traces of perfume in the parting (of hair) of the Messenger of Allah (ﷺ) after three days, and he was a Muhrim.”}}
\hadithdefcmd{ibnmajah}{2929}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَلْبَسُ الْقُمُصَ وَلاَ الْعَمَائِمَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ إِلاَّ أَنْ لاَ يَجِدَ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ تَلْبَسُوا مِنَ الثِّيَابِ شَيْئًا مَسَّهُ الزَّعْفَرَانُ أَوِ الْوَرْسُ ‏"‏ ‏.‏\hadithno{2929}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that a man asked the Messenger of Allah (ﷺ), what clothes may the Muhrim wear? The Messenger of Allah (ﷺ) said:“He should not wear a shirt, or turbans (or head cover), pants or pajamas, hooded cloaks and no leather socks, unless he cannot find sandals, in which case he may wear leather socks but should cut them to below the ankles. And he should not wear any clothes that have been touched (dyed) with saffron or Wars.”}}
\hadithdefcmd{ibnmajah}{2930}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَلْبَسَ الْمُحْرِمُ ثَوْبًا مَصْبُوغًا بِوَرْسٍ أَوْ زَعْفَرَانٍ ‏.‏\hadithno{2930}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“The Messenger of Allah (ﷺ) forbade the Muhrim to wear a garment dyed with Wars or saffron.”}}
\hadithdefcmd{ibnmajah}{2931}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَخْطُبُ - قَالَ هِشَامٌ عَلَى الْمِنْبَرِ - فَقَالَ ‏"‏ مَنْ لَمْ يَجِدْ إِزَارًا فَلْيَلْبَسْ سَرَاوِيلَ وَمَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ ‏"‏ ‏.‏ وَقَالَ هِشَامٌ فِي حَدِيثِهِ ‏"‏ فَلْيَلْبَسْ سَرَاوِيلَ إِلاَّ أَنْ يَفْقِدَ ‏"‏ ‏.‏\hadithno{2931}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Abbas said:“I heard the Prophet (ﷺ) delivering a sermon – (one of the narrators) Hisham said: ‘On the pulpit’ – and he said: ‘Whoever does not have a waist wrap, let him wear pants or pajamas, and whoever does not have sandals, let him wear leather socks.’” In his narration, Hisham said: “If he does not find any, then let him wear pants or pajamas.”}}
\hadithdefcmd{ibnmajah}{2932}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، وَعَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{2932}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Whoever does not have sandals let him wear leather socks, and let him cut them to below the ankle.”}}
\hadithdefcmd{ibnmajah}{2933}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَتَّى إِذَا كُنَّا بِالْعَرْجِ نَزَلْنَا فَجَلَسَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَعَائِشَةُ إِلَى جَنْبِهِ وَأَنَا إِلَى جَنْبِ أَبِي بَكْرٍ وَكَانَتْ زِمَالَتُنَا وَزِمَالَةُ أَبِي بَكْرٍ وَاحِدَةً مَعَ غُلاَمِ أَبِي بَكْرٍ قَالَ فَطَلَعَ الْغُلاَمُ وَلَيْسَ مَعَهُ بَعِيرُهُ فَقَالَ لَهُ أَيْنَ بَعِيرُكَ قَالَ أَضْلَلْتُهُ الْبَارِحَةَ ‏.‏ قَالَ مَعَكَ بَعِيرٌ وَاحِدٌ تُضِلُّهُ قَالَ فَطَفِقَ يَضْرِبُهُ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ انْظُرُوا إِلَى هَذَا الْمُحْرِمِ مَا يَصْنَعُ ‏"‏ ‏.‏\hadithno{2933}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Asma’ bint Abu Bakr said:“We went out with the Messenger of Allah (ﷺ) until, when we were in ‘Arj, we stopped to camp. The Messenger of Allah (ﷺ) sat, with ‘Aishah by his side, and I was sitting beside Abu Bakr. Our mount* and the mount of Abu Bakr was one, under the care of the slave of Abu Bakr. The slave looked and his camel was not with him, so he said to him: ‘Where is your camel?’ He said: ‘I lost it yesterday.’ He said: ‘You have one camel with you and you lost it?’ He started to beat him, and the Messenger of Allah (ﷺ) said: ‘Look at what this Muhrim is doing!’”}}
\hadithdefcmd{ibnmajah}{2934}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، اخْتَلَفَا بِالأَبْوَاءِ فَقَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ ‏.‏ وَقَالَ الْمِسْوَرُ بْنُ مَخْرَمَةَ لاَ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ ‏.‏ فَأَرْسَلَنِي ابْنُ عَبَّاسٍ إِلَى أَبِي أَيُّوبَ الأَنْصَارِيِّ أَسْأَلُهُ عَنْ ذَلِكَ، فَوَجَدْتُهُ يَغْتَسِلُ بَيْنَ الْقَرْنَيْنِ وَهُوَ يَسْتَتِرُ بِثَوْبٍ فَسَلَّمْتُ عَلَيْهِ فَقَالَ مَنْ هَذَا قُلْتُ أَنَا عَبْدُ اللَّهِ بْنُ حُنَيْنٍ أَرْسَلَنِي إِلَيْكَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ أَسْأَلُكَ كَيْفَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَغْسِلُ رَأْسَهُ وَهُوَ مُحْرِمٌ قَالَ فَوَضَعَ أَبُو أَيُّوبَ يَدَهُ عَلَى الثَّوْبِ فَطَأْطَأَهُ حَتَّى بَدَا لِي رَأْسُهُ ثُمَّ قَالَ لإِنْسَانٍ يَصُبُّ عَلَيْهِ اصْبُبْ ‏.‏ فَصَبَّ عَلَى رَأْسِهِ ثُمَّ حَرَّكَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ ‏.‏ ثُمَّ قَالَ هَكَذَا رَأَيْتُهُ ـ صلى الله عليه وسلم ـ يَفْعَلُ ‏.‏\hadithno{2934}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibrahim bin ‘Abdullah bin Hunain, from his father, that ‘Abdullah bin ‘Abbas and Miswar bin Makhramah disagreed at Abwa’. Abdullah bin ‘Abbas said that the Muhrim may wash his head, and Miswar said that the Muhrim may not wash his head. Ibn ‘Abbas sent me to Abu Ayyub Al-Ansari to ask him about that, and I found him taking a bath near the well, screened with a piece of cloth. I greeted him with Salam, and he said:“Who is this?” I said: “I am ‘Abdullah bin Hunain. ‘Abdullah bin ‘Abbas sent me to you to ask you how the Messenger of Allah (ﷺ) used to wash his head when he was in Ihram.” He said: “Abu Ayyub put his hand on the cloth and lowered it until his head appeared, then he said to someone who was pouring water for him, Pour water. So he poured water on his head. Then he rubbed his head with his hands, forwards and backwards, and said: ‘This is what I saw him (ﷺ) doing.’”}}
\hadithdefcmd{ibnmajah}{2935}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ "كُنَّا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَنَحْنُ مُحْرِمُونَ فَإِذَا لَقِيَنَا الرَّاكِبُ أَسْدَلْنَا ثِيَابَنَا مِنْ فَوْقِ رُءُوسِنَا فَإِذَا جَاوَزَنَا رَفَعْنَاهَا".‏ حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏\hadithno{2935}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“We were with the Prophet (ﷺ), and we were in Ihram. When a rider met us we would lower our garments from the top of our heads, and when he has gone, we would lift them up again.” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{2936}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ جَدَّتِهِ، - قَالَ لاَ أَدْرِي أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ أَوْ سُعْدَى بِنْتِ عَوْفٍ ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ دَخَلَ عَلَى ضُبَاعَةَ بِنْتِ عَبْدِ الْمُطَّلِبِ فَقَالَ ‏"‏ مَا يَمْنَعُكِ يَا عَمَّتَاهُ مِنَ الْحَجِّ ‏"‏ ‏.‏ فَقَالَتْ أَنَا امْرَأَةٌ سَقِيمَةٌ وَأَنَا أَخَافُ الْحَبْسَ ‏.‏ قَالَ ‏"‏ فَأَحْرِمِي وَاشْتَرِطِي أَنَّ مَحِلَّكِ حَيْثُ حُبِسْتِ ‏"‏ ‏.‏\hadithno{2936}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Bakr bin ‘Abdullah bin Zubair from his grandmother – he (the narrator) said:“I do not know if it was Asma’ bint Abu Bakr or Su’da bint ‘Awf’ – that the Messenger of Allah (ﷺ) entered upon Duba’ah bint ‘Abdul-Muttalib and said: “What is keeping you, O my aunt, from performing Hajj?” She said: “I am a sick woman, and I am afraid of being prevented (from completing Hajj).” He said: ‘Enter Ihram and stipulate the condition that you will exit Ihram from the point where you are prevented.’”}}
\hadithdefcmd{ibnmajah}{2937}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، وَوَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ ضُبَاعَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَنَا شَاكِيَةٌ فَقَالَ ‏"‏ أَمَا تُرِيدِينَ الْحَجَّ الْعَامَ ‏"‏ قُلْتُ إِنِّي لَعَلِيلَةٌ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ حُجِّي وَقُولِي مَحِلِّي حَيْثُ تَحْبِسُنِي ‏"‏ ‏.‏\hadithno{2937}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Duba’ah said:“The Messenger of Allah (ﷺ) entered upon me when I was unwell. He said: ‘Do you intend to perform Hajj this year?’ I said: ‘I am sick, O Messenger of Allah.’ He said: ‘Go for Hajj and say: “I will exit Ihram from the point where I am prevented.’”}}
\hadithdefcmd{ibnmajah}{2938}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ طَاوُسًا، وَعِكْرِمَةَ، يُحَدِّثَانِ عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَتْ ضُبَاعَةُ بِنْتُ الزُّبَيْرِ بْنِ عَبْدِ الْمُطَّلِبِ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ إِنِّي امْرَأَةٌ ثَقِيلَةٌ وَإِنِّي أُرِيدُ الْحَجَّ فَكَيْفَ أُهِلُّ قَالَ ‏ "‏ أَهِلِّي وَاشْتَرِطِي أَنَّ مَحِلِّي حَيْثُ حَبَسْتَنِي ‏"‏ ‏.‏\hadithno{2938}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:Duba’ah bint Zubair bin ‘Abdul- Muttalib came to the Messenger of Allah (ﷺ) and said: “I am a heavy woman and I want to go for Hajj. How should I enter Ihram?” He said: “Enter Ihram and stipulate the condition that you will exit Ihram from the point where you are prevented.”}}
\hadithdefcmd{ibnmajah}{2939}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ صَبِيحٍ، حَدَّثَنَا مُبَارَكُ بْنُ حَسَّانَ أَبُو عَبْدِ اللَّهِ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كَانَتِ الأَنْبِيَاءُ تَدْخُلُ الْحَرَمَ مُشَاةً حُفَاةً وَيَطُوفُونَ بِالْبَيْتِ وَيَقْضُونَ الْمَنَاسِكَ حُفَاةً مُشَاةً ‏.‏\hadithno{2939}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin ‘Abbas said:“The Prophets used to enter the Haram walking barefoot. They would circumambulate the House and complete all the rituals barefoot and walking.”}}
\hadithdefcmd{ibnmajah}{2940}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَدْخُلُ مَكَّةَ مِنَ الثَّنِيَّةِ الْعُلْيَا وَإِذَا خَرَجَ خَرَجَ مِنَ الثَّنِيَّةِ السُّفْلَى ‏.‏\hadithno{2940}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) used to enter Makkah from the upper mountain pass and when he left, he would leave from the lower mountain pass}}
\hadithdefcmd{ibnmajah}{2941}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الْعُمَرِيُّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ دَخَلَ مَكَّةَ نَهَارًا ‏.‏\hadithno{2941}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) entered Makkah by day}}
\hadithdefcmd{ibnmajah}{2942}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَيْنَ تَنْزِلُ غَدًا وَذَلِكَ فِي حَجَّتِهِ قَالَ ‏"‏ وَهَلْ تَرَكَ لَنَا عَقِيلٌ مَنْزِلاً ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ نَحْنُ نَازِلُونَ غَدًا بِخَيْفِ بَنِي كِنَانَةَ - يَعْنِي الْمُحَصَّبَ - حَيْثُ قَاسَمَتْ قُرَيْشٌ عَلَى الْكُفْرِ ‏"‏ ‏.‏ وَذَلِكَ أَنَّ بَنِي كِنَانَةَ حَالَفَتْ قُرَيْشًا عَلَى بَنِي هَاشِمٍ أَنْ لاَ يُنَاكِحُوهُمْ وَلاَ يُبَايِعُوهُمْ ‏.‏ قَالَ مَعْمَرٌ قَالَ الزُّهْرِيُّ وَالْخَيْفُ الْوَادِي ‏.‏\hadithno{2942}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Usamah bin Zaid said:“I said: ‘O Messenger of Allah, where will you stay tomorrow?’ That was during his Hajj. He said: ‘Has ‘Aqil left us any house?’ Then he said: ‘Tomorrow we will stay in the valley of Banu Kinanah, Muhassab where the Quraish swore an oath of disbelief.’” That was where the Banu Kinana had sworn an oath with the Quriash against Banu Hashim, that they would not intermarry with them or engage in trade with them. Ma’mar said: “Zuhri said: Khaif means a valley.’”}}
\hadithdefcmd{ibnmajah}{2943}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ رَأَيْتُ الأُصَيْلِعَ عُمَرَ بْنَ الْخَطَّابِ يُقَبِّلُ الْحَجَرَ وَيَقُولُ إِنِّي لأُقَبِّلُكَ وَإِنِّي لأَعْلَمُ أَنَّكَ حَجَرٌ لاَ تَضُرُّ وَلاَ تَنْفَعُ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُقَبِّلُكَ مَا قَبَّلْتُكَ ‏.‏\hadithno{2943}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Abdullah bin Sarjis said:“I saw the bald forehead of ‘Umar bin Khattab when he kissed the Black Stone and said: ‘I am kissing you, although I know that you are only a stone and you can neither cause harm nor bring benefit. Had I not seen the Messenger of Allah (ﷺ) kissing you, I would not have kissed you.’”}}
\hadithdefcmd{ibnmajah}{2944}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ الرَّازِيُّ، عَنِ ابْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيَأْتِيَنَّ هَذَا الْحَجَرُ يَوْمَ الْقِيَامَةِ وَلَهُ عَيْنَانِ يُبْصِرُ بِهِمَا وَلِسَانٌ يَنْطِقُ بِهِ يَشْهَدُ عَلَى مَنْ يَسْتَلِمُهُ بِحَقٍّ ‏"‏ ‏.‏\hadithno{2944}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Sa’eed bin Jubair said:I heard Ibn ‘Abbas say: The Messenger of Allah (ﷺ) said: “This Stone will be brought on the Day of Resurrection, and it will be given two eyes with which to see, and a tongue with which to speak, and it will bear witness for those who touched it in sincerity.”}}
\hadithdefcmd{ibnmajah}{2945}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا خَالِي، يَعْلَى عَنْ مُحَمَّدِ بْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اسْتَقْبَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْحَجَرَ ثُمَّ وَضَعَ شَفَتَيْهِ عَلَيْهِ يَبْكِي طَوِيلاً ثُمَّ الْتَفَتَ فَإِذَا هُوَ بِعُمَرَ بْنِ الْخَطَّابِ يَبْكِي فَقَالَ ‏ "‏ يَا عُمَرُ هَاهُنَا تُسْكَبُ الْعَبَرَاتُ ‏"‏ ‏.‏\hadithno{2945}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) turned to face the Stone, then he put his lips on it and wept for a long time. Then he turned and saw ‘Umar bin Khattab weeping. He said: ‘O ‘Umar, this is the place where tears should be shed.’”}}
\hadithdefcmd{ibnmajah}{2946}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ لَمْ يَكُنْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَسْتَلِمُ مِنْ أَرْكَانِ الْبَيْتِ إِلاَّ الرُّكْنَ الأَسْوَدَ وَالَّذِي يَلِيهِ مِنْ نَحْوِ دُورِ الْجُمَحِيِّينَ ‏.‏\hadithno{2946}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim bin ‘Abdullah that his father said:“The Messenger of Allah (ﷺ) did not touch the corners of the Ka’bah apart from the Black Corner (i.e., the corner where the Black Stone is) and the one that is next to it facing the houses of Banu Jumah (i.e., the Yemenite Corner).”}}
\hadithdefcmd{ibnmajah}{2947}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، قَالَتْ لَمَّا اطْمَأَنَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَامَ الْفَتْحِ طَافَ عَلَى بَعِيرِهِ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ بِيَدِهِ ثُمَّ دَخَلَ الْكَعْبَةَ فَوَجَدَ فِيهَا حَمَامَةَ عَيْدَانٍ فَكَسَرَهَا ثُمَّ قَامَ عَلَى بَابِ الْكَعْبَةِ فَرَمَى بِهَا وَأَنَا أَنْظُرُهُ ‏.‏\hadithno{2947}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Safiyyah bint Shaibah said:“When the Messenger of Allah (ﷺ) saw that things had settled down, in the year of the Conquest (of Makkah), he performed Tawaf on his camel, touching the corner with a staff in his hand. Then he entered the House and found a dove made of aloeswood. He broke it, then he stood at the door of the Ka’bah and threw it out, and I was watching him.”}}
\hadithdefcmd{ibnmajah}{2948}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ طَافَ فِي حَجَّةِ الْوَدَاعِ عَلَى بَعِيرٍ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ ‏.‏\hadithno{2948}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) performed Tawaf on a camel during the Farewell Pilgrimage, touching the corner with a staff}}
\hadithdefcmd{ibnmajah}{2949}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا هَدِيَّةُ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا مَعْرُوفُ بْنُ خَرَّبُوذَ الْمَكِّيُّ، قَالَ سَمِعْتُ أَبَا الطُّفَيْلِ، عَامِرَ بْنَ وَاثِلَةَ قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَطُوفُ بِالْبَيْتِ عَلَى رَاحِلَتِهِ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنِهِ وَيُقَبِّلُ الْمِحْجَنَ ‏.‏\hadithno{2949}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ma’ruf bin Kharrabudh Al-Makki narrated:“I heard Abu Tufail, ‘Amir bin Wathilah, say: ‘I saw the Prophet (ﷺ) performing Tawaf on his camel, touching the corner with his staff and kissing the staff.’”}}
\hadithdefcmd{ibnmajah}{2950}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَحْمَدُ بْنُ بَشِيرٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا طَافَ بِالْبَيْتِ الطَّوَافَ الأَوَّلَ رَمَلَ ثَلاَثَةً وَمَشَى أَرْبَعَةً مِنَ الْحَجَرِ إِلَى الْحَجَرِ وَكَانَ ابْنُ عُمَرَ يَفْعَلُهُ ‏.‏\hadithno{2950}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari}\hadithtrans{It was narrated from Nafi’, from Ibn ‘Umar that when the Messenger of Allah (ﷺ) performed Tawaf around the House for the first time, he walked briskly with short steps in the first three circuits, and walked normally in the last four, starting and ending at the Hijr.* And Ibn ‘Umar used to do that}}
\hadithdefcmd{ibnmajah}{2951}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو الْحُسَيْنِ الْعُكْلِيُّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَمَلَ مِنَ الْحَجَرِ إِلَى الْحَجَرِ ثَلاَثًا وَمَشَى أَرْبَعًا ‏.‏\hadithno{2951}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) walked briskly (Ramala), from the Hijr to the Hijr, three times, then he walked normally for four}}
\hadithdefcmd{ibnmajah}{2952}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ، يَقُولُ فِيمَ الرَّمَلاَنُ الآنَ وَقَدْ أَطَّأَ اللَّهُ الإِسْلاَمَ وَنَفَى الْكُفْرَ وَأَهْلَهُ وَايْمُ اللَّهِ مَا نَدَعُ شَيْئًا كُنَّا نَفْعَلُهُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{2952}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Zaid bin Aslam that his father said:“I heard ‘Umar say: ‘Why do they perform Ramal now, when Allah has established Islam and done away with disbelief and its people? By Allah,* we will not give up something that we used to do at the time of the Messenger of Allah (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{2953}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ خُثَيْمٍ، عَنْ أَبِي الطُّفَيْلِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لأَصْحَابِهِ حِينَ أَرَادُوا دُخُولَ مَكَّةَ فِي عُمْرَتِهِ بَعْدَ الْحُدَيْبِيَةِ ‏ "‏ إِنَّ قَوْمَكُمْ غَدًا سَيَرَوْنَكُمْ فَلَيَرَوُنَّكُمْ جُلْدًا ‏"‏ ‏.‏ فَلَمَّا دَخَلُوا الْمَسْجِدَ اسْتَلَمُوا الرُّكْنَ وَرَمَلُوا وَالنَّبِيُّ ـ صلى الله عليه وسلم ـ مَعَهُمْ حَتَّى إِذَا بَلَغُوا الرُّكْنَ الْيَمَانِيَّ مَشَوْا إِلَى الرُّكْنِ الأَسْوَدِ ثُمَّ رَمَلُوا حَتَّى بَلَغُوا الرُّكْنَ الْيَمَانِيَّ ثُمَّ مَشَوْا إِلَى الرُّكْنِ الأَسْوَدِ فَفَعَلَ ذَلِكَ ثَلاَثَ مَرَّاتٍ ثُمَّ مَشَى الأَرْبَعَ ‏.‏\hadithno{2953}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“During his ‘Umrah after Hudaibiyah – when they wanted to enter Makkah – the Prophet (ﷺ) said to his Companions: ‘Your people will see you tomorrow, so let them see you looking strong.’ When they entered the mosque, they touched the corner and started to walk briskly, and the Prophet (ﷺ) was with them. When they reached the Yemenite Corner, they walked normally to the Black Corner (the corner where the Black Stone is), then they walked briskly until they reached the Yemenite Corner, then they walked normally to the Black Corner. They did that three times, then they walked normally for four circuits.”}}
\hadithdefcmd{ibnmajah}{2954}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، وَقَبِيصَةُ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَبْدِ الْحَمِيدِ، عَنِ ابْنِ يَعْلَى بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، يَعْلَى أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ طَافَ مُضْطَبِعًا ‏.‏ قَالَ قَبِيصَةُ وَعَلَيْهِ بُرْدٌ ‏.‏\hadithno{2954}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Ya’la bin Umayyah that his father Ya’la said:“The Prophet (ﷺ) performed Tawaf while doing Idtiba’.”* (In his narration, one of the narrators) Qabisah said: “While wearing a Yemenite cloth.”}}
\hadithdefcmd{ibnmajah}{2955}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْحِجْرِ ‏.‏ فَقَالَ ‏"‏ هُوَ مِنَ الْبَيْتِ ‏"‏ ‏.‏ قُلْتُ مَا مَنَعَهُمْ أَنْ يُدْخِلُوهُ فِيهِ قَالَ ‏"‏ عَجَزَتْ بِهِمُ النَّفَقَةُ ‏"‏ ‏.‏ قُلْتُ فَمَا شَأْنُ بَابِهِ مُرْتَفِعًا لاَ يُصْعَدُ إِلَيْهِ إِلاَّ بِسُلَّمٍ قَالَ ‏"‏ ذَلِكَ فِعْلُ قَوْمِكِ لِيُدْخِلُوهُ مَنْ شَاءُوا وَيَمْنَعُوهُ مَنْ شَاءُوا وَلَوْلاَ أَنَّ قَوْمَكِ حَدِيثُ عَهْدٍ بِكُفْرٍ مَخَافَةَ أَنْ تَنْفِرَ قُلُوبُهُمْ لَنَظَرْتُ هَلْ أُغَيِّرُهُ فَأُدْخِلَ فِيهِ مَا انْتَقَصَ مِنْهُ وَجَعَلْتُ بَابَهُ بِالأَرْضِ ‏"‏ ‏.‏\hadithno{2955}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“I asked the Messenger of Allah (ﷺ) about the Hijr, and he said: ‘It is part of the House.’ I said: ‘What kept them from incorporating it into it?’ He said: ‘They ran out of funds.’ I said: ‘Why is its door so high up that it can only be reached with a ladder?’* He said: ‘That is what your people did so that they could let in whoever they wanted and keep out whoever they wanted. Were it not that your people have so recently left disbelief behind, and I am afraid that it would bother them, I would have changed it, incorporating what they left out and I would put its door at ground level.”}}
\hadithdefcmd{ibnmajah}{2956}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنِ الْعَلاَءِ بْنِ الْمُسَيَّبِ، عَنْ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ طَافَ بِالْبَيْتِ وَصَلَّى رَكْعَتَيْنِ كَانَ كَعِتْقِ رَقَبَةٍ ‏"‏ ‏.‏\hadithno{2956}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“I heard the Messenger of Allah (ﷺ) say: ‘Whoever performs Tawaf around the House and prays two Rak’ah, it is as if he freed a slave.’”}}
\hadithdefcmd{ibnmajah}{2957}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا حُمَيْدُ بْنُ أَبِي سَوِيَّةَ، قَالَ سَمِعْتُ ابْنَ هِشَامٍ، يَسْأَلُ عَطَاءَ بْنَ أَبِي رَبَاحٍ عَنِ الرُّكْنِ الْيَمَانِيِّ، وَهُوَ يَطُوفُ بِالْبَيْتِ فَقَالَ عَطَاءٌ حَدَّثَنِي أَبُو هُرَيْرَةَ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ وُكِلَ بِهِ سَبْعُونَ مَلَكًا فَمَنْ قَالَ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْعَفْوَ وَالْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ رَبَّنَا آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنَا عَذَابَ النَّارِ - قَالُوا آمِينَ ‏"‏ ‏.‏ فَلَمَّا بَلَغَ الرُّكْنَ الأَسْوَدَ قَالَ يَا أَبَا مُحَمَّدٍ مَا بَلَغَكَ فِي هَذَا الرُّكْنِ الأَسْوَدِ فَقَالَ عَطَاءٌ حَدَّثَنِي أَبُو هُرَيْرَةَ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ مَنْ فَاوَضَهُ فَإِنَّمَا يُفَاوِضُ يَدَ الرَّحْمَنِ ‏"‏ ‏.‏ قَالَ لَهُ ابْنُ هِشَامٍ يَا أَبَا مُحَمَّدٍ فَالطَّوَافُ قَالَ عَطَاءٌ حَدَّثَنِي أَبُو هُرَيْرَةَ أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ مَنْ طَافَ بِالْبَيْتِ سَبْعًا وَلاَ يَتَكَلَّمُ إِلاَّ بِسُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ وَلاَ حَوْلَ وَلاَقُوَّةَ إِلاَّ بِاللَّهِ مُحِيَتْ عَنْهُ عَشْرُ سِيِّئَاتٍ وَكُتِبَتْ لَهُ عَشْرُ حَسَنَاتٍ وَرُفِعَ لَهُ بِهَا عَشْرُ دَرَجَاتٍ وَمَنْ طَافَ فَتَكَلَّمَ وَهُوَ فِي تِلْكَ الْحَالِ خَاضَ فِي الرَّحْمَةِ بِرِجْلَيْهِ كَخَائِضِ الْمَاءِ بِرِجْلَيْهِ ‏"‏ ‏.‏\hadithno{2957}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Humaid bin Abu Sawiyyah said:I heard Ibn Hisham asking ‘Ata’ bin Abu Rabah about the Yemenite Corner, when he was performing Tawaf around the House. ‘Ata’ said: Abu Hurairah told me that the Prophet (ﷺ) said: “Seventy angels have been appointed over it. Whoever says: Allahumma inni as’alukal-‘afwa wal-‘afiyah fid-dunya wal-akhirah; Rabbana atina fid-dunya hasanah, wa fil-akhirati hasanah, wa qina ‘adhaban-Nar (O Allah, I ask You for pardon and well-being in this world and in the Hereafter. Our Lord, give us good in this world and good in the Hereafter and protect us from the torment of the Fire), they say: Amin.” When he reached the Black Corner (where the Black Stone is), he said: O Abu Muhammad! What have you heard about this Black Corner? ‘Ata’ said: Abu Hurairah told me that he heard the Messenger of Allah (ﷺ) say: “Whoever faces it is facing the Hand of the Most Merciful.’” Ibn Hisham said to him: O Abu Muhammad, what about Tawaf? ‘Ata’ said: Abu Hurairah told me that he heard the Prophet (ﷺ) say: “Whoever performs Tawaf around the House seven times and does not say anything except: Subhan Allah wal-hamdu lillah, wa la ilaha illallah wa Allahu Akbar, wa la hawla wa la quwwata illa billah (Glory is to Allah, praise is to Allah, none has the right to be worshipping but Allah, and there is no power nor strength except with Allah), ten bad deeds will be erased from him, ten merits will be recorded for him, and he will be raised ten degrees in status. Whoever performs Tawaf and talks when he is in that situation, is wading in mercy like one who wades in water.”}}
\hadithdefcmd{ibnmajah}{2958}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ كَثِيرِ بْنِ كَثِيرِ بْنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ السَّهْمِيِّ، عَنْ أَبِيهِ، عَنِ الْمُطَّلِبِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا فَرَغَ مِنْ سَبْعِهِ جَاءَ حَتَّى يُحَاذِيَ بِالرُّكْنِ فَصَلَّى رَكْعَتَيْنِ فى حَاشِيَةِ الْمَطَافِ وَلَيْسَ بَيْنَهُ وَبَيْنَ الطُّوَّافِ أَحَدٌ ‏.‏ قَالَ ابْنُ مَاجَهْ هَذَا بِمَكَّةَ خَاصَّةً ‏.‏\hadithno{2958}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Muttalib said:“When he finished seven (circuits of Tawaf), I saw the Messenger of Allah (ﷺ) come until he was parallel with the Corner, then he prayed two Rak’ah at the edge of the Mataf (area for Tawaf), and there was nothing between him and the people who were performing Tawaf.”}}
\hadithdefcmd{ibnmajah}{2959}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ مُحَمَّدِ بْنِ ثَابِتٍ الْعَبْدِيِّ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَدِمَ فَطَافَ بِالْبَيْتِ سَبْعًا ثُمَّ صَلَّى رَكْعَتَيْنِ - قَالَ وَكِيعٌ يَعْنِي عِنْدَ الْمَقَامِ - ثُمَّ خَرَجَ إِلَى الصَّفَا ‏.‏\hadithno{2959}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) came and performed Tawaf around the House seven times, then he prayed two Rak’ahs. Waki’ said:“Meaning, at the Maqam,* then he went out to Safa.”}}
\hadithdefcmd{ibnmajah}{2960}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ لَمَّا فَرَغَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ طَوَافِ الْبَيْتِ أَتَى مَقَامَ إِبْرَاهِيمَ فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ هَذَا مَقَامُ أَبِينَا إِبْرَاهِيمَ الَّذِي قَالَ اللَّهُ سُبْحَانَهُ ‏\{وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى\}‏ ‏.‏ قَالَ الْوَلِيدُ فَقُلْتُ لِمَالِكٍ هَكَذَا قَرَأَهَا ‏\{وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى\}‏ قَالَ نَعَمْ ‏.‏\hadithno{2960}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:“When Allah’s Messenger (ﷺ) finished circumambulating the House, he came to Maqam Ibrahim. ‘Umar said: ‘O Messenger of Allah, this is the Maqam of our father Ibrahim, about which Allah says, “And take you (people) the Maqam (place) of Ibrahim as a place of prayer.’” [2:]}}
\hadithdefcmd{ibnmajah}{2961}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَأَحْمَدُ بْنُ سِنَانٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ، عَنْ أُمِّ سَلَمَةَ، أَنَّهَا مَرِضَتْ فَأَمَرَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ تَطُوفَ مِنْ وَرَاءِ النَّاسِ وَهِيَ رَاكِبَةٌ ‏.‏ قَالَتْ فَرَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي إِلَى الْبَيْتِ وَهُوَ يَقْرَأُ ‏\{وَالطُّورِ * وَكِتَابٍ مَسْطُورٍ\}‏ ‏.‏ قَالَ ابْنُ مَاجَهْ هَذَا حَدِيثُ أَبِي بَكْرٍ ‏.‏\hadithno{2961}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Salamah that she fell sick, so the Messenger of Allah (ﷺ) told her to perform Tawaf from behind the people, riding. She said:“I saw the Messenger of Allah (ﷺ) praying facing the House, and reciting: “By the Tur (Mount), And by the Book Inscribed.’” [52:]}}
\hadithdefcmd{ibnmajah}{2962}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ سَمِعْتُ الْمُثَنَّى بْنَ الصَّبَّاحِ، يَقُولُ حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ طُفْتُ مَعَ عَبْدِ اللَّهِ بْنِ عَمْرٍو فَلَمَّا فَرَغْنَا مِنَ السَّبْعِ رَكَعْنَا فِي دُبُرِ الْكَعْبَةِ فَقُلْتُ أَلاَ نَتَعَوَّذُ بِاللَّهِ مِنَ النَّارِ ‏.‏ قَالَ أَعُوذُ بِاللَّهِ مِنَ النَّارِ ‏.‏ قَالَ ثُمَّ مَضَى فَاسْتَلَمَ الرُّكْنَ ثُمَّ قَامَ بَيْنَ الْحَجَرِ وَالْبَابِ فَأَلْصَقَ صَدْرَهُ وَيَدَيْهِ وَخَدَّهُ إِلَيْهِ ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَفْعَلُ ‏.‏\hadithno{2962}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Amr bin Shu’aib narrated from his father that his grandfather said:“I performed Tawaf with ‘Abdullah bin ‘Amr, and when we had finished seven (circuits), we prayed two Rak’ah at the back of the Ka’bah. I said: ‘Why do you not seek refuge with Allah from the Fire?’ He said: ‘I seek refuge with Allah from the fire.’ Then he went and touched the Corner, then he stood between the (Black) Stone and the door (of the Ka’bah) and clung with his chest, hands and cheek against it. Then he said: ‘I saw the Messenger of Allah (ﷺ) do this.’”}}
\hadithdefcmd{ibnmajah}{2963}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لاَ نَرَى إِلاَّ الْحَجَّ فَلَمَّا كُنَّا بِسَرِفَ أَوْ قَرِيبًا مِنْ سَرِفَ حِضْتُ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَنَا أَبْكِي فَقَالَ مَالَكِ أَنَفِسْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ إِنَّ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ فَاقْضِي الْمَنَاسِكَ كُلَّهَا غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ ‏"‏ ‏.‏ قَالَتْ وَضَحَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ نِسَائِهِ بِالْبَقَرِ ‏.‏\hadithno{2963}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“We went out with the Messenger of Allah (ﷺ), intending only to perform Hajj. When we were in Sarif or close to Sarif, my menses came. The Messenger of Allah (ﷺ) entered upon me when I was weeping. He said: ‘What is the matter with you? Have your menses come?’ I said: ‘Yes.’ He said: ‘This is something that Allah has decreed for the daughters of Adam. Do all the rites, but do not circumambulate the House.’” She said: “And the Messenger of Allah (ﷺ) sacrificed a cow on behalf of his wives.”}}
\hadithdefcmd{ibnmajah}{2964}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَأَبُو مُصْعَبٍ قَالاَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَفْرَدَ الْحَجَّ ‏.‏\hadithno{2964}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) performed Hajj Ifrad}}
\hadithdefcmd{ibnmajah}{2965}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ - وَكَانَ يَتِيمًا فِي حِجْرِ عُرْوَةَ بْنِ الزُّبَيْرِ - عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَفْرَدَ الْحَجَّ ‏.‏\hadithno{2965}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Aishah the Mother of the Believers that the Messenger of Allah (ﷺ) performed Hajj Ifrad}}
\hadithdefcmd{ibnmajah}{2966}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الدَّرَاوَرْدِيُّ، وَحَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَفْرَدَ الْحَجَّ ‏.‏\hadithno{2966}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) performed Hajj Ifrad (Single Hajj)}}
\hadithdefcmd{ibnmajah}{2967}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْقَاسِمُ بْنُ عَبْدِ اللَّهِ الْعُمَرِيُّ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبَا بَكْرٍ وَعُمَرَ وَعُثْمَانَ أَفْرَدُوا الْحَجَّ ‏.‏\hadithno{2967}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ), Abu Bakr, ‘Umar and ‘Uthman performed Hajj Ifrad (Single Hajj)}}
\hadithdefcmd{ibnmajah}{2968}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى مَكَّةَ فَسَمِعْتُهُ يَقُولُ ‏ "‏ لَبَّيْكَ عُمْرَةً وَحَجَّةً ‏"‏ ‏.‏\hadithno{2968}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“We went out with the Messenger of Allah (ﷺ) to Makkah, and I heard him say: ‘Labbaika ‘Umratan wa hajjatan [Here I am (O Allah), for ‘Umrah and Hajj].’”}}
\hadithdefcmd{ibnmajah}{2969}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَبَّيْكَ بِعُمْرَةٍ وَحَجَّةٍ ‏"‏ ‏.‏\hadithno{2969}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) said:“Labbaika bi-‘Umratin wa hajjatin [Here I am (O Allah), for ‘Umrah and Hajj].”}}
\hadithdefcmd{ibnmajah}{2970}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدَةَ بْنِ أَبِي لُبَابَةَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، شَقِيقَ بْنَ سَلَمَةَ يَقُولُ سَمِعْتُ الصُّبَىَّ بْنَ مَعْبَدٍ، يَقُولُ كُنْتُ رَجُلاً نَصْرَانِيًّا فَأَسْلَمْتُ فَأَهْلَلْتُ بِالْحَجِّ وَالْعُمْرَةِ فَسَمِعَنِي سَلْمَانُ بْنُ رَبِيعَةَ وَزَيْدُ بْنُ صُوحَانَ وَأَنَا أُهِلُّ بِهِمَا جَمِيعًا بِالْقَادِسِيَّةِ فَقَالاَ لَهَذَا أَضَلُّ مِنْ بَعِيرِهِ فَكَأَنَّمَا حَمَلاَ عَلَىَّ جَبَلاً بِكَلِمَتِهِمَا فَقَدِمْتُ عَلَى عُمَرَ بْنِ الْخَطَّابِ فَذَكَرْتُ ذَلِكَ لَهُ فَأَقْبَلَ عَلَيْهِمَا فَلاَمَهُمَا ثُمَّ أَقْبَلَ عَلَىَّ فَقَالَ هُدِيتَ لِسُنَّةِ النَّبِيِّ ـ صلى الله عليه وسلم ـ هُدِيتَ لِسُنَّةِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ هِشَامٌ فِي حَدِيثِهِ قَالَ شَقِيقٌ: فَكَثِيرًا مَا ذَهَبْتُ أَنَا وَمَسْرُوقٌ نَسْأَلُهُ عَنْهُ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ وَخَالِي يَعْلَى قَالُوا حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنِ الصُّبَىِّ بْنِ مَعْبَدٍ، قَالَ كُنْتُ حَدِيثَ عَهْدٍ بِنَصْرَانِيَّةٍ فَأَسْلَمْتُ فَلَمْ آلُ أَنْ أَجْتَهِدَ، فَأَهْلَلْتُ بِالْحَجِّ وَالْعُمْرَةِ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2970}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Abdah bin Abu Lubabah said:“I heard Abu Wa’il, Shaqiq bin Salamah, say: ‘I heard Subai bin Ma’bad say: “I was a Christian man, then I became Muslim and I entered Ihram for Hajj and ‘Umrah. Salman bin Rabi’ah and Zaid bin Suhan heard me when I was entering Ihram for them both together at Qadisiyyah. They said: ‘This man is more lost than his camel!’ It was as if they had heaped a mountain on me with their words. I went to ‘Umar bin Khattab and told him about that. He turned to them and reproached them, then he turned to me and said: ‘You have been guided to the Sunnah of the Prophet (ﷺ), you have been guided to the Sunnah of the Prophet (ﷺ).’” Another chain reports a similar narration}}
\hadithdefcmd{ibnmajah}{2971}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا حَجَّاجٌ، عَنِ الْحَسَنِ بْنِ سَعْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَخْبَرَنِي أَبُو طَلْحَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَرَنَ الْحَجَّ وَالْعُمْرَةَ ‏.‏\hadithno{2971}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Abu Talhah told me that the Messenger of Allah (ﷺ) performed Hajj and ‘Umrah together (Qiran).”}}
\hadithdefcmd{ibnmajah}{2972}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى بْنِ حَارِثٍ الْمُحَارِبِيُّ، حَدَّثَنَا أَبِي، عَنْ غَيْلاَنَ بْنِ جَامِعٍ، عَنْ لَيْثٍ، عَنْ عَطَاءٍ، وَطَاوُسٍ، وَمُجَاهِدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، وَابْنِ، عُمَرَ وَابْنِ عَبَّاسٍ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ لَمْ يَطُفْ هُوَ وَأَصْحَابُهُ لِعُمْرَتِهِمْ وَحَجَّتِهِمْ حِينَ قَدِمُوا إِلاَّ طَوَافًا وَاحِدًا ‏.‏\hadithno{2972}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin ‘Abdullah, Ibn ‘Umar and Ibn ‘Abbas that when the Messenger of Allah (ﷺ) and his Companions came (to Makkah) to perform their Hajj and ‘Umrah, they only performed Tawaf once}}
\hadithdefcmd{ibnmajah}{2973}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْثَرُ بْنُ الْقَاسِمِ، عَنْ أَشْعَثَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ طَافَ لِلْحَجِّ وَالْعُمْرَةِ طَوَافًا وَاحِدًا ‏.‏\hadithno{2973}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) performed one Tawaf for Hajj and ‘Umrah}}
\hadithdefcmd{ibnmajah}{2974}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُسْلِمُ بْنُ خَالِدٍ الزَّنْجِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَدِمَ قَارِنًا فَطَافَ بِالْبَيْتِ سَبْعًا وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ قَالَ هَكَذَا فَعَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{2974}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that he came (to Makkah) to perform Hajj and ‘Umrah together (Qiran). He circumambulated the House seven times, and performed Sa’y between Safa and Marwah, then he said:“This is what the Messenger of Allah (ﷺ) did.”}}
\hadithdefcmd{ibnmajah}{2975}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَحْرَمَ بِالْحَجِّ وَالْعُمْرَةِ كَفَى لَهُمَا طَوَافٌ وَاحِدٌ وَلَمْ يَحِلَّ حَتَّى يَقْضِيَ حَجَّهُ وَيَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{2975}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Whoever enters Ihram for Hajj and ‘Umrah, one Tawaf is sufficient for both, and he should not exit Ihram until he has completed his Hajj, when he should exit Ihram for both.”}}
\hadithdefcmd{ibnmajah}{2976}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، - يَعْنِي دُحَيْمًا - حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالاَ حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي عِكْرِمَةُ، قَالَ حَدَّثَنَا ابْنُ عَبَّاسٍ، قَالَ حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ وَهُوَ بِالْعَقِيقِ ‏ "‏ أَتَانِي آتٍ مِنْ رَبِّي فَقَالَ صَلِّ فِي هَذَا الْوَادِي الْمُبَارَكِ وَقُلْ عُمْرَةٌ فِي حَجَّةٍ ‏"‏ ‏.‏ وَاللَّفْظُ لِدُحَيْمٍ ‏.‏\hadithno{2976}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{‘Umar bin Khattab said:I heard the Messenger of Allah (ﷺ) say, when he was in ‘Aqiq: “Someone came to me from my Lord and said: ‘Pray in this blessed valley and say: (I intend to do) ‘Umrah in Hajj.’”}}
\hadithdefcmd{ibnmajah}{2977}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ عَبْدِ الْمَلِكَ بْنِ مَيْسَرَةَ، عَنْ طَاوُسٍ، عَنْ سُرَاقَةَ بْنِ جُعْشُمٍ، قَالَ قَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ خَطِيبًا فِي هَذَا الْوَادِي فَقَالَ ‏ "‏ أَلاَ إِنَّ الْعُمْرَةَ قَدْ دَخَلَتْ فِي الْحَجِّ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2977}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Suraqah bin Ju’shum said:“The Messenger of Allah (ﷺ) stood up to deliver a speech in this valley, and said: ‘Lo! ‘Umrah has been included in Hajj until the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{2978}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الْعَلاَءِ، يَزِيدَ بْنِ الشِّخِّيرِ عَنْ أَخِيهِ، مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ قَالَ قَالَ لِي عِمْرَانُ بْنُ الْحُصَيْنِ إِنِّي أُحَدِّثُكَ حَدِيثًا لَعَلَّ اللَّهَ أَنْ يَنْفَعَكَ بِهِ بَعْدَ الْيَوْمِ اعْلَمْ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَدْ أَعْمَرَ طَائِفَةً مِنْ أَهْلِهِ فِي الْعَشْرِ مِنْ ذِي الْحِجَّةِ وَلَمْ يَنْهَ عَنْهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَلَمْ يَنْزِلْ نَسْخُهُ قَالَ فِي ذَلِكَ بَعْدُ رَجُلٌ بِرَأْيِهِ مَا شَاءَ أَنْ يَقُولَ ‏.‏\hadithno{2978}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Mutarrif bin ‘Abdullah bin Shikhkhir said:“Imran bin Husain said to me: ‘I will tell you a Hadith, that Allah may benefit you thereby after this day. Know that Allah’s Messenger (ﷺ) had a group from his family perform ‘Umrah during the ten (days) of Dhul-Hijjah, and the Messenger of Allah (ﷺ) did not forbid that, and no abrogation of that was revealed, and it does not matter what anyone else suggests.’”}}
\hadithdefcmd{ibnmajah}{2979}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنِي أَبِي قَالاَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي مُوسَى، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّهُ كَانَ يُفْتِي بِالْمُتْعَةِ فَقَالَ لَهُ رَجُلٌ رُوَيْدَكَ بَعْضَ فُتْيَاكَ فَإِنَّكَ لاَ تَدْرِي مَا أَحْدَثَ أَمِيرُ الْمُؤْمِنِينَ فِي النُّسُكِ بَعْدَكَ ‏.‏ حَتَّى لَقِيتُهُ بَعْدُ فَسَأَلْتُهُ فَقَالَ عُمَرُ قَدْ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَعَلَهُ وَأَصْحَابُهُ وَلَكِنِّي كَرِهْتُ أَنْ يَظَلُّوا بِهِنَّ مُعْرِسِينَ تَحْتَ الأَرَاكِ ثُمَّ يَرُوحُونَ بِالْحَجِّ تَقْطُرُ رُءُوسُهُمْ ‏.‏\hadithno{2979}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibrahim bin Abu Musa:“Abu Musa Al-Ash’ari used to issue rulings concerning Tamattu’. Then a man said to him: ‘Withhold some of your rulings, for you do not know what the Commander of the Believers has introduced into the rites after you.’ (Abu Musa said:) ‘Then when I met him later on, I asked him.’ ‘Umar said: ‘I know that the Messenger of Allah (ﷺ) and his Companions did it, but I did not like that people should lie with their wives in the shade of the Arak trees and then go out for Hajj with their heads dripping,’ (i.e. due to the bath after sexual relations).”}}
\hadithdefcmd{ibnmajah}{2980}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَهْلَلْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِالْحَجِّ خَالِصًا لاَ نَخْلِطُهُ بِعُمْرَةٍ فَقَدِمْنَا مَكَّةَ لأَرْبَعِ لَيَالٍ خَلَوْنَ مِنْ ذِي الْحِجَّةِ فَلَمَّا طُفْنَا بِالْبَيْتِ وَسَعَيْنَا بَيْنَ الصَّفَا وَالْمَرْوَةِ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَجْعَلَهَا عُمْرَةً وَأَنْ نَحِلَّ إِلَى النِّسَاءِ ‏.‏ فَقُلْنَا مَا بَيْنَنَا لَيْسَ بَيْنَنَا وَبَيْنَ عَرَفَةَ إِلاَّ خَمْسٌ فَنَخْرُجُ إِلَيْهَا وَمَذَاكِيرُنَا تَقْطُرُ مَنِيًّا فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنِّي لأَبَرُّكُمْ وَأَصْدَقُكُمْ وَلَوْلاَ الْهَدْىُ لأَحْلَلْتُ ‏"‏ ‏.‏ فَقَالَ سُرَاقَةُ بْنُ مَالِكٍ أَمُتْعَتُنَا هَذِهِ لِعَامِنَا هَذَا أَمْ لأَبَدٍ فَقَالَ ‏"‏ لاَ بَلْ لأَبَدِ الأَبَدِ ‏"‏ ‏.‏\hadithno{2980}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“We began our Talbiyah for Hajj only with Allah’s Messenger (ﷺ), and we did not mix it with ‘Umrah. We arrived in Makkah when four nights of Dhul-Hijjah had passed, and when we had performed Tawaf around the Ka’bah and Sa’y between Safa and Marwah, the Messenger of Allah (ﷺ) commanded us to make it ‘Umrah, and to come out of Ihram and have relations with our wives. We said: ‘There are only five (days) until ‘Arafah. Will we g out to it with our male organs dripping with semen?’ The Messenger of Allah (ﷺ) said: ‘I am the most righteous and truthful among you, and were it not for the sacrificial animal, I would have exited Ihram.’ Suraqah bin Malik said: ‘Is this Tamattu’ for this year only or forever?’ He said: ‘No, it is forever and ever.’”}}
\hadithdefcmd{ibnmajah}{2981}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ لاَ نُرَى إِلاَّ الْحَجَّ حَتَّى إِذَا قَدِمْنَا وَدَنَوْنَا أَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ أَنْ يَحِلَّ فَحَلَّ النَّاسُ كُلُّهُمْ إِلاَّ مَنْ كَانَ مَعَهُ هَدْىٌ فَلَمَّا كَانَ يَوْمُ النَّحْرِ دُخِلَ عَلَيْنَا بِلَحْمِ بَقَرٍ فَقِيلَ ذَبَحَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ أَزْوَاجِهِ ‏.‏\hadithno{2981}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“We went out with the Messenger of Allah (ﷺ) when there were five nights left of Dhul-Qa’dah, intending only to perform Hajj. When we came close, the Messenger of Allah (ﷺ) ordered that whoever did not have a sacrificial animal, then he should exit the Ihram. So all the people exited Ihram, except those who had the sacrificial animal. When the Day of Sacrifice i.e., the 10th of Dhul-Hijjah) came, some beef was brought to us, and it was said: ‘The Messenger of Allah (ﷺ) has offered a sacrifice on behalf of his wives.’”}}
\hadithdefcmd{ibnmajah}{2982}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَصْحَابُهُ فَأَحْرَمْنَا بِالْحَجِّ فَلَمَّا قَدِمْنَا مَكَّةَ قَالَ ‏"‏ اجْعَلُوا حَجَّكُمْ عُمْرَةً ‏"‏ ‏.‏ فَقَالَ النَّاسُ يَا رَسُولَ اللَّهِ قَدْ أَحْرَمْنَا بِالْحَجِّ فَكَيْفَ نَجْعَلُهَا عُمْرَةً قَالَ ‏"‏ انْظُرُوا مَا آمُرُكُمْ بِهِ فَافْعَلُوا ‏"‏ ‏.‏ فَرَدُّوا عَلَيْهِ الْقَوْلَ فَغَضِبَ فَانْطَلَقَ حَتَّى دَخَلَ عَلَى عَائِشَةَ غَضْبَانَ فَرَأَتِ الْغَضَبَ فِي وَجْهِهِ فَقَالَتْ مَنْ أَغْضَبَكَ أَغْضَبَهُ اللَّهُ قَالَ ‏"‏ وَمَالِي لاَ أَغْضَبُ وَأَنَا آمُرُ أَمْرًا فَلاَ أُتْبَعُ ‏"‏ ‏.‏\hadithno{2982}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Bara’ bin ‘Azib said:“The Messenger of Allah (ﷺ) and his Companions came out to us and we entered Ihram for Hajj. When we came to Makkah, he said: ‘Make your Hajj (to) ‘Umrah.’ The people said: ‘O Messenger of Allah, we have entered Ihram for Hajj, how can we make it ‘Umrah?’ He said: ‘Look at what I command you to do, and do it.’ They repeated their question and he got angry and went away. Then he entered upon ‘Aishah angry and she saw anger in his face, and said: ‘Who has made you angry? May Allah vex him!’ He said: ‘Why should I not get angry, when I give a command and it is not obeyed?’”}}
\hadithdefcmd{ibnmajah}{2983}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا أَبُو عَاصِمٍ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مَنْصُورُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، صَفِيَّةَ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مُحْرِمِينَ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُقِمْ عَلَى إِحْرَامِهِ وَمَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ فَلْيَحْلِلْ ‏"‏ ‏.‏ قَالَتْ وَلَمْ يَكُنْ مَعِي هَدْىٌ فَأَحْلَلْتُ وَكَانَ مَعَ الزُّبَيْرِ هَدْىٌ فَلَمْ يَحِلَّ فَلَبِسْتُ ثِيَابِي وَجِئْتُ إِلَى الزُّبَيْرِ فَقَالَ قُومِي عَنِّي ‏.‏ فَقُلْتُ أَتَخْشَى أَنْ أَثِبَ عَلَيْكَ ‏.‏\hadithno{2983}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Asma’ bint Abi Bakr said:“We went out with the Messenger of Allah (ﷺ) in Ihram. The Prophet (ﷺ) said: ‘Whoever has a sacrificial animal with him, let him remain in Ihram. Whoever does not have a sacrificial animal with him, let him exit Ihram.’ She said: ‘I did not have a sacrificial animal with me, so I exited Ihram, but Zubair had a sacrificial animal with him, so he did not exit Ihram. So I put on my regular clothes and came to Zubair, and he said: ‘Go away from me.’ I said: ‘Are you afraid I am going to jump on you?!’”}}
\hadithdefcmd{ibnmajah}{2984}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْحَارِثِ بْنِ بِلاَلِ بْنِ الْحَارِثِ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ فَسْخَ الْحَجِّ فِي الْعُمْرَةِ لَنَا خَاصَّةً أَمْ لِلنَّاسِ عَامَّةً فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ بَلْ لَنَا خَاصَّةً ‏"‏ ‏.‏\hadithno{2984}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Harith bin Bilal bin Harith, that his father said:“I said: ‘O Messenger of Allah, do you think that this cancellation of Hajj and it being replaced with ‘Umrah is only for us, or for all people?’ The Messenger of Allah (ﷺ) said: ‘No, it is only for us.’”}}
\hadithdefcmd{ibnmajah}{2985}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ كَانَتِ الْمُتْعَةُ فِي الْحَجِّ لأَصْحَابِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ خَاصَّةً ‏.‏\hadithno{2985}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Dharr said:“Tamattu’ in Hajj was for the Companions of Muhammad (ﷺ) specifically.”}}
\hadithdefcmd{ibnmajah}{2986}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي قَالَ، قُلْتُ لِعَائِشَةَ مَا أَرَى عَلَىَّ جُنَاحًا أَنْ لاَ أَطَّوَّفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏ قَالَتْ إِنَّ اللَّهَ يَقُولُ ‏\{إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا\}‏ وَلَوْ كَانَ كَمَا تَقُولُ لَكَانَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا ‏.‏ إِنَّمَا أُنْزِلَ هَذَا فِي نَاسٍ مِنَ الأَنْصَارِ كَانُوا إِذَا أَهَلُّوا أَهَلُّوا لِمَنَاةَ فَلاَ يَحِلُّ لَهُمْ أَنْ يَطَّوَّفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ فَلَمَّا قَدِمُوا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي الْحَجِّ ذَكَرُوا ذَلِكَ لَهُ فَأَنْزَلَهَا اللَّهُ فَلَعَمْرِي مَا أَتَمَّ اللَّهُ عَزَّ وَجَلَّ حَجَّ مَنْ لَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏\hadithno{2986}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Hisham bin ‘Urwah said:“My father told me: ‘I said to ‘Aishah: “I do not think there is any sin on me if I do not perform Tawaf* between Safa and Marwah.” She said: “Allah says: ‘Verily, Safa and Marwah are of the Symbols of Allah. So it is not a sin on him who performs Hajj or ‘Umrah of the House to perform Tawaf between them.’” [2:158] If the matter were as you say, then it would have said, ‘it is not a sin on him to not perform the Sa’y between them.’ Rather this was revealed concerning some people among the Ansar who previously, when they stated the Talbiyah, they used to recite it for Manat, and it was not lawful for them to perform Sa’y between Safa and Marwah. When they arrived with the Prophet (ﷺ) for Hajj, they mentioned that to him, and Allah revealed this Verse. By Allah, Allah will not accept the Hajj as complete if one who does not perform Sa’y between Safa and Marwah.’”}}
\hadithdefcmd{ibnmajah}{2987}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ أُمِّ وَلَدِ، شَيْبَةَ قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَسْعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ وَهُوَ يَقُولُ ‏ "‏ لاَ يُقْطَعُ الأَبْطَحُ إِلاَّ شَدًّا ‏"‏ ‏.‏\hadithno{2987}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narratd that an Umm Walad* of Shaibah said:“I saw the Messenger of Allah (ﷺ) performing Sa’y between Safa and Marwah saying: ‘The valley should not be crossed except quickly.’”}}
\hadithdefcmd{ibnmajah}{2988}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبِي، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ كَثِيرِ بْنِ جُمْهَانَ، عَنِ ابْنِ عُمَرَ، قَالَ إِنْ أَسْعَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَسْعَى وَإِنْ أَمْشِ فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَمْشِي وَأَنَا شَيْخٌ كَبِيرٌ ‏.‏\hadithno{2988}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Umar said:“If I go quickly between Safa and Marwah, that is because I saw the Messenger of Allah (ﷺ) going quickly, and if I walk that is because I saw the Messenger of Allah (ﷺ) walking, even though I am an old man.”}}
\hadithdefcmd{ibnmajah}{2989}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْحَسَنُ بْنُ يَحْيَى الْخُشَنِيُّ، حَدَّثَنَا عُمَرُ بْنُ قَيْسٍ، أَخْبَرَنِي طَلْحَةُ بْنُ يَحْيَى، عَنْ عَمِّهِ، إِسْحَاقَ بْنِ طَلْحَةَ عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْحَجُّ جِهَادٌ وَالْعُمْرَةُ تَطَوُّعٌ ‏"‏ ‏.‏\hadithno{2989}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Talhah bin ‘Ubaidullah that he heard the Messenger of Allah (ﷺ) say:“Hajj is Jihad and ‘Umrah is voluntary.”}}
\hadithdefcmd{ibnmajah}{2990}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يَعْلَى، حَدَّثَنَا إِسْمَاعِيلُ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يَقُولُ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حِينَ اعْتَمَرَ فَطَافَ وَطُفْنَا مَعَهُ وَصَلَّى وَصَلَّيْنَا مَعَهُ وَكُنَّا نَسْتُرُهُ مِنْ أَهْلِ مَكَّةَ لاَ يُصِيبُهُ أَحَدٌ بِشَىْءٍ ‏.‏\hadithno{2990}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Isma’il narrated:“I heard ‘Abdullah bin Abu Awfa say: ‘We were with the Messenger of Allah (ﷺ) when he performed ‘Umrah. He performed Tawaf (around the Ka’bah) and we performed Tawaf with him. He prayed and we prayed with him, and we were shielding him from the people of Makkah lest anyone harm him.’”}}
\hadithdefcmd{ibnmajah}{2991}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ بَيَانٍ، وَجَابِرٍ، عَنِ الشَّعْبِيِّ، عَنْ وَهْبِ بْنِ خَنْبَشٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عُمْرَةٌ فِي رَمَضَانَ تَعْدِلُ حِجَّةً ‏"‏ ‏.‏\hadithno{2991}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Wahb bin Khanbash that the Messenger of Allah (ﷺ) said:“ ‘Umrah during Ramadan is equivalent to Hajj (i.e. in reward).”}}
\hadithdefcmd{ibnmajah}{2992}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، جَمِيعًا عَنْ دَاوُدَ بْنِ يَزِيدَ الزَّعَافِرِيِّ، عَنِ الشَّعْبِيِّ، عَنْ هَرِمِ بْنِ خَنْبَشٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عُمْرَةٌ فِي رَمَضَانَ تَعْدِلُ حِجَّةً ‏"‏ ‏.‏\hadithno{2992}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Harim bin Khanbash that the Messenger of Allah (ﷺ) said:‘ ‘Umrah during Ramadan is equivalent to Hajj (i.e., in reward).’”}}
\hadithdefcmd{ibnmajah}{2993}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُثْمَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ أَبِي مَعْقِلٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ عُمْرَةٌ فِي رَمَضَانَ تَعْدِلُ حِجَّةً ‏"‏ ‏.‏\hadithno{2993}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Ma’qil that the Prophet (ﷺ) said:“ ‘Umrah during Ramadan is equivalent to Hajj.”}}
\hadithdefcmd{ibnmajah}{2994}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ حَجَّاجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عُمْرَةٌ فِي رَمَضَانَ تَعْدِلُ حِجَّةً ‏"‏ ‏.‏\hadithno{2994}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Umrah during Ramadan is equivalent to Hajj.”}}
\hadithdefcmd{ibnmajah}{2995}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الْمَلِكِ بْنِ وَاقِدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ عُمْرَةٌ فِي رَمَضَانَ تَعْدِلُ حِجَّةً ‏"‏ ‏.‏\hadithno{2995}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) said:“ ‘Umrah during Ramadan is equivalent to Hajj.”}}
\hadithdefcmd{ibnmajah}{2996}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمْ يَعْتَمِرْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلاَّ فِي ذِي الْقَعْدَةِ ‏.‏\hadithno{2996}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) did not perform any ‘Umrah except in Dhul-Qa’dah.”}}
\hadithdefcmd{ibnmajah}{2997}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ لَمْ يَعْتَمِرْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عُمْرَةً إِلاَّ فِي ذِي الْقَعْدَةِ ‏.‏\hadithno{2997}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) did not perform any ‘Umrah except in Dhul-Qa’dah.”}}
\hadithdefcmd{ibnmajah}{2998}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ حَبِيبٍ، - يَعْنِي ابْنَ أَبِي ثَابِتٍ - عَنْ عُرْوَةَ، قَالَ سُئِلَ ابْنُ عُمَرَ فِي أَىِّ شَهْرٍ اعْتَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ فِي رَجَبٍ ‏.‏ فَقَالَتْ عَائِشَةُ مَا اعْتَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي رَجَبٍ قَطُّ وَمَا اعْتَمَرَ إِلاَّ وَهُوَ مَعَهُ - تَعْنِي ابْنَ عُمَرَ ‏.‏\hadithno{2998}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Urwah said:“Ibn ‘Umar was asked: ‘In which month did the Messenger of Allah (ﷺ) perform ‘Umrah?’ He said: ‘In Rajab.’ But ‘Aishah said: “The Messenger of Allah (ﷺ) never performed ‘Umrah during Rajab, and he never performed ‘Umrah, but he (meaning Ibn ‘Umar) was with him.”}}
\hadithdefcmd{ibnmajah}{2999}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو إِسْحَاقَ الشَّافِعِيُّ إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ الْعَبَّاسِ بْنِ عُثْمَانَ بْنِ شَافِعٍ قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، أَخْبَرَنِي عَمْرُو بْنُ أَوْسٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَمَرَهُ أَنْ يُرْدِفَ عَائِشَةَ فَيُعْمِرَهَا مِنَ التَّنْعِيمِ ‏.‏\hadithno{2999}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{‘Abdur-Rahman bin Abu Bakr narrated that the Prophet (ﷺ) told him to seat ‘Aishah behind him on his riding animal, and perform ‘Umrah with her from Tan’im}}
\hadithdefcmd{ibnmajah}{3000}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي حِجَّةِ الْوَدَاعِ نُوَافِي هِلاَلَ ذِي الْحِجَّةِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ أَرَادَ مِنْكُمْ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهْلِلْ فَلَوْلاَ أَنِّي أَهْدَيْتُ لأَهْلَلْتُ بِعُمْرَةٍ ‏"‏ ‏.‏ قَالَتْ فَكَانَ مِنَ الْقَوْمِ مَنْ أَهَلَّ بِعُمْرَةٍ وَمِنْهُمْ مَنْ أَهَلَّ بِحَجٍّ فَكُنْتُ أَنَا مِمَّنْ أَهَلَّ بِعُمْرَةٍ ‏.‏ قَالَتْ فَخَرَجْنَا حَتَّى قَدِمْنَا مَكَّةَ فَأَدْرَكَنِي يَوْمُ عَرَفَةَ وَأَنَا حَائِضٌ لَمْ أَحِلَّ مِنْ عُمْرَتِي فَشَكَوْتُ ذَلِكَ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ دَعِي عُمْرَتَكِ وَانْقُضِي رَأْسَكِ وَامْتَشِطِي وَأَهِلِّي بِالْحَجِّ ‏"‏ ‏.‏ قَالَتْ فَفَعَلْتُ فَلَمَّا كَانَتْ لَيْلَةُ الْحَصْبَةِ وَقَدْ قَضَى اللَّهُ حَجَّنَا أَرْسَلَ مَعِي عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ فَأَرْدَفَنِي وَخَرَجَ إِلَى التَّنْعِيمِ فَأَهْلَلْتُ بِعُمْرَةٍ فَقَضَى اللَّهُ حَجَّنَا وَعُمْرَتَنَا وَلَمْ يَكُنْ فِي ذَلِكَ هَدْىٌ وَلاَ صَدَقَةٌ وَلاَ صَوْمٌ ‏.‏\hadithno{3000}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“We went out with the Messenger of Allah (ﷺ) on the Farewell Pilgrimage, close to the time of the crescent of Dhul-Hijjah. The Messenger of Allah (ﷺ) said: ‘Whoever among you wants to begin the Talbiyah for ‘Umrah, let him do so. If it were not for the fact that I have brought a sacrificial animal with me, I would have began the Talbiyah for ‘Umrah.’” She said: “Some of the people began the Talbiyah for ‘Umrah, and some began the Talbiyah for Hajj. I was one of those who began the Talbiyah for ‘Umrah.” She said: “We set out until we reached Makkah, then the Day of ‘Arafah came while I was in menses, but I did not exit Ihram for ‘Umrah I complained about that to the Prophet (ﷺ) and he said: ‘Leave your ‘Umrah, undo your hair and comb it, and begin the Talbiyah for Hajj.’” She said: “So I did that, then on the night of Hasbah (i.e., the twelfth night of Dhul-Hijjah), when Allah had enables us to complete our Hajj, he sent ‘Abdur-Rahman bin Abu Bakr with me. He seated me behind him and went out to Tan’im, then I began the Talbiyah for ‘Umrah and Allah enabled us to complete our Hajj and ‘Umrah, and there was no sacrificial animal, charity nor fasting.”}}
\hadithdefcmd{ibnmajah}{3001}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي سُلَيْمَانُ بْنُ سُحَيْمٍ، عَنْ أُمِّ حَكِيمٍ بِنْتِ أُمَيَّةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَهَلَّ بِعُمْرَةٍ مِنْ بَيْتِ الْمَقْدِسِ غُفِرَ لَهُ ‏"‏ ‏.‏\hadithno{3001}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that the Messenger of Allah (ﷺ) said:“Whoever begins the Talbiyah for ‘Umrah from Baitul-Maqdis, will be forgiven.”}}
\hadithdefcmd{ibnmajah}{3002}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ يَحْيَى بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّهِ أُمِّ حَكِيمٍ بِنْتِ أُمَيَّةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَهَلَّ بِعُمْرَةٍ مِنْ بَيْتِ الْمَقْدِسِ كَانَتْ لَهُ كَفَّارَةً لِمَا قَبْلَهَا مِنَ الذُّنُوبِ ‏"‏ ‏.‏ قَالَتْ فَخَرَجْتُ - أَىْ مِنْ بَيْتِ الْمَقْدِسِ - بِعُمْرَةٍ ‏.‏\hadithno{3002}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah, the wife of the Prophet (ﷺ), that the Messenger of Allah (ﷺ) said:“Whoever begins the Talbiyah for ‘Umrah from Baitul-Maqdis, that will be an expiation for all his previous sins.” She said: “So I went out.” Meaning, from Baitul-Maqdis for ‘Umrah}}
\hadithdefcmd{ibnmajah}{3003}{حَدَّثَنَا أَبُو إِسْحَاقَ الشَّافِعِيُّ، إِبْرَاهِيمُ بْنُ مُحَمَّدٍ حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ اعْتَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَرْبَعَ عُمَرٍ عُمْرَةَ الْحُدَيْبِيَةِ وَعُمْرَةَ الْقَضَاءِ مِنْ قَابِلٍ وَالثَّالِثَةَ مِنَ الْجِعْرَانَةِ وَالرَّابِعَةَ الَّتِي مَعَ حَجَّتِهِ ‏.‏\hadithno{3003}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) performed ‘Umrah four times: The ‘Umrah of Hudaibiyah, the ‘Umrah to make up for (the one not completed previously), the third from Ji’ranah and the fourth that he did with his Hajj.”}}
\hadithdefcmd{ibnmajah}{3004}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ إِسْمَاعِيلَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى بِمِنًى يَوْمَ التَّرْوِيَةِ الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ وَالْفَجْرَ ثُمَّ غَدَا إِلَى عَرَفَةَ ‏.‏\hadithno{3004}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) prayed in Mina, on the Day of Tarwiyah (the 8th of Dhul-Hijjah), Zuhr, ‘Asr, Maghrib, ‘Isha’ and Fajr, then he went in the morning to ‘Arafat}}
\hadithdefcmd{ibnmajah}{3005}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يُصَلِّي الصَّلَوَاتِ الْخَمْسَ بِمِنًى ثُمَّ يُخْبِرُهُمْ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{3005}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that he used to pray all five prayers in Mina, then he would tell them that the Messenger of Allah (ﷺ) used to do that}}
\hadithdefcmd{ibnmajah}{3006}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَلاَ نَبْنِي لَكَ بِمِنًى بَيْتًا قَالَ ‏ "‏ لاَ مِنًى مُنَاخُ مَنْ سَبَقَ ‏"‏ ‏.‏\hadithno{3006}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:‘I said: ‘O Messenger of Allah, should we not build you a house in Mina?’ He said: ‘No, Mina is just a stopping place for those who get there first.’”}}
\hadithdefcmd{ibnmajah}{3007}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ أُمِّهِ، مُسَيْكَةَ عَنْ عَائِشَةَ، قَالَتْ قُلْنَا يَا رَسُولَ اللَّهِ أَلاَ نَبْنِي لَكَ بِمِنًى بُنْيَانًا يُظِلُّكَ قَالَ ‏ "‏ لاَ مِنًى مُنَاخُ مَنْ سَبَقَ ‏"‏ ‏.‏\hadithno{3007}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“We said: ‘O Messenger of Allah, should we not build you a house in Mina that will be a means of shade for you?’ He said: ‘No, Mina is just a stopping place for those who get there first.’”}}
\hadithdefcmd{ibnmajah}{3008}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ عُقْبَةَ، عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، عَنْ أَنَسٍ، قَالَ غَدَوْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي هَذَا الْيَوْمِ مِنْ مِنًى إِلَى عَرَفَةَ فَمِنَّا مَنْ يُكَبِّرُ وَمِنَّا مَنْ يُهِلُّ فَلَمْ يَعِبْ هَذَا عَلَى هَذَا وَلاَ هَذَا عَلَى هَذَا - وَرُبَّمَا قَالَ هَؤُلاَءِ عَلَى هَؤُلاَءِ وَلاَ هَؤُلاَءِ عَلَى هَؤُلاَءِ ‏.‏\hadithno{3008}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:“We went in the morning on this day with the Messenger of Allah (ﷺ) from Mina to ‘Arafat. Some of us recited the Takbir (Allahu Akbar) and some of us recited the Tahlil (La ilaha illallah), and neither criticized the other.”}}
\hadithdefcmd{ibnmajah}{3009}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، أَنْبَأَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنْ سَعِيدِ بْنِ حَسَّانَ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَنْزِلُ بِعَرَفَةَ فِي وَادِي نَمِرَةَ ‏.‏ قَالَ فَلَمَّا قَتَلَ الْحَجَّاجُ ابْنَ الزُّبَيْرِ أَرْسَلَ إِلَى ابْنِ عُمَرَ أَىَّ سَاعَةٍ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَرُوحُ فِي هَذَا الْيَوْمِ قَالَ إِذَا كَانَ ذَلِكَ رُحْنَا ‏.‏ فَأَرْسَلَ الْحَجَّاجُ رَجُلاً يَنْظُرُ إِلَى سَاعَةِ يَرْتَحِلُ ‏.‏ فَلَمَّا أَرَادَ ابْنُ عُمَرَ أَنْ يَرْتَحِلَ قَالَ أَزَاغَتِ الشَّمْسُ قَالُوا لَمْ تَزِغْ بَعْدُ ‏.‏ فَجَلَسَ ثُمَّ قَالَ أَزَاغَتِ الشَّمْسُ قَالُوا لَمْ تَزِغْ بَعْدُ ‏.‏ فَجَلَسَ ثُمَّ قَالَ أَزَاغَتِ الشَّمْسُ قَالُوا لَمْ تَزِغْ بَعْدُ ‏.‏ فَجَلَسَ ثُمَّ قَالَ أَزَاغَتِ الشَّمْسُ قَالُوا نَعَمْ ‏.‏ فَلَمَّا قَالُوا قَدْ زَاغَتِ ارْتَحَلَ ‏.‏ قَالَ وَكِيعٌ يَعْنِي رَاحَ ‏.‏\hadithno{3009}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) used to stop at ‘Arafat in Namirah Valley. When Hajjaj killed Ibn Zubair, he sent word to Ibn ‘Umar asking:“At what hour did the Prophet (ﷺ) go out on this day?” He said: “When that time comes, we will go out.” So Hajjah sent a man to watch for the time when they went out. When Ibn ‘Umar wanted to set out, he said: “Has the sun passed the zenith?” They said: “It has not passed the zenith yet.” So he sat down. Then he said: “Has the sun passed the zenith?” They said: “It has not passed the zenith yet.” So he sat down. Then he said: “Has the sun passed the zenith?” They said: “Yes.” When they said that it had passed the zenith, he set out}}
\hadithdefcmd{ibnmajah}{3010}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَيَّاشٍ، عَنْ زَيْدِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيٍّ، قَالَ وَقَفَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِعَرَفَةَ فَقَالَ ‏ "‏ هَذَا الْمَوْقِفُ وَعَرَفَةُ كُلُّهَا مَوْقِفٌ ‏"‏ ‏.‏\hadithno{3010}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) stopped at ‘Arafat and said: ‘This is the place of standing, and all of ‘Arafat is a place of standing.’”}}
\hadithdefcmd{ibnmajah}{3011}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، عَنْ يَزِيدَ بْنِ شَيْبَانَ، قَالَ كُنَّا وُقُوفًا فِي مَكَانٍ تُبَاعِدُهُ مِنَ الْمَوْقِفِ فَأَتَانَا ابْنُ مِرْبَعٍ فَقَالَ إِنِّي رَسُولُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَيْكُمْ يَقُولُ ‏ "‏ كُونُوا عَلَى مَشَاعِرِكُمْ فَإِنَّكُمُ الْيَوْمَ عَلَى إِرْثٍ مِنْ إِرْثِ إِبْرَاهِيمَ ‏"‏ ‏.‏\hadithno{3011}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Yazid bin Shaiban said:“We were standing in a place that was far from the place of standing. Ibn Mirba’ came to us and said: ‘I am the messenger of the Messenger of Allah (ﷺ) to you. He said: “Stay where you are today for today you are on the legacy of Ibrahim.’”}}
\hadithdefcmd{ibnmajah}{3012}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْقَاسِمُ بْنُ عَبْدِ اللَّهِ الْعُمَرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُّ عَرَفَةَ مَوْقِفٌ وَارْفَعُوا عَنْ بَطْنِ عُرَنَةَ وَكُلُّ الْمُزْدَلِفَةِ مَوْقِفٌ وَارْفَعُوا عَنْ بَطْنِ مُحَسِّرٍ وَكُلُّ مِنًى مَنْحَرٌ إِلاَّ مَا وَرَاءَ الْعَقَبَةِ ‏"‏ ‏.‏\hadithno{3012}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“All of ‘Arafat is the place of standing, but keep away from the interior of ‘Uranah. And all of Muzdalifah is the place of standing but keep away from the interior of Muhassir. And all of Mina is the place of sacrifice, except for what is beyond ‘Aqaba.”}}
\hadithdefcmd{ibnmajah}{3013}{حَدَّثَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الْهَاشِمِيُّ، حَدَّثَنَا عَبْدُ الْقَاهِرِ بْنُ السَّرِيِّ السُّلَمِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ كِنَانَةَ بْنِ عَبَّاسِ بْنِ مِرْدَاسٍ السُّلَمِيُّ، أَنَّ أَبَاهُ، أَخْبَرَهُ عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ دَعَا لأُمَّتِهِ عَشِيَّةَ عَرَفَةَ بِالْمَغْفِرَةِ فَأُجِيبَ إِنِّي قَدْ غَفَرْتُ لَهُمْ مَا خَلاَ الظَّالِمَ فَإِنِّي آ��ُذُ لِلْمَظْلُومِ مِنْهُ ‏.‏ قَالَ ‏"‏ أَىْ رَبِّ إِنْ شِئْتَ أَعْطَيْتَ الْمَظْلُومَ مِنَ الْجَنَّةِ وَغَفَرْتَ لِلظَّالِمِ ‏"‏ ‏.‏ فَلَمْ يُجَبْ عَشِيَّتَهُ فَلَمَّا أَصْبَحَ بِالْمُزْدَلِفَةِ أَعَادَ الدُّعَاءَ فَأُجِيبَ إِلَى مَا سَأَلَ ‏.‏ قَالَ فَضَحِكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ أَوْ قَالَ تَبَسَّمَ ‏.‏ فَقَالَ لَهُ أَبُو بَكْرٍ وَعُمَرُ بِأَبِي أَنْتَ وَأُمِّي إِنَّ هَذِهِ لَسَاعَةٌ مَا كُنْتَ تَضْحَكُ فِيهَا فَمَا الَّذِي أَضْحَكَكَ أَضْحَكَ اللَّهُ سِنَّكَ قَالَ ‏"‏ إِنَّ عَدُوَّ اللَّهِ إِبْلِيسَ لَمَّا عَلِمَ أَنَّ اللَّهَ عَزَّ وَجَلَّ قَدِ اسْتَجَابَ دُعَائِي وَغَفَرَ لأُمَّتِي أَخَذَ التُّرَابَ فَجَعَلَ يَحْثُوهُ عَلَى رَأْسِهِ وَيَدْعُو بِالْوَيْلِ وَالثُّبُورِ فَأَضْحَكَنِي مَا رَأَيْتُ مِنْ جَزَعِهِ ‏"‏ ‏.‏\hadithno{3013}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abdullah bin Kinanah bin ‘Abbas bin Mirdas As-Sulami narrated that his father told him, from his father, that the Messenger of Allah (ﷺ) prayed for forgiveness for his nation one evening at ‘Arafat, and the response came:“I have forgiven them, except for the wrongdoer, with whom I will settle the score in favor of the one whom he wronged.” He said: “O Lord, if You will, then grant Paradise to the one who is wronged, and forgive the wrongdoer.” No response came (that evening).The next day at Muzdalifah he repeated the supplication, and received a response to what he asked for. He (the narrator) said: “The Messenger of Allah (ﷺ) laughed,” or he said, “He smiled. Abu Bakr and ‘Umar said to him: ‘May my father and mother be ransomed for you, this is not a time when you usually laugh. What made you laugh, may Allah make your years filled with laughter?’ He said: ‘The enemy of Allah, Iblis, when he came to know that Allah answered my prayer and forgiven my nation, took some dust and started to sprinkle it on his head, uttering cries of woe and doom, and what I saw of his anguish made me laugh.’”}}
\hadithdefcmd{ibnmajah}{3014}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الْمِصْرِيُّ أَبُو جَعْفَرٍ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ يُونُسَ بْنَ يُوسُفَ، يَقُولُ عَنِ ابْنِ الْمُسَيَّبِ، قَالَ قَالَتْ عَائِشَةُ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا مِنْ يَوْمٍ أَكْثَرَ مِنْ أَنْ يُعْتِقَ اللَّهُ عَزَّ وَجَلَّ فِيهِ عَبْدًا مِنَ النَّارِ مِنْ يَوْمِ عَرَفَةَ وَإِنَّهُ لَيَدْنُو عَزَّ وَجَلَّ ثُمَّ يُبَاهِي بِهِمُ الْمَلاَئِكَةَ فَيَقُولُ مَا أَرَادَ هَؤُلاَءِ ‏"‏ ‏.‏\hadithno{3014}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Musayyab that ‘Aishah said that the Messenger of Allah (ﷺ) said:“There is no day on which Allah ransoms more slaves from the Fire than the Day of ‘Arafah. He draws closer and closer, then He boasts about them before the angels and says: ‘What do these people want?’”}}
\hadithdefcmd{ibnmajah}{3015}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ بُكَيْرِ بْنِ عَطَاءٍ، سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَعْمُرَ الدِّيلِيَّ، قَالَ شَهِدْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ وَاقِفٌ بِعَرَفَةَ وَأَتَاهُ نَاسٌ مِنْ أَهْلِ نَجْدٍ فَقَالُوا يَا رَسُولَ اللَّهِ كَيْفَ الْحَجُّ قَالَ ‏ "‏ الْحَجُّ عَرَفَةُ فَمَنْ جَاءَ قَبْلَ صَلاَةِ الْفَجْرِ لَيْلَةَ جَمْعٍ فَقَدْ تَمَّ حَجُّهُ أَيَّامُ مِنًى ثَلاَثَةٌ فَمَنْ تَعَجَّلَ فِي يَوْمَيْنِ فَلاَ إِثْمَ عَلَيْهِ وَمَنْ تَأَخَّرَ فَلاَ إِثْمَ عَلَيْهِ ‏"‏ ‏.‏ ثُمَّ أَرْدَفَ رَجُلاً خَلْفَهُ فَجَعَلَ يُنَادِي بِهِنَّ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا الثَّوْرِيُّ، عَنْ بُكَيْرِ بْنِ عَطَاءٍ اللَّيْثِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَعْمُرَ الدِّيلِيِّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بِعَرَفَةَ فَجَاءَهُ نَفَرٌ مِنْ أَهْلِ نَجْدٍ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى مَا أُرَى لِلثَّوْرِيِّ حَدِيثًا أَشْرَفَ مِنْهُ ‏.‏\hadithno{3015}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sufyan bin Bukair bin ‘Ata’ said:“I heard ‘Abdur-Rahman bin Ya’mur Dili say: ‘I saw the Messenger of Allah (ﷺ) when he was standing at ‘Arafat, and some people from Najd came to him and said: “O Messenger of Allah, what is Hajj?” He said: “Hajj is ‘Arafah. Whoever comes before Fajr prayer on the night of Jam’, he has completed his Hajj. The days at Mina are three. ‘But whosoever hastens to leave in two days, there is no sin on him and whosoever stays on, there is no sin on him.’” [2:203] Then he seated a man behind him on his mount and he started calling out these words.’” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{3016}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ أَبِي خَالِدٍ، عَنْ عَامِرٍ، - يَعْنِي الشَّعْبِيَّ - عَنْ عُرْوَةَ بْنِ مُضَرِّسٍ الطَّائِيِّ، أَنَّهُ حَجَّ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمْ يُدْرِكِ النَّاسَ إِلاَّ وَهُمْ بِجَمْعٍ ‏.‏ قَالَ فَأَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَنْضَيْتُ رَاحِلَتِي وَأَتْعَبْتُ نَفْسِي وَاللَّهِ إِنْ تَرَكْتُ مِنْ حَبْلٍ إِلاَّ وَقَفْتُ عَلَيْهِ فَهَلْ لِي مِنْ حَجٍّ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ شَهِدَ مَعَنَا الصَّلاَةَ وَأَفَاضَ مِنْ عَرَفَاتٍ لَيْلاً أَوْ نَهَارًا فَقَدْ قَضَى تَفَثَهُ وَتَمَّ حَجُّهُ ‏"‏ ‏.‏\hadithno{3016}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Urwah bin Mudarris At-Ta’i that he performed Hajj during the time of the Messenger of Allah (ﷺ), and he did not catch up with the people until they were at Jam’ (Al-Muzdalifah). He said:“I came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, I have made my camel lean (because of the long journey) and I have worn myself out. By Allah, there is no sand hill on which I did not stand. Have I performed Hajj?’ The Prophet (ﷺ) said: ‘Whoever attended the prayer (i.e., Fajr at Muzdalifah) with us and departed from ‘Arafat, by night or day, may remove the dirt and has completed his Hajj.’”}}
\hadithdefcmd{ibnmajah}{3017}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ سُئِلَ كَيْفَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَسِيرُ حِينَ دَفَعَ مِنْ عَرَفَةَ قَالَ كَانَ يَسِيرُ الْعَنَقَ فَإِذَا وَجَدَ فَجْوَةً نَصَّ ‏.‏ قَالَ وَكِيعٌ وَالنَّصُّ يَعْنِي فَوْقَ الْعَنَقِ ‏.‏\hadithno{3017}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Usamah bin Zaid that he was asked:“How did the Messenger of Allah (ﷺ) travel when he departed from ‘Arafat?” He said: “He moved at a quick pace, and when he reached an open space he would make his camel run.”}}
\hadithdefcmd{ibnmajah}{3018}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا الثَّوْرِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَتْ قُرَيْشٌ نَحْنُ قَوَاطِنُ الْبَيْتِ لاَ نُجَاوِزُ الْحَرَمَ ‏.‏ فَقَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ \}‏ ‏.‏\hadithno{3018}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Quraish said: ‘We are the neighbors of the House and we do not leave the sanctuary.’ Allah said: ‘Then depart from the place whence all the people depart.’” [2:]}}
\hadithdefcmd{ibnmajah}{3019}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ أَفَضْتُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمَّا بَلَغَ الشِّعْبَ الَّذِي يَنْزِلُ عِنْدَهُ الأُمَرَاءُ نَزَلَ فَبَالَ وَتَوَضَّأَ قُلْتُ الصَّلاَةَ ‏.‏ قَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ فَلَمَّا انْتَهَى إِلَى جَمْعٍ أَذَّنَ وَأَقَامَ ثُمَّ صَلَّى الْمَغْرِبَ ثُمَّ لَمْ يَحِلَّ أَحَدٌ مِنَ النَّاسِ حَتَّى قَامَ فَصَلَّى الْعِشَاءَ ‏.‏\hadithno{3019}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Usamah bin Zaid said:“I departed from ‘Arafat with the Messenger of Allah (ﷺ), and when he reached the mountain path at which the chiefs would dismount, he dismounted and urinated, then performed ablution. I said: ‘(Is it time for) prayer?’ He said: ‘The prayer is still ahead of you.’ When he reached Jam’ (Muzdalifah) he called the Adhan and Iqamah, then he prayed Maghrib. Then no one among the people unloaded (the camels) until he had prayed ‘Isha’.”}}
\hadithdefcmd{ibnmajah}{3020}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ الأَنْصَارِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْخَطْمِيِّ، أَنَّهُ سَمِعَ أَبَا أَيُّوبَ الأَنْصَارِيَّ، يَقُولُ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ الْمَغْرِبَ وَالْعِشَاءَ فِي حِجَّةِ الْوَدَاعِ بِالْمُزْدَلِفَةِ ‏.‏\hadithno{3020}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin Yazid Al-Khatmi that he heard Abu Ayyub Al-Ansari say:“I prayed Maghrib and ‘Isha’ with the Messenger of Allah (ﷺ) during the Farewell Pilgrimage, at Muzdalifah.”}}
\hadithdefcmd{ibnmajah}{3021}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى الْمَغْرِبَ بِالْمُزْدَلِفَةِ فَلَمَّا أَنَخْنَا قَالَ ‏ "‏ الصَّلاَةُ بِإِقَامَةٍ ‏"‏ ‏.‏\hadithno{3021}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Ubaidullah, from Salim, from his father, that the Prophet (ﷺ) prayed Maghrib at Muzdalifah. When we halted he said:“Prayer should be done with Iqamah.”}}
\hadithdefcmd{ibnmajah}{3022}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَجَّاجٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ حَجَجْنَا مَعَ عُمَرَ بْنِ الْخَطَّابِ فَلَمَّا أَرَدْنَا أَنْ نُفِيضَ، مِنَ الْمُزْدَلِفَةِ قَالَ إِنَّ الْمُشْرِكِينَ كَانُوا يَقُولُونَ أَشْرِقْ ثَبِيرُ كَيْمَا نُغِيرُ ‏.‏ وَكَانُوا لاَ يُفِيضُونَ حَتَّى تَطْلُعَ الشَّمْسُ فَخَالَفَهُمْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَفَاضَ قَبْلَ طُلُوعِ الشَّمْسِ ‏.‏\hadithno{3022}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that ‘Amr bin Maimun said:“We performed Hajj with ‘Umar bin Khattab, and when we wanted to depart from Muzdalifah, he said: ‘The idolators used to say: “May the sun rise over you, O Thabir!* So that we may begin our journey (to Mina),” and they did not depart until the sun had risen.’ So the Messenger of Allah (ﷺ) differed from them by departing before the sun rose.”}}
\hadithdefcmd{ibnmajah}{3023}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنِ الثَّوْرِيِّ، قَالَ قَالَ أَبُو الزُّبَيْرِ قَالَ جَابِرٌ أَفَاضَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فِي حَجَّةِ الْوَدَاعِ وَعَلَيْهِ السَّكِينَةُ وَأَمَرَهُمْ بِالسَّكِينَةِ وَأَمَرَهُمْ أَنْ يَرْمُوا بِمِثْلِ حَصَى الْخَذْفِ وَأَوْضَعَ فِي وَادِي مُحَسِّرٍ ‏.‏ وَقَالَ ‏ "‏ لِتَأْخُذْ أُمَّتِي نُسُكَهَا فَإِنِّي لاَ أَدْرِي لَعَلِّي لاَ أَلْقَاهُمْ بَعْدَ عَامِي هَذَا ‏"‏ ‏.‏\hadithno{3023}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir said:“The Messenger of Allah (ﷺ) departed during the Farewell Pilgrimage in a tranquil manner, and he urged them to be tranquil. He told them to throw small pebbles. He hastened through Muhassir Valley, and said: ‘Let my nation learn its rites (of Hajj), for I do not know, perhaps I will not meet them again after this year.’”}}
\hadithdefcmd{ibnmajah}{3024}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا ابْنُ أَبِي رَوَّادٍ، عَنْ أَبِي سَلَمَةَ الْحِمْصِيِّ، عَنْ بِلاَلِ بْنِ رَبَاحٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ لَهُ غَدَاةَ جَمْعٍ ‏"‏ يَا بِلاَلُ أَسْكِتِ النَّاسَ ‏"‏ ‏.‏ أَوْ ‏"‏ أَنْصِتِ النَّاسَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ تَطَوَّلَ عَلَيْكُمْ فِي جَمْعِكُمْ هَذَا فَوَهَبَ مُسِيئَكُمْ لِمُحْسِنِكُمْ وَأَعْطَى مُحْسِنَكُمْ مَا سَأَلَ ادْفَعُوا بِاسْمِ اللَّهِ ‏"‏ ‏.‏\hadithno{3024}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Bilal bin Rabah that the Prophet (ﷺ) said to him, on the morning of Jama’:“O Bilal, calm the people down,” or “make them be quiet.” Then he said: “Allah has been very gracious to you in this Jam’ of yours. He has forgiven the wrongdoers among you because of the righteous among you, and He has given the righteous among you whatever they ask. Move on in the Name of Allah.”}}
\hadithdefcmd{ibnmajah}{3025}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مِسْعَرٌ، وَسُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنِ الْحَسَنِ الْعُرَنِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدَّمَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أُغَيْلِمَةَ بَنِي عَبْدِ الْمُطَّلِبِ عَلَى حُمُرَاتٍ لَنَا مِنْ جَمْعٍ فَجَعَلَ يَلْطَحُ أَفْخَاذَنَا وَيَقُولُ ‏"‏ أُبَيْنِيَّ لاَ تَرْمُوا الْجَمْرَةَ حَتَّى تَطْلُعَ الشَّمْسُ ‏"‏ ‏.‏ زَادَ سُفْيَانُ فِيهِ ‏"‏ وَلاَ إِخَالُ أَحَدًا يَرْمِيهَا حَتَّى تَطْلُعَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{3025}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“We youngsters from the clan of ‘Abdul-Muttalib came to the Messenger of Allah (ﷺ), from Jam’, on donkeys of ours. He started striking our thighs and saying: ‘O my sons, do not stone the Pillar until the sun rises.’”}}
\hadithdefcmd{ibnmajah}{3026}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ فِيمَنْ قَدَّمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي ضَعَفَةِ أَهْلِهِ ‏.‏\hadithno{3026}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“I was among the weak ones of his family (i.e., the women and children) whom the Messenger of Allah (ﷺ) sent on ahead.”}}
\hadithdefcmd{ibnmajah}{3027}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ سَوْدَةَ بِنْتَ زَمْعَةَ، كَانَتِ امْرَأَةً ثَبِطَةً فَاسْتَأْذَنَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ تَدْفَعَ مِنْ جَمْعٍ قَبْلَ دُفْعَةِ النَّاسِ فَأَذِنَ لَهَا ‏.‏\hadithno{3027}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Aishah that Sawdah bint Zam’ah was a slow- moving woman, so she asked the Messenger of Allah (ﷺ) for permission to depart from Jam’ ahead of the people, and he gave her permission}}
\hadithdefcmd{ibnmajah}{3028}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أُمِّهِ، قَالَتْ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَوْمَ النَّحْرِ عِنْدَ جَمْرَةِ الْعَقَبَةِ وَهُوَ رَاكِبٌ عَلَى بَغْلَةٍ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِذَا رَمَيْتُمُ الْجَمْرَةَ فَارْمُوا بِمِثْلِ حَصَى الْخَذْفِ ‏"‏ ‏.‏\hadithno{3028}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sulaiman bin ‘Amr bin Ahwas that his mother said:“I saw the Prophet (saw0 on the Day of Sacrifice, at ‘Aqabah Pillar, riding a mule. He said: ‘O people! When you stone the Pillar, throw small pebbles.’”)}}
\hadithdefcmd{ibnmajah}{3029}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَوْفٍ، عَنْ زِيَادِ بْنِ الْحُصَيْنِ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ غَدَاةَ الْعَقَبَةِ وَهُوَ عَلَى نَاقَتِهِ ‏"‏ الْقُطْ لِي حَصًى ‏"‏ ‏.‏ فَلَقَطْتُ لَهُ سَبْعَ حَصَيَاتٍ هُنَّ حَصَى الْخَذْفِ فَجَعَلَ يَنْفُضُهُنَّ فِي كَفِّهِ وَيَقُولُ ‏"‏ أَمْثَالَ هَؤُلاَءِ فَارْمُوا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِيَّاكُمْ وَالْغُلُوَّ فِي الدِّينِ فَإِنَّمَا أَهْلَكَ مَنْ كَانَ قَبْلَكُمُ الْغُلُوُّ فِي الدِّينِ ‏"‏ ‏.‏\hadithno{3029}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“On the morning of ‘Aqabah, when he was atop his she-camel, the Messenger of Allah (ﷺ) said: ‘Pick up some pebbles for me.’ So I picked up seven pebbles for him, suitable for Khadhf.* He began to toss them in his hand, saying: ‘Throw something like these.’ Then he said: ‘O people, beware of exaggeration in religious matters for those who came before you were doomed because of exaggeration in religious matters.’”}}
\hadithdefcmd{ibnmajah}{3030}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الْمَسْعُودِيِّ، عَنْ جَامِعِ بْنِ شَدَّادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ لَمَّا أَتَى عَبْدُ اللَّهِ بْنُ مَسْعُودٍ جَمْرَةَ الْعَقَبَةِ اسْتَبْطَنَ الْوَادِيَ وَاسْتَقْبَلَ الْكَعْبَةَ وَجَعَلَ الْجَمْرَةَ عَلَى حَاجِبِهِ الأَيْمَنِ ثُمَّ رَمَى بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ ثُمَّ قَالَ مِنْ هَاهُنَا وَالَّذِي لاَ إِلَهَ غَيْرُهُ رَمَى الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏\hadithno{3030}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Abdur-Rahman bin Yazid said:“When ‘Abdullah bin Mas’ud stoned ‘Aqabah Pillar, he went to the bottom of the valley and turned to face the Ka’bah, with the Pillar on his right hand side. Then he threw seven pebbles, saying the Takbir with each one. Then he said: ‘From here, by the One besides Whom there is none worthy of worship, did the one throw, to whom Surat Al-Baqarah was revealed.’”}}
\hadithdefcmd{ibnmajah}{3031}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أُمِّهِ، قَالَتْ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَوْمَ النَّحْرِ عِنْدَ جَمْرَةِ الْعَقَبَةِ اسْتَبْطَنَ الْوَادِيَ فَرَمَى الْجَمْرَةَ بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ ثُمَّ انْصَرَفَ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أُمِّ جُنْدُبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏\hadithno{3031}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sulaiman bin ‘Amr bin Ahwas that his mother said:“I saw the Prophet (ﷺ) on the Day of Sacrifice, at ‘Aqabah Pillar. He went to the interior of the valley and threw seven pebbles, saying Takbir with each pebble, then he departed.” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{3032}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنِ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ رَمَى جَمْرَةَ الْعَقَبَةِ وَلَمْ يَقِفْ عِنْدَهَا وَذَكَرَ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَعَلَ مِثْلَ ذَلِكَ ‏.‏\hadithno{3032}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Umar stoned ‘Aqabah Pillar, but he did not stay there, and he mentioned that the Prophet (ﷺ) had done likewise}}
\hadithdefcmd{ibnmajah}{3033}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الْحَجَّاجِ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا رَمَى جَمْرَةَ الْعَقَبَةِ مَضَى وَلَمْ يَقِفْ ‏.‏\hadithno{3033}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“When the Messenger of Allah (ﷺ) had stoned ‘Aqabah Pillar, he would continue on, and would not stay there.”}}
\hadithdefcmd{ibnmajah}{3034}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَجَّاجٍ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَمَى الْجَمْرَةَ عَلَى رَاحِلَتِهِ ‏.‏\hadithno{3034}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) stoned the Pillar from atop his mount}}
\hadithdefcmd{ibnmajah}{3035}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أَيْمَنَ بْنِ نَابِلٍ، عَنْ قُدَامَةَ بْنِ عَبْدِ اللَّهِ الْعَامِرِيِّ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَمَى الْجَمْرَةَ يَوْمَ النَّحْرِ عَلَى نَاقَةٍ لَهُ صَهْبَاءَ لاَ ضَرْبَ وَلاَ طَرْدَ وَلاَ إِلَيْكَ إِلَيْكَ ‏.‏\hadithno{3035}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Qudamah bin ‘Abdullah Al-‘Amiri said:“I saw the Prophet (ﷺ) stone the Pillar, on the Day of Sacrifice, from atop a reddish-brown camel of his, without beating anyone, driving them off or telling them to go away.”}}
\hadithdefcmd{ibnmajah}{3036}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِي الْبَدَّاحِ بْنِ عَاصِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَخَّصَ لِلرِّعَاءِ أَنْ يَرْمُوا يَوْمًا وَيَدَعُوا يَوْمًا ‏.‏\hadithno{3036}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Baddah bin ‘Asim, from his father, that the Prophet (ﷺ) granted permission for some shepherds to stone one day and to not stone (the next) day}}
\hadithdefcmd{ibnmajah}{3037}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَالِكُ بْنُ أَنَسٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكِ بْنِ أَنَسٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي الْبَدَّاحِ بْنِ عَاصِمٍ، عَنْ أَبِيهِ، قَالَ رَخَّصَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِرِعَاءِ الإِبِلِ فِي الْبَيْتُوتَةِ أَنْ يَرْمُوا يَوْمَ النَّحْرِ ثُمَّ يَجْمَعُوا رَمْىَ يَوْمَيْنِ بَعْدَ النَّحْرِ فَيَرْمُونَهُ فِي أَحَدِهِمَا - قَالَ مَالِكٌ ظَنَنْتُ أَنَّهُ قَالَ فِي الأَوَّلِ مِنْهُمَا - ثُمَّ يَرْمُونَ يَوْمَ النَّفْرِ ‏.‏\hadithno{3037}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Baddah bin ‘Asim that his father said:“The Messenger of Allah (ﷺ) granted permission to some camel herders regarding staying (in Mina),* and allowing them to stone the Pillars on the Day of Sacrifice, then to combine the stoning of two days after the sacrifice, so that they could do it on one of the two days.”** Malik said: “I think that he said: ‘On the first of the first of the two days, then they could stone them on the day of departure (from Mina).’”}}
\hadithdefcmd{ibnmajah}{3038}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ أَشْعَثَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ حَجَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَمَعَنَا النِّسَاءُ وَالصِّبْيَانُ فَلَبَّيْنَا عَنِ الصِّبْيَانِ وَرَمَيْنَا عَنْهُمْ ‏.‏\hadithno{3038}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“We performed Hajj with the Messenger of Allah (ﷺ), and there were women and children with us. We recited Talbiyah on behalf of the children and stoned the Pillars on their behalf.”}}
\hadithdefcmd{ibnmajah}{3039}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا حَمْزَةُ بْنُ الْحَارِثِ بْنِ عُمَيْرٍ، عَنْ أَبِيهِ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ لَبَّى حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ ‏.‏\hadithno{3039}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) recited Talbiyah until he stoned ‘Aqabah Pillar}}
\hadithdefcmd{ibnmajah}{3040}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ خُصَيْفٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ الْفَضْلُ بْنُ عَبَّاسٍ كُنْتُ رِدْفَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَمَا زِلْتُ أَسْمَعُهُ يُلَبِّي حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ فَلَمَّا رَمَاهَا قَطَعَ التَّلْبِيَةَ ‏.‏\hadithno{3040}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Fadl bin ‘Abbas said: ‘I was riding behind the Prophet (ﷺ) and I continued to hear him reciting the Talbiyah until he stoned ‘Aqabah Pillar, and when he stoned it, he stopped reciting the Talbiyah.’”}}
\hadithdefcmd{ibnmajah}{3041}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَوَكِيعٌ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنِ الْحَسَنِ الْعُرَنِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِذَا رَمَيْتُمُ الْجَمْرَةَ فَقَدْ حَلَّ لَكُمْ كُلُّ شَىْءٍ إِلاَّ النِّسَاءَ ‏.‏ فَقَالَ لَهُ رَجُلٌ يَا ابْنَ عَبَّاسٍ وَالطِّيبُ فَقَالَ أَمَّا أَنَا فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُضَمِّخُ رَأْسَهُ بِالْمِسْكِ أَفَطِيبٌ ذَلِكَ أَمْ لاَ ‏.‏\hadithno{3041}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“When you have stoned the Pillar, everything becomes permissible to you except your wives. A man said to him: ‘O Ibn ‘Abbas, and perfume?’ He said: ‘I saw the Messenger of Allah (ﷺ) perfume his head with musk. Is that perfume or not?’”}}
\hadithdefcmd{ibnmajah}{3042}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا خَالِي، مُحَمَّدٌ وَأَبُو مُعَاوِيَةَ وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ لإِحْرَامِهِ حِينَ أَحْرَمَ وَلإِحْلاَلِهِ حِينَ أَحَلَّ ‏.‏\hadithno{3042}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“I applied perfume to the Messenger of Allah (ﷺ) for his Ihram when he entered Ihram, and when he exited Ihram.”}}
\hadithdefcmd{ibnmajah}{3043}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عُمَارَةُ بْنُ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اللَّهُمَّ اغْفِرْ لِلْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَالْمُقَصِّرِينَ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِلْمُحَلِّقِينَ ‏"‏ ‏.‏ ثَلاَثًا قَالُوا يَا رَسُولَ اللَّهِ وَالْمُقَصِّرِينَ قَالَ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏ ‏.‏\hadithno{3043}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“O Allah, forgive those who shave (their heads).” They said: “O Messenger of Allah, and those who cut (their hair)?’ He said; “O Allah, forgive those who shave (their heads),” three times. They said: “O Messenger of Allah, and those who cut (their hair)?” He said: “And those who cut (their hair).”}}
\hadithdefcmd{ibnmajah}{3044}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَأَحْمَدُ بْنُ أَبِي الْحَوَارِيِّ الدِّمَشْقِيُّ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏ ‏.‏\hadithno{3044}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“May Allah have mercy on those who shave (their heads).” They said: “And those who cut (their hair), O Messenger of Allah!” He said: “May Allah have mercy on those who shave (their heads).” They said: “And those who cut (their hair), O Messenger of Allah!” He said: “May Allah have mercy on those who shave (their heads).” They said: “And those who cut (their hair), O Messenger of Allah!” He said: “And those who cut (their hair).”}}
\hadithdefcmd{ibnmajah}{3045}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنَا ابْنُ إِسْحَاقَ، حَدَّثَنَا ابْنُ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ لِمَ ظَاهَرْتَ لِلْمُحَلِّقِينَ ثَلاَثًا وَلِلْمُقَصِّرِينَ وَاحِدَةً قَالَ ‏ "‏ إِنَّهُمْ لَمْ يَشُكُّوا ‏"‏ ‏.‏\hadithno{3045}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“It was said: ‘O Messenger of Allah, why did you support (by supplicating for) those who shave (their heads) three times and those who cut (their hair) only once?’ He said: ‘Because they did not entertain any doubts.’”}}
\hadithdefcmd{ibnmajah}{3046}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ حَفْصَةَ، زَوْجَ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَا شَأْنُ النَّاسِ حَلُّوا وَلَمْ تَحِلَّ أَنْتَ مِنْ عُمْرَتِكَ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي وَقَلَّدْتُ هَدْيِي فَلاَ أَحِلُّ حَتَّى أَنْحَرَ ‏"‏ ‏.‏\hadithno{3046}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Umar that Hafsah, the wife of the Prophet (ﷺ), said:“I said: ‘O Messenger of Allah, what is the matter with people who have exited Ihram when you have not exited your Ihram?’ He said: ‘I have applied something to my head to keep my hair together, and I have garlanded my sacrificial animal, so I will not exit Ihram until I have offered my sacrifice.’”}}
\hadithdefcmd{ibnmajah}{3047}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُهِلُّ مُلَبِّدًا ‏.‏\hadithno{3047}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim, from his father:“I heard the Messenger of Allah (ﷺ) reciting the Talbiyah when he entered Ihram with something applied to his head to keep the hair together.’”}}
\hadithdefcmd{ibnmajah}{3048}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مِنًى كُلُّهَا مَنْحَرٌ وَكُلُّ فِجَاجِ مَكَّةَ طَرِيقٌ وَمَنْحَرٌ وَكُلُّ عَرَفَةَ مَوْقِفٌ وَكُلُّ الْمُزْدَلِفَةِ مَوْقِفٌ ‏"‏ ‏.‏\hadithno{3048}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“All of Mina is a place of sacrifice. Every road of Makkah is a thoroughfare and a place of sacrifice. All of ‘Arafat is the place of standing, and all of Muzdalifah is a place of standing.”}}
\hadithdefcmd{ibnmajah}{3049}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَا سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَمَّنْ قَدَّمَ شَيْئًا قَبْلَ شَىْءٍ إِلاَّ يُلْقِي بِيَدَيْهِ كِلْتَيْهِمَا ‏ "‏ لاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3049}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) was never asked about someone who had done one thing before another, but he would gesture with both his hands to say: ‘There is no harm in that.’”}}
\hadithdefcmd{ibnmajah}{3050}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُسْأَلُ يَوْمَ مِنًى فَيَقُولُ ‏"‏ لاَ حَرَجَ لاَ حَرَجَ ‏"‏ ‏.‏ فَأَتَاهُ رَجُلٌ فَقَالَ حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏ قَالَ رَمَيْتُ بَعْدَ مَا أَمْسَيْتُ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3050}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) was asked on the Day of Mina, and he would say: ‘There is no harm in that, there is no harm in that.’ A man came to him and said: ‘I shaved my head before I slaughtered (my sacrifice),’ and he said: ‘There is no harm in that.’ He said: ‘I stoned (the Pillar) after evening came,’ and he said: ‘There is no harm in that.’”}}
\hadithdefcmd{ibnmajah}{3051}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ سُئِلَ عَمَّنْ ذَبَحَ قَبْلَ أَنْ يَحْلِقَ أَوْ حَلَقَ قَبْلَ أَنْ يَذْبَحَ قَالَ ‏ "‏ لاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3051}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Prophet (ﷺ) was asked about a man who slaughtered his sacrifice before shaving his head, or who shaved his head before slaughtering his sacrifice, and he said:“There is no harm in that.”}}
\hadithdefcmd{ibnmajah}{3052}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَعَدَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِمِنًى يَوْمَ النَّحْرِ لِلنَّاسِ فَجَاءَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏ ثُمَّ جَاءَهُ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي نَحَرْتُ قَبْلَ أَنْ أَرْمِيَ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏ فَمَا سُئِلَ يَوْمَئِذٍ عَنْ شَىْءٍ قُدِّمَ قَبْلَ شَىْءٍ إِلاَّ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3052}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) sat in Mina, on the Day of Sacrifice, for the people (to come and speak to him). A man came to him and said: ‘O Messenger of Allah, I shaved my head before I slaughtered my sacrifice.’ He said: ‘There is no harm in that.’ Then another man came and said: ‘O Messenger of Allah, I slaughtered my sacrifice before I stoned (the Pillar).’ He said: ‘There is no harm in that.’ And he was not asked that day about anything being done before another but he replied: ‘There is no harm in that.’”}}
\hadithdefcmd{ibnmajah}{3053}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَمَى جَمْرَةَ الْعَقَبَةِ ضُحًى وَأَمَّا بَعْدَ ذَلِكَ فَبَعْدَ زَوَالِ الشَّمْسِ ‏.‏\hadithno{3053}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“I saw the Messenger of Allah (ﷺ) stoning ‘Aqabah Pillar at forenoon, but after that day, he would do it after the sun had passed its zenith.”}}
\hadithdefcmd{ibnmajah}{3054}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُثْمَانَ بْنِ أَبِي شَيْبَةَ أَبُو شَيْبَةَ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَرْمِي الْجِمَارَ إِذَا زَالَتِ الشَّمْسُ قَدْرَ مَا إِذَا فَرَغَ مِنْ رَمْيِهِ صَلَّى الظُّهْرَ ‏.‏\hadithno{3054}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) used to stone the Pillars when the sun had passed its zenith, to the extent that, as soon as he finished stoning them, he would pray Zuhr}}
\hadithdefcmd{ibnmajah}{3055}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ فِي حَجَّةِ الْوَدَاعِ ‏"‏ يَا أَيُّهَا النَّاسُ أَلاَ أَىُّ يَوْمٍ أَحْرَمُ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ قَالُوا يَوْمُ الْحَجِّ الأَكْبَرِ ‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ وَأَعْرَاضَكُمْ بَيْنَكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا أَلاَ لاَ يَجْنِي جَانٍ إِلاَّ عَلَى نَفْسِهِ وَلاَ يَجْنِي وَالِدٌ عَلَى وَلَدِهِ وَلاَ مَوْلُودٌ عَلَى وَالِدِهِ ‏.‏ أَلاَ إِنَّ الشَّيْطَانَ قَدْ أَيِسَ أَنْ يُعْبَدَ فِي بَلَدِكُمْ هَذَا أَبَدًا وَلَكِنْ سَيَكُونُ لَهُ طَاعَةٌ فِي بَعْضِ مَا تَحْتَقِرُونَ مِنْ أَعْمَالِكُمْ فَيَرْضَى بِهَا أَلاَ وَكُلُّ دَمٍ مِنْ دِمَاءِ الْجَاهِلِيَّةِ مَوْضُوعٌ وَأَوَّلُ مَا أَضَعُ مِنْهَا دَمُ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ - كَانَ مُسْتَرْضِعًا فِي بَنِي لَيْثٍ فَقَتَلَتْهُ هُذَيْلٌ - أَلاَ وَإِنَّ كُلَّ رِبًا مِنْ رِبَا الْجَاهِلِيَّةِ مَوْضُوعٌ لَكُمْ رُءُوسُ أَمْوَالِكُمْ لاَ تَظْلِمُونَ وَلاَ تُظْلَمُونَ أَلاَ يَا أُمَّتَاهُ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{3055}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sulaiman bin ‘Amr bin Ahwas that his father said:“I heard the Prophet (ﷺ) say, during the Farewell Pilgrimage: ‘O people! Which day is the most sacred?’ three times. They said: ‘The day of the greatest Hajj.’ He said: ‘Your blood and your wealth and your honor are sacred to one another, as sacred as this day of yours, in this land of your. No sinner commits a sin but it is against himself. No father is to be punished for the sins of his child, and no child is to be punished for the sins of his father. Satan has despaired of ever being worshipping in this land of yours, but he will be obeyed in some matters which you regard as insignificant, and he will be content with that. All the blood feuds of the Ignorance days are abolished, and the first of them that I abolish is the blood feud of Harith bin ‘Abdul-Muttalib, who was nursed among Banu Laith and killed by Hudhail. All the usuries of the Ignorance days are abolished, but you will have your capital. Do not wrong others and you will not be wronged. O my nation, have I conveyed (the message)?’ (He asked this) three times. They said: ‘Yes.’ He said: ‘O Allah, bear witness!’ three times.”}}
\hadithdefcmd{ibnmajah}{3056}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ السَّلاَمِ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ قَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِالْخَيْفِ مِنْ مِنًى فَقَالَ ‏ "‏ نَضَّرَ اللَّهُ امْرَأً سَمِعَ مَقَالَتِي فَبَلَّغَهَا فَرُبَّ حَامِلِ فِقْهٍ غَيْرُ فَقِيهٍ وَرُبَّ حَامِلِ فِقْهٍ إِلَى مَنْ هُوَ أَفْقَهُ مِنْهُ ثَلاَثٌ لاَ يُغِلُّ عَلَيْهِنَّ قَلْبُ مُؤْمِنٍ إِخْلاَصُ الْعَمَلِ لِلَّهِ وَالنَّصِيحَةُ لِوُلاَةِ الْمُسْلِمِينَ وَلُزُومُ جَمَاعَتِهِمْ فَإِنَّ دَعْوَتَهُمْ تُحِيطُ مِنْ وَرَائِهِمْ ‏"‏ ‏.‏\hadithno{3056}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muhammad bin Jubair bin Mut’im that his father said:“The Messenger of Allah (ﷺ) stood up in Khaif in Mina, and said: ‘May Allah make his face shine, the man who hears my words and conveys them. It may be that the bearer of knowledge does not understand it, and it may be that he takes it to one who will understand it more than he does. There are three things in which the heart of the believer does not betray: sincerity of action for the sake of Allah, offering sincere advice to the rulers of the Muslims, and adhering to the Jama’ah (main body of the Muslims). Their supplication is answered (i.e. encompassing every good, and all of the people).”}}
\hadithdefcmd{ibnmajah}{3057}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ تَوْبَةَ، حَدَّثَنَا زَافِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِي سِنَانٍ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ عَلَى نَاقَتِهِ الْمُخَضْرَمَةِ بِعَرَفَاتٍ فَقَالَ ‏"‏ أَتَدْرُونَ أَىُّ يَوْمٍ هَذَا وَأَىُّ شَهْرٍ هَذَا وَأَىُّ بَلَدٍ هَذَا ‏"‏ ‏.‏ قَالُوا هَذَا بَلَدٌ حَرَامٌ وَشَهْرٌ حَرَامٌ وَيَوْمٌ حَرَامٌ ‏.‏ قَالَ ‏"‏ أَلاَ وَإِنَّ أَمْوَالَكُمْ وَدِمَاءَكُمْ عَلَيْكُمْ حَرَامٌ كَحُرْمَةِ شَهْرِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا فِي يَوْمِكُمْ هَذَا أَلاَ وَإِنِّي فَرَطُكُمْ عَلَى الْحَوْضِ وَأُكَاثِرُ بِكُمُ الأُمَمَ فَلاَ تُسَوِّدُوا وَجْهِي أَلاَ وَإِنِّي مُسْتَنْقِذٌ أُنَاسًا وَمُسْتَنْقَذٌ مِنِّي أُنَاسٌ فَأَقُولُ يَا رَبِّ أُصَيْحَابِي ‏.‏ فَيَقُولُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ ‏"‏ ‏.‏\hadithno{3057}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin Mas’ud said:“The Messenger of Allah (ﷺ) said, when he was atop his camel with the clipped ears in ‘Arafat: ‘Do you know what day this is, what month this is and what land this is?’ They said: ‘This is a sacred land, a sacred month and a sacred day.’ He said: ‘Your wealth and your blood are sacred to you as this month of yours, in this land of yours, on this day of yours. I will reach the Cistern (Hawd) before you, and I will be proud of your great numbers before the nations, so do not blacken my face (i.e., cause me to be ashamed). I will rescue some people, and some people will be taken away from me. I will say: “O Lord, my companions!” and He will say: “You do not know what innovations they introduced after you were gone.’”}}
\hadithdefcmd{ibnmajah}{3058}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا هِشَامُ بْنُ الْغَازِ، قَالَ سَمِعْتُ نَافِعًا، يُحَدِّثُ عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَفَ يَوْمَ النَّحْرِ بَيْنَ الْجَمَرَاتِ فِي الْحَجَّةِ الَّتِي حَجَّ فِيهَا فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَىُّ يَوْمٍ هَذَا ‏"‏ ‏.‏ قَالُوا يَوْمُ النَّحْرِ ‏.‏ قَالَ ‏"‏ فَأَىُّ بَلَدٍ هَذَا ‏"‏ ‏.‏ قَالُوا هَذَا بَلَدُ اللَّهِ الْحَرَامُ ‏.‏ قَالَ ‏"‏ فَأَىُّ شَهْرٍ هَذَا ‏"‏ ‏.‏ قَالُوا شَهْرُ اللَّهِ الْحَرَامُ ‏.‏ قَالَ ‏"‏ هَذَا يَوْمُ الْحَجِّ الأَكْبَرِ وَدِمَاؤُكُمْ وَأَمْوَالُكُمْ وَأَعْرَاضُكُمْ عَلَيْكُمْ حَرَامٌ كَحُرْمَةِ هَذَا الْبَلَدِ فِي هَذَا الشَّهْرِ فِي هَذَا الْيَوْمِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَطَفِقَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏ ثُمَّ وَدَّعَ النَّاسَ فَقَالُوا هَذِهِ حَجَّةُ الْوَدَاعِ ‏.‏\hadithno{3058}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) stood, on the Day of Sacrifice, between the Pillars, during the Hajj that he performed. The Prophet (ﷺ) said:“What day is this?” They said: “The day of sacrifice.” He said: “What land is this?” They said: “This is the sacred land of Allah.” He said: “What month is this?” They said: “The sacred month of Allah.” He said: “This is the day of the greatest Hajj, and your blood, your wealth and your honor are sacred to you, as sacred as this land, in this month, on this day.” Then he said: “Have I conveyed (the message)?” They said: “Yes.” Then the Prophet (ﷺ) started to say: “O Allah, bear witness.” Then he bade farewell to the people, and they said: “This is the Farewell Pilgrimage.”}}
\hadithdefcmd{ibnmajah}{3059}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي مُحَمَّدُ بْنُ طَارِقٍ، عَنْ طَاوُسٍ، وَأَبُو الزُّبَيْرِ، عَنْ عَائِشَةَ، وَابْنِ، عَبَّاسٍ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَخَّرَ طَوَافَ الزِّيَارَةِ إِلَى اللَّيْلِ ‏.‏\hadithno{3059}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Shadh; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah and Ibn ‘Abbas that the Prophet (ﷺ) delayed Tawafuz-Ziyarah until nighttime}}
\hadithdefcmd{ibnmajah}{3060}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ لَمْ يَرْمُلْ فِي السَّبْعِ الَّذِي أَفَاضَ فِيهِ ‏.‏ قَالَ عَطَاءٌ وَلاَ رَمَلَ فِيهِ ‏.‏\hadithno{3060}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Abbas that the Prophet (ﷺ) did not walk quickly (Ramal) during the seven circuits of Tawaful-Ifadah (done on 10th day of Dhul-Hijjah)}}
\hadithdefcmd{ibnmajah}{3061}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ عُثْمَانَ بْنِ الأَسْوَدِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، قَالَ كُنْتُ عِنْدَ ابْنِ عَبَّاسٍ جَالِسًا فَجَاءَهُ رَجُلٌ فَقَالَ مِنْ أَيْنَ جِئْتَ قَالَ مِنْ زَمْزَمَ ‏.‏ قَالَ فَشَرِبْتَ مِنْهَا كَمَا يَنْبَغِي قَالَ وَكَيْفَ قَالَ إِذَا شَرِبْتَ مِنْهَا فَاسْتَقْبِلِ الْكَعْبَةَ وَاذْكُرِ اسْمَ اللَّهِ وَتَنَفَّسْ ثَلاَثًا وَتَضَلَّعْ مِنْهَا فَإِذَا فَرَغْتَ فَاحْمَدِ اللَّهَ عَزَّ وَجَلَّ فَإِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ آيَةَ مَا بَيْنَنَا وَبَيْنَ الْمُنَافِقِينَ أَنَّهُمْ لاَ يَتَضَلَّعُونَ مِنْ زَمْزَمَ ‏"‏ ‏.‏\hadithno{3061}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Muhammad bin ‘Abdur-Rahman bin Abu Bakr said:“I was sitting with Ibn ‘Abbas, and a man came to him and he said: ‘Where have you come from?’ He said: ‘From Zamzam.’ He said: ‘Did you drink from it as you should?’ He said: ‘How is that?’ He said: ‘When you drink from it, turn to face the Qiblah and mention the name of Allah, drink three draughts and drink your fill of it. When you have finished, then praise Allah.’ The Messenger of Allah (ﷺ) said: ‘The sign (that differentiates) between us and the hypocrites is that they do not drink their fill from Zamzam.”}}
\hadithdefcmd{ibnmajah}{3062}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ الْمُؤَمَّلِ إِنَّهُ سَمِعَ أَبَا الزُّبَيْرِ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَاءُ زَمْزَمَ لِمَا شُرِبَ لَهُ ‏"‏ ‏.‏\hadithno{3062}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“I heard the Messenger of Allah (ﷺ) say: ‘The water of Zamzam is for whatever it is drunk for.’”}}
\hadithdefcmd{ibnmajah}{3063}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ الْوَاحِدِ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنِي حَسَّانُ بْنُ عَطِيَّةَ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ دَخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ الْفَتْحِ الْكَعْبَةَ وَمَعَهُ بِلاَلٌ وَعُثْمَانُ بْنُ شَيْبَةَ فَأَغْلَقُوهَا عَلَيْهِمْ مِنْ دَاخِلٍ فَلَمَّا خَرَجُوا سَأَلْتُ بِلاَلاً أَيْنَ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَخْبَرَنِي أَنَّهُ صَلَّى عَلَى وَجْهِهِ حِينَ دَخَلَ بَيْنَ الْعَمُودَيْنِ عَنْ يَمِينِهِ ثُمَّ لُمْتُ نَفْسِي أَنْ لاَ أَكُونَ سَأَلْتُهُ كَمْ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3063}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) entered the Ka’bah on the Day of the Conquest (of Makkah), with Bilal and ‘Uthman bin Shaibah, and they locked the door behind them from the inside. When they came out, I asked Bilal: ‘Where did the Messenger of Allah (ﷺ) pray?’ He told me that when he entered, he turned to his right and prayed in the direction that he was facing, between the two columns.”}}
\hadithdefcmd{ibnmajah}{3064}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ الْمَلِكِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ خَرَجَ النَّبِيُّ ـ صلى الله عليه وسلم ـ مِنْ عِنْدِي وَهُوَ قَرِيرُ الْعَيْنِ طَيِّبُ النَّفْسِ ثُمَّ رَجَعَ إِلَىَّ وَهُوَ حَزِينٌ فَقُلْتُ يَا رَسُولَ اللَّهِ خَرَجْتَ مِنْ عِنْدِي وَأَنْتَ قَرِيرُ الْعَيْنِ وَرَجَعْتَ وَأَنْتَ حَزِينٌ ‏.‏ فَقَالَ ‏ "‏ إِنِّي دَخَلْتُ الْكَعْبَةَ وَوَدِدْتُ أَنِّي لَمْ أَكُنْ فَعَلْتُ إِنِّي أَخَافُ أَنْ أَكُونَ أَتْعَبْتُ أُمَّتِي مِنْ بَعْدِي ‏"‏ ‏.‏\hadithno{3064}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) went out delighted, then he came back to me sad. I said: ‘O Messenger of Allah, (why did) you go out happy and come back sad?’ He said: ‘I entered the Ka’bah, and I wish that I had not done that, because I am afraid that I may have caused difficulty for my nation after I am gone.’”}}
\hadithdefcmd{ibnmajah}{3065}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اسْتَأْذَنَ الْعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَبِيتَ بِمَكَّةَ أَيَّامَ مِنًى مِنْ أَجْلِ سِقَايَتِهِ فَأَذِنَ لَهُ ‏.‏\hadithno{3065}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Umar said:“Abbas bin ‘Abdul-Muttalib asked the Messenger of Allah (ﷺ) for permission to stay overnight in Makkah on the nights of Mina for the purpose of supplying water to the pilgrims, and he gave him permission}}
\hadithdefcmd{ibnmajah}{3066}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمْ يُرَخِّصِ النَّبِيُّ ـ صلى الله عليه وسلم ـ لأَحَدٍ يَبِيتُ بِمَكَّةَ إِلاَّ لِلْعَبَّاسِ مِنْ أَجْلِ السِّقَايَةِ ‏.‏\hadithno{3066}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) did not allow anyone to stay overnight in Makkah apart from ‘Abbas, for the purpose of supplying water to the pilgrims.”}}
\hadithdefcmd{ibnmajah}{3067}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، وَعَبْدَةُ، وَوَكِيعٌ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، كُلُّهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ نُزُولَ الأَبْطَحِ لَيْسَ بِسُنَّةٍ إِنَّمَا نَزَلَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِيَكُونَ أَسْمَحَ لِخُرُوجِهِ ‏.‏\hadithno{3067}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“Staying in Abtah is not Sunnah; the Messenger of Allah (ﷺ) only stayed there because it was more convenient for his departure.”}}
\hadithdefcmd{ibnmajah}{3068}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ عَمَّارِ بْنِ رُزَيْقٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتِ ادَّلَجَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لَيْلَةَ النَّفْرِ مِنَ الْبَطْحَاءِ ادِّلاَجًا ‏.‏\hadithno{3068}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) set out before daybreak, on the night of departure, from Batha’.”}}
\hadithdefcmd{ibnmajah}{3069}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ يَنْزِلُونَ بِالأَبْطَحِ ‏.‏\hadithno{3069}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ), Abu Bakr, ‘Umar and ‘Uthman used to stay at Abtah.”}}
\hadithdefcmd{ibnmajah}{3070}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سُلَيْمَانَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّاسُ يَنْصَرِفُونَ كُلَّ وَجْهٍ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَنْفِرَنَّ أَحَدٌ حَتَّى يَكُونَ آخِرُ عَهْدِهِ بِالْبَيْتِ ‏"‏ ‏.‏\hadithno{3070}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The people were going in all directions, and the Messenger of Allah (ﷺ) said: ‘No one should depart until the last thing he does is (Tawaf around) the House.’”}}
\hadithdefcmd{ibnmajah}{3071}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَزِيدَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَنْفِرَ الرَّجُلُ حَتَّى يَكُونَ آخِرُ عَهْدِهِ بِالْبَيْتِ ‏.‏\hadithno{3071}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade a man to depart until the last thing he did was (Tawaf around) the House.”}}
\hadithdefcmd{ibnmajah}{3072}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَعُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ حَاضَتْ صَفِيَّةُ بِنْتُ حُيَىٍّ بَعْدَمَا أَفَاضَتْ ‏.‏ قَالَتْ عَائِشَةُ فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقَالَ ‏"‏ أَحَابِسَتُنَا هِيَ ‏"‏ ‏.‏ فَقُلْتُ إِنَّهَا قَدْ أَفَاضَتْ ثُمَّ حَاضَتْ بَعْدَ ذَلِكَ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَلْتَنْفِرْ ‏"‏ ‏.‏\hadithno{3072}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“Safiyyah bint Huyai got her menses after she had done Tawaful-Ifadah.” ‘Aishah said: “I mentioned that to the Messenger of Allah (ﷺ) and he said: ‘Has she detained us?’ I said: ‘She performed Tawaful-Ifadah then she got her menses after that.’ The Messenger of Allah (ﷺ) said: ‘Then let her depart.’”}}
\hadithdefcmd{ibnmajah}{3073}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ ذَكَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَفِيَّةَ فَقُلْنَا قَدْ حَاضَتْ ‏.‏ فَقَالَ ‏"‏ عَقْرَى حَلْقَى مَا أُرَاهَا إِلاَّ حَابِسَتَنَا ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ طَافَتْ يَوْمَ النَّحْرِ ‏.‏ قَالَ ‏"‏ فَلاَ إِذًا مُرُوهَا فَلْتَنْفِرْ ‏"‏ ‏.‏\hadithno{3073}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) mentioned Safiyyah and we said: ‘She has got her menses.’ He said: ‘ ‘Aqra Halqa!* I think that she has detained us.’ I said: ‘O Messenger of Allah, she performed Tawaful-Ifadah on the Day of Sacrifice.’ He said: ‘No then, tell her to depart.’”}}
\hadithdefcmd{ibnmajah}{3074}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، قَالَ دَخَلْنَا عَلَى جَابِرِ بْنِ عَبْدِ اللَّهِ فَلَمَّا انْتَهَيْنَا إِلَيْهِ سَأَلَ عَنِ الْقَوْمِ، حَتَّى انْتَهَى إِلَىَّ فَقُلْتُ أَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحُسَيْنِ، ‏.‏ فَأَهْوَى بِيَدِهِ إِلَى رَأْسِي فَحَلَّ زِرِّي الأَعْلَى ثُمَّ حَلَّ زِرِّي الأَسْفَلَ ثُمَّ وَضَعَ كَفَّهُ بَيْنَ ثَدْيَىَّ وَأَنَا يَوْمَئِذٍ غُلاَمٌ شَابٌّ فَقَالَ مَرْحَبًا بِكَ سَلْ عَمَّا شِئْتَ ‏.‏ فَسَأَلْتُهُ وَهُوَ أَعْمَى فَجَاءَ وَقْتُ الصَّلاَةِ فَقَامَ فِي نِسَاجَةٍ مُلْتَحِفًا بِهَا كُلَّمَا وَضَعَهَا عَلَى مَنْكِبَيْهِ رَجَعَ طَرَفَاهَا إِلَيْهِ مِنْ صِغَرِهَا وَرِدَاؤُهُ إِلَى جَانِبِهِ عَلَى الْمِشْجَبِ فَصَلَّى بِنَا فَقُلْتُ أَخْبِرْنَا عَنْ حَجَّةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقَالَ بِيَدِهِ فَعَقَدَ تِسْعًا وَقَالَ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَكَثَ تِسْعَ سِنِينَ لَمْ يَحُجَّ فَأَذَّنَ فِي النَّاسِ فِي الْعَاشِرَةِ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ حَاجٌّ فَقَدِمَ الْمَدِينَةَ بَشَرٌ كَثِيرٌ كُلُّهُمْ يَلْتَمِسُ أَنْ يَأْتَمَّ بِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَيَعْمَلَ بِمِثْلِ عَمَلِهِ فَخَرَجَ وَخَرَجْنَا مَعَهُ فَأَتَيْنَا ذَا الْحُلَيْفَةِ فَوَلَدَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ كَيْفَ أَصْنَعُ قَالَ ‏"‏ اغْتَسِلِي وَاسْتَثْفِرِي بِثَوْبٍ وَأَحْرِمِي ‏"‏ ‏.‏ فَصَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْمَسْجِدِ ثُمَّ رَكِبَ الْقَصْوَاءَ ‏.‏ حَتَّى إِذَا اسْتَوَتْ بِهِ نَاقَتُهُ عَلَى الْبَيْدَاءِ - قَالَ جَابِرٌ نَظَرْتُ إِلَى مَدِّ بَصَرِي مِنْ بَيْنِ يَدَيْهِ بَيْنَ رَاكِبٍ وَمَاشٍ وَعَنْ يَمِينِهِ مِثْلُ ذَلِكَ وَعَنْ يَسَارِهِ مِثْلُ ذَلِكَ وَمِنْ خَلْفِهِ مِثْلُ ذَلِكَ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَيْنَ أَظْهُرِنَا وَعَلَيْهِ يَنْزِلُ الْقُرْآنُ وَهُوَ يَعْرِفُ تَأْوِيلَهُ مَا عَمِلَ مِنْ شَىْءٍ عَمِلْنَا بِهِ فَأَهَلَّ بِالتَّوْحِيدِ ‏"‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ وَأَهَلَّ النَّاسُ بِهَذَا الَّذِي يُهِلُّونَ بِهِ فَلَمْ يَرُدَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَيْهِمْ شَيْئًا مِنْهُ وَلَزِمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ تَلْبِيَتَهُ ‏.‏ قَالَ جَابِرٌ لَسْنَا نَنْوِي إِلاَّ الْحَجَّ لَسْنَا نَعْرِفُ الْعُمْرَةَ حَتَّى إِذَا أَتَيْنَا الْبَيْتَ مَعَهُ اسْتَلَمَ الرُّكْنَ فَرَمَلَ ثَلاَثًا وَمَشَى أَرْبَعًا ثُمَّ قَامَ إِلَى مَقَامِ إِبْرَاهِيمَ فَقَالَ ‏"‏ ‏\{وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى\}‏ ‏"‏ ‏.‏ فَجَعَلَ الْمَقَامَ بَيْنَهُ وَبَيْنَ الْبَيْتِ فَكَانَ أَبِي يَقُولُ - وَلاَ أَعْلَمُهُ إِلاَّ ذَكَرَهُ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ - إِنَّهُ كَانَ يَقْرَأُ فِي الرَّكْعَتَيْنِ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ\}‏ وَ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ \}‏ ‏.‏ ثُمَّ رَجَعَ إِلَى الْبَيْتِ فَاسْتَلَمَ الرُّكْنَ ثُمَّ خَرَجَ مِنَ الْبَابِ إِلَى الصَّفَا حَتَّى إِذَا دَنَا مِنَ الصَّفَا قَرَأَ ‏"‏ ‏\{إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ ‏)‏ ‏.‏ نَبْدَأُ بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏ فَبَدَأَ بِالصَّفَا ‏.‏ فَرَقِيَ عَلَيْهِ حَتَّى رَأَى الْبَيْتَ فَكَبَّرَ اللَّهَ وَهَلَّلَهُ وَحَمِدَهُ وَقَالَ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ أَنْجَزَ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏ ‏.‏ ثُمَّ دَعَا بَيْنَ ذَلِكَ وَقَالَ مِثْلَ هَذَا ثَلاَثَ مَرَّاتٍ ثُمَّ نَزَلَ إِلَى الْمَرْوَةِ فَمَشَى حَتَّى إِذَا انْصَبَّتْ قَدَمَاهُ رَمَلَ فِي بَطْنِ الْوَادِي حَتَّى إِذَا صَعِدَتَا - يَعْنِي قَدَمَاهُ - مَشَى حَتَّى أَتَى الْمَرْوَةَ فَفَعَلَ عَلَى الْمَرْوَةِ كَمَا فَعَلَ عَلَى الصَّفَا فَلَمَّا كَانَ آخِرُ طَوَافِهِ عَلَى الْمَرْوَةِ ‏.‏ قَالَ ‏"‏ لَوْ أَنِّي اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ لَمْ أَسُقِ الْهَدْىَ وَجَعَلْتُهَا عُمْرَةً فَمَنْ كَانَ مِنْكُمْ لَيْسَ مَعَهُ هَدْىٌ فَلْيَحْلِلْ وَلْيَجْعَلْهَا عُمْرَةً ‏"‏ ‏.‏ فَحَلَّ النَّاسُ كُلُّهُمْ وَقَصَّرُوا إِلاَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَمَنْ كَانَ مَعَهُ الْهَدْىُ فَقَامَ سُرَاقَةُ بْنُ مَالِكِ بْنِ جُعْشُمٍ فَقَالَ يَا رَسُولَ اللَّهِ أَلِعَامِنَا هَذَا أَمْ لأَبَدِ الأَبَدِ قَالَ فَشَبَّكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَصَابِعَهُ فِي الأُخْرَى وَقَالَ ‏"‏ دَخَلَتِ الْعُمْرَةُ فِي الْحَجِّ هَكَذَا - مَرَّتَيْنِ - لاَ بَلْ لأَبَدِ الأَبَدِ ‏"‏ ‏.‏ قَالَ وَقَدِمَ عَلِيٌّ بِبُدْنٍ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏ فَوَجَدَ فَاطِمَةَ مِمَّنْ حَلَّ وَلَبِسَتْ ثِيابًا صَبِيغًا وَاكْتَحَلَتْ فَأَنْكَرَ ذَلِكَ عَلَيْهَا عَلِيٌّ فَقَالَتْ أَمَرَنِي أَبِي بِهَذَا ‏.‏ فَكَانَ عَلِيٌّ يَقُولُ بِالْعِرَاقِ فَذَهَبْتُ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مُحَرِّشًا عَلَى فَاطِمَةَ فِي الَّذِي صَنَعَتْهُ مُسْتَفْتِيًا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الَّذِي ذَكَرَتْ عَنْهُ وَأَنْكَرْتُ ذَلِكَ عَلَيْهَا ‏.‏ فَقَالَ ‏"‏ صَدَقَتْ صَدَقَتْ مَاذَا قُلْتَ حِينَ فَرَضْتَ الْحَجَّ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُمَّ إِنِّي أُهِلُّ بِمَا أَهَلَّ بِهِ رَسُولُكَ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ ‏"‏ فَإِنَّ مَعِيَ الْهَدْىَ فَلاَ تَحِلُّ ‏"‏ ‏.‏ قَالَ فَكَانَ جَمَاعَةُ الْهَدْىِ الَّذِي جَاءَ بِهِ عَلِيٌّ مِنَ الْيَمَنِ وَالَّذِي أَتَى بِهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ مِنَ الْمَدِينَةِ مِائَةً ثُمَّ حَلَّ النَّاسُ كُلُّهُمْ وَقَصَّرُوا إِلاَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَمَنْ كَانَ مَعَهُ هَدْىٌ فَلَمَّا كَانَ يَوْمُ التَّرْوِيَةِ وَتَوَجَّهُوا إِلَى مِنًى أَهَلُّوا بِالْحَجِّ ‏.‏ فَرَكِبَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَصَلَّى بِمِنًى الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ وَالصُّبْحَ ثُمَّ مَكَثَ قَلِيلاً حَتَّى طَلَعَتِ الشَّمْسُ وَأَمَرَ بِقُبَّةٍ مِنْ شَعَرٍ فَضُرِبَتْ لَهُ بِنَمِرَةَ فَسَارَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لاَ تَشُكُّ قُرَيْشٌ إِلاَّ أَنَّهُ وَاقِفٌ عِنْدَ الْمَشْعَرِ الْحَرَامِ أَوِ الْمُزْدَلِفَةِ كَمَا كَانَتْ قُرَيْشٌ تَصْنَعُ فِي الْجَاهِلِيَّةِ فَأَجَازَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حَتَّى أَتَى عَرَفَةَ فَوَجَدَ الْقُبَّةَ قَدْ ضُرِبَتْ لَهُ بِنَمِرَةَ فَنَزَلَ بِهَا حَتَّى إِذَا زَاغَتِ الشَّمْسُ أَمَرَ بِالْقَصْوَاءِ فَرُحِلَتْ لَهُ فَرَكِبَ حَتَّى أَتَى بَطْنَ الْوَادِي فَخَطَبَ النَّاسَ فَقَالَ ‏"‏ إِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ عَلَيْكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا أَلاَ وَإِنَّ كُلَّ شَىْءٍ مِنْ أَمْرِ الْجَاهِلِيَّةِ مَوْضُوعٌ تَحْتَ قَدَمَىَّ هَاتَيْنِ وَدِمَاءُ الْجَاهِلِيَّةِ مَوْضُوعَةٌ وَأَوَّلُ دَمٍ أَضَعُهُ دَمُ رَبِيعَةَ بْنِ الْحَارِثِ - كَانَ مُسْتَرْضِعًا فِي بَنِي سَعْدٍ فَقَتَلَتْهُ هُذَيْلٌ - وَرِبَا الْجَاهِلِيَّةِ مَوْضُوعٌ وَأَوَّلُ رِبًا أَضَعُهُ رِبَانَا رِبَا الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ فَإِنَّهُ مَوْضُوعٌ كُلُّهُ فَاتَّقُوا اللَّهَ فِي النِّسَاءِ فَإِنَّكُمْ أَخَذْتُمُوهُنَّ بِأَمَانَةِ اللَّهِ وَاسْتَحْلَلْتُمْ فُرُوجَهُنَّ بِكَلِمَةِ اللَّهِ وَإِنَّ لَكُمْ عَلَيْهِنَّ أَنْ لاَ يُوطِئْنَ فُرُشَكُمْ أَحَدًا تَكْرَهُونَهُ فَإِنْ فَعَلْنَ ذَلِكَ فَاضْرِبُوهُنَّ ضَرْبًا غَيْرَ مُبَرِّحٍ وَلَهُنَّ عَلَيْكُمْ رِزْقُهُنَّ وَكِسْوَتُهُنَّ بِالْمَعْرُوفِ وَقَدْ تَرَكْتُ فِيكُمْ مَا لَمْ تَضِلُّوا إِنِ اعْتَصَمْتُمْ بِهِ كِتَابَ اللَّهِ وَأَنْتُمْ مَسْئُولُونَ عَنِّي فَمَا أَنْتُمْ قَائِلُونَ ‏"‏ ‏.‏ قَالُوا نَشْهَدُ أَنَّكَ قَدْ بَلَّغْتَ وَأَدَّيْتَ وَنَصَحْتَ ‏.‏ فَقَالَ بِإِصْبَعِهِ السَّبَّابَةِ إِلَى السَّمَاءِ وَيَنْكُبُهَا إِلَى النَّاسِ ‏"‏ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ثُمَّ أَذَّنَ بِلاَلٌ ثُمَّ أَقَامَ فَصَلَّى الظُّهْرَ ثُمَّ أَقَامَ فَصَلَّى الْعَصْرَ وَلَمْ يُصَلِّ بَيْنَهُمَا شَيْئًا ثُمَّ رَكِبَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حَتَّى أَتَى الْمَوْقِفَ فَجَعَلَ بَطْنَ نَاقَتِهِ إِلَى الصَّخَرَاتِ وَجَعَلَ حَبْلَ الْمُشَاةِ بَيْنَ يَدَيْهِ وَاسْتَقْبَلَ الْقِبْلَةَ فَلَمْ يَزَلْ وَاقِفًا حَتَّى غَرَبَتِ الشَّمْسُ وَذَهَبَتِ الصُّفْرَةُ قَلِيلاً حَتَّى غَابَ الْقُرْصُ وَأَرْدَفَ أُسَامَةَ بْنَ زَيْدٍ خَلْفَهُ فَدَفَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَدْ شَنَقَ الْقَصْوَاءَ بِالزِّمَامِ حَتَّى إِنَّ رَأْسَهَا لَيُصِيبُ مَوْرِكَ رَحْلِهِ وَيَقُولُ بِيَدِهِ الْيُمْنَى ‏"‏ أَيُّهَا النَّاسُ السَّكِينَةَ السَّكِينَةَ ‏"‏ ‏.‏ كُلَّمَا أَتَى حَبْلاً مِنَ الْحِبَالِ أَرْخَى لَهَا قَلِيلاً حَتَّى تَصْعَدَ ثُمَّ أَتَى الْمُزْدَلِفَةَ فَصَلَّى بِهَا الْمَغْرِبَ وَالْعِشَاءَ بِأَذَانٍ وَاحِدٍ وَإِقَامَتَيْنِ وَلَمْ يُصَلِّ بَيْنَهُمَا شَيْئًا ثُمَّ اضْطَجَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حَتَّى طَلَعَ الْفَجْرُ فَصَلَّى الْفَجْرَ حِينَ تَبَيَّنَ لَهُ الصُّبْحُ بِأَذَانٍ وَإِقَامَةٍ ثُمَّ رَكِبَ الْقَصْوَاءَ حَتَّى أَتَى الْمَشْعَرَ الْحَرَامَ فَرَقِيَ عَلَيْهِ فَحَمِدَ اللَّهَ وَكَبَّرَهُ وَهَلَّلَهُ فَلَمْ يَزَلْ وَاقِفًا حَتَّى أَسْفَرَ جِدًّا ثُمَّ دَفَعَ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ وَأَرْدَفَ الْفَضْلَ بْنَ الْعَبَّاسِ وَكَانَ رَجُلاً حَسَنَ الشَّعَرِ أَبْيَضَ وَسِيمًا فَلَمَّا دَفَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّ الظُّعُنُ يَجْرِينَ فَطَفِقَ الْفَضْلُ يَنْظُرُ إِلَيْهِنَّ فَوَضَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَدَهُ مِنَ الشِّقِّ الآخَرِ فَصَرَفَ الْفَضْلُ وَجْهَهُ مِنَ الشِّقِّ الآخَرِ يَنْظُرُ حَتَّى أَتَى مُحَسِّرًا حَرَّكَ قَلِيلاً ثُمَّ سَلَكَ الطَّرِيقَ الْوُسْطَى الَّتِي تُخْرِجُكَ إِلَى الْجَمْرَةِ الْكُبْرَى حَتَّى أَتَى الْجَمْرَةَ الَّتِي عِنْدَ الشَّجَرَةِ فَرَمَى بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ مِنْهَا مِثْلِ حَصَى الْخَذْفِ وَرَمَى مِنْ بَطْنِ الْوَادِي ثُمَّ انْصَرَفَ إِلَى الْمَنْحَرِ فَنَحَرَ ثَلاَثًا وَسِتِّينَ بَدَنَةً بِيَدِهِ وَأَعْطَى عَلِيًّا فَنَحَرَ مَا غَبَرَ وَأَشْرَكَهُ فِي هَدْيِهِ ثُمَّ أَمَرَ مِنْ كُلِّ بَدَنَةٍ بِبَضْعَةٍ فَجُعِلَتْ فِي قِدْرٍ فَطُبِخَتْ فَأَكَلاَ مِنْ لَحْمِهَا وَشَرِبَا مِنْ مَرَقِهَا ثُمَّ أَفَاضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى الْبَيْتِ فَصَلَّى بِمَكَّةَ الظُّهْرَ فَأَتَى بَنِي عَبْدِ الْمُطَّلِبِ وَهُمْ يَسْقُونَ عَلَى زَمْزَمَ فَقَالَ ‏"‏ انْزِعُوا بَنِي عَبْدِ الْمُطَّلِبِ لَوْلاَ أَنْ يَغْلِبَكُمُ النَّاسُ عَلَى سِقَايَتِكُمْ لَنَزَعْتُ مَعَكُمْ ‏"‏ ‏.‏ فَنَاوَلُوهُ دَلْوًا فَشَرِبَ مِنْهُ ‏.‏\hadithno{3074}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ja’far bin Muhammad narrated that his father said:“We entered upon Jabir bin ‘Abdullah, and when we reached him he asked about the people (i.e., what their names were, etc.). When he reached me, I said: ‘I am Muhammad bin ‘Ali bin Husain.’ He stretched forth his hand towards my head, and undid my top button, then undid my lower button. Then he placed his hand on my chest, and I was a young boy at that time. Then he said: ‘Welcome to you, ask whatever you want.’ So I asked him, and he was blind. The time for prayer came, so he stood up, wrapping himself in a woven cloth. Every time he put it on his shoulders, its edges came up, because it was too small. And his cloak was beside him on a hook. He led us in prayer, then he said: ‘Tell us about the Hajj of the Messenger of Allah (ﷺ).’ He held up his hands, showing nine (fingers), and said: ‘The Messenger of Allah (ﷺ) stayed for nine years without performing Hajj, then it was announced to the people in the tenth year that the Messenger of Allah (ﷺ) was going for Hajj. So many people came to Al-Madinah, all of them seeking to follow the Messenger of Allah (ﷺ) and do what he did. He set out and we set out with him, and we came to Dhul-Hulaifah where Asma’ bint ‘Umais gave birth to Muhammad bin Abu Bakr. She sent word to the Messenger of Allah (ﷺ) asking what she should do. He said: “Perform Ghusl, fasten a cloth around your waist and enter Ihram.” The Messenger of Allah (ﷺ) prayed in the mosque, then he rode Qaswa’ (his she-camel) until, when his she-camel arose with him upon Baida’,’ Jabir said: ‘As far as I could see, I saw people riding and walking in front of him, and I saw the same to his right and left, and behind him, and the Messenger of Allah (ﷺ) was among us and Qur’an was being revealed to him, and he understood its meaning. Whatever he did, we did too. Then he began the Talbiyah of monotheism: “Labbaika Allahumma labbaik, labbaika la sharika laka labbaik. Innal-hamda wan-ni’mata laka wal-mulk, la sharika laka (Here I am, O Allah, here I am. Here I am, You have no partner, here I am. Verily all praise and blessings are Yours, and all sovereignty, You have no partner).” And the people repeated his words. And the Messenger of Allah (ﷺ) approved of that. And the Messenger of Allah (ﷺ) continued to recite the Talbiyah.’ Jabir said: ‘We did not intend (to do) anything but Hajj. We were not aware of ‘Umrah. Then when we reached the House with him, he touched the Corner, and walked quickly (Ramal) for three circuits and walked (normally) for four. Then he stood at the place of Ibrahim and said: “And take you (people) the place of Ibrahim as a place of prayer.” [2:125] He stood with the place between him and the House. My father used to say:* “And I do not think that he mentioned it other than from the Prophet (ﷺ): ‘That he used to recite in those two Rak’ah (at the place of Ibrahim): “Say: ‘O you disbelievers!’” [Al-Kafirun (109)] and “Say: ‘He is Allah, (the) One.’” [Al-Ikhlas (112)] “Then he went back to the House and touched the Corner, then he went out through the gate to Safa. When he drew near to Safa he recited: “Verily, Safa and Marwah are among the symbols of Allah,” [2:158] (and said:) “We will start with that with which Allah started.” So he started with Safa and climbed it until he could see the House, then proclaimed the greatness of Allah (by saying: Allahu Akbar) and said Tahlil (La ilaha illallah) and praised Him (saying Al-Hamdulillah), and he said: “La ilaha illallah wahdahu la sharika lahu, lahul-mulku, wa lahul-hamdu, yuhyi wa yumit wa huwa ‘ala kulli shai’in Qadir. La ilaha illallah wahdahu, La sharika lahu anjaza wa’dahu, wa nasara ‘abduhu, wa hazamal-Ahzaba wahdahu (None has the right to be worshiped but Allah alone, with no partner or associate; His is the dominion, all praise is due to Him, He gives life and causes death and He is able to do all things. None has the right to be worshiped but Allah alone; He has no partner or associate, He fulfilled His promise, granted victory to His slave, and defeated the Confederates alone).” And he said that three times, supplication in between. Then he headed towards Marwah walking normally until, when he started to go downhill, he walked quickly (Ramal) in the bottom of the valley. When he started to go uphill, he walked normally, until he reached Marwah, and he did atop Marwah what he had done atop Safa. At the end of his Sa’y, atop Marwah he said: “If I had known before what I have come to know now, I would not have garlanded the sacrificial animal, and I would have made it ‘Umrah. Whoever among you does not have a sacrificial animal with him, let him exit Ihram and make it ‘Umrah.” So all the people exited Ihram and cut their hair, except the Prophet (ﷺ) and those who had sacrificial animals with them. Suraqah bin Malik bin Ju’shum stood up and said: “O Messenger of Allah! Is this for this year only, or forever and ever?” The Messenger of Allah (ﷺ) interlaced his fingers and said: “‘Umrah is included in Hajj like this,” twice. “No, it is forever and ever.” ‘Ali brought the camels of the Prophet (ﷺ), and he found that Fatimah was one of those who had exited Ihram. She had put on a dyed garment and used kohl. ‘Ali disliked this action on her part, but she said: “My father told me to do this.” ‘Ali used to say in Iraq: “So I went to the Messenger of Allah (ﷺ), feeling upset with Fatimah because of what she had done, to ask the Messenger of Allah (ﷺ) about what she had said that he said, and that I had disliked that. He said: ‘She spoke the truth, she spoke the truth. What did you say when you began your Hajj?’” He said: “I said: ‘O Allah, I begin the Talbiyah for that for which your Messenger (ﷺ) begins the Talbiyah.’ (He said:) ‘And I have the sacrificial animal with me, so do not exit Ihram.’ He said: “The total number of sacrificial animals that ‘Ali had brought from Yemen and that the Prophet (ﷺ) brought from Al-Madinah were one hundred. Then all the people exited Ihram and cut their hair, apart from the Prophet (ﷺ) and those who had sacrificial animals with them. When the day of Tarwiyah came (the 8th of Dhul-Hijjah), they headed for Mina and began the Talbiyah for Hajj. The Messenger of Allah (ﷺ) rode. He prayed Zuhr, ‘Asr, Maghrib, ‘Isha’ and Fajr at Mina. Then he stayed for a short while until the sun rose, and he ordered that a tent of goat hair be pitched for him in Namirah. Then the Messenger of Allah (ﷺ) set out, and the Quraish were certain that he was going to stay at Al-Mash’ar Haram or at Al-Muzdalifah, as Quraish used to do during the Ignorance days. But the Messenger of Allah (ﷺ) continued until he came to ‘Arafat, where he found that the tent had been pitched for him in Namirah, and he stopped there. Then when the sun had passed its zenith, he called for Qaswa’ and she was saddled for him. He rode until he came to the bottom of the valley, and he addressed the people and said: ‘Your blood and your wealth are sacred to you, as sacred as this day of yours, in this month of yours, in this land of yours. Every matter of Ignorance days is abolished, beneath these two feet of mine. The blood feuds of the Ignorance days are abolished, and the first blood feud of Rabi’ah bin Harith, who was nursed among Banu Sa’d and killed by Hudhail. The usuries of Ignorance days are abolished, and the first usury (that I abolish) is our usury, the usury due to ‘Abbas bin ‘Abdul-Muttalib. It is all abolished. Fear Allah with regard to women, for you have taken them as a trust from Allah, and intimacy with them has become permissible to you through Allah’s Word. Your rights over them are that they should not allow anyone whom you dislike to sit on your bedding.** If they do that, then hit them, but in a manner that does not cause injury or leave a mark. Their rights over you are that you should provide for them and clothe them in a reasonable manner. I have left behind you something which, if you adhere to it, you will never go astray: the Book of Allah. You will be asked about me. What will you say?’ They said: ‘We bear witness that you have conveyed (the message) and fulfilled (your duty) and offered sincere advice.’ He gestured with his forefinger towards the sky and then towards the people, (and said:) ‘O Allah, bear witness, O Allah bear witness,’ three times. Then Bilal called the Adhan, then the Iqamah, and he prayed Zuhr. Then he made Iqamah and prayed ‘Asr, and he did not offer any prayer between them. Then the Messenger of Allah (ﷺ) rode until he came to the place of standing, and he made his she-camel face Sakharat*** with the path in the sand in front of him, and he faced the Qiblah, then he remained standing until the sun had set and the afterglow had lessened somewhat, when the disk of the sun disappeared. Then he seated Usamah bin Zaid behind him and the Messenger of Allah (ﷺ) set out. He pulled Qaswa’s reins tight until her head was touching the saddle, and he gestured with his right hand: ‘O people, calmly, calmly!’ Every time he came to a hill, he released the reins a little so that she could climb. Then he came to Muzdalifah where he prayed Maghrib and ‘Isha’ with one Adhan and two Iqamah, offering no prayer in between. Then the Messenger of Allah (ﷺ) lay down until dawn came, and he prayed Fajr, when he saw that morning had come, with one Adhan and one Iqamah. Then he rode Qaswa’ until he came to Al-Mash’ar Al-Haram. He climbed it and praised Allah and proclaimed His greatness and that He is the only One worthy of worship. Then he remained standing until it had become quite bright, then he moved on before the sun rose. He seated Fadl bin ‘Abbas behind him, who was a man with lovely hair, white and handsome. When the Messenger of Allah (ﷺ) moved on, he passed some women riding camels. Fadl started to look at them, so the Messenger of Allah (ﷺ) put his hand on the other side. Fadl turned his face to the other side to look. When he came to Muhassir, he sped up a little. Then he followed the middle road that brings you out to the biggest Pillar, until he reached the Pillar that is by the tree. He threw seven pebbles, saying the Takbir with each throw, pebbles suitable for Khadhf (i.e., the size of a chickpea) throwing from the bottom of the valley. Then he went to the place of slaughter, and slaughtered sixty-three camels with his own hand. Then he handed it over to ‘Ali who slaughtered the rest, and he gave him a share in his sacrificial animal. Then he ordered that a piece from each camel be brought; (the pieces) were put in a pot and cooked, and they (the Prophet (ﷺ) and ‘Ali) ate from the meat and drank from the soup. Then the Messenger of Allah (ﷺ) hastened to the House, and prayed Zuhr in Makkah. He came to Banu ‘Abdul-Muttalib, who were providing water to the pilgrims at Zamzam, and said: ‘Draw me some water, O Banu ‘Abdul-Muttalib. Were it not that the people would overwhelm you, I would have drawn water with you.’ So they drew up a bucket for him and he drank from it.’” * It appears that the speaker is Ja’far bin Muhammad who is narrating from his father, from Jabir. **And they say that the meaning if ‘your furniture’ or, ‘your special place’ in which case the objective is to say that the wife is not to admit anyone in the house whom the husband would be displeased with. ***Sakharat plural of Sakhrah rock or boulder. Nawawi said: “They are the rocks that lay at the base of the Mount of Mercy, and it is the mount in the middle of ‘Arafat.”}}
\hadithdefcmd{ibnmajah}{3075}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنِي يَحْيَى بْنُ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لِلْحَجِّ عَلَى أَنْوَاعٍ ثَلاَثَةٍ فَمِنَّا مَنْ أَهَلَّ بِحَجٍّ وَعُمْرَةٍ مَعًا وَمِنَّا مَنْ أَهَلَّ بِحَجٍّ مُفْرَدٍ وَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ مُفْرَدَةٍ ‏.‏ فَمَنْ كَانَ أَهَلَّ بِحَجٍّ وَعُمْرَةٍ مَعًا لَمْ يَحْلِلْ مِنْ شَىْءٍ مِمَّا حَرُمَ مِنْهُ حَتَّى يَقْضِيَ مَنَاسِكَ الْحَجِّ وَمَنْ أَهَلَّ بِالْحَجِّ مُفْرَدًا لَمْ يَحْلِلْ مِنْ شَىْءٍ مِمَّا حَرُمَ مِنْهُ حَتَّى يَقْضِيَ مَنَاسِكَ الْحَجِّ وَمَنْ أَهَلَّ بِعُمْرَةٍ مُفْرَدَةٍ فَطَافَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ حَلَّ مَا حَرُمَ مِنْهُ حَتَّى يَسْتَقْبِلَ حَجًّا ‏.‏\hadithno{3075}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Fouad Abd al-Baqi: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“We went out with the Messenger of Allah (ﷺ) for Hajj in three ways. Some of us began the Talbiyah for Hajj and ‘Umrah together, some of us began the Talbiyah for Hajj on its own, and some of us began the Talbiyah for ‘Umrah on its own. Those who began the Talbiyah for Hajj and ‘Umrah together did not exit Ihram at all until they had completed the rites of Hajj. Those who began the Talbiyah for Hajj on its own did not exit ihram at all until they had completed the rites of Hajj. And those who began the Talbiyah for ‘Umrah on its own circumambulated the House and ran between Safa and Marwah, then whatever had been forbidden to them became permissible until the time for Hajj came.”}}
\hadithdefcmd{ibnmajah}{3076}{حَدَّثَنَا الْقَاسِمُ بْنُ مُحَمَّدِ بْنِ عَبَّادٍ الْمُهَلَّبِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، حَدَّثَنَا سُفْيَانُ، قَالَ حَجَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ثَلاَثَ حَجَّاتٍ حِجَّتَيْنِ قَبْلَ أَنْ يُهَاجِرَ وَحَجَّةً بَعْدَ مَا هَاجَرَ مِنَ الْمَدِينَةِ وَقَرَنَ مَعَ حَجَّتِهِ عُمْرَةً وَاجْتَمَعَ مَا جَاءَ بِهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَمَا جَاءَ بِهِ عَلِيٌّ مِائَةَ بَدَنَةٍ مِنْهَا جَمَلٌ لأَبِي جَهْلٍ فِي أَنْفِهِ بُرَةٌ مِنْ فِضَّةٍ فَنَحَرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِيَدِهِ ثَلاَثًا وَسِتِّينَ وَنَحَرَ عَلِيٌّ مَا غَبَرَ ‏.‏ قِيلَ لَهُ مَنْ ذَكَرَهُ قَالَ جَعْفَرٌ عَنْ أَبِيهِ عَنْ جَابِرٍ وَابْنُ أَبِي لَيْلَى عَنِ الْحَكَمِ عَنْ مِقْسَمٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{3076}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Sufyan said:“The Messenger of Allah (ﷺ) performed Hajj three times, twice before he emigrated, and once after he had emigrated, and once after he had emigrated to Al-Madinah. He performed ‘Umrah along with his Hajj. The total number of camels brought by the Prophet (ﷺ) and ‘Ali was one hundred. Among them was a (male) camel belonging to Abu Jahl, which had a silver ring in its nose. The Prophet (ﷺ) slaughtered sixty-three with his own hand, and ‘Ali slaughtered the rest.”}}
\hadithdefcmd{ibnmajah}{3077}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَابْنُ، عُلَيَّةَ عَنْ حَجَّاجِ بْنِ أَبِي عُثْمَانَ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي عِكْرِمَةُ، حَدَّثَنِي الْحَجَّاجُ بْنُ عَمْرٍو الأَنْصَارِيُّ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ كُسِرَ أَوْ عَرِجَ فَقَدْ حَلَّ وَعَلَيْهِ حَجَّةٌ أُخْرَى ‏"‏ ‏.‏ فَحَدَّثْتُ بِهِ ابْنَ عَبَّاسٍ، وَأَبَا، هُرَيْرَةَ فَقَالاَ صَدَقَ ‏.‏\hadithno{3077}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Ikrimah:“Hajjaj bin ‘Amr Ansari narrated to me, he said: ‘I heard the Prophet (ﷺ) say: “Whoever breaks a bone or becomes lame, has exited Ihram, but he must perform another Hajj.”}}
\hadithdefcmd{ibnmajah}{3078}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، - مَوْلَى أُمِّ سَلَمَةَ - قَالَ سَأَلْتُ الْحَجَّاجَ بْنَ عَمْرٍو عَنْ حَبْسِ الْمُحْرِمِ فَقَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كُسِرَ أَوْ مَرِضَ أَوْ عَرِجَ فَقَدْ حَلَّ وَعَلَيْهِ الْحَجُّ مِنْ قَابِلٍ ‏"‏ ‏.‏ قَالَ عِكْرِمَةُ فَحَدَّثْتُ بِهِ ابْنَ عَبَّاسٍ، وَأَبَا، هُرَيْرَةَ فَقَالاَ صَدَقَ ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ فَوَجَدْتُهُ فِي جُزْءِ هِشَامٍ صَاحِبِ الدَّسْتَوَائِيِّ فَأَتَيْتُ بِهِ مَعْمَرًا فَقَرَأَ عَلَىَّ أَوْ قَرَأْتُ عَلَيْهِ ‏.‏\hadithno{3078}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Ikrimah, from ‘Abdullah bin Rafi’, the freed slave of Umm Salamah, that he said:“I asked Hajjaj bin ‘Amr about a Muhrim being prevented (from completing Hajj). He said: ‘The Messenger of Allah (ﷺ) said: “Whoever breaks a bone, falls sick or becomes lame, has exited Ihram, and he has to perform Hajj the following year.” 'Ikrimah (a subnarrator) said: I narrated it to Ibn 'Abbas and Abu Hurairah. They said he spoke the truth}}
\hadithdefcmd{ibnmajah}{3079}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْقِلٍ، قَالَ قَعَدْتُ إِلَى كَعْبِ بْنِ عُجْرَةَ فِي الْمَسْجِدِ فَسَأَلْتُهُ عَنْ هَذِهِ الآيَةِ، ‏\{فَفِدْيَةٌ مِنْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ\}‏ ‏.‏ قَالَ كَعْبٌ فِيَّ أُنْزِلَتْ كَانَ بِي أَذًى مِنْ رَأْسِي فَحُمِلْتُ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَالْقَمْلُ يَتَنَاثَرُ عَلَى وَجْهِي فَقَالَ ‏"‏ مَا كُنْتُ أُرَى الْجُهْدَ بَلَغَ مِنْكَ مَا أَرَى أَتَجِدُ شَاةً ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{فَفِدْيَةٌ مِنْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ\}‏ ‏.‏ قَالَ فَالصَّوْمُ ثَلاَثَةُ أَيَّامٍ وَالصَّدَقَةُ عَلَى سِتَّةِ مَسَاكِينَ لِكُلِّ مِسْكِينٍ نِصْفُ صَاعٍ مِنْ طَعَامٍ وَالنُّسُكُ شَاةٌ ‏.‏\hadithno{3079}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Abdullah bin Ma’qil said:“I sat with Ka’b bin ‘Ujrah in the mosque and asked him about this Verse: ‘He must pay a compensation of either fasting (three days) or giving charity (feeding six poor persons) or offering sacrifice (one sheep).’ [2:196] Ka’b said: it was revealed concerning me. I had trouble with my head, so I was carried to the Messenger of Allah (ﷺ), with lice crawling on my face. He said: ‘I did not think that you were suffering as much as I see. Do you have a sheep?’ I said: ‘No.’ Then this Verse was revealed: “He must pay a Fidyah (ransom) of either fasting (three days) or giving Sadaqah (charity – feeding six poor persons) or offering sacrifice (one sheep).” [2:196] He said: ‘Fasting is three days, charity is to be given to six poor persons, giving each one half of a Sa’ of food, and the sacrifice is a sheep.’”}}
\hadithdefcmd{ibnmajah}{3080}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ أَمَرَنِي النَّبِيُّ ـ صلى الله عليه وسلم ـ حِينَ آذَانِي الْقَمْلُ أَنْ أَحْلِقَ رَأْسِي وَأَصُومَ ثَلاَثَةَ أَيَّامٍ أَوْ أُطْعِمَ سِتَّةَ مَسَاكِينَ وَقَدْ عَلِمَ أَنْ لَيْسَ عِنْدِي مَا أَنْسُكُ ‏.‏\hadithno{3080}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ka’b bin ‘Ujrah said:“The Prophet (ﷺ) commanded me, when I was suffering, from live, to shave my head and fast for three days or feed six poor persons. He knew that I did not have an animal I could sacrifice.”}}
\hadithdefcmd{ibnmajah}{3081}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ احْتَجَمَ وَهُوَ صَائِمٌ مُحْرِمٌ ‏.‏\hadithno{3081}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) was treated with cupping when he was fasting and in the state of Ihram}}
\hadithdefcmd{ibnmajah}{3082}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي الضَّيْفِ، عَنِ ابْنِ خُثَيْمٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ احْتَجَمَ وَهُوَ مُحْرِمٌ مِنْ رَهْصَةٍ أَخَذَتْهُ ‏.‏\hadithno{3082}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) was treated with cupping when he was in the state of Ihram, because he did not feel well}}
\hadithdefcmd{ibnmajah}{3083}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ فَرْقَدٍ السَّبَخِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَدَّهِنُ رَأْسَهُ بِالزَّيْتِ وَهُوَ مُحْرِمٌ غَيْرَ الْمُقَتَّتِ ‏.‏\hadithno{3083}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) used to put oil on his head when he was in the state of Ihram, but not oil that was perfumed}}
\hadithdefcmd{ibnmajah}{3084}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، أَوْقَصَتْهُ رَاحِلَتُهُ وَهُوَ مُحْرِمٌ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْهِ وَلاَ تُخَمِّرُوا وَجْهَهُ وَلاَ رَأْسَهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، مِثْلَهُ إِلاَّ أَنَّهُ قَالَ أَعْقَصَتْهُ رَاحِلَتُهُ ‏.‏ وَقَالَ ‏"‏ لاَ تُقَرِّبُوهُ طِيبًا فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏\hadithno{3084}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Abbas that a man’s neck was broken by his mount (from falling) while he was in the state of Ihram. The Prophet (ﷺ) said:“Wash him with water and lote leaves, and shroud him in his two garments, but do not cover his face or his head, for he will be raised on the Day of Resurrection reciting the Talbiyah.” Another chain reports the same except a different verb was used for the break of the neck and he said "do not bring him near perfume, for he will be raised on the Day of Resurrection reciting the Talbiyah.”}}
\hadithdefcmd{ibnmajah}{3085}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمَّارٍ، عَنْ جَابِرٍ، قَالَ جَعَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الضَّبُعِ يُصِيبُهُ الْمُحْرِمُ كَبْشًا وَجَعَلَهُ مِنَ الصَّيْدِ ‏.‏\hadithno{3085}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) stipulated (the penalty of) a man for a hyena killed by a man in Ihram, and he considered it as game.”}}
\hadithdefcmd{ibnmajah}{3086}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْقَطَّانُ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ بْنُ مَوْهَبٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ أَبِي الْمُهَزِّمِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ فِي بَيْضِ النَّعَامِ يُصِيبُهُ الْمُحْرِمُ ‏ "‏ ثَمَنُهُ ‏"‏ ‏.‏\hadithno{3086}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said, concerning an ostrich egg taken by a Muhrim:“Its cost (must be paid as a penalty).”}}
\hadithdefcmd{ibnmajah}{3087}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ خَمْسٌ فَوَاسِقُ يُقْتَلْنَ فِي الْحِلِّ وَالْحَرَمِ الْحَيَّةُ وَالْغُرَابُ الأَبْقَعُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ وَالْحِدَأَةُ ‏"‏ ‏.‏\hadithno{3087}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said:“There are five vermin that might be killed whether one is in or outside the sacred precincts: the snake, the speckled crow, the mouse, the vicious dog, and the kite.”}}
\hadithdefcmd{ibnmajah}{3088}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ خَمْسٌ مِنَ الدَّوَابِّ لاَ جُنَاحَ عَلَى مَنْ قَتَلَهُنَّ - أَوْ قَالَ فِي قَتْلِهِنَّ - وَهُوَ حَرَامٌ الْعَقْرَبُ وَالْغُرَابُ وَالْحِدَأَةُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{3088}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“There are five animals, for which there is no sin on a person if he kills them” – or he said: “if he kills them when in Ihram – the scorpion, the crow, the kite, the mouse and the vicious dog.”}}
\hadithdefcmd{ibnmajah}{3089}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ يَقْتُلُ الْمُحْرِمُ الْحَيَّةَ وَالْعَقْرَبَ وَالسَّبُعَ الْعَادِيَ وَالْكَلْبَ الْعَقُورَ وَالْفَأْرَةَ الْفُوَيْسِقَةَ ‏"‏ ‏.‏ فَقِيلَ لَهُ لِمَ قِيلَ لَهَا الْفُوَيْسِقَةُ قَالَ لأَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ اسْتَيْقَظَ لَهَا وَقَدْ أَخَذَتِ الْفَتِيلَةَ لِتُحْرِقَ بِهَا الْبَيْتَ ‏.‏\hadithno{3089}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed that the Prophet (ﷺ) said:‘The one in Ihram may kill the snake, the scorpion, the aggressive predator, the vicious dog and the harmful mouse.” It was said to him: “Why is it said that they are harmful?” He said:* “Because the Messenger of Allah (ﷺ) woke up because of one, and it had taken the wick (of the lamp) to burn down the house.”}}
\hadithdefcmd{ibnmajah}{3090}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، جَمِيعًا عَنِ ابْنِ شِهَابٍ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَنْبَأَنَا صَعْبُ بْنُ جَثَّامَةَ، قَالَ مَرَّ بِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَنَا بِالأَبْوَاءِ أَوْ بِوَدَّانَ فَأَهْدَيْتُ لَهُ حِمَارَ وَحْشٍ فَرَدَّهُ عَلَىَّ فَلَمَّا رَأَى فِي وَجْهِيَ الْكَرَاهِيَةَ ‏.‏ قَالَ ‏ "‏ إِنَّهُ لَيْسَ بِنَا رَدٌّ عَلَيْكَ وَلَكِنَّا حُرُمٌ ‏"‏ ‏.‏\hadithno{3090}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Sa;b bin Jaththamah told us: ‘The Messenger of Allah (ﷺ) passed by me when I was in Abwa’ or Waddan, and I gave him some meat of a wild donkey, but he gave it back to me, and when he saw from my face that I was upset, he said: ‘The only reason that we are giving it back is that we are in Ihram.’”}}
\hadithdefcmd{ibnmajah}{3091}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عِمْرَانُ بْنُ مُحَمَّدِ بْنِ أَبِي لَيْلَى، عَنْ أَبِيهِ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ أُتِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِلَحْمِ صَيْدٍ وَهُوَ مُحْرِمٌ فَلَمْ يَأْكُلْهُ ‏.‏\hadithno{3091}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Ali bin Abu Talib said:“The Prophet (ﷺ) brought some meat from some game when he was in Ihram, and he did not eat it.”}}
\hadithdefcmd{ibnmajah}{3092}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَعْطَاهُ حِمَارَ وَحْشٍ وَأَمَرَهُ أَنْ يُفَرِّقَهُ فِي الرِّفَاقِ وَهُمْ مُحْرِمُونَ ‏.‏\hadithno{3092}\hadithgrade{Al-Albani: Isnaad Malool; Muhammad Fouad Abd al-Baqi: Isnaad Malool; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Talhah bin ‘Ubaidullah that the Prophet (ﷺ) gave him some wild donkey meat, and told him to distribute it among his Companions, who were in Ihram}}
\hadithdefcmd{ibnmajah}{3093}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ خَرَجْتُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ زَمَنَ الْحُدَيْبِيَةِ فَأَحْرَمَ أَصْحَابُهُ وَلَمْ أُحْرِمْ فَرَأَيْتُ حِمَارًا فَحَمَلْتُ عَلَيْهِ وَاصْطَدْتُهُ فَذَكَرْتُ شَأْنَهُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَذَكَرْتُ أَنِّي لَمْ أَكُنْ أَحْرَمْتُ وَأَنِّي إِنَّمَا اصْطَدْتُهُ لَكَ فَأَمَرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَصْحَابَهُ فَأَكَلُوا وَلَمْ يَأْكُلْ مِنْهُ حِينَ أَخْبَرْتُهُ أَنِّي اصْطَدْتُهُ لَهُ ‏.‏\hadithno{3093}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin Abu Qatadah that his father said:“I went out with the Messenger of Allah (ﷺ) at the time of Hudaibiyah, and his Companions entered Ihram, but I did not. I saw a donkey do I hunted it. I mentioned that to the Messenger of Allah (ﷺ) and told him: ‘I had not entered Ihram, and I was hunting it for you.’ The Prophet (ﷺ) told his Companions to eat it, but he did not eat from it, because I told him that I had hunted it for him.”}}
\hadithdefcmd{ibnmajah}{3094}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُهْدِي مِنَ الْمَدِينَةِ فَأَفْتِلُ قَلاَئِدَ هَدْيِهِ ثُمَّ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُ الْمُحْرِمُ ‏.‏\hadithno{3094}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{‘Aishah the wife of the Prophet (ﷺ) said; “The Messenger of Allah (ﷺ) used to send the sacrificial animal from Al-Madinah, and I would twist the garlands for his sacrificial animal, then, he would not (because of that) avoid the things that the one in Ihram avoids.”}}
\hadithdefcmd{ibnmajah}{3095}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ كُنْتُ أَفْتِلُ الْقَلاَئِدَ لِهَدْىِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَيُقَلِّدُ هَدْيَهُ ثُمَّ يَبْعَثُ بِهِ ثُمَّ يُقِيمُ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُهُ الْمُحْرِمُ ‏.‏\hadithno{3095}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah the wife of the Prophet (ﷺ) said:“I used to twist the garlands for the sacrificial animal of the Prophet (ﷺ), and his sacrificial animal would be garlanded and sent (to Makkah), and he would stay (in Al-Madinah) without avoiding any of the things that the one in Ihram avoids.”}}
\hadithdefcmd{ibnmajah}{3096}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ أَهْدَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّةً غَنَمًا إِلَى الْبَيْتِ فَقَلَّدَهَا ‏.‏\hadithno{3096}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“On one occasion the Messenger of Allah (ﷺ) sent sheep to the House, and he garlanded them.”}}
\hadithdefcmd{ibnmajah}{3097}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ الأَعْرَجِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَشْعَرَ الْهَدْىَ فِي السَّنَامِ الأَيْمَنِ وَأَمَاطَ عَنْهُ الدَّمَ ‏.‏ وَقَالَ عَلِيٌّ فِي حَدِيثِهِ بِذِي الْحُلَيْفَةِ وَقَلَّدَ نَعْلَيْنِ ‏.‏\hadithno{3097}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) marked the sacrificial animal on the right side of the hump and wiped away the blood}}
\hadithdefcmd{ibnmajah}{3098}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ، عَنْ أَفْلَحَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَلَّدَ وَأَشْعَرَ وَأَرْسَلَ بِهَا وَلَمْ يَجْتَنِبْ مَا يَجْتَنِبُ الْمُحْرِمُ ‏.‏\hadithno{3098}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) garlanded, and marked, and sent (the sacrificial animals), but he did not avoid anything that the one in Ihram avoids}}
\hadithdefcmd{ibnmajah}{3099}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ أَقُومَ عَلَى بُدْنِهِ وَأَنْ أَقْسِمَ جِلاَلَهَا وَجُلُودَهَا وَأَنْ لاَ أُعْطِيَ الْجَازِرَ مِنْهَا شَيْئًا وَقَالَ ‏ "‏ نَحْنُ نُعْطِيهِ ‏"‏ ‏.‏\hadithno{3099}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Ali bin Abu Talib said:“The Messenger of Allah (ﷺ) commanded me to look after his sacrificial camels, to share out their covers and skins, and not to give the butcher any of it. He said: ‘We will give him (his wages).’”}}
\hadithdefcmd{ibnmajah}{3100}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَهْدَى فِي بُدْنِهِ جَمَلاً لأَبِي جَهْلٍ بُرَتُهُ مِنْ فِضَّةٍ ‏.‏\hadithno{3100}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that among the sacrificial animals the Prophet (ﷺ) included a (male) camel belonging to Abu Jahl, which had a silver nose ring}}
\hadithdefcmd{ibnmajah}{3101}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا مُوسَى بْنُ عُبَيْدَةَ، عَنْ إِيَاسِ بْنِ سَلَمَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ فِي بُدْنِهِ جَمَلٌ ‏.‏\hadithno{3101}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Iyas bin Salamah, from his father, that the Prophet (ﷺ) had a (male) camel among his sacrificial animals}}
\hadithdefcmd{ibnmajah}{3102}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يَحْيَى بْنُ يَمَانٍ، عَنْ سُفْيَانَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ اشْتَرَى هَدْيَهُ مِنْ قُدَيْدٍ ‏.‏\hadithno{3102}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) bought his sacrificial animal from Qudaid}}
\hadithdefcmd{ibnmajah}{3103}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَأَى رَجُلاً يَسُوقُ بَدَنَةً فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ إِنَّهَا بَدَنَةٌ ‏.‏ قَالَ ‏"‏ ارْكَبْهَا وَيْحَكَ ‏"‏ ‏.‏\hadithno{3103}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) saw a man driving a camel and said:“Ride it.” He said: “It is a sacrificial animal.” He said: “Ride it, woe to you!”}}
\hadithdefcmd{ibnmajah}{3104}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، - صَاحِبِ الدَّسْتَوَائِيِّ - عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ مُرَّ عَلَيْهِ بِبَدَنَةٍ فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ إِنَّهَا بَدَنَةٌ ‏.‏ قَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ فَرَأَيْتُهُ رَاكِبَهَا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي عُنُقِهَا نَعْلٌ ‏.‏\hadithno{3104}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) was brought a sacrificial animal and he said (to the man driving the animal):“Ride it.” He said: “It is a sacrificial animal.” He said: “Ride it.” He said: “I saw him riding it with the Prophet (ﷺ), and there was a sandal (tied) around its neck.”}}
\hadithdefcmd{ibnmajah}{3105}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ سِنَانِ بْنِ سَلَمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ ذُؤَيْبًا الْخُزَاعِيَّ، حَدَّثَ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَبْعَثُ مَعَهُ بِالْبُدْنِ ثُمَّ يَقُولُ ‏ "‏ إِذَا عَطِبَ مِنْهَا شَىْءٌ فَخَشِيتَ عَلَيْهِ مَوْتًا فَانْحَرْهَا ثُمَّ اغْمِسْ نَعْلَهَا فِي دَمِهَا ثُمَّ اضْرِبْ صَفْحَتَهَا وَلاَ تَطْعَمْ مِنْهَا أَنْتَ وَلاَ أَحَدٌ مِنْ أَهْلِ رُفْقَتِكَ ‏"‏ ‏.‏\hadithno{3105}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Abbas that Dhu’aib Al-Khuza’i narrated that the Prophet (ﷺ) used to send the sacrificial animals with him, then he would say:“If any of them becomes unfit and you are afraid that it will die, then slaughter it, dip the sandal (tied around its neck) in its blood and place it on its side, but neither you nor any of your companions should eat anything from it.”}}
\hadithdefcmd{ibnmajah}{3106}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ نَاجِيَةَ الْخُزَاعِيِّ، - قَالَ عَمْرٌو فِي حَدِيثِهِ وَكَانَ صَاحِبَ بُدْنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ - قَالَ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَصْنَعُ بِمَا عَطِبَ مِنَ الْبُدْنِ قَالَ ‏ "‏ انْحَرْهُ وَاغْمِسْ نَعْلَهُ فِي دَمِهِ ثُمَّ اضْرِبْ صَفْحَتَهُ وَخَلِّ بَيْنَهُ وَبَيْنَ النَّاسِ فَلْيَأْكُلُوهُ ‏"‏ ‏.‏\hadithno{3106}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Najiyah Al-Khuza’i – in his narration, ‘Amr (one of the narrators) said that he was the one who looked after the sacrificial animals of the Prophet (ﷺ) – said:“I said: ‘O Messenger of Allah, what should I do with those sacrificial animals that become unfit?’ He said: ‘Slaughter them, dip its sandal in its blood, then place it on its side, and leave them for the people to eat.’”}}
\hadithdefcmd{ibnmajah}{3107}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، عَنْ عُثْمَانَ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَلْقَمَةَ بْنِ نَضْلَةَ، قَالَ تُوُفِّيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبُو بَكْرٍ وَعُمَرُ وَمَا تُدْعَى رِبَاعُ مَكَّةَ إِلاَّ السَّوَائِبَ مَنِ احْتَاجَ سَكَنَ وَمَنِ اسْتَغْنَى أَسْكَنَ ‏.‏\hadithno{3107}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Alqamah bin Nadlah said:“The Messenger of Allah (ﷺ), Abu Bakr and ‘Umar died, and the houses in Makkah were still called free. Whoever needed to, lived there, and whoever had no need of them allowed others to live there (without asking for rent).”}}
\hadithdefcmd{ibnmajah}{3108}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، أَخْبَرَنِي عُقَيْلٌ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، أَنَّهُ قَالَ إِنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَدِيِّ بْنِ الْحَمْرَاءِ قَالَ لَهُ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ عَلَى رَاحِلَتِهِ وَاقِفٌ بِالْحَزْوَرَةِ يَقُولُ ‏ "‏ وَاللَّهِ إِنَّكِ لَخَيْرُ أَرْضِ اللَّهِ وَأَحَبُّ أَرْضِ اللَّهِ إِلَيَّ وَاللَّهِ لَوْلاَ أَنِّي أُخْرِجْتُ مِنْكِ مَا خَرَجْتُ ‏"‏ ‏.‏\hadithno{3108}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Salamah bin ‘Abdur-Rahman bin ‘Awf narrated that ‘Abdullah bin ‘Adiy bin Hamra’ said to him:“I saw the Messenger of Allah (ﷺ), when he was on his she-camel, standing in Al-Hazwarah* saying: ‘By Allah, you are the best land of Allah, and the dearest of the land of Allah to me. By Allah, had I not been expelled from you I would never have left.’” *A place in Makkah}}
\hadithdefcmd{ibnmajah}{3109}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبَانُ بْنُ صَالِحٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمِ بْنِ يَنَّاقٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، قَالَتْ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَخْطُبُ عَامَ الْفَتْحِ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّ اللَّهَ حَرَّمَ مَكَّةَ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ فَهِيَ حَرَامٌ إِلَى يَوْمِ الْقِيَامَةِ لاَ يُعْضَدُ شَجَرُهَا وَلاَ يُنَفَّرُ صَيْدُهَا وَلاَ يَأْخُذُ لُقَطَتَهَا إِلاَّ مُنْشِدٌ ‏"‏ ‏.‏ فَقَالَ الْعَبَّاسُ إِلاَّ الإِذْخِرَ فَإِنَّهُ لِلْبُيُوتِ وَالْقُبُورِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏ ‏.‏\hadithno{3109}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Safiyyah bint Shaibah said:“I heard the Prophet (ﷺ) delivering a sermon in the Year of the Conquest (of Makkah), and he said: ‘O people, Allah made Makkah sacred the day He created the heavens and the earth, and it is sacred until the Day of Resurrection. Its trees are not to be cut, its game is not to be disturbed, and its lost property is not to be taken except by one who will announce it.’‘Abbas said: ‘Except for Idhkhir (a kind of fragrant grass), for it is (used) for houses and graves.’ The messenger of Allah (ﷺ) said: ‘Except for Idhkhir.’”}}
\hadithdefcmd{ibnmajah}{3110}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَابْنُ الْفُضَيْلِ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ سَابِطٍ، عَنْ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ الْمَخْزُومِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَزَالُ هَذِهِ الأُمَّةُ بِخَيْرٍ مَا عَظَّمُوا هَذِهِ الْحُرْمَةَ حَقَّ تَعْظِيمِهَا فَإِذَا ضَيَّعُوا ذَلِكَ هَلَكُوا ‏"‏ ‏.‏\hadithno{3110}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Ayyash bin Abu Rabi’ah (Makhzumi) that the Messenger of Allah (ﷺ) said:‘The goodness of this nation will not cease as long as they revere this sanctuary* as it is due. But when they lose that reverence, they will be doomed.”}}
\hadithdefcmd{ibnmajah}{3111}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ الإِيمَانَ لَيَأْرِزُ إِلَى الْمَدِينَةِ كَمَا تَأْرِزُ الْحَيَّةُ إِلَى جُحْرِهَا ‏"‏ ‏.‏\hadithno{3111}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{it was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Faith will retreat to Al-Madinah as a snake retreats to its hole.”}}
\hadithdefcmd{ibnmajah}{3112}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَمُوتَ بِالْمَدِينَةِ فَلْيَفْعَلْ فَإِنِّي أَشْهَدُ لِمَنْ مَاتَ بِهَا ‏"‏ ‏.‏\hadithno{3112}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:‘Whoever among you can die in Al-Madinah, let him do so, for I will bear witness in favor of those who die there.”}}
\hadithdefcmd{ibnmajah}{3113}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ اللَّهُمَّ إِنَّ إِبْرَاهِيمَ خَلِيلُكَ وَنَبِيُّكَ وَإِنَّكَ حَرَّمْتَ مَكَّةَ عَلَى لِسَانِ إِبْرَاهِيمَ اللَّهُمَّ وَأَنَا عَبْدُكَ وَنَبِيُّكَ وَإِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا ‏"‏ ‏.‏ قَالَ أَبُو مَرْوَانَ لاَبَتَيْهَا حَرَّتَىِ الْمَدِينَةِ ‏.‏\hadithno{3113}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“O Allah! Ibrahim was Your Friend and Prophet, and You declared Makkah to be sacred through Ibrahim. O Allah! I am Your slave and Prophet, and I declare what is between its two lava fields to be sacred.”}}
\hadithdefcmd{ibnmajah}{3114}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَرَادَ أَهْلَ الْمَدِينَةِ بِسُوءٍ أَذَابَهُ اللَّهُ كَمَا يَذُوبُ الْمِلْحُ فِي الْمَاءِ ‏"‏ ‏.‏\hadithno{3114}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever wishes bad upon the people of Al-Madinah, Allah will cause him to melt as salt melts in water.”}}
\hadithdefcmd{ibnmajah}{3115}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ مِكْنَفٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ أُحُدًا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ وَهُوَ عَلَى تُرْعَةٍ مِنْ تُرَعِ الْجَنَّةِ وَعَيْرٌ عَلَى تُرْعَةٍ مِنْ تُرَعِ النَّارِ ‏"‏ ‏.‏\hadithno{3115}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin Miknaf said:“I heard Anas bin Malik say: ‘The Messenger of Allah (ﷺ) said: “Uhud is a mountain which loves us and we love it, and it stands at one of the gates of Paradise. And ‘Aer* stands at one of the gates of Hell.’”}}
\hadithdefcmd{ibnmajah}{3116}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنِ الشَّيْبَانِيِّ، عَنْ وَاصِلٍ الأَحْدَبِ، عَنْ شَقِيقٍ، قَالَ بَعَثَ رَجُلٌ مَعِيَ بِدَرَاهِمَ هَدِيَّةً إِلَى الْبَيْتِ ‏.‏ قَالَ فَدَخَلْتُ الْبَيْتَ وَشَيْبَةُ جَالِسٌ عَلَى كُرْسِيٍّ فَنَاوَلْتُهُ إِيَّاهَا ‏.‏ فَقَالَ أَلَكَ هَذِهِ قُلْتُ لاَ وَلَوْ كَانَتْ لِي لَمْ آتِكَ بِهَا ‏.‏ قَالَ أَمَا لَئِنْ قُلْتَ ذَلِكَ لَقَدْ جَلَسَ عُمَرُ بْنُ الْخَطَّابِ مَجْلِسَكَ الَّذِي جَلَسْتَ فِيهِ فَقَالَ لاَ أَخْرُجُ حَتَّى أَقْسِمَ مَالَ الْكَعْبَةِ بَيْنَ فُقَرَاءِ الْمُسْلِمِينَ ‏.‏ قُلْتُ مَا أَنْتَ بِفَاعِلٍ ‏.‏ قَالَ لأَفْعَلَنَّ ‏.‏ قَالَ وَلِمَ ذَاكَ قُلْتُ لأَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَدْ رَأَى مَكَانَهُ ‏.‏ وَأَبُو بَكْرٍ وَهُمَا أَحْوَجُ مِنْكَ إِلَى الْمَالِ فَلَمْ يُحَرِّكَاهُ ‏.‏ فَقَامَ كَمَا هُوَ فَخَرَجَ ‏.‏\hadithno{3116}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Shaqiq said:“A man sent some Dirham through me to the House.” He said: “I entered the House and Shaibah was sitting on a chair. I handed it (the money) to him and he said: ‘Is this yours?’ I said: ‘No, if it were mine I would not have given it to you.’ He said: ‘Since you say that, ‘Umar was sitting in the place where you are sitting now and said: “I will not go out until I distribute the wealth of the poor Muslims.” I said: “You will not do that.” He said: “I will certainly do that.” He said: “Why is that?” I said: “Because, the Prophet (ﷺ) and Abu Bakr saw where it was, and they had more need of the money than you do. But, they did not move it. Then, he stood up just as he was and went out.”}}
\hadithdefcmd{ibnmajah}{3117}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ زَيْدٍ الْعَمِّيِّ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَدْرَكَ رَمَضَانَ بِمَكَّةَ فَصَامَ وَقَامَ مِنْهُ مَا تَيَسَّرَ لَهُ كَتَبَ اللَّهُ لَهُ مِائَةَ أَلْفِ شَهْرِ رَمَضَانَ فِيمَا سِوَاهَا ‏.‏ وَكَتَبَ اللَّهُ لَهُ بِكُلِّ يَوْمٍ عِتْقَ رَقَبَةٍ وَكُلِّ لَيْلَةٍ عِتْقَ رَقَبَةٍ وَكُلِّ يَوْمٍ حُمْلاَنَ فَرَسٍ فِي سَبِيلِ اللَّهِ وَفِي كُلِّ يَوْمٍ حَسَنَةً وَفِي كُلِّ لَيْلَةٍ حَسَنَةً ‏"‏ ‏.‏\hadithno{3117}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Whoever is in Makkah when the month of Ramadan comes, and he fasts it and prays at night as much as he can, Allah will record for him (reward equivalent to that for) one hundred thousand months of Ramadan observed elsewhere. For each day Allah will record for him (reward equivalent to that for) freeing a slave, and for each day (reward equivalent to that for) providing a horse in the cause of Allah, and for every day merits and for every night merits.”}}
\hadithdefcmd{ibnmajah}{3118}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا دَاوُدُ بْنُ عَجْلاَنَ، قَالَ طُفْنَا مَعَ أَبِي عِقَالٍ فِي مَطَرٍ فَلَمَّا قَضَيْنَا طَوَافَنَا أَتَيْنَا خَلْفَ الْمَقَامِ فَقَالَ طُفْتُ مَعَ أَنَسِ بْنِ مَالِكٍ فِي مَطَرٍ فَلَمَّا قَضَيْنَا الطَّوَافَ أَتَيْنَا الْمَقَامَ فَصَلَّيْنَا رَكْعَتَيْنِ فَقَالَ لَنَا أَنَسٌ ‏ "‏ ائْتَنِفُوا الْعَمَلَ فَقَدْ غُفِرَ لَكُمْ ‏"‏ ‏.‏ هَكَذَا قَالَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَطُفْنَا مَعَهُ فِي مَطَرٍ ‏.‏\hadithno{3118}\hadithgrade{Al-Albani: Very Daif Isnaad; Muhammad Fouad Abd al-Baqi: Very Daif Isnaad; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Dawud bin ‘Ajlan said:“We performed Tawaf with Abu ‘Iqal in the rain, and when we finished our Tawaf, we came behind the Maqam. He said: I performed Tawaf with Anas bin Malik in the rain. When we finished the Tawaf, we came behind the Maqam and prayed two Rak’ah.’ Anas said to us: ‘Start your deeds anew, for you have been forgiven. This is what the Messenger of Allah (ﷺ) said to us when we performed Tawaf with him in the rain.’”}}
\hadithdefcmd{ibnmajah}{3119}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ حَفْصٍ الأُبُلِّيُّ، حَدَّثَنَا يَحْيَى بْنُ يَمَانٍ، عَنْ حَمْزَةَ بْنِ حَبِيبٍ الزَّيَّاتِ، عَنْ حُمْرَانَ بْنِ أَعْيَنَ، عَنْ أَبِي الطُّفَيْلِ، عَنْ أَبِي سَعِيدٍ، قَالَ حَجَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَصْحَابُهُ مُشَاةً مِنَ الْمَدِينَةِ إِلَى مَكَّةَ وَقَالَ ‏ "‏ ارْبُطُوا أَوْسَاطَكُمْ بِأُزُرِكُمْ ‏"‏ ‏.‏ وَمَشَى خِلْطَ الْهَرْوَلَةِ ‏.‏\hadithno{3119}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed said:“The Prophet (ﷺ) and his Companions performed Hajj walking from Al-Madinah to Makkah. He said: ‘Tie your lower garments around your waists,’ and he alternated between walking and jogging.”}}
