% Auto-generated chapter 43 for abudawud
% Hadiths in this chapter: 502

\hadithdefcmd{abudawud}{4773}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ الشَّعِيرِيُّ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ، - يَعْنِي ابْنَ عَمَّارٍ - قَالَ حَدَّثَنِي إِسْحَاقُ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ - قَالَ قَالَ أَنَسٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَحْسَنِ النَّاسِ خُلُقًا فَأَرْسَلَنِي يَوْمًا لِحَاجَةٍ فَقُلْتُ وَاللَّهِ لاَ أَذْهَبُ ‏.‏ وَفِي نَفْسِي أَنْ أَذْهَبَ لِمَا أَمَرَنِي بِهِ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَخَرَجْتُ حَتَّى أَمُرَّ عَلَى صِبْيَانٍ وَهُمْ يَلْعَبُونَ فِي السُّوقِ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَابِضٌ بِقَفَاىَ مِنْ وَرَائِي فَنَظَرْتُ إِلَيْهِ وَهُوَ يَضْحَكُ فَقَالَ ‏ "‏ يَا أُنَيْسُ اذْهَبْ حَيْثُ أَمَرْتُكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ أَنَا أَذْهَبُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ أَنَسٌ وَاللَّهِ لَقَدْ خَدَمْتُهُ سَبْعَ سِنِينَ أَوْ تِسْعَ سِنِينَ مَا عَلِمْتُ قَالَ لِشَىْءٍ صَنَعْتُ لِمَ فَعَلْتَ كَذَا وَكَذَا ‏.‏ وَلاَ لِشَىْءٍ تَرَكْتُ هَلاَّ فَعَلْتَ كَذَا وَكَذَا ‏.‏\hadithno{4773}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2310)}\hadithtrans{Anas said:the Messenger of Allah (ﷺ) was one of the best of men in character. One day he sent me to do something, and I said: I swore by Allah that I would not go. But in my heart I felt that I should go to do what the Prophet of Allah (ﷺ) had commanded me; so I went out and came upon some boys who were playing in the street. All of a sudden the Messenger of Allah (ﷺ) who had come up behind caught me by the back of the neck, and when I looked at him he was laughing. He said: Go where I ordered you, little Anas. I replied: Yes, I am going, Apostle of Allah! Anas said: I swear by Allah, I served him for seven or nine years, and he never said to me about a thing which I had done: Why did you do such and such? Nor about a thing which I left: why did not do such and such?}}
\hadithdefcmd{abudawud}{4774}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ خَدَمْتُ النَّبِيَّ صلى الله عليه وسلم عَشْرَ سِنِينَ بِالْمَدِينَةِ وَأَنَا غُلاَمٌ لَيْسَ كُلُّ أَمْرِي كَمَا يَشْتَهِي صَاحِبِي أَنْ أَكُونَ عَلَيْهِ مَا قَالَ لِي فِيهَا أُفٍّ قَطُّ وَمَا قَالَ لِي لِمَ فَعَلْتَ هَذَا أَوْ أَلاَ فَعَلْتَ هَذَا ‏.‏\hadithno{4774}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: I served the Prophet (ﷺ) at Medina for ten years. I was a boy. Every work that I did was not according to the desire of my master, but he never said to me: Fie, nor did he say to me: Why did you do this? or Why did you not do this?}}
\hadithdefcmd{abudawud}{4775}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ هِلاَلٍ، سَمِعَ أَبَاهُ، يُحَدِّثُ قَالَ قَالَ أَبُو هُرَيْرَةَ وَهُوَ يُحَدِّثُنَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَجْلِسُ مَعَنَا فِي الْمَجْلِسِ يُحَدِّثُنَا فَإِذَا قَامَ قُمْنَا قِيَامًا حَتَّى نَرَاهُ قَدْ دَخَلَ بَعْضَ بُيُوتِ أَزْوَاجِهِ فَحَدَّثَنَا يَوْمًا فَقُمْنَا حِينَ قَامَ فَنَظَرْنَا إِلَى أَعْرَابِيٍّ قَدْ أَدْرَكَهُ فَجَبَذَهُ بِرِدَائِهِ فَحَمَّرَ رَقَبَتَهُ قَالَ أَبُو هُرَيْرَةَ وَكَانَ رِدَاءً خَشِنًا فَالْتَفَتَ فَقَالَ لَهُ الأَعْرَابِيُّ احْمِلْ لِي عَلَى بَعِيرَىَّ هَذَيْنِ فَإِنَّكَ لاَ تَحْمِلُ لِي مِنْ مَالِكَ وَلاَ مِنْ مَالِ أَبِيكَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ وَأَسْتَغْفِرُ اللَّهَ لاَ وَأَسْتَغْفِرُ اللَّهَ لاَ وَأَسْتَغْفِرُ اللَّهَ لاَ أَحْمِلُ لَكَ حَتَّى تُقِيدَنِي مِنْ جَبْذَتِكَ الَّتِي جَبَذْتَنِي ‏"‏ ‏.‏ فَكُلُّ ذَلِكَ يَقُولُ لَهُ الأَعْرَابِيُّ وَاللَّهِ لاَ أَقِيدُكَهَا ‏.‏ فَذَكَرَ الْحَدِيثَ قَالَ ثُمَّ دَعَا رَجُلاً فَقَالَ لَهُ ‏"‏ احْمِلْ لَهُ عَلَى بَعِيرَيْهِ هَذَيْنِ عَلَى بَعِيرٍ شَعِيرًا وَعَلَى الآخَرِ تَمْرًا ‏"‏ ‏.‏ ثُمَّ الْتَفَتَ إِلَيْنَا فَقَالَ ‏"‏ انْصَرِفُوا عَلَى بَرَكَةِ اللَّهِ تَعَالَى ‏"‏ ‏.‏\hadithno{4775}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) used to sit with us in meetings and talk to us. When he stood up we also used to stand up and see him entering the house of one of his wives. One day he talked to us and we stood up as he stood up and we saw that an Arabi (a nomadic Arab) caught hold of him and gave his cloak a violent tug making his neck red. AbuHurayrah said: The cloak was coarse. He turned to him and the Arabi said to him: Load these two camels of mine, for you do not give me anything from your property or from your father's property. The Prophet (ﷺ) said to him: No, I ask Allah's forgiveness; no, I ask Allah's forgiveness; no, I ask Allah's forgiveness. I shall not give you the camel-load until you make amends for the way in which you tugged at me. Each time the Arabi said to him: I swear by Allah, I shall not do so. He then mentioned the rest of the tradition. He (the Prophet), then called a man and said to him: Load these two camels of his: one camel with barley and the other with dates. He then turned to us and said: Go on your way with the blessing of Allah}}
\hadithdefcmd{abudawud}{4776}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا قَابُوسُ بْنُ أَبِي ظَبْيَانَ، أَنَّ أَبَاهُ، حَدَّثَهُ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبَّاسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْهَدْىَ الصَّالِحَ وَالسَّمْتَ الصَّالِحَ وَالاِقْتِصَادَ جُزْءٌ مِنْ خَمْسَةٍ وَعِشْرِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{4776}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Good way, dignified good bearing and moderation are the twenty-fifth part of Prophecy}}
\hadithdefcmd{abudawud}{4777}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ سَعِيدٍ، - يَعْنِي ابْنَ أَبِي أَيُّوبَ - عَنْ أَبِي مَرْحُومٍ، عَنْ سَهْلِ بْنِ مُعَاذٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَظَمَ غَيْظًا - وَهُوَ قَادِرٌ عَلَى أَنْ يُنْفِذَهُ - دَعَاهُ اللَّهُ عَزَّ وَجَلَّ عَلَى رُءُوسِ الْخَلاَئِقِ يَوْمَ الْقِيَامَةِ حَتَّى يُخَيِّرَهُ اللَّهُ مِنَ الْحُورِ مَا شَاءَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ اسْمُ أَبِي مَرْحُومٍ عَبْدُ الرَّحْمَنِ بْنُ مَيْمُونٍ ‏.‏\hadithno{4777}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'adh ibn Anas: The Messenger of Allah (ﷺ) said: If anyone suppresses anger when he is in a position to give vent to it, Allah, the Exalted, will call him on the Day of Resurrection over the heads of all creatures, and ask him to choose any of the bright and large eyed maidens he wishes. Abu Dawud said: The name of the transmitter Abu Marhum is 'Abd al-Rahman b. Maimun}}
\hadithdefcmd{abudawud}{4778}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - عَنْ بِشْرٍ، - يَعْنِي ابْنَ مَنْصُورٍ - عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ سُوَيْدِ بْنِ وَهْبٍ، عَنْ رَجُلٍ، مِنْ أَبْنَاءِ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنْ أَبِيهِ قَالَ - قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَحْوَهُ قَالَ ‏"‏ مَلأَهُ اللَّهُ أَمْنًا وَإِيمَانًا ‏"‏ ‏.‏ لَمْ يَذْكُرْ قِصَّةَ ‏"‏ دَعَاهُ اللَّهُ ‏"‏ ‏.‏ زَادَ ‏"‏ وَمَنْ تَرَكَ لُبْسَ ثَوْبِ جَمَالٍ وَهُوَ يَقْدِرُ عَلَيْهِ ‏"‏ ‏.‏ قَالَ بِشْرٌ أَحْسِبُهُ قَالَ ‏"‏ تَوَاضُعًا كَسَاهُ اللَّهُ حُلَّةَ الْكَرَامَةِ وَمَنْ زَوَّجَ لِلَّهِ تَعَالَى تَوَّجَهُ اللَّهُ تَاجَ الْمُلْكِ ‏"‏ ‏.‏\hadithno{4778}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Suwaid b. Wahb quoted a son of a Companion of the Prophet (ﷺ) who said his father reported the Messenger of Allah (ﷺ) said:He then mentioned a similar tradition described above. This version has: Allah will fill his heart with security and faith. He did not mention the words "Allah will call him". This version further adds: He who gives up wearing beautiful garments when he is able to do so (out of humility, as Bishr's version has) will be clothed by Allah with the robe of honour, and he who marries for Allah's sake will be crowned by Allah with the crown of Kingdom}}
\hadithdefcmd{abudawud}{4779}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَعُدُّونَ الصُّرَعَةَ فِيكُمْ ‏"‏ ‏.‏ قَالُوا الَّذِي لاَ يَصْرَعُهُ الرِّجَالُ ‏.‏ قَالَ ‏"‏ لاَ وَلَكِنَّهُ الَّذِي يَمْلِكُ نَفْسَهُ عِنْدَ الْغَضَبِ ‏"‏ ‏.‏\hadithno{4779}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2608)}\hadithtrans{Abd Allah (b. Mas`ud) reported the Messenger of Allah (ﷺ) as saying:Whom do you consider a wrestler among you? The people replied: (the man) whom the men cannot defeat in wrestling. He said: No, it is he who controls himself when he is angry}}
\hadithdefcmd{abudawud}{4780}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ اسْتَبَّ رَجُلاَنِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَغَضِبَ أَحَدُهُمَا غَضَبًا شَدِيدًا حَتَّى خُيِّلَ إِلَىَّ أَنَّ أَنْفَهُ يَتَمَزَّعُ مِنْ شِدَّةِ غَضَبِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي لأَعْلَمُ كَلِمَةً لَوْ قَالَهَا لَذَهَبَ عَنْهُ مَا يَجِدُهُ مِنَ الْغَضَبِ ‏"‏ ‏.‏ فَقَالَ مَا هِيَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ يَقُولُ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الشَّيْطَانِ الرَّجِيمِ ‏"‏ ‏.‏ قَالَ فَجَعَلَ مُعَاذٌ يَأْمُرُهُ فَأَبَى وَمَحِكَ وَجَعَلَ يَزْدَادُ غَضَبًا ‏.‏\hadithno{4780}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: Two men reviled each other in the presence of the Prophet (ﷺ) and one of them became excessively angry so much so that I thought that his nose will break up on account of excess of anger. The Prophet (ﷺ) said: I know a phrase which, if he repeated, he could get rid of this angry feeling. They asked: What is it, Messenger of Allah? He replied: He should say: I seek refuge in Thee from the accursed devil. Mu'adh then began to ask him to do so, but he refused and persisted in quarrelling, and began to enhance his anger}}
\hadithdefcmd{abudawud}{4781}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ سُلَيْمَانَ بْنِ صُرَدَ، قَالَ اسْتَبَّ رَجُلاَنِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَجَعَلَ أَحَدُهُمَا تَحْمَرُّ عَيْنَاهُ وَتَنْتَفِخُ أَوْدَاجُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْرِفُ كَلِمَةً لَوْ قَالَهَا هَذَا لَذَهَبَ عَنْهُ الَّذِي يَجِدُ أَعُوذُ بِاللَّهِ مِنَ الشَّيْطَانِ الرَّجِيمِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ هَلْ تَرَى بِي مِنْ جُنُونٍ\hadithno{4781}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2382) Sahih Muslim (2610)}\hadithtrans{Sulaiman b. Surad said:Two men reviled each other in the presence of the Prophet (ﷺ). Then the eyes of one of them became red and his jugular veins swelled. The Apostle of Allah (ﷺ) said: I know a phrase by repeating which the man could get rid of the angry feelings: I seek refuge in Allah from the accursed devil. The man said: Do you see insanity in me}}
\hadithdefcmd{abudawud}{4782}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ أَبِي حَرْبِ بْنِ الأَسْوَدِ، عَنْ أَبِي ذَرٍّ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَنَا ‏ "‏ إِذَا غَضِبَ أَحَدُكُمْ وَهُوَ قَائِمٌ فَلْيَجْلِسْ فَإِنْ ذَهَبَ عَنْهُ الْغَضَبُ وَإِلاَّ فَلْيَضْطَجِعْ ‏"‏ ‏.‏\hadithno{4782}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuDharr: The Messenger of Allah (ﷺ) said to us: When one of you becomes angry while standing, he should sit down. If the anger leaves him, well and good; otherwise he should lie down}}
\hadithdefcmd{abudawud}{4783}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ دَاوُدَ، عَنْ بَكْرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ أَبَا ذَرٍّ بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا أَصَحُّ الْحَدِيثَيْنِ ‏.‏\hadithno{4783}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Bakr said:The Prophet (ﷺ) sent Mu`adh for some of his work. He then transmitted the rest of the tradition mentioned above. Abu Dawud said: This tradition is sounder of the two traditions}}
\hadithdefcmd{abudawud}{4784}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ، وَالْحَسَنُ بْنُ عَلِيٍّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو وَائِلٍ الْقَاصُّ، قَالَ دَخَلْنَا عَلَى عُرْوَةَ بْنِ مُحَمَّدِ بْنِ السَّعْدِيِّ فَكَلَّمَهُ رَجُلٌ فَأَغْضَبَهُ فَقَامَ فَتَوَضَّأَ ثُمَّ رَجَعَ وَقَدْ تَوَضَّأَ فَقَالَ حَدَّثَنِي أَبِي عَنْ جَدِّي عَطِيَّةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْغَضَبَ مِنَ الشَّيْطَانِ وَإِنَّ الشَّيْطَانَ خُلِقَ مِنَ النَّارِ وَإِنَّمَا تُطْفَأُ النَّارُ بِالْمَاءِ فَإِذَا غَضِبَ أَحَدُكُمْ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{4784}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Atiyyah as-Sa'di: AbuWa'il al-Qass said: We entered upon Urwah ibn Muhammad ibn as-Sa'di. A man spoke to him and made him angry. So he stood and performed ablution; he then returned and performed ablution, and said: My father told me on the authority of my grandfather Atiyyah who reported the Messenger of Allah (ﷺ) as saying: Anger comes from the devil, the devil was created of fire, and fire is extinguished only with water; so when one of you becomes angry, he should perform ablution}}
\hadithdefcmd{abudawud}{4785}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّهَا قَالَتْ مَا خُيِّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَمْرَيْنِ إِلاَّ اخْتَارَ أَيْسَرَهُمَا مَا لَمْ يَكُنْ إِثْمًا فَإِنْ كَانَ إِثْمًا كَانَ أَبْعَدَ النَّاسِ مِنْهُ وَمَا انْتَقَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَفْسِهِ إِلاَّ أَنْ تُنْتَهَكَ حُرْمَةُ اللَّهِ تَعَالَى فَيَنْتَقِمَ لِلَّهِ بِهَا ‏.‏\hadithno{4785}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6126) Sahih Muslim (2327)}\hadithtrans{A’ishah said:the Messenger of Allah (ﷺ) was never given his choice between two things without taking the easier(or lesser) of them provided it involved no sin, for if it did, no one kept farther away from it than he. And the Messenger of Allah (ﷺ) never took revenge on his own behalf for anything unless something Allah had forbidden has been transgressed, in which event he took revenge for it for Allah’s sake}}
\hadithdefcmd{abudawud}{4786}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها، قَالَتْ مَا ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَادِمًا وَلاَ امْرَأَةً قَطُّ ‏.‏\hadithno{4786}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{A’isha said:the Messenger of Allah (saws ) never struck a servant or a woman}}
\hadithdefcmd{abudawud}{4787}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الطُّفَاوِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ الزُّبَيْرِ - فِي قَوْلِهِ ‏\{‏ خُذِ الْعَفْوَ ‏\}‏ قَالَ أُمِرَ نَبِيُّ اللَّهِ صلى الله عليه وسلم أَنْ يَأْخُذَ الْعَفْوَ مِنْ أَخْلاَقِ النَّاسِ ‏.‏\hadithno{4787}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4644)}\hadithtrans{Explaining the Qur’anic verse “Hold to forgiveness”, `Abd Allah b. Al-Zubair said:The Prophet of Allah (ﷺ) was commanded to hold to forgiveness from the conduct of the people}}
\hadithdefcmd{abudawud}{4788}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الْحَمِيدِ، - يَعْنِي الْحِمَّانِيَّ - حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا بَلَغَهُ عَنِ الرَّجُلِ الشَّىْءُ لَمْ يَقُلْ مَا بَالُ فُلاَنٍ يَقُولُ وَلَكِنْ يَقُولُ ‏ "‏ مَا بَالُ أَقْوَامٍ يَقُولُونَ كَذَا وَكَذَا ‏"‏ ‏.‏\hadithno{4788}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6101) Sahih Muslim (2356)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When the Prophet (ﷺ) was informed of anything of a certain man, he would not say: What is the matter with so and so that he says? But he would say: What is the matter with the people that they say such and such?}}
\hadithdefcmd{abudawud}{4789}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا سَلْمٌ الْعَلَوِيُّ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، دَخَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ أَثَرُ صُفْرَةٍ - وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَلَّمَا يُوَاجِهُ رَجُلاً فِي وَجْهِهِ بِشَىْءٍ يَكْرَهُهُ - فَلَمَّا خَرَجَ قَالَ ‏ "‏ لَوْ أَمَرْتُمْ هَذَا أَنْ يَغْسِلَ ذَا عَنْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَلْمٌ لَيْسَ هُوَ عَلَوِيًّا كَانَ يُبْصِرُ فِي النُّجُومِ وَشَهِدَ عِنْدَ عَدِيِّ بْنِ أَرْطَاةَ عَلَى رُؤْيَةِ الْهِلاَلِ فَلَمْ يُجِزْ شَهَادَتَهُ ‏.‏\hadithno{4789}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: A man who had the mark of yellowness on him came to the Messenger of Allah (ﷺ). The apostle of Allah (ﷺ) rarely mentioned anything of a man which he disliked before him. When he went out, he said: Would that you asked him to wash it from him. Abu Dawud said: Salam is not 'Alawi (from the descendants of 'Ali). He used to foretell events by stars. He bore witness before 'Abi b. Arafat to the visibility of moon, but he did not accept his witness}}
\hadithdefcmd{abudawud}{4790}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ أَخْبَرَنِي أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنِ الْحَجَّاجِ بْنِ فُرَافِصَةَ، عَنْ رَجُلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا بِشْرُ بْنُ رَافِعٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، رَفَعَاهُ جَمِيعًا قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُؤْمِنُ غِرٌّ كَرِيمٌ وَالْفَاجِرُ خِبٌّ لَئِيمٌ ‏"‏ ‏.‏\hadithno{4790}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSalamah ; AbuHurayrah: The Prophet (ﷺ) said: The believer is simple and generous, but the profligate is deceitful and ignoble}}
\hadithdefcmd{abudawud}{4791}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ الْمُنْكَدِرِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اسْتَأْذَنَ رَجُلٌ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ بِئْسَ ابْنُ الْعَشِيرَةِ ‏"‏ ‏.‏ أَوْ ‏"‏ بِئْسَ رَجُلُ الْعَشِيرَةِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ ائْذَنُوا لَهُ ‏"‏ ‏.‏ فَلَمَّا دَخَلَ أَلاَنَ لَهُ الْقَوْلَ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ أَلَنْتَ لَهُ الْقَوْلَ وَقَدْ قُلْتَ لَهُ مَا قُلْتَ ‏.‏ قَالَ ‏"‏ إِنَّ شَرَّ النَّاسِ عِنْدَ اللَّهِ مَنْزِلَةً يَوْمَ الْقِيَامَةِ مَنْ وَدَعَهُ - أَوْ تَرَكَهُ - النَّاسُ لاِتِّقَاءِ فُحْشِهِ ‏"‏ ‏.‏\hadithno{4791}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6054) Sahih Muslim (2591)}\hadithtrans{A’isha said :A man asked permission to see the Prophet (ﷺ), and he said: He is a bad son of the tribe, or: He is a bad member of the tribe. He then said : Give him permission. Then when he entered, he spoke to him leniently. `A’isha asked : Apostle of Allah! You spoke to him leniently while you said about him what you said! He replied: The one who will have the worst position in Allah’s estimation on the Day of Resurrection will be the one whom people left alone for fear of his ribaldry}}
\hadithdefcmd{abudawud}{4792}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَجُلاً، اسْتَأْذَنَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِئْسَ أَخُو الْعَشِيرَةِ ‏"‏ ‏.‏ فَلَمَّا دَخَلَ انْبَسَطَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَلَّمَهُ فَلَمَّا خَرَجَ قُلْتُ يَا رَسُولَ اللَّهِ لَمَّا اسْتَأْذَنَ قُلْتَ ‏"‏ بِئْسَ أَخُو الْعَشِيرَةِ ‏"‏ ‏.‏ فَلَمَّا دَخَلَ انْبَسَطْتَ إِلَيْهِ ‏.‏ فَقَالَ ‏"‏ يَا عَائِشَةُ إِنَّ اللَّهَ لاَ يُحِبُّ الْفَاحِشَ الْمُتَفَحِّشَ ‏"‏ ‏.‏\hadithno{4792}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A man asked permission to see the Prophet (ﷺ), and the Prophet (ﷺ) said: He is a bad member of the tribe. When he entered, the Messenger of Allah (ﷺ) treated in a frank and friendly way and spoke to him. When he departed , I said: Messenger of Allah! When he asked permission, you said: He is a bad member of the tribe, but when he entered, you treated him in a frank and friendly way. The Messenger of Allah replied: Aisha! Allah does not like the one who is unseemly and lewd in his language}}
\hadithdefcmd{abudawud}{4793}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا شَرِيكٌ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، فِي هَذِهِ الْقِصَّةِ قَالَتْ فَقَالَ تَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏ "‏ يَا عَائِشَةُ إِنَّ مِنْ شِرَارِ النَّاسِ الَّذِينَ يُكْرَمُونَ اتِّقَاءَ أَلْسِنَتِهِمْ ‏"‏ ‏.‏\hadithno{4793}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has been transmitted by `A’isha through a different chain of narrators. This version has:the Prophet (ﷺ) said: `A’isha! There are some bad people who are respected for fear of their tongues}}
\hadithdefcmd{abudawud}{4794}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو قَطَنٍ، أَخْبَرَنَا مُبَارَكٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ مَا رَأَيْتُ رَجُلاً الْتَقَمَ أُذُنَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيُنَحِّي رَأْسَهُ حَتَّى يَكُونَ الرَّجُلُ هُوَ الَّذِي يُنَحِّي رَأْسَهُ وَمَا رَأَيْتُ رَجُلاً أَخَذَ بِيَدِهِ فَتَرَكَ يَدَهُ حَتَّى يَكُونَ الرَّجُلُ هُوَ الَّذِي يَدَعُ يَدَهُ ‏.‏\hadithno{4794}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: I never said that when any man brought his mouth to the ear of the Messenger of Allah (ﷺ) and he withdrew his head until the man himself withdrew his head, and I never saw that when any man took him by his hand and he withdrew his hand, until the man himself withdrew his hand}}
\hadithdefcmd{abudawud}{4795}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ عَلَى رَجُلٍ مِنَ الأَنْصَارِ وَهُوَ يَعِظُ أَخَاهُ فِي الْحَيَاءِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعْهُ فَإِنَّ الْحَيَاءَ مِنَ الإِيمَانِ ‏"‏ ‏.‏\hadithno{4795}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (24) Sahih Muslim (36)}\hadithtrans{Abd Allah b. ‘Umar said:The Prophet (ﷺ) passed by a man of the Ansar when he was giving his brother a warning against modesty. The Apostle of Allah (ﷺ) said : Leave him alone, for modesty is a part of faith}}
\hadithdefcmd{abudawud}{4796}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ إِسْحَاقَ بْنِ سُوَيْدٍ، عَنْ أَبِي قَتَادَةَ، قَالَ كُنَّا مَعَ عِمْرَانَ بْنِ حُصَيْنٍ وَثَمَّ بُشَيْرُ بْنُ كَعْبٍ فَحَدَّثَ عِمْرَانُ بْنُ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْحَيَاءُ خَيْرٌ كُلُّهُ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ الْحَيَاءُ كُلُّهُ خَيْرٌ ‏"‏ ‏.‏ فَقَالَ بُشَيْرُ بْنُ كَعْبٍ إِنَّا نَجِدُ فِي بَعْضِ الْكُتُبِ أَنَّ مِنْهُ سَكِينَةً وَوَقَارًا وَمِنْهُ ضَعْفًا ‏.‏ فَأَعَادَ عِمْرَانُ الْحَدِيثَ وَأَعَادَ بُشَيْرٌ الْكَلاَمَ قَالَ فَغَضِبَ عِمْرَانُ حَتَّى احْمَرَّتْ عَيْنَاهُ وَقَالَ أَلاَ أَرَانِي أُحَدِّثُكَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَتُحَدِّثُنِي عَنْ كُتُبِكَ ‏.‏ قَالَ قُلْنَا يَا أَبَا نُجَيْدٍ إِيهٍ إِيهٍ ‏.‏\hadithno{4796}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6117) Sahih Muslim (37)}\hadithtrans{Abu Qatadah said :We were sitting with `Imran b. Hussain and Bushair b. Ka`b was also there. `Imran b. Hussain reported the Messenger of Allah (ﷺ) as saying: Modesty is good altogether, or he said: Modesty is altogether good. Bushair b. Ka`b said : We find in some books that there is a modesty which produces peace and dignified bearing, and there is a modesty which produces weakness. `Imran b. Hussain repeated the same words. So `Imran became angry so much so that his eyes became red, and he said : Don’t you see that I am transmitting a tradition from the Messenger of Allah (ﷺ) and you are mentioning something from your books? He (Qatadah) said : We said : Abu Nujaid, it is sufficient}}
\hadithdefcmd{abudawud}{4797}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِمَّا أَدْرَكَ النَّاسُ مِنْ كَلاَمِ النُّبُوَّةِ الأُولَى إِذَا لَمْ تَسْتَحِ فَافْعَلْ مَا شِئْتَ ‏"‏ ‏.‏\hadithno{4797}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3484)}\hadithtrans{Abu Mas`ud reported the Messenger of Allah (ﷺ) as saying :One of the things people have learnt from the words of the earliest prophecy is : If you have no shame, do what you like}}
\hadithdefcmd{abudawud}{4798}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي الإِسْكَنْدَرَانِيَّ - عَنْ عَمْرٍو، عَنِ الْمُطَّلِبِ، عَنْ عَائِشَةَ، رَحِمَهَا اللَّهُ قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الْمُؤْمِنَ لَيُدْرِكُ بِحُسْنِ خُلُقِهِ دَرَجَةَ الصَّائِمِ الْقَائِمِ ‏"‏ ‏.‏\hadithno{4798}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: By his good character a believer will attain the degree of one who prays during the night and fasts during the day}}
\hadithdefcmd{abudawud}{4799}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، وَحَفْصُ بْنُ عُمَرَ، قَالاَ حَدَّثَنَا ح، وَحَدَّثَنَا ابْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْقَاسِمِ بْنِ أَبِي بَزَّةَ، عَنْ عَطَاءٍ الْكَيْخَارَانِيِّ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ شَىْءٍ أَثْقَلُ فِي الْمِيزَانِ مِنْ حُسْنِ الْخُلُقِ ‏"‏ ‏.‏ قَالَ أَبُو الْوَلِيدِ قَالَ سَمِعْتُ عَطَاءً الْكَيْخَارَانِيَّ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ عَطَاءُ بْنُ يَعْقُوبَ وَهُوَ خَالُ إِبْرَاهِيمَ بْنِ نَافِعٍ يُقَالُ كَيْخَارَانِيٌّ وَكَوْخَارَانِيٌّ ‏.‏\hadithno{4799}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbudDarda': The Prophet (ﷺ) said: There is nothing heavier than good character put in the scale of a believer on the Day of Resurrection. Abu al-Walid said: I heard 'Ata al-Kaikharani say: Abu Dawud said: His name is 'Ata b. Ya'qub. He is the maternal uncle of Ibrahim b. Nafi'. He is called Kaikharani or Kukharani}}
\hadithdefcmd{abudawud}{4800}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ أَبُو الْجَمَاهِرِ، قَالَ حَدَّثَنَا أَبُو كَعْبٍ، أَيُّوبُ بْنُ مُحَمَّدٍ السَّعْدِيُّ قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ حَبِيبٍ الْمُحَارِبِيُّ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا زَعِيمٌ بِبَيْتٍ فِي رَبَضِ الْجَنَّةِ لِمَنْ تَرَكَ الْمِرَاءَ وَإِنْ كَانَ مُحِقًّا وَبِبَيْتٍ فِي وَسَطِ الْجَنَّةِ لِمَنْ تَرَكَ الْكَذِبَ وَإِنْ كَانَ مَازِحًا وَبِبَيْتٍ فِي أَعْلَى الْجَنَّةِ لِمَنْ حَسَّنَ خُلُقَهُ ‏"‏ ‏.‏\hadithno{4800}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuUmamah: The Prophet (ﷺ) said: I guarantee a house in the surroundings of Paradise for a man who avoids quarrelling even if he were in the right, a house in the middle of Paradise for a man who avoids lying even if he were joking, and a house in the upper part of Paradise for a man who made his character good}}
\hadithdefcmd{abudawud}{4801}{حَدَّثَنَا أَبُو بَكْرٍ، وَعُثْمَانُ، ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، عَنْ حَارِثَةَ بْنِ وَهْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ الْجَوَّاظُ وَلاَ الْجَعْظَرِيُّ ‏"‏ ‏.‏ قَالَ وَالْجَوَّاظُ الْغَلِيظُ الْفَظُّ ‏.‏\hadithno{4801}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Harithah b. Wahab reported the Messenger of Allah (ﷺ) as saying :neither the Jawwaz nor the Jazari will enter paradise. He said that the Jawwaz is the one who is coarse and uncivil}}
\hadithdefcmd{abudawud}{4802}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَتِ الْعَضْبَاءُ لاَ تُسْبَقُ فَجَاءَ أَعْرَابِيٌّ عَلَى قَعُودٍ لَهُ فَسَابَقَهَا فَسَبَقَهَا الأَعْرَابِيُّ فَكَأَنَّ ذَلِكَ شَقَّ عَلَى أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ حَقٌّ عَلَى اللَّهِ عَزَّ وَجَلَّ أَنْ لاَ يَرْفَعَ شَيْئًا مِنَ الدُّنْيَا إِلاَّ وَضَعَهُ ‏"‏ ‏.‏\hadithno{4802}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas said:The she-camel of the Messenger of Allah (ﷺ) called al-Adba’ had not been outstripped by another, but an A`rabi (a nomadic Arab) came on a young riding camel of his and it outstripped it. That distressed the companions of the Messenger of Allah (ﷺ), but he said: It is Allah’s right that nothing should become exalted in the world but he lowers it}}
\hadithdefcmd{abudawud}{4803}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، بِهَذِهِ الْقِصَّةِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ حَقًّا عَلَى اللَّهِ عَزَّ وَجَلَّ أَنْ لاَ يَرْتَفِعَ شَىْءٌ مِنَ الدُّنْيَا إِلاَّ وَضَعَهُ ‏"‏ ‏.‏\hadithno{4803}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6501)}\hadithtrans{Narrating this story Anas reported the Prophet (ﷺ) as saying:It is Allah’s right that nothing should become exalted in the world but he lowers it}}
\hadithdefcmd{abudawud}{4804}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، قَالَ جَاءَ رَجُلٌ فَأَثْنَى عَلَى عُثْمَانَ فِي وَجْهِهِ فَأَخَذَ الْمِقْدَادُ بْنُ الأَسْوَدِ تُرَابًا فَحَثَا فِي وَجْهِهِ وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا لَقِيتُمُ الْمَدَّاحِينَ فَاحْثُوا فِي وُجُوهِهِمُ التُّرَابَ ‏"‏ ‏.‏\hadithno{4804}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (3002)}\hadithtrans{Hammam said :A man came and praised ‘Uthman in his face, al-Miqdad b. Al-Aswad took dust and threw it on his face, saying : The Apostle of Allah (ﷺ) said : When you see those who are given to praising people, throw dust in their faces}}
\hadithdefcmd{abudawud}{4805}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَثْنَى عَلَى رَجُلٍ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ ‏"‏ قَطَعْتَ عُنُقَ صَاحِبِكَ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ثُمَّ قَالَ ‏"‏ إِذَا مَدَحَ أَحَدُكُمْ صَاحِبَهُ لاَ مَحَالَةَ فَلْيَقُلْ إِنِّي أَحْسِبُهُ كَمَا يُرِيدُ أَنْ يَقُولَ وَلاَ أُزَكِّيهِ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{4805}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6061) Sahih Muslim (3000)}\hadithtrans{Abu Bakrah said that when a man praised another man in his face in the presence of the Prophet (ﷺ) said :You have beheaded your friend (saying it three times). He then said : One who cannot help expressing praise of his companion, should say : I consider him such and such (as he intends to say), but I do not declare him pure with Allah}}
\hadithdefcmd{abudawud}{4806}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - حَدَّثَنَا أَبُو مَسْلَمَةَ، سَعِيدُ بْنُ يَزِيدَ عَنْ أَبِي نَضْرَةَ، عَنْ مُطَرِّفٍ، قَالَ قَالَ أَبِي انْطَلَقْتُ فِي وَفْدِ بَنِي عَامِرٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْنَا أَنْتَ سَيِّدُنَا ‏.‏ فَقَالَ ‏"‏ السَّيِّدُ اللَّهُ تَبَارَكَ وَتَعَالَى ‏"‏ ‏.‏ قُلْنَا وَأَفْضَلُنَا فَضْلاً وَأَعْظَمُنَا طَوْلاً ‏.‏ فَقَالَ ‏"‏ قُولُوا بِقَوْلِكُمْ أَوْ بَعْضِ قَوْلِكُمْ وَلاَ يَسْتَجْرِيَنَّكُمُ الشَّيْطَانُ ‏"‏ ‏.‏\hadithno{4806}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn ash-Shikhkhir: I went with a deputation of Banu Amir to the apostle of Allah (ﷺ), and we said: You are our lord (sayyid). To this he replied: The lord is Allah, the Blessed and Exalted. Then we said: And the one of us most endowed with excellence and superiority. To this he replied: Say what you have to say, or part of what you have to say, and do not let the devil make you his agents}}
\hadithdefcmd{abudawud}{4807}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ يُونُسَ، وَحُمَيْدٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ رَفِيقٌ يُحِبُّ الرِّفْقَ وَيُعْطِي عَلَيْهِ مَا لاَ يُعْطِي عَلَى الْعُنْفِ ‏"‏ ‏.‏\hadithno{4807}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abd Allah b. Mughaffal reported the Messenger of Allah (ﷺ) as saying :Allah is gentle, likes gentleness, and gives for gentleness what he does not give for harshness}}
\hadithdefcmd{abudawud}{4808}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ وَمُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ قَالُوا حَدَّثَنَا شَرِيكٌ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَائِشَةَ عَنِ الْبَدَاوَةِ، فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَبْدُو إِلَى هَذِهِ التِّلاَعِ وَإِنَّهُ أَرَادَ الْبَدَاوَةَ مَرَّةً فَأَرْسَلَ إِلَىَّ نَاقَةً مُحَرَّمَةً مِنْ إِبِلِ الصَّدَقَةِ فَقَالَ لِي ‏ "‏ يَا عَائِشَةُ ارْفُقِي فَإِنَّ الرِّفْقَ لَمْ يَكُنْ فِي شَىْءٍ قَطُّ إِلاَّ زَانَهُ وَلاَ نُزِعَ مِنْ شَىْءٍ قَطُّ إِلاَّ شَانَهُ ‏"‏ ‏.‏ قَالَ ابْنُ الصَّبَّاحِ فِي حَدِيثِهِ مُحَرَّمَةٌ يَعْنِي لَمْ تُرْكَبْ ‏.‏\hadithno{4808}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Al-Miqdam ibn Shurayh, quoting his father, said: I asked Aisha about living in the desert. She said: The Messenger of Allah (ﷺ) used to go to the desert to these rivulets. Once he intended to go to the desert and he sent to me a she-camel from the camel of sadaqah which had not been used for riding so far. He said to me: Aisha! show gentleness, for if gentleness is found in anything, it beautifies it and when it is taken out from anything it damages it. Ibn al-Sabbah said in his version: Muharramah means a mount which has not been used for riding}}
\hadithdefcmd{abudawud}{4809}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هِلاَلٍ، عَنْ جَرِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يُحْرَمِ الرِّفْقَ يُحْرَمِ الْخَيْرَ كُلَّهُ ‏"‏ ‏.‏\hadithno{4809}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2592)}\hadithtrans{Narrated Jarir: The Prophet (ﷺ) said: He who is deprived of gentleness is deprived of good}}
\hadithdefcmd{abudawud}{4810}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا سُلَيْمَانُ الأَعْمَشُ، عَنْ مَالِكِ بْنِ الْحَارِثِ، - قَالَ الأَعْمَشُ وَقَدْ سَمِعْتُهُمْ يَذْكُرُونَ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ الأَعْمَشُ - وَلاَ أَعْلَمُهُ إِلاَّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ التُّؤَدَةُ فِي كُلِّ شَىْءٍ إِلاَّ فِي عَمَلِ الآخِرَةِ ‏"‏ ‏.‏\hadithno{4810}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd: The Prophet (ﷺ) said: There is hesitation in everything except in the actions of the next world}}
\hadithdefcmd{abudawud}{4811}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الرَّبِيعُ بْنُ مُسْلِمٍ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَشْكُرُ اللَّهَ مَنْ لاَ يَشْكُرُ النَّاسَ ‏"‏ ‏.‏\hadithno{4811}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: He who does not thank the people is not thankful to Allah}}
\hadithdefcmd{abudawud}{4812}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ الْمُهَاجِرِينَ، قَالُوا يَا رَسُولَ اللَّهِ ذَهَبَتِ الأَنْصَارُ بِالأَجْرِ كُلِّهِ ‏.‏ قَالَ ‏ "‏ لاَ مَا دَعَوْتُمُ اللَّهَ لَهُمْ وَأَثْنَيْتُمْ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{4812}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: The Immigrants (Muhajirun) said: Messenger of Allah! the Helpers (Ansar) got the entire reward. He said: no, so long as you pray to Allah for them and praise them}}
\hadithdefcmd{abudawud}{4813}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، قَالَ حَدَّثَنِي رَجُلٌ، مِنْ قَوْمِي عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أُعْطِيَ عَطَاءً فَوَجَدَ فَلْيَجْزِ بِهِ فَإِنْ لَمْ يَجِدْ فَلْيُثْنِ بِهِ فَمَنْ أَثْنَى بِهِ فَقَدْ شَكَرَهُ وَمَنْ كَتَمَهُ فَقَدْ كَفَرَهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ يَحْيَى بْنُ أَيُّوبَ عَنْ عُمَارَةَ بْنِ غَزِيَّةَ عَنْ شُرَحْبِيلَ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ شُرَحْبِيلُ يَعْنِي رَجُلاً مِنْ قَوْمِي كَأَنَّهُمْ كَرِهُوهُ فَلَمْ يُسَمُّوهُ ‏.‏\hadithno{4813}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If someone is given something, he should give a return for it provided he can afford; if he cannot afford, he should praise him. He who praises him for it, thanks him, and he who conceals it is ungrateful to him. Abu Dawud said: It has been transmitted by Yahya b. Ayyub, from `Umarah b. Ghaziyyah, from Sharahbil on the authority of Jabir. Abu Dawud said: In the chain of this tradition `Umarah b. Ghaziyyah said: A man from my tribe said. The man referred by him is Sharahbil. It is likely that they disliked him and, therefore, they did not name him}}
\hadithdefcmd{abudawud}{4814}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَبْلَى بَلاَءً فَذَكَرَهُ فَقَدْ شَكَرَهُ وَإِنْ كَتَمَهُ فَقَدْ كَفَرَهُ ‏"‏ ‏.‏\hadithno{4814}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If someone is donated something, and he mentions it, he thanks for it, and if he conceals it, he is ungrateful for it}}
\hadithdefcmd{abudawud}{4815}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ زَيْدٍ، - يَعْنِي ابْنَ أَسْلَمَ - عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْجُلُوسَ بِالطُّرُقَاتِ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ مَا بُدٌّ لَنَا مِنْ مَجَالِسِنَا نَتَحَدَّثُ فِيهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ أَبَيْتُمْ فَأَعْطُوا الطَّرِيقَ حَقَّهُ ‏"‏ ‏.‏ قَالُوا وَمَا حَقُّ الطَّرِيقِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ غَضُّ الْبَصَرِ وَكَفُّ الأَذَى وَرَدُّ السَّلاَمِ وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏ ‏.‏\hadithno{4815}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2465) Sahih Muslim (2121)}\hadithtrans{Abu Sa`id al-Khudri reported the Messenger of Allah (ﷺ) as saying :Avoid sitting in the roads. The people said: Apostle of Allah! We must have meeting places in which to converse. The apostle of Allah (ﷺ) said: If you insist on meeting, give the road its due. They asked: What is the due of roads, Apostle of Allah? He replied: Lowering the eyes, removing anything offensive, returning salutation, commanding what is reputable and forbidding what is disreputable}}
\hadithdefcmd{abudawud}{4816}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذِهِ الْقِصَّةِ قَالَ ‏ "‏ وَإِرْشَادُ السَّبِيلِ ‏"‏ ‏.‏\hadithno{4816}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying on the same occasion:And guiding the people on their way}}
\hadithdefcmd{abudawud}{4817}{حَدَّثَنَا الْحَسَنُ بْنُ عِيسَى النَّيْسَابُورِيُّ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ إِسْحَاقَ بْنِ سُوَيْدٍ، عَنِ ابْنِ حُجَيْرٍ الْعَدَوِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذِهِ الْقِصَّةِ قَالَ ‏ "‏ وَتُغِيثُوا الْمَلْهُوفَ وَتَهْدُوا الضَّالَّ ‏"‏ ‏.‏\hadithno{4817}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: The Prophet (ﷺ) said: the same occasion: Help the oppressed (sorrowful) and guide those who have lost their way}}
\hadithdefcmd{abudawud}{4818}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى بْنِ الطَّبَّاعِ، وَكَثِيرُ بْنُ عُبَيْدٍ، قَالاَ حَدَّثَنَا مَرْوَانُ، - قَالَ ابْنُ عِيسَى قَالَ - حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ لِي إِلَيْكَ حَاجَةً ‏.‏ فَقَالَ لَهَا ‏ "‏ يَا أُمَّ فُلاَنٍ اجْلِسِي فِي أَىِّ نَوَاحِي السِّكَكِ شِئْتِ حَتَّى أَجْلِسَ إِلَيْكِ ‏"‏ ‏.‏ قَالَ فَجَلَسَتْ فَجَلَسَ النَّبِيُّ صلى الله عليه وسلم إِلَيْهَا حَتَّى قَضَتْ حَاجَتَهَا ‏.‏ وَلَمْ يَذْكُرِ ابْنُ عِيسَى حَتَّى قَضَتْ حَاجَتَهَا ‏.‏ وَقَالَ كَثِيرٌ عَنْ حُمَيْدٍ عَنْ أَنَسٍ ‏.‏\hadithno{4818}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: A woman came to the Messenger of Allah (ﷺ) and said: Messenger of Allah: I have some need with you. He said to her: Mother of so and so, sit in the corner of any street you wish and I shall sit with you. So she sat and the Messenger of Allah (ﷺ) also sat with her till she fulfilled her need. The narrator Ibn 'Isa did not mention "till she fulfilled her need." And Kathir said: from Humaid on the authority of Anas}}
\hadithdefcmd{abudawud}{4819}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ امْرَأَةً، كَانَ فِي عَقْلِهَا شَىْءٌ بِمَعْنَاهُ ‏.‏\hadithno{4819}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2326)}\hadithtrans{Anas reported this tradition to the same effect through a different chain of narrators. This version adds:A woman who had something (feebleness) in her mind}}
\hadithdefcmd{abudawud}{4820}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ الأَنْصَارِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ الْمَجَالِسِ أَوْسَعُهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هُوَ عَبْدُ الرَّحْمَنِ بْنُ عَمْرِو بْنِ أَبِي عَمْرَةَ الأَنْصَارِيُّ ‏.‏\hadithno{4820}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: I heard the Messenger of Allah (ﷺ) as saying: The best places to sit are those which provide most room. Abu Dawud said: The name of 'Abd al-Rahman b. Abi 'Amr is 'Abd al-Rahman b. 'Amr b. Abi 'Umrat al-Ansari}}
\hadithdefcmd{abudawud}{4821}{حَدَّثَنَا ابْنُ السَّرْحِ، وَمَخْلَدُ بْنُ خَالِدٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ حَدَّثَنِي مَنْ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏"‏ إِذَا كَانَ أَحَدُكُمْ فِي الشَّمْسِ ‏"‏ ‏.‏ وَقَالَ مَخْلَدٌ ‏"‏ فِي الْفَىْءِ ‏"‏ ‏.‏ ‏"‏ فَقَلَصَ عَنْهُ الظِّلُّ وَصَارَ بَعْضُهُ فِي الشَّمْسِ وَبَعْضُهُ فِي الظِّلِّ فَلْيَقُمْ ‏"‏ ‏.‏\hadithno{4821}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: AbulQasim (ﷺ) said: When one of you is in the sun (Shams)--Makhlad's version has "fay'"--and the shadow withdraws from him so that he is partly in sun and partly in shade, he should get up}}
\hadithdefcmd{abudawud}{4822}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسٌ، عَنْ أَبِيهِ، أَنَّهُ جَاءَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ فَقَامَ فِي الشَّمْسِ فَأَمَرَ بِهِ فَحُوِّلَ إِلَى الظِّلِّ ‏.‏\hadithno{4822}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Qais quoted his father as saying that he (his father) came when the Messenger of Allah (ﷺ) was addressing. He stood in the sun. He ordered him (to shift) and he shifted to the shade}}
\hadithdefcmd{abudawud}{4823}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ الأَعْمَشِ، قَالَ حَدَّثَنِي الْمُسَيَّبُ بْنُ رَافِعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْجِدَ وَهُمْ حِلَقٌ فَقَالَ ‏ "‏ مَا لِي أَرَاكُمْ عِزِينَ ‏"‏ ‏.‏\hadithno{4823}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir b. Samurah said:the Messenger of Allah (ﷺ) entered the mosque, and saw them (his companions) in separate groups. He said: How is it that I see you in separate groups?}}
\hadithdefcmd{abudawud}{4824}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، عَنِ ابْنِ فُضَيْلٍ، عَنِ الأَعْمَشِ، بِهَذَا قَالَ كَأَنَّهُ يُحِبُّ الْجَمَاعَةَ ‏.‏\hadithno{4824}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-A`mash said:It seems he liked collective gathering}}
\hadithdefcmd{abudawud}{4825}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ الْوَرْكَانِيُّ، وَهَنَّادٌ، أَنَّ شَرِيكًا، أَخْبَرَهُمْ عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كُنَّا إِذَا أَتَيْنَا النَّبِيَّ صلى الله عليه وسلم جَلَسَ أَحَدُنَا حَيْثُ يَنْتَهِي ‏.‏\hadithno{4825}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Samurah: When we came to the Prophet (ﷺ), each one would sit down where there was room}}
\hadithdefcmd{abudawud}{4826}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، قَالَ حَدَّثَنِي أَبُو مِجْلَزٍ، عَنْ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ مَنْ جَلَسَ وَسْطَ الْحَلْقَةِ ‏.‏\hadithno{4826}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hudhayfah: The Messenger of Allah (ﷺ) cursed the one who sat in the middle of a circle}}
\hadithdefcmd{abudawud}{4827}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ أَبِي عَبْدِ اللَّهِ، مَوْلَى آلِ أَبِي بُرْدَةَ عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، قَالَ جَاءَنَا أَبُو بَكْرَةَ فِي شَهَادَةٍ فَقَامَ لَهُ رَجُلٌ مِنْ مَجْلِسِهِ فَأَبَى أَنْ يَجْلِسَ فِيهِ وَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ ذَا وَنَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَمْسَحَ الرَّجُلُ يَدَهُ بِثَوْبِ مَنْ لَمْ يَكْسُهُ ‏.‏\hadithno{4827}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuBakrah: Sa'id ibn AbulHasan said: When AbuBakrah came to us to give some evidence, a man got up from his place, but he refused to sit in it saying: The Prophet (ﷺ) forbade this, and the Prophet (ﷺ) forbade anyone to wipe his hand on the garment of anyone whose clothing he had not himself provided}}
\hadithdefcmd{abudawud}{4828}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرٍ، حَدَّثَهُمْ عَنْ شُعْبَةَ، عَنْ عَقِيلِ بْنِ طَلْحَةَ، قَالَ سَمِعْتُ أَبَا الْخَصِيبِ، عَنِ ابْنِ عُمَرَ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ لَهُ رَجُلٌ مِنْ مَجْلِسِهِ فَذَهَبَ لِيَجْلِسَ فِيهِ فَنَهَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو الْخَصِيبِ اسْمُهُ زِيَادُ بْنُ عَبْدِ الرَّحْمَنِ ‏.‏\hadithno{4828}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: A man came to the Prophet (ﷺ), another man got up from his place for him, and when he went to sit in it, the Prophet (ﷺ) forbade him. Abu Dawud said: The name of Abu al-Khusaib is Ziyad b. 'Abd al-Rahman}}
\hadithdefcmd{abudawud}{4829}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُؤْمِنِ الَّذِي يَقْرَأُ الْقُرْآنَ مَثَلُ الأُتْرُجَّةِ رِيحُهَا طَيِّبٌ وَطَعْمُهَا طَيِّبٌ وَمَثَلُ الْمُؤْمِنِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ التَّمْرَةِ طَعْمُهَا طَيِّبٌ وَلاَ رِيحَ لَهَا وَمَثَلُ الْفَاجِرِ الَّذِي يَقْرَأُ الْقُرْآنَ كَمَثَلِ الرَّيْحَانَةِ رِيحُهَا طَيِّبٌ وَطَعْمُهَا مُرٌّ وَمَثَلُ الْفَاجِرِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ الْحَنْظَلَةِ طَعْمُهَا مُرٌّ وَلاَ رِيحَ لَهَا وَمَثَلُ الْجَلِيسِ الصَّالِحِ كَمَثَلِ صَاحِبِ الْمِسْكِ إِنْ لَمْ يُصِبْكَ مِنْهُ شَىْءٌ أَصَابَكَ مِنْ رِيحِهِ وَمَثَلُ جَلِيسِ السُّوءِ كَمَثَلِ صَاحِبِ الْكِيرِ إِنْ لَمْ يُصِبْكَ مِنْ سَوَادِهِ أَصَابَكَ مِنْ دُخَانِهِ ‏"‏ ‏.‏\hadithno{4829}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: A believer who recites the Qur'an is like a citron whose fragrance is sweet and whose taste is sweet, a believer who does not recite the Qur'an is like a date which has no fragrance but has sweet taste, a profligate who recites the Qur'an is like basil whose fragrance is sweet but whose taste is bitter, and the profligate who does not recite the Qur'an is like the colocynth which has a bitter taste and has not fragrance. A good companion is like a man who has musk; if nothing of it goes to you, its fragrance will (certainly) go to you; and a bad companion is like a man who has bellows; if its (black) root does not go to you, its smoke will (certainly) go to you}}
\hadithdefcmd{abudawud}{4830}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، - الْمَعْنَى - ح وَحَدَّثَنَا ابْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْكَلاَمِ الأَوَّلِ إِلَى قَوْلِهِ ‏ "‏ وَطَعْمُهَا مُرٌّ ‏"‏ ‏.‏ وَزَادَ ابْنُ مُعَاذٍ قَالَ قَالَ أَنَسٌ وَكُنَّا نَتَحَدَّثُ أَنَّ مَثَلَ جَلِيسِ الصَّالِحِ وَسَاقَ بَقِيَّةَ الْحَدِيثِ ‏.‏\hadithno{4830}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5059) Sahih Muslim (797)}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Musa from the Prophet (ﷺ) through a different chain of narrators up to “and its taste bitter”. Ibn Mu`adh added:Anas said: We used tell one another that a good companion is like... He then transmitted the rest of the tradition}}
\hadithdefcmd{abudawud}{4831}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْعَطَّارُ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنْ شُبَيْلِ بْنِ عَزْرَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْجَلِيسِ الصَّالِحِ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{4831}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Anas b. Malik from the Prophet (ﷺ) through a different chain of narrators in a similar way}}
\hadithdefcmd{abudawud}{4832}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، عَنْ سَالِمِ بْنِ غَيْلاَنَ، عَنِ الْوَلِيدِ بْنِ قَيْسٍ، عَنْ أَبِي سَعِيدٍ، أَوْ عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُصَاحِبْ إِلاَّ مُؤْمِنًا وَلاَ يَأْكُلْ طَعَامَكَ إِلاَّ تَقِيٌّ ‏"‏ ‏.‏\hadithno{4832}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: Associate only with a believer, and let only a God-fearing man eat your meals}}
\hadithdefcmd{abudawud}{4833}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، وَأَبُو دَاوُدَ قَالاَ حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي مُوسَى بْنُ وَرْدَانَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الرَّجُلُ عَلَى دِينِ خَلِيلِهِ فَلْيَنْظُرْ أَحَدُكُمْ مَنْ يُخَالِلُ ‏"‏ ‏.‏\hadithno{4833}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: A man follows the religion of his friend; so each one should consider whom he makes his friend}}
\hadithdefcmd{abudawud}{4834}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا جَعْفَرٌ، - يَعْنِي ابْنَ بُرْقَانَ - عَنْ يَزِيدَ، - يَعْنِي ابْنَ الأَصَمِّ - عَنْ أَبِي هُرَيْرَةَ، يَرْفَعُهُ قَالَ ‏ "‏ الأَرْوَاحُ جُنُودٌ مُجَنَّدَةٌ فَمَا تَعَارَفَ مِنْهَا ائْتَلَفَ وَمَا تَنَاكَرَ مِنْهَا اخْتَلَفَ ‏"‏ ‏.‏\hadithno{4834}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2638)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying:The spirits are in marshaled hosts; those who know one another will be friendly, and those who do not, will keep apart}}
\hadithdefcmd{abudawud}{4835}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا بُرَيْدُ بْنُ عَبْدِ اللَّهِ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا بَعَثَ أَحَدًا مِنْ أَصْحَابِهِ فِي بَعْضِ أَمْرِهِ قَالَ ‏ "‏ بَشِّرُوا وَلاَ تُنَفِّرُوا وَيَسِّرُوا وَلاَ تُعَسِّرُوا ‏"‏ ‏.‏\hadithno{4835}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1732)}\hadithtrans{Abu Musa reported the Messenger of Allah (ﷺ) as saying:Gladden people and do not scare them; make things easy and do not make them difficult}}
\hadithdefcmd{abudawud}{4836}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُهَاجِرِ، عَنْ مُجَاهِدٍ، عَنْ قَائِدِ السَّائِبِ، عَنِ السَّائِبِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَجَعَلُوا يُثْنُونَ عَلَىَّ وَيَذْكُرُونِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا أَعْلَمُكُمْ ‏"‏ ‏.‏ يَعْنِي بِهِ ‏.‏ قُلْتُ صَدَقْتَ بِأَبِي أَنْتَ وَأُمِّي كُنْتَ شَرِيكِي فَنِعْمَ الشَّرِيكُ كُنْتَ لاَ تُدَارِي وَلاَ تُمَارِي ‏.‏\hadithno{4836}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated As-Sa'ib: I came to the Prophet (ﷺ). The people began to praise me and make a mention of me. The Messenger of Allah (ﷺ) said: I know you, that is, he knew him. I said: My father and mother be sacrificed for you! you were my partner and how good a partner ; you neither disputed nor quarrelled}}
\hadithdefcmd{abudawud}{4837}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، قَالَ حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَعْقُوبَ بْنِ عُتْبَةَ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا جَلَسَ يَتَحَدَّثُ يُكْثِرُ أَنْ يَرْفَعَ طَرْفَهُ إِلَى السَّمَاءِ ‏.‏\hadithno{4837}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Salam: When the Messenger of Allah (ﷺ) sat talking (to the people), he would often raise his eyes to the sky}}
\hadithdefcmd{abudawud}{4838}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مِسْعَرٍ، قَالَ سَمِعْتُ شَيْخًا، فِي الْمَسْجِدِ يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَ فِي كَلاَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم تَرْتِيلٌ أَوْ تَرْسِيلٌ ‏.‏\hadithno{4838}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) spoke in a distinct and leisurely manner}}
\hadithdefcmd{abudawud}{4839}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أُسَامَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رَحِمَهَا اللَّهُ قَالَتْ كَانَ كَلاَمُ رَسُولِ اللَّهِ صلى الله عليه وسلم كَلاَمًا فَصْلاً يَفْهَمُهُ كُلُّ مَنْ سَمِعَهُ ‏.‏\hadithno{4839}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) spoke in a distinct manner so that anyone who listened to him could understand it}}
\hadithdefcmd{abudawud}{4840}{حَدَّثَنَا أَبُو تَوْبَةَ، قَالَ زَعَمَ الْوَلِيدُ عَنِ الأَوْزَاعِيِّ، عَنْ قُرَّةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ كَلاَمٍ لاَ يُبْدَأُ فِيهِ بِـ الْحَمْدُ لِلَّهِ فَهُوَ أَجْذَمُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ يُونُسُ وَعُقَيْلٌ وَشُعَيْبٌ وَسَعِيدُ بْنُ عَبْدِ الْعَزِيزِ عَنِ الزُّهْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{4840}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Every important matter which is not begun by an expression of praise to Allah is maimed. Abu Dawud said: It has also been transmitted by Yunus, 'Aqil, Shu'aib, Sa'id b. 'Abd al-Aziz from al-Zuhri from the Prophet (ﷺ) in Mursal form (the link of the Companion is missing)}}
\hadithdefcmd{abudawud}{4841}{حَدَّثَنَا مُسَدَّدٌ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ خُطْبَةٍ لَيْسَ فِيهَا تَشَهُّدٌ فَهِيَ كَالْيَدِ الْجَذْمَاءِ ‏"‏ ‏.‏\hadithno{4841}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Every sermon which does not contain a tashahhud is like a hand cut off}}
\hadithdefcmd{abudawud}{4842}{حَدَّثَنَا يَحْيَى بْنُ إِسْمَاعِيلَ، وَابْنُ أَبِي خَلَفٍ، أَنَّ يَحْيَى بْنَ الْيَمَانِ، أَخْبَرَهُمْ عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، أَنَّ عَائِشَةَ [رضى الله عنها] مَرَّ بِهَا سَائِلٌ فَأَعْطَتْهُ كِسْرَةً وَمَرَّ بِهَا رَجُلٌ عَلَيْهِ ثِيَابٌ وَهَيْئَةٌ فَأَقْعَدَتْهُ فَأَكَلَ فَقِيلَ لَهَا فِي ذَلِكَ فَقَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنْزِلُوا النَّاسَ مَنَازِلَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ يَحْيَى مُخْتَصَرٌ ‏.‏ قَالَ أَبُو دَاوُدَ مَيْمُونٌ لَمْ يُدْرِكْ عَائِشَةَ ‏.‏\hadithno{4842}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Maimun ibn Abu Shabib: A beggar passed by Aisha and she gave him a piece of bread. Another man who wore clothes and had a good appearance passed by her, and she made him sit down and he ate (with her). When she was asked about that, she replied: The Messenger of Allah (ﷺ) said: Treat the people according to their ranks. Abu Dawud said: The version of Yahya is short. Abu Dawud said: Maimun did not meet 'A'ishah}}
\hadithdefcmd{abudawud}{4843}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الصَّوَّافُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ حُمْرَانَ، أَخْبَرَنَا عَوْفُ بْنُ أَبِي جَمِيلَةَ، عَنْ زِيَادِ بْنِ مِخْرَاقٍ، عَنْ أَبِي كِنَانَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ إِجْلاَلِ اللَّهِ إِكْرَامَ ذِي الشَّيْبَةِ الْمُسْلِمِ وَحَامِلِ الْقُرْآنِ غَيْرِ الْغَالِي فِيهِ وَالْجَافِي عَنْهُ وَإِكْرَامَ ذِي السُّلْطَانِ الْمُقْسِطِ ‏"‏ ‏.‏\hadithno{4843}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMusa al-Ash'ari: The Prophet (ﷺ) said: Glorifying Allah involves showing honour to a grey-haired Muslim and to one who can expound the Qur'an, but not to one who acts extravagantly regarding it, or turns away from it, and showing honour to a just ruler}}
\hadithdefcmd{abudawud}{4844}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا عَامِرٌ الأَحْوَلُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، - قَالَ ابْنُ عَبْدَةَ - عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُجْلَسُ بَيْنَ رَجُلَيْنِ إِلاَّ بِإِذْنِهِمَا ‏"‏ ‏.‏\hadithno{4844}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) said: One should not sit between two men except with their permission}}
\hadithdefcmd{abudawud}{4845}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ اللَّيْثِيُّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِرَجُلٍ أَنْ يُفَرِّقَ بَيْنَ اثْنَيْنِ إِلاَّ بِإِذْنِهِمَا ‏"‏ ‏.‏\hadithno{4845}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) said: It is not lawful for a man to separate two persons except with their permission}}
\hadithdefcmd{abudawud}{4846}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي إِسْحَاقُ بْنُ مُحَمَّدٍ الأَنْصَارِيُّ، عَنْ رُبَيْحِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا جَلَسَ احْتَبَى بِيَدِهِ ‏.‏ قَالَ أَبُو دَاوُدَ عَبْدُ اللَّهِ بْنُ إِبْرَاهِيمَ شَيْخٌ مُنْكَرُ الْحَدِيثِ ‏.‏\hadithno{4846}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: When the Messenger of Allah (ﷺ) sat, he had his knees drawn up supported by his hands. Abu Dawud said: 'Abd Allah b. Ibrahim was an old man and his traditions were rejected}}
\hadithdefcmd{abudawud}{4847}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ حَسَّانَ الْعَنْبَرِيُّ، قَالَ حَدَّثَتْنِي جَدَّتَاىَ، صَفِيَّةُ وَدُحَيْبَةُ ابْنَتَا عُلَيْبَةَ - قَالَ مُوسَى بِنْتُ حَرْمَلَةَ - وَكَانَتَا رَبِيبَتَىْ قَيْلَةَ بِنْتِ مَخْرَمَةَ وَكَانَتْ جَدَّةَ أَبِيهِمَا أَنَّهَا أَخْبَرَتْهُمَا أَنَّهَا، رَأَتِ النَّبِيَّ صلى الله عليه وسلم وَهُوَ قَاعِدٌ الْقُرْفُصَاءَ فَلَمَّا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم الْمُخْتَشِعَ - وَقَالَ مُوسَى الْمُتَخَشِّعَ فِي الْجِلْسَةِ - أُرْعِدْتُ مِنَ الْفَرَقِ ‏.‏\hadithno{4847}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qaylah daughter of Makhramah: She saw the Prophet (ﷺ) sitting with his arms round his legs. She said: When I saw the Messenger of Allah (ﷺ) in such humble condition in the sitting position (according to Musa's version), I trembled with fear}}
\hadithdefcmd{abudawud}{4848}{حَدَّثَنَا عَلِيُّ بْنُ بَحْرٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ الشَّرِيدِ بْنِ سُوَيْدٍ، قَالَ مَرَّ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا جَالِسٌ هَكَذَا وَقَدْ وَضَعْتُ يَدِيَ الْيُسْرَى خَلْفَ ظَهْرِي وَاتَّكَأْتُ عَلَى أَلْيَةِ يَدِي فَقَالَ ‏ "‏ أَتَقْعُدُ قِعْدَةَ الْمَغْضُوبِ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{4848}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Amr b. al-Sharid quoted his father al-Sharid b. Suwaid as saying:The Messenger of Allah (ﷺ) came upon me when I was sitting thus: having my left hand behind my back and leaning on the fleshy part of it, and said: Are you sitting in the manner of those with whom Allah is angry?}}
\hadithdefcmd{abudawud}{4849}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عَوْفٍ، قَالَ حَدَّثَنِي أَبُو الْمِنْهَالِ، عَنْ أَبِي بَرْزَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ النَّوْمِ قَبْلَهَا وَالْحَدِيثِ بَعْدَهَا ‏.‏\hadithno{4849}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (599)}\hadithtrans{Abu Barzah said:the Messenger of Allah (ﷺ) forbade sleeping before the night prayer and talking after it}}
\hadithdefcmd{abudawud}{4850}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى الْفَجْرَ تَرَبَّعَ فِي مَجْلِسِهِ حَتَّى تَطْلُعَ الشَّمْسُ حَسْنَاءَ ‏.‏\hadithno{4850}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (670)}\hadithtrans{Jabir b. Samurah said:When the Prophet (ﷺ) prayed the dawn prayer, he sat cross-legged where he was till the sun had come well up}}
\hadithdefcmd{abudawud}{4851}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، - يَعْنِي ابْنَ سَلَمَةَ - عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْتَجِي اثْنَانِ دُونَ الثَّالِثِ فَإِنَّ ذَلِكَ يُحْزِنُهُ ‏"‏ ‏.‏\hadithno{4851}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (8184)}\hadithtrans{Abd Allah (b. Mas`ud) reported the Messenger of Allah (ﷺ) as saying:Two persons should not talk privately ignoring the third, for that will grieve him}}
\hadithdefcmd{abudawud}{4852}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِثْلَهُ ‏.‏ قَالَ أَبُو صَالِحٍ فَقُلْتُ لاِبْنِ عُمَرَ فَأَرْبَعَةٌ قَالَ لاَ يَضُرُّكَ ‏.‏\hadithno{4852}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A similar tradition has been transmitted by Ibn `Umar through a different chain of narrators. This version has:Abu Salih said: I asked Ibn `Umar: If they are four? He replied: Then it does not harm you}}
\hadithdefcmd{abudawud}{4853}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، قَالَ كُنْتُ عِنْدَ أَبِي جَالِسًا وَعِنْدَهُ غُلاَمٌ فَقَامَ ثُمَّ رَجَعَ فَحَدَّثَ أَبِي، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَامَ الرَّجُلُ مِنْ مَجْلِسٍ ثُمَّ رَجَعَ إِلَيْهِ فَهُوَ أَحَقُّ بِهِ ‏"‏ ‏.‏\hadithno{4853}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2179)}\hadithtrans{Abu Salih said:I was sitting with my father and there was also a boy with him. He got up and then returned. So my father mentioned a tradition on the authority of Abu Hurairah from the Prophet (ﷺ) saying: If anyone gets up from where he has been sitting and comes back to it, he has most right to it}}
\hadithdefcmd{abudawud}{4854}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا مُبَشِّرٌ الْحَلَبِيُّ، عَنْ تَمَّامِ بْنِ نَجِيحٍ، عَنْ كَعْبٍ الإِيَادِيِّ، قَالَ كُنْتُ أَخْتَلِفُ إِلَى أَبِي الدَّرْدَاءِ فَقَالَ أَبُو الدَّرْدَاءِ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا جَلَسَ وَجَلَسْنَا حَوْلَهُ فَقَامَ فَأَرَادَ الرُّجُوعَ نَزَعَ نَعْلَيْهِ أَوْ بَعْضَ مَا يَكُونُ عَلَيْهِ فَيَعْرِفُ ذَلِكَ أَصْحَابُهُ فَيَثْبُتُونَ ‏.‏\hadithno{4854}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbudDarda': The Messenger of Allah (ﷺ) would sit and we would also sit around him. If he got up intending to return, he would take off his sandals or something he was wearing, and his Companions recognising his purpose (that he would return) would stay where they were}}
\hadithdefcmd{abudawud}{4855}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ قَوْمٍ يَقُومُونَ مِنْ مَجْلِسٍ لاَ يَذْكُرُونَ اللَّهَ فِيهِ إِلاَّ قَامُوا عَنْ مِثْلِ جِيفَةِ حِمَارٍ وَكَانَ لَهُمْ حَسْرَةً ‏"‏ ‏.‏\hadithno{4855}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: People who get up from an assembly in which they did not remember Allah will be just as if they had got up from an ass's corpse, and it will be a cause of grief to them}}
\hadithdefcmd{abudawud}{4856}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ قَعَدَ مَقْعَدًا لَمْ يَذْكُرِ اللَّهَ فِيهِ كَانَتْ عَلَيْهِ مِنَ اللَّهِ تِرَةً وَمَنِ اضْطَجَعَ مَضْجَعًا لاَ يَذْكُرُ اللَّهَ فِيهِ كَانَتْ عَلَيْهِ مِنَ اللَّهِ تِرَةً ‏"‏ ‏.‏\hadithno{4856}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone sits at a place where he does not remember Allah, deprivation will descend on him from Allah; and if he lies at a place where he does not remember Allah, deprivation will descend on him from Allah}}
\hadithdefcmd{abudawud}{4857}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ سَعِيدَ بْنَ أَبِي هِلاَلٍ، حَدَّثَهُ أَنَّ سَعِيدَ بْنَ أَبِي سَعِيدٍ الْمَقْبُرِيَّ حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ قَالَ كَلِمَاتٌ لاَ يَتَكَلَّمُ بِهِنَّ أَحَدٌ فِي مَجْلِسِهِ عِنْدَ قِيَامِهِ ثَلاَثَ مَرَّاتٍ إِلاَّ كُفِّرَ بِهِنَّ عَنْهُ وَلاَ يَقُولُهُنَّ فِي مَجْلِسِ خَيْرٍ وَمَجْلِسِ ذِكْرٍ إِلاَّ خُتِمَ لَهُ بِهِنَّ عَلَيْهِ كَمَا يُخْتَمُ بِالْخَاتَمِ عَلَى الصَّحِيفَةِ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ لاَ إِلَهَ إِلاَّ أَنْتَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏.‏\hadithno{4857}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: There are some expressions which a man utters three times when he gets up from an assembly he will be forgiven for what happened in the assembly; and no one utters them in an assembly held for a noble cause or for remembrance of Allah but that is stamped with them just as a document is stamped with a signet-ring. These expressions are: Glory be to Thee, O Allah, and I begin with praise of Thee, there is no god but thou; I ask Thy pardon, and return to Thee in repentance}}
\hadithdefcmd{abudawud}{4858}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ قَالَ عَمْرٌو وَحَدَّثَنِي بِنَحْوِ، ذَلِكَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرٍو عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{4858}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{A similar tradition has also been transmitted by Abu Hurairah from the Prophet (ﷺ) through a different chain of narrators}}
\hadithdefcmd{abudawud}{4859}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْجَرْجَرَائِيُّ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - الْمَعْنَى - أَنَّ عَبْدَةَ بْنَ سُلَيْمَانَ، أَخْبَرَهُمْ عَنِ الْحَجَّاجِ بْنِ دِينَارٍ، عَنْ أَبِي هَاشِمٍ، عَنْ أَبِي الْعَالِيَةِ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ بِأَخَرَةٍ إِذَا أَرَادَ أَنْ يَقُومَ مِنَ الْمَجْلِسِ ‏"‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ أَنْتَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنَّكَ لَتَقُولُ قَوْلاً مَا كُنْتَ تَقُولُهُ فِيمَا مَضَى ‏.‏ قَالَ ‏"‏ كَفَّارَةٌ لِمَا يَكُونُ فِي الْمَجْلِسِ ‏"‏ ‏.‏\hadithno{4859}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuBarzah al-Aslami: When the Messenger of Allah (ﷺ) intended to get up from the assembly he used to say in the last. Glory be to Thee. O Allah, and I begin with praise of Thee, I testify that there is no god but Thou; I ask Thy pardon, and return to Thee in repentance. The man asked: Messenger of Allah! you utter the words now which you did not do in the past? He replied: (This is an) atonement for what takes place in the assembly}}
\hadithdefcmd{abudawud}{4860}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا الْفِرْيَابِيُّ، عَنْ إِسْرَائِيلَ، عَنِ الْوَلِيدِ، - قَالَ أَبُو دَاوُدَ وَنَسَبَهُ لَنَا زُهَيْرُ بْنُ حَرْبٍ - عَنْ حُسَيْنِ بْنِ مُحَمَّدٍ، عَنْ إِسْرَائِيلَ، فِي هَذَا الْحَدِيثِ - قَالَ الْوَلِيدُ بْنُ أَبِي هِشَامٍ - عَنْ زَيْدِ بْنِ زَائِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُبَلِّغْنِي أَحَدٌ مِنْ أَصْحَابِي عَنْ أَحَدٍ شَيْئًا فَإِنِّي أُحِبُّ أَنْ أَخْرُجَ إِلَيْكُمْ وَأَنَا سَلِيمُ الصَّدْرِ ‏"‏ ‏.‏\hadithno{4860}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: None of my Companions must tell me anything about anyone, for I like to come out to you with no ill-feelings}}
\hadithdefcmd{abudawud}{4861}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا نُوحُ بْنُ يَزِيدَ بْنِ سَيَّارٍ الْمُؤَدِّبُ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، قَالَ حَدَّثَنِيهِ ابْنُ إِسْحَاقَ، عَنْ عِيسَى بْنِ مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْفَغْوَاءِ الْخُزَاعِيِّ، عَنْ أَبِيهِ، قَالَ دَعَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ أَرَادَ أَنْ يَبْعَثَنِي بِمَالٍ إِلَى أَبِي سُفْيَانَ يَقْسِمُهُ فِي قُرَيْشٍ بِمَكَّةَ بَعْدَ الْفَتْحِ فَقَالَ ‏"‏ الْتَمِسْ صَاحِبًا ‏"‏ ‏.‏ قَالَ فَجَاءَنِي عَمْرُو بْنُ أُمَيَّةَ الضَّمْرِيُّ فَقَالَ بَلَغَنِي أَنَّكَ تُرِيدُ الْخُرُوجَ وَتَلْتَمِسُ صَاحِبًا ‏.‏ قَالَ قُلْتُ أَجَلْ ‏.‏ قَالَ فَأَنَا لَكَ صَاحِبٌ ‏.‏ قَالَ فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ قَدْ وَجَدْتُ صَاحِبًا ‏.‏ قَالَ فَقَالَ ‏"‏ مَنْ ‏"‏ ‏.‏ قُلْتُ عَمْرَو بْنَ أُمَيَّةَ الضَّمْرِيَّ ‏.‏ قَالَ ‏"‏ إِذَا هَبَطْتَ بِلاَدَ قَوْمِهِ فَاحْذَرْهُ فَإِنَّهُ قَدْ قَالَ الْقَائِلُ أَخُوكَ الْبِكْرِيُّ وَلاَ تَأْمَنْهُ ‏"‏ ‏.‏ فَخَرَجْنَا حَتَّى إِذَا كُنْتُ بِالأَبْوَاءِ قَالَ إِنِّي أُرِيدُ حَاجَةً إِلَى قَوْمِي بِوَدَّانَ فَتَلْبَثُ لِي قُلْتُ رَاشِدًا فَلَمَّا وَلَّى ذَكَرْتُ قَوْلَ النَّبِيِّ صلى الله عليه وسلم فَشَدَدْتُ عَلَى بَعِيرِي حَتَّى خَرَجْتُ أُوضِعُهُ حَتَّى إِذَا كُنْتُ بِالأَصَافِرِ إِذَا هُوَ يُعَارِضُنِي فِي رَهْطٍ قَالَ وَأَوْضَعْتُ فَسَبَقْتُهُ فَلَمَّا رَآنِي قَدْ فُتُّهُ انْصَرَفُوا وَجَاءَنِي فَقَالَ كَانَتْ لِي إِلَى قَوْمِي حَاجَةٌ ‏.‏ قَالَ قُلْتُ أَجَلْ وَمَضَيْنَا حَتَّى قَدِمْنَا مَكَّةَ فَدَفَعْتُ الْمَالَ إِلَى أَبِي سُفْيَانَ ‏.‏\hadithno{4861}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amr ibn al-Faghwa' al-Khuza'i: The Messenger of Allah (ﷺ) called me. He intended to send me with some goods to AbuSufyan to distribute among the Quraysh at Mecca after the conquest. He said: Search for a companion. Then Amr ibn Umayyah ad-Damri came to me and said: I have been told that you are intending to make a journey and are seeking a companion. I said: Yes. He said: I am your companion. I then went to the Messenger of Allah (ﷺ) and said: I have found a companion. He asked: Who is he? I replied: Amr ibn Umayyah ad-Damri. He said: When you come down to the territory of his people, be careful of him, for a maxim says: If one is your real brother, do not feel safe with him. So we proceeded, and when I reached al-Abwa', he said to me: I have some work with my people at Waddan, so stay here till I come back. I said: Do not lose your way. When he turned his back, I recalled the words of the Prophet (ﷺ). So I rode my camel and galloped without stopping. When I reached al-Asafir, he was pursuing me with a group of men. So I galloped and forged ahead of him. When he saw me that I had outstripped him, they returned and he came to me. He said to me: I had some work with my people. I said: Yes. We then went on until we reached Mecca, and I gave the goods to AbuSufyan}}
\hadithdefcmd{abudawud}{4862}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يُلْدَغُ الْمُؤْمِنُ مِنْ جُحْرٍ وَاحِدٍ مَرَّتَيْنِ ‏"‏ ‏.‏\hadithno{4862}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6133) Sahih Muslim (2998)}\hadithtrans{Abu Hurairah reported the Prophet(ﷺ) as saying:A believer is not stung twice from the same hole}}
\hadithdefcmd{abudawud}{4863}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا مَشَى كَأَنَّهُ يَتَوَكَّأُ ‏.‏\hadithno{4863}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas said:when the Prophet(ﷺ) walked, it looked as if he bent forwards}}
\hadithdefcmd{abudawud}{4864}{حَدَّثَنَا حُسَيْنُ بْنُ مُعَاذِ بْنِ خُلَيْفٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ الْجُرَيْرِيُّ، عَنْ أَبِي الطُّفَيْلِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قُلْتُ كَيْفَ رَأَيْتَهُ قَالَ كَانَ أَبْيَضَ مَلِيحًا إِذَا مَشَى كَأَنَّمَا يَهْوِي فِي صَبُوبٍ ‏.‏\hadithno{4864}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2340)}\hadithtrans{Sa’id al-Jariri quoted Abu al-Tufail as saying:I saw the Messenger of Allah(ﷺ). I asked: How did you see him? He said: He was white, good-looking, and when he walked, it looked as if he was descending to a low ground}}
\hadithdefcmd{abudawud}{4865}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَضَعَ - وَقَالَ قُتَيْبَةُ يَرْفَعَ الرَّجُلُ إِحْدَى - رِجْلَيْهِ عَلَى الأُخْرَى - زَادَ قُتَيْبَةُ - وَهُوَ مُسْتَلْقٍ عَلَى ظَهْرِهِ ‏.‏\hadithno{4865}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2099)}\hadithtrans{Jabir said:The Messenger of Allah(ﷺ) forbade that a man should lie placing(and according to Qutaibah’s version: “should raise”) one of his legs over the other. Qutaibah’s version adds: When he was lying on his back}}
\hadithdefcmd{abudawud}{4866}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم مُسْتَلْقِيًا - قَالَ الْقَعْنَبِيُّ - فِي الْمَسْجِدِ وَاضِعًا إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى ‏.‏\hadithno{4866}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (475) Sahih Muslim (2100)}\hadithtrans{‘Abbad b. Tamim quoted his paternal uncle as saying that he had seen the Messenger of Allah(ﷺ) lying on his back in the mosque according to Qa’nabi’s version) placing one foot over the other}}
\hadithdefcmd{abudawud}{4867}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رضى الله عنه وَعُثْمَانَ بْنَ عَفَّانَ كَانَا يَفْعَلاَنِ ذَلِكَ ‏.‏\hadithno{4867}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Sahih Bukhari (475)}\hadithtrans{Sa’id b. al-musayyab said :‘Umar b. al-khattab and ‘Uthman b. ‘Affan used to do that}}
\hadithdefcmd{abudawud}{4868}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَطَاءٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ جَابِرِ بْنِ عَتِيكٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَدَّثَ الرَّجُلُ بِالْحَدِيثِ ثُمَّ الْتَفَتَ فَهِيَ أَمَانَةٌ ‏"‏ ‏.‏\hadithno{4868}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: When a man tells something and then departs, it is a trust}}
\hadithdefcmd{abudawud}{4869}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، قَالَ قَرَأْتُ عَلَى عَبْدِ اللَّهِ بْنِ نَافِعٍ قَالَ أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، عَنِ ابْنِ أَخِي، جَابِرِ بْنِ عَبْدِ اللَّهِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَجَالِسُ بِالأَمَانَةِ إِلاَّ ثَلاَثَةَ مَجَالِسَ سَفْكُ دَمٍ حَرَامٍ أَوْ فَرْجٌ حَرَامٌ أَوِ اقْتِطَاعُ مَالٍ بِغَيْرِ حَقٍّ ‏"‏ ‏.‏\hadithno{4869}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: Meetings are confidential except three: those for the purpose of shedding blood unlawfully, or committing fornication, or acquiring property unjustly}}
\hadithdefcmd{abudawud}{4870}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَإِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، قَالاَ أَخْبَرَنَا أَبُو أُسَامَةَ، عَنْ عُمَرَ، - قَالَ إِبْرَاهِيمُ هُوَ عُمَرُ بْنُ حَمْزَةَ بْنِ عَبْدِ اللَّهِ الْعُمَرِيُّ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَعْدٍ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَعْظَمِ الأَمَانَةِ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ الرَّجُلَ يُفْضِي إِلَى امْرَأَتِهِ وَتُفْضِي إِلَيْهِ ثُمَّ يَنْشُرُ سِرَّهَا ‏"‏ ‏.‏\hadithno{4870}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Sahih Muslim (1437)}\hadithtrans{Abu sa’id al-khudri reported the Messenger of Allah (May peace be upon him) as saying:The most serious breach of trust in Allah’s sight is that a man who has intercourse with his wife, and she with him, spreads her secret}}
\hadithdefcmd{abudawud}{4871}{حَدَّثَنَا مُسَدَّدٌ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ قَتَّاتٌ ‏"‏ ‏.‏\hadithno{4871}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6056) Sahih Muslim (105)}\hadithtrans{Hudhaifah reported the Messenger of Allah (May peace be upon him) as saying :A mischief-maker will not enter paradise}}
\hadithdefcmd{abudawud}{4872}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْ شَرِّ النَّاسِ ذُو الْوَجْهَيْنِ الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ وَهَؤُلاَءِ بِوَجْهٍ ‏"‏ ‏.‏\hadithno{4872}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported the Prophet (May peace be upon him) as saying:The worst of the people is a man who is double-faced; he presents one face to some and another to others}}
\hadithdefcmd{abudawud}{4873}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنِ الرُّكَيْنِ بْنِ الرَّبِيعِ، عَنْ نُعَيْمِ بْنِ حَنْظَلَةَ، عَنْ عَمَّارٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ لَهُ وَجْهَانِ فِي الدُّنْيَا كَانَ لَهُ يَوْمَ الْقِيَامَةِ لِسَانَانِ مِنْ نَارٍ ‏"‏ ‏.‏\hadithno{4873}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ammar: The Prophet (ﷺ) said: He who is two-faced in this world will have two tongues of fire on the Day of Resurrection}}
\hadithdefcmd{abudawud}{4874}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قِيلَ يَا رَسُولَ اللَّهِ مَا الْغِيبَةُ قَالَ ‏"‏ ذِكْرُكَ أَخَاكَ بِمَا يَكْرَهُ ‏"‏ ‏.‏ قِيلَ أَفَرَأَيْتَ إِنْ كَانَ فِي أَخِي مَا أَقُولُ قَالَ ‏"‏ إِنْ كَانَ فِيهِ مَا تَقُولُ فَقَدِ اغْتَبْتَهُ وَإِنْ لَمْ يَكُنْ فِيهِ مَا تَقُولُ فَقَدْ بَهَتَّهُ ‏"‏ ‏.‏\hadithno{4874}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2589)}\hadithtrans{Abu Hurairah said:The Messenger of Allah (ﷺ) was asked: Messenger of Allah! What is back-biting? He replied: It is saying something about your brother which he would dislike. He was asked again: Tell me how the matter stands if what I say about my brother is true? He replied: If what you say of him is true, you have slandered him, and if what you say of him is not true, you have reviled him}}
\hadithdefcmd{abudawud}{4875}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي عَلِيُّ بْنُ الأَقْمَرِ، عَنْ أَبِي حُذَيْفَةَ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم حَسْبُكَ مِنْ صَفِيَّةَ كَذَا وَكَذَا قَالَ غَيْرُ مُسَدَّدٍ تَعْنِي قَصِيرَةً ‏.‏ فَقَالَ ‏"‏ لَقَدْ قُلْتِ كَلِمَةً لَوْ مُزِجَتْ بِمَاءِ الْبَحْرِ لَمَزَجَتْهُ ‏"‏ ‏.‏ قَالَتْ وَحَكَيْتُ لَهُ إِنْسَانًا فَقَالَ ‏"‏ مَا أُحِبُّ أَنِّي حَكَيْتُ إِنْسَانًا وَأَنَّ لِي كَذَا وَكَذَا ‏"‏ ‏.‏\hadithno{4875}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I said to the Prophet (ﷺ): It is enough for you in Safiyyah that she is such and such (the other version than Musaddad's has:) meaning that she was short-statured. He replied; You have said a word which would change the sea if it were mixed in it. She said: I imitated a man before him (out of disgrace). He said: I do not like that I imitate anyone even if I should get such and such}}
\hadithdefcmd{abudawud}{4876}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، حَدَّثَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي حُسَيْنٍ، حَدَّثَنَا نَوْفَلُ بْنُ مُسَاحِقٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مِنْ أَرْبَى الرِّبَا الاِسْتِطَالَةَ فِي عِرْضِ الْمُسْلِمِ بِغَيْرِ حَقٍّ ‏"‏ ‏.‏\hadithno{4876}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Sa'id ibn Zayd: The Prophet (ﷺ) said: The most prevalent kind of usury is going to lengths in talking unjustly against a Muslim's honour}}
\hadithdefcmd{abudawud}{4877}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، قَالَ حَدَّثَنَا زُهَيْرٌ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَكْبَرِ الْكَبَائِرِ اسْتِطَالَةَ الْمَرْءِ فِي عِرْضِ رَجُلٍ مُسْلِمٍ بِغَيْرِ حَقٍّ وَمِنَ الْكَبَائِرِ السَّبَّتَانِ بِالسَّبَّةِ ‏"‏ ‏.‏\hadithno{4877}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The gravest sin is going to lengths in talking unjustly against a Muslim's honour, and it is a major sin to abuse twice for abusing once}}
\hadithdefcmd{abudawud}{4878}{حَدَّثَنَا ابْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ، وَأَبُو الْمُغِيرَةِ، قَالاَ حَدَّثَنَا صَفْوَانُ، قَالَ حَدَّثَنِي رَاشِدُ بْنُ سَعْدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ جُبَيْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَمَّا عُرِجَ بِي مَرَرْتُ بِقَوْمٍ لَهُمْ أَظْفَارٌ مِنْ نُحَاسٍ يَخْمِشُونَ وُجُوهَهُمْ وَصُدُورَهُمْ فَقُلْتُ مَنْ هَؤُلاَءِ يَا جِبْرِيلُ قَالَ هَؤُلاَءِ الَّذِينَ يَأْكُلُونَ لُحُومَ النَّاسِ وَيَقَعُونَ فِي أَعْرَاضِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ حَدَّثَنَاهُ يَحْيَى بْنُ عُثْمَانَ عَنْ بَقِيَّةَ لَيْسَ فِيهِ أَنَسٌ ‏.‏\hadithno{4878}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: When I was taken up to heaven I passed by people who had nails of copper and were scratching their faces and their breasts. I said: Who are these people, Gabriel? He replied: They are those who were given to back biting and who aspersed people's honour. Abu Dawud said: Yahya b. 'Uthman has also transmitted it from Baqiyyah, there is no mention of Anas in it}}
\hadithdefcmd{abudawud}{4879}{حَدَّثَنَا عِيسَى بْنُ أَبِي عِيسَى السَّيْلَحِينِيُّ، عَنْ أَبِي الْمُغِيرَةِ، كَمَا قَالَ ابْنُ الْمُصَفَّى ‏.‏\hadithno{4879}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by ‘Isa b. Abi ‘Isa al-sailahini from Abu al-Mughirah, as Ibn al-musaffa said}}
\hadithdefcmd{abudawud}{4880}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ سَعِيدِ بْنِ عَبْدِ اللَّهِ بْنِ جُرَيْجٍ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ مَنْ آمَنَ بِلِسَانِهِ وَلَمْ يَدْخُلِ الإِيمَانُ قَلْبَهُ لاَ تَغْتَابُوا الْمُسْلِمِينَ وَلاَ تَتَّبِعُوا عَوْرَاتِهِمْ فَإِنَّهُ مَنِ اتَّبَعَ عَوْرَاتِهِمْ يَتَّبِعِ اللَّهُ عَوْرَتَهُ وَمَنْ يَتَّبِعِ اللَّهُ عَوْرَتَهُ يَفْضَحْهُ فِي بَيْتِهِ ‏"‏ ‏.‏\hadithno{4880}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuBarzah al-Aslami: The Prophet (ﷺ) said: O community of people, who believed by their tongue, and belief did not enter their hearts, do not back-bite Muslims, and do not search for their faults, for if anyone searches for their faults, Allah will search for his fault, and if Allah searches for the fault of anyone, He disgraces him in his house}}
\hadithdefcmd{abudawud}{4881}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْمِصْرِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنِ ابْنِ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ مَكْحُولٍ، عَنْ وَقَّاصِ بْنِ رَبِيعَةَ، عَنِ الْمُسْتَوْرِدِ، أَنَّهُ حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَكَلَ بِرَجُلٍ مُسْلِمٍ أَكْلَةً فَإِنَّ اللَّهَ يُطْعِمُهُ مِثْلَهَا مِنْ جَهَنَّمَ وَمَنْ كُسِيَ ثَوْبًا بِرَجُلٍ مُسْلِمٍ فَإِنَّ اللَّهَ يَكْسُوهُ مِثْلَهُ مِنْ جَهَنَّمَ وَمَنْ قَامَ بِرَجُلٍ مَقَامَ سُمْعَةٍ وَرِيَاءٍ فَإِنَّ اللَّهَ يَقُومُ بِهِ مَقَامَ سُمْعَةٍ وَرِيَاءٍ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4881}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Mustawrid: The Prophet (ﷺ) said: If anyone eats once at the cost of a Muslim's honour, Allah will give him a like amount of Jahannam to eat; if anyone clothes himself with a garment at the cost of a Muslim's honour, Allah will clothe him with like amount of Jahannam; and if anyone puts himself in a position of reputation and show Allah will disgrace him with a place of reputation and show on the Day of Resurrection}}
\hadithdefcmd{abudawud}{4882}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ الْمُسْلِمِ عَلَى الْمُسْلِمِ حَرَامٌ مَالُهُ وَعِرْضُهُ وَدَمُهُ حَسْبُ امْرِئٍ مِنَ الشَّرِّ أَنْ يَحْقِرَ أَخَاهُ الْمُسْلِمَ ‏"‏ ‏.‏\hadithno{4882}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :Everything of a Muslim is sacred to a Muslim : his property, honour and blood. It is enough evil for any man to despise his brother Muslim}}
\hadithdefcmd{abudawud}{4883}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ بْنِ عُبَيْدٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ سُلَيْمَانَ، عَنْ إِسْمَاعِيلَ بْنِ يَحْيَى الْمَعَافِرِيِّ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَمَى مُؤْمِنًا مِنْ مُنَافِقٍ ‏"‏ ‏.‏ أُرَاهُ قَالَ ‏"‏ بَعَثَ اللَّهُ مَلَكًا يَحْمِي لَحْمَهُ يَوْمَ الْقِيَامَةِ مِنْ نَارِ جَهَنَّمَ وَمَنْ رَمَى مُسْلِمًا بِشَىْءٍ يُرِيدُ شَيْنَهُ بِهِ حَبَسَهُ اللَّهُ عَلَى جِسْرِ جَهَنَّمَ حَتَّى يَخْرُجَ مِمَّا قَالَ ‏"‏ ‏.‏\hadithno{4883}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Anas: The Prophet (ﷺ) said: If anyone guards a believer from a hypocrite, Allah will send an angel who will guard his flesh on the Day of Resurrection from the fire of Jahannam; but if anyone attacks a Muslim saying something by which he wishes to disgrace him, he will be restrained by Allah on the bridge over Jahannam till he is acquitted of what he said}}
\hadithdefcmd{abudawud}{4884}{حَدَّثَنَا إِسْحَاقُ بْنُ الصَّبَّاحِ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا اللَّيْثُ، قَالَ حَدَّثَنِي يَحْيَى بْنُ سُلَيْمٍ، أَنَّهُ سَمِعَ إِسْمَاعِيلَ بْنَ بَشِيرٍ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، وَأَبَا، طَلْحَةَ بْنَ سَهْلٍ الأَنْصَارِيَّ يَقُولاَنِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنِ امْرِئٍ يَخْذُلُ امْرَأً مُسْلِمًا فِي مَوْضِعٍ تُنْتَهَكُ فِيهِ حُرْمَتُهُ وَيُنْتَقَصُ فِيهِ مِنْ عِرْضِهِ إِلاَّ خَذَلَهُ اللَّهُ فِي مَوْطِنٍ يُحِبُّ فِيهِ نُصْرَتَهُ وَمَا مِنِ امْرِئٍ يَنْصُرُ مُسْلِمًا فِي مَوْضِعٍ يُنْتَقَصُ فِيهِ مِنْ عِرْضِهِ وَيُنْتَهَكُ فِيهِ مِنْ حُرْمَتِهِ إِلاَّ نَصَرَهُ اللَّهُ فِي مَوْطِنٍ يُحِبُّ نُصْرَتَهُ ‏"‏ ‏.‏ قَالَ يَحْيَى وَحَدَّثَنِيهِ عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ وَعُقْبَةُ بْنُ شَدَّادٍ ‏.‏ قَالَ أَبُو دَاوُدَ يَحْيَى بْنُ سُلَيْمٍ هَذَا هُوَ ابْنُ زَيْدٍ مَوْلَى النَّبِيِّ صلى الله عليه وسلم وَإِسْمَاعِيلُ بْنُ بَشِيرٍ مَوْلَى بَنِي مَغَالَةَ وَقَدْ قِيلَ عُتْبَةُ بْنُ شَدَّادٍ مَوْضِعَ عُقْبَةَ ‏.‏\hadithno{4884}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah ; AbuTalhah ibn Sahl al-Ansari: The Prophet (ﷺ) said: No (Muslim) man will desert a man who is a Muslim in a place where his respect may be violated and his honour aspersed without Allah deserting him in a place here he wishes his help; and no (Muslim) man who will help a Muslim in a place where his honour may be aspersed and his respect violated without Allah helping him in a place where he wishes his help. Yahya said: 'Ubaid Allah b. 'Abd Allah b. 'Umar and 'Uqbah b. Shaddad transmitted it to me. Abu Dawud said: This yahya b. Sulaim is the son of Zaid, the freed slave of the Prophet (ﷺ), and Isma'il b. Bashir is the freed slave of Banu Maghalah. Sometimes the name of 'Utbah b. Shaddad is mentioned instead of 'Uqbah}}
\hadithdefcmd{abudawud}{4885}{حَدَّثَنَا عَلِيُّ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، مِنْ كِتَابِهِ قَالَ حَدَّثَنِي أَبِي، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ أَبِي عَبْدِ اللَّهِ الْجُشَمِيِّ، قَالَ حَدَّثَنَا جُنْدُبٌ، قَالَ جَاءَ أَعْرَابِيٌّ فَأَنَاخَ رَاحِلَتَهُ ثُمَّ عَقَلَهَا ثُمَّ دَخَلَ الْمَسْجِدَ فَصَلَّى خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَتَى رَاحِلَتَهُ فَأَطْلَقَهَا ثُمَّ رَكِبَ ثُمَّ نَادَى اللَّهُمَّ ارْحَمْنِي وَمُحَمَّدًا وَلاَ تُشْرِكْ فِي رَحْمَتِنَا أَحَدًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتَقُولُونَ هُوَ أَضَلُّ أَمْ بَعِيرُهُ أَلَمْ تَسْمَعُوا إِلَى مَا قَالَ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏\hadithno{4885}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jundub: A desert Arab came and making his camel kneel and tethering it, entered the mosque and prayed behind the Messenger of Allah (ﷺ). When The Messenger of Allah (ﷺ) had given the salutation, he went to his riding beast and, after untethering and riding it, he called out: O Allah, show mercy to me and to Muhammad and associate no one else in Thy mercy to us. The Messenger of Allah (ﷺ) then said: Do you think that he or his camel is farther astray? Did you not listen to what he said? They replied: Certainly}}
\hadithdefcmd{abudawud}{4886}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا ابْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، قَالَ أَيَعْجَزُ أَحَدُكُمْ أَنْ يَكُونَ، مِثْلَ أَبِي ضَيْغَمٍ - أَوْ ضَمْضَمٍ شَكَّ ابْنُ عُبَيْدٍ - كَانَ إِذَا أَصْبَحَ قَالَ اللَّهُمَّ إِنِّي قَدْ تَصَدَّقْتُ بِعِرْضِي عَلَى عِبَادِكَ ‏.‏\hadithno{4886}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qatadah: Is one of you helpless to be like AbuDaygham or Damdam (Ibn Ubayd is doubtful) who would say when morning came: O Allah, I gave my honour as alms to Thy servants?}}
\hadithdefcmd{abudawud}{4887}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَجْلاَنَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيَعْجَزُ أَحَدُكُمْ أَنْ يَكُونَ مِثْلَ أَبِي ضَمْضَمٍ ‏"‏ ‏.‏ قَالُوا وَمَنْ أَبُو ضَمْضَمٍ قَالَ ‏"‏ رَجُلٌ فِيمَنْ كَانَ مِنْ قَبْلِكُمْ ‏"‏ ‏.‏ بِمَعْنَاهُ قَالَ ‏"‏ عِرْضِي لِمَنْ شَتَمَنِي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ هَاشِمُ بْنُ الْقَاسِمِ قَالَ عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ الْعَمِّيِّ عَنْ ثَابِتٍ قَالَ حَدَّثَنَا أَنَسٌ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ حَمَّادٍ أَصَحُّ ‏.‏\hadithno{4887}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abd al-Rahman b. ‘Ajlan reported the Messenger of Allah (May peace be upon him) as saying :Is one of you unable to be like Abu Damdam? The people asked: who is Abu Damdam? He replied : A man of old before you. He then mentioned the rest of tradition to the tradition to the same effect. This version has : who would say (in the morning) : My honors is for the one who reviles me. Abu Dawud said: This tradition has also been transmitted by Hashim bin al-Qasim from Muhammad b. 'Adb Allah al-'Ammi from Thabit on the authority of Anas from Prophet (ﷺ) to the same effect. Abu Dawud said: The tradition of Hammad (i.e. 'Abd al-Rahman's version) is sounder}}
\hadithdefcmd{abudawud}{4888}{حَدَّثَنَا عِيسَى بْنُ مُحَمَّدٍ الرَّمْلِيُّ، وَابْنُ، عَوْفٍ - وَهَذَا لَفْظُهُ - قَالاَ حَدَّثَنَا الْفِرْيَابِيُّ، عَنْ سُفْيَانَ، عَنْ ثَوْرٍ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ مُعَاوِيَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّكَ إِنِ اتَّبَعْتَ عَوْرَاتِ النَّاسِ أَفْسَدْتَهُمْ أَوْ كِدْتَ أَنْ تُفْسِدَهُمْ ‏"‏ ‏.‏ فَقَالَ أَبُو الدَّرْدَاءِ كَلِمَةٌ سَمِعَهَا مُعَاوِيَةُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم نَفَعَهُ اللَّهُ تَعَالَى بِهَا ‏.‏\hadithno{4888}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Mu'awiyah: I heard the Messenger of Allah (ﷺ) say: If you search for the faults of the people, you will corrupt them, or will nearly corrupt them. AbudDarda' said: These are the words which Mu'awiyah himself from the Messenger of Allah (ﷺ), and Allah benefited him by them}}
\hadithdefcmd{abudawud}{4889}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الْحَضْرَمِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا ضَمْضَمُ بْنُ زُرْعَةَ، عَنْ شُرَيْحِ بْنِ عُبَيْدٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، وَكَثِيرِ بْنِ مُرَّةَ، وَعَمْرِو بْنِ الأَسْوَدِ، وَالْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، وَأَبِي، أُمَامَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الأَمِيرَ إِذَا ابْتَغَى الرِّيبَةَ فِي النَّاسِ أَفْسَدَهُمْ ‏"‏ ‏.‏\hadithno{4889}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Miqdam ibn Ma'dikarib ; AbuUmamah: The Prophet (ﷺ) said: When a ruler seeks to make imputations against the people, he corrupts them}}
\hadithdefcmd{abudawud}{4890}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، قَالَ أُتِيَ ابْنُ مَسْعُودٍ فَقِيلَ هَذَا فُلاَنٌ تَقْطُرُ لِحْيَتُهُ خَمْرًا فَقَالَ عَبْدُ اللَّهِ إِنَّا قَدْ نُهِينَا عَنِ التَّجَسُّسِ وَلَكِنْ إِنْ يَظْهَرْ لَنَا شَىْءٌ نَأْخُذْ بِهِ ‏.‏\hadithno{4890}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: Zayd ibn Wahb said: A man was brought to Ibn Mas'ud. He was told: This is so and so, and wine was dropping from his beard. Abdullah thereupon said: We have been prohibited to seek out (faults). If anything becomes manifest to us, we shall seize it}}
\hadithdefcmd{abudawud}{4891}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ إِبْرَاهِيمَ بْنِ نَشِيطٍ، عَنْ كَعْبِ بْنِ عَلْقَمَةَ، عَنْ أَبِي الْهَيْثَمِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ رَأَى عَوْرَةً فَسَتَرَهَا كَانَ كَمَنْ أَحْيَا مَوْءُودَةً ‏"‏ ‏.‏\hadithno{4891}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Uqbah ibn Amir: The Prophet (ﷺ) said: He who sees something which should be kept hidden and conceals it will be like one who has brought to life a girl buried alive}}
\hadithdefcmd{abudawud}{4892}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا اللَّيْثُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ نَشِيطٍ، عَنْ كَعْبِ بْنِ عَلْقَمَةَ، أَنَّهُ سَمِعَ أَبَا الْهَيْثَمِ، يَذْكُرُ أَنَّهُ سَمِعَ دُخَيْنًا، كَاتِبَ عُقْبَةَ بْنِ عَامِرٍ قَالَ كَانَ لَنَا جِيرَانٌ يَشْرَبُونَ الْخَمْرَ فَنَهَيْتُهُمْ فَلَمْ يَنْتَهُوا فَقُلْتُ لِعُقْبَةَ بْنِ عَامِرٍ إِنَّ جِيرَانَنَا هَؤُلاَءِ يَشْرَبُونَ الْخَمْرَ وَإِنِّي نَهَيْتُهُمْ فَلَمْ يَنْتَهُوا فَأَنَا دَاعٍ لَهُمُ الشُّرَطَ ‏.‏ فَقَالَ دَعْهُمْ ‏.‏ ثُمَّ رَجَعْتُ إِلَى عُقْبَةَ مَرَّةً أُخْرَى فَقُلْتُ إِنَّ جِيرَانَنَا قَدْ أَبَوْا أَنْ يَنْتَهُوا عَنْ شُرْبِ الْخَمْرِ وَأَنَا دَاعٍ لَهُمُ الشُّرَطَ ‏.‏ قَالَ وَيْحَكَ دَعْهُمْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مَعْنَى حَدِيثِ مُسْلِمٍ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ هَاشِمُ بْنُ الْقَاسِمِ عَنْ لَيْثٍ فِي هَذَا الْحَدِيثِ قَالَ لاَ تَفْعَلْ وَلَكِنْ عِظْهُمْ وَتَهَدَّدْهُمْ ‏.‏\hadithno{4892}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Uqbah ibn Amir: AbulHaytham quoted Dukhayn, the scribe of Uqbah ibn Amir, saying: We had some neighbours who used to drink wine. I forbade them, but they did not stop. I then said to Uqbah ibn Amir: These neighbours of ours drink wine, and I tried to prevent them but they did not stop, and I am going to call the police about them. He said: Leave them. I again came to Uqbah ibn Amir and said: Our neighbours have refused to refrain from drinking wine, and I am going to call the police for them. He said: Woe to thee! Leave them alone. I heard the Messenger of Allah (ﷺ) say: he then mentioned the tradition to the same effect as recorded above on the authority of the narrator Muslim. Abu Dawud said: In this version Hashim b. al-Qasim said on the authority of Laith: Do not do it, but preach them and threaten them}}
\hadithdefcmd{abudawud}{4893}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْلِمُ أَخُو الْمُسْلِمِ لاَ يَظْلِمُهُ وَلاَ يُسْلِمُهُ مَنْ كَانَ فِي حَاجَةِ أَخِيهِ فَإِنَّ اللَّهَ فِي حَاجَتِهِ وَمَنْ فَرَّجَ عَنْ مُسْلِمٍ كُرْبَةً فَرَّجَ اللَّهُ عَنْهُ بِهَا كُرْبَةً مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ وَمَنْ سَتَرَ مُسْلِمًا سَتَرَهُ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4893}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2442) Sahih Muslim (2580)}\hadithtrans{‘Abd Allah b. Umar reported the prophet (May peace be upon him) as saying :A Muslim is a Muslim’s brother: he does not wrong him or abandon him. If anyone cares for his brother’s need, Allah will care for his need ; if anyone removes a Muslim’s anxiety, Allah will remove from him, on account of it, one of the anxieties of the Day of resurrection ; and if anyone conceals a Muslim’s fault, Allah will conceal his fault on the Day of resurrection}}
\hadithdefcmd{abudawud}{4894}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْتَبَّانِ مَا قَالاَ فَعَلَى الْبَادِي مِنْهُمَا مَا لَمْ يَعْتَدِ الْمَظْلُومُ ‏"‏ ‏.‏\hadithno{4894}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2587)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:when two men abuse one another, what they say is laid to the charge of the one who began it, so long as the one who is wronged does not go over the score}}
\hadithdefcmd{abudawud}{4895}{حَدَّثَنَا أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنِ الْحَجَّاجِ، عَنْ قَتَادَةَ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ عِيَاضِ بْنِ حِمَارٍ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ أَوْحَى إِلَىَّ أَنْ تَوَاضَعُوا حَتَّى لاَ يَبْغِيَ أَحَدٌ عَلَى أَحَدٍ وَلاَ يَفْخَرَ أَحَدٌ عَلَى أَحَدٍ ‏"‏ ‏.‏\hadithno{4895}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Iyad ibn Himar (al-Mujashi'i): The Prophet (ﷺ) said: Allah has revealed to me that you must be humble, so that no one oppresses another and boasts over another}}
\hadithdefcmd{abudawud}{4896}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ بَشِيرِ بْنِ الْمُحَرَّرِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ وَمَعَهُ أَصْحَابُهُ وَقَعَ رَجُلٌ بِأَبِي بَكْرٍ فَآذَاهُ فَصَمَتَ عنه أَبُو بَكْرٍ ثُمَّ آذَاهُ الثَّانِيَةَ فَصَمَتَ عَنْهُ أَبُو بَكْرٍ ثُمَّ آذَاهُ الثَّالِثَةَ فَانْتَصَرَ مِنْهُ أَبُو بَكْرٍ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ انْتَصَرَ أَبُو بَكْرٍ فَقَالَ أَبُو بَكْرٍ أَوَجَدْتَ عَلَىَّ يَا رَسُولَ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَزَلَ مَلَكٌ مِنَ السَّمَاءِ يُكَذِّبُهُ بِمَا قَالَ لَكَ فَلَمَّا انْتَصَرْتَ وَقَعَ الشَّيْطَانُ فَلَمْ أَكُنْ لأَجْلِسَ إِذْ وَقَعَ الشَّيْطَانُ ‏"‏ ‏.‏\hadithno{4896}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sa'id ibn al-Musayyab: While the Messenger of Allah (ﷺ) was sitting with some of his companions, a man reviled AbuBakr and insulted him. But AbuBakr remained silent. He insulted him twice, but AbuBakr controlled himself. He insulted him thrice and AbuBakr took revenge on him. Then the Messenger of Allah (ﷺ) got up when AbuBakr took revenge. AbuBakr said: Were you angry with me, Messenger of Allah? The Messenger of Allah (ﷺ) replied: An angel came down from Heaven and he was rejecting what he had said to you. When you took revenge, a devil came down. I was not going to sit when the devil came down}}
\hadithdefcmd{abudawud}{4897}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، كَانَ يَسُبُّ أَبَا بَكْرٍ وَسَاقَ نَحْوَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ صَفْوَانُ بْنُ عِيسَى عَنِ ابْنِ عَجْلاَنَ، كَمَا قَالَ سُفْيَانُ ‏.‏\hadithno{4897}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Hurairah through a different chain of narrators. This version has:A man was reviling Abu Bakr. He then mentioned the rest of the tradition in a similar manner. Abu Dawud said: Similarly, it has been transmitted by Safwan b. ‘Isa, from Ibn ‘Affan, as Sufyan said}}
\hadithdefcmd{abudawud}{4898}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، - الْمَعْنَى وَاحِدٌ - قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، قَالَ كُنْتُ أَسْأَلُ عَنْ الاِنْتِصَارِ، ‏\{‏ وَلَمَنِ انْتَصَرَ بَعْدَ ظُلْمِهِ فَأُولَئِكَ مَا عَلَيْهِمْ مِنْ سَبِيلٍ ‏\}‏ فَحَدَّثَنِي عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ عَنْ أُمِّ مُحَمَّدٍ امْرَأَةِ أَبِيهِ قَالَ ابْنُ عَوْنٍ وَزَعَمُوا أَنَّهَا كَانَتْ تَدْخُلُ عَلَى أُمِّ الْمُؤْمِنِينَ قَالَتْ قَالَتْ أُمُّ الْمُؤْمِنِينَ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدَنَا زَيْنَبُ بِنْتُ جَحْشٍ فَجَعَلَ يَصْنَعُ شَيْئًا بِيَدِهِ فَقُلْتُ بِيَدِهِ حَتَّى فَطَنْتُهُ لَهَا فَأَمْسَكَ وَأَقْبَلَتْ زَيْنَبُ تَقْحَمُ لِعَائِشَةَ رضى الله عنها فَنَهَاهَا فَأَبَتْ أَنْ تَنْتَهِيَ فَقَالَ لِعَائِشَةَ ‏"‏ سُبِّيهَا ‏"‏ فَسَبَّتْهَا فَغَلَبَتْهَا فَانْطَلَقَتْ زَيْنَبُ إِلَى عَلِيٍّ رضى الله عنه فَقَالَتْ إِنَّ عَائِشَةَ رضى الله عنها وَقَعَتْ بِكُمْ وَفَعَلَتْ ‏.‏ فَجَاءَتْ فَاطِمَةُ فَقَالَ لَهَا ‏"‏ إِنَّهَا حِبَّةُ أَبِيكِ وَرَبِّ الْكَعْبَةِ ‏"‏ ‏.‏ فَانْصَرَفَتْ فَقَالَتْ لَهُمْ إِنِّي قُلْتُ لَهُ كَذَا وَكَذَا فَقَالَ لِي كَذَا وَكَذَا ‏.‏ قَالَ وَجَاءَ عَلِيٌّ رضى الله عنه إِلَى النَّبِيِّ صلى الله عليه وسلم فَكَلَّمَهُ فِي ذَلِكَ ‏.‏\hadithno{4898}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Ibn Awn said: I asked about the meaning of intisar (revenge) in the Qur'anic verse: "But indeed if any do help and defend themselves (intasara) after a wrong (done) to them, against them there is no cause of blame." Then Ali ibn Zayd ibn Jad'an told me on the authority of Umm Muhammad, the wife of his father. Ibn Awn said: It was believed that she used to go to the Mother of the Faithful (i.e. Aisha). She said: The Mother of the Faithful said: The Messenger of Allah (ﷺ) came upon me while Zaynab, daughter of Jahsh, was with us. He began to do something with his hand. I signalled to him until I made him understand about her. So he stopped. Zaynab came on and began to abuse Aisha. She tried to prevent her but she did not stop. So he (the Prophet) said to Aisha: Abuse her. So she abused her and dominated her. Zaynab then went to Ali and said: Aisha abused you and did (such and such). Then Fatimah came (to the Prophet) and he said to her: She is the favourite of your father, by the Lord of the Ka'bah! She then returned and said to them: I said to him such and such, and he said to me such and such. Then Ali came to the Prophet (ﷺ) and spoke to him about that}}
\hadithdefcmd{abudawud}{4899}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَاتَ صَاحِبُكُمْ فَدَعُوهُ لاَ تَقَعُوا فِيهِ ‏"‏ ‏.‏\hadithno{4899}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A’ishah reported the Messenger of Allah (May peace be upon him) as saying :When your companion dies, leave him and do not revile him}}
\hadithdefcmd{abudawud}{4900}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ عِمْرَانَ بْنِ أَنَسٍ الْمَكِّيِّ، عَنْ عَطَاءٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اذْكُرُوا مَحَاسِنَ مَوْتَاكُمْ وَكُفُّوا عَنْ مَسَاوِيهِمْ ‏"‏ ‏.‏\hadithno{4900}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: Make a mention of the virtues of your dead, and refrain from (mentioning) their evils}}
\hadithdefcmd{abudawud}{4901}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، أَخْبَرَنَا عَلِيُّ بْنُ ثَابِتٍ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، قَالَ حَدَّثَنِي ضَمْضَمُ بْنُ جَوْسٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ كَانَ رَجُلاَنِ فِي بَنِي إِسْرَائِيلَ مُتَآخِيَيْنِ فَكَانَ أَحَدُهُمَا يُذْنِبُ وَالآخَرُ مُجْتَهِدٌ فِي الْعِبَادَةِ فَكَانَ لاَ يَزَالُ الْمُجْتَهِدُ يَرَى الآخَرَ عَلَى الذَّنْبِ فَيَقُولُ أَقْصِرْ ‏.‏ فَوَجَدَهُ يَوْمًا عَلَى ذَنْبٍ فَقَالَ لَهُ أَقْصِرْ فَقَالَ خَلِّنِي وَرَبِّي أَبُعِثْتَ عَلَىَّ رَقِيبًا فَقَالَ وَاللَّهِ لاَ يَغْفِرُ اللَّهُ لَكَ أَوْ لاَ يُدْخِلُكَ اللَّهُ الْجَنَّةَ ‏.‏ فَقُبِضَ أَرْوَاحُهُمَا فَاجْتَمَعَا عِنْدَ رَبِّ الْعَالَمِينَ فَقَالَ لِهَذَا الْمُجْتَهِدِ أَكُنْتَ بِي عَالِمًا أَوْ كُنْتَ عَلَى مَا فِي يَدِي قَادِرًا وَقَالَ لِلْمُذْنِبِ اذْهَبْ فَادْخُلِ الْجَنَّةَ بِرَحْمَتِي وَقَالَ لِلآخَرِ اذْهَبُوا بِهِ إِلَى النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَالَّذِي نَفْسِي بِيَدِهِ لَتَكَلَّمَ بِكَلِمَةٍ أَوْبَقَتْ دُنْيَاهُ وَآخِرَتَهُ ‏.‏\hadithno{4901}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: I heard the Messenger of Allah (ﷺ) say: There were two men among Banu Isra'il, who were striving for the same goal. One of them would commit sin and the other would strive to do his best in the world. The man who exerted himself in worship continued to see the other in sin. He would say: Refrain from it. One day he found him in sin and said to him: Refrain from it. He said: Leave me alone with my Lord. Have you been sent as a watchman over me? He said: I swear by Allah, Allah will not forgive you, nor will he admit you to Paradise. Then their souls were taken back (by Allah), and they met together with the Lord of the worlds. He (Allah) said to this man who had striven hard in worship; Had you knowledge about Me or had you power over that which I had in My hand? He said to the man who sinned: Go and enter Paradise by My mercy. He said about the other: Take him to Hell. AbuHurayrah said: By Him in Whose hand my soul is, he spoke a word by which this world and the next world of his were destroyed}}
\hadithdefcmd{abudawud}{4902}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ عُيَيْنَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ ذَنْبٍ أَجْدَرُ أَنْ يُعَجِّلَ اللَّهُ تَعَالَى لِصَاحِبِهِ الْعُقُوبَةَ فِي الدُّنْيَا - مَعَ مَا يَدَّخِرُ لَهُ فِي الآخِرَةِ - مِثْلُ الْبَغْىِ وَقَطِيعَةِ الرَّحِمِ ‏"‏ ‏.‏\hadithno{4902}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuBakrah: The Prophet (ﷺ) said: There is no sin more fitted to have punishment meted out by Allah to its perpetrator in advance in this world along with what He stores up for him in the next world than oppression and severing ties of relationship}}
\hadithdefcmd{abudawud}{4903}{حَدَّثَنَا عُثْمَانُ بْنُ صَالِحٍ الْبَغْدَادِيُّ، حَدَّثَنَا أَبُو عَامِرٍ، - يَعْنِي عَبْدَ الْمَلِكِ بْنَ عَمْرٍو - حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي أَسِيدٍ، عَنْ جَدِّهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْحَسَدَ فَإِنَّ الْحَسَدَ يَأْكُلُ الْحَسَنَاتِ كَمَا تَأْكُلُ النَّارُ الْحَطَبَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ الْعُشْبَ ‏"‏ ‏.‏\hadithno{4903}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Avoid envy, for envy devours good deeds just as fire devours fuel or (he said) "grass}}
\hadithdefcmd{abudawud}{4904}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الْعَمْيَاءِ، أَنَّ سَهْلَ بْنَ أَبِي أُمَامَةَ، حَدَّثَهُ أَنَّهُ، دَخَلَ هُوَ وَأَبُوهُ عَلَى أَنَسِ بْنِ مَالِكٍ بِالْمَدِينَةِ فِي زَمَانِ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ وَهُوَ أَمِيرُ الْمَدِينَةِ فَإِذَا هُوَ يُصَلِّي صَلاَةً خَفِيفَةً دَقِيقَةً كَأَنَّهَا صَلاَةُ مُسَافِرٍ أَوْ قَرِيبًا مِنْهَا فَلَمَّا سَلَّمَ قَالَ أَبِي يَرْحَمُكَ اللَّهُ أَرَأَيْتَ هَذِهِ الصَّلاَةَ الْمَكْتُوبَةَ أَوْ شَىْءٌ تَنَفَّلْتَهُ قَالَ إِنَّهَا الْمَكْتُوبَةُ وَإِنَّهَا لَصَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أَخْطَأْتُ إِلاَّ شَيْئًا سَهَوْتُ عَنْهُ - فَقَالَ - إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏"‏ لاَ تُشَدِّدُوا عَلَى أَنْفُسِكُمْ فَيُشَدَّدَ عَلَيْكُمْ فَإِنَّ قَوْمًا شَدَّدُوا عَلَى أَنْفُسِهِمْ فَشَدَّدَ اللَّهُ عَلَيْهِمْ فَتِلْكَ بَقَايَاهُمْ فِي الصَّوَامِعِ وَالدِّيَارِ ‏\{‏ رَهْبَانِيَّةً ابْتَدَعُوهَا مَا كَتَبْنَاهَا عَلَيْهِمْ ‏\}‏ ‏"‏ ‏.‏ ثُمَّ غَدَا مِنَ الْغَدِ فَقَالَ أَلاَ تَرْكَبُ لِتَنْظُرَ وَلِتَعْتَبِرَ قَالَ نَعَمْ فَرَكِبُوا جَمِيعًا فَإِذَا هُمْ بِدِيَارٍ بَادَ أَهْلُهَا وَانْقَضَوْا وَفَنَوْا خَاوِيَةً عَلَى عُرُوشِهَا فَقَالَ ‏"‏ أَتَعْرِفُ هَذِهِ الدِّيَارَ ‏"‏ ‏.‏ فَقُلْتُ مَا أَعْرَفَنِي بِهَا وَبِأَهْلِهَا هَذِهِ دِيَارُ قَوْمٍ أَهْلَكَهُمُ الْبَغْىُ وَالْحَسَدُ إِنَّ الْحَسَدَ يُطْفِئُ نُورَ الْحَسَنَاتِ وَالْبَغْىُ يُصَدِّقُ ذَلِكَ أَوْ يُكَذِّبُهُ وَالْعَيْنُ تَزْنِي وَالْكَفُّ وَالْقَدَمُ وَالْجَسَدُ وَاللِّسَانُ وَالْفَرْجُ يُصَدِّقُ ذَلِكَ أَوْ يُكَذِّبُهُ ‏.‏\hadithno{4904}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: Sahl ibn AbuUmamah said that he and his father (AbuUmamah) visited Anas ibn Malik at Medina during the time (rule) of Umar ibn AbdulAziz when he (Anas ibn Malik) was the governor of Medina. He was praying a very short prayer as if it were the prayer of a traveller or near it. When he gave a greeting, my father said: May Allah have mercy on you! Tell me about this prayer: Is it obligatory or supererogatory? He said: It is obligatory; it is the prayer performed by the Messenger of Allah (ﷺ). I did not make a mistake except in one thing that I forgot. He said: The Messenger of Allah (ﷺ) used to say: Do not impose austerities on yourselves so that austerities will be imposed on you, for people have imposed austerities on themselves and Allah imposed austerities on them. Their survivors are to be found in cells and monasteries. (Then he quoted:) "Monasticism, they invented it; we did not prescribe it for them." Next day he went out in the morning and said: will you not go out for a ride, so that you may see something and take a lesson from it? He said: Yes. Then all of them rode away and reached a land whose inhabitants had perished, passed away and died. The roofs of the town had fallen in. He asked: Do you know this land? I said: Who acquainted me with it and its inhabitants? (Anas said:) This is the land of the people whom oppression and envy destroyed. Envy extinguishes the light of good deeds, and oppression confirms or falsifies it. The eye commits fornication, and the palm of the hand, the foot, body, tongue and private part of the body confirm it or deny it}}
\hadithdefcmd{abudawud}{4905}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا الْوَلِيدُ بْنُ رَبَاحٍ، قَالَ سَمِعْتُ نِمْرَانَ، يَذْكُرُ عَنْ أُمِّ الدَّرْدَاءِ، قَالَتْ سَمِعْتُ أَبَا الدَّرْدَاءِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْعَبْدَ إِذَا لَعَنَ شَيْئًا صَعِدَتِ اللَّعْنَةُ إِلَى السَّمَاءِ فَتُغْلَقُ أَبْوَابُ السَّمَاءِ دُونَهَا ثُمَّ تَهِبْطُ إِلَى الأَرْضِ فَتُغْلَقُ أَبْوَابُهَا دُونَهَا ثُمَّ تَأْخُذُ يَمِينًا وَشِمَالاً فَإِذَا لَمْ تَجِدْ مَسَاغًا رَجَعَتْ إِلَى الَّذِي لُعِنَ فَإِنْ كَانَ لِذَلِكَ أَهْلاً وَإِلاَّ رَجَعَتْ إِلَى قَائِلِهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مَرْوَانُ بْنُ مُحَمَّدٍ هُوَ رَبَاحُ بْنُ الْوَلِيدِ سَمِعَ مِنْهُ وَذَكَرَ أَنَّ يَحْيَى بْنَ حَسَّانَ وَهِمَ فِيهِ ‏.‏\hadithno{4905}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu al-Darda’ reported the Messenger of Allah (May peace be upon him) as saying :when a man cures anything, the curse goes up to heaven and the gates of heaven are locked against it. Then it comes down to the earth and its gates are locked against it. Then it goes right and left, and if it finds no place of entrance it returns to the thing which was cursed, and if it finds no place of entrance it returns to the thing which was cursed, and if it deserves what was said (it enters it), otherwise it returns to the one who uttered it. Abu Dawud said : Marwan b. Muhammad said: He is Rabah b. al-Walid who heard from him (nimran). He (Marwan b. Muhammad) said: Yahya b. Hussain was confused in it}}
\hadithdefcmd{abudawud}{4906}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَلاَعَنُوا بِلَعْنَةِ اللَّهِ وَلاَ بِغَضَبِ اللَّهِ وَلاَ بِالنَّارِ ‏"‏ ‏.‏\hadithno{4906}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) said: Do not invoke Allah's curse, Allah's anger, or Hell}}
\hadithdefcmd{abudawud}{4907}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ أَبِي حَازِمٍ، وَزَيْدِ بْنِ أَسْلَمَ، أَنَّ أُمَّ الدَّرْدَاءِ، قَالَتْ سَمِعْتُ أَبَا الدَّرْدَاءِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَكُونُ اللَّعَّانُونَ شُفَعَاءَ وَلاَ شُهَدَاءَ ‏"‏ ‏.‏\hadithno{4907}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2598)}\hadithtrans{Abu al-Darda’ said :I heard the Messenger of Allah (May peace be upon him) say: Men given to cursing will not be witnesses or intercessors}}
\hadithdefcmd{abudawud}{4908}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، ح وَحَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ الْعَطَّارُ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي الْعَالِيَةِ، - قَالَ زَيْدٌ - عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، لَعَنَ الرِّيحَ - وَقَالَ مُسْلِمٌ إِنَّ رَجُلاً نَازَعَتْهُ الرِّيحُ رِدَاءَهُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَلَعَنَهَا - فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَلْعَنْهَا فَإِنَّهَا مَأْمُورَةٌ وَإِنَّهُ مَنْ لَعَنَ شَيْئًا لَيْسَ لَهُ بِأَهْلٍ رَجَعَتِ اللَّعْنَةُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4908}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: A man cursed the wind. The narrator Muslim's version has: The wind snatched away a man's cloak during the time of the Prophet (ﷺ) and he cursed it. The Prophet (ﷺ) said: Do not curse it, for it is under command, and if anyone curses a thing undeservedly, the curse returns upon him}}
\hadithdefcmd{abudawud}{4909}{حَدَّثَنَا ابْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبٍ، عَنْ عَطَاءٍ، عَنْ عَائ��شَةَ، رضى الله عنها قَالَتْ سُرِقَ لَهَا شَىْءٌ فَجَعَلَتْ تَدْعُو عَلَيْهِ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُسَبِّخِي عَنْهُ ‏"‏ ‏.‏\hadithno{4909}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Something of her was stolen, and she began to curse him (i.e. the thief). The Messenger of Allah (ﷺ) said to her: Do not lessen his sin}}
\hadithdefcmd{abudawud}{4910}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبَاغَضُوا وَلاَ تَحَاسَدُوا وَلاَ تَدَابَرُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا وَلاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثِ لَيَالٍ ‏"‏ ‏.‏\hadithno{4910}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6075) Sahih Muslim (2559)}\hadithtrans{Anas b. Malik reported the Messenger of Allah (May peace be upon him) as saying:Do not hate each other; do not envy each other; do not desert each other; and be the servants of Allah as brethren. It is not allowed for a Muslim to keep apart from his brother for more than three days}}
\hadithdefcmd{abudawud}{4911}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثَةِ أَيَّامٍ يَلْتَقِيَانِ فَيُعْرِضُ هَذَا وَيُعْرِضُ هَذَا وَخَيْرُهُمَا الَّذِي يَبْدَأُ بِالسَّلاَمِ ‏"‏ ‏.‏\hadithno{4911}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6077) Sahih Muslim (2560)}\hadithtrans{Abu Ayyub al-Ansari reported the Messenger of Allah (May peace be upon him) as saying :it is not allowable for a Muslim to keep apart from his brother for more than three days. When they meet, this turns away from him, and that turns away from him. The better of the two is the one who initiates in salutation}}
\hadithdefcmd{abudawud}{4912}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، وَأَحْمَدُ بْنُ سَعِيدٍ السَّرْخَسِيُّ، أَنَّ أَبَا عَامِرٍ، أَخْبَرَهُمْ قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَحِلُّ لِمُؤْمِنٍ أَنْ يَهْجُرَ مُؤْمِنًا فَوْقَ ثَلاَثٍ فَإِنْ مَرَّتْ بِهِ ثَلاَثٌ فَلْيَلْقَهُ فَلْيُسَلِّمْ عَلَيْهِ فَإِنْ رَدَّ عَلَيْهِ السَّلاَمَ فَقَدِ اشْتَرَكَا فِي الأَجْرِ وَإِنْ لَمْ يَرُدَّ عَلَيْهِ فَقَدْ بَاءَ بِالإِثْمِ ‏"‏ ‏.‏ زَادَ أَحْمَدُ ‏"‏ وَخَرَجَ الْمُسَلِّمُ مِنَ الْهِجْرَةِ ‏"‏ ‏.‏\hadithno{4912}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: It is not allowable for a believer to keep from a believer for more than three days. If three days pass, he should meet him and give him a salutation, and if he replies to it they will both have shared in the reward; but if he does not reply he will bear his sin (according to Ahmad's version) and the one who gives the salutation will have come forth from the sin of keeping apart}}
\hadithdefcmd{abudawud}{4913}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ عَثْمَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُنِيبِ، - يَعْنِي الْمَدَنِيَّ - قَالَ أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَكُونُ لِمُسْلِمٍ أَنْ يَهْجُرَ مُسْلِمًا فَوْقَ ثَلاَثَةٍ فَإِذَا لَقِيَهُ سَلَّمَ عَلَيْهِ ثَلاَثَ مِرَارٍ كُلُّ ذَلِكَ لاَ يَرُدُّ عَلَيْهِ فَقَدْ بَاءَ بِإِثْمِهِ ‏"‏ ‏.‏\hadithno{4913}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: It is not right for a Muslim to keep apart from another Muslim for more than three days. Then when he meets him and gives three salutations, receiving during that time no response, the other bears his sin}}
\hadithdefcmd{abudawud}{4914}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ مَنْصُورٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثٍ فَمَنْ هَجَرَ فَوْقَ ثَلاَثٍ فَمَاتَ دَخَلَ النَّارَ ‏"‏ ‏.‏\hadithno{4914}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: It is not allowable for a Muslim to keep apart from his brother for more than three days, for one who does so and dies will enter Hell}}
\hadithdefcmd{abudawud}{4915}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ حَيْوَةَ، عَنْ أَبِي عُثْمَانَ الْوَلِيدِ بْنِ أَبِي الْوَلِيدِ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ أَبِي خِرَاشٍ السُّلَمِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ هَجَرَ أَخَاهُ سَنَةً فَهُوَ كَسَفْكِ دَمِهِ ‏"‏ ‏.‏\hadithno{4915}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuKhirash as-Sulami: AbuKhirash heard the Messenger of Allah (ﷺ) say: If one keeps apart from his brother for a year, it is like shedding his blood}}
\hadithdefcmd{abudawud}{4916}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُفْتَحُ أَبْوَابُ الْجَنَّةِ كُلَّ يَوْمِ اثْنَيْنِ وَخَمِيسٍ فَيُغْفَرُ فِي ذَلِكَ الْيَوْمَيْنِ لِكُلِّ عَبْدٍ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا إِلاَّ مَنْ بَيْنَهُ وَبَيْنَ أَخِيهِ شَحْنَاءُ فَيُقَالُ أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ النَّبِيُّ صلى الله عليه وسلم هَجَرَ بَعْضَ نِسَائِهِ أَرْبَعِينَ يَوْمًا وَابْنُ عُمَرَ هَجَرَ ابْنًا لَهُ إِلَى أَنْ مَاتَ ‏.‏ قَالَ أَبُو دَاوُدَ إِذَا كَانَتِ الْهِجْرَةُ لِلَّهِ فَلَيْسَ مِنْ هَذَا بِشَىْءٍ وَإِنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ غَطَّى وَجْهَهُ عَنْ رَجُلٍ ‏.‏\hadithno{4916}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2565)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:The gates of Paradise are opened on Mondays and Thursdays, and forgiveness is granted to every man who does not associate anything with Allah, except for a man between whom and his brother there is rancor. Command will be given that they should be given respite till they conciliate. Abu Dawud said: The Prophet (ﷺ) kept apart from some of his wives for forty days, and Ibn 'Umar kept apart from his son till he died. Abu Dawud said: If keeping apart is meant for the sake of Allah, then it has no concern with it. 'Umar bin 'Abd al-'Aziz covered his face from a man}}
\hadithdefcmd{abudawud}{4917}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ وَالظَّنَّ فَإِنَّ الظَّنَّ أَكْذَبُ الْحَدِيثِ وَلاَ تَحَسَّسُوا وَلاَ تَجَسَّسُوا ‏"‏ ‏.‏\hadithno{4917}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6066) Sahih Muslim (2563)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:Avoid suspicion for suspicion is the most lying form of talk. Do not be inquisitive about one another, or spy on one another}}
\hadithdefcmd{abudawud}{4918}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ الْمُؤَذِّنُ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ سُلَيْمَانَ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنِ الْوَلِيدِ بْنِ رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُؤْمِنُ مِرْآةُ الْمُؤْمِنِ وَالْمُؤْمِنُ أَخُو الْمُؤْمِنِ يَكُفُّ عَلَيْهِ ضَيْعَتَهُ وَيَحُوطُهُ مِنْ وَرَائِهِ ‏"‏ ‏.‏\hadithno{4918}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The believer is the believer's mirror, and the believer is the believer's brother who guards him against loss and protects him when he is absent}}
\hadithdefcmd{abudawud}{4919}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أُخْبِرُكُمْ بِأَفْضَلَ مِنْ دَرَجَةِ الصِّيَامِ وَالصَّلاَةِ وَالصَّدَقَةِ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ إِصْلاَحُ ذَاتِ الْبَيْنِ وَفَسَادُ ذَاتِ الْبَيْنِ الْحَالِقَةُ ‏"‏ ‏.‏\hadithno{4919}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbudDarda': The Prophet (ﷺ) said: Shall I not inform you of something more excellent in degree than fasting, prayer and almsgiving (sadaqah)? The people replied: Yes, Prophet of Allah! He said: It is putting things right between people, spoiling them is the shaver (destructive)}}
\hadithdefcmd{abudawud}{4920}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ شَبُّويَةَ الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لَمْ يَكْذِبْ مَنْ نَمَى بَيْنَ اثْنَيْنِ لِيُصْلِحَ ‏"‏ ‏.‏ وَقَالَ أَحْمَدُ بْنُ مُحَمَّدٍ وَمُسَدَّدٌ ‏"‏ لَيْسَ بِالْكَاذِبِ مَنْ أَصْلَحَ بَيْنَ النَّاسِ فَقَالَ خَيْرًا أَوْ نَمَى خَيْرًا ‏"‏ ‏.‏\hadithno{4920}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2692) Sahih Muslim (2605)}\hadithtrans{Humaid b. 'Abd al-Rahman quoted his mother as saying:The Prophet (ﷺ) said: He who forged in order to put things right between two persons did not lie. The version by Ahmad ibn Muhammad and Musaddad has: The liar is not the one who puts things right between people, saying what is good and increasing good}}
\hadithdefcmd{abudawud}{4921}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ الْجِيزِيُّ، حَدَّثَنَا أَبُو الأَسْوَدِ، عَنْ نَافِعٍ، - يَعْنِي ابْنَ يَزِيدَ - عَنِ ابْنِ الْهَادِ، أَنَّ عَبْدَ الْوَهَّابِ بْنَ أَبِي بَكْرٍ، حَدَّثَهُ عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ أُمِّ كُلْثُومٍ بِنْتِ عُقْبَةَ، قَالَتْ مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُرَخِّصُ فِي شَىْءٍ مِنَ الْكَذِبِ إِلاَّ فِي ثَلاَثٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ أَعُدُّهُ كَاذِبًا الرَّجُلُ يُصْلِحُ بَيْنَ النَّاسِ يَقُولُ الْقَوْلَ وَلاَ يُرِيدُ بِهِ إِلاَّ الإِصْلاَحَ وَالرَّجُلُ يَقُولُ فِي الْحَرْبِ وَالرَّجُلُ يُحَدِّثُ امْرَأَتَهُ وَالْمَرْأَةُ تُحَدِّثُ زَوْجَهَا ‏"‏ ‏.‏\hadithno{4921}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Kulthum, daughter of ‘Uqbah, said:I did not hear the Messenger of Allah (ﷺ) making a concession for anything people say falsely except in three matters. The Messenger of Allah (ﷺ) would say: I do not count as a liar a man who puts things right between people, saying a word by which he intends only putting things right, and a man who says something in war, and a man who says something to his wife, or a wife who says something to her husband}}
\hadithdefcmd{abudawud}{4922}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، عَنْ خَالِدِ بْنِ ذَكْوَانَ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ بْنِ عَفْرَاءَ، قَالَتْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ عَلَىَّ صَبِيحَةَ بُنِيَ بِي فَجَلَسَ عَلَى فِرَاشِي كَمَجْلِسِكَ مِنِّي فَجَعَلَتْ جُوَيْرِيَاتٌ يَضْرِبْنَ بِدُفٍّ لَهُنَّ وَيَنْدُبْنَ مَنْ قُتِلَ مِنْ آبَائِي يَوْمَ بَدْرٍ إِلَى أَنْ قَالَتْ إِحْدَاهُنَّ وَفِينَا نَبِيُّ يَعْلَمُ مَا فِي غَدٍ ‏.‏ فَقَالَ ‏ "‏ دَعِي هَذِهِ وَقُولِي الَّذِي كُنْتِ تَقُولِينَ ‏"‏ ‏.‏\hadithno{4922}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5147)}\hadithtrans{Al-Ruhayyi’, daughter of Mu’awwidh b. ‘Afra’, said :The Messenger of Allah (May peace be upon him) came and visited me in the morning when I had been conducted to my husband, and sat on my bedding as you are sitting beside me. Some little girls of ours began to play the tambourine and eulogise those of my ancestors who were killed in the battle of Badr, and then one of them said: And among us is a Prophet who knows what will happen tomorrow. He said : Stop this and say what you were saying}}
\hadithdefcmd{abudawud}{4923}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ لَعِبَتِ الْحَبَشَةُ لِقُدُومِهِ فَرَحًا بِذَلِكَ لَعِبُوا بِحِرَابِهِمْ ‏.‏\hadithno{4923}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: When the Messenger of Allah (ﷺ) came to Medina, the Abyssinians played for his coming out of joy; they played with spears}}
\hadithdefcmd{abudawud}{4924}{حَدَّثَنَا أَحْمَدُ بْنُ عُبَيْدِ اللَّهِ الْغُدَانِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ نَافِعٍ، قَالَ سَمِعَ ابْنُ عُمَرَ، مِزْمَارًا - قَالَ - فَوَضَعَ أُصْبُعَيْهِ عَلَى أُذُنَيْهِ وَنَأَى عَنِ الطَّرِيقِ وَقَالَ لِي يَا نَافِعُ هَلْ تَسْمَعُ شَيْئًا قَالَ فَقُلْتُ لاَ ‏.‏ قَالَ فَرَفَعَ أُصْبُعَيْهِ مِنْ أُذُنَيْهِ وَقَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَسَمِعَ مِثْلَ هَذَا فَصَنَعَ مِثْلَ هَذَا ‏.‏ قَالَ أَبُو عَلِيٍّ اللُّؤْلُؤِيُّ سَمِعْتُ أَبَا دَاوُدَ يَقُولُ هَذَا حَدِيثٌ مُنْكَرٌ ‏.‏\hadithno{4924}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: Nafi' said: Ibn Umar heard a pipe, put his fingers in his ears and went away from the road. He said to me: Are you hearing anything? I said: No. He said: He then took his fingers out of his ears and said: I was with the Prophet (ﷺ), and he heard like this and he did like this. AbuAli al-Lu'lu said: I heard AbuDawud say: This is a rejected tradition}}
\hadithdefcmd{abudawud}{4925}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُطْعِمُ بْنُ الْمِقْدَامِ، قَالَ حَدَّثَنَا نَافِعٌ، قَالَ كُنْتُ رِدْفَ ابْنِ عُمَرَ إِذْ مَرَّ بِرَاعٍ يَزْمُرُ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو دَاوُدَ أُدْخِلَ بَيْنَ مُطْعِمٍ وَنَافِعٍ سُلَيْمَانُ بْنُ مُوسَى ‏.‏\hadithno{4925}\hadithgrade{Al-Albani: Hasan Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi said :I was sitting behind Ibn ‘Umar on the mount when he passed a shepherd who was blowing a pipe. He then mentioned the rest of the tradition in a similar manner. Abu Dawud said : Between Mut’im and Nafi the name of a narrator Sulaiman b. Musa has been inserted}}
\hadithdefcmd{abudawud}{4926}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، قَالَ حَدَّثَنَا أَبُو الْمَلِيحِ، عَنْ مَيْمُونٍ، عَنْ نَافِعٍ، قَالَ كُنَّا مَعَ ابْنِ عُمَرَ فَسَمِعَ صَوْتَ، زَامِرٍ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا أَنْكَرُهَا ‏.‏\hadithno{4926}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi said :When we were with Ibn ‘Umar, he heard the sound of a man who was blowing a pipe. He then mentioned a similar tradition. Abu Dawud said : This is more rejected}}
\hadithdefcmd{abudawud}{4927}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سَلاَّمُ بْنُ مِسْكِينٍ، عَنْ شَيْخٍ، شَهِدَ أَبَا وَائِلٍ فِي وَلِيمَةٍ فَجَعَلُوا يَلْعَبُونَ يَتَلَعَّبُونَ يُغَنُّونَ فَحَلَّ أَبُو وَائِلٍ حَبْوَتَهُ وَقَالَ سَمِعْتُ عَبْدَ اللَّهِ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْغِنَاءُ يُنْبِتُ النِّفَاقَ فِي الْقَلْبِ ‏"‏ ‏.‏\hadithno{4927}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Salam ibn Miskin, quoting an old man who witnessed AbuWa'il in a wedding feast, said:They began to play, amuse and sing. He united the support of his hand round his knees that were drawn up, and said: I heard Abdullah (ibn Mas'ud) say: I heard the apostle of Allah (ﷺ) say: Singing produces hypocrisy in the heart}}
\hadithdefcmd{abudawud}{4928}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، أَنَّ أَبَا أُسَامَةَ، أَخْبَرَهُمْ عَنْ مُفَضَّلِ بْنِ يُونُسَ، عَنِ الأَوْزَاعِيِّ، عَنْ أَبِي يَسَارٍ الْقُرَشِيِّ، عَنْ أَبِي هَاشِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِمُخَنَّثٍ قَدْ خَضَبَ يَدَيْهِ وَرِجْلَيْهِ بِالْحِنَّاءِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا بَالُ هَذَا ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ يَتَشَبَّهُ بِالنِّسَاءِ ‏.‏ فَأُمِرَ بِهِ فَنُفِيَ إِلَى النَّقِيعِ فَقَالُوا يَا رَسُولَ اللَّهِ أَلاَ نَقْتُلُهُ فَقَالَ ‏"‏ إِنِّي نُهِيتُ عَنْ قَتْلِ الْمُصَلِّينَ ‏"‏ ‏.‏ قَالَ أَبُو أُسَامَةَ وَالنَّقِيعُ نَاحِيَةٌ عَنِ الْمَدِينَةِ وَلَيْسَ بِالْبَقِيعِ ‏.‏\hadithno{4928}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: Am effeminate man (mukhannath) who had dyed his hands and feet with henna was brought to the Prophet (ﷺ). He asked: What is the matter with this man? He was told: "Messenger of Allah! He imitates the look of women." So he issued an order regarding him and he was banished to an-Naqi'. The people said: Messenger of Allah! Should we not kill him? He said: I have been prohibited from killing people who pray. AbuUsamah said: Naqi' is a region near Medina and not a Baqi}}
\hadithdefcmd{abudawud}{4929}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، - يَعْنِي ابْنَ عُرْوَةَ - عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا وَعِنْدَهَا مُخَنَّثٌ وَهُوَ يَقُولُ لِعَبْدِ اللَّهِ أَخِيهَا إِنْ يَفْتَحِ اللَّهُ الطَّائِفَ غَدًا دَلَلْتُكَ عَلَى امْرَأَةٍ تُقْبِلُ بِأَرْبَعٍ وَتُدْبِرُ بِثَمَانٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَخْرِجُوهُمْ مِنْ بُيُوتِكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْمَرْأَةُ كَانَ لَهَا أَرْبَعُ عُكَنٍ فِي بَطْنِهَا ‏.‏\hadithno{4929}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2535) Sahih Muslim (2180)}\hadithtrans{Umm Salamah said that the Prophet (May peace be upon him) came upon her when there was with her an effeminate man (mukhannath) who said to her brother ‘Abd Allah (b. Abi Umayyah) :if Allah conquers al-Ta’if for you tomorrow, I shall lead you to a woman who has four folds of fats in front and eight behind. Thereupon the Prophet (May peace be upon him) said: Put them out of your houses. Abu Dawud said : The woman had four folds of fat on her belly}}
\hadithdefcmd{abudawud}{4930}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَعَنَ الْمُخَنَّثِينَ مِنَ الرِّجَالِ وَالْمُتَرَجِّلاَتِ مِنَ النِّسَاءِ وَقَالَ ‏ "‏ أَخْرِجُوهُمْ مِنْ بُيُوتِكُمْ وَأَخْرِجُوا فُلاَنًا وَفُلاَنًا ‏"‏ ‏.‏ يَعْنِي الْمُخَنَّثِينَ ‏.‏\hadithno{4930}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6834)}\hadithtrans{Ibn ‘Abbas said:The Prophet (May peace be upon him) cursed effeminate men (mukhannathan) and women who imitated men, saying: Put them out of your houses, and put so-and-so out. (that is to say, the effeminate men)}}
\hadithdefcmd{abudawud}{4931}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَلْعَبُ بِالْبَنَاتِ فَرُبَّمَا دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي الْجَوَارِي فَإِذَا دَخَلَ خَرَجْنَ وَإِذَا خَرَجَ دَخَلْنَ ‏.‏\hadithno{4931}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6130) Sahih Muslim (2440)}\hadithtrans{‘A’ishah said :I used to play with dolls. Sometimes the Messenger of Allah (May peace be upon him) entered upon me when the girls were with me. When he came in, they went out, and when he went out, they came in}}
\hadithdefcmd{abudawud}{4932}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، قَالَ حَدَّثَنِي عُمَارَةُ بْنُ غَزِيَّةَ، أَنَّ مُحَمَّدَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ غَزْوَةِ تَبُوكَ أَوْ خَيْبَرَ وَفِي سَهْوَتِهَا سِتْرٌ فَهَبَّتْ رِيحٌ فَكَشَفَتْ نَاحِيَةَ السِّتْرِ عَنْ بَنَاتٍ لِعَائِشَةَ لُعَبٍ فَقَالَ ‏"‏ مَا هَذَا يَا عَائِشَةُ ‏"‏ ‏.‏ قَالَتْ بَنَاتِي ‏.‏ وَرَأَى بَيْنَهُنَّ فَرَسًا لَهُ جَنَاحَانِ مِنْ رِقَاعٍ فَقَالَ ‏"‏ مَا هَذَا الَّذِي أَرَى وَسْطَهُنَّ ‏"‏ ‏.‏ قَالَتْ فَرَسٌ ‏.‏ قَالَ ‏"‏ وَمَا هَذَا الَّذِي عَلَيْهِ ‏"‏ ‏.‏ قَالَتْ جَنَاحَانِ ‏.‏ قَالَ ‏"‏ فَرَسٌ لَهُ جَنَاحَانِ ‏"‏ ‏.‏ قَالَتْ أَمَا سَمِعْتَ أَنَّ لِسُلَيْمَانَ خَيْلاً لَهَا أَجْنِحَةٌ قَالَتْ فَضَحِكَ حَتَّى رَأَيْتُ نَوَاجِذَهُ ‏.‏\hadithno{4932}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When the Messenger of Allah (ﷺ) arrived after the expedition to Tabuk or Khaybar (the narrator is doubtful), the draught raised an end of a curtain which was hung in front of her store-room, revealing some dolls which belonged to her. He asked: What is this? She replied: My dolls. Among them he saw a horse with wings made of rags, and asked: What is this I see among them? She replied: A horse. He asked: What is this that it has on it? She replied: Two wings. He asked: A horse with two wings? She replied: Have you not heard that Solomon had horses with wings? She said: Thereupon the Messenger of Allah (ﷺ) laughed so heartily that I could see his molar teeth}}
\hadithdefcmd{abudawud}{4933}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالاَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَنِي وَأَنَا بِنْتُ سَبْعِ سِنِينَ فَلَمَّا قَدِمْنَا الْمَدِينَةَ أَتَيْنَ نِسْوَةٌ - وَقَالَ بِشْرٌ فَأَتَتْنِي أُمُّ رُومَانَ - وَأَنَا عَلَى أُرْجُوحَةٍ فَذَهَبْنَ بِي وَهَيَّأْنَنِي وَصَنَعْنَنِي فَأُتِيَ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَبَنَى بِي وَأَنَا ابْنَةُ تِسْعٍ فَوَقَفَتْ بِي عَلَى الْبَابِ فَقُلْتُ هِيهْ هِيهْ - قَالَ أَبُو دَاوُدَ أَىْ تَنَفَّسَتْ - فَأُدْخِلْتُ بَيْتًا فَإِذَا فِيهِ نِسْوَةٌ مِنَ الأَنْصَارِ فَقُلْنَ عَلَى الْخَيْرِ وَالْبَرَكَةِ ‏.‏ دَخَلَ حَدِيثُ أَحَدِهِمَا فِي الآخَرِ ‏.‏\hadithno{4933}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3894) Sahih Muslim (1422)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) married me when I was seven or six. When we came to Medina, some women came. according to Bishr's version: Umm Ruman came to me when I was swinging. They took me, made me prepared and decorated me. I was then brought to the Messenger of Allah (ﷺ), and he took up cohabitation with me when I was nine. She halted me at the door, and I burst into laughter. Abu Dawud said: That is to say: I menstruated, and I was brought in a house, and there were some women of the Ansari in it. They said: With good luck and blessing. The tradition of one of them has been included in the other}}
\hadithdefcmd{abudawud}{4934}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، مِثْلَهُ قَالَ عَلَى خَيْرِ طَائِرٍ فَسَلَّمَتْنِي إِلَيْهِنَّ فَغَسَلْنَ رَأْسِي وَأَصْلَحْنَنِي فَلَمْ يَرُعْنِي إِلاَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ضُحًى فَأَسْلَمْنَنِي إِلَيْهِ ‏.‏\hadithno{4934}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuUsamah: The tradition mentioned above (No. 4915) has also been transmitted by AbuUsamah in a similar manner through a different chain of narrators. This version has: "With good fortune. " She (Umm Ruman) entrusted me to them. They washed my head and redressed me. No one came to me suddenly except the Messenger of Allah (ﷺ) in the forenoon. So they entrusted me to him}}
\hadithdefcmd{abudawud}{4935}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها، قَالَتْ فَلَمَّا قَدِمْنَا الْمَدِينَةَ جَاءَنِي نِسْوَةٌ وَأَنَا أَلْعَبُ عَلَى أُرْجُوحَةٍ وَأَنَا مُجَمَّمَةٌ فَذَهَبْنَ بِي فَهَيَّأْنَنِي وَصَنَّعْنَنِي ثُمَّ أَتَيْنَ بِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَبَنَى بِي وَأَنَا ابْنَةُ تِسْعِ سِنِينَ ‏.‏\hadithno{4935}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When we came to Medina, the women came to me when I was playing on the swing, and my hair were up to my ears. They brought me, prepared me, and decorated me. Then they brought me to the Messenger of Allah (ﷺ) and he took up cohabitation with me, when I was nine}}
\hadithdefcmd{abudawud}{4936}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، بِإِسْنَادِهِ فِي هَذَا الْحَدِيثِ قَالَتْ وَأَنَا عَلَى الأُرْجُوحَةِ، وَمَعِي، صَوَاحِبَاتِي فَأَدْخَلْنَنِي بَيْتًا فَإِذَا نِسْوَةٌ مِنَ الأَنْصَارِ فَقُلْنَ عَلَى الْخَيْرِ وَالْبَرَكَةِ ‏.‏\hadithno{4936}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Hisham b. 'Urwah through different chain of narrators. This version adds:I was swinging and I had my friends. They brought me to a house ; there were some women of the Ansar (Helpers). They said: With good luck and blessing}}
\hadithdefcmd{abudawud}{4937}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ يَحْيَى، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ - قَالَ قَالَتْ عَائِشَةُ رضى الله عنها فَقَدِمْنَا الْمَدِينَةَ فَنَزَلْنَا فِي بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ - قَالَتْ - فَوَاللَّهِ إِنِّي لَعَلَى أُرْجُوحَةٍ بَيْنَ عَذْقَيْنِ فَجَاءَتْنِي أُمِّي فَأَنْزَلَتْنِي وَلِي جُمَيْمَةٌ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{4937}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘A’ishah said :We came to Medina and stayed with Banu al-Harith b. al-Khazraj. She said : I swear by Allah, I was swinging between two date-palms. Then my mother came down; and I had my hair up to the ears. The transmitter then rest of the tradition}}
\hadithdefcmd{abudawud}{4938}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ مَيْسَرَةَ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَعِبَ بِالنَّرْدِ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏\hadithno{4938}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMusa al-Ash'ari: The Messenger of Allah (ﷺ) said: He who plays backgammon disobeys Allah and His Apostle}}
\hadithdefcmd{abudawud}{4939}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَعِبَ بِالنَّرْدَشِيرِ فَكَأَنَّمَا غَمَسَ يَدَهُ فِي لَحْمِ خِنْزِيرٍ وَدَمِهِ ‏"‏ ‏.‏\hadithno{4939}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2060)}\hadithtrans{Buraidah reported the Prophet (May peace be upon him) as saying :If anyone plays backgammon, he sinks his hand in the flesh of swine and its blood}}
\hadithdefcmd{abudawud}{4940}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَتْبَعُ حَمَامَةً فَقَالَ ‏ "‏ شَيْطَانٌ يَتْبَعُ شَيْطَانَةً ‏"‏ ‏.‏\hadithno{4940}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) saw a man pursuing a pigeon. He said: A devil is pursuing a female devil}}
\hadithdefcmd{abudawud}{4941}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُسَدَّدٌ، - الْمَعْنَى - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي قَابُوسَ، مَوْلًى لِعَبْدِ اللَّهِ بْنِ عَمْرٍو عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ الرَّاحِمُونَ يَرْحَمُهُمُ الرَّحْمَنُ ارْحَمُوا أَهْلَ الأَرْضِ يَرْحَمْكُمْ مَنْ فِي السَّمَاءِ ‏"‏ ‏.‏ لَمْ يَقُلْ مُسَدَّدٌ مَوْلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو وَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4941}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: The Compassionate One has mercy on those who are merciful. If you show mercy to those who are on the earth, He Who is in the heaven will show mercy to you. Musaddad did not say: The client of 'Adb Allah b. 'Amr. He said: The Prophet (ﷺ) said}}
\hadithdefcmd{abudawud}{4942}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا ح، وَحَدَّثَنَا ابْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا شُعْبَةُ، قَالَ كَتَبَ إِلَىَّ مَنْصُورٌ - قَالَ ابْنُ كَثِيرٍ فِي حَدِيثِهِ وَقَرَأْتُهُ عَلَيْهِ وَقُلْتُ أَقُولُ حَدَّثَنِي مَنْصُورٌ فَقَالَ إِذَا قَرَأْتَهُ عَلَىَّ فَقَدْ حَدَّثْتُكَ بِهِ ثُمَّ اتَّفَقَا - عَنْ أَبِي عُثْمَانَ مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ عَنْ أَبِي هُرَيْرَةَ قَالَ سَمِعْتُ أَبَا الْقَاسِمِ الصَّادِقَ الْمَصْدُوقَ صلى الله عليه وسلم صَاحِبَ هَذِهِ الْحُجْرَةِ يَقُولُ ‏ "‏ لاَ تُنْزَعُ الرَّحْمَةُ إِلاَّ مِنْ شَقِيٍّ ‏"‏ ‏.‏\hadithno{4942}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: I heard AbulQasim (ﷺ) who spoke the truth and whose word was verified say: Mercy is taken away only from him who is miserable}}
\hadithdefcmd{abudawud}{4943}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ السَّرْحِ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنِ ابْنِ عَامِرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، يَرْوِيهِ - قَالَ ابْنُ السَّرْحِ - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يَرْحَمْ صَغِيرَنَا وَيَعْرِفْ حَقَّ كَبِيرِنَا فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{4943}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: Those who do not show mercy to our young ones and do not realise the right of our elders are not from us}}
\hadithdefcmd{abudawud}{4944}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ تَمِيمٍ الدَّارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الدِّينَ النَّصِيحَةُ إِنَّ الدِّينَ النَّصِيحَةُ إِنَّ الدِّينَ النَّصِيحَةُ ‏"‏ ‏.‏ قَالُوا لِمَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لِلَّهِ وَكِتَابِهِ وَرَسُولِهِ وَأَئِمَّةِ الْمُؤْمِنِينَ وَعَامَّتِهِمْ وَأَئِمَّةِ الْمُسْلِمِينَ وَعَامَّتِهِمْ ‏"‏ ‏.‏\hadithno{4944}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (55)}\hadithtrans{Tamim al-Dari reported the Prophet (May peace be upon him) as saying; Religion conduct; religion consists in sincere conduct. The people asked; to whom should it be directed, Messenger of Allah? He replied :To Allah, his book, his Apostle, the leaders (public authorities) of the believers and all the believers, and the leaders (public authorities) of Muslim and the Muslims and the Muslims in general}}
\hadithdefcmd{abudawud}{4945}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا خَالِدٌ، عَنْ يُونُسَ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ جَرِيرٍ، قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ وَأَنْ أَنْصَحَ لِكُلِّ مُسْلِمٍ - قَالَ - وَكَانَ إِذَا بَاعَ الشَّىْءَ أَوِ اشْتَرَاهُ قَالَ ‏ "‏ أَمَا إِنَّ الَّذِي أَخَذْنَا مِنْكَ أَحَبُّ إِلَيْنَا مِمَّا أَعْطَيْنَاكَ فَاخْتَرْ ‏"‏ ‏.‏\hadithno{4945}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jarir: I swore allegiance to the Messenger of Allah (ﷺ) promising to hear and obey, and behave sincerely towards every Muslim. AbuZur'ah said: Whenever he sold and bought anything, he would say: What we took from you is dearer to us than what we gave you. So choose (as you like)}}
\hadithdefcmd{abudawud}{4946}{حَدَّثَنَا أَبُو بَكْرٍ، وَعُثْمَانُ، ابْنَا أَبِي شَيْبَةَ - الْمَعْنَى قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ عُثْمَانُ وَجَرِيرٌ الرَّازِيُّ ح وَحَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا أَسْبَاطٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، - وَقَالَ وَاصِلٌ قَالَ حُدِّثْتُ عَنْ أَبِي صَالِحٍ، ثُمَّ اتَّفَقُوا - عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ نَفَّسَ عَنْ مُسْلِمٍ كُرْبَةً مِنْ كُرَبِ الدُّنْيَا نَفَّسَ اللَّهُ عَنْهُ كُرْبَةً مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ - وَمَنْ يَسَّرَ عَلَى مُعْسِرٍ يَسَّرَ اللَّهُ عَلَيْهِ فِي الدُّنْيَا وَالآخِرَةِ وَمَنْ سَتَرَ عَلَى مُسْلِمٍ سَتَرَ اللَّهُ عَلَيْهِ فِي الدُّنْيَا وَالآخِرَةِ وَاللَّهُ فِي عَوْنِ الْعَبْدِ مَا كَانَ الْعَبْدُ فِي عَوْنِ أَخِيهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَذْكُرْ عُثْمَانُ عَنْ أَبِي مُعَاوِيَةَ ‏"‏ وَمَنْ يَسَّرَ عَلَى مُعْسِرٍ ‏"‏ ‏.‏\hadithno{4946}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2699)}\hadithtrans{Abu Hurairah reported the prophet (ﷺ) as saying:If anyone removes his brother’s anxiety of this world, Allah will remove for him one of the anxieties of the Day of resurrection; if anyone makes easy for an impoverished man, Allah will make easy for him in this world and on the day of resurrection; if anyone conceals a Muslim’s secrets, Allah will conceal his secrets in this world and on the Day of resurrection; Allah will remain in the aid of a servant so long as the servant remains in the aid of his brother. Abu Dawud said: ‘Uthman did not transmit the following words from Abu Mu’awiyah: “if anyone makes easy for an impoverished man”}}
\hadithdefcmd{abudawud}{4947}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ نَبِيُّكُمْ صلى الله عليه وسلم ‏ "‏ كُلُّ مَعْرُوفٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{4947}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1005)}\hadithtrans{Hudhaifah said :Your prophet (May peace be upon him) said : Every good act is a SADAQAH (almsgiving)}}
\hadithdefcmd{abudawud}{4948}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ أَخْبَرَنَا ح، وَحَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ دَاوُدَ بْنِ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي زَكَرِيَّاءَ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ تُدْعَوْنَ يَوْمَ الْقِيَامَةِ بِأَسْمَائِكُمْ وَأَسْمَاءِ آبَائِكُمْ فَأَحْسِنُوا أَسْمَاءَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ابْنُ أَبِي زَكَرِيَّاءَ لَمْ يُدْرِكْ أَبَا الدَّرْدَاءِ ‏.‏\hadithno{4948}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbudDarda': The Prophet (ﷺ) said: On the Day of Resurrection you will be called by your names and by your father's names, so give yourselves good names}}
\hadithdefcmd{abudawud}{4949}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ زِيَادٍ، سَبَلاَنُ حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحَبُّ الأَسْمَاءِ إِلَى اللَّهِ تَعَالَى عَبْدُ اللَّهِ وَعَبْدُ الرَّحْمَنِ ‏"‏ ‏.‏\hadithno{4949}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2132)}\hadithtrans{Ibn ‘Umar reported the Messenger of Allah (May peace be upon him) as saying :Your names which are dearest to Allah are ‘Abd Allah and ‘Abd al-Rahman}}
\hadithdefcmd{abudawud}{4950}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هِشَامُ بْنُ سَعِيدٍ الطَّالْقَانِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُهَاجِرِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي عَقِيلُ بْنُ شَبِيبٍ، عَنْ أَبِي وَهْبٍ الْجُشَمِيِّ، وَكَانَتْ، لَهُ صُحْبَةٌ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَمَّوْا بِأَسْمَاءِ الأَنْبِيَاءِ وَأَحَبُّ الأَسْمَاءِ إِلَى اللَّهِ عَبْدُ اللَّهِ وَعَبْدُ الرَّحْمَنِ وَأَصْدَقُهَا حَارِثٌ وَهَمَّامٌ وَأَقْبَحُهَا حَرْبٌ وَمُرَّةُ ‏"‏ ‏.‏\hadithno{4950}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuWahb al-Jushami: The Prophet (ﷺ) said: Call yourselves by the names of the Prophets. The names dearest to Allah are Abdullah and AbdurRahman, the truest are Harith and Hammam, and the worst are Harb and Murrah}}
\hadithdefcmd{abudawud}{4951}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ ذَهَبْتُ بِعَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم حِينَ وُلِدَ وَالنَّبِيُّ صلى الله عليه وسلم فِي عَبَاءَةٍ يَهْنَأُ بَعِيرًا لَهُ قَالَ ‏"‏ هَلْ مَعَكَ تَمْرٌ ‏"‏ ‏.‏ قُلْتُ نَعَمْ - قَالَ - فَنَاوَلْتُهُ تَمَرَاتٍ فَأَلْقَاهُنَّ فِي فِيهِ فَلاَكَهُنَّ ثُمَّ فَغَرَ فَاهُ فَأَوْجَرَهُنَّ إِيَّاهُ فَجَعَلَ الصَّبِيُّ يَتَلَمَّظُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ حِبُّ الأَنْصَارِ التَّمْرُ ‏"‏ ‏.‏ وَسَمَّاهُ عَبْدَ اللَّهِ ‏.‏\hadithno{4951}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2144)}\hadithtrans{Anas said; I took ‘Abd Allah b. Abi Talhah, when he was born, to the Prophet (May peace be upon him), and the prophet (May peace be upon him) was wearing a wool;en cloak and rubbing tar on his camel. He asked:Have you some dates? I said : Yes. I then gave him some dates which he put in his mouth, chewed them, opened his mouth and them in it. The baby began to lick them. The prophet (May peace be upon him) said: ANSAR’s favourite (fruit) is dates. And he gave him the name of ‘Abd al-Rahman}}
\hadithdefcmd{abudawud}{4952}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيَّرَ اسْمَ عَاصِيَةَ وَقَالَ ‏ "‏ أَنْتِ جَمِيلَةُ ‏"‏ ‏.‏\hadithno{4952}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2139)}\hadithtrans{Ibn ‘Umar said :The Messenger of Allah (May peace be upon him) changed the name of ‘Asiyah and called her Jamilah}}
\hadithdefcmd{abudawud}{4953}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، سَأَلَتْهُ مَا سَمَّيْتَ ابْنَتَكَ قَالَ سَمَّيْتُهَا بَرَّةَ فَقَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ هَذَا الاِسْمِ سُمِّيتُ بَرَّةَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تُزَكُّوا أَنْفُسَكُمُ اللَّهُ أَعْلَمُ بِأَهْلِ الْبِرِّ مِنْكُمْ ‏"‏ ‏.‏ فَقَالَ مَا نُسَمِّيهَا قَالَ ‏"‏ سَمُّوهَا زَيْنَبَ ‏"‏ ‏.‏\hadithno{4953}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Muhammad b. ‘Amr b. ‘Ata said :Zainab daughter of Abu Salamah asked him: Which name did you give to your daughter? He replied : Barrah. She said: The Messenger of Allah (May peace be upon him) forbade giving this name. I was called Barrah but the Prophet (May peace be upon him) said: Do not declare yourselves pure, for Allah knows best those of you who are obedient. He said: we asked; which name should we give her? He replied: Call her Zainab}}
\hadithdefcmd{abudawud}{4954}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - قَالَ حَدَّثَنِي بَشِيرُ بْنُ مَيْمُونٍ، عَنْ عَمِّهِ، أُسَامَةَ بْنِ أَخْدَرِيٍّ أَنَّ رَجُلاً، يُقَالُ لَهُ أَصْرَمُ كَانَ فِي النَّفَرِ الَّذِينَ أَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا اسْمُكَ ‏"‏ ‏.‏ قَالَ أَنَا أَصْرَمُ ‏.‏ قَالَ ‏"‏ بَلْ أَنْتَ زُرْعَةُ ‏"‏ ‏.‏\hadithno{4954}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Usamah ibn Akhdari: A man called Asram was among those who came to the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said: What is your name? He replied: Asram. He said: No, you are Zur'ah}}
\hadithdefcmd{abudawud}{4955}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ، عَنْ يَزِيدَ، - يَعْنِي ابْنَ الْمِقْدَامِ بْنِ شُرَيْحٍ - عَنْ أَبِيهِ، عَنْ جَدِّهِ، شُرَيْحٍ عَنْ أَبِيهِ، هَانِئٍ أَنَّهُ لَمَّا وَفَدَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَعَ قَوْمِهِ سَمِعَهُمْ يَكْنُونَهُ بِأَبِي الْحَكَمِ فَدَعَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ اللَّهَ هُوَ الْحَكَمُ وَإِلَيْهِ الْحُكْمُ فَلِمَ تُكْنَى أَبَا الْحَكَمِ ‏"‏ ‏.‏ فَقَالَ إِنَّ قَوْمِي إِذَا اخْتَلَفُوا فِي شَىْءٍ أَتَوْنِي فَحَكَمْتُ بَيْنَهُمْ فَرَضِيَ كِلاَ الْفَرِيقَيْنِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَحْسَنَ هَذَا فَمَا لَكَ مِنَ الْوَلَدِ ‏"‏ ‏.‏ قَالَ لِي شُرَيْحٌ وَمُسْلِمٌ وَعَبْدُ اللَّهِ ‏.‏ قَالَ ‏"‏ فَمَنْ أَكْبَرُهُمْ ‏"‏ ‏.‏ قُلْتُ شُرَيْحٌ قَالَ ‏"‏ فَأَنْتَ أَبُو شُرَيْحٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ شُرَيْحٌ هَذَا هُوَ الَّذِي كَسَرَ السِّلْسِلَةَ وَهُوَ مِمَّنْ دَخَلَ تُسْتَرَ ‏.‏ قَالَ أَبُو دَاوُدَ وَبَلَغَنِي أَنَّ شُرَيْحًا كَسَرَ بَابَ تُسْتَرَ وَذَلِكَ أَنَّهُ دَخَلَ مِنْ سِرْبٍ ‏.‏\hadithno{4955}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hani ibn Yazid: When Hani went with his people in a deputation to the Messenger of Allah (ﷺ), he heard them calling him by his kunyah (surname), AbulHakam. So the Messenger of Allah (ﷺ) called him and said: Allah is the judge (al-Hakam), and to Him judgment belongs. Why are you given the kunyah AbulHakam? He replied: When my people disagree about a matter, they come to me, and I decide between them, and both parties are satisfied with my decision. He said: How good this is! What children have you? He replied: I have Shurayh, Muslim and Abdullah. He asked; Who is the oldest of them? I replied: Shurayh. He said: Then you are AbuShurayh. Abu Dawud said: This is Shuraib who broke the chain, and who entered Tustar. Abu Dawud said: I have been told that Shuraib broke the gate of Tustar, and he entered it through tunnel}}
\hadithdefcmd{abudawud}{4956}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ مَا اسْمُكَ ‏"‏ ‏.‏ قَالَ حَزْنٌ ‏.‏ قَالَ ‏"‏ أَنْتَ سَهْلٌ ‏"‏ ‏.‏ قَالَ لاَ السَّهْلُ يُوطَأُ وَيُمْتَهَنُ ‏.‏ قَالَ سَعِيدٌ فَظَنَنْتُ أَنَّهُ سَيُصِيبُنَا بَعْدَهُ حُزُونَةٌ ‏.‏ قَالَ أَبُو دَاوُدَ وَغَيَّرَ النَّبِيُّ صلى الله عليه وسلم اسْمَ الْعَاصِ وَعَزِيزٍ وَعَتَلَةَ وَشَيْطَانٍ وَالْحَكَمِ وَغُرَابٍ وَحُبَابٍ وَشِهَابٍ فَسَمَّاهُ هِشَامًا وَسَمَّى حَرْبًا سَلْمًا وَسَمَّى الْمُضْطَجِعَ الْمُنْبَعِثَ وَأَرْضًا تُسَمَّى عَفِرَةَ سَمَّاهَا خَضِرَةَ وَشِعْبَ الضَّلاَلَةِ سَمَّاهُ شِعْبَ الْهُدَى وَبَنُو الزِّنْيَةِ سَمَّاهُمْ بَنِي الرِّشْدَةِ وَسَمَّى بَنِي مُغْوِيَةَ بَنِي رِشْدَةَ ‏.‏ قَالَ أَبُو دَاوُدَ تَرَكْتُ أَسَانِيدَهَا لِلاِخْتِصَارِ ‏.‏\hadithno{4956}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6190)}\hadithtrans{Sa'id b. Musayyab told that his father said on the authority of his grandfather (Hazn):The Prophet (ﷺ) asked: What is your name? He replied: Hazn (rugged). He said: You are Sahl (smooth). He said: No, smooth is trodden upon and disgraced. Sa'id said: I then thought that ruggedness would remain among us after it. AbuDawud said: The Prophet (ﷺ) changed the names al-'As, Aziz, Atalah, Shaytan, al-Hakam, Ghurab, Hubab, and Shihab and called him Hisham. He changed the name Harb (war) and called him Silm (peace). He changed the name al-Munba'ith (one who lies) and called him al-Mudtaji' (one who stands up). He changed the name of a land Afrah (barren) and called it Khadrah (green). He changed the name Shi'b ad-Dalalah (the mountain path of a stray), the name of a mountain path and called it Shi'b al-Huda (mountain path of guidance). He changed the name Banu az-Zinyah (children of fornication) and called them Banu ar-Rushdah (children of those who are on the right path), and changed the name Banu Mughwiyah (children of a woman who allures and goes astray), and called them Banu Rushdah (children of a woman who is on the right path). AbuDawud said: I omitted the chains of these for the sake of brevity}}
\hadithdefcmd{abudawud}{4957}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا أَبُو عَقِيلٍ، حَدَّثَنَا مُجَالِدُ بْنُ سَعِيدٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، قَالَ لَقِيتُ عُمَرَ بْنَ الْخَطَّابِ رَضِيَ اللَّهُ عَنْهُ فَقَالَ مَنْ أَنْتَ قُلْتُ مَسْرُوقُ بْنُ الأَجْدَعِ ‏.‏ فَقَالَ عُمَرُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الأَجْدَعُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{4957}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: Masruq said: I met Umar ibn al-Khattab (Allah be pleased with him) who said: Who are you? I replied: Masruq ibn al-Ajda'. Umar then said: I heard the Messenger of Allah (ﷺ) say: al-Ajda' (mutilated) is a devil}}
\hadithdefcmd{abudawud}{4958}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مَنْصُورُ بْنُ الْمُعْتَمِرِ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ رَبِيعِ بْنِ عُمَيْلَةَ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُسَمِّيَنَّ غُلاَمَكَ يَسَارًا وَلاَ رَبَاحًا وَلاَ نَجِيحًا وَلاَ أَفْلَحَ فَإِنَّكَ تَقُولُ أَثَمَّ هُوَ فَيَقُولُ لاَ إِنَّمَا هُنَّ أَرْبَعٌ فَلاَ تَزِيدَنَّ عَلَىَّ ‏"‏ ‏.‏\hadithno{4958}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2137)}\hadithtrans{Samurah b. Jundub reported the Messenger of Allah (May peace be upon him) as saying:Do not call your servant Yasar (wealth), Rabah (profit), Nijih(prosperous) and Aflah (successful), for you may ask; Is he there? And someone says: No. Samurah said: These are four (names), so do not attribute more to me}}
\hadithdefcmd{abudawud}{4959}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ الرُّكَيْنَ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ سَمُرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُسَمِّيَ رَقِيقَنَا أَرْبَعَةَ أَسْمَاءٍ أَفْلَحَ وَيَسَارًا وَنَافِعًا وَرَبَاحًا ‏.‏\hadithno{4959}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2136)}\hadithtrans{Samurah said:The Aposlte of Allah (May peace be upon him) forbade giving four names to our slaves : Aflah (successful), Yasar (wealth), Naf(beneficial) and Rabah (profit)}}
\hadithdefcmd{abudawud}{4960}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ عِشْتُ إِنْ شَاءَ اللَّهُ أَنْهَى أُمَّتِي أَنْ يُسَمُّوا نَافِعًا وَأَفْلَحَ وَبَرَكَةَ ‏"‏ ‏.‏ قَالَ الأَعْمَشُ وَلاَ أَدْرِي ذَكَرَ نَافِعًا أَمْ لاَ ‏"‏ فَإِنَّ الرَّجُلَ يَقُولُ إِذَا جَاءَ أَثَمَّ بَرَكَةٌ فَيَقُولُونَ لاَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى أَبُو الزُّبَيْرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ لَمْ يَذْكُرْ بَرَكَةَ ‏.‏\hadithno{4960}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If I survive (God willing), I shall forbid my people to give the names Nafi' (beneficial), Aflah (successful) and Barakah (blessing). Al-A'mash said: I do not know whether he mentioned Nafi' or not. When a man comes and asks: Is there Barakah (blessing)? The people say: No. Abu Dawud said: A similar tradition has been transmitted by Abu al-Zubair on the authority of Jabir from the Prophet (ﷺ) through a different chain of narrators. This version has no mention of Barakah}}
\hadithdefcmd{abudawud}{4961}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ أَخْنَعُ اسْمٍ عِنْدَ اللَّهِ تَبَارَكَ وَتَعَالَى يَوْمَ الْقِيَامَةِ رَجُلٌ تَسَمَّى مَلِكَ الأَمْلاَكِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ شُعَيْبُ بْنُ أَبِي حَمْزَةَ عَنْ أَبِي الزِّنَادِ بِإِسْنَادِهِ قَالَ ‏"‏ أَخْنَى اسْمٍ ‏"‏ ‏.‏\hadithno{4961}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6206) Sahih Muslim (2143)}\hadithtrans{Abu Hurairah reported the prophet (May peace be upon him) as saying :The vilest names in Allah’s sight on the Day of resurrection will be that of a man called Malik al-Amlak. Abu Dawud said: This tradition has also been transmitted by Shu'aib b. Abi Hamzah from Abi al-Zinad through different chain of narrators. This version has the words "akhna' ismin" (most obscene name) instead of "akhna ismin" (the vilest name)}}
\hadithdefcmd{abudawud}{4962}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ دَاوُدَ، عَنْ عَامِرٍ، قَالَ حَدَّثَنِي أَبُو جُبَيْرَةَ بْنُ الضَّحَّاكِ، قَالَ فِينَا نَزَلَتْ هَذِهِ الآيَةُ فِي بَنِي سَلِمَةَ ‏\{‏ وَلاَ تَنَابَزُوا بِالأَلْقَابِ بِئْسَ الاِسْمُ الْفُسُوقُ بَعْدَ الإِيمَانِ ‏\}‏ قَالَ قَدِمَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَيْسَ مِنَّا رَجُلٌ إِلاَّ وَلَهُ اسْمَانِ أَوْ ثَلاَثَةٌ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ يَا فُلاَنُ ‏"‏ ‏.‏ فَيَقُولُونَ مَهْ يَا رَسُولَ اللَّهِ إِنَّهُ يَغْضَبُ مِنْ هَذَا الاِسْمِ فَأُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏ وَلاَ تَنَابَزُوا بِالأَلْقَابِ ‏\}‏ ‏.‏\hadithno{4962}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuJubayrah ibn ad-Dahhak: This verse was revealed about us, the Banu Salimah: "Nor call each other by (offensive) nicknames: ill-seeming is a name connoting wickedness (to be used of one) after he has believed." He said: When the apostle of Allah (ﷺ) came to us, every one of us had two or three names. The Messenger of Allah (ﷺ) began to say: O so and so! But they would say: Keep silence, Messenger of Allah! He becomes angry by this name. So this verse was revealed: "Nor call each other by (offensive) nicknames}}
\hadithdefcmd{abudawud}{4963}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رضى الله عنه ضَرَبَ ابْنًا لَهُ تَكَنَّى أَبَا عِيسَى وَأَنَّ الْمُغِيرَةَ بْنَ شُعْبَةَ تَكَنَّى بِأَبِي عِيسَى فَقَالَ لَهُ عُمَرُ أَمَا يَكْفِيكَ أَنْ تُكَنَّى بِأَبِي عَبْدِ اللَّهِ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَنَّانِي فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ وَإِنَّا فِي جَلْجَلَتِنَا فَلَمْ يَزَلْ يُكْنَى بِأَبِي عَبْدِ اللَّهِ حَتَّى هَلَكَ ‏.‏\hadithno{4963}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umar ibn al-Khattab: Zayd ibn Aslam quoted his father as saying: Umar ibn al-Khattab (Allah be pleased with him) struck one of his sons who was given the kunyah AbuIsa, and al-Mughirah ibn Shu'bah had the kunyah AbuIsa. Umar said to him: Is it not sufficient for you that you are called by the kunyah AbuAbdullah? He replied: The Messenger of Allah (ﷺ) gave me this kunyah. Thereupon he said: The Messenger of Allah (ﷺ) was forgiven all his sins, past and those followed. But we are among the people similar to us. Henceforth he was called by the kunyah AbuAbdullah until he died}}
\hadithdefcmd{abudawud}{4964}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ أَخْبَرَنَا ح، وَحَدَّثَنَا مُسَدَّدٌ، وَمُحَمَّدُ بْنُ مَحْبُوبٍ، قَالُوا حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي عُثْمَانَ، - وَسَمَّاهُ ابْنُ مَحْبُوبٍ الْجَعْدَ - عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ يَا بُنَىَّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ يَحْيَى بْنَ مَعِينٍ يُثْنِي عَلَى مُحَمَّدِ بْنِ مَحْبُوبٍ وَيَقُولُ كَثِيرُ الْحَدِيثِ ‏.‏\hadithno{4964}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2151)}\hadithtrans{Narrated Anas bin Malik: The Prophet (ﷺ) said to him: My sonny. Abu Dawud said: I heard Yahya b. Ma'in praising the transmitter Muhammad b. Mahbub, and he said: He transmitted a large number of traditions}}
\hadithdefcmd{abudawud}{4965}{حَدَّثَنَا مُسَدَّدٌ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكْتَنُوا بِكُنْيَتِي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ أَبُو صَالِحٍ عَنْ أَبِي هُرَيْرَةَ وَكَذَلِكَ رِوَايَةُ أَبِي سُفْيَانَ عَنْ جَابِرٍ وَسَالِمِ بْنِ أَبِي الْجَعْدِ عَنْ جَابِرٍ وَسُلَيْمَانَ الْيَشْكُرِيِّ عَنْ جَابِرٍ وَابْنِ الْمُنْكَدِرِ عَنْ جَابِرٍ نَحْوَهُمْ وَأَنَسِ بْنِ مَالِكٍ ‏.‏\hadithno{4965}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6188) Sahih Muslim (2134)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:Call yourselves by my name, but do not use my KUNYAH (surname). Abu Dawud said : Abu Salih has transmitted it in a similar way from Abu Hurairah, and similar are the traditions of Abu Sufyan from Jabir, of Salim b. Abl al-Ja’d from Jabir, of Sulaiman al-Yashkuri from Jabir, and of Ibn al-Munkadir from Jabir and similar others and Anas b. Malik}}
\hadithdefcmd{abudawud}{4966}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَسَمَّى بِاسْمِي فَلاَ يَكْتَنِي بِكُنْيَتِي وَمَنْ تَكَنَّى بِكُنْيَتِي فَلاَ يَتَسَمَّى بِاسْمِي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى بِهَذَا الْمَعْنَى ابْنُ عَجْلاَنَ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ وَرُوِيَ عَنْ أَبِي زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ مُخْتَلِفًا عَلَى الرِّوَايَتَيْنِ وَكَذَلِكَ رِوَايَةُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ عَنْ أَبِي هُرَيْرَةَ اخْتُلِفَ فِيهِ رَوَاهُ الثَّوْرِيُّ وَابْنُ جُرَيْجٍ عَلَى مَا قَالَ أَبُو الزُّبَيْرِ وَرَوَاهُ مَعْقِلُ بْنُ عُبَيْدِ اللَّهِ عَلَى مَا قَالَ ابْنُ سِيرِينَ وَاخْتُلِفَ فِيهِ عَلَى مُوسَى بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ أَيْضًا عَلَى الْقَوْلَيْنِ اخْتَلَفَ فِيهِ حَمَّادُ بْنُ خَالِدٍ وَابْنُ أَبِي فُدَيْكٍ ‏.‏\hadithno{4966}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If anyone is called by my name, he must not be given my kunyah (surname), and if anyone uses my kunyah (surname), he must not be called by my name. Abu Dawud said: Ibn 'Ajlan transmitted it to the same effect from his father on the authority if Abu Hurairah. It has also been transmitted by Abu Zar'ah from Abu Hurairah in two different versions. And similar is the version of 'Abd al-Rahman b. Abi 'Amrah from Abu Hurairah. This version is disputed: Al-Thawri and Ibn Juraij transmitted it according to the version of Abu al-Zubair; and Ma'qil b. 'Ubaid Allah transmitted it according to the version of Ibn Sirin. It is again dispted on Musa b. Yasar from Abu Hurariah, transmitting it in two versions: Hammad b. Khalid and Ibn Abi Fudaik varied in their versions}}
\hadithdefcmd{abudawud}{4967}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ فِطْرٍ، عَنْ مُنْذِرٍ، عَنْ مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ، قَالَ قَالَ عَلِيٌّ رَحِمَهُ اللَّهُ قُلْتُ يَا رَسُولَ اللَّهِ إِنْ وُلِدَ لِي مِنْ بَعْدِكَ وَلَدٌ أُسَمِّيهِ بِاسْمِكَ وَأُكْنِيهِ بِكُنْيَتِكَ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ وَلَمْ يَقُلْ أَبُو بَكْرٍ قُلْتُ قَالَ عَلِيٌّ عَلَيْهِ السَّلاَمُ لِلنَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4967}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammad b. al-Hanafiyyah quoted 'Ali as saying:I said: Messenger of Allah! tell me if a son is born to me after your death, may I give him your name and your kunyah? He replied: Yes. The transmitter Abu Bakr did not mention the words "I said". Instead, he said: 'Ali said to the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{4968}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عِمْرَانَ الْحَجَبِيُّ، عَنْ جَدَّتِهِ، صَفِيَّةَ بِنْتِ شَيْبَةَ عَنْ عَائِشَةَ، رَضِيَ اللَّهُ عَنْهَا قَالَتْ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي قَدْ وَلَدْتُ غُلاَمًا فَسَمَّيْتُهُ مُحَمَّدًا وَكَنَّيْتُهُ أَبَا الْقَاسِمِ فَذُكِرَ لِي أَنَّكَ تَكْرَهُ ذَلِكَ فَقَالَ ‏"‏ مَا الَّذِي أَحَلَّ اسْمِي وَحَرَّمَ كُنْيَتِي ‏"‏ ‏.‏ أَوْ ‏"‏ مَا الَّذِي حَرَّمَ كُنْيَتِي وَأَحَلَّ اسْمِي ‏"‏ ‏.‏\hadithno{4968}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A woman came to the Messenger of Allah (ﷺ) and said: Messenger of Allah! I have given birth to a boy, and call him Muhammad and AbulQasim as kunyah (surname), but I have been told that you disapproved of that. He replied: What is it which has made my name lawful and my kunyah unlawful, or what is it which has made my kunyah unlawful and my name lawful?}}
\hadithdefcmd{abudawud}{4969}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُ عَلَيْنَا وَلِي أَخٌ صَغِيرٌ يُكْنَى أَبَا عُمَيْرٍ وَكَانَ لَهُ نُغَرٌ يَلْعَبُ بِهِ فَمَاتَ فَدَخَلَ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَرَآهُ حَزِينًا فَقَالَ ‏"‏ مَا شَأْنُهُ ‏"‏ ‏.‏ قَالُوا مَاتَ نُغَرُهُ فَقَالَ ‏"‏ يَا أَبَا عُمَيْرٍ مَا فَعَلَ النُّغَيْرُ ‏"‏ ‏.‏\hadithno{4969}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (847)}\hadithtrans{Anas b. Malik said :The Messenger of Allah (May peace be upon him) used to come to visit us. I had a younger brother who was called Abu ‘Umair by Kunyah (surname). He had a sparrow with which he played, but it died. So one day the prophet (May peace be upon him) came to see him and saw him grieved. He asked: What is the matter with him? The people replied: His sparrow has died. He then said: Abu ‘Umair! What has happened to the little sparrow?}}
\hadithdefcmd{abudawud}{4970}{حَدَّثَنَا مُسَدَّدٌ، وَسُلَيْمَانُ بْنُ حَرْبٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ كُلُّ صَوَاحِبِي لَهُنَّ كُنًى ‏.‏ قَالَ ‏ "‏ فَاكْتَنِي بِابْنِكِ عَبْدِ اللَّهِ ‏"‏ ‏.‏ يَعْنِي ابْنَ أُخْتِهَا قَالَ مُسَدَّدٌ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ قَالَ فَكَانَتْ تُكَنَّى بِأُمِّ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَكَذَا قَالَ قُرَّانُ بْنُ تَمَّامٍ وَمَعْمَرٌ جَمِيعًا عَنْ هِشَامٍ نَحْوَهُ وَرَوَاهُ أَبُو أُسَامَةَ عَنْ هِشَامٍ عَنْ عَبَّادِ بْنِ حَمْزَةَ وَكَذَلِكَ حَمَّادُ بْنُ سَلَمَةَ وَمَسْلَمَةُ بْنُ قَعْنَبٍ عَنْ هِشَامٍ كَمَا قَالَ أَبُو أُسَامَةَ ‏.‏\hadithno{4970}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Aisha said: Messenger of Allah! All my fellow-wives have kunyahs? He said: Give yourself the kunyah by Abdullah, your son - that is to say, her nephew (her sister's son). Musaddad said: Abdullah ibn az-Zubayr. She was called by the kunyah Umm Abdullah. Abu Dawud said: Qurran b. Tammam and Ma'mar all have transmitted it from Hisham in a similar manner. It has also been transmitted by Abu Usamah from Hisham, from 'Abbad b. Hamzah. Similarly, Hammad b. Salamah and Maslamah b. Qa'nab have narrated it from Hisham, like the tradition transmitted by Abu Usamah}}
\hadithdefcmd{abudawud}{4971}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحَضْرَمِيُّ، - إِمَامُ مَسْجِدِ حِمْصٍ - حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ ضُبَارَةَ بْنِ مَالِكٍ الْحَضْرَمِيِّ، عَنْ أَبِيهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ سُفْيَانَ بْنِ أَسِيدٍ الْحَضْرَمِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ كَبُرَتْ خِيَانَةً أَنْ تُحَدِّثَ أَخَاكَ حَدِيثًا هُوَ لَكَ بِهِ مُصَدِّقٌ وَأَنْتَ لَهُ بِهِ كَاذِبٌ ‏"‏ ‏.‏\hadithno{4971}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sufyan ibn Asid al-Hadrami: I heard the Messenger of Allah (ﷺ) say: It is great treachery that you should tell your brother something and have him believe you when you are lying}}
\hadithdefcmd{abudawud}{4972}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى، عَنْ أَبِي قِلاَبَةَ، قَالَ أَبُو مَسْعُودٍ لأَبِي عَبْدِ اللَّهِ أَوْ قَالَ أَبُو عَبْدِ اللَّهِ لأَبِي مَسْعُودٍ مَا سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي ‏"‏ زَعَمُوا ‏"‏ ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ بِئْسَ مَطِيَّةُ الرَّجُلِ زَعَمُوا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو عَبْدِ اللَّهِ هَذَا حُذَيْفَةُ ‏.‏\hadithno{4972}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Mas’ud asked Abu ‘Abu Allah, or Abu Abd Allah asked Abu Mas’ud; what did you hear the Messenger of Allah (May peace be upon him) say about za’ama (they alleged, asserted, or it is said). He replied :I heard the Messenger of Allah (May peace be upon him) say: it is a bad riding-beast for a man (to say) za’ama (they asserted). Abu DAwud said : This Abu ‘Abd Allah is Hudhaifah}}
\hadithdefcmd{abudawud}{4973}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِي حَيَّانَ، عَنْ يَزِيدَ بْنِ حَيَّانَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَهُمْ فَقَالَ ‏ "‏ أَمَّا بَعْدُ ‏"‏ ‏.‏\hadithno{4973}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2408)}\hadithtrans{Zaid b. Arqam said that the Prophet (May peace be upon him) addressed them, saying :To proceed (amma ba’d)}}
\hadithdefcmd{abudawud}{4974}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمُ الْكَرْمَ فَإِنَّ الْكَرْمَ الرَّجُلُ الْمُسْلِمُ وَلَكِنْ قُولُوا حَدَائِقَ الأَعْنَابِ ‏"‏ ‏.‏\hadithno{4974}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :None of you should Call (grapes) karm, for the karm is a Muslim man, but call (grapes) garden of grapes (hada’iq al-a’nab)}}
\hadithdefcmd{abudawud}{4975}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، وَحَبِيبِ بْنِ الشَّهِيدِ، وَهِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ عَبْدِي وَأَمَتِي وَلاَ يَقُولَنَّ الْمَمْلُوكُ رَبِّي وَرَبَّتِي وَلْيَقُلِ الْمَالِكُ فَتَاىَ وَفَتَاتِي وَلْيَقُلِ الْمَمْلُوكُ سَيِّدِي وَسَيِّدَتِي فَإِنَّكُمُ الْمَمْلُوكُونَ وَالرَّبُّ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4975}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: None of you must say: "My slave" (abdi) and "My slave-woman" (amati), and a slave must not say: "My lord" (rabbi or rabbati). The master (of a slave) should say: "My young man" (fataya) and "My young woman" (fatati), and a slave should say "My master" (sayyidi) and "My mistress" (sayyidati), for you are all (Allah's slave and the Lord is Allah, Most High)}}
\hadithdefcmd{abudawud}{4976}{حَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ أَبَا يُونُسَ، حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، فِي هَذَا الْخَبَرِ وَلَمْ يَذْكُرِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ وَلْيَقُلْ سَيِّدِي وَمَوْلاَىَ ‏"‏ ‏.‏\hadithno{4976}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Hurairah through a different chain of narrators. This version does not mention the Prophet (May peace be upon him) i.e, it does not go back to him. It has :He must say: “My master” (sayyidi) and “My patron” (mawlaya)}}
\hadithdefcmd{abudawud}{4977}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُولُوا لِلْمُنَافِقِ سَيِّدٌ فَإِنَّهُ إِنْ يَكُ سَيِّدًا فَقَدْ أَسْخَطْتُمْ رَبَّكُمْ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4977}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Prophet (ﷺ) said: Do not call a hypocrite sayyid (master), for if he is a sayyid, you will displease your Lord, Most High}}
\hadithdefcmd{abudawud}{4978}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ خَبُثَتْ نَفْسِي وَلْيَقُلْ لَقِسَتْ نَفْسِي ‏"‏ ‏.‏\hadithno{4978}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6180) Sahih Muslim (2251)}\hadithtrans{Abu Umamah b. Sahl b. Hunaif quoted his father as saying :None of you must say Khabuthat nafsi (My heart is heaving), but one should say Laqisat nafsi (My heart is being annoyed)}}
\hadithdefcmd{abudawud}{4979}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ جَاشَتْ نَفْسِي وَلَكِنْ لِيَقُلْ لَقِسَتْ نَفْسِي ‏"‏ ‏.‏\hadithno{4979}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘A’ishah reported the Prophet (May peace be upon him) as saying:None of you should say Ja’shat nafsi (My heart is being agitated), but one should say Laqisat nafsi (My heart is being annoyed)}}
\hadithdefcmd{abudawud}{4980}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَسَارٍ، عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُولُوا مَا شَاءَ اللَّهُ وَشَاءَ فُلاَنٌ وَلَكِنْ قُولُوا مَا شَاءَ اللَّهُ ثُمَّ شَاءَ فُلاَنٌ ‏"‏ ‏.‏\hadithno{4980}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hudhayfah: The Prophet (ﷺ) said: Do not say: "What Allah wills and so and so wills," but say: "What Allah wills and afterwards so and so wills}}
\hadithdefcmd{abudawud}{4981}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ بْنِ سَعِيدٍ، قَالَ حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ رُفَيْعٍ، عَنْ تَمِيمٍ الطَّائِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّ خَطِيبًا، خَطَبَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ مَنْ يُطِعِ اللَّهَ وَرَسُولَهُ فَقَدْ رَشَدَ وَمَنْ يَعْصِهِمَا ‏.‏ فَقَالَ ‏"‏ قُمْ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ اذْهَبْ فَبِئْسَ الْخَطِيبُ أَنْتَ ‏"‏ ‏.‏\hadithno{4981}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (870)}\hadithtrans{‘Adl b. Hatim said:A speaker gave sermon before the prophet (May peace be upon him). He said : he who obeys Allah and his Prophet will follow the right course, and he who disobeys them. He (The prophet) said: get up; he said: go away, a bad speaker you are}}
\hadithdefcmd{abudawud}{4982}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ - عَنْ خَالِدٍ، - يَعْنِي الْحَذَّاءَ - عَنْ أَبِي تَمِيمَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ رَجُلٍ، قَالَ كُنْتُ رَدِيفَ النَّبِيِّ صلى الله عليه وسلم فَعَثَرَتْ دَابَّتُهُ فَقُلْتُ تَعِسَ الشَّيْطَانُ ‏.‏ فَقَالَ ‏ "‏ لاَ تَقُلْ تَعِسَ الشَّيْطَانُ فَإِنَّكَ إِذَا قُلْتَ ذَلِكَ تَعَاظَمَ حَتَّى يَكُونَ مِثْلَ الْبَيْتِ وَيَقُولَ بِقُوَّتِي وَلَكِنْ قُلْ بِسْمِ اللَّهِ فَإِنَّكَ إِذَا قُلْتَ ذَلِكَ تَصَاغَرَ حَتَّى يَكُونَ مِثْلَ الذُّبَابِ ‏"‏ ‏.‏\hadithno{4982}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu al-Malih reported on the authority of a man :I was riding on a mount behind the prophet (May peace be upon him). It stumbled. Thereupon I said: May the devil perish! He said: do not say; may the devil perish! For you say that, he will swell so much so that he will be like a house, and say: by my power. But say: in the name of Allah; for when you say that, he will diminish so much so that he will be like a fly}}
\hadithdefcmd{abudawud}{4983}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا سَمِعْتَ ‏"‏ ‏.‏ وَقَالَ مُوسَى ‏"‏ إِذَا قَالَ الرَّجُلُ هَلَكَ النَّاسُ فَهُوَ أَهْلَكُهُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مَالِكٌ إِذَا قَالَ ذَلِكَ تَحَزُّنًا لِمَا يَرَى فِي النَّاسِ - يَعْنِي فِي أَمْرِ دِينِهِمْ - فَلاَ أَرَى بِهِ بَأْسًا وَإِذَا قَالَ ذَلِكَ عُجْبًا بِنَفْسِهِ وَتَصَاغُرًا لِلنَّاسِ فَهُوَ الْمَكْرُوهُ الَّذِي نُهِيَ عَنْهُ ‏.‏\hadithno{4983}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2623)}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When you hear....(Musa's version has): When a man says people have perished, he is the one who has suffered that fate most. Abu Dawud said: Malik said: If he says that out of sadness for the decadence of religion which he sees among the people, I do not think there is any harm in that. If he says that out of self-conceit and servility of the people, it is an abominable act which has been prohibited}}
\hadithdefcmd{abudawud}{4984}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَغْلِبَنَّكُمُ الأَعْرَابُ عَلَى اسْمِ صَلاَتِكُمْ أَلاَ وَإِنَّهَا الْعِشَاءُ وَلَكِنَّهُمْ يُعْتِمُونَ بِالإِبِلِ ‏"‏ ‏.‏\hadithno{4984}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (644)}\hadithtrans{Ibn ‘Umar reported the prophet (May peace be upon him) as saying:The desert Arabs may not dominate you in respect of the name of your prayer. Beware! It is al-`Isha, but they milk their camels when it is fairly dark}}
\hadithdefcmd{abudawud}{4985}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا مِسْعَرُ بْنُ كِدَامٍ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، قَالَ قَالَ رَجُلٌ - قَالَ مِسْعَرٌ أُرَاهُ مِنْ خُزَاعَةَ - لَيْتَنِي صَلَّيْتُ فَاسْتَرَحْتُ فَكَأَنَّهُمْ عَابُوا عَلَيْهِ ذَلِكَ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَا بِلاَلُ أَقِمِ الصَّلاَةَ أَرِحْنَا بِهَا ‏"‏ ‏.‏\hadithno{4985}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated A man: Salim ibn AbulJa'dah said: A man said: (Mis'ar said: I think he was from the tribe of Khuza'ah): would that I had prayed, and got comfort. The people objected to him for it. Thereupon he said: I heard the Messenger of Allah (ﷺ) as saying: O Bilal, call iqamah for prayer: give us comfort by it}}
\hadithdefcmd{abudawud}{4986}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا إِسْرَائِيلُ، حَدَّثَنَا عُثْمَانُ بْنُ الْمُغِيرَةِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ، قَالَ انْطَلَقْتُ أَنَا وَأَبِي، إِلَى صِهْرٍ لَنَا مِنَ الأَنْصَارِ نَعُودُهُ فَحَضَرَتِ الصَّلاَةُ فَقَالَ لِبَعْضِ أَهْلِهِ يَا جَارِيَةُ ائْتُونِي بِوَضُوءٍ لَعَلِّي أُصَلِّي فَأَسْتَرِيحَ - قَالَ - فَأَنْكَرْنَا ذَلِكَ عَلَيْهِ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قُمْ يَا بِلاَلُ أَقِمْ فَأَرِحْنَا بِالصَّلاَةِ ‏"‏ ‏.‏\hadithno{4986}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Muhammad ibn al-Hanafiyyah: I and my father went to the house of my father-in-law from the Ansar to pay a sick visit to him. The time of prayer came. He said to someone of his relatives: O girl! bring me water for ablution so that I pray and get comfort. We objected to him for it. He said: I heard the Messenger of Allah (ﷺ) say: Get up, Bilal, and give us comfort by the prayer}}
\hadithdefcmd{abudawud}{4987}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَائِشَةَ، رضى الله عنها، قَالَتْ مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْسُبُ أَحَدًا إِلاَّ إِلَى الدِّينِ ‏.‏\hadithno{4987}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I never heard the Messenger of Allah (ﷺ) attributing anyone to anything except to religion}}
\hadithdefcmd{abudawud}{4988}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ فَزَعٌ بِالْمَدِينَةِ فَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَسًا لأَبِي طَلْحَةَ فَقَالَ ‏"‏ مَا رَأَيْنَا شَيْئًا ‏"‏ ‏.‏ أَوْ ‏"‏ مَا رَأَيْنَا مِنْ فَزَعٍ وَإِنْ وَجَدْنَاهُ لَبَحْرًا ‏"‏ ‏.‏\hadithno{4988}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2627) Sahih Muslim (2307)}\hadithtrans{Anas said:The people of Madina were started. The Messenger of Allah (May peace be upon him) rode on the horse belonging to Abu Talhah. He said: We did not see anything, or he said: we did not see (find) any fear. I found it (could run) like a river}}
\hadithdefcmd{abudawud}{4989}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، أَخْبَرَنَا الأَعْمَشُ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِيَّاكُمْ وَالْكَذِبَ فَإِنَّ الْكَذِبَ يَهْدِي إِلَى الْفُجُورِ وَإِنَّ الْفُجُورَ يَهْدِي إِلَى النَّارِ وَإِنَّ الرَّجُلَ لَيَكْذِبُ وَيَتَحَرَّى الْكَذِبَ حَتَّى يُكْتَبَ عِنْدَ اللَّهِ كَذَّابًا وَعَلَيْكُمْ بِالصِّدْقِ فَإِنَّ الصِّدْقَ يَهْدِي إِلَى الْبِرِّ وَإِنَّ الْبِرَّ يَهْدِي إِلَى الْجَنَّةِ وَإِنَّ الرَّجُلَ لَيَصْدُقُ وَيَتَحَرَّى الصِّدْقَ حَتَّى يُكْتَبَ عِنْدَ اللَّهِ صِدِّيقًا ‏"‏ ‏.‏\hadithno{4989}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6094) Sahih Muslim (2607)}\hadithtrans{‘Abd Allah (b. Mas’ud) reported the Messenger of Allah (May peace be upon him) as saying :Avoid falsehood, for falsehood leads to wickedness, and wickedness to hell; and if a man continues to speak falsehood and makes falsehood his object, he will be recorded in Allah’s presence as a great liar. And adhere to truth, for truth leads to good deeds, and good deeds lead to paradise. If a man continues to speak the truth and makes truth his object, he will be recorded in Allah’s presence as eminently truthful}}
\hadithdefcmd{abudawud}{4990}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا يَحْيَى، عَنْ بَهْزِ بْنِ حَكِيمٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَيْلٌ لِلَّذِي يُحَدِّثُ فَيَكْذِبُ لِيُضْحِكَ بِهِ الْقَوْمَ وَيْلٌ لَهُ وَيْلٌ لَهُ ‏"‏ ‏.‏\hadithno{4990}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'awiyah ibn Jaydah al-Qushayri: The Messenger of Allah (ﷺ) said: Woe to him who tells things, speaking falsely, to make people laugh thereby. Woe to him! Woe to him}}
\hadithdefcmd{abudawud}{4991}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، أَنَّ رَجُلاً، مِنْ مَوَالِي عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ الْعَدَوِيِّ حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَامِرٍ أَنَّهُ قَالَ دَعَتْنِي أُمِّي يَوْمًا وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَاعِدٌ فِي بَيْتِنَا فَقَالَتْ هَا تَعَالَ أُعْطِيكَ ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَا أَرَدْتِ أَنْ تُعْطِيهِ ‏"‏ ‏.‏ قَالَتْ أُعْطِيهِ تَمْرًا ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا إِنَّكِ لَوْ لَمْ تُعْطِيهِ شَيْئًا كُتِبَتْ عَلَيْكِ كِذْبَةٌ ‏"‏ ‏.‏\hadithno{4991}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amir: My mother called me one day when the Messenger of Allah (ﷺ) was sitting in our house. She said: Come here and I shall give you something. The Messenger of Allah (ﷺ) asked her: What did you intend to give him? She replied: I intended to give him some dates. The Messenger of Allah (ﷺ) said: If you were not to give him anything, a lie would be recorded against you}}
\hadithdefcmd{abudawud}{4992}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْحُسَيْنِ، حَدَّثَنَا عَلِيُّ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، - قَالَ ابْنُ حُسَيْنٍ فِي حَدِيثِهِ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ كَفَى بِالْمَرْءِ إِثْمًا أَنْ يُحَدِّثَ بِكُلِّ مَا سَمِعَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَمْ يَذْكُرْ حَفْصٌ أَبَا هُرَيْرَةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَمْ يُسْنِدْهُ إِلاَّ هَذَا الشَّيْخُ يَعْنِي عَلِيَّ بْنَ حَفْصٍ الْمَدَائِنِيَّ ‏.‏\hadithno{4992}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: It is enough falsehood for a man to relate everything he hears. Abu Dawud said: Hafs did not mention Abu Hurairah (in his version). Abu Dawud said: No other transmitter except this old man, that is, 'Ali b. Hafs al-Mada'ini related the perfect chain of this tradition}}
\hadithdefcmd{abudawud}{4993}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، عَنْ مُهَنَّا أَبِي شِبْلٍ، - قَالَ أَبُو دَاوُدَ وَلَمْ أَفْهَمْهُ مِنْهُ جَيِّدًا - عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ وَاسِعٍ، عَنْ شُتَيْرٍ، - قَالَ نَصْرٌ ‏:‏ ابْنِ نَهَّارٍ - عَنْ أَبِي هُرَيْرَةَ، - قَالَ نَصْرٌ - عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ حُسْنُ الظَّنِّ مِنْ حُسْنِ الْعِبَادَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ مُهَنَّا ثِقَةٌ بَصْرِيٌّ ‏.‏\hadithno{4993}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: To harbour good thoughts is a part of well-conducted worship. (This is according to Nasr's version). Abu Dawud said: Mahna' is reliable and he is from Basrah}}
\hadithdefcmd{abudawud}{4994}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ صَفِيَّةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُعْتَكِفًا فَأَتَيْتُهُ أَزُورُهُ لَيْلاً فَحَدَّثْتُهُ وَقُمْتُ فَانْقَلَبْتُ فَقَامَ مَعِي لِيَقْلِبَنِي - وَكَانَ مَسْكَنُهَا فِي دَارِ أُسَامَةَ بْنِ زَيْدٍ - فَمَرَّ رَجُلاَنِ مِنَ الأَنْصَارِ فَلَمَّا رَأَيَا النَّبِيَّ صلى الله عليه وسلم أَسْرَعَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى رِسْلِكُمَا إِنَّهَا صَفِيَّةُ بِنْتُ حُيَىٍّ ‏"‏ ‏.‏ قَالاَ سُبْحَانَ اللَّهِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنَ الإِنْسَانِ مَجْرَى الدَّمِ فَخَشِيتُ أَنْ يَقْذِفَ فِي قُلُوبِكُمَا شَيْئًا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ شَرًّا ‏"‏ ‏.‏\hadithno{4994}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3281) Sahih Muslim (2175)}\hadithtrans{Safiyyah said :The Messenger of Allah (May peace be upon him) was in the I’TIKAF(seclusion in the mosque). I came to visit him at night . I talked to him, got up and turned my back. He got up with me to accompany me. He was living in the house of Usamah b. Zaid. Two men of the Ansar passed by him. When they saw the Messenger of Allah (May peace be upon him), they walked quickly. The prophet (May peace be upon him) said: Be at ease; she is Safiyyah daughter of Huyayy. They said: Glory be to Allah, Messenger of Allah! He said: The devil flows in man as the blood flows in him. I feared that he might inject something in your hearts, or he said “evil” (instead of something)}}
\hadithdefcmd{abudawud}{4995}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ عَلِيِّ بْنِ عَبْدِ الأَعْلَى، عَنْ أَبِي النُّعْمَانِ، عَنْ أَبِي وَقَّاصٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَعَدَ الرَّجُلُ أَخَاهُ - وَمِنْ نِيَّتِهِ أَنْ يَفِيَ لَهُ - فَلَمْ يَفِ وَلَمْ يَجِئْ لِلْمِيعَادِ فَلاَ إِثْمَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4995}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zayd ibn Arqam: The Prophet (ﷺ) said: When a man makes a promise to his brother with the intention of fulfilling it and does not do so, and does not come at the appointed time, he is guilty of no sin}}
\hadithdefcmd{abudawud}{4996}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ النَّيْسَابُورِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ بُدَيْلٍ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْحَمْسَاءِ، قَالَ بَايَعْتُ النَّبِيَّ صلى الله عليه وسلم بِبَيْعٍ قَبْلَ أَنْ يُبْعَثَ وَبَقِيَتْ لَهُ بَقِيَّةٌ فَوَعَدْتُهُ أَنْ آتِيَهُ بِهَا فِي مَكَانِهِ فَنَسِيتُ ثُمَّ ذَكَرْتُ بَعْدَ ثَلاَثٍ فَجِئْتُ فَإِذَا هُوَ فِي مَكَانِهِ فَقَالَ ‏ "‏ يَا فَتَى لَقَدْ شَقَقْتَ عَلَىَّ أَنَا هَا هُنَا مُنْذُ ثَلاَثٍ أَنْتَظِرُكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مُحَمَّدُ بْنُ يَحْيَى هَذَا عِنْدَنَا عَبْدُ الْكَرِيمِ بْنُ عَبْدِ اللَّهِ بْنِ شَقِيقٍ ‏.‏ قَالَ أَبُو دَاوُدَ هَكَذَا بَلَغَنِي عَنْ عَلِيِّ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو دَاوُدَ بَلَغَنِي أَنَّ بِشْرَ بْنَ السَّرِيِّ رَوَاهُ عَنْ عَبْدِ الْكَرِيمِ بْنِ عَبْدِ اللَّهِ بْنِ شَقِيقٍ ‏.‏\hadithno{4996}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn AbulHamsa': I bought something from the Prophet (ﷺ) before he received his Prophetic commission, and as there was something still due to him I promised him that I would bring it to him at his place, but I forgot. When I remembered three days later, I went to that place and found him there. He said: You have vexed me, young man. I have been here for three days waiting for you. Abu Dawud said: Muhammad b. Yahya said : This is, in our opinion, 'Abd al-Karim b. 'Abd Allah b. Shaqiq (instead of "from 'Abd al-Karim from 'Abd Allah b. Shaqiq"). Abu Dawud said: In a similar way I have been informed by 'Ali b. 'Abd Allah. Abu Dawud said: I have been told that Bishr b. al-Sarri transmitted it from 'Abd Allah b. Shaqiq}}
\hadithdefcmd{abudawud}{4997}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّ امْرَأَةً، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ لِي جَارَةً - تَعْنِي ضَرَّةً - هَلْ عَلَىَّ جُنَاحٌ إِنْ تَشَبَّعْتُ لَهَا بِمَا لَمْ يُعْطِ زَوْجِي قَالَ ‏ "‏ الْمُتَشَبِّعُ بِمَا لَمْ يُعْطَ كَلاَبِسِ ثَوْبَىْ زُورٍ ‏"‏ ‏.‏\hadithno{4997}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5219) Sahih Muslim (2130)}\hadithtrans{Asma’, daughter of Abu Bakr, told of a woman who said :Messenger of Allah! I have a fellow-wife; will it be wrong for me to boast of receiving from my husband what he does not give me? He replied: the one who boasts of receiving what he has not been given is like him who has put on two garments of falsehood}}
\hadithdefcmd{abudawud}{4998}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ احْمِلْنِي ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّا حَامِلُوكَ عَلَى وَلَدِ نَاقَةٍ ‏"‏ ‏.‏ قَالَ وَمَا أَصْنَعُ بِوَلَدِ النَّاقَةِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَهَلْ تَلِدُ الإِبِلَ إِلاَّ النُّوقُ ‏"‏ ‏.‏\hadithno{4998}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: A man came to the Prophet (ﷺ) and said: Messenger of Allah! give me a mount. The Prophet (ﷺ) said: We shall give you a she-camel's child to ride on. He said: What shall I do with a she-camel's child? The Prophet (ﷺ) replied: Do any others than she-camels give birth to camels?}}
\hadithdefcmd{abudawud}{4999}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْعَيْزَارِ بْنِ حُرَيْثٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ اسْتَأْذَنَ أَبُو بَكْرٍ رَحْمَةُ اللَّهِ عَلَيْهِ عَلَى النَّبِيِّ صلى الله عليه وسلم فَسَمِعَ صَوْتَ عَائِشَةَ عَالِيًا فَلَمَّا دَخَلَ تَنَاوَلَهَا لِيَلْطِمَهَا وَقَالَ لاَ أَرَاكِ تَرْفَعِينَ صَوْتَكِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَحْجُزُهُ وَخَرَجَ أَبُو بَكْرٍ مُغْضَبًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم حِينَ خَرَجَ أَبُو بَكْرٍ ‏"‏ كَيْفَ رَأَيْتِنِي أَنْقَذْتُكِ مِنَ الرَّجُلِ ‏"‏ ‏.‏ قَالَ فَمَكَثَ أَبُو بَكْرٍ أَيَّامًا ثُمَّ اسْتَأْذَنَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَجَدَهُمَا قَدِ اصْطَلَحَا فَقَالَ لَهُمَا أَدْخِلاَنِي فِي سِلْمِكُمَا كَمَا أَدْخَلْتُمَانِي فِي حَرْبِكُمَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَدْ فَعَلْنَا قَدْ فَعَلْنَا ‏"‏ ‏.‏\hadithno{4999}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated An-Nu'man ibn Bashir: When AbuBakr asked the permission of the Prophet (ﷺ) to come in, he heard Aisha speaking in a loud voice. So when he entered, he caught hold of her in order to slap her, and said: Do I see you raising your voice to the Messenger of Allah? The Prophet (ﷺ) began to prevent him and AbuBakr went out angry. The Prophet (ﷺ) said when AbuBakr went out: You see I rescued you from the man. AbuBakr waited for some days, then asked permission of the Messenger of Allah (ﷺ) to enter, and found that they had made peace with each other. He said to them: Bring me into your peace as you brought me into your war. The Prophet (ﷺ) said: We have done so: we have done so}}
\hadithdefcmd{abudawud}{5000}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْعَلاَءِ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ وَهُوَ فِي قُبَّةٍ مِنْ أَدَمٍ فَسَلَّمْتُ فَرَدَّ وَقَالَ ‏"‏ ادْخُلْ ‏"‏ ‏.‏ فَقُلْتُ أَكُلِّي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ كُلُّكَ ‏"‏ ‏.‏ فَدَخَلْتُ ‏.‏\hadithno{5000}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3176)}\hadithtrans{‘Awf b. Malik al-Ashja’i said :I came to the Messenger of Allah (May peace be upon him) at the expedition to Tabuk when he was in a small skin tent. I gave him a salutation and he returned it, saying: come in. I asked : the whole of me Messenger of Allah? He replied : The whole of you. So I entered}}
\hadithdefcmd{abudawud}{5001}{حَدَّثَنَا صَفْوَانُ بْنُ صَالِحٍ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا عُثْمَانُ بْنُ أَبِي الْعَاتِكَةِ، قَالَ إِنَّمَا قَالَ أَدْخُلُ كُلِّي ‏.‏ مِنْ صِغَرِ الْقُبَّةِ ‏.‏\hadithno{5001}\hadithgrade{Al-Albani: Daif Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Uthman b. Abu 'Atikah said :The only reason why he asked whether the whole of him should come in was because of the smallness of the tent}}
\hadithdefcmd{abudawud}{5002}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مَهْدِيٍّ، حَدَّثَنَا شَرِيكٌ، عَنْ عَاصِمٍ، عَنْ أَنَسٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا ذَا الأُذُنَيْنِ ‏"‏ ‏.‏\hadithno{5002}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) addressed me as: O you with the two ears}}
\hadithdefcmd{abudawud}{5003}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ أَبِي ذِئْبٍ، ح وَحَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَأْخُذَنَّ أَحَدُكُمْ مَتَاعَ أَخِيهِ لاَعِبًا وَلاَ جَادًّا ‏"‏ ‏.‏ وَقَالَ سُلَيْمَانُ ‏"‏ لَعِبًا وَلاَ جِدًّا ‏"‏ ‏.‏ ‏"‏ وَمَنْ أَخَذَ عَصَا أَخِيهِ فَلْيَرُدَّهَا ‏"‏ ‏.‏ لَمْ يَقُلِ ابْنُ بَشَّارٍ ابْنِ يَزِيدَ وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5003}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn as-Sa'ib ibn Yazid: The Messenger of Allah (ﷺ) said: None of you should take the property of his brother in amusement (i.e. jest), nor in earnest. The narrator Sulayman said: Out of amusement and out of earnest. If anyone takes the staff of his brother, he should return it. The transmitter Ibn Bashshar did not say "Ibn Yazid, and he said: The Messenger of Allah (ﷺ) said}}
\hadithdefcmd{abudawud}{5004}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ يَسَارٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ حَدَّثَنَا أَصْحَابُ، مُحَمَّدٍ صلى الله عليه وسلم أَنَّهُمْ كَانُوا يَسِيرُونَ مَعَ النَّبِيِّ صلى الله عليه وسلم فَنَامَ رَجُلٌ مِنْهُمْ فَانْطَلَقَ بَعْضُهُمْ إِلَى حَبْلٍ مَعَهُ فَأَخَذَهُ فَفَزِعَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يُرَوِّعَ مُسْلِمًا ‏"‏ ‏.‏\hadithno{5004}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbdurRahman ibn AbuLayla: The Companions of the Prophet (ﷺ) told us that they were travelling with the Prophet (ﷺ). A man of them slept, and one of them went to the rope which he had with him. He took it, by which he was frightened. The Prophet (ﷺ) said: It is not lawful for a Muslim that he frightens a Muslim}}
\hadithdefcmd{abudawud}{5005}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ الْبَاهِلِيُّ، - وَكَانَ يَنْزِلُ الْعَوَقَةَ - حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنْ بِشْرِ بْنِ عَاصِمٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ، - قَالَ أَبُو دَاوُدَ وَهُوَ ابْنُ عَمْرٍو - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يُبْغِضُ الْبَلِيغَ مِنَ الرِّجَالِ الَّذِي يَتَخَلَّلُ بِلِسَانِهِ تَخَلُّلَ الْبَاقِرَةِ بِلِسَانِهَا ‏"‏ ‏.‏\hadithno{5005}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) said: Allah , the Exalted, hates the eloquent one among men who moves his tongue round (among his teeth), as cattle do}}
\hadithdefcmd{abudawud}{5006}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا وَهْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُسَيَّبِ، عَنِ الضَّحَّاكِ بْنِ شُرَحْبِيلَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَعَلَّمَ صَرْفَ الْكَلاَمِ لِيَسْبِيَ بِهِ قُلُوبَ الرِّجَالِ أَوِ النَّاسِ لَمْ يَقْبَلِ اللَّهُ مِنْهُ يَوْمَ الْقِيَامَةِ صَرْفًا وَلاَ عَدْلاً ‏"‏ ‏.‏\hadithno{5006}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: On the Day of resurrection Allah will not accept repentance or ransom from him who learns excellence of speech to captivate thereby the hearts of men, or of people}}
\hadithdefcmd{abudawud}{5007}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ قَدِمَ رَجُلاَنِ مِنَ الْمَشْرِقِ فَخَطَبَا فَعَجِبَ النَّاسُ - يَعْنِي لِبَيَانِهِمَا - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنَ الْبَيَانِ لَسِحْرًا ‏"‏ ‏.‏ أَوْ ‏"‏ إِنَّ بَعْضَ الْبَيَانِ لَسِحْرٌ ‏"‏ ‏.‏\hadithno{5007}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5767)}\hadithtrans{‘Abd Allah b. ‘Umar said :When two men who came from the east made a speech and the people were charmed with their eloquence, the Messenger of Allah (May peace be upon him) said: In some eloquent speech there is magic}}
\hadithdefcmd{abudawud}{5008}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الْحَمِيدِ الْبَهْرَانِيُّ، أَنَّهُ قَرَأَ فِي أَصْلِ إِسْمَاعِيلَ بْنِ عَيَّاشٍ وَحَدَّثَهُ مُحَمَّدُ بْنُ إِسْمَاعِيلَ ابْنُهُ قَالَ حَدَّثَنِي أَبِي قَالَ حَدَّثَنِي ضَمْضَمٌ عَنْ شُرَيْحِ بْنِ عُبَيْدٍ قَالَ حَدَّثَنَا أَبُو ظَبْيَةَ أَنَّ عَمْرَو بْنَ الْعَاصِ قَالَ يَوْمًا وَقَامَ رَجُلٌ فَأَكْثَرَ الْقَوْلَ فَقَالَ عَمْرٌو لَوْ قَصَدَ فِي قَوْلِهِ لَكَانَ خَيْرًا لَهُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَقَدْ رَأَيْتُ أَوْ أُمِرْتُ أَنْ أَتَجَوَّزَ فِي الْقَوْلِ فَإِنَّ الْجَوَازَ هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{5008}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{One day when a man got up and spoke at length Amr ibn al-'As said If he had been moderate in what he said:It would have been better for him. I heard the Messenger of Allah (ﷺ) say: I think (or, I have been commanded) that I should be brief in what I say, for brevity is better}}
\hadithdefcmd{abudawud}{5009}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَمْتَلِئَ جَوْفُ أَحَدِكُمْ قَيْحًا خَيْرٌ لَهُ مِنْ أَنْ يَمْتَلِئَ شِعْرًا ‏"‏ ‏.‏ قَالَ أَبُو عَلِيٍّ بَلَغَنِي عَنْ أَبِي عُبَيْدٍ أَنَّهُ قَالَ وَجْهُهُ أَنْ يَمْتَلِئَ قَلْبُهُ حَتَّى يَشْغَلَهُ عَنِ الْقُرْآنِ وَذِكْرِ اللَّهِ فَإِذَا كَانَ الْقُرْآنُ وَالْعِلْمُ الْغَالِبُ فَلَيْسَ جَوْفُ هَذَا عِنْدَنَا مُمْتَلِئًا مِنَ الشِّعْرِ وَإِنَّ مِنَ الْبَيَانِ لَسِحْرًا ‏.‏ قَالَ كَأَنَّ الْمَعْنَى أَنْ يَبْلُغَ مِنْ بَيَانِهِ أَنْ يَمْدَحَ الإِنْسَانَ فَيَصْدُقَ فِيهِ حَتَّى يَصْرِفَ الْقُلُوبَ إِلَى قَوْلِهِ ثُمَّ يَذُمَّهُ فَيَصْدُقَ فِيهِ حَتَّى يَصْرِفَ الْقُلُوبَ إِلَى قَوْلِهِ الآخَرِ فَكَأَنَّهُ سَحَرَ السَّامِعِينَ بِذَلِكَ ‏.‏\hadithno{5009}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :it is better for a man’s belly to be full of pus than to be full of poetry. Abu ‘Ali said : I have been told that Abu ‘Ubaid said : It means that his heart is full of poetry so much so that it makes him neglectful of the Quran and remembrance of Allah. If the Quran and the knowledge (of religion) are dominant, the belly will not be full of poetry in our opinion. Some eloquent speech is magic. It means that a man expresses his eloquence by praising another man, and he speaks the truth about him so much so that he attracts the hearts to his speech. He then condemns him and speaks the truth about him so much so that he attracts the hearts to another of his speech, as if he spelled the audience by it}}
\hadithdefcmd{abudawud}{5010}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ مَرْوَانَ بْنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ بْنِ عَبْدِ يَغُوثَ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مِنَ الشِّعْرِ حِكْمَةً ‏"‏ ‏.‏\hadithno{5010}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6145)}\hadithtrans{Ubayy b. Ka’b reported the Prophet (May peace be upon him) as saying :In poetry there is wisdom}}
\hadithdefcmd{abudawud}{5011}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَجَعَلَ يَتَكَلَّمُ بِكَلاَمٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنَ الْبَيَانِ سِحْرًا وَإِنَّ مِنَ الشِّعْرِ حُكْمًا ‏"‏ ‏.‏\hadithno{5011}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: A desert Arab came to the Prophet (ﷺ) and began to speak. Thereupon the Messenger of Allah (ﷺ) said: In eloquence there is magic and in poetry there is wisdom}}
\hadithdefcmd{abudawud}{5012}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو تُمَيْلَةَ، قَالَ حَدَّثَنِي أَبُو جَعْفَرٍ النَّحْوِيُّ عَبْدُ اللَّهِ بْنُ ثَابِتٍ، قَالَ حَدَّثَنِي صَخْرُ بْنُ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ مِنَ الْبَيَانِ سِحْرًا وَإِنَّ مِنَ الْعِلْمِ جَهْلاً وَإِنَّ مِنَ الشِّعْرِ حُكْمًا وَإِنَّ مِنَ الْقَوْلِ عِيَالاً ‏"‏ ‏.‏ فَقَالَ صَعْصَعَةُ بْنُ صُوحَانَ صَدَقَ نَبِيُّ اللَّهِ صلى الله عليه وسلم أَمَّا قَوْلُهُ ‏"‏ إِنَّ مِنَ الْبَيَانِ سِحْرًا ‏"‏ ‏.‏ فَالرَّجُلُ يَكُونُ عَلَيْهِ الْحَقُّ وَهُوَ أَلْحَنُ بِالْحُجَجِ مِنْ صَاحِبِ الْحَقِّ فَيَسْحَرُ الْقَوْمَ بِبَيَانِهِ فَيَذْهَبُ بِالْحَقِّ وَأَمَّا قَوْلُهُ ‏"‏ إِنَّ مِنَ الْعِلْمِ جَهْلاً ‏"‏ ‏.‏ فَيَتَكَلَّفُ الْعَالِمُ إِلَى عِلْمِهِ مَا لاَ يَعْلَمُ فَيُجَهِّلُهُ ذَلِكَ وَأَمَّا قَوْلُهُ ‏"‏ إِنَّ مِنَ الشِّعْرِ حُكْمًا ‏"‏ ‏.‏ فَهِيَ هَذِهِ الْمَوَاعِظُ وَالأَمْثَالُ الَّتِي يَتَّعِظُ بِهَا النَّاسُ وَأَمَّا قَوْلُهُ ‏"‏ إِنَّ مِنَ الْقَوْلِ عِيَالاً ‏"‏ ‏.‏ فَعَرْضُكَ كَلاَمَكَ وَحَدِيثَكَ عَلَى مَنْ لَيْسَ مِنْ شَأْنِهِ وَلاَ يُرِيدُهُ ‏.‏\hadithno{5012}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraydah ibn al-Hasib: I heard the Messenger of Allah (ﷺ) say: In eloquence there is magic, in knowledge ignorance, in poetry wisdom, and in speech heaviness. Sa'sa'ah ibn Suhan said: The Prophet of Allah (ﷺ) spoke the truth. His statement "In eloquence there is magic" means: (For example), there is a right due from a man who is more eloquent in reasoning than the man who is demanding his right. He (the defendant) charms the people by his speech and takes away his right. His statement "In knowledge there is ignorance" means: A scholar brings to his knowledge what he does not know, and thus he becomes ignorant of that. His statement "In poetry there is wisdom" means: These are the sermons and examples by which people receive admonition. His statement "In speech there is heaviness" means: That you present your speech and your talk to a man who is not capable of understanding it, and who does not want it}}
\hadithdefcmd{abudawud}{5013}{حَدَّثَنَا ابْنُ أَبِي خَلَفٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، قَالَ مَرَّ عُمَرُ بِحَسَّانَ وَهُوَ يُنْشِدُ فِي الْمَسْجِدِ فَلَحَظَ إِلَيْهِ فَقَالَ قَدْ كُنْتُ أُنْشِدُ وَفِيهِ مَنْ هُوَ خَيْرٌ مِنْكَ ‏.‏\hadithno{5013}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sa'id said:Umar passed by Hassan when he was reciting verses in the mosque. He looked at him. Thereupon he said: I used to recite verses when there was present in it the one who was better than you (i.e. the Prophet)}}
\hadithdefcmd{abudawud}{5014}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، بِمَعْنَاهُ زَادَ فَخَشِيَ أَنْ يَرْمِيَهُ، بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَجَازَهُ ‏.‏\hadithno{5014}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3212) Sahih Muslim (2485)}\hadithtrans{The tradition mention above has also been transmitted by Sa’id b. al-Musayyab through a different chain of narrators to the same effect. This version adds:so he (‘Umar’) feared that he would refer to the Messenger of Allah (May peace be upon him); therefore he allowed him}}
\hadithdefcmd{abudawud}{5015}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الْمِصِّيصِيُّ، لُوَيْنٌ حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، وَهِشَامٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضَعُ لِحَسَّانَ مِنْبَرًا فِي الْمَسْجِدِ فَيَقُومُ عَلَيْهِ يَهْجُو مَنْ قَالَ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ رُوحَ الْقُدُسِ مَعَ حَسَّانَ مَا نَافَحَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏\hadithno{5015}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) used to setup a pulpit in the mosque for Hassan who would stand on it and satirise those who spoke against the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) would say: The spirit of holiness (i.e. Gabriel) is with Hassan so long as he speaks in defence of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{5016}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ وَالشُّعَرَاءُ يَتَّبِعُهُمُ الْغَاوُونَ ‏\}‏ فَنَسَخَ مِنْ ذَلِكَ وَاسْتَثْنَى فَقَالَ ‏\{‏ إِلاَّ الَّذِينَ آمَنُوا وَعَمِلُوا الصَّالِحَاتِ وَذَكَرُوا اللَّهَ كَثِيرًا ‏\}‏ ‏.‏\hadithno{5016}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Abbas said :The verse “And the poets it is those straying in evil who follow them. He (Allah) then abrogated it and made an exception saying: Except those who believe and work righteousness, engage much in the remembrance of Allah}}
\hadithdefcmd{abudawud}{5017}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ زُفَرَ بْنِ صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا انْصَرَفَ مِنَ صَلاَةِ الْغَدَاةِ يَقُولُ ‏"‏ هَلْ رَأَى أَحَدٌ مِنْكُمُ اللَّيْلَةَ رُؤْيَا وَيَقُولُ ‏"‏ إِنَّهُ لَيْسَ يَبْقَى بَعْدِي مِنَ النُّبُوَّةِ إِلاَّ الرُّؤْيَا الصَّالِحَةُ ‏"‏ ‏.‏\hadithno{5017}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: When the Messenger of Allah (ﷺ) finished the dawn prayer, he would ask: Did any of you have a dream last night? And he said: All that is left of Prophecy after me is a good vision}}
\hadithdefcmd{abudawud}{5018}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رُؤْيَا الْمُؤْمِنِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5018}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6987) Sahih Muslim (2264)}\hadithtrans{‘Ubadah b. al-Samit reported the Prophet (May peace be upon him) as saying :A believer’s vision is the forty-sixth part of Prophecy}}
\hadithdefcmd{abudawud}{5019}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا اقْتَرَبَ الزَّمَانُ لَمْ تَكَدْ رُؤْيَا الْمُؤْمِنِ أَنْ تَكْذِبَ وَأَصْدَقُهُمْ رُؤْيَا أَصْدَقُهُمْ حَدِيثًا وَالرُّؤْيَا ثَلاَثٌ فَالرُّؤْيَا الصَّالِحَةُ بُشْرَى مِنَ اللَّهِ وَالرُّؤْيَا تَحْزِينٌ مِنَ الشَّيْطَانِ وَرُؤْيَا مِمَّا يُحَدِّثُ بِهِ الْمَرْءُ نَفْسَهُ فَإِذَا رَأَى أَحَدُكُمْ مَا يَكْرَهُ فَلْيَقُمْ فَلْيُصَلِّ وَلاَ يُحَدِّثْ بِهَا النَّاسَ ‏"‏ ‏.‏ قَالَ ‏"‏ وَأُحِبُّ الْقَيْدَ وَأَكْرَهُ الْغُلَّ وَالْقَيْدُ ثَبَاتٌ فِي الدِّينِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏"‏ إِذَا اقْتَرَبَ الزَّمَانُ ‏"‏ ‏.‏ يَعْنِي إِذَا اقْتَرَبَ اللَّيْلُ وَالنَّهَارُ يَعْنِي يَسْتَوِيَانِ ‏.‏\hadithno{5019}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7017) Sahih Muslim (2263)}\hadithtrans{Abu Hurairah reported the Prophet (May peace be upon him) as saying:When the time draws near, a believer’s vision can hardly be false. The truer one of them is in his speech, the truer he is in his vision. Visions are of three types: Good visions are glad tidings from Allah, a terrifying vision caused by the devil, and the ideas which come from within a man. So when one sees anything he dislikes, he should get up and pray, and should not tell it to the people. He said : I like a fetter and dislike a shackle on the neck; a fetter indicates being firmly established in religion. Abu Dawud said : “when the time draws near” means that when the day and night are equal}}
\hadithdefcmd{abudawud}{5020}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يَعْلَى بْنُ عَطَاءٍ، عَنْ وَكِيعِ بْنِ عُدُسٍ، عَنْ عَمِّهِ أَبِي رَزِينٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الرُّؤْيَا عَلَى رِجْلِ طَائِرٍ مَا لَمْ تُعَبَّرْ فَإِذَا عُبِّرَتْ وَقَعَتْ ‏"‏ ‏.‏ قَالَ وَأَحْسِبُهُ قَالَ ‏"‏ وَلاَ يَقُصُّهَا إِلاَّ عَلَى وَادٍّ أَوْ ذِي رَأْىٍ ‏"‏ ‏.‏\hadithno{5020}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuRazin: The Prophet (ﷺ) said: The vision flutters over a man as long as it is not interpreted , but when it is interpreted, it settles. And I think he said: Tell it only to one who loves (i.e. friend) or one who has judgment}}
\hadithdefcmd{abudawud}{5021}{حَدَّثَنَا النُّفَيْلِيُّ، قَالَ سَمِعْتُ زُهَيْرًا، يَقُولُ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ سَمِعْتُ أَبَا سَلَمَةَ، يَقُولُ سَمِعْتُ أَبَا قَتَادَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الرُّؤْيَا مِنَ اللَّهِ وَالْحُلْمُ مِنَ الشَّيْطَانِ فَإِذَا رَأَى أَحَدُكُمْ شَيْئًا يَكْرَهُهُ فَلْيَنْفُثْ عَنْ يَسَارِهِ ثَلاَثَ مَرَّاتٍ ثُمَّ لْيَتَعَوَّذْ مِنْ شَرِّهَا فَإِنَّهَا لاَ تَضُرُّهُ ‏"‏ ‏.‏\hadithno{5021}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6984) Sahih Muslim (2261)}\hadithtrans{Abu Qatadah said:I heard the Messenger of Allah (May peace be upon him) say: A good vision comes from Allah and a dream (hulm) from the devil, so when one of you sees what he dislikes, he must spit on his left (three times), and seek refuge in Allah from its evil. It will then not harm him}}
\hadithdefcmd{abudawud}{5022}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الْهَمْدَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، قَالاَ أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا رَأَى أَحَدُكُمُ الرُّؤْيَا يَكْرَهُهَا فَلْيَبْصُقْ عَنْ يَسَارِهِ وَلْيَتَعَوَّذْ بِاللَّهِ مِنَ الشَّيْطَانِ ثَلاَثًا وَيَتَحَوَّلْ عَنْ جَنْبِهِ الَّذِي كَانَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{5022}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2262)}\hadithtrans{Jabir reported the Messenger of Allah (May peace be upon him) as saying :When one of you sees a vision which he dislikes, he must spit on his left (three times), seek refuge in Allah from the devil three times, and turn from the side on which he was lying}}
\hadithdefcmd{abudawud}{5023}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ رَآنِي فِي الْمَنَامِ فَسَيَرَانِي فِي الْيَقَظَةِ ‏"‏ ‏.‏ أَوْ ‏"‏ لَكَأَنَّمَا رَآنِي فِي الْيَقَظَةِ وَلاَ يَتَمَثَّلُ الشَّيْطَانُ بِي ‏"‏ ‏.‏\hadithno{5023}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6993) Sahih Muslim (2266)}\hadithtrans{Abu Hurairah said :I heard the Messenger of Allah (May peace be upon him) say : He who sees me in a dream will see me when awake or as if he will see me when awake, for the devil does not take my likeness}}
\hadithdefcmd{abudawud}{5024}{حَدَّثَنَا مُسَدَّدٌ، وَسُلَيْمَانُ بْنُ دَاوُدَ، قَالاَ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَوَّرَ صُورَةً عَذَّبَهُ اللَّهُ بِهَا يَوْمَ الْقِيَامَةِ حَتَّى يَنْفُخَ فِيهَا وَلَيْسَ بِنَافِخٍ وَمَنْ تَحَلَّمَ كُلِّفَ أَنْ يَعْقِدَ شَعِيرَةً وَمَنِ اسْتَمَعَ إِلَى حَدِيثِ قَوْمٍ يَفِرُّونَ بِهِ مِنْهُ صُبَّ فِي أُذُنِهِ الآنُكُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5024}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7042)}\hadithtrans{Ibn ‘Abbas reported the Prophet (ﷺ) as saying :If anyone makes a representation of anything, Allah will punish him on the Day of Resurrection for it until he breathes into it, but he will be unable to do so. If anyone pretends to have had a dream which he did not see, he will be ordered to tie a knot in a grain of barley. If anyone listens to other people’s talk when they try to avoid him, lead will be poured into his ears on the Day of Resurrection}}
\hadithdefcmd{abudawud}{5025}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رَأَيْتُ اللَّيْلَةَ كَأَنَّا فِي دَارِ عُقْبَةَ بْنِ رَافِعٍ وَأُتِينَا بِرُطَبٍ مِنْ رُطَبِ ابْنِ طَابٍ فَأَوَّلْتُ أَنَّ الرِّفْعَةَ لَنَا فِي الدُّنْيَا وَالْعَاقِبَةَ فِي الآخِرَةِ وَأَنَّ دِينَنَا قَدْ طَابَ ‏"‏ ‏.‏\hadithno{5025}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2270)}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: One night it seemed to me in a dream that we were in the house of Uqbah ibn Rafi' and were brought some of the fresh dates of Ibn tab. I interpreted it as meaning that to us is granted eminence (rif'ah) in this world, a blessed hereafter ('aqibah), and that our religion has been good (tabah)}}
\hadithdefcmd{abudawud}{5026}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، عَنْ سُهَيْلٍ، عَنِ ابْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَثَاءَبَ أَحَدُكُمْ فَلْيُمْسِكْ عَلَى فِيهِ فَإِنَّ الشَّيْطَانَ يَدْخُلُ ‏"‏ ‏.‏\hadithno{5026}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2995)}\hadithtrans{Abu Sa’id al-Khudri reported the Messenger of Allah (May peace be upon him) as saying:When one of you yawns, he should hold his hand over his mouth, for the devil enters}}
\hadithdefcmd{abudawud}{5027}{حَدَّثَنَا ابْنُ الْعَلاَءِ، عَنْ وَكِيعٍ، عَنْ سُفْيَانَ، عَنْ سُهَيْلٍ، نَحْوَهُ قَالَ ‏ "‏ فِي الصَّلاَةِ فَلْيَكْظِمْ مَا اسْتَطَاعَ ‏"‏ ‏.‏\hadithno{5027}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2995)}\hadithtrans{The tradition mentioned above has also been transmitted in a similar way by Suhail through a different chain of narrators. This version has; “during prayer, so he should hold as far as possible”}}
\hadithdefcmd{abudawud}{5028}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يُحِبُّ الْعُطَاسَ وَيَكْرَهُ التَّثَاؤُبَ فَإِذَا تَثَاءَبَ أَحَدُكُمْ فَلْيَرُدَّهُ مَا اسْتَطَاعَ وَلاَ يَقُلْ هَاهْ هَاهْ فَإِنَّمَا ذَلِكُمْ مِنَ الشَّيْطَانِ يَضْحَكُ مِنْهُ ‏"‏ ‏.‏\hadithno{5028}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6226)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:Allah likes sneezing but dislikes yawning. So when one of you yawns, he should restrain it as much as possible, and should not say Ha, Ha, for that is from the devil who laughs at him}}
\hadithdefcmd{abudawud}{5029}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا عَطَسَ وَضَعَ يَدَهُ أَوْ ثَوْبَهُ عَلَى فِيهِ وَخَفَضَ أَوْ غَضَّ بِهَا صَوْتَهُ ‏.‏ شَكَّ يَحْيَى ‏.‏\hadithno{5029}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: When the Messenger of Allah (ﷺ) sneezed, he placed his hand or a garment on his mouth, and lessened the noise. The transmitter Yahya is doubtful about the exact words khafada or ghadda (lessened)}}
\hadithdefcmd{abudawud}{5030}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، وَخُشَيْشُ بْنُ أَصْرَمَ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ تَجِبُ لِلْمُسْلِمِ عَلَى أَخِيهِ رَدُّ السَّلاَمِ وَتَشْمِيتُ الْعَاطِسِ وَإِجَابَةُ الدَّعْوَةِ وَعِيَادَةُ الْمَرِيضِ وَاتِّبَاعُ الْجَنَازَةِ ‏"‏ ‏.‏\hadithno{5030}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2162)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:There are five qualities which a Muslim should display to his brother : return of salutation, response to the one who sneezes, acceptance of the invitation, paying sick visit to a patient, and accompanying the funeral}}
\hadithdefcmd{abudawud}{5031}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، قَالَ كُنَّا مَعَ سَالِمِ بْنِ عُبَيْدٍ فَعَطَسَ رَجُلٌ مِنَ الْقَوْمِ فَقَالَ السَّلاَمُ عَلَيْكُمْ ‏.‏ فَقَالَ سَالِمٌ وَعَلَيْكَ وَعَلَى أُمِّكَ ‏.‏ ثُمَّ قَالَ بَعْدُ لَعَلَّكَ وَجَدْتَ مِمَّا قُلْتُ لَكَ قَالَ لَوَدِدْتُ أَنَّكَ لَمْ تَذْكُرْ أُمِّي بِخَيْرٍ وَلاَ بِشَرٍّ قَالَ إِنَّمَا قُلْتُ لَكَ كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنَّا بَيْنَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ عَطَسَ رَجُلٌ مِنَ الْقَوْمِ فَقَالَ السَّلاَمُ عَلَيْكُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ وَعَلَى أُمِّكَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِذَا عَطَسَ أَحَدُكُمْ فَلْيَحْمَدِ اللَّهَ ‏"‏ ‏.‏ قَالَ فَذَكَرَ بَعْضَ الْمَحَامِدِ ‏"‏ وَلْيَقُلْ لَهُ مَنْ عِنْدَهُ يَرْحَمُكَ اللَّهُ وَلْيَرُدَّ - يَعْنِي عَلَيْهِمْ - يَغْفِرُ اللَّهُ لَنَا وَلَكُمْ ‏"‏ ‏.‏\hadithno{5031}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salim ibn Ubayd: Hilal ibn Yasar said: We were with Salim ibn Ubayd when a man from among the people sneezed and said: Peace be upon you. Salim said: And upon you and your mother. Later he said: Perhaps you found something (annoying) in what I said to you. He said: I wished you would not mention my mother with good or evil. He said: I have just said to you what the Messenger of Allah (ﷺ) said. We were in the presence of the Messenger of Allah (ﷺ) when a man from among the people sneezed, saying: Peace be upon you! The Messenger of Allah (ﷺ) said: And upon you and your mother. He then said: When one of you sneezes, he should praise Allah. He further mentioned some attributes (of Allah), saying: The one who is with him should say to him: Allah have mercy on you, and he should reply to them: Allah forgive us and you}}
\hadithdefcmd{abudawud}{5032}{حَدَّثَنَا تَمِيمُ بْنُ الْمُنْتَصِرِ، حَدَّثَنَا إِسْحَاقُ، - يَعْنِي ابْنَ يُوسُفَ - عَنْ أَبِي بِشْرٍ، وَرْقَاءَ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ خَالِدِ بْنِ عَرْفَجَةَ، عَنْ سَالِمِ بْنِ عُبَيْدٍ الأَشْجَعِيِّ، بِهَذَا الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{5032}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salim ibn Ubayd al-Ashja'i: The tradition mentioned above (No. 5013) has also been mentioned by Salim ibn Ubayd al-Ashja'i to the same effect from the Prophet (ﷺ) through a different chain of narrators}}
\hadithdefcmd{abudawud}{5033}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا عَطَسَ أَحَدُكُمْ فَلْيَقُلِ الْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ وَلْيَقُلْ أَخُوهُ أَوْ صَاحِبُهُ يَرْحَمُكَ اللَّهُ وَيَقُولُ هُوَ يَهْدِيكُمُ اللَّهُ وَيُصْلِحُ بَالَكُمْ ‏"‏ ‏.‏\hadithno{5033}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported the prophet (May peace be upon him) as saying:When one of you sneezes, he should say: "Praise be to Allah in every circumstance," and his brother or his companion should say: "May Allah have mercy on you!" And he should then reply: "May Allah guide you and set right your affairs}}
\hadithdefcmd{abudawud}{5034}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ شَمِّتْ أَخَاكَ ثَلاَثًا فَمَا زَادَ فَهُوَ زُكَامٌ ‏.‏\hadithno{5034}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: Respond three times to your brother when he sneezes, and if he sneezes more often, he has a cold in his head}}
\hadithdefcmd{abudawud}{5035}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَقَالَ لاَ أَعْلَمُهُ إِلاَّ أَنَّهُ رَفَعَ الْحَدِيثَ إِلَى النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَبُو نُعَيْمٍ عَنْ مُوسَى بْنِ قَيْسٍ عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{5035}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Hurairah through a different chain from the prophet (May peace be upon him). A transmitter Sa’id b. Sa’id said:I know him that he traced this tradition back to the prophet (May peace be upon him). Abu Dawud said: Abu Nu’aim transmitted it from Musa b. Qais, from Muhammad b. Ajlan, from Sa’id, on the authority of Abu Hurairah, from the prophet (May peace be upon him)}}
\hadithdefcmd{abudawud}{5036}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ يَزِيدَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ يَحْيَى بْنِ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أُمِّهِ، حُمَيْدَةَ أَوْ عُبَيْدَةَ بِنْتِ عُبَيْدِ بْنِ رِفَاعَةَ الزُّرَقِيِّ عَنْ أَبِيهَا، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُشَمِّتُ الْعَاطِسَ ثَلاَثًا فَإِنْ شِئْتَ أَنْ تُشَمِّتَهُ فَشَمِّتْهُ وَإِنْ شِئْتَ فَكُفَّ ‏"‏ ‏.‏\hadithno{5036}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ubayd ibn Rifa'ah az-Zuraqi: The Prophet (ﷺ) said: Invoke a blessing on one who sneezes three times; (and if he sneezes more often), then if you wish to invoke a blessing on him, you may invoke, and if you wish (to stop), then stop}}
\hadithdefcmd{abudawud}{5037}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، عَطَسَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ ‏"‏ يَرْحَمُكَ اللَّهُ ‏"‏ ‏.‏ ثُمَّ عَطَسَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الرَّجُلُ مَزْكُومٌ ‏"‏ ‏.‏\hadithno{5037}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2993)}\hadithtrans{Salamah b. al-Akwa said :when a man sneezed beside the prophet (May peace be upon him), he said to him : Allah have mercy on you, but when he sneezed again, he said : The man has a cold in the head}}
\hadithdefcmd{abudawud}{5038}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ حَكِيمِ بْنِ الدَّيْلَمِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَتِ الْيَهُودُ تَعَاطَسُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم رَجَاءَ أَنْ يَقُولَ لَهَا يَرْحَمُكُمُ اللَّهُ فَكَانَ يَقُولُ ‏ "‏ يَهْدِيكُمُ اللَّهُ وَيُصْلِحُ بَالَكُمْ ‏"‏ ‏.‏\hadithno{5038}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuBurdah: The Jews used to try to sneezes in the presence of the Prophet (ﷺ) hoping that he would say to them: "Allah have mercy on you!" but he would say: May Allah guide you and grant you well-being}}
\hadithdefcmd{abudawud}{5039}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، - الْمَعْنَى - قَالاَ حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَنَسٍ، قَالَ عَطَسَ رَجُلاَنِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَشَمَّتَ أَحَدَهُمَا وَتَرَكَ الآخَرَ قَالَ فَقِيلَ يَا رَسُولَ اللَّهِ رَجُلاَنِ عَطَسَا فَشَمَّتَّ أَحَدَهُمَا - قَالَ أَحْمَدُ أَوْ فَشَمَّتَّ أَحَدَهُمَا - وَتَرَكْتَ الآخَرَ ‏.‏ فَقَالَ ‏ "‏ إِنَّ هَذَا حَمِدَ اللَّهَ وَإِنَّ هَذَا لَمْ يَحْمَدِ اللَّهَ ‏"‏ ‏.‏\hadithno{5039}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6221) Sahih Muslim (2991)}\hadithtrans{Anas said:Two men sneezed in the presence of the prophet (May peace be upon him). He said : Allah have mercy on you! To one and not to the other. He was asked: Messenger of Allah! Two persons sneezed. Ahmad’s version has: You invoked a blessing on one of them and left the other. He replied : This man praised Allah, and this man did not praise Allah}}
\hadithdefcmd{abudawud}{5040}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَحَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ يَعِيشَ بْنِ طِخْفَةَ بْنِ قَيْسٍ الْغِفَارِيِّ، قَالَ كَانَ أَبِي مِنْ أَصْحَابِ الصُّفَّةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْطَلِقُوا بِنَا إِلَى بَيْتِ عَائِشَةَ ‏"‏ ‏.‏ فَانْطَلَقْنَا فَقَالَ ‏"‏ يَا عَائِشَةُ أَطْعِمِينَا ‏"‏ ‏.‏ فَجَاءَتْ بِحَشِيشَةٍ فَأَكَلْنَا ثُمَّ قَالَ ‏"‏ يَا عَائِشَةُ أَطْعِمِينَا ‏"‏ ‏.‏ فَجَاءَتْ بِحَيْسَةٍ مِثْلِ الْقَطَاةِ فَأَكَلْنَا ثُمَّ قَالَ ‏"‏ يَا عَائِشَةُ اسْقِينَا ‏"‏ ‏.‏ فَجَاءَتْ بِعُسٍّ مِنْ لَبَنٍ فَشَرِبْنَا ثُمَّ قَالَ ‏"‏ يَا عَائِشَةُ اسْقِينَا ‏"‏ ‏.‏ فَجَاءَتْ بِقَدَحٍ صَغِيرٍ فَشَرِبْنَا ثُمَّ قَالَ ‏"‏ إِنْ شِئْتُمْ بِتُّمْ وَإِنْ شِئْتُمُ انْطَلَقْتُمْ إِلَى الْمَسْجِدِ ‏"‏ ‏.‏ قَالَ فَبَيْنَمَا أَنَا مُضْطَجِعٌ فِي الْمَسْجِدِ مِنَ السَّحَرِ عَلَى بَطْنِي إِذَا رَجُلٌ يُحَرِّكُنِي بِرِجْلِهِ فَقَالَ ‏"‏ إِنَّ هَذِهِ ضِجْعَةٌ يُبْغِضُهَا اللَّهُ ‏"‏ ‏.‏ قَالَ فَنَظَرْتُ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5040}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Tikhfat al-Ghifari: Ya'ish ibn Tikhfat al-Ghifari said: My father was one of the people in the Suffah. The Messenger of Allah (ﷺ) said: Come with us to the house of Aisha. So we went and he said: Give us food, Aisha. She brought hashishah and we ate. He then said: Give us food, Aisha. She then brought haysah as small in quantity as a pigeon and we ate. He then said: Give us something to drink, Aisha. So she brought a bowl of milk, and we drank. Again he said: Give us something to drink, Aisha. She then brought a small cup and we drank. He then said: If you wish, you may spend the night (here), or if you wish, you may go to the mosque. He said: While I was lying on my stomach because of pain in the lung, a man began to shake me with his foot and then said: This is a method of lying which Allah hates. I looked and saw that he was the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{5041}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمٌ، - يَعْنِي ابْنَ نُوحٍ - عَنْ عُمَرَ بْنِ جَابِرٍ الْحَنَفِيِّ، عَنْ وَعْلَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ وَثَّابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَلِيٍّ، - يَعْنِي ابْنَ شَيْبَانَ - عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَاتَ عَلَى ظَهْرِ بَيْتٍ لَيْسَ لَهُ حِجَارٌ فَقَدْ بَرِئَتْ مِنْهُ الذِّمَّةُ ‏"‏ ‏.‏\hadithno{5041}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn Shayban: The Prophet (ﷺ) said: If anyone spends the night on the roof of a house with no stone palisade, Allah's responsibility to guard him no longer applies}}
\hadithdefcmd{abudawud}{5042}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَاصِمُ بْنُ بَهْدَلَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي ظَبْيَةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مُسْلِمٍ يَبِيتُ عَلَى ذِكْرٍ طَاهِرًا فَيَتَعَارُّ مِنَ اللَّيْلِ فَيَسْأَلُ اللَّهَ خَيْرًا مِنَ الدُّنْيَا وَالآخِرَةِ إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ قَالَ ثَابِتٌ الْبُنَانِيُّ قَدِمَ عَلَيْنَا أَبُو ظَبْيَةَ فَحَدَّثَنَا بِهَذَا الْحَدِيثِ عَنْ مُعَاذِ بْنِ جَبَلٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ثَابِتٌ قَالَ فُلاَنٌ لَقَدْ جَهَدْتُ أَنْ أَقُولَهَا حِينَ أَنْبَعِثُ فَمَا قَدَرْتُ عَلَيْهَا ‏.‏\hadithno{5042}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Mu'adh ibn Jabal: The Prophet (ﷺ) said: If a Muslim sleeps while remembering Allah, in the state of purification, is alarmed while asleep at night, and asks Allah for good in this world and in the Hereafter. He surely gives it to him. Thabit al-Bunani said: AbuZabyah came to visit us and he transmitted this tradition to us from Mu'adh ibn Jabal from the Prophet (ﷺ). Thabit said: So and so said: I tried my best to utter these (prayers) when I got up, but I could not do}}
\hadithdefcmd{abudawud}{5043}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ مِنَ اللَّيْلِ فَقَضَى حَاجَتَهُ فَغَسَلَ وَجْهَهُ وَيَدَيْهِ ثُمَّ نَامَ ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي بَالَ ‏.‏\hadithno{5043}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6316) Sahih Muslim (763)}\hadithtrans{Ibn ‘Abbas said:The Messenger of Allah (May peace be upon him) got up at night, fulfilled his need and washed his face and hand and then slept. Abu Dawud said: that is to say, he urinated}}
\hadithdefcmd{abudawud}{5044}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ بَعْضِ، آلِ أُمِّ سَلَمَةَ قَالَ كَانَ فِرَاشُ النَّبِيِّ صلى الله عليه وسلم نَحْوًا مِمَّا يُوضَعُ الإِنْسَانُ فِي قَبْرِهِ وَكَانَ الْمَسْجِدُ عِنْدَ رَأْسِهِ ‏.‏\hadithno{5044}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Some relative of Umm Salamah said: The bed of the Prophet (ﷺ) was set as a man is laid in his grave; the mosque was towards his head}}
\hadithdefcmd{abudawud}{5045}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا عَاصِمٌ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، عَنْ سَوَاءٍ، عَنْ حَفْصَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَرْقُدَ وَضَعَ يَدَهُ الْيُمْنَى تَحْتَ خَدِّهِ ثُمَّ يَقُولُ ‏ "‏ اللَّهُمَّ قِنِي عَذَابَكَ يَوْمَ تَبْعَثُ عِبَادَكَ ‏"‏ ‏.‏ ثَلاَثَ مِرَارٍ ‏.‏\hadithno{5045}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hafsah, Ummul Mu'minin: When the Messenger of Allah (ﷺ) wanted to go to sleep, he put his right hand under his cheek and would then say three times: O Allah, guard me from Thy punishment on the day when Thou raisest up Thy servants}}
\hadithdefcmd{abudawud}{5046}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ مَنْصُورًا، يُحَدِّثُ عَنْ سَعْدِ بْنِ عُبَيْدَةَ، قَالَ حَدَّثَنِي الْبَرَاءُ بْنُ عَازِبٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَتَيْتَ مَضْجَعَكَ فَتَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ ثُمَّ اضْطَجِعْ عَلَى شِقِّكَ الأَيْمَنِ وَقُلِ اللَّهُمَّ أَسْلَمْتُ وَجْهِي إِلَيْكَ وَفَوَّضْتُ أَمْرِي إِلَيْكَ وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ رَهْبَةً وَرَغْبَةً إِلَيْكَ لاَ مَلْجَأَ وَلاَ مَنْجَى مِنْكَ إِلاَّ إِلَيْكَ آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏"‏ ‏.‏ قَالَ ‏"‏ فَإِنْ مِتَّ مِتَّ عَلَى الْفِطْرَةِ وَاجْعَلْهُنَّ آخِرَ مَا تَقُولُ ‏"‏ ‏.‏ قَالَ الْبَرَاءُ فَقُلْتُ أَسْتَذْكِرُهُنَّ فَقُلْتُ وَبِرَسُولِكَ الَّذِي أَرْسَلْتَ ‏.‏ قَالَ ‏"‏ لاَ وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏"‏ ‏.‏\hadithno{5046}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6311) Sahih Muslim (2710)}\hadithtrans{Al-Bara b. ‘Azib said :The Messenger of Allah (May peace be upon him) said to me: When you go to your bed, perform ablution like the ablution for prayer, and then lie on your right side and say: O Allah I have handed over my face to thee, entrusted my affairs to thee, and committed my back to thee out of desire for and fear to thee. There is no refuge and no place of safety from thee except by having recource to thee. I believe in Thy Book which Thou hast sent down and in Thy prophet whom thou hast sent down. He said : If you die (that night), you would die in the true religion, and utter these words in the last of that you utter (other prayers). Al-Bara said : I said: I memorise them, and then I repeated, saying “and in Thy Apostle whom Thou hast sent”. He said : No, say : “and in Thy Prophet whom Thou hast sent}}
\hadithdefcmd{abudawud}{5047}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ فِطْرِ بْنِ خَلِيفَةَ، قَالَ سَمِعْتُ سَعْدَ بْنَ عُبَيْدَةَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَوَيْتَ إِلَى فِرَاشِكَ وَأَنْتَ طَاهِرٌ فَتَوَسَّدْ يَمِينَكَ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ نَحْوَهُ ‏.‏\hadithno{5047}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Bara b. Azib said :The Messenger of Allah (May peace be upon him) said to me: when you go to bed while you are in the state of purification, lay your head on your right hand. He then mentioned the rest of the tradition in a similar manner as above}}
\hadithdefcmd{abudawud}{5048}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الْغَزَّالُ، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، وَمَنْصُورٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا قَالَ سُفْيَانُ قَالَ أَحَدُهُمَا ‏"‏ إِذَا أَتَيْتَ فِرَاشَكَ طَاهِرًا ‏"‏ ‏.‏ وَقَالَ الآخَرُ ‏"‏ تَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ ‏"‏ ‏.‏ وَسَاقَ مَعْنَى مُعْتَمِرٍ ‏.‏\hadithno{5048}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by al-Bara b. Azil from the prophet (May peace be upon him) to the same effect through a different chain of narrators. One transmitter said:when you go to your bed while you are in the state of purification. The other said: Perform ablution like the ablution for prayer. He then transmitted the tradition to the effect as Mu’tamir transmitted}}
\hadithdefcmd{abudawud}{5049}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا نَامَ قَالَ ‏"‏ اللَّهُمَّ بِاسْمِكَ أَحْيَا وَأَمُوتُ ‏"‏ ‏.‏ وَإِذَا اسْتَيْقَظَ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا وَإِلَيْهِ النُّشُورُ ‏"‏ ‏.‏\hadithno{5049}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6312)}\hadithtrans{Hudhaifah said :when the prophet (May peace be upon him) lay down on his bed (at night), he would say: O Allah! In Thy name I die and live. When he awoke, he said: praise be to Allah who has given us life after causing us to die and to whom we shall be resurrected}}
\hadithdefcmd{abudawud}{5050}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَوَى أَحَدُكُمْ إِلَى فِرَاشِهِ فَلْيَنْفُضْ فِرَاشَهُ بِدَاخِلَةِ إِزَارِهِ فَإِنَّهُ لاَ يَدْرِي مَا خَلَفَهُ عَلَيْهِ ثُمَّ لْيَضْطَجِعْ عَلَى شِقِّهِ الأَيْمَنِ ثُمَّ لْيَقُلْ بِاسْمِكَ رَبِّي وَضَعْتُ جَنْبِي وَبِكَ أَرْفَعُهُ إِنْ أَمْسَكْتَ نَفْسِي فَارْحَمْهَا وَإِنْ أَرْسَلْتَهَا فَاحْفَظْهَا بِمَا تَحْفَظُ بِهِ عِبَادَكَ الصَّالِحِينَ ‏"‏ ‏.‏\hadithno{5050}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6320) Sahih Muslim (2714)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:when any of you goes to his bed, he should dust his bedding with the inner extremity of his lower garment, for he does not know what has come on it since he left it. He should then lie down on his right side and say: In Thy name, my mercy on it, but if Thou lettest it go, guard it with that which Thou guardest Thy upright servants}}
\hadithdefcmd{abudawud}{5051}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، ح وَحَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، نَحْوَهُ عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ إِذَا أَوَى إِلَى فِرَاشِهِ ‏"‏ اللَّهُمَّ رَبَّ السَّمَوَاتِ وَرَبَّ الأَرْضِ وَرَبَّ كُلِّ شَىْءٍ فَالِقَ الْحَبِّ وَالنَّوَى مُنَزِّلَ التَّوْرَاةِ وَالإِنْجِيلِ وَالْقُرْآنِ أَعُوذُ بِكَ مِنْ شَرِّ كُلِّ ذِي شَرٍّ أَنْتَ آخِذٌ بِنَاصِيَتِهِ أَنْتَ الأَوَّلُ فَلَيْسَ قَبْلَكَ شَىْءٌ وَأَنْتَ الآخِرُ فَلَيْسَ بَعْدَكَ شَىْءٌ وَأَنْتَ الظَّاهِرُ فَلَيْسَ فَوْقَكَ شَىْءٌ وَأَنْتَ الْبَاطِنُ فَلَيْسَ دُونَكَ شَىْءٌ ‏"‏ ‏.‏ زَادَ وَهْبٌ فِي حَدِيثِهِ ‏"‏ اقْضِ عَنِّي الدَّيْنَ وَأَغْنِنِي مِنَ الْفَقْرِ ‏"‏ ‏.‏\hadithno{5051}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2713)}\hadithtrans{Abu Hurairah said:when the prophet (May peace be upon him) went to his bed, he used to say : O Allah! Lord of the heavens, Lord of the earth, Lord of everything, who splittest the grain and the kernel, who hast sent down the Torah, forelock Thou seizes. Thou art the first and there is nothing before thee; Thou art the Last and there is nothing after Thee; Thou art the Outward and there is nothing above Thee; Thou art the Inward and there is nothing below Thee. Wahb added in his version : pay the debt for me and grant me riches instead of poverty}}
\hadithdefcmd{abudawud}{5052}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا الأَحْوَصُ، - يَعْنِي ابْنَ جَوَّابٍ - حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، وَأَبِي، مَيْسَرَةَ عَنْ عَلِيٍّ، رَحِمَهُ اللَّهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ عِنْدَ مَضْجَعِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِوَجْهِكَ الْكَرِيمِ وَكَلِمَاتِكَ التَّامَّةِ مِنْ شَرِّ مَا أَنْتَ آخِذٌ بِنَاصِيَتِهِ اللَّهُمَّ أَنْتَ تَكْشِفُ الْمَغْرَمَ وَالْمَأْثَمَ اللَّهُمَّ لاَ يُهْزَمُ جُنْدُكَ وَلاَ يُخْلَفُ وَعْدُكَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ سُبْحَانَكَ وَبِحَمْدِكَ ‏"‏ ‏.‏\hadithno{5052}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) used to say when he lay down: O Allah, I seek refuge in Thy noble Person and in Thy perfect Words from the evil of what Thou seizest by its forelock; O Allah! Thou removest debt and sin; O Allah! thy troop's not routed, Thy promise is not broken and the riches of the rich do not avail against Thee. Glory and praise be unto Thee}}
\hadithdefcmd{abudawud}{5053}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَوَى إِلَى فِرَاشِهِ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنَا وَسَقَانَا وَكَفَانَا وَآوَانَا فَكَمْ مِمَّنْ لاَ كَافِيَ لَهُ وَلاَ مُئْوِيَ ‏"‏ ‏.‏\hadithno{5053}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2715)}\hadithtrans{Anas said:When the Messenger of Allah (May peace be upon him) went to his bed, he would say: Praise be to Allah who has fed us, given us drink, satisfied us and given us refuge. Many there are who have no one to provide sufficiency for them, or give them refuge}}
\hadithdefcmd{abudawud}{5054}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ التِّنِّيسِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ ثَوْرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي الأَزْهَرِ الأَنْمَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَخَذَ مَضْجَعَهُ مِنَ اللَّيْلِ قَالَ ‏ "‏ بِسْمِ اللَّهِ وَضَعْتُ جَنْبِي اللَّهُمَّ اغْفِرْ لِي ذَنْبِي وَأَخْسِئْ شَيْطَانِي وَفُكَّ رِهَانِي وَاجْعَلْنِي فِي النَّدِيِّ الأَعْلَى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَبُو هَمَّامٍ الأَهْوَازِيُّ عَنْ ثَوْرٍ قَالَ أَبُو زُهَيْرٍ الأَنْمَارِيُّ ‏.‏\hadithno{5054}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbulAzhar al-Anmari: When the Messenger of Allah (ﷺ) went to his bed at night, he would say: in the name of Allah, I have laid down my side for Allah. O Allah! forgive me my sin, drive away my devil, free me from my responsibility, and place me in the highest assembly. Abu Dawud said: Abu Hammam al-Ahwazi transmitted it from Thawr. He mentioned Abu Zuhair al-Anmari (instead of Abu al-Azhar)}}
\hadithdefcmd{abudawud}{5055}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِنَوْفَلٍ ‏"‏ اقْرَأْ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏\}‏ ثُمَّ نَمْ عَلَى خَاتِمَتِهَا فَإِنَّهَا بَرَاءَةٌ مِنَ الشِّرْكِ ‏"‏ ‏.‏\hadithno{5055}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Farwah b. Nawfal quoted his father as saying that the Prophet (ﷺ) said to Nawfal (his father):Recite (the Surah) 'Say, O you disbelievers!' and then go to sleep at its end, for it is a declaration of freedom from polytheism}}
\hadithdefcmd{abudawud}{5056}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، قَالاَ حَدَّثَنَا الْمُفَضَّلُ، - يَعْنِيَانِ ابْنَ فَضَالَةَ - عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَوَى إِلَى فِرَاشِهِ كُلَّ لَيْلَةٍ جَمَعَ كَفَّيْهِ ثُمَّ نَفَثَ فِيهِمَا وَقَرَأَ فِيهِمَا ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ ثُمَّ يَمْسَحُ بِهِمَا مَا اسْتَطَاعَ مِنْ جَسَدِهِ يَبْدَأُ بِهِمَا عَلَى رَأْسِهِ وَوَجْهِهِ وَمَا أَقْبَلَ مِنْ جَسَدِهِ يَفْعَلُ ذَلِكَ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{5056}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5017)}\hadithtrans{‘A’ishah said :Every night when he prophet (May peace be upon him) went to his bed, he joined his hands and breathed into them, reciting into them:”say: he is Allah, One” and say ; I seek refuge in the Lord of the dawn and Say: I seek refuge in the Lord of men. Then he would wipe as much of his body as he could with his hands, beginning with his head, his face and the front of his body, doing that three times}}
\hadithdefcmd{abudawud}{5057}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَّرَّانِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ ابْنِ أَبِي بِلاَلٍ، عَنْ عِرْبَاضِ بْنِ سَارِيَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ الْمُسَبِّحَاتِ قَبْلَ أَنْ يَرْقُدَ وَقَالَ ‏ "‏ إِنَّ فِيهِنَّ آيَةً أَفْضَلُ مِنْ أَلْفِ آيَةٍ ‏"‏ ‏.‏\hadithno{5057}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Irbad ibn Sariyah: The Messenger of Allah (ﷺ) used to recite al-Musabbihat before going to sleep, and say: They contain a verse which is better than a thousand verses}}
\hadithdefcmd{abudawud}{5058}{حَدَّثَنَا عَلِيُّ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنَا حُسَيْنٌ، عَنِ ابْنِ بُرَيْدَةَ، عَنِ ابْنِ عُمَرَ، أَنَّهُ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ إِذَا أَخَذَ مَضْجَعَهُ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي كَفَانِي وَآوَانِي وَأَطْعَمَنِي وَسَقَانِي وَالَّذِي مَنَّ عَلَىَّ فَأَفْضَلَ وَالَّذِي أَعْطَانِي فَأَجْزَلَ الْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ اللَّهُمَّ رَبَّ كُلِّ شَىْءٍ وَمَلِيكَهُ وَإِلَهَ كُلِّ شَىْءٍ أَعُوذُ بِكَ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{5058}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: When the Messenger of Allah (ﷺ) went to his bed, he would say: Praise be to Allah Who has given me sufficiency, has guarded me, given me food and drink, been most gracious to me, and given to me most lavishly. Praise be to Allah in every circumstance. O Allah! Lord and King of everything, God of everything, I seek refuge in Thee from Hell}}
\hadithdefcmd{abudawud}{5059}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اضْطَجَعَ مَضْجَعًا لَمْ يَذْكُرِ اللَّهَ تَعَالَى فِيهِ إِلاَّ كَانَ عَلَيْهِ تِرَةً يَوْمَ الْقِيَامَةِ وَمَنْ قَعَدَ مَقْعَدًا لَمْ يَذْكُرِ اللَّهَ عَزَّ وَجَلَّ فِيهِ إِلاَّ كَانَ عَلَيْهِ تِرَةً يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5059}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone lies on his side where he does not remember Allah, deprivation will descend on him on the Day of Resurrection; and if anyone sits in a place where he does not remember Allah, deprivation will descend on him on the Day of Resurrection}}
\hadithdefcmd{abudawud}{5060}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ، قَالَ قَالَ الأَوْزَاعِيُّ حَدَّثَنِي عُمَيْرُ بْنُ هَانِئٍ، قَالَ حَدَّثَنِي جُنَادَةُ بْنُ أَبِي أُمَيَّةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ تَعَارَّ مِنَ اللَّيْلِ فَقَالَ حِينَ يَسْتَيْقِظُ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ثُمَّ دَعَا رَبِّ اغْفِرْ لِي ‏"‏ ‏.‏ قَالَ الْوَلِيدُ أَوْ قَالَ ‏"‏ دَعَا اسْتُجِيبَ لَهُ فَإِنْ قَامَ فَتَوَضَّأَ ثُمَّ صَلَّى قُبِلَتْ صَلاَتُهُ ‏"‏ ‏.‏\hadithno{5060}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1154)}\hadithtrans{‘Ubadah b. al-Samit reported the Messenger of Allah (May peace be upon him) as saying; If anyone is alarmed while asleep and he says when awakes :there is no god but Allah alone Who has no partner, to whom dominion belongs, to whom praise is due, and who has power over everything (omnipotent). Glory be to Allah, and praise be to Allah, and there is no god but Allah, and then he prays: O my Lord, forgive me. Abu Dawud said : Al-Walid’s version has; and he prays, his prayer will be answered. If he gets up, performs ablution, and prays, his prayer will be accepted}}
\hadithdefcmd{abudawud}{5061}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ، حَدَّثَنَا سَعِيدٌ، - يَعْنِي ابْنَ أَبِي أَيُّوبَ - قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ الْوَلِيدِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اسْتَيْقَظَ مِنَ اللَّيْلِ قَالَ ‏ "‏ لاَ إِلَهَ إِلاَّ أَنْتَ سُبْحَانَكَ اللَّهُمَّ أَسْتَغْفِرُكَ لِذَنْبِي وَأَسْأَلُكَ رَحْمَتَكَ اللَّهُمَّ زِدْنِي عِلْمًا وَلاَ تُزِغْ قَلْبِي بَعْدَ إِذْ هَدَيْتَنِي وَهَبْ لِي مِنْ لَدُنْكَ رَحْمَةً إِنَّكَ أَنْتَ الْوَهَّابُ ‏"‏ ‏.‏\hadithno{5061}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When the Messenger of Allah (ﷺ) awake at night, he said: There is no god but thou, glory be to Thee, O Allah, I ask Thy pardon for my sin and I ask Thee for Thy mercy. O Allah! advance me in knowledge: do not cause my heart to deviate (from guidance) after Thou hast guided me, and grant me mercy from thyself; verily thou art the grantor}}
\hadithdefcmd{abudawud}{5062}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، - الْمَعْنَى - عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، - قَالَ مُسَدَّدٌ - قَالَ حَدَّثَنَا عَلِيٌّ، قَالَ شَكَتْ فَاطِمَةُ إِلَى النَّبِيِّ صلى الله عليه وسلم مَا تَلْقَى فِي يَدِهَا مِنَ الرَّحَى فَأُتِيَ بِسَبْىٍ فَأَتَتْهُ تَسْأَلُهُ فَلَمْ تَرَهُ فَأَخْبَرَتْ بِذَلِكَ عَائِشَةَ فَلَمَّا جَاءَ النَّبِيُّ صلى الله عليه وسلم أَخْبَرَتْهُ فَأَتَانَا وَقَدْ أَخَذْنَا مَضَاجِعَنَا فَذَهَبْنَا لِنَقُومَ فَقَالَ ‏"‏ عَلَى مَكَانِكُمَا ‏"‏ ‏.‏ فَجَاءَ فَقَعَدَ بَيْنَنَا حَتَّى وَجَدْتُ بَرْدَ قَدَمَيْهِ عَلَى صَدْرِي فَقَالَ ‏"‏ أَلاَ أَدُلُّكُمَا عَلَى خَيْرٍ مِمَّا سَأَلْتُمَا إِذَا أَخَذْتُمَا مَضَاجِعَكُمَا فَسَبِّحَا ثَلاَثًا وَثَلاَثِينَ وَاحْمَدَا ثَلاَثًا وَثَلاَثِينَ وَكَبِّرَا أَرْبَعًا وَثَلاَثِينَ فَهُوَ خَيْرٌ لَكُمَا مِنْ خَادِمٍ ‏"‏ ‏.‏\hadithno{5062}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5361) Sahih Muslim (2727)}\hadithtrans{Ali said :Fatimah complained to the Prophet (May peace be upon him) of the effect of the grinding stone on her hand. Then some slaves (prisoners of war) were brought to him. So she went to him to ask for (one of) them, but she did not find him. She mentioned the matter to ‘A’ishah. When the prophet (May peace be upon him) came, she informed him. He (the prophet) visited us (Ali) when we had gone to bed, and when we were about to get up, he said: stay where you are. He then came and sat down between us (her and me), and I felt the coldness of his feet on my chest. He then said; “Let me guide to something better than what you have asked. When you go bed, say: Glory be to Allah” thirty-three times.”Praise be to Allah” thirty-three times, and “ Allah is most Great” thirty-four times. That will be better for you than a servant}}
\hadithdefcmd{abudawud}{5063}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ الْيَشْكُرِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الْوَرْدِ بْنِ ثُمَامَةَ، قَالَ قَالَ عَلِيٌّ لاِبْنِ أَعْبَدَ أَلاَ أُحَدِّثُكَ عَنِّي وَعَنْ فَاطِمَةَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَتْ أَحَبَّ أَهْلِهِ إِلَيْهِ وَكَانَتْ عِنْدِي فَجَرَّتْ بِالرَّحَى حَتَّى أَثَّرَتْ بِيَدِهَا وَاسْتَقَتْ بِالْقِرْبَةِ حَتَّى أَثَّرَتْ فِي نَحْرِهَا وَقَمَّتِ الْبَيْتَ حَتَّى اغْبَرَّتْ ثِيَابُهَا وَأَوْقَدَتِ الْقِدْرَ حَتَّى دَكِنَتْ ثِيَابُهَا وَأَصَابَهَا مِنْ ذَلِكَ ضُرٌّ فَسَمِعْنَا أَنَّ رَقِيقًا أُتِيَ بِهِمْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ لَوْ أَتَيْتِ أَبَاكِ فَسَأَلْتِيهِ خَادِمًا يَكْفِيكِ ‏.‏ فَأَتَتْهُ فَوَجَدَتْ عِنْدَهُ حُدَّاثًا فَاسْتَحْيَتْ فَرَجَعَتْ فَغَدَا عَلَيْنَا وَنَحْنُ فِي لِفَاعِنَا فَجَلَسَ عِنْدَ رَأْسِهَا فَأَدْخَلَتْ رَأْسَهَا فِي اللِّفَاعِ حَيَاءً مِنْ أَبِيهَا فَقَالَ ‏ "‏ مَا كَانَ حَاجَتُكِ أَمْسِ إِلَى آلِ مُحَمَّدٍ ‏"‏ ‏.‏ فَسَكَتَتْ مَرَّتَيْنِ فَقُلْتُ أَنَا وَاللَّهِ أُحَدِّثُكَ يَا رَسُولَ اللَّهِ إِنَّ هَذِهِ جَرَّتْ عِنْدِي بِالرَّحَى حَتَّى أَثَّرَتْ فِي يَدِهَا وَاسْتَقَتْ بِالْقِرْبَةِ حَتَّى أَثَّرَتْ فِي نَحْرِهَا وَكَسَحَتِ الْبَيْتَ حَتَّى اغْبَرَّتْ ثِيَابُهَا وَأَوْقَدَتِ الْقِدْرَ حَتَّى دَكِنَتْ ثِيَابُهَا وَبَلَغَنَا أَنَّهُ قَدْ أَتَاكَ رَقِيقٌ أَوْ خَدَمٌ فَقُلْتُ لَهَا سَلِيهِ خَادِمًا ‏.‏ فَذَكَرَ مَعْنَى حَدِيثِ الْحَكَمِ وَأَتَمَّ ‏.‏\hadithno{5063}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Ali said to Ibn A’bad :should I not tell you about me and about Fatimah, daughter of the Messenger of Allah (May peace be upon him). She was dearest to him of his family. When she was with me, she pulled mill-stone which affected her hand; she carried water with the water-bag which affected the upper portion of her chest: She swept the house so much so that her clothes became dusty; and she cooked food by which her clothes became black, and it harmed her. We heard that some slaves had been brought to the prophet (May peace be upon him). I said: if you go to your father and ask him for a servant, that will be sufficient for you. She came to him and found some people talking to him. She felt shy and returned. Next morning he visited us when we were in our quilt. He sat beside her head, and she took her head into the quilt out of shame from her father. He asked: What need had you with me, O family of Muhammad? She kept silence twice. I then said : I swear by Allah, I shall tell you. She pulls the mile-stone which has affected her hand; she carrys water with the water-bag which has affected the upper portion of her chest; she sweeps the house by which her clothes have become dusty, and she cooks food by which her clothes have become black. We were told that some slaves or servants had come to you. So I said to her; ask him for a servant. He then mentioned the rest of the tradition to the same effect as mentioned by al-Hakam rather more perfectly}}
\hadithdefcmd{abudawud}{5064}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، عَنْ شَبَثِ بْنِ رِبْعِيٍّ، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْخَبَرِ قَالَ فِيهِ قَالَ عَلِيٌّ فَمَا تَرَكْتُهُنَّ مُنْذُ سَمِعْتُهُنَّ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ لَيْلَةَ صِفِّينَ فَإِنِّي ذَكَرْتُهَا مِنْ آخِرِ اللَّيْلِ فَقُلْتُهَا ‏.‏\hadithno{5064}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The tradition (No 5045, about Tasbih Fatimah) has been transmitted by Ali to the same effect through a different chain of narrators. This version adds: Ali said: I did not leave them (Tasbih Fatimah) since I heard them from the Messenger of Allah (ﷺ) except on the night of Siffin, for I remembered them towards the end of the night and then I uttered them}}
\hadithdefcmd{abudawud}{5065}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ خَصْلَتَانِ أَوْ خَلَّتَانِ لاَ يُحَافِظُ عَلَيْهِمَا عَبْدٌ مُسْلِمٌ إِلاَّ دَخَلَ الْجَنَّةَ هُمَا يَسِيرٌ وَمَنْ يَعْمَلُ بِهِمَا قَلِيلٌ يُسَبِّحُ فِي دُبُرِ كُلِّ صَلاَةٍ عَشْرًا وَيَحْمَدُ عَشْرًا وَيُكَبِّرُ عَشْرًا فَذَلِكَ خَمْسُونَ وَمِائَةٌ بِاللِّسَانِ وَأَلْفٌ وَخَمْسُمِائَةٍ فِي الْمِيزَانِ وَيُكَبِّرُ أَرْبَعًا وَثَلاَثِينَ إِذَا أَخَذَ مَضْجَعَهُ وَيَحْمَدُ ثَلاَثًا وَثَلاَثِينَ وَيُسَبِّحُ ثَلاَثًا وَثَلاَثِينَ فَذَلِكَ مِائَةٌ بِاللِّسَانِ وَأَلْفٌ فِي الْمِيزَانِ ‏"‏ ‏.‏ فَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَعْقِدُهَا بِيَدِهِ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ هُمَا يَسِيرٌ وَمَنْ يَعْمَلُ بِهِمَا قَلِيلٌ قَالَ ‏"‏ يَأْتِي أَحَدَكُمْ - يَعْنِي الشَّيْطَانَ - فِي مَنَامِهِ فَيُنَوِّمُهُ قَبْلَ أَنْ يَقُولَهُ وَيَأْتِيهِ فِي صَلاَتِهِ فَيُذَكِّرُهُ حَاجَةً قَبْلَ أَنْ يَقُولَهَا ‏"‏ ‏.‏\hadithno{5065}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr: The Prophet (ﷺ) said: There are two qualities or characteristics which will not be returned by any Muslim without his entering Paradise. While they are easy, those who act upon them are few. One should say: "Glory be to Allah" ten times after every prayer, "Praise be to Allah" ten times and "Allah is Most Great" ten times. That is a hundred and fifty on the tongue, but one thousand and five hundred on the scale. When he goes to bed, he should say: "Allah is Most Great" thirty-four times, "Praise be to Allah" thirty-three times, and Glory be to Allah thirty-three times, for that is a hundred on the tongue and a thousand on the scale. (He said:) I saw the Messenger of Allah (ﷺ) counting them on his hand. The people asked: Messenger of Allah! How is it that while they are easy, those who act upon them are few? He replied: The Devil comes to one of you when he goes to bed and he makes him sleep, before he utters them, and he comes to him while he is engaged in prayer and calls a need to his mind before he utters them}}
\hadithdefcmd{abudawud}{5066}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ حَدَّثَنِي عَيَّاشُ بْنُ عُقْبَةَ الْحَضْرَمِيُّ، عَنِ الْفَضْلِ بْنِ حَسَنٍ الضَّمْرِيِّ، أَنَّ ابْنَ أُمِّ الْحَكَمِ، أَوْ ضُبَاعَةَ ابْنَتَىِ الزُّبَيْرِ حَدَّثَهُ عَنْ إِحْدَاهُمَا، أَنَّهَا قَالَتْ أَصَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَبْيًا فَذَهَبْتُ أَنَا وَأُخْتِي وَفَاطِمَةُ بِنْتُ النَّبِيِّ صلى الله عليه وسلم إِلَى النَّبِيِّ صلى الله عليه وسلم فَشَكَوْنَا إِلَيْهِ مَا نَحْنُ فِيهِ وَسَأَلْنَاهُ أَنْ يَأْمُرَ لَنَا بِشَىْءٍ مِنَ السَّبْىِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَبَقَكُنَّ يَتَامَى بَدْرٍ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ قِصَّةَ التَّسْبِيحِ قَالَ عَلَى أَثَرِ كُلِّ صَلاَةٍ لَمْ يَذْكُرِ النَّوْمَ ‏.‏\hadithno{5066}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Umm al-Hakam or Duba’ah, daughter of al-Zubair, said :The Messenger of Allah (May peace be upon him) got some prisoners of war (slaves). I my sister and Fatimah, daughter of the prophet (May peace be upon him), went to the prophet (May peace be upon him). We complained to him about our condition, and asked him to command for giving us some prisoners (slaves). The Messenger of Allah (May peace be upon him) said; The orphans of Badr came before you (and took the slaves). The transmitter then mentioned the story of glorifying Allah after every prayer. He did not mention sleeping}}
\hadithdefcmd{abudawud}{5067}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا هُشَيْمٌ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ عَمْرِو بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ، رضى الله عنه قَالَ يَا رَسُولَ اللَّهِ مُرْنِي بِكَلِمَاتٍ أَقُولُهُنَّ إِذَا أَصْبَحْتُ وَإِذَا أَمْسَيْتُ ‏.‏ قَالَ ‏"‏ قُلِ اللَّهُمَّ فَاطِرَ السَّمَوَاتِ وَالأَرْضِ عَالِمَ الْغَيْبِ وَالشَّهَادَةِ رَبَّ كُلِّ شَىْءٍ وَمَلِيكَهُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ أَنْتَ أَعُوذُ بِكَ مِنْ شَرِّ نَفْسِي وَشَرِّ الشَّيْطَانِ وَشِرْكِهِ ‏"‏ ‏.‏ قَالَ ‏"‏ قُلْهَا إِذَا أَصْبَحْتَ وَإِذَا أَمْسَيْتَ وَإِذَا أَخَذْتَ مَضْجَعَكَ ‏"‏ ‏.‏\hadithno{5067}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: AbuBakr as-Siddiq said: Messenger of Allah! command me something to say in the morning and in the evening. He said: Say "O Allah, Creator of the heavens and the earth, Who knowest the unseen and the seen, Lord and Possessor of everything. I testify that there is no god but Thee; I seek refuge in Thee from the evil within myself, from the evil of the devil, and his (incitement to) attributing partners (to Allah)." He said: Say this in the morning}}
\hadithdefcmd{abudawud}{5068}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ إِذَا أَصْبَحَ ‏"‏ اللَّهُمَّ بِكَ أَصْبَحْنَا وَبِكَ أَمْسَيْنَا وَبِكَ نَحْيَا وَبِكَ نَمُوتُ وَإِلَيْكَ النُّشُورُ ‏"‏ ‏.‏ وَإِذَا أَمْسَى قَالَ ‏"‏ اللَّهُمَّ بِكَ أَمْسَيْنَا وَبِكَ نَحْيَا وَبِكَ نَمُوتُ وَإِلَيْكَ النُّشُورُ ‏"‏ ‏.‏\hadithno{5068}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) used to say in the morning: "O Allah, by Thee we come to the morning, by Thee we come to the evening, by Thee are we resurrected." In the evening he would say: "O Allah, by Thee we come to the evening, by Thee we die, and to Thee are we resurrected}}
\hadithdefcmd{abudawud}{5069}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي فُدَيْكٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْمَجِيدِ، عَنْ هِشَامِ بْنِ الْغَازِ بْنِ رَبِيعَةَ، عَنْ مَكْحُولٍ الدِّمَشْقِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ أَوْ يُمْسِي اللَّهُمَّ إِنِّي أَصْبَحْتُ أُشْهِدُكَ وَأُشْهِدُ حَمَلَةَ عَرْشِكَ وَمَلاَئِكَتَكَ وَجَمِيعَ خَلْقِكَ أَنَّكَ أَنْتَ اللَّهُ لاَ إِلَهَ إِلاَّ أَنْتَ وَأَنَّ مُحَمَّدًا عَبْدُكَ وَرَسُولُكَ أَعْتَقَ اللَّهُ رُبْعَهُ مِنَ النَّارِ فَمَنْ قَالَهَا مَرَّتَيْنِ أَعْتَقَ اللَّهُ نِصْفَهُ وَمَنْ قَالَهَا ثَلاَثًا أَعْتَقَ اللَّهُ ثَلاَثَةَ أَرْبَاعِهِ فَإِنْ قَالَهَا أَرْبَعًا أَعْتَقَهُ اللَّهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{5069}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: If anyone says in the morning or in the evening: "O Allah! in the morning we call Thee, the bearers of Thy Throne, Thy angels and all Thy creatures to witness that thou art Allah (God) than Whom alone there is no god, and that Muhammad is Thy Servant and Apostle," Allah will emancipate his fourth from Hell; if anyone says twice, Allah will emancipate his half; if anyone says it thrice, Allah will emancipate three-fourth; and if he says four times, Allah will emancipate him from Hell}}
\hadithdefcmd{abudawud}{5070}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا الْوَلِيدُ بْنُ ثَعْلَبَةَ الطَّائِيُّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ أَوْ حِينَ يُمْسِي اللَّهُمَّ أَنْتَ رَبِّي لاَ إِلَهَ إِلاَّ أَنْتَ خَلَقْتَنِي وَأَنَا عَبْدُكَ وَأَنَا عَلَى عَهْدِكَ وَوَعْدِكَ مَا اسْتَطَعْتُ أَعُوذُ بِكَ مِنْ شَرِّ مَا صَنَعْتُ أَبُوءُ بِنِعْمَتِكَ وَأَبُوءُ بِذَنْبِي فَاغْفِرْ لِي إِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ ‏.‏ فَمَاتَ مِنْ يَوْمِهِ أَوْ مِنْ لَيْلَتِهِ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{5070}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Prophet (ﷺ) said: If anyone says in the morning or in the evening: "O Allah! Thou art my Lord; there is no god but Thee, Thou hast created me, and I am Thy servant and hold to Thy covenant and promise as much as I can; I seek refuge in Thee from the evil of what I have done: I acknowledge Thy favour to me, and I acknowledge my sin; pardon me, for none but Thee pardons sins, and dies during the daytime or during the night." he will go to Paradise}}
\hadithdefcmd{abudawud}{5071}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ قُدَامَةَ بْنِ أَعْيَنَ، حَدَّثَنَا جَرِيرٌ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ سُوَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ إِذَا أَمْسَى ‏"‏ أَمْسَيْنَا وَأَمْسَى الْمُلْكُ لِلَّهِ وَالْحَمْدُ لِلَّهِ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ ‏"‏ ‏.‏ زَادَ فِي حَدِيثِ جَرِيرٍ وَأَمَّا زُبَيْدٌ كَانَ يَقُولُ كَانَ إِبْرَاهِيمُ بْنُ سُوَيْدٍ يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ رَبِّ أَسْأَلُكَ خَيْرَ مَا فِي هَذِهِ اللَّيْلَةِ وَخَيْرَ مَا بَعْدَهَا وَأَعُوذُ بِكَ مِنْ شَرِّ مَا فِي هَذِهِ اللَّيْلَةِ وَشَرِّ مَا بَعْدَهَا رَبِّ أَعُوذُ بِكَ مِنَ الْكَسَلِ وَمِنْ سُوءِ الْكِبْرِ أَوِ الْكُفْرِ رَبِّ أَعُوذُ بِكَ مِنْ عَذَابٍ فِي النَّارِ وَعَذَابٍ فِي الْقَبْرِ ‏"‏ ‏.‏ وَإِذَا أَصْبَحَ قَالَ ذَلِكَ أَيْضًا ‏"‏ أَصْبَحْنَا وَأَصْبَحَ الْمُلْكُ لِلَّهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ شُعْبَةُ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ عَنْ إِبْرَاهِيمَ بْنِ سُوَيْدٍ قَالَ ‏"‏ مِنْ سُوءِ الْكِبْرِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ سُوءَ الْكُفْرِ ‏.‏\hadithno{5071}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2732)}\hadithtrans{‘Abd Allah (b. Mas’ud) told that when the evening came, the prophet (May peace be upon him) would say:we have come to the evening, and in the evening the dominion belongs to Allah: “Praise be to Allah; there is no god but Allah alone who has no partner”. The version of Jarir adds: Zubaid said that Ibrahim b. Suwaid said: There is no god but Allah alone who has no partner; to him belongs the dominion, to him praise is due, and He is omnipotent. O Allah! I ask thee for the good of what this night contains, and the good of what comes after it; and I seek refuge in Thee from the evil of what this night contains, and from the evil of what comes after it. My Lord! I seek refuge in Thee from indolence, the evil of old age or of disbelief. My Lord! I seek refuge in Thee from a punishment in Hell and a punishment in the grave. In the morning he said that also: we have come to the morning, and in the morning the dominion belongs to Allah. Abu Dawud said: Shu’bah transmitted from Salamah b. Kuhail, from Ibrahim b. Suwaid, saying: from the evil of old age. He did not mention the evil of disbelief}}
\hadithdefcmd{abudawud}{5072}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عَقِيلٍ، عَنْ سَابِقِ بْنِ نَاجِيَةَ، عَنْ أَبِي سَلاَّمٍ، أَنَّهُ كَانَ فِي مَسْجِدِ حِمْصٍ فَمَرَّ بِهِ رَجُلٌ فَقَالُوا هَذَا خَدَمَ النَّبِيَّ صلى الله عليه وسلم فَقَامَ إِلَيْهِ فَقَالَ حَدِّثْنِي بِحَدِيثٍ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَمْ يَتَدَاوَلْهُ بَيْنَكَ وَبَيْنَهُ الرِّجَالُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَالَ إِذَا أَصْبَحَ وَإِذَا أَمْسَى رَضِينَا بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ رَسُولاً إِلاَّ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يُرْضِيَهُ ‏"‏ ‏.‏\hadithno{5072}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated A man: AbuSallam told that he was in the mosque of Hims. A man passed him and the people said about him that he served the Prophet (ﷺ). He (AbuSallam) went to him and said: Tell me any tradition which you heard from the Messenger of Allah (ﷺ) and there were no man between him and you. He said: I heard the Messenger of Allah (ﷺ) say: If anyone says in the morning and in the evening: "I am pleased with Allah as Lord, with Islam as religion, with Muhammad as Prophet," Allah will certainly please him}}
\hadithdefcmd{abudawud}{5073}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، وَإِسْمَاعِيلُ، قَالاَ حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عَنْبَسَةَ، عَنْ عَبْدِ اللَّهِ بْنِ غَنَّامٍ الْبَيَاضِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ اللَّهُمَّ مَا أَصْبَحَ بِي مِنْ نِعْمَةٍ فَمِنْكَ وَحْدَكَ لاَ شَرِيكَ لَكَ فَلَكَ الْحَمْدُ وَلَكَ الشُّكْرُ ‏.‏ فَقَدْ أَدَّى شُكْرَ يَوْمِهِ وَمَنْ قَالَ مِثْلَ ذَلِكَ حِينَ يُمْسِي فَقَدْ أَدَّى شُكْرَ لَيْلَتِهِ ‏"‏ ‏.‏\hadithno{5073}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Ghannam: The Prophet (ﷺ) said: If anyone says in the morning: "O Allah! whatever favour has come to me, it comes from Thee alone Who has no partner; to Thee praise is due and thanksgiving,'! he will have expressed full thanksgiving for the day; and if anyone says the same in the evening, he will have expressed full thanksgiving for the night}}
\hadithdefcmd{abudawud}{5074}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، - الْمَعْنَى - حَدَّثَنَا ابْنُ نُمَيْرٍ، قَالاَ حَدَّثَنَا عُبَادَةُ بْنُ مُسْلِمٍ الْفَزَارِيُّ، عَنْ جُبَيْرِ بْنِ أَبِي سُلَيْمَانَ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَعُ هَؤُلاَءِ الدَّعَوَاتِ حِينَ يُمْسِي وَحِينَ يُصْبِحُ ‏"‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْعَفْوَ وَالْعَافِيَةَ فِي دِينِي وَدُنْيَاىَ وَأَهْلِي وَمَالِي اللَّهُمَّ اسْتُرْ عَوْرَتِي ‏"‏ ‏.‏ وَقَالَ عُثْمَانُ ‏"‏ عَوْرَاتِي وَآمِنْ رَوْعَاتِي اللَّهُمَّ احْفَظْنِي مِنْ بَيْنِ يَدَىَّ وَمِنْ خَلْفِي وَعَنْ يَمِينِي وَعَنْ شِمَالِي وَمِنْ فَوْقِي وَأَعُوذُ بِعَظَمَتِكَ أَنْ أُغْتَالَ مِنْ تَحْتِي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ وَكِيعٌ يَعْنِي الْخَسْفَ ‏.‏\hadithno{5074}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) never failed to utter these supplications in the evening and in the morning: O Allah, I ask Thee for security in this world and in the Hereafter: O Allah! I ask Thee for forgiveness and security in my religion and my worldly affairs, in my family and my property; O Allah! conceal my fault or faults (according to Uthman's version), and keep me safe from the things which I fear; O Allah! guard me in front of me and behind me, on my right hand and on my left, and from above me: and I seek in Thy greatness from receiving unexpected harm from below me." AbuDawud said: Waki' said: That is to say, swallowing by the earth}}
\hadithdefcmd{abudawud}{5075}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ سَالِمًا الْفَرَّاءَ، حَدَّثَهُ أَنَّ عَبْدَ الْحَمِيدِ مَوْلَى بَنِي هَاشِمٍ حَدَّثَهُ أَنَّ أُمَّهُ حَدَّثَتْهُ وَكَانَتْ، تَخْدِمُ بَعْضَ بَنَاتِ النَّبِيِّ صلى الله عليه وسلم أَنَّ بِنْتَ النَّبِيِّ، صلى الله عليه وسلم حَدَّثَتْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُعَلِّمُهَا فَيَقُولُ ‏ "‏ قُولِي حِينَ تُصْبِحِينَ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ لاَ قُوَّةَ إِلاَّ بِاللَّهِ مَا شَاءَ اللَّهُ كَانَ وَمَا لَمْ يَشَأْ لَمْ يَكُنْ أَعْلَمُ أَنَّ اللَّهَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ وَأَنَّ اللَّهَ قَدْ أَحَاطَ بِكُلِّ شَىْءٍ عِلْمًا فَإِنَّهُ مَنْ قَالَهُنَّ حِينَ يُصْبِحُ حُفِظَ حَتَّى يُمْسِيَ وَمَنْ قَالَهُنَّ حِينَ يُمْسِي حُفِظَ حَتَّى يُصْبِحَ ‏"‏ ‏.‏\hadithno{5075}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Daughter of the Prophet: AbdulHamid, a client of Banu Hashim, said that his mother who served some of the daughters of the Prophet (ﷺ) told him that one of the daughters of the Prophet (ﷺ) said that the Prophet (ﷺ) used to teach her saying: Say in the morning: Glory be to Allah, and I begin with praise of Him; there is no power but in Allah ; what Allah wills comes to pass and what He does not will does not come to pass; I know that Allah is Omnipotent and that Allah has comprehended everything in knowledge" ; for whoever says it in the morning will be guarded till the evening, and whoever says it in the evening will be guarded till the morning}}
\hadithdefcmd{abudawud}{5076}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، قَالَ أَخْبَرَنَا ح، وَحَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي اللَّيْثُ، عَنْ سَعِيدِ بْنِ بَشِيرٍ النَّجَّارِيِّ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الْبَيْلَمَانِيِّ، - قَالَ الرَّبِيعُ ابْنُ الْبَيْلَمَانِيِّ - عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ قَالَ حِينَ يُصْبِحُ ‏\{‏ فَسُبْحَانَ اللَّهِ حِينَ تُمْسُونَ وَحِينَ تُصْبِحُونَ * وَلَهُ الْحَمْدُ فِي السَّمَوَاتِ وَالأَرْضِ وَعَشِيًّا وَحِينَ تُظْهِرُونَ ‏\}‏ إِلَى ‏\{‏ وَكَذَلِكَ تُخْرَجُونَ ‏\}‏ أَدْرَكَ مَا فَاتَهُ فِي يَوْمِهِ ذَلِكَ وَمَنْ قَالَهُنَّ حِينَ يُمْسِي أَدْرَكَ مَا فَاتَهُ فِي لَيْلَتِهِ ‏"‏ ‏.‏ قَالَ الرَّبِيعُ عَنِ اللَّيْثِ ‏.‏\hadithno{5076}\hadithgrade{Al-Albani: Very Daif; Muhammad Muhyi Al-Din Abdul Hamid: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone repeats in the morning: "So glory be to Allah in the evening and in the morning; to Him is the praise in the heavens and the earth, and in the late evening and at noon....thus shall you be brought forth, " he will get that day what he has missed; and if anyone repeats these words in the evening he will get that night what he has missed. Ar-Rabi' transmitted it from al-Layth}}
\hadithdefcmd{abudawud}{5077}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، وَوُهَيْبٌ، نَحْوَهُ عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي عَائِشٍ، - وَقَالَ حَمَّادٌ عَنْ أَبِي عَيَّاشٍ، - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قَالَ إِذَا أَصْبَحَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ كَانَ لَهُ عِدْلُ رَقَبَةٍ مِنْ وَلَدِ إِسْمَاعِيلَ وَكُتِبَ لَهُ عَشْرُ حَسَنَاتٍ وَحُطَّ عَنْهُ عَشْرُ سَيِّئَاتٍ وَرُفِعَ لَهُ عَشْرُ دَرَجَاتٍ وَكَانَ فِي حِرْزٍ مِنَ الشَّيْطَانِ حَتَّى يُمْسِيَ وَإِنْ قَالَهَا إِذَا أَمْسَى كَانَ لَهُ مِثْلُ ذَلِكَ حَتَّى يُصْبِحَ ‏"‏ ‏.‏ قَالَ فِي حَدِيثِ حَمَّادٍ فَرَأَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فِيمَا يَرَى النَّائِمُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبَا عَيَّاشٍ يُحَدِّثُ عَنْكَ بِكَذَا وَكَذَا قَالَ ‏"‏ صَدَقَ أَبُو عَيَّاشٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ إِسْمَاعِيلُ بْنُ جَعْفَرٍ وَمُوسَى الزَّمْعِيُّ وَعَبْدُ اللَّهِ بْنُ جَعْفَرٍ عَنْ سُهَيْلٍ عَنْ أَبِيهِ عَنِ ابْنِ عَائِشٍ ‏.‏\hadithno{5077}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuAyyash: The Messenger of Allah (ﷺ) said: If anyone says in the morning: "There is no god but Allah alone Who has no partner; to Him belong the dominions, to Him praise is due, and He is Omnipotent," he will have a reward equivalent to that for setting free a slave from among the descendants of Isma'il. He will have ten good deeds recorded for him, ten evil deeds deducted from him, he will be advanced ten degrees, and will be guarded from the Devil till the evening. If he says them in the evening, he will have a similar recompense till the morning. The version of Hammad says: A man saw the Messenger of Allah (ﷺ) in a dream and said: Messenger of Allah! AbuAyyash is relating such and such on your authority. He said: AbuAyyash has spoken the truth. Abu Dawud said: Isma'il b. Ja'far, Musa al-Zim'i and 'Adb Allah b. Ja'far transmitted it from Suhail, from his father on the authority of Ibn 'A'ish}}
\hadithdefcmd{abudawud}{5078}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا بَقِيَّةُ، عَنْ مُسْلِمٍ، - يَعْنِي ابْنَ زِيَادٍ - قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ اللَّهُمَّ إِنِّي أَصْبَحْتُ أُشْهِدُكَ وَأُشْهِدُ حَمَلَةَ عَرْشِكَ وَمَلاَئِكَتَكَ وَجَمِيعَ خَلْقِكَ أَنَّكَ أَنْتَ اللَّهُ لاَ إِلَهَ إِلاَّ أَنْتَ وَحْدَكَ لاَ شَرِيكَ لَكَ وَأَنَّ مُحَمَّدًا عَبْدُكَ وَرَسُولُكَ إِلاَّ غُفِرَ لَهُ مَا أَصَابَ فِي يَوْمِهِ ذَلِكَ مِنْ ذَنْبٍ وَإِنْ قَالَهَا حِينَ يُمْسِي غُفِرَ لَهُ مَا أَصَابَ تِلْكَ اللَّيْلَةَ ‏"‏ ‏.‏\hadithno{5078}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: If anyone says in the morning: "O Allah! in the morning we call Thee, the bearers of Thy Throne, Thy angels, and all Thy creatures to witness that Thou art Allah than Whom there is no god, Thou being alone and without a partner, and that Muhammad is Thy servant and Thy Apostle," Allah will forgive him any sins that he commits that day; and if he repeats them in the evening. Allah will forgive him any sins he commits that night}}
\hadithdefcmd{abudawud}{5079}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ أَبُو النَّضْرِ الدِّمَشْقِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، قَالَ أَخْبَرَنِي أَبُو سَعِيدٍ الْفِلَسْطِينِيُّ عَبْدُ الرَّحْمَنِ بْنُ حَسَّانَ، عَنِ الْحَارِثِ بْنِ مُسْلِمٍ، أَنَّهُ أَخْبَرَهُ عَنْ أَبِيهِ، مُسْلِمِ بْنِ الْحَارِثِ التَّمِيمِيِّ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَسَرَّ إِلَيْهِ فَقَالَ ‏ "‏ إِذَا انْصَرَفْتَ مِنْ صَلاَةِ الْمَغْرِبِ فَقُلِ اللَّهُمَّ أَجِرْنِي مِنَ النَّارِ ‏.‏ سَبْعَ مَرَّاتٍ فَإِنَّكَ إِذَا قُلْتَ ذَلِكَ ثُمَّ مِتَّ فِي لَيْلَتِكَ كُتِبَ لَكَ جِوَارٌ مِنْهَا وَإِذَا صَلَّيْتَ الصُّبْحَ فَقُلْ كَذَلِكَ فَإِنَّكَ إِنْ مِتَّ فِي يَوْمِكَ كُتِبَ لَكَ جِوَارٌ مِنْهَا ‏"‏ ‏.‏ أَخْبَرَنِي أَبُو سَعِيدٍ عَنِ الْحَارِثِ أَنَّهُ قَالَ أَسَرَّهَا إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَحْنُ نَخُصُّ بِهَا إِخْوَانَنَا ‏.‏\hadithno{5079}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Al-Harith b. Muslim al-Tamimi quoted his father Muslim b. al-Harith al-Tamimi as saying that the Messenger of Allah (ﷺ) told him secretly:When you finish the sunset prayer, say: 'O Allah, protect me from Hell" seven times; for if you say that and die that night, protection from it would be recorded for you; and when you finish the dawn prayer, say it in a similar way, for if you die that day, protection from it would be recorded for you. AbuSa'id told me that al-Harith said: The Messenger of Allah (ﷺ) said this to us secretly, so we confine it to our brethren}}
\hadithdefcmd{abudawud}{5080}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ الْحِمْصِيُّ، وَمُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، وَعَلِيُّ بْنُ سَهْلٍ الرَّمْلِيُّ، وَمُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، قَالُوا حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ حَسَّانَ الْكِنَانِيُّ، قَالَ حَدَّثَنِي مُسْلِمُ بْنُ الْحَارِثِ بْنِ مُسْلِمٍ التَّمِيمِيُّ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ نَحْوَهُ إِلَى قَوْلِهِ ‏"‏ جِوَارٌ مِنْهَا ‏"‏ ‏.‏ إِلاَّ أَنَّهُ قَالَ فِيهِمَا ‏"‏ قَبْلَ أَنْ تُكَلِّمَ أَحَدًا ‏"‏ ‏.‏ قَالَ عَلِيُّ بْنُ سَهْلٍ فِيهِ إِنَّ أَبَاهُ حَدَّثَهُ وَقَالَ عَلِيٌّ وَابْنُ الْمُصَفَّى بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَرِيَّةٍ فَلَمَّا بَلَغْنَا الْمُغَارَ اسْتَحْثَثْتُ فَرَسِي فَسَبَقْتُ أَصْحَابِي وَتَلَقَّانِي الْحَىُّ بِالرَّنِينِ فَقُلْتُ لَهُمْ قُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ تُحْرَزُوا فَقَالُوهَا فَلاَمَنِي أَصْحَابِي وَقَالُوا حَرَمْتَنَا الْغَنِيمَةَ فَلَمَّا قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَخْبَرُوهُ بِالَّذِي صَنَعْتُ فَدَعَانِي فَحَسَّنَ لِي مَا صَنَعْتُ وَقَالَ ‏"‏ أَمَا إِنَّ اللَّهَ قَدْ كَتَبَ لَكَ مِنْ كُلِّ إِنْسَانٍ مِنْهُمْ كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ فَأَنَا نَسِيتُ الثَّوَابَ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا إِنِّي سَأَكْتُبُ لَكَ بِالْوَصَاةِ بَعْدِي ‏"‏ ‏.‏ قَالَ فَفَعَلَ وَخَتَمَ عَلَيْهِ فَدَفَعَهُ إِلَىَّ وَقَالَ لِي ثُمَّ ذَكَرَ مَعْنَاهُمْ وَقَالَ ابْنُ الْمُصَفَّى قَالَ سَمِعْتُ الْحَارِثَ بْنَ مُسْلِمِ بْنِ الْحَارِثِ التَّمِيمِيَّ يُحَدِّثُ عَنْ أَبِيهِ ‏.‏\hadithno{5080}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Muslim ibn al-Harith ibn Muslim at-Tamimi: A similar tradition (to No. 5061) has been transmitted by Muslim ibn al-Harith ibn Muslim at-Tamimi on the authority of his father from the Prophet (ﷺ) through a different chain of narrators, up to "protection from it". But this version says: "before speaking to anyone". In this version Ali ibn Sahl said that his father told him. Ali and Ibn al-Musaffa said: The Messenger of Allah (ﷺ) sent us on an expedition. When we reached the place of attack, I galloped my horse and outstripped my companions, and the people of that locality received me with a great noise. I said to them: Say "There is no god but Allah," and you will be protected. They said this. My companions blamed me, saying: You deprived us of the booty. When we came to the Messenger of Allah (ﷺ), they told him what I had done. So he called me, appreciating what I had done, and said: Allah has recorded for you so and so (a reward) for every man of them. AbdurRahman said: I forgot the reward. The Messenger of Allah (ﷺ) then said: I shall write a will for you after me. He did this and stamped it, and gave it to me, saying....He then mentioned the rest of the tradition to the same effect. Ibn al-Musaffa said: I heard al-Harith ibn Muslim ibn al-Harith at-Tamimi transmitting it from his father}}
\hadithdefcmd{abudawud}{5081}{حَدَّثَنَا يَزِيدُ بْنُ مُحَمَّدٍ الدِّمَشْقِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ مُسْلِمٍ الدِّمَشْقِيُّ، - وَكَانَ مِنْ ثِقَاتِ الْمُسْلِمِينَ مِنَ الْمُتَعَبِّدِينَ - قَالَ حَدَّثَنَا مُدْرِكُ بْنُ سَعْدٍ - قَالَ يَزِيدُ شَيْخٌ ثِقَةٌ - عَنْ يُونُسَ بْنِ مَيْسَرَةَ بْنِ حَلْبَسٍ عَنْ أُمِّ الدَّرْدَاءِ عَنْ أَبِي الدَّرْدَاءِ رضى الله عنه قَالَ مَنْ قَالَ إِذَا أَصْبَحَ وَإِذَا أَمْسَى حَسْبِيَ اللَّهُ لاَ إِلَهَ إِلاَّ هُوَ عَلَيْهِ تَوَكَّلْتُ وَهُوَ رَبُّ الْعَرْشِ الْعَظِيمِ سَبْعَ مَرَّاتٍ كَفَاهُ اللَّهُ مَا أَهَمَّهُ صَادِقًا كَانَ بِهَا أَوْ كَاذِبًا ‏.‏\hadithno{5081}\hadithgrade{Al-Albani: Mawdu; Muhammad Muhyi Al-Din Abdul Hamid: Mawdu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu al-Darda’ said:if anyone says seven times morning and evening; “Allah sufficeth me: there is no god but He; on him is my trust- he, the Lord of the Throne (of glory) Supreme”, Allah will be sufficient for him against anything which grieves him, whether he is true or false in (repeating) them}}
\hadithdefcmd{abudawud}{5082}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، عَنْ أَبِي أَسِيدٍ الْبَرَّادِ، عَنْ مُعَاذِ بْنِ عَبْدِ اللَّهِ بْنِ خُبَيْبٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ خَرَجْنَا فِي لَيْلَةِ مَطَرٍ وَظُلْمَةٍ شَدِيدَةٍ نَطْلُبُ رَسُولَ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ لَنَا فَأَدْرَكْنَاهُ فَقَالَ ‏"‏ أَصَلَّيْتُمْ ‏"‏ ‏.‏ فَلَمْ أَقُلْ شَيْئًا فَقَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ فَلَمْ أَقُلْ شَيْئًا ثُمَّ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ فَلَمْ أَقُلْ شَيْئًا ثُمَّ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا أَقُولُ قَالَ ‏"‏ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ وَالْمُعَوِّذَتَيْنِ حِينَ تُمْسِي وَحِينَ تُصْبِحُ ثَلاَثَ مَرَّاتٍ تَكْفِيكَ مِنْ كُلِّ شَىْءٍ ‏"‏ ‏.‏\hadithno{5082}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Khubayb: We went out one rainy and intensely dark night to look for the Messenger of Allah (ﷺ) to lead us in prayer, and when we found him, he asked: Have you prayed?, but I did not say anything. So he said: Say, but I did not say anything. He again said: Say, but I did not say anything. He then said: Say. So I said: What am I to say? He said: Say: "Say, He is Allah, One," and al-Mu'awwadhatan three times in the morning and evening; they will serve you for every purpose}}
\hadithdefcmd{abudawud}{5083}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي أَبِي، - قَالَ ابْنُ عَوْفٍ وَرَأَيْتُهُ فِي أَصْلِ إِسْمَاعِيلَ - قَالَ حَدَّثَنِي ضَمْضَمٌ، عَنْ شُرَيْحٍ، عَنْ أَبِي مَالِكٍ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ حَدِّثْنَا بِكَلِمَةٍ، نَقُولُهَا إِذَا أَصْبَحْنَا وَأَمْسَيْنَا وَاضْطَجَعْنَا فَأَمَرَهُمْ أَنْ يَقُولُوا ‏:‏ اللَّهُمَّ فَاطِرَ السَّمَوَاتِ وَالأَرْضِ عَالِمَ الْغَيْبِ وَالشَّهَادَةِ أَنْتَ رَبُّ كُلِّ شَىْءٍ وَالْمَلاَئِكَةُ يَشْهَدُونَ أَنَّكَ لاَ إِلَهَ إِلاَّ أَنْتَ فَإِنَّا نَعُوذُ بِكَ مِنْ شَرِّ أَنْفُسِنَا وَمِنْ شَرِّ الشَّيْطَانِ الرَّجِيمِ وَشِرْكِهِ وَأَنْ نَقْتَرِفَ سُوءًا عَلَى أَنْفُسِنَا أَوْ نَجُرَّهُ إِلَى مُسْلِمٍ ‏.‏\hadithno{5083}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMalik: The people asked: Tell us a word which we repeat in the morning, evening and when we rise. So he commanded us to say: "O Allah! Creator of Heavens and Earth; Knower of all that is hidden and open; Thou art the Lord of everything; the angels testify that there is no god but Thee, for we seek refuge in Thee from the evil within ourselves, from the evil of the Devil accused and from the evil of his suggestion about partnership with Allah, and that we earn sin for ourselves or drag it to a Muslim}}
\hadithdefcmd{abudawud}{5084}{قَالَ أَبُو دَاوُدَ وَبِهَذَا الإِسْنَادِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَصْبَحَ أَحَدُكُمْ فَلْيَقُلْ أَصْبَحْنَا وَأَصْبَحَ الْمُلْكُ لِلَّهِ رَبِّ الْعَالَمِينَ اللَّهُمَّ إِنِّي أَسْأَلُكَ خَيْرَ هَذَا الْيَوْمِ فَتْحَهُ وَنَصْرَهُ وَنُورَهُ وَبَرَكَتَهُ وَهُدَاهُ وَأَعُوذُ بِكَ مِنْ شَرِّ مَا فِيهِ وَشَرِّ مَا بَعْدَهُ ثُمَّ إِذَا أَمْسَى فَلْيَقُلْ مِثْلَ ذَلِكَ ‏"‏ ‏.‏\hadithno{5084}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{AbuDawud said:And through the same chain of transmitters the Messenger of Allah (ﷺ) said: When one rises in the morning, one should say: "We have reached the morning, and in the morning the dominion belongs to Allah, the Lord of the universe. O Allah! I ask Thee for the good this day contains, for conquest, victory, light, blessing and guidance during it; and I seek refuge in Thee from the evil it contains and the evil contained in what comes after it." In the evening he should say the equivalent}}
\hadithdefcmd{abudawud}{5085}{حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ عُمَرَ بْنِ جُعْثُمٍ، قَالَ حَدَّثَنِي الأَزْهَرُ بْنُ عَبْدِ اللَّهِ الْحَرَازِيُّ، قَالَ حَدَّثَنِي شَرِيقٌ الْهَوْزَنِيُّ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ رضى الله عنها فَسَأَلْتُهَا بِمَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَفْتَتِحُ إِذَا هَبَّ مِنَ اللَّيْلِ فَقَالَتْ لَقَدْ سَأَلْتَنِي عَنْ شَىْءٍ مَا سَأَلَنِي عَنْهُ أَحَدٌ قَبْلَكَ كَانَ إِذَا هَبَّ مِنَ اللَّيْلِ كَبَّرَ عَشْرًا وَحَمِدَ عَشْرًا وَقَالَ ‏"‏ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ ‏"‏ ‏.‏ عَشْرًا وَقَالَ ‏"‏ سُبْحَانَ الْمَلِكِ الْقُدُّوسِ ‏"‏ ‏.‏ عَشْرًا وَاسْتَغْفَرَ عَشْرًا وَهَلَّلَ عَشْرًا ثُمَّ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ ضِيقِ الدُّنْيَا وَضِيقِ يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ عَشْرًا ثُمَّ يَفْتَتِحُ الصَّلاَةَ ‏.‏\hadithno{5085}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Shariq al-Hawzani and I came to Aisha (Allah be pleased with her) and asked her: By which (prayer) the Messenger of Allah (ﷺ) began when he woke up at night? She replied: You asked me about a thing which no one asked me before. When he woke up at night, he uttered: "Allah is Most Great" ten times, and uttered "Praise be to Allah" ten times, and said "Glory be to Allah and I begin with His praise" ten times, and said: "Glory be to the King, the Most Holy" ten times, and asked Allah's pardon ten times, and said: "There is no god but Allah" ten times, and then said: "O Allah! I seek refuge in Thee from the strait of the Day of resurrection," ten times. He then began the prayer}}
\hadithdefcmd{abudawud}{5086}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ فِي سَفَرٍ فَأَسْحَرَ يَقُولُ ‏ "‏ سَمِعَ سَامِعٌ بِحَمْدِ اللَّهِ وَنِعْمَتِهِ وَحُسْنِ بَلاَئِهِ عَلَيْنَا اللَّهُمَّ صَاحِبْنَا فَأَفْضِلْ عَلَيْنَا ‏"‏ ‏.‏ عَائِذًا بِاللَّهِ مِنَ النَّارِ ‏.‏\hadithno{5086}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2718)}\hadithtrans{Abu Hurairah said; When the Messenger of Allah (May peace be upon him) was on a journey, he would say at daybreak:Let a hearer hear beginning with praise of Allah and His good favours and blessing to us. Our Lord, accompany us and show favour to us, and I seek refuge in Allah from Hell}}
\hadithdefcmd{abudawud}{5087}{حَدَّثَنَا ابْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الْمَسْعُودِيُّ، حَدَّثَنَا الْقَاسِمُ، قَالَ كَانَ أَبُو ذَرٍّ يَقُولُ مَنْ قَالَ حِينَ يُصْبِحُ اللَّهُمَّ مَا حَلَفْتُ مِنْ حَلِفٍ أَوْ قُلْتُ مِنْ قَوْلٍ أَوْ نَذَرْتُ مِنْ نَذْرٍ فَمَشِيئَتُكَ بَيْنَ يَدَىْ ذَلِكَ كُلِّهِ مَا شِئْتَ كَانَ وَمَا لَمْ تَشَأْ لَمْ يَكُنِ اللَّهُمَّ اغْفِرْ لِي وَتَجَاوَزْ لِي عَنْهُ اللَّهُمَّ فَمَنْ صَلَّيْتَ عَلَيْهِ فَعَلَيْهِ صَلاَتِي وَمَنْ لَعَنْتَ فَعَلَيْهِ لَعْنَتِي كَانَ فِي اسْتِثْنَاءٍ يَوْمَهُ ذَلِكَ أَوْ قَالَ ذَلِكَ الْيَوْمَ ‏.‏\hadithno{5087}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuDharr: If anyone says in the morning: "O Allah! whatever oath I take, whatever word I speak, and whatever vow I take, Thine will precedes all that: whatever Thou willeth, occurs, and whatever Thou dost not will, dost not occur. O Allah! pardon me and disregard me for it. O Allah! whomsoever Thou sendest thine blessing, to him my blessing is due, and whomsoever thou cursest, to him my curse is due, " exemption from it will be granted to him that day}}
\hadithdefcmd{abudawud}{5088}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا أَبُو مَوْدُودٍ، عَمَّنْ سَمِعَ أَبَانَ بْنَ عُثْمَانَ، يَقُولُ سَمِعْتُ عُثْمَانَ، - يَعْنِي ابْنَ عَفَّانَ - يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَالَ بِسْمِ اللَّهِ الَّذِي لاَ يَضُرُّ مَعَ اسْمِهِ شَىْءٌ فِي الأَرْضِ وَلاَ فِي السَّمَاءِ وَهُوَ السَّمِيعُ الْعَلِيمُ ثَلاَثَ مَرَّاتٍ لَمْ تُصِبْهُ فَجْأَةُ بَلاَءٍ حَتَّى يُصْبِحَ وَمَنْ قَالَهَا حِينَ يُصْبِحُ ثَلاَثَ مَرَّاتٍ لَمْ تُصِبْهُ فَجْأَةُ بَلاَءٍ حَتَّى يُمْسِيَ ‏"‏ ‏.‏ قَالَ فَأَصَابَ أَبَانَ بْنَ عُثْمَانَ الْفَالِجُ فَجَعَلَ الرَّجُلُ الَّذِي سَمِعَ مِنْهُ الْحَدِيثَ يَنْظُرُ إِلَيْهِ فَقَالَ لَهُ مَا لَكَ تَنْظُرُ إِلَىَّ فَوَاللَّهِ مَا كَذَبْتُ عَلَى عُثْمَانَ وَلاَ كَذَبَ عُثْمَانُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَلَكِنَّ الْيَوْمَ الَّذِي أَصَابَنِي فِيهِ مَا أَصَابَنِي غَضِبْتُ فَنَسِيتُ أَنْ أَقُولَهَا ‏.‏\hadithno{5088}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Uthman ibn Affan: Aban ibn Uthman said: I heard Uthman ibn Affan (his father) say: I heard the Messenger of Allah (ﷺ) say: If anyone says three times: "In the name of Allah, when Whose name is mentioned nothing on Earth or in Heaven can cause harm, and He is the Hearer, the Knower" he will not suffer sudden affliction till the morning, and if anyone says this in the morning, he will not suffer sudden affliction till the evening. Aban was afflicted by some paralysis and when a man who heard the tradition began to look at him, he said to him: Why are you looking at me? I swear by Allah, I did not tell a lie about Uthman, nor did Uthman tell a lie about the Prophet (ﷺ), but that day when I was afflicted by it, I became angry and forgot to say them}}
\hadithdefcmd{abudawud}{5089}{حَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ الأَنْطَاكِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، قَالَ حَدَّثَنِي أَبُو مَوْدُودٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنْ أَبَانَ بْنِ عُثْمَانَ، عَنْ عُثْمَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ لَمْ يَذْكُرْ قِصَّةَ الْفَالِجِ ‏.‏\hadithno{5089}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A similar tradition has been transmitted by Aban b. ‘Uthman, from ‘Uthman, from the prophet (May peace be upon him). This version does not mention the story of paralysis}}
\hadithdefcmd{abudawud}{5090}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، عَنْ عَبْدِ الْجَلِيلِ بْنِ عَطِيَّةَ، عَنْ جَعْفَرِ بْنِ مَيْمُونٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، أَنَّهُ قَالَ لأَبِيهِ يَا أَبَةِ إِنِّي أَسْمَعُكَ تَدْعُو كُلَّ غَدَاةٍ اللَّهُمَّ عَافِنِي فِي بَدَنِي اللَّهُمَّ عَافِنِي فِي سَمْعِي اللَّهُمَّ عَافِنِي فِي بَصَرِي لاَ إِلَهَ إِلاَّ أَنْتَ تُعِيدُهَا ثَلاَثًا حِينَ تُصْبِحُ وَثَلاَثًا حِينَ تُمْسِي ‏.‏ فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهِنَّ فَأَنَا أُحِبُّ أَنْ أَسْتَنَّ بِسُنَّتِهِ ‏.‏ قَالَ عَبَّاسٌ فِيهِ وَتَقُولُ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكُفْرِ وَالْفَقْرِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ لاَ إِلَهَ إِلاَّ أَنْتَ تُعِيدُهَا ثَلاَثًا حِينَ تُصْبِحُ وَثَلاَثًا حِينَ تُمْسِي فَتَدْعُو بِهِنَّ فَأُحِبُّ أَنْ أَسْتَنَّ بِسُنَّتِهِ قَالَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعَوَاتُ الْمَكْرُوبِ اللَّهُمَّ رَحْمَتَكَ أَرْجُو فَلاَ تَكِلْنِي إِلَى نَفْسِي طَرْفَةَ عَيْنٍ وَأَصْلِحْ لِي شَأْنِي كُلَّهُ لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ وَبَعْضُهُمْ يَزِيدُ عَلَى صَاحِبِهِ ‏.‏\hadithno{5090}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuBakrah: AbdurRahman ibn AbuBakrah said that he told his father: O my father! I hear you supplicating every morning: "O Allah! Grant me health in my body. O Allah! Grant me good hearing. O Allah! Grant me good eyesight. There is no god but Thou." You repeat them three times in the morning and three times in the evening. He said: I heard the Messenger of Allah (ﷺ) using these words as a supplication and I like to follow his practice. The transmitter, Abbas, said in this version: And you say: "O Allah! I seek refuge in Thee from infidelity and poverty. O Allah! I seek refuge in Thee from punishment in the grave. There is no god but Thee". You repeat them three times in the morning and three times in the evening, and use them as a supplication. I like to follow his practice. He said: The Messenger of Allah (ﷺ) said: The supplications to be used by one who is distressed are: "O Allah! Thy mercy is what I hope for. Do not abandon me to myself for an instant, but put all my affairs in good order for me. There is no god but Thou." Some transmitters added more than others}}
\hadithdefcmd{abudawud}{5091}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمِنْهَالِ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحُ بْنُ الْقَاسِمِ، عَنْ سُهَيْلٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ سُبْحَانَ اللَّهِ الْعَظِيمِ وَبِحَمْدِهِ مِائَةَ مَرَّةٍ وَإِذَا أَمْسَى كَذَلِكَ لَمْ يُوَافِ أَحَدٌ مِنَ الْخَلاَئِقِ بِمِثْلِ مَا وَافَى ‏"‏ ‏.‏\hadithno{5091}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2692)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:if anyone says a hundred times in the morning: “Glory be to Allah, the Sublime, and I begin with praise of him”, and says likewise in the evening, no one from the creatures will bring anything like the one which he will bring}}
\hadithdefcmd{abudawud}{5092}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، أَنَّهُ بَلَغَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَأَى الْهِلاَلَ قَالَ ‏"‏ هِلاَلُ خَيْرٍ وَرُشْدٍ هِلاَلُ خَيْرٍ وَرُشْدٍ هِلاَلُ خَيْرٍ وَرُشْدٍ آمَنْتُ بِالَّذِي خَلَقَكَ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏ ثُمَّ يَقُولُ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي ذَهَبَ بِشَهْرِ كَذَا وَجَاءَ بِشَهْرِ كَذَا ‏"‏ ‏.‏\hadithno{5092}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qatadah: When the Prophet of Allah (ﷺ) saw the new moon, he said: "a new moon of good and right guidance; a new moon of good and right guidance; a new moon of good and right guidance. I believe in Him Who created you" three times. He would then say: "Praise be to Allah Who has made such and such a month to pass and has brought such and such a month}}
\hadithdefcmd{abudawud}{5093}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَنَّ زَيْدَ بْنَ حُبَابٍ، أَخْبَرَهُمْ عَنْ أَبِي هِلاَلٍ، عَنْ قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا رَأَى الْهِلاَلَ صَرَفَ وَجْهَهُ عَنْهُ ‏.‏ قَالَ أَبُو دَاوُدَ لَيْسَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ حَدِيثٌ مُسْنَدٌ صَحِيحٌ ‏.‏\hadithno{5093}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qatadah: When the Messenger of Allah (ﷺ) saw the new moon, he turned away his face from it. Abu Dawud said: On this subject there is no tradition which has perfect chain and is sound}}
\hadithdefcmd{abudawud}{5094}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ مَا خَرَجَ النَّبِيُّ صلى الله عليه وسلم مِنْ بَيْتِي قَطُّ إِلاَّ رَفَعَ طَرْفَهُ إِلَى السَّمَاءِ فَقَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ أَنْ أَضِلَّ أَوْ أُضَلَّ أَوْ أَزِلَّ أَوْ أُزَلَّ أَوْ أَظْلِمَ أَوْ أُظْلَمَ أَوْ أَجْهَلَ أَوْ يُجْهَلَ عَلَىَّ ‏"‏ ‏.‏\hadithno{5094}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The Messenger of Allah (ﷺ) never went out of my house without raising his eye to the sky and saying: "O Allah! I seek refuge in Thee lest I stray or be led astray, or slip or made to slip, or cause injustice, or suffer injustice, or do wrong, or have wrong done to me}}
\hadithdefcmd{abudawud}{5095}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ الْخَثْعَمِيُّ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا خَرَجَ الرَّجُلُ مِنْ بَيْتِهِ فَقَالَ بِسْمِ اللَّهِ تَوَكَّلْتُ عَلَى اللَّهِ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏ قَالَ ‏"‏ يُقَالُ حِينَئِذٍ هُدِيتَ وَكُفِيتَ وَوُقِيتَ فَتَتَنَحَّى لَهُ الشَّيَاطِينُ فَيَقُولُ لَهُ شَيْطَانٌ آخَرُ كَيْفَ لَكَ بِرَجُلٍ قَدْ هُدِيَ وَكُفِيَ وَوُقِيَ ‏"‏ ‏.‏\hadithno{5095}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: When a man goes out of his house and says: "In the name of Allah, I trust in Allah; there is no might and no power but in Allah," the following will be said to him at that time: "You are guided, defended and protected." The devils will go far from him and another devil will say: How can you deal with a man who has been guided, defended and protected?}}
\hadithdefcmd{abudawud}{5096}{حَدَّثَنَا ابْنُ عَوْفٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي أَبِي، - قَالَ ابْنُ عَوْفٍ وَرَأَيْتُ فِي أَصْلِ إِسْمَاعِيلَ - قَالَ حَدَّثَنِي ضَمْضَمٌ، عَنْ شُرَيْحٍ، عَنْ أَبِي مَالِكٍ الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَلَجَ الرَّجُلُ فِي بَيْتِهِ فَلْيَقُلِ اللَّهُمَّ إِنِّي أَسْأَلُكَ خَيْرَ الْمَوْلِجِ وَخَيْرَ الْمَخْرَجِ بِسْمِ اللَّهِ وَلَجْنَا وَبِسْمِ اللَّهِ خَرَجْنَا وَعَلَى اللَّهِ رَبِّنَا تَوَكَّلْنَا ثُمَّ لْيُسَلِّمْ عَلَى أَهْلِهِ ‏"‏ ‏.‏\hadithno{5096}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMalik Al-Ash'ari: The Prophet (ﷺ) said: When a man goes into his house, he should say: "O Allah! I ask Thee for good both when entering and when going out; in the name of Allah we have entered, and in the name of Allah we have gone out, and in Allah our Lord do we trust." He should then greet his family}}
\hadithdefcmd{abudawud}{5097}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، وَسَلَمَةُ، - يَعْنِي ابْنَ شَبِيبٍ - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي ثَابِتُ بْنُ قَيْسٍ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الرِّيحُ مِنْ رَوْحِ اللَّهِ ‏"‏ ‏.‏ قَالَ سَلَمَةُ فَرَوْحُ اللَّهِ تَأْتِي بِالرَّحْمَةِ وَتَأْتِي بِالْعَذَابِ فَإِذَا رَأَيْتُمُوهَا فَلاَ تَسُبُّوهَا وَسَلُوا اللَّهَ خَيْرَهَا وَاسْتَعِيذُوا بِاللَّهِ مِنْ شَرِّهَا ‏"‏ ‏.‏\hadithno{5097}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: I heard the Messenger of Allah (ﷺ) say: The wind comes from Allah's mercy. Salamah's version has: It is Allah's mercy; it (sometimes) brings blessing and (sometimes) brings punishment. So when you see it, do not revile it, but ask Allah for some of its good, and seek refuge in Allah from its evil}}
\hadithdefcmd{abudawud}{5098}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، أَنَّ أَبَا النَّضْرِ، حَدَّثَهُ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطُّ مُسْتَجْمِعًا ضَاحِكًا حَتَّى أَرَى مِنْهُ لَهَوَاتِهِ إِنَّمَا كَانَ يَتَبَسَّمُ وَكَانَ إِذَا رَأَى غَيْمًا أَوْ رِيحًا عُرِفَ ذَلِكَ فِي وَجْهِهِ فَقُلْتُ يَا رَسُولَ اللَّهِ النَّاسُ إِذَا رَأَوُا الْغَيْمَ فَرِحُوا رَجَاءَ أَنْ يَكُونَ فِيهِ الْمَطَرُ وَأَرَاكَ إِذَا رَأَيْتَهُ عُرِفَتْ فِي وَجْهِكَ الْكَرَاهِيَةُ فَقَالَ ‏ "‏ يَا عَائِشَةُ مَا يُؤَمِّنُنِي أَنْ يَكُونَ فِيهِ عَذَابٌ قَدْ عُذِّبَ قَوْمٌ بِالرِّيحِ وَقَدْ رَأَى قَوْمٌ الْعَذَابَ فَقَالُوا هَذَا عَارِضٌ مُمْطِرُنَا ‏"‏ ‏.‏\hadithno{5098}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4828) Sahih Muslim (899)}\hadithtrans{‘A’ishah, wife of the prophet (May peace be upon him), said :I never saw the Messenger of Allah (May peace be upon him) laugh fully to such an extent that I could see his uvula. He would only smile, and when he saw clouds or wind, his face showed signs (of fear). I asked him: Messenger of Allah! When the people see the cloud, they rejoice, hoping for that it may contain rain, and I notice that when you see it, (the signs of) abomination on your face. He replied: ‘A’ishah! What gives me safety from the fact that it might contain punishment? A people were punished by the wind. When those people saw the punishment, they said: this is a cloud which would give us rain}}
\hadithdefcmd{abudawud}{5099}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رَضِيَ اللَّهُ عَنْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَأَى نَاشِئًا فِي أُفُقِ السَّمَاءِ تَرَكَ الْعَمَلَ وَإِنْ كَانَ فِي صَلاَةٍ ثُمَّ يَقُولُ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّهَا ‏"‏ ‏.‏ فَإِنْ مُطِرَ قَالَ ‏"‏ اللَّهُمَّ صَيِّبًا هَنِيئًا ‏"‏ ‏.‏\hadithno{5099}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When the Prophet (ﷺ) saw a cloud formation in the sky, he left work, even if he were at prayer, and then would say: "O Allah! I seek refuge in Thee from its evil. " If it rained, he would say: "O Allah! send a beneficial downpour}}
\hadithdefcmd{abudawud}{5100}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُسَدَّدٌ، - الْمَعْنَى - قَالاَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ أَصَابَنَا وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَطَرٌ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَحَسَرَ ثَوْبَهُ عَنْهُ حَتَّى أَصَابَهُ فَقُلْنَا يَا رَسُولَ اللَّهِ لِمَ صَنَعْتَ هَذَا قَالَ ‏ "‏ لأَنَّهُ حَدِيثُ عَهْدٍ بِرَبِّهِ ‏"‏ ‏.‏\hadithno{5100}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (898)}\hadithtrans{Anas said; A shower of rain fell on us when we were with the Messenger of Allah (May peace be upon him). The Messenger of Allah (May peace be upon him) went out and removed his garment till some of the rain fell on him. We asked him; apostle of Allah! Why did you do this? He replied:Because it has recently been with its Lord}}
\hadithdefcmd{abudawud}{5101}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ زَيْدِ بْنِ خَالِدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا الدِّيكَ فَإِنَّهُ يُوقِظُ لِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{5101}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Zayd ibn Khalid: The Prophet (ﷺ) said: Do not curse the cock, for it awakens for prayer}}
\hadithdefcmd{abudawud}{5102}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ صِيَاحَ الدِّيَكَةِ فَسَلُوا اللَّهَ تَعَالَى مِنْ فَضْلِهِ فَإِنَّهَا رَأَتْ مَلَكًا وَإِذَا سَمِعْتُمْ نَهِيقَ الْحِمَارِ فَتَعَوَّذُوا بِاللَّهِ مِنَ الشَّيْطَانِ فَإِنَّهَا رَأَتْ شَيْطَانًا ‏"‏ ‏.‏\hadithno{5102}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3303) Sahih Muslim (2729)}\hadithtrans{Abu Hurairah reported the Prophet (May peace be upon him) as saying:when you hear the cocks crowing, ask Allah for some of His grace, for they have seen as angel; but when you hear an ass braying, seek refuge in Allah from the devil, for it has seen the devil}}
\hadithdefcmd{abudawud}{5103}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَمِعْتُمْ نُبَاحَ الْكِلاَبِ وَنَهِيقَ الْحُمُرِ بِاللَّيْلِ فَتَعَوَّذُوا بِاللَّهِ فَإِنَّهُنَّ يَرَيْنَ مَا لاَ تَرَوْنَ ‏"‏ ‏.‏\hadithno{5103}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: When you hear the barking of dogs and the braying of asses at night, seek refuge in Allah, for they see which you do not see}}
\hadithdefcmd{abudawud}{5104}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ سَعِيدِ بْنِ زِيَادٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ مَرْوَانَ الدِّمَشْقِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ عَلِيِّ بْنِ عُمَرَ بْنِ حُسَيْنِ بْنِ عَلِيٍّ، وَغَيْرِهِ، قَالاَ قَالَ رَسُولُ اللَّهِ ‏"‏ أَقِلُّوا الْخُرُوجَ بَعْدَ هَدْأَةِ الرِّجْلِ فَإِنَّ لِلَّهِ تَعَالَى دَوَابَّ يَبُثُّهُنَّ فِي الأَرْضِ ‏"‏ ‏.‏ قَالَ ابْنُ مَرْوَانَ ‏"‏ فِي تِلْكَ السَّاعَةِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ فَإِنَّ لِلَّهِ خَلْقًا ‏"‏ ‏.‏ ثُمَّ ذَكَرَ نُبَاحَ الْكَلْبِ وَالْحَمِيرَ نَحْوَهُ وَزَادَ فِي حَدِيثِهِ قَالَ ابْنُ الْهَادِ وَحَدَّثَنِي شُرَحْبِيلُ الْحَاجِبُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{5104}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn Umar ibn Husayn ibn Ali: The Messenger of Allah (ﷺ) as saying: Do not go out much when there are few people about , for Allah the Exalted scatters abroad of His beasts in that hour (according to Ibn Marwan's version). Ibn Marwan's version has: For Allah has creatures. He then mentioned the barking of dogs and braying of asses in a similar manner. He added in his version: Ibn al-Had said: Shurahbil ibn al-Hajib told me on the authority of Jabir ibn Abdullah from the Messenger of Allah (ﷺ) similar to it}}
\hadithdefcmd{abudawud}{5105}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي عَاصِمُ بْنُ عُبَيْدِ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَذَّنَ فِي أُذُنِ الْحَسَنِ بْنِ عَلِيٍّ - حِينَ وَلَدَتْهُ فَاطِمَةُ - بِالصَّلاَةِ ‏.‏\hadithno{5105}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuRafi': I saw the Messenger of Allah (ﷺ) uttering the call to prayer (Adhan) in the ear of al-Hasan ibn Ali when Fatimah gave birth to him}}
\hadithdefcmd{abudawud}{5106}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، ح وَحَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُؤْتَى بِالصِّبْيَانِ فَيَدْعُو لَهُمْ بِالْبَرَكَةِ - زَادَ يُوسُفُ - وَيُحَنِّكُهُمْ وَلَمْ يَذْكُرْ بِالْبَرَكَةِ ‏.‏\hadithno{5106}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (6355) Sahih Muslim (286)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Boys used to be brought to the Messenger of Allah (ﷺ), and he would invoke blessings on them. Yusuf added: "and soften some dates and rub their palates with them". He did not mention "blessings}}
\hadithdefcmd{abudawud}{5107}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي الْوَزِيرِ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِيهِ، عَنْ أُمِّ حُمَيْدٍ، عَنْ عَائِشَةَ، رَضِيَ اللَّهُ عَنْهَا قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ رُئِيَ - أَوْ كَلِمَةً غَيْرَهَا - فِيكُمُ الْمُغَرِّبُونَ ‏"‏ ‏.‏ قُلْتُ وَمَا الْمُغَرِّبُونَ قَالَ ‏"‏ الَّذِينَ يَشْتَرِكُ فِيهِمُ الْجِنُّ ‏"‏ ‏.‏\hadithno{5107}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said to me: Have the mugharribun been seen (or some other word) among you? I asked: What do the mugharribun mean? He replied: They are those in whom is a strain of the jinn}}
\hadithdefcmd{abudawud}{5108}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ الْجُشَمِيُّ، قَالاَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، - قَالَ نَصْرٌ ابْنُ أَبِي عَرُوبَةَ - عَنْ قَتَادَةَ، عَنْ أَبِي نَهِيكٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اسْتَعَاذَ بِاللَّهِ فَأَعِيذُوهُ وَمَنْ سَأَلَكُمْ بِوَجْهِ اللَّهِ فَأَعْطُوهُ ‏"‏ ‏.‏ قَالَ عُبَيْدُ اللَّهِ ‏"‏ مَنْ سَأَلَكُمْ بِاللَّهِ ‏"‏ ‏.‏\hadithno{5108}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone asks (you) for refuge for the sake of Allah, give him refuge; and if anyone asks you (for something) for the pleasure of Allah, give him. Ubaydullah said: If anyone asks you for the sake of Allah}}
\hadithdefcmd{abudawud}{5109}{حَدَّثَنَا مُسَدَّدٌ، وَسَهْلُ بْنُ بَكَّارٍ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، - الْمَعْنَى - عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ اسْتَعَاذَكُمْ بِاللَّهِ فَأَعِيذُوهُ وَمَنْ سَأَلَكُمْ بِاللَّهِ فَأَعْطُوهُ ‏"‏ ‏.‏ وَقَالَ سَهْلٌ وَعُثْمَانُ ‏"‏ وَمَنْ دَعَاكُمْ فَأَجِيبُوهُ ‏"‏ ‏.‏ ثُمَّ اتَّفَقُوا ‏"‏ وَمَنْ آتَى إِلَيْكُمْ مَعْرُوفًا فَكَافِئُوهُ ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ وَعُثْمَانُ ‏"‏ فَإِنْ لَمْ تَجِدُوا فَادْعُوا اللَّهَ لَهُ حَتَّى تَعْلَمُوا أَنْ قَدْ كَافَأْتُمُوهُ ‏"‏ ‏.‏\hadithno{5109}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas reported the Messenger of Allah (May peace be upon him) as saying:If anyone asks you refuge for Allah’s sake give him refuge; and if anyone asks you (for something) for Allah’s sake, give him. Sahl and Sulaiman said: if anyone calls you, respond to him. The Agreed version goes; if you do not afford to compensate him, pray Allah for him until you know that you have compensated him}}
\hadithdefcmd{abudawud}{5110}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عِكْرِمَةُ، - يَعْنِي ابْنَ عَمَّارٍ - قَالَ حَدَّثَنَا أَبُو زُمَيْلٍ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ فَقُلْتُ مَا شَىْءٌ أَجِدُهُ فِي صَدْرِي قَالَ مَا هُوَ قُلْتُ وَاللَّهِ مَا أَتَكَلَّمُ بِهِ ‏.‏ قَالَ فَقَالَ لِي أَشَىْءٌ مِنْ شَكٍّ قَالَ وَضَحِكَ ‏.‏ قَالَ مَا نَجَا مِنْ ذَلِكَ أَحَدٌ - قَالَ - حَتَّى أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ فَإِنْ كُنْتَ فِي شَكٍّ مِمَّا أَنْزَلْنَا إِلَيْكَ فَاسْأَلِ الَّذِينَ يَقْرَءُونَ الْكِتَابَ مِنْ قَبْلِكَ ‏\}‏ الآيَةَ قَالَ فَقَالَ لِي إِذَا وَجَدْتَ فِي نَفْسِكَ شَيْئًا فَقُلْ ‏\{‏ هُوَ الأَوَّلُ وَالآخِرُ وَالظَّاهِرُ وَالْبَاطِنُ وَهُوَ بِكُلِّ شَىْءٍ عَلِيمٌ ‏\}‏\hadithno{5110}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: AbuZumayl said: I asked Ibn Abbas, saying: What is that I find in my breast? He asked: What is it? I replied: I swear by Allah, I cannot speak about it. He asked me: Is it something doubtful? and he laughed. He then said: No one could escape that, until Allah, the exalted, revealed: "If thou went in doubt as to what we have revealed unto thee, and ask those who have been reading the Book from before thee." He said: If you find something in your heart, say: He is the first and the Last, the Evident and the Immanent, and He has full knowledge of all things}}
\hadithdefcmd{abudawud}{5111}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَهُ نَاسٌ مِنْ أَصْحَابِهِ فَقَالُوا يَا رَسُولَ اللَّهِ نَجِدُ فِي أَنْفُسِنَا الشَّىْءَ نُعْظِمُ أَنْ نَتَكَلَّمَ بِهِ أَوِ الْكَلاَمَ بِهِ مَا نُحِبُّ أَنَّ لَنَا وَأَنَّا تَكَلَّمْنَا بِهِ ‏.‏ قَالَ ‏"‏ أَوَقَدْ وَجَدْتُمُوهُ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ ذَاكَ صَرِيحُ الإِيمَانِ ‏"‏ ‏.‏\hadithno{5111}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (132)}\hadithtrans{Abu Hurairah said; His companion came to him and said; Messenger of Allah! We have thoughts which we cannot dare talk about and we do not like that we have them or talk about them. He said:Have you experienced that? They replied: yes. He said : that is clear faith}}
\hadithdefcmd{abudawud}{5112}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَابْنُ، قُدَامَةَ بْنِ أَعْيَنَ قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ ذَرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَحَدَنَا يَجِدُ فِي نَفْسِهِ - يُعَرِّضُ بِالشَّىْءِ - لأَنْ يَكُونَ حُمَمَةً أَحَبُّ إِلَيْهِ مِنْ أَنْ يَتَكَلَّمَ بِهِ فَقَالَ ‏"‏ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ الْحَمْدُ لِلَّهِ الَّذِي رَدَّ كَيْدَهُ إِلَى الْوَسْوَسَةِ ‏"‏ ‏.‏ قَالَ ابْنُ قُدَامَةَ ‏"‏ رَدَّ أَمْرَهُ ‏"‏ ‏.‏ مَكَانَ ‏"‏ رَدَّ كَيْدَهُ ‏"‏ ‏.‏\hadithno{5112}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: A man came to the Prophet (ﷺ) and said: Messenger of Allah! one of us has thoughts of such nature that he would rather be reduced to charcoal than speak about them. He said: Allah is Most Great, Allah is Most Great, Allah is Most Great. Praise be to Allah Who has reduced the guile of the devil to evil prompting. Ibn Qudamah said "reduced his matter" instead of "reduced his guile". Ibn Qudamah said "reduced his matter" instead of "reduced his guile}}
\hadithdefcmd{abudawud}{5113}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، قَالَ حَدَّثَنِي أَبُو عُثْمَانَ، قَالَ حَدَّثَنِي سَعْدُ بْنُ مَالِكٍ، قَالَ سَمِعَتْهُ أُذُنَاىَ، وَوَعَاهُ، قَلْبِي مِنْ مُحَمَّدٍ عَلَيْهِ السَّلاَمُ أَنَّهُ قَالَ ‏ "‏ مَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ وَهُوَ يَعْلَمُ أَنَّهُ غَيْرُ أَبِيهِ فَالْجَنَّةُ عَلَيْهِ حَرَامٌ ‏"‏ ‏.‏ قَالَ فَلَقِيتُ أَبَا بَكْرَةَ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي مِنْ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏ قَالَ عَاصِمٌ فَقُلْتُ يَا أَبَا عُثْمَانَ لَقَدْ شَهِدَ عِنْدَكَ رَجُلاَنِ أَيُّمَا رَجُلَيْنِ ‏.‏ فَقَالَ أَمَّا أَحَدُهُمَا فَأَوَّلُ مَنْ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ أَوْ فِي الإِسْلاَمِ يَعْنِي سَعْدَ بْنَ مَالِكٍ وَالآخَرُ قَدِمَ مِنَ الطَّائِفِ فِي بِضْعَةٍ وَعِشْرِينَ رَجُلاً عَلَى أَقْدَامِهِمْ فَذَكَرَ فَضْلاً ‏.‏ قَالَ أَبُو عَلِيٍّ سَمِعْتُ أَبَا دَاوُدَ قَالَ قَالَ النُّفَيْلِيُّ حَيْثُ حَدَّثَ بِهَذَا الْحَدِيثِ وَاللَّهِ إِنَّهُ عِنْدِي أَحْلَى مِنَ الْعَسَلِ يَعْنِي قَوْلَهُ حَدَّثَنَا وَحَدَّثَنِي قَالَ أَبُو عَلِيٍّ وَسَمِعْتُ أَبَا دَاوُدَ يَقُولُ سَمِعْتُ أَحْمَدَ يَقُولُ لَيْسَ لِحَدِيثِ أَهْلِ الْكُوفَةِ نُورٌ - قَالَ - وَمَا رَأَيْتُ مِثْلَ أَهْلِ الْبَصْرَةِ كَانُوا تَعَلَّمُوهُ مِنْ شُعْبَةَ ‏.‏\hadithno{5113}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4326، 4327) Sahih Muslim (63)}\hadithtrans{Sa’id b. Malik said:My ears heard it end my heart remembered it from Muhammad (May peace be upon him) who said: if a man claims to be the son of a man who is not his father, paradise will be forbidden for him. He said: I then met Abu Bakrah and mentioned it to him. He said: my ears heard it and my heart remembered it from Muhammad (peace be upon him). ‘Asim said : I said : Abu ‘Uthman! Two men testified before you. Who are they? He said : One of them is the one who is first to shoot arrow in the path of Allah or in the path of Islam, that is to say : Sa’d b. Malik. The other is the one came from al-Taif with ten and some men on foot. He then mentioned his excellence. Abu Dawud said : When al-Nufaili mentioned this tradition, he said : I swear by Allah, this is sweater with me than honey, that is no say, his way transmission. Abu ‘Ali said : I heard Abu Dawud say : I heard Ahmad say : The people of Kufah have no light in their traditions. I did not see them like the people of Basrah. They learnt it from Shu’bah}}
\hadithdefcmd{abudawud}{5114}{حَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ عَمْرٍو - حَدَّثَنَا زَائِدَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَوَلَّى قَوْمًا بِغَيْرِ إِذْنِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ يَوْمَ الْقِيَامَةِ عَدْلٌ وَلاَ صَرْفٌ ‏"‏ ‏.‏\hadithno{5114}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1508)}\hadithtrans{Abu Hurairah reported the Prophet (May peace be upon him) as saying :if a man becomes the client of any people without the permission of his patrons (i.e. those who have freed him), on him will be the curse of Allah, of angels and of all people; no obligatory or supererogatory worship will be accepted from him}}
\hadithdefcmd{abudawud}{5115}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ الْوَاحِدِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، - وَنَحْنُ بِبَيْرُوتَ - عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ أَوِ انْتَمَى إِلَى غَيْرِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ الْمُتَتَابِعَةُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5115}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas b. Malik reported the Messenger of Allah (May peace be upon him) as saying:If anyone pretends to be the son of a man other than his father, or attributes his freedom to people other than those who set him free, on him will be the curse of Allah that will continue till the day of resurrection}}
\hadithdefcmd{abudawud}{5116}{حَدَّثَنَا مُوسَى بْنُ مَرْوَانَ الرَّقِّيُّ، حَدَّثَنَا الْمُعَافَى، ح وَحَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، - وَهَذَا حَدِيثُهُ - عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ أَذْهَبَ عَنْكُمْ عُبِّيَّةَ الْجَاهِلِيَّةِ وَفَخْرَهَا بِالآبَاءِ مُؤْمِنٌ تَقِيٌّ وَفَاجِرٌ شَقِيٌّ أَنْتُمْ بَنُو آدَمَ وَآدَمُ مِنْ تُرَابٍ لَيَدَعَنَّ رِجَالٌ فَخْرَهُمْ بِأَقْوَامٍ إِنَّمَا هُمْ فَحْمٌ مِنْ فَحْمِ جَهَنَّمَ أَوْ لَيَكُونُنَّ أَهْوَنَ عَلَى اللَّهِ مِنَ الْجِعْلاَنِ الَّتِي تَدْفَعُ بِأَنْفِهَا النَّتْنَ ‏"‏ ‏.‏\hadithno{5116}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Allah, Most High, has removed from you the pride of the pre-Islamic period and its boasting in ancestors. One is only a pious believer or a miserable sinner. You are sons of Adam, and Adam came from dust. Let the people cease to boast about their ancestors. They are merely fuel in Jahannam; or they will certainly be of less account with Allah than the beetle which rolls dung with its nose}}
\hadithdefcmd{abudawud}{5117}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنْ أَبِيهِ، قَالَ مَنْ نَصَرَ قَوْمَهُ عَلَى غَيْرِ الْحَقِّ فَهُوَ كَالْبَعِيرِ الَّذِي رُدِّيَ فَهُوَ يُنْزَعُ بِذَنَبِهِ ‏.‏\hadithno{5117}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Mas'ud: If anyone helps his people in an unrighteous cause, he is like a camel which falls into a well and is pulled out by its tail}}
\hadithdefcmd{abudawud}{5118}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ انْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ فِي قُبَّةٍ مِنْ أَدَمٍ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{5118}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Abd Allah b. Mas’ud said :I went to the prophet (May peace be upon him) when he was in a skin tent. He then mentioned something similar to it}}
\hadithdefcmd{abudawud}{5119}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، حَدَّثَنَا الْفِرْيَابِيُّ، حَدَّثَنَا سَلَمَةُ بْنُ بِشْرٍ الدِّمَشْقِيُّ، عَنْ بِنْتِ وَاثِلَةَ بْنِ الأَسْقَعِ، أَنَّهَا سَمِعَتْ أَبَاهَا، يَقُولُ قُلْتُ يَا رَسُولَ اللَّهِ مَا الْعَصَبِيَّةُ قَالَ ‏ "‏ أَنْ تُعِينَ قَوْمَكَ عَلَى الظُّلْمِ ‏"‏ ‏.‏\hadithno{5119}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Wathilah ibn al-Asqa': I asked: Messenger of Allah! what is party spirit? He replied: That you should help your people in wrongdoing}}
\hadithdefcmd{abudawud}{5120}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا أَيُّوبُ بْنُ سُوَيْدٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يُحَدِّثُ عَنْ سُرَاقَةَ بْنِ مَالِكِ بْنِ جُعْشُمٍ الْمُدْلِجِيِّ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ خَيْرُكُمُ الْمُدَافِعُ عَنْ عَشِيرَتِهِ مَا لَمْ يَأْثَمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَيُّوبُ بْنُ سُوَيْدٍ ضَعِيفٌ ‏.‏\hadithno{5120}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Suraqah ibn Malik ibn Ju'sham al-Mudlaji: The Messenger of Allah (ﷺ) gave us an address and said: The best of you is the one who defends his tribe, so long as he commits no sin. Abu Dawud said: Abu Ayyub b. Suwaid is weak}}
\hadithdefcmd{abudawud}{5121}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الْمَكِّيِّ، - يَعْنِي ابْنَ أَبِي لَبِيبَةَ - عَنْ عَبْدِ اللَّهِ بْنِ أَبِي سُلَيْمَانَ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنَّا مَنْ دَعَا إِلَى عَصَبِيَّةٍ وَلَيْسَ مِنَّا مَنْ قَاتَلَ عَلَى عَصَبِيَّةٍ وَلَيْسَ مِنَّا مَنْ مَاتَ عَلَى عَصَبِيَّةٍ ‏"‏ ‏.‏\hadithno{5121}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jubair b. Mut’im reported the Messenger of Allah (May peace be upon him) as saying:he who summons others to party-spirit does not belong to us; and he who dies upholding party spirit does not belong to us.’}}
\hadithdefcmd{abudawud}{5122}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَوْفٍ، عَنْ زِيَادِ بْنِ مِخْرَاقٍ، عَنْ أَبِي كِنَانَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ابْنُ أُخْتِ الْقَوْمِ مِنْهُمْ ‏"‏ ‏.‏\hadithno{5122}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Musa reported the Messenger of Allah (May peace be upon him) as saying:the son of a sister of a people belongs to them}}
\hadithdefcmd{abudawud}{5123}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ دَاوُدَ بْنِ حُصَيْنٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عُقْبَةَ، عَنْ أَبِي عُقْبَةَ، - وَكَانَ مَوْلًى مِنْ أَهْلِ فَارِسَ - قَالَ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم أُحُدًا فَضَرَبْتُ رَجُلاً مِنَ الْمُشْرِكِينَ فَقُلْتُ خُذْهَا مِنِّي وَأَنَا الْغُلاَمُ الْفَارِسِيُّ فَالْتَفَتَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ فَهَلاَّ قُلْتَ خُذْهَا مِنِّي وَأَنَا الْغُلاَمُ الأَنْصَارِيُّ ‏"‏ ‏.‏\hadithno{5123}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuUqbah: AbdurRahman ibn AbuUqbah quoted his father AbuUqbah who was a client from the people of Persia as saying: I was present at Uhud along with the Messenger of Allah (ﷺ), and on smiting one of the polytheists I said: Take this from me who is the young Persian. The Messenger of Allah (ﷺ) then turned to me and said: Why did you not say: Take this from me who is the young Ansari?}}
\hadithdefcmd{abudawud}{5124}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ ثَوْرٍ، قَالَ حَدَّثَنِي حَبِيبُ بْنُ عُبَيْدٍ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، - وَقَدْ كَانَ أَدْرَكَهُ - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَحَبَّ الرَّجُلُ أَخَاهُ فَلْيُخْبِرْهُ أَنَّهُ يُحِبُّهُ ‏"‏ ‏.‏\hadithno{5124}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Miqdam ibn Ma'dikarib: The Prophet (ﷺ) said: When a man loves his brother, he should tell him that he loves him}}
\hadithdefcmd{abudawud}{5125}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْمُبَارَكُ بْنُ فَضَالَةَ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، كَانَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَمَرَّ بِهِ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي لأُحِبُّ هَذَا ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَعْلَمْتَهُ ‏"‏ ‏.‏ قَالَ لاَ قَالَ ‏"‏ أَعْلِمْهُ ‏"‏ ‏.‏ قَالَ فَلَحِقَهُ فَقَالَ إِنِّي أُحِبُّكَ فِي اللَّهِ ‏.‏ فَقَالَ أَحَبَّكَ الَّذِي أَحْبَبْتَنِي لَهُ ‏.‏\hadithno{5125}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: A man was with the Prophet (ﷺ) and a man passed by him and said: Messenger of Allah! I love this man. The Messenger of Allah (ﷺ) then asked: Have you informed him? He replied: No. He said: Inform him. He then went to him and said: I love you for Allah's sake. He replied: May He for Whose sake you love me love you}}
\hadithdefcmd{abudawud}{5126}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُلَيْمَانُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ الرَّجُلُ يُحِبُّ الْقَوْمَ وَلاَ يَسْتَطِيعُ أَنْ يَعْمَلَ كَعَمَلِهِمْ ‏.‏ قَالَ ‏"‏ أَنْتَ يَا أَبَا ذَرٍّ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏ قَالَ فَإِنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ ‏.‏ قَالَ ‏"‏ فَإِنَّكَ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏ قَالَ فَأَعَادَهَا أَبُو ذَرٍّ فَأَعَادَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5126}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Abd Allah b. al-samit told that Abu Dharr said :Messenger of Allah! A man loves some people, but he cannot do work like their work. He replied; Yes, Abu Dharr, will be with those whom you love. Abu Dharr then repeated it. The Messenger of Allah (May peace be upon him) also repeated it}}
\hadithdefcmd{abudawud}{5127}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، حَدَّثَنَا خَالِدٌ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرِحُوا بِشَىْءٍ لَمْ أَرَهُمْ فَرِحُوا بِشَىْءٍ أَشَدَّ مِنْهُ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ الرَّجُلُ يُحِبُّ الرَّجُلَ عَلَى الْعَمَلِ مِنَ الْخَيْرِ يَعْمَلُ بِهِ وَلاَ يَعْمَلُ بِمِثْلِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَرْءُ مَعَ مَنْ أَحَبَّ ‏"‏ ‏.‏\hadithno{5127}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas b. Malik said :I never saw the Companions of the Messenger of Allah (May peace be upon him) so happy about anything as I saw them happy about this thing. A man said : Messenger of Allah! A man loves another man for the good work which he does, but he himself cannot do like it. The Messenger of Allah (May peace be upon him) said: A man will be with those whom he loves}}
\hadithdefcmd{abudawud}{5128}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا شَيْبَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُسْتَشَارُ مُؤْتَمَنٌ ‏"‏ ‏.‏\hadithno{5128}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: He who is consulted is trustworthy}}
\hadithdefcmd{abudawud}{5129}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أُبْدِعَ بِي فَاحْمِلْنِي ‏.‏ قَالَ ‏"‏ لاَ أَجِدُ مَا أَحْمِلُكَ عَلَيْهِ وَلَكِنِ ائْتِ فُلاَنًا فَلَعَلَّهُ أَنْ يَحْمِلَكَ ‏"‏ ‏.‏ فَأَتَاهُ فَحَمَلَهُ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ دَلَّ عَلَى خَيْرٍ فَلَهُ مِثْلُ أَجْرِ فَاعِلِهِ ‏"‏ ‏.‏\hadithno{5129}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1893)}\hadithtrans{Abu Mas’ud al-Ansari said :A man came to the prophet (May peace be upon him) and said: Messenger of Allah! I have been left without a mount. So give me a mount. He replied: I have no mount to give, but go to so and so; he may perhaps give you a mount. He then went to him and he gave him a mount. He came to the Messenger of Allah (May peace be upon him) and informed him about it. Thereupon the Messenger of Allah (May peace be upon him) said: if anyone guides someone to a good (deed), he will get the reward like the reward of the one who does it}}
\hadithdefcmd{abudawud}{5130}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، حَدَّثَنَا بَقِيَّةُ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مَرْيَمَ، عَنْ خَالِدِ بْنِ مُحَمَّدٍ الثَّقَفِيِّ، عَنْ بِلاَلِ بْنِ أَبِي الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ حُبُّكَ الشَّىْءَ يُعْمِي وَيُصِمُّ ‏"‏ ‏.‏\hadithno{5130}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbudDarda': The Prophet (ﷺ) said: Your love for a thing causes blindness and deafness}}
\hadithdefcmd{abudawud}{5131}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ بُرَيْدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْفَعُوا إِلَىَّ لِتُؤْجَرُوا وَلْيَقْضِ اللَّهُ عَلَى لِسَانِ نَبِيِّهِ مَا شَاءَ ‏"‏ ‏.‏\hadithno{5131}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6027) Sahih Muslim (2627)}\hadithtrans{Abu Musa reported the Messenger of Allah (May peace be upon him) as saying:Make intercession to me, you will be rewarded, for Allah decrees what he wishes by the tongue of his prophet}}
\hadithdefcmd{abudawud}{5132}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَأَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ أَخِيهِ، عَنْ مُعَاوِيَةَ، اشْفَعُوا تُؤْجَرُوا فَإِنِّي لأُرِيدُ الأَمْرَ فَأُؤَخِّرُهُ كَيْمَا تَشْفَعُوا فَتُؤْجَرُوا فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اشْفَعُوا تُؤْجَرُوا ‏"‏ ‏.‏\hadithno{5132}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Mu'awiyah: Make intercession, you will be rewarded, for I purposely delay a matter so that you intercede and then you are rewarded. The Messenger of Allah (ﷺ) said: If you make intercession, you will be rewarded}}
\hadithdefcmd{abudawud}{5133}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{5133}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{A similar tradition has also been transmitted by Abu Musa from the prophet (May peace be upon him) through a different chain of narrators}}
\hadithdefcmd{abudawud}{5134}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ مَنْصُورٍ، عَنِ ابْنِ سِيرِينَ، - قَالَ أَحْمَدُ قَالَ مَرَّةً يَعْنِي هُشَيْمًا - عَنْ بَعْضِ وَلَدِ الْعَلاَءِ أَنَّ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ كَانَ عَامِلَ النَّبِيِّ صلى الله عليه وسلم عَلَى الْبَحْرَيْنِ فَكَانَ إِذَا كَتَبَ إِلَيْهِ بَدَأَ بِنَفْسِهِ ‏.‏\hadithno{5134}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated al-Ala' ibn al-Hadrami: Some of the children of al-Ala' ibn al-Hadrami said: Al-Ala' ibn al-Hadrami was the governor of the Prophet (ﷺ) at al-Bahrayn, and when he wrote to him he began with his won name}}
\hadithdefcmd{abudawud}{5135}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا الْمُعَلَّى بْنُ مَنْصُورٍ، أَخْبَرَنَا هُشَيْمٌ، عَنْ مَنْصُورٍ، عَنِ ابْنِ سِيرِينَ، عَنِ ابْنِ الْعَلاَءِ، عَنِ الْعَلاَءِ، - يَعْنِي ابْنَ الْحَضْرَمِيِّ - أَنَّهُ كَتَبَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَبَدَأَ بِاسْمِهِ ‏.‏\hadithno{5135}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn al-Ala said :Al-Ala b. al-Hadrami wrote to the prophet (May peace be upon him), and he began with his name}}
\hadithdefcmd{abudawud}{5136}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَتَبَ إِلَى هِرَقْلَ ‏"‏ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ إِلَى هِرَقْلَ عَظِيمِ الرُّومِ سَلاَمٌ عَلَى مَنِ اتَّبَعَ الْهُدَى ‏"‏ ‏.‏ قَالَ ابْنُ يَحْيَى عَنِ ابْنِ عَبَّاسٍ أَنَّ أَبَا سُفْيَانَ أَخْبَرَهُ قَالَ فَدَخَلْنَا عَلَى هِرَقْلَ فَأَجْلَسَنَا بَيْنَ يَدَيْهِ ثُمَّ دَعَا بِكِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا فِيهِ ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ إِلَى هِرَقْلَ عَظِيمِ الرُّومِ سَلاَمٌ عَلَى مَنِ اتَّبَعَ الْهُدَى أَمَّا بَعْدُ ‏"‏ ‏.‏\hadithno{5136}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7) Sahih Muslim (1773)}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) wrote a letter to Heraclius: "From Muhammad, the Messenger of Allah, to Hiraql (Heraclius), Chief of the Byzantines. Peace be to those who follow the guidance." Ibn Yahya reported on the authority of Ibn Abbas that AbuSufyan said to him: We then came to see Hiraql (Heraclius) who seated us before him. He then called for the letter from the Messenger of Allah (ﷺ). Its contents were: "In the name of Allah, the Compassionate, the Merciful, from Muhammad the Messenger of Allah, to Hiraql, chief of Byzantines. Peace be to those who follow the guidance. To proceed}}
\hadithdefcmd{abudawud}{5137}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، قَالَ حَدَّثَنِي سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَجْزِي وَلَدٌ وَالِدَهُ إِلاَّ أَنْ يَجِدَهُ مَمْلُوكًا فَيَشْتَرِيَهُ فَيُعْتِقَهُ ‏"‏ ‏.‏\hadithno{5137}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1510)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:A son does not repay what he owes to his father unless he buys him and emancipates him if he finds him in slavery}}
\hadithdefcmd{abudawud}{5138}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ أَبِي ذِئْبٍ، قَالَ حَدَّثَنِي خَالِي الْحَارِثُ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ كَانَتْ تَحْتِي امْرَأَةٌ وَكُنْتُ أُحِبُّهَا وَكَانَ عُمَرُ يَكْرَهُهَا فَقَالَ لِي طَلِّقْهَا فَأَبَيْتُ فَأَتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ طَلِّقْهَا ‏"‏ ‏.‏\hadithno{5138}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: A woman was my wife and I loved her, but Umar hated her. He said to me: Divorce her, but I refused. Umar then went to the Prophet (ﷺ) and mentioned that to him. The Prophet (ﷺ) said: Divorce her}}
\hadithdefcmd{abudawud}{5139}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَنْ أَبَرُّ قَالَ ‏"‏ أُمَّكَ ثُمَّ أُمَّكَ ثُمَّ أُمَّكَ ثُمَّ أَبَاكَ ثُمَّ الأَقْرَبَ فَالأَقْرَبَ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَسْأَلُ رَجُلٌ مَوْلاَهُ مِنْ فَضْلٍ هُوَ عِنْدَهُ فَيَمْنَعُهُ إِيَّاهُ إِلاَّ دُعِيَ لَهُ يَوْمَ الْقِيَامَةِ فَضْلُهُ الَّذِي مَنَعَهُ شُجَاعًا أَقْرَعَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الأَقْرَعُ الَّذِي ذَهَبَ شَعْرُ رَأْسِهِ مِنَ السُّمِّ ‏.‏\hadithno{5139}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Bahz b. Hakim on his father's authority said that his grandfather said:I said: Messenger of Allah! to whom should I show kindness? He replied: Your mother, next your mother, next your mother, and then comes your father, and then your relatives in order of relationship. The Messenger of Allah (ﷺ) said: If a man asks his slave whom he freed for giving him property which is surplus with him and he refuses to give it to him, the surplus property which he refused to give will be called on the Day of resurrection as a large bald snake. Abu Dawud said: Aqra' means a snake whose hair of the head were removed on account of poison}}
\hadithdefcmd{abudawud}{5140}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا الْحَارِثُ بْنُ مُرَّةَ، حَدَّثَنَا كُلَيْبُ بْنُ مَنْفَعَةَ، عَنْ جَدِّهِ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَنْ أَبَرُّ قَالَ ‏ "‏ أُمَّكَ وَأَبَاكَ وَأُخْتَكَ وَأَخَاكَ وَمَوْلاَكَ الَّذِي يَلِي ذَاكَ حَقٌّ وَاجِبٌ وَرَحِمٌ مَوْصُولَةٌ ‏"‏ ‏.‏\hadithno{5140}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif}\hadithtrans{Kulaib b. Manfa'ah said that his grandfather told then he went to the Prophet (ﷺ) and said:Messenger of Allah! to whom should I show kindness? He said: Your mother, your sister, your brother and the slave whom you set free and who is your relative, a due binding (on you), and a tie of relationship which should be joined}}
\hadithdefcmd{abudawud}{5141}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ، وَقَالَ، أَخْبَرَنَا ح، وَحَدَّثَنَا عَبَّادُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ أَكْبَرِ الْكَبَائِرِ أَنْ يَلْعَنَ الرَّجُلُ وَالِدَيْهِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ كَيْفَ يَلْعَنُ الرَّجُلُ وَالِدَيْهِ قَالَ ‏"‏ يَلْعَنُ أَبَا الرَّجُلِ فَيَلْعَنُ أَبَاهُ وَيَلْعَنُ أُمَّهُ فَيَلْعَنُ أُمَّهُ ‏"‏ ‏.‏\hadithno{5141}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5973) Sahih Muslim (90)}\hadithtrans{‘Abd Allah b. ‘Amr (b. al-As) reported the Messenger of Allah (May peace be upon him) as saying:A man’s reviling of his parents is one of the grave sins. He was asked : Messenger of Allah! How does a man revile his parents? He replied: He reviles the father of a man who then reviles his father, and he reviles a man’s mother and he reviles his}}
\hadithdefcmd{abudawud}{5142}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مَهْدِيٍّ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، - الْمَعْنَى - قَالُوا حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سُلَيْمَانَ، عَنْ أَسِيدِ بْنِ عَلِيِّ بْنِ عُبَيْدٍ، مَوْلَى بَنِي سَاعِدَةَ عَنْ أَبِيهِ، عَنْ أَبِي أُسَيْدٍ، مَالِكِ بْنِ رَبِيعَةَ السَّاعِدِيِّ قَالَ بَيْنَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا جَاءَهُ رَجُلٌ مِنْ بَنِي سَلِمَةَ فَقَالَ يَا رَسُولَ اللَّهِ هَلْ بَقِيَ مِنْ بِرِّ أَبَوَىَّ شَىْءٌ أَبَرُّهُمَا بِهِ بَعْدَ مَوْتِهِمَا قَالَ ‏ "‏ نَعَمِ الصَّلاَةُ عَلَيْهِمَا وَالاِسْتِغْفَارُ لَهُمَا وَإِنْفَاذُ عَهْدِهِمَا مِنْ بَعْدِهِمَا وَصِلَةُ الرَّحِمِ الَّتِي لاَ تُوصَلُ إِلاَّ بِهِمَا وَإِكْرَامُ صَدِيقِهِمَا ‏"‏ ‏.‏\hadithno{5142}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuUsayd Malik ibn Rabi'ah as-Sa'idi: While we were with the Messenger of Allah! (ﷺ) a man of Banu Salmah came to Him and said: Messenger of Allah is there any kindness left that I can do to my parents after their death? He replied: Yes, you can invoke blessings on them, forgiveness for them, carry out their final instructions after their death, join ties of relationship which are dependent on them, and honour their friends}}
\hadithdefcmd{abudawud}{5143}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَبَرَّ الْبِرِّ صِلَةُ الْمَرْءِ أَهْلَ وُدِّ أَبِيهِ بَعْدَ أَنْ يُوَلِّيَ ‏"‏ ‏.‏\hadithno{5143}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2552)}\hadithtrans{Ibn ‘Umar reported the Messenger of Allah (May peace be upon him) as saying:One of the finest acts of kindness is for a man to treat his father’s friends in a kindly way after he has departed}}
\hadithdefcmd{abudawud}{5144}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ يَحْيَى بْنِ عُمَارَةَ بْنِ ثَوْبَانَ، أَخْبَرَنَا عُمَارَةُ بْنُ ثَوْبَانَ، أَنَّ أَبَا الطُّفَيْلِ، أَخْبَرَهُ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَقْسِمُ لَحْمًا بِالْجِعِرَّانَةِ - قَالَ أَبُو الطُّفَيْلِ وَأَنَا يَوْمَئِذٍ غُلاَمٌ أَحْمِلُ عَظْمَ الْجَزُورِ - إِذْ أَقْبَلَتِ امْرَأَةٌ حَتَّى دَنَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَبَسَطَ لَهَا رِدَاءَهُ فَجَلَسَتْ عَلَيْهِ فَقُلْتُ مَنْ هِيَ فَقَالُوا هَذِهِ أُمُّهُ الَّتِي أَرْضَعَتْهُ ‏.‏\hadithno{5144}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbutTufayl: I saw the Prophet (ﷺ) distributing flesh at Ji'irranah, and I was a boy in those days bearing the bone of the camel, and when a woman who came forward approach the Prophet (ﷺ), he spread out his cloak for her, and she sat on it. I asked: Who is she? The people said: She is his foster-mother}}
\hadithdefcmd{abudawud}{5145}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ عُمَرَ بْنَ السَّائِبِ، حَدَّثَهُ أَنَّهُ، بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ جَالِسًا يَوْمًا فَأَقْبَلَ أَبُوهُ مِنَ الرَّضَاعَةِ فَوَضَعَ لَهُ بَعْضَ ثَوْبِهِ فَقَعَدَ عَلَيْهِ ثُمَّ أَقْبَلَتْ أُمُّهُ فَوَضَعَ لَهَا شِقَّ ثَوْبِهِ مِنْ جَانِبِهِ الآخَرِ فَجَلَسَتْ عَلَيْهِ ثُمَّ أَقْبَلَ أَخُوهُ مِنَ الرَّضَاعَةِ فَقَامَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَجْلَسَهُ بَيْنَ يَدَيْهِ ‏.‏\hadithno{5145}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn as-Sa'ib: One day when the Messenger of Allah (ﷺ) was sitting, his foster-father came forward. He spread out of a part of his garment and he sit on it. Then his mother came forward to him and he spread out the other side of his garment and she sat on it. Again , his foster-brother came forward. The Messenger of Allah (ﷺ) stood for him and seated him before himself}}
\hadithdefcmd{abudawud}{5146}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنِ ابْنِ حُدَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أُنْثَى فَلَمْ يَئِدْهَا وَلَمْ يُهِنْهَا وَلَمْ يُؤْثِرْ وَلَدَهُ عَلَيْهَا - قَالَ يَعْنِي الذُّكُورَ - أَدْخَلَهُ اللَّهُ الْجَنَّةَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ عُثْمَانُ يَعْنِي الذُّكُورَ ‏.‏\hadithno{5146}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone has a female child, and does not bury her alive, or slight her, or prefer his children (i.e. the male ones) to her, Allah will bring him into Paradise. Uthman did not mention "male children}}
\hadithdefcmd{abudawud}{5147}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا سُهَيْلٌ، - يَعْنِي ابْنَ أَبِي صَالِحٍ - عَنْ سَعِيدٍ الأَعْشَى، - قَالَ أَبُو دَاوُدَ وَهُوَ سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مُكْمِلٍ الزُّهْرِيُّ - عَنْ أَيُّوبَ بْنِ بَشِيرٍ الأَنْصَارِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَالَ ثَلاَثَ بَنَاتٍ فَأَدَّبَهُنَّ وَزَوَّجَهُنَّ وَأَحْسَنَ إِلَيْهِنَّ فَلَهُ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{5147}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: If anyone cares for three daughters, disciplines them, marries them, and does good to them, he will go to Paradise}}
\hadithdefcmd{abudawud}{5148}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ بِمَعْنَاهُ قَالَ ‏ "‏ ثَلاَثُ أَخَوَاتٍ أَوْ ثَلاَثُ بَنَاتٍ أَوْ بِنْتَانِ أَوْ أُخْتَانِ ‏"‏ ‏.‏\hadithno{5148}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Suhail through a different chain of narrators to the same effect. This version has :“three sisters, or three daughter, or two daughter, or two sisters”}}
\hadithdefcmd{abudawud}{5149}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا النَّهَّاسُ بْنُ قَهْمٍ، قَالَ حَدَّثَنِي شَدَّادٌ أَبُو عَمَّارٍ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنَا وَامْرَأَةٌ سَفْعَاءُ الْخَدَّيْنِ كَهَاتَيْنِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَأَوْمَأَ يَزِيدُ بِالْوُسْطَى وَالسَّبَّابَةِ ‏"‏ امْرَأَةٌ آمَتْ مِنْ زَوْجِهَا ذَاتُ مَنْصِبٍ وَجَمَالٍ حَبَسَتْ نَفْسَهَا عَلَى يَتَامَاهَا حَتَّى بَانُوا أَوْ مَاتُوا ‏"‏ ‏.‏\hadithno{5149}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Awf ibn Malik al-Ashja'i': The Prophet (ﷺ) said: I and a woman whose cheeks have become black shall on the Day of Resurrection be like these two (pointing to the middle and forefinger), i.e. a woman of rank and beauty who has been bereft of her husband and devotes herself to her fatherless children till they go their separate ways or die}}
\hadithdefcmd{abudawud}{5150}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ أَبِي حَازِمٍ - قَالَ حَدَّثَنِي أَبِي، عَنْ سَهْلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَنَا وَكَافِلُ الْيَتِيمِ كَهَاتَيْنِ فِي الْجَنَّةِ ‏"‏ ‏.‏ وَقَرَنَ بَيْنَ أُصْبُعَيْهِ الْوُسْطَى وَالَّتِي تَلِي الإِبْهَامَ ‏.‏\hadithno{5150}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6005)}\hadithtrans{Sahl (b. Sa’d) reported the prophet (May peace be upon him) as saying; I and the one who takes the responsibility of an orphan will be in Paradise thus, and he joined his middle finger and forefinger}}
\hadithdefcmd{abudawud}{5151}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا زَالَ جِبْرِيلُ يُوصِينِي بِالْجَارِ حَتَّى قُلْتُ لَيُوَرِّثَنَّهُ ‏"‏ ‏.‏\hadithno{5151}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6014) Sahih Muslim (2624)}\hadithtrans{‘A’ishah reported the Messenger of Allah (May peace be upon him) as saying:Gabriel kept on commending the neighbor to me so that I thought he would make him an heir}}
\hadithdefcmd{abudawud}{5152}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا سُفْيَانُ، عَنْ بَشِيرٍ أَبِي إِسْمَاعِيلَ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّهُ ذَبَحَ شَاةً فَقَالَ أَهْدَيْتُمْ لِجَارِي الْيَهُودِيِّ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا زَالَ جِبْرِيلُ يُوصِينِي بِالْجَارِ حَتَّى ظَنَنْتُ أَنَّهُ سَيُوَرِّثُهُ ‏"‏ ‏.‏\hadithno{5152}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: Mujahid said that Abdullah ibn Amr slaughtered a sheep and said: Have you presented a gift from it to my neighbour, the Jew, for I heard the Messenger of Allah (ﷺ) say: Gabriel kept on commending the neighbour to me so that I thought he would make an heir?}}
\hadithdefcmd{abudawud}{5153}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَيَّانَ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم يَشْكُو جَارَهُ فَقَالَ ‏"‏ اذْهَبْ فَاصْبِرْ ‏"‏ ‏.‏ فَأَتَاهُ مَرَّتَيْنِ أَوْ ثَلاَثًا فَقَالَ ‏"‏ اذْهَبْ فَاطْرَحْ مَتَاعَكَ فِي الطَّرِيقِ ‏"‏ ‏.‏ فَطَرَحَ مَتَاعَهُ فِي الطَّرِيقِ فَجَعَلَ النَّاسُ يَسْأَلُونَهُ فَيُخْبِرُهُمْ خَبَرَهُ فَجَعَلَ النَّاسُ يَلْعَنُونَهُ فَعَلَ اللَّهُ بِهِ وَفَعَلَ وَفَعَلَ فَجَاءَ إِلَيْهِ جَارُهُ فَقَالَ لَهُ ارْجِعْ لاَ تَرَى مِنِّي شَيْئًا تَكْرَهُهُ ‏.‏\hadithno{5153}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said :A man came to the prophet (May peace be upon him) complaining against his neighbor. He said: go and have patience. He again came to him twice or thrice. He then said : Go and throw your property in the way. So he threw his property in the way and the people began to ask him and he would tell them about him. The people then began to curse him; may Allah do with him so and so! Then his neighbor came to him and said: Return, you will not see from me anything which you dislike}}
\hadithdefcmd{abudawud}{5154}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يُؤْذِ جَارَهُ - وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا أَوْ لِيَصْمُتْ ‏"‏ ‏.‏\hadithno{5154}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6138) Sahih Muslim (47)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:He who believes in Allah and in the last day should honour his guest; he who believes in Allah and in the last day should not harm his neighbor; he who believes in Allah and in the last day should speak good or keep silence}}
\hadithdefcmd{abudawud}{5155}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، وَسَعِيدُ بْنُ مَنْصُورٍ، أَنَّ الْحَارِثَ بْنَ عُبَيْدٍ، حَدَّثَهُمْ عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ طَلْحَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لِي جَارَيْنِ بِأَيِّهِمَا أَبْدَأُ قَالَ ‏ "‏ بِأَدْنَاهُمَا بَابًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ شُعْبَةُ فِي هَذَا الْحَدِيثِ طَلْحَةُ رَجُلٌ مِنْ قُرَيْشٍ ‏.‏\hadithno{5155}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1661)}\hadithtrans{‘A’ishah said:I asked : apostle of Allah! I have two neighbors. With which of them should I begin? He replied: Begin with the one whose door is nearer to you. Abu Dawud said: Shu’bah said this tradition : Talhah is a man of the Quraish}}
\hadithdefcmd{abudawud}{5156}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنْ مُغِيرَةَ، عَنْ أُمِّ مُوسَى، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ قَالَ كَانَ آخِرُ كَلاَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصَّلاَةَ الصَّلاَةَ اتَّقُوا اللَّهَ فِيمَا مَلَكَتْ أَيْمَانُكُمْ ‏"‏ ‏.‏\hadithno{5156}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi}\hadithtrans{Narrated Ali ibn AbuTalib: The last words which the Messenger of Allah (ﷺ) spoke were: Prayer, prayer; fear Allah about those whom your right hands possess}}
\hadithdefcmd{abudawud}{5157}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، قَالَ رَأَيْتُ أَبَا ذَرٍّ بِالرَّبَذَةِ وَعَلَيْهِ بُرْدٌ غَلِيظٌ وَعَلَى غُلاَمِهِ مِثْلُهُ قَالَ فَقَالَ الْقَوْمُ يَا أَبَا ذَرٍّ لَوْ كُنْتَ أَخَذْتَ الَّذِي عَلَى غُلاَمِكَ فَجَعَلْتَهُ مَعَ هَذَا فَكَانَتْ حُلَّةً وَكَسَوْتَ غُلاَمَكَ ثَوْبًا غَيْرَهُ ‏.‏ قَالَ فَقَالَ أَبُو ذَرٍّ إِنِّي كُنْتُ سَابَبْتُ رَجُلاً وَكَانَتْ أُمُّهُ أَعْجَمِيَّةً فَعَيَّرْتُهُ بِأُمِّهِ فَشَكَانِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ إِنَّكَ امْرُؤٌ فِيكَ جَاهِلِيَّةٌ ‏"‏ ‏.‏ قَالَ ‏"‏ إِنَّهُمْ إِخْوَانُكُمْ فَضَّلَكُمُ اللَّهُ عَلَيْهِمْ فَمَنْ لَمْ يُلاَئِمْكُمْ فَبِيعُوهُ وَلاَ تُعَذِّبُوا خَلْقَ اللَّهِ ‏"‏ ‏.‏\hadithno{5157}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Ma’rur b. Suwaid said :I saw Abu Dharr at Rabadhah. He was wearing a thick cloak, and his slave also wore a similar one. He said : the people said: Abu Dharr! (it would be better) if you could take the cloak which your slave wore, and you combined that with, and it would be a pair of garments (hullah) and you would clothe him with another garment. He said: Abu Dharr said : I abused a man whose mother was a non-Arab and I reviled him for his mother. He complained against me to the apostle of allah (May peace be upon him). He said: Abu Dharr! You are a man who has a characteristic of pre-Islamic days. He said: they are your brethren; Allah has given you superiority over them; sell those who do not please you and do not punish Allah’s creatures}}
\hadithdefcmd{abudawud}{5158}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، قَالَ دَخَلْنَا عَلَى أَبِي ذَرٍّ بِالرَّبَذَةِ فَإِذَا عَلَيْهِ بُرْدٌ وَعَلَى غُلاَمِهِ مِثْلُهُ فَقُلْنَا يَا أَبَا ذَرٍّ لَوْ أَخَذْتَ بُرْدَ غُلاَمِكَ إِلَى بُرْدِكَ فَكَانَتْ حُلَّةً وَكَسَوْتَهُ ثَوْبًا غَيْرَهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِخْوَانُكُمْ جَعَلَهُمُ اللَّهُ تَحْتَ أَيْدِيكُمْ فَمَنْ كَانَ أَخُوهُ تَحْتَ يَدَيْهِ فَلْيُطْعِمْهُ مِمَّا يَأْكُلُ وَلْيَكْسُهُ مِمَّا يَلْبَسُ وَلاَ يُكَلِّفْهُ مَا يَغْلِبُهُ فَإِنْ كَلَّفَهُ مَا يَغْلِبُهُ فَلْيُعِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ ابْنُ نُمَيْرٍ عَنِ الأَعْمَشِ نَحْوَهُ ‏.‏\hadithno{5158}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{Ma’rur b. Suwaid said :We called on Abu Dharr at al-Rabadhah. He wore a cloak and his slave also wore a similar one. We said; Abu Dharr! If you took the cloak of your slave and combined it with your cloak, so that it could be a part of garments (hullah) and clothed him in another garment, (it would be better). He said; I heard the Messenger of Allah (May peace be upon him) say; They are your brethren. Allah has put them under your authority; so he who has his brother under his authority must feed him from what he eats and clothe him with what he wears, and not impose on him work which is too much for him, but if he does so, he must help him. Abu Dawud said: Ibn Numair transmitted it from al-A'mash in a similar way}}
\hadithdefcmd{abudawud}{5159}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ كُنْتُ أَضْرِبُ غُلاَمًا لِي فَسَمِعْتُ مِنْ خَلْفِي صَوْتًا ‏"‏ اعْلَمْ أَبَا مَسْعُودٍ ‏"‏ ‏.‏ قَالَ ابْنُ الْمُثَنَّى مَرَّتَيْنِ ‏"‏ لَلَّهُ أَقْدَرُ عَلَيْكَ مِنْكَ عَلَيْهِ ‏"‏ ‏.‏ فَالْتَفَتُّ فَإِذَا هُوَ النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ هُوَ حُرٌّ لِوَجْهِ اللَّهِ ‏.‏ قَالَ ‏"‏ أَمَا إِنَّكَ لَوْ لَمْ تَفْعَلْ لَلَفَعَتْكَ النَّارُ أَوْ ‏"‏ لَمَسَّتْكَ النَّارُ ‏"‏ ‏.‏\hadithno{5159}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Mas’ud al-Ansari said:when I was beating a servant of mine, I heard a voice behind me saying: know, Abu Mas’ud-Ibn al-Muthanna said: “twice”-that Allah has more power over you than you have over him. I turned round and saw that it was that it was the prophet (May peace be upon him). I said : Messenger of Allah! He is free for Allah’s sake. He said : If you had not done it, fire would have burned you or the fire would have touched you}}
\hadithdefcmd{abudawud}{5160}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنِ الأَعْمَشِ، بِإِسْنَادِهِ وَمَعْنَاهُ نَحْوَهُ قَالَ كُنْتُ أَضْرِبُ غُلاَمًا لِي أَسْوَدَ بِالسَّوْطِ وَلَمْ يَذْكُرْ أَمْرَ الْعِتْقِ ‏.‏\hadithno{5160}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by al-A’mash in a similar way to same way to the same effect through a different chain of narrators}}
\hadithdefcmd{abudawud}{5161}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ مُوَرِّقٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لاَءَمَكُمْ مِنْ مَمْلُوكِيكُمْ فَأَطْعِمُوهُ مِمَّا تَأْكُلُونَ وَاكْسُوهُ مِمَّا تَكْتَسُونَ وَمَنْ لَمْ يُلاَئِمْكُمْ مِنْهُمْ فَبِيعُوهُ وَلاَ تُعَذِّبُوا خَلْقَ اللَّهِ ‏"‏ ‏.‏\hadithno{5161}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated AbuDharr: The Prophet (ﷺ) said: Feed those of your slaves who please you from what you eat and clothe them with what you clothe yourselves, but sell those who do not please you and do not punish Allah's creatures}}
\hadithdefcmd{abudawud}{5162}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ عُثْمَانَ بْنِ زُفَرَ، عَنْ بَعْضِ بَنِي رَافِعِ بْنِ مَكِيثٍ، عَنْ رَافِعِ بْنِ مَكِيثٍ، وَكَانَ، مِمَّنْ شَهِدَ الْحُدَيْبِيَةَ مَعَ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ حُسْنُ الْمَلَكَةِ نَمَاءٌ وَسُوءُ الْخُلُقِ شُؤْمٌ ‏"‏ ‏.‏\hadithno{5162}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Rafi' ibn Makith: The Prophet (ﷺ) said: Treating those under one's authority will produce prosperity, but an evil nature produces evil fortune}}
\hadithdefcmd{abudawud}{5163}{حَدَّثَنَا ابْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا عُثْمَانُ بْنُ زُفَرَ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ خَالِدِ بْنِ رَافِعِ بْنِ مَكِيثٍ، عَنْ عَمِّهِ الْحَارِثِ بْنِ رَافِعِ بْنِ مَكِيثٍ، وَكَانَ، رَافِعٌ مِنْ جُهَيْنَةَ قَدْ شَهِدَ الْحُدَيْبِيَةَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ حُسْنُ الْمَلَكَةِ نَمَاءٌ وَسُوءُ الْخُلُقِ شُؤْمٌ ‏"‏ ‏.‏\hadithno{5163}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Rafi' ibn Makith: The Messenger of Allah (ﷺ) said: Treating those under one's authority well produces prosperity, but an evil nature produces evil fortune}}
\hadithdefcmd{abudawud}{5164}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، وَأَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، - وَهَذَا حَدِيثُ الْهَمْدَانِيِّ وَهُوَ أَتَمُّ - قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ قَالَ أَخْبَرَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ عَنِ الْعَبَّاسِ بْنِ جُلَيْدٍ الْحَجْرِيِّ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو يَقُولُ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ كَمْ نَعْفُو عَنِ الْخَادِمِ فَصَمَتَ ثُمَّ أَعَادَ عَلَيْهِ الْكَلاَمَ فَصَمَتَ فَلَمَّا كَانَ فِي الثَّالِثَةِ قَالَ ‏ "‏ اعْفُوا عَنْهُ فِي كُلِّ يَوْمٍ سَبْعِينَ مَرَّةً ‏"‏ ‏.‏\hadithno{5164}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: A man came to the Prophet (ﷺ) and asked: Messenger of Allah! how often shall I forgive a servant? He gave no reply, so the man repeated what he had said, but he still kept silence. When he asked a third time, he replied: Forgive him seventy times daily}}
\hadithdefcmd{abudawud}{5165}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، قَالَ أَخْبَرَنَا ح، وَحَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، قَالَ أَخْبَرَنَا عِيسَى، حَدَّثَنَا فُضَيْلٌ، - يَعْنِي ابْنَ غَزْوَانَ - عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ حَدَّثَنِي أَبُو الْقَاسِمِ، نَبِيُّ التَّوْبَةِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَذَفَ مَمْلُوكَهُ وَهُوَ بَرِيءٌ مِمَّا قَالَ جُلِدَ لَهُ يَوْمَ الْقِيَامَةِ حَدًّا ‏"‏ ‏.‏ قَالَ مُؤَمَّلٌ حَدَّثَنَا عِيسَى عَنِ الْفُضَيْلِ يَعْنِي ابْنَ غَزْوَانَ ‏.‏\hadithno{5165}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (6858) Sahih Muslim (1660)}\hadithtrans{Abu Hurairah said:Abu al-Qasim, the Prophet of Atonement (ﷺ) said to me: If anyone reviles his slave when he is innocent of what he said, he will be beaten on the Day of Resurrection. The transmitter Mu'ammal said: 'Isa narrated it to us from al-Fudial, that is, Ibn Ghazwan}}
\hadithdefcmd{abudawud}{5166}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا فُضَيْلُ بْنُ عِيَاضٍ، عَنْ حُصَيْنٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، قَالَ كُنَّا نُزُولاً فِي دَارِ سُوَيْدِ بْنِ مُقَرِّنٍ وَفِينَا شَيْخٌ فِيهِ حِدَّةٌ وَمَعَهُ جَارِيَةٌ فَلَطَمَ وَجْهَهَا فَمَا رَأَيْتُ سُوَيْدًا أَشَدَّ غَضَبًا مِنْهُ ذَاكَ الْيَوْمَ قَالَ عَجَزَ عَلَيْكَ إِلاَّ حُرُّ وَجْهِهَا لَقَدْ رَأَيْتُنَا سَابِعَ سَبْعَةٍ مِنْ وَلَدِ مُقَرِّنٍ وَمَا لَنَا إِلاَّ خَادِمٌ فَلَطَمَ أَصْغَرُنَا وَجْهَهَا فَأَمَرَنَا النَّبِيُّ صلى الله عليه وسلم بِعِتْقِهَا ‏.‏\hadithno{5166}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1658)}\hadithtrans{Hilal b. Yasaf said :We were staying in the house of Suwaid b. Muqarrin. There was among us an old man who was hot-tempered. He had a slave-girl with him. He gave a slap on her face. I never saw Suwaid more angry than on that day. He said: there is no alternative for you except to free her. I was the seventh child in order of Muqarrin and we had only a female servant. The youngest of us gave a slap on her face. The prophet (May peace be upon him) commanded us to set her free}}
\hadithdefcmd{abudawud}{5167}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي سَلَمَةُ بْنُ كُهَيْلٍ، قَالَ حَدَّثَنِي مُعَاوِيَةُ بْنُ سُوَيْدِ بْنِ مُقَرِّنٍ، قَالَ لَطَمْتُ مَوْلًى لَنَا فَدَعَاهُ أَبِي وَدَعَانِي فَقَالَ اقْتَصَّ مِنْهُ فَإِنَّا مَعْشَرَ بَنِي مُقَرِّنٍ كُنَّا سَبْعَةً عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَلَيْسَ لَنَا إِلاَّ خَادِمٌ ‏.‏ فَلَطَمَهَا رَجُلٌ مِنَّا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْتِقُوهَا ‏"‏ ‏.‏ قَالُوا إِنَّهُ لَيْسَ لَنَا خَادِمٌ غَيْرَهَا ‏.‏ قَالَ ‏"‏ فَلْتَخْدُمْهُمْ حَتَّى يَسْتَغْنُوا فَإِذَا اسْتَغْنَوْا فَلْيُعْتِقُوهَا ‏"‏ ‏.‏\hadithno{5167}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1658)}\hadithtrans{Narrated Mu'awiyah ibn Suwayd ibn Muqarrin: I slapped a freed slave of ours. My father called him and me and said: Take retaliation on him. We, the people of Banu Muqarrin, were seven during the time of the Prophet (ﷺ),and we had only a female servant. A man of us slapped her. The Messenger of Allah (ﷺ) said: Set her free. They said: We have no other servant than her. He said: She must serve them till they become well off. When they become well off, they should set her free}}
\hadithdefcmd{abudawud}{5168}{حَدَّثَنَا مُسَدَّدٌ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ فِرَاسٍ، عَنْ أَبِي صَالِحٍ، ذَكْوَانَ عَنْ زَاذَانَ، قَالَ أَتَيْتُ ابْنَ عُمَرَ وَقَدْ أَعْتَقَ مَمْلُوكًا لَهُ فَأَخَذَ مِنَ الأَرْضِ عُودًا أَوْ شَيْئًا فَقَالَ مَا لِي فِيهِ مِنَ الأَجْرِ مَا يَسْوَى هَذَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ لَطَمَ مَمْلُوكَهُ أَوْ ضَرَبَهُ فَكَفَّارَتُهُ أَنْ يُعْتِقَهُ ‏"‏ ‏.‏\hadithno{5168}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1657)}\hadithtrans{Zadhan said:I came to Ibn ‘Umar when he set his slave free. He took a stick or something else from the earth and said; for me there is no reward even equivalent to this. I heard the Messenger of Allah (May peace be upon him) say: If anyone slaps or beats his slave the atonement due from him is to set him free}}
\hadithdefcmd{abudawud}{5169}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْعَبْدَ إِذَا نَصَحَ لِسَيِّدِهِ وَأَحْسَنَ عِبَادَةَ اللَّهِ فَلَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏ ‏.‏\hadithno{5169}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2546) Sahih Muslim (1664)}\hadithtrans{‘Abd Allah b. ‘Umar reported the Messenger of Allah (May peace be upon him) as saying:when a slave acts sincerely towards his master and worship Allah well, he will have a double reward}}
\hadithdefcmd{abudawud}{5170}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ عَمَّارِ بْنِ رُزَيْقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ عِكْرِمَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ خَبَّبَ زَوْجَةَ امْرِئٍ أَوْ مَمْلُوكَهُ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{5170}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone corrupts (instigates) the wife of a man or his slave (against him), he is not from us}}
\hadithdefcmd{abudawud}{5171}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، اطَّلَعَ مِنْ بَعْضِ حُجَرِ النَّبِيِّ صلى الله عليه وسلم فَقَامَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِشْقَصٍ أَوْ مَشَاقِصَ - قَالَ - فَكَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَخْتِلُهُ لِيَطْعُنَهُ ‏.‏\hadithno{5171}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (6242) Sahih Muslim (2157)}\hadithtrans{Anas b. malik said :A man peeped into some of the apartment of the prophet (May peace be upon him). The prophet (May peace be upon him) got up taking an arrowhead or arrowheads. He said: I can still picture myself looking at the Messenger of Allah (May peace be upon him) when he was exploring to pierce him}}
\hadithdefcmd{abudawud}{5172}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، قَالَ حَدَّثَنَا أَبُو هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اطَّلَعَ فِي دَارِ قَوْمٍ بِغَيْرِ إِذْنِهِمْ فَفَقَأُوا عَيْنَهُ فَقَدْ هَدَرَتْ عَيْنُهُ ‏"‏ ‏.‏\hadithno{5172}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2158)}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone peeps into the house of a people without their permission and he knocks out his eye, no responsibility is incurred for his eye}}
\hadithdefcmd{abudawud}{5173}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ الْمُؤَذِّنُ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ سُلَيْمَانَ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ كَثِيرٍ، عَنْ وَلِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ الْبَصَرُ فَلاَ إِذْنَ ‏"‏ ‏.‏\hadithno{5173}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When one has a look into the house, then there is no (need of) permission}}
\hadithdefcmd{abudawud}{5174}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصٌ، عَنِ الأَعْمَشِ، عَنْ طَلْحَةَ، عَنْ هُزَيْلٍ، قَالَ جَاءَ رَجُلٌ - قَالَ عُثْمَانُ سَعْدُ بْنُ أَبِي وَقَّاصٍ - فَوَقَفَ عَلَى بَابِ النَّبِيِّ صلى الله عليه وسلم يَسْتَأْذِنُ فَقَامَ عَلَى الْبَابِ - قَالَ عُثْمَانُ مُسْتَقْبِلَ الْبَابِ - فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ هَكَذَا عَنْكَ أَوْ هَكَذَا فَإِنَّمَا الاِسْتِئْذَانُ مِنَ النَّظَرِ ‏"‏ ‏.‏\hadithno{5174}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Huzayl: A man came. Uthman's version has: Sa'd ibn AbuWaqqas came. He stood at the door. Uthman's version has: (He stood) facing the door. The Prophet (ﷺ) said to him: Away from it, (stand) this side or that side. Asking permission is meant to escape from the look of an eye}}
\hadithdefcmd{abudawud}{5175}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ رَجُلٍ، عَنْ سَعْدٍ، نَحْوَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{5175}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Talhah b. Musarrif from a man from Sa’d from the prophet (May peace be upon him) through a different chain of narrators}}
\hadithdefcmd{abudawud}{5176}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، ح حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا رَوْحٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ أَبِي سُفْيَانَ، أَنَّ عَمْرَو بْنَ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، أَخْبَرَهُ عَنْ كَلَدَةَ بْنِ حَنْبَلٍ، أَنَّ صَفْوَانَ بْنَ أُمَيَّةَ، بَعَثَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِلَبَنٍ وَجِدَايَةٍ وَضَغَابِيسَ - وَالنَّبِيُّ صلى الله عليه وسلم بِأَعْلَى مَكَّةَ - فَدَخَلْتُ وَلَمْ أُسَلِّمْ فَقَالَ ‏ "‏ ارْجِعْ فَقُلِ السَّلاَمُ عَلَيْكُمْ ‏"‏ ‏.‏ وَذَاكَ بَعْدَ مَا أَسْلَمَ صَفْوَانُ بْنُ أُمَيَّةَ ‏.‏ قَالَ عَمْرٌو وَأَخْبَرَنِي ابْنُ صَفْوَانَ بِهَذَا أَجْمَعَ عَنْ كَلَدَةَ بْنِ حَنْبَلٍ وَلَمْ يَقُلْ سَمِعْتُهُ مِنْهُ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ يَحْيَى بْنُ حَبِيبٍ أُمَيَّةُ بْنُ صَفْوَانَ وَلَمْ يَقُلْ سَمِعْتُهُ مِنْ كَلَدَةَ بْنِ حَنْبَلٍ وَقَالَ يَحْيَى أَيْضًا عَمْرُو بْنُ عَبْدِ اللَّهِ بْنِ صَفْوَانَ أَخْبَرَهُ أَنَّ كَلَدَةَ بْنَ الْحَنْبَلِ أَخْبَرَهُ ‏.‏\hadithno{5176}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Kaladah ibn Hanbal: Safwan ibn Umayyah sent him with some milk, a young gazelle and some small cucumbers to the Messenger of Allah (ﷺ) when he was in the upper part of Mecca. I entered but I did not give a salutation. He said: Go back and say: "Peace be upon you"! This happened after Safwan ibn Umayyah and embraced Islam. Amr said: Ibn Safwan told me all this on the authority of Kaladah ibn Hanbal, and he did not say: I heard it from him. Abu Dawud said: Yahya b. Habib said: Umayyah b. Safwan. He did not say: I heard from Kaladah b. Hanbal. Yahya also said: 'Amr b. 'Abd Allah b. Safwan told him that Kaladah b. al-Hanbal told him}}
\hadithdefcmd{abudawud}{5177}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، قَالَ حَدَّثَنَا رَجُلٌ، مِنْ بَنِي عَامِرٍ أَنَّهُ اسْتَأْذَنَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ فِي بَيْتٍ فَقَالَ أَلِجُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِخَادِمِهِ ‏ "‏ اخْرُجْ إِلَى هَذَا فَعَلِّمْهُ الاِسْتِئْذَانَ فَقُلْ لَهُ قُلِ السَّلاَمُ عَلَيْكُمْ أَأَدْخُلُ ‏"‏ ‏.‏ فَسَمِعَهُ الرَّجُلُ فَقَالَ السَّلاَمُ عَلَيْكُمْ أَأَدْخُلُ فَأَذِنَ لَهُ النَّبِيُّ صلى الله عليه وسلم فَدَخَلَ ‏.‏\hadithno{5177}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Rib'i: A man of Banu Amir told that he asked the Prophet (ﷺ) for permission (to enter the house) when he was in the house, saying: May I enter ? The Prophet (ﷺ) said to his servant: Go out to this (man) and teach him how to ask permission to enter the house, and say to him: "Say : Peace be upon you. May I enter?" The man heard it and said: Peace be upon you! May I enter ? The Prophet (ﷺ) permitted him and he entered}}
\hadithdefcmd{abudawud}{5178}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، قَالَ حُدِّثْتُ أَنَّ رَجُلاً مِنْ بَنِي عَامِرٍ اسْتَأْذَنَ عَلَى النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ حَدَّثَنَا مُسَدَّدٌ حَدَّثَنَا أَبُو عَوَانَةَ عَنْ مَنْصُورٍ عَنْ رِبْعِيٍّ وَلَمْ يَقُلْ عَنْ رَجُلٍ مِنْ بَنِي عَامِرٍ ‏.‏\hadithno{5178}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Rib’i b. Hirash said I was told that a man of Banu ‘Amir asked the prophet (May peace be upon him) for permission to enter the house. He then mentioned the rest of the tradition to the same effect. Abu Dawud said:Similarly, Musaddad transmitted it to us saying that Abu 'Awanah related it to us from Mansur. He did not say: "a man of Banu 'Amir}}
\hadithdefcmd{abudawud}{5179}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، عَنْ رَجُلٍ، مِنْ بَنِي عَامِرٍ أَنَّهُ اسْتَأْذَنَ عَلَى النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ فَسَمِعْتُهُ فَقُلْتُ السَّلاَمُ عَلَيْكُمْ أَأَدْخُلُ\hadithno{5179}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Rib’i said that a man of Banu Amir told him that he asked permission of the prophet (May peace be upon him) to enter the house. He related the tradition to the same effect, saying :I heard it and so I said: Peace be upon you. May I enter?}}
\hadithdefcmd{abudawud}{5180}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَخْبَرَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنْتُ جَالِسًا فِي مَجْلِسٍ مِنْ مَجَالِسِ الأَنْصَارِ فَجَاءَ أَبُو مُوسَى فَزِعًا فَقُلْنَا لَهُ مَا أَفْزَعَكَ قَالَ أَمَرَنِي عُمَرُ أَنْ آتِيَهُ فَأَتَيْتُهُ فَاسْتَأْذَنْتُ ثَلاَثًا فَلَمْ يُؤْذَنْ لِي فَرَجَعْتُ فَقَالَ مَا مَنَعَكَ أَنْ تَأْتِيَنِي قُلْتُ قَدْ جِئْتُ فَاسْتَأْذَنْتُ ثَلاَثًا فَلَمْ يُؤْذَنْ لِي وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَأْذَنَ أَحَدُكُمْ ثَلاَثًا فَلَمْ يُؤْذَنْ لَهُ فَلْيَرْجِعْ ‏"‏ ‏.‏ قَالَ لَتَأْتِيَنِّي عَلَى هَذَا بِالْبَيِّنَةِ قَالَ فَقَالَ أَبُو سَعِيدٍ لاَ يَقُومُ مَعَكَ إِلاَّ أَصْغَرُ الْقَوْمِ ‏.‏ قَالَ فَقَامَ أَبُو سَعِيدٍ مَعَهُ فَشَهِدَ لَهُ ‏.‏\hadithno{5180}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6245) Sahih Muslim (2153)}\hadithtrans{Abu Sa’id al-Khudri said:I was sitting in one of the meeting of the Ansar. Abu Musa came terrified. We asked him; what makes you terrified? He replied: ‘Umar sent for me; so I went to him and asked his permission three times, but he did not permit me (to enter), so I came back. He asked; what has prevented you from coming to me? I replied: I came and asked permission three times, but it was not granted to me (so I returned). The Messenger of Allah (May peace be upon him) has said: When one of you asks permission three times and it is not granted to him, he should go away. He (‘Umar’) said; establish the proof of it. So Abu Sa’id said: the youngest of the people will accompany you. So Abu Sa’id got up with him and testified}}
\hadithdefcmd{abudawud}{5181}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، أَنَّهُ أَتَى عُمَرَ فَاسْتَأْذَنَ ثَلاَثًا فَقَالَ يَسْتَأْذِنُ أَبُو مُوسَى يَسْتَأْذِنُ الأَشْعَرِيُّ يَسْتَأْذِنُ عَبْدُ اللَّهِ بْنُ قَيْسٍ فَلَمْ يُؤْذَنْ لَهُ فَرَجَعَ فَبَعَثَ إِلَيْهِ عُمَرُ مَا رَدَّكَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَسْتَأْذِنُ أَحَدُكُمْ ثَلاَثًا فَإِنْ أُذِنَ لَهُ وَإِلاَّ فَلْيَرْجِعْ ‏"‏ ‏.‏ قَالَ ائْتِنِي بِبَيِّنَةٍ عَلَى هَذَا ‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ هَذَا أُبَىٌّ فَقَالَ أُبَىٌّ يَا عُمَرُ لاَ تَكُنْ عَذَابًا عَلَى أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ عُمَرُ لاَ أَكُونُ عَذَابًا عَلَى أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5181}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Sahih Muslim (2154)}\hadithtrans{Abu Musa said that he came to ‘Umar and asked permission three times saying :Abu Musa asks permission, al-Ash’ari ask permission, and ‘Abd Allah b. Qais asks permission, but it was not granted to him. So he went away and ‘umar sent for him saying: what did you return? He replied: The Messenger of Allah (May peace be upon him) said: When one of you asks permission three times and it is not granted to him, he should go away. He said: Establish the proof of it. He went, came back, and said; This is Ubayy. Ubayy said: ‘Umar, do not be an agony for the Companions of the Messenger of Allah (peace be upon him). ‘Umar said : I shall not be an agony for the Companions of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{5182}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، أَنَّ أَبَا مُوسَى، اسْتَأْذَنَ عَلَى عُمَرَ بِهَذِهِ الْقِصَّةِ ‏.‏ قَالَ فِيهِ فَانْطَلَقَ بِأَبِي سَعِيدٍ فَشَهِدَ لَهُ فَقَالَ أَخَفِيَ عَلَىَّ هَذَا مِنْ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَلْهَانِي السَّفْقُ بِالأَسْوَاقِ وَلَكِنْ سَلِّمْ مَا شِئْتَ وَلاَ تَسْتَأْذِنْ ‏.‏\hadithno{5182}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2062) Sahih Muslim (2153)}\hadithtrans{’Ubaid b. ‘Umair said :Abu Musa asked ‘Umar for permission to enter the house. This version has: he went with Abu sa’ld who testified to it. He said Did this practice of the Messenger of Allah (May peace be upon him) remain hidden from me? My engagement in the transaction in the market made me oblivious of it. Now give me salutation as you wish; and do not ask permission}}
\hadithdefcmd{abudawud}{5183}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ، حَدَّثَنَا عَبْدُ الْقَاهِرِ بْنُ شُعَيْبٍ، حَدَّثَنَا هِشَامٌ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، بِهَذِهِ الْقِصَّةِ قَالَ فَقَالَ عُمَرُ لأَبِي مُوسَى إِنِّي لَمْ أَتَّهِمْكَ وَلَكِنَّ الْحَدِيثَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم شَدِيدٌ ‏.‏\hadithno{5183}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Musa in a similar way through a different chain of narrators. This version has:‘Umar said to Abu Musa : I do not blame you, but the matter of transmitting a tradition from the Messenger of Allah (May peace be upon him) is serious}}
\hadithdefcmd{abudawud}{5184}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ غَيْرِ، وَاحِدٍ، مِنْ عُلَمَائِهِمْ فِي هَذَا فَقَالَ عُمَرُ لأَبِي مُوسَى أَمَا إِنِّي لَمْ أَتَّهِمْكَ وَلَكِنْ خَشِيتُ أَنْ يَتَقَوَّلَ النَّاسُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5184}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Musa through a different chain of narrators in a similar manner. This version has :‘Umar said to Abd Musa: I do not blame you, but I am afraid that the people may talk carelessly about the Messenger of Allah (May peace be upon him)}}
\hadithdefcmd{abudawud}{5185}{حَدَّثَنَا هِشَامٌ أَبُو مَرْوَانَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - الْمَعْنَى - قَالَ مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ سَمِعْتُ يَحْيَى بْنَ أَبِي كَثِيرٍ، يَقُولُ حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَسْعَدَ بْنِ زُرَارَةَ، عَنْ قَيْسِ بْنِ سَعْدٍ، قَالَ زَارَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَنْزِلِنَا فَقَالَ ‏"‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ فَرَدَّ سَعْدٌ رَدًّا خَفِيًّا ‏.‏ قَالَ قَيْسٌ فَقُلْتُ أَلاَ تَأْذَنُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ذَرْهُ يُكْثِرْ عَلَيْنَا مِنَ السَّلاَمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ فَرَدَّ سَعْدٌ رَدًّا خَفِيًّا ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ ثُمَّ رَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاتَّبَعَهُ سَعْدٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ أَسْمَعُ تَسْلِيمَكَ وَأَرُدُّ عَلَيْكَ رَدًّا خَفِيًّا لِتُكْثِرَ عَلَيْنَا مِنَ السَّلاَمِ ‏.‏ قَالَ فَانْصَرَفَ مَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَمَرَ لَهُ سَعْدٌ بِغِسْلٍ فَاغْتَسَلَ ثُمَّ نَاوَلَهُ مِلْحَفَةً مَصْبُوغَةً بِزَعْفَرَانٍ أَوْ وَرْسٍ فَاشْتَمَلَ بِهَا ثُمَّ رَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ وَهُوَ يَقُولُ ‏"‏ اللَّهُمَّ اجْعَلْ صَلَوَاتِكَ وَرَحْمَتَكَ عَلَى آلِ سَعْدِ بْنِ عُبَادَةَ ‏"‏ ‏.‏ قَالَ ثُمَّ أَصَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الطَّعَامِ فَلَمَّا أَرَادَ الاِنْصِرَافَ قَرَّبَ لَهُ سَعْدٌ حِمَارًا قَدْ وَطَّأَ عَلَيْهِ بِقَطِيفَةٍ فَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ سَعْدٌ يَا قَيْسُ اصْحَبْ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ قَيْسٌ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ارْكَبْ ‏"‏ ‏.‏ فَأَبَيْتُ ثُمَّ قَالَ ‏"‏ إِمَّا أَنْ تَرْكَبَ وَإِمَّا أَنْ تَنْصَرِفَ ‏"‏ ‏.‏ قَالَ فَانْصَرَفْتُ ‏.‏ قَالَ هِشَامٌ أَبُو مَرْوَانَ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَسْعَدَ بْنِ زُرَارَةَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عُمَرُ بْنُ عَبْدِ الْوَاحِدِ وَابْنُ سَمَاعَةَ عَنِ الأَوْزَاعِيِّ مُرْسَلاً وَلَمْ يَذْكُرَا قَيْسَ بْنَ سَعْدٍ ‏.‏\hadithno{5185}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qays ibn Sa'd: The Messenger of Allah (ﷺ) came to visit us in our house, and said: Peace and Allah's mercy be upon you! Sa'd returned the greeting in a lower tone. Qays said: I said: Do you not grant permission to the Messenger of Allah (ﷺ) to enter? He said: Leave him, he will give us many greetings. The Messenger of Allah (ﷺ) then said: Peace and Allah's mercy be upon you! Sa'd again responded in a lower tone. The Messenger of Allah (ﷺ) again said: Peace and Allah's mercy be upon you! So the Messenger of Allah (ﷺ) went away. Sa'd went after him and said: Messenger of Allah! I heard your greetings and responded in a lower tone so that you might give us many greetings. The Messenger of Allah (ﷺ) returned with him. Sa'd then offered to prepare bath-water for him, and he took a bath. He then gave him a long wrapper dyed with saffron or wars and he wrapped himself in it. The Messenger of Allah (ﷺ) then raised his hands and said: O Allah, bestow Thy blessings and mercy on the family of Sa'd ibn Ubadah! The Messenger of Allah (ﷺ) then shared their meals. When he intended to return, Sa'd brought near him an ass which was covered with a blanket. The Messenger of Allah (ﷺ) mounted it. Sa'd said: O Qays, accompany the Messenger of Allah. Qays said: The Messenger of Allah (ﷺ) said to me: Ride. But I refused. He again said: Either ride or go away. He said: So I went away. Hisham said: AbuMarwan (transmitted) from Muhammad ibn AbdurRahman ibn As'ad ibn Zurarah. Abu Dawud said: 'Umar b. 'Abd al-Wahid and Ibn Sama'ah transmitted it from al-Awzai' in mursal form (the ling of the Companion being missing), and they did not mention Qais b. Sa'd}}
\hadithdefcmd{abudawud}{5186}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَى بَابَ قَوْمٍ لَمْ يَسْتَقْبِلِ الْبَابَ مِنْ تِلْقَاءِ وَجْهِهِ وَلَكِنْ مِنْ رُكْنِهِ الأَيْمَنِ أَوِ الأَيْسَرِ وَيَقُولُ ‏ "‏ السَّلاَمُ عَلَيْكُمُ السَّلاَمُ عَلَيْكُمْ ‏"‏ ‏.‏ وَذَلِكَ أَنَّ الدُّورَ لَمْ يَكُنْ عَلَيْهَا يَوْمَئِذٍ سُتُورٌ ‏.‏\hadithno{5186}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Busr: When the Messenger of Allah (ﷺ) came to some people's door, he did not face it squarely, but faced the right or left corner, and said: Peace be upon you! peace be upon you! That was because there were no curtains on the doors of the house at that time}}
\hadithdefcmd{abudawud}{5187}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، أَنَّهُ ذَهَبَ إِلَى النَّبِيِّ صلى الله عليه وسلم فِي دَيْنِ أَبِيهِ فَدَقَقْتُ الْبَابَ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ قُلْتُ أَنَا ‏.‏ قَالَ ‏"‏ أَنَا أَنَا ‏"‏ ‏.‏ كَأَنَّهُ كَرِهَهُ ‏.‏\hadithno{5187}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6250) Sahih Muslim (2155)}\hadithtrans{Jabir said that he went to the prophet (ﷺ) about the debt of my father. He said :I knocked at the door. He asked : who is there? I replied: it is I. he said: I, as though he disapproved of it}}
\hadithdefcmd{abudawud}{5188}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، - يَعْنِي الْمَقَابِرِيَّ - حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ نَافِعِ بْنِ عَبْدِ الْحَارِثِ، قَالَ خَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى دَخَلْتُ حَائِطًا فَقَالَ لِي ‏"‏ أَمْسِكِ الْبَابَ ‏"‏ ‏.‏ فَضُرِبَ الْبَابُ فَقُلْتُ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي حَدِيثَ أَبِي مُوسَى الأَشْعَرِيَّ قَالَ فِيهِ فَدَقَّ الْبَابَ ‏.‏\hadithno{5188}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Nafi' ibn AbdulHarith: I went out with the (Messenger of Allah (ﷺ) until I entered a garden, he said: Keep on closing the door. The door was then closed. I then said: Who is there ? He then narrated the rest of the tradition. Abu Dawud said: That is to say, the tradition of Abu Musa al-Ash'ari. In this version he said: "He then knocked at the door}}
\hadithdefcmd{abudawud}{5189}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ حَبِيبٍ، وَهِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ رَسُولُ الرَّجُلِ إِلَى الرَّجُلِ إِذْنُهُ ‏"‏ ‏.‏\hadithno{5189}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: A man's messenger sent to another indicates his permission to enter}}
\hadithdefcmd{abudawud}{5190}{حَدَّثَنَا حُسَيْنُ بْنُ مُعَاذٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى طَعَامٍ فَجَاءَ مَعَ الرَّسُولِ فَإِنَّ ذَلِكَ لَهُ إِذْنٌ ‏"‏ ‏.‏ قَالَ أَبُو عَلِيٍّ اللُّؤْلُؤِيُّ سَمِعْتُ أَبَا دَاوُدَ يَقُولُ قَتَادَةُ لَمْ يَسْمَعْ مِنْ أَبِي رَافِعٍ شَيْئًا ‏.‏\hadithno{5190}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When one of you is invited to take meals and comes along with the messenger, that serves as permission for him to enter. Abu 'Ali al-Lu'lu said: I heard Abu Dawud say: Qatadah did not hear anything from Abu Rafi}}
\hadithdefcmd{abudawud}{5191}{حَدَّثَنَا ابْنُ السَّرْحِ، قَالَ حَدَّثَنَا ح، وَحَدَّثَنَا ابْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، وَابْنُ، عَبْدَةَ - وَهَذَا حَدِيثُهُ - قَالاَ أَخْبَرَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ لَمْ يُؤْمَرْ بِهَا أَكْثَرُ النَّاسِ آيَةُ الإِذْنِ وَإِنِّي لآمُرُ جَارِيَتِي هَذِهِ تَسْتَأْذِنُ عَلَىَّ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ عَطَاءٌ عَنِ ابْنِ عَبَّاسٍ يَأْمُرُ بِهِ ‏.‏\hadithno{5191}\hadithgrade{Al-Albani: Sahih Isnaad Mauquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Mauquf; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas said :Most of the people did not act upon the verse about asking permission to enter the house. I have commanded this slave-girl of mine to ask my permission to enter. Abu Dawud said: 'Ata also transmitted it from Ibn 'Abbas in a similar way. He commanded to act upon this}}
\hadithdefcmd{abudawud}{5192}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عِكْرِمَةَ، أَنَّ نَفَرًا، مِنْ أَهْلِ الْعِرَاقِ قَالُوا يَا ابْنَ عَبَّاسٍ كَيْفَ تَرَى فِي هَذِهِ الآيَةِ الَّتِي أُمِرْنَا فِيهَا بِمَا أُمِرْنَا وَلاَ يَعْمَلُ بِهَا أَحَدٌ قَوْلُ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لِيَسْتَأْذِنْكُمُ الَّذِينَ مَلَكَتْ أَيْمَانُكُمْ وَالَّذِينَ لَمْ يَبْلُغُوا الْحُلُمَ مِنْكُمْ ثَلاَثَ مَرَّاتٍ مِنْ قَبْلِ صَلاَةِ الْفَجْرِ وَحِينَ تَضَعُونَ ثِيَابَكُمْ مِنَ الظَّهِيرَةِ وَمِنْ بَعْدِ صَلاَةِ الْعِشَاءِ ثَلاَثُ عَوْرَاتٍ لَكُمْ لَيْسَ عَلَيْكُمْ وَلاَ عَلَيْهِمْ جُنَاحٌ بَعْدَهُنَّ طَوَّافُونَ عَلَيْكُمْ ‏\}‏ قَرَأَ الْقَعْنَبِيُّ إِلَى ‏\{‏ عَلِيمٌ حَكِيمٌ ‏\}‏ قَالَ ابْنُ عَبَّاسٍ إِنَّ اللَّهَ حَلِيمٌ رَحِيمٌ بِالْمُؤْمِنِينَ يُحِبُّ السَّتْرَ وَكَانَ النَّاسُ لَيْسَ لِبُيُوتِهِمْ سُتُورٌ وَلاَ حِجَالٌ فَرُبَّمَا دَخَلَ الْخَادِمُ أَوِ الْوَلَدُ أَوْ يَتِيمَةُ الرَّجُلِ وَالرَّجُلُ عَلَى أَهْلِهِ فَأَمَرَهُمُ اللَّهُ بِالاِسْتِئْذَانِ فِي تِلْكَ الْعَوْرَاتِ فَجَاءَهُمُ اللَّهُ بِالسُّتُورِ وَالْخَيْرِ فَلَمْ أَرَ أَحَدًا يَعْمَلُ بِذَلِكَ بَعْدُ ‏.‏ قَالَ أَبُو دَاوُدَ حَدِيثُ عُبَيْدِ اللَّهِ وَعَطَاءٍ يُفْسِدُ هَذَا ‏.‏\hadithno{5192}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah Ibn Abbas: Ikrimah said: A group of people from Iraq said: Ibn Abbas, what is your opinion about the verse in which we have been commanded whatever we have been commanded, but no one acts upon it? The word of Allah, Most High, reads: "O ye who believe! Let those whom your right hands possess, and the (children) among you, who have not come of age, ask your permission (before) they enter your presence on three occasions: before morning prayer, while you are undressing for the noonday heat, and after late-night prayer. These are your three times of undress; outside those times it is not wrong for you or for them to move about." Al-Qa'nabi recited the verse up to "full of knowledge and wisdom". Ibn Abbas said: Allah is Most Clement and Most Merciful to the believers. He loves concealment. The people had neither curtains nor curtained canopies in their houses. Sometimes a servant, a child or a female orphan of a man entered while the man was having sexual intercourse with his wife. So Allah commanded them to ask permission in those times of undress. Then Allah brought them curtains and all good things. But I did not see anyone following it after that. Abu Dawud said: The tradition of 'Ubaid Allah and of 'Ata, weakens this tradition}}
\hadithdefcmd{abudawud}{5193}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَدْخُلُوا الْجَنَّةَ حَتَّى تُؤْمِنُوا وَلاَ تُؤْمِنُوا حَتَّى تَحَابُّوا أَفَلاَ أَدُلُّكُمْ عَلَى أَمْرٍ إِذَا فَعَلْتُمُوهُ تَحَابَبْتُمْ أَفْشُوا السَّلاَمَ بَيْنَكُمْ ‏"‏ ‏.‏\hadithno{5193}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (54)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:By him in whose hand my soul is, you will not enter Paradise until you believe, and you will not believe until you love one another: should I not guide you to something doing which you will love one another: spread out salutation among you}}
\hadithdefcmd{abudawud}{5194}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَىُّ الإِسْلاَمِ خَيْرٌ قَالَ ‏ "‏ تُطْعِمُ الطَّعَامَ وَتَقْرَأُ السَّلاَمَ عَلَى مَنْ عَرَفْتَ وَمَنْ لَمْ تَعْرِفْ ‏"‏ ‏.‏\hadithno{5194}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (28) Sahih Muslim (39)}\hadithtrans{‘Abd Allah b. ‘Amr said :A man asked the Messenger of Allah (May peace be upon him): When aspect of Islam is best? He replied: that you should provide food and greet both those you know and those you do not know}}
\hadithdefcmd{abudawud}{5195}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ عَوْفٍ، عَنْ أَبِي رَجَاءٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ السَّلاَمُ عَلَيْكُمْ ‏.‏ فَرَدَّ عَلَيْهِ السَّلاَمَ ثُمَّ جَلَسَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَشْرٌ ‏"‏ ‏.‏ ثُمَّ جَاءَ آخَرُ فَقَالَ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏.‏ فَرَدَّ عَلَيْهِ فَجَلَسَ فَقَالَ ‏"‏ عِشْرُونَ ‏"‏ ‏.‏ ثُمَّ جَاءَ آخَرُ فَقَالَ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ ‏.‏ فَرَدَّ عَلَيْهِ فَجَلَسَ فَقَالَ ‏"‏ ثَلاَثُونَ ‏"‏ ‏.‏\hadithno{5195}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Imran ibn Husayn: A man came to the Prophet (ﷺ) and said: Peace be upon you! He responded to his salutation. He then sat down. The Prophet (ﷺ) said: Ten. Another man came and said: Peace and Allah's mercy be upon you! He responded to his salutation when he sat down. He said: Twenty. Another man came and said: Peace and Allah's mercy and blessings be upon you! He responded to him and said when he sat down: and blessings be upon you! He responded to him and said when he sat down: Thirty}}
\hadithdefcmd{abudawud}{5196}{حَدَّثَنَا إِسْحَاقُ بْنُ سُوَيْدٍ الرَّمْلِيُّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ أَظُنُّ أَنِّي سَمِعْتُ نَافِعَ بْنَ يَزِيدَ، قَالَ أَخْبَرَنِي أَبُو مَرْحُومٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ زَادَ ثُمَّ أَتَى آخَرُ فَقَالَ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ وَمَغْفِرَتُهُ فَقَالَ ‏"‏ أَرْبَعُونَ ‏"‏ ‏.‏ قَالَ ‏"‏ هَكَذَا تَكُونُ الْفَضَائِلُ ‏"‏ ‏.‏\hadithno{5196}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad}\hadithtrans{Narrated Mu'adh ibn Anas: (This version is same as previous No 5176 from the Prophet (ﷺ), adding that): Afterwards another man came and said: Peace and Allah's mercy, blessings and forgiveness be upon you! whereupon he said: Forty. adding: Thus are excellent qualities rewarded}}
\hadithdefcmd{abudawud}{5197}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ الذُّهْلِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ أَبِي خَالِدٍ، وَهْبٍ عَنْ أَبِي سُفْيَانَ الْحِمْصِيِّ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَوْلَى النَّاسِ بِاللَّهِ مَنْ بَدَأَهُمْ بِالسَّلاَمِ ‏"‏ ‏.‏\hadithno{5197}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuUmamah: The Prophet (ﷺ) said: Those who are nearest to Allah are they who are first to give a salutation}}
\hadithdefcmd{abudawud}{5198}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُسَلِّمُ الصَّغِيرُ عَلَى الْكَبِيرِ وَالْمَارُّ عَلَى الْقَاعِدِ وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏ ‏.‏\hadithno{5198}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying :The young should salute the old, the one who is passing by should salute the one who is sitting, and a small company should salute a large one}}
\hadithdefcmd{abudawud}{5199}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، أَخْبَرَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنَا زِيَادٌ، أَنَّ ثَابِتًا، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُسَلِّمُ الرَّاكِبُ عَلَى الْمَاشِي ‏"‏ ‏.‏ ثُمَّ ذَكَرَ الْحَدِيثَ ‏.‏\hadithno{5199}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6233) Sahih Muslim (2160)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (May peace be upon him) as saying:one who is riding should salute one who is walking. He then mentioned the rest of the tradition}}
\hadithdefcmd{abudawud}{5200}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ أَبِي مُوسَى، عَنْ أَبِي مَرْيَمَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ إِذَا لَقِيَ أَحَدُكُمْ أَخَاهُ فَلْيُسَلِّمْ عَلَيْهِ فَإِنْ حَالَتْ بَيْنَهُمَا شَجَرَةٌ أَوْ جِدَارٌ أَوْ حَجَرٌ ثُمَّ لَقِيَهُ فَلْيُسَلِّمْ عَلَيْهِ أَيْضًا ‏.‏ قَالَ مُعَاوِيَةُ وَحَدَّثَنِي عَبْدُ الْوَهَّابِ بْنُ بُخْتٍ عَنْ أَبِي الزِّنَادِ عَنِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِثْلَهُ سَوَاءً ‏.‏\hadithno{5200}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: When one of you meets his brother, he should salute him, then if he meets him again after a tree, wall or stone has come between them, he should also salute him. Mu'awiyah said: 'Abd al-Wahhab b. Bakht transmitted a similar tradition to me from Abu al-Zinad, from al-A'raj, from Abu Hurairah, from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{5201}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا حَسَنُ بْنُ صَالِحٍ، عَنْ أَبِيهِ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ فِي مَشْرُبَةٍ لَهُ فَقَالَ السَّلاَمُ عَلَيْكَ يَا رَسُولَ اللَّهِ السَّلاَمُ عَلَيْكُمْ أَيَدْخُلُ عُمَرُ ‏.‏\hadithno{5201}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: Umar came to the Prophet (ﷺ) when he was in his wooden oriel, and said to him: Peace be upon you. Messenger of Allah, peace be upon you! May Umar enter ?}}
\hadithdefcmd{abudawud}{5202}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - عَنْ ثَابِتٍ، قَالَ قَالَ أَنَسٌ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى غِلْمَانٍ يَلْعَبُونَ فَسَلَّمَ عَلَيْهِمْ ‏.‏\hadithno{5202}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: The Messenger of Allah (ﷺ) came to some children who were playing: He saluted them}}
\hadithdefcmd{abudawud}{5203}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا حُمَيْدٌ، قَالَ قَالَ أَنَسٌ انْتَهَى إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا غُلاَمٌ فِي الْغِلْمَانِ فَسَلَّمَ عَلَيْنَا ثُمَّ أَخَذَ بِيَدِي فَأَرْسَلَنِي بِرِسَالَةٍ وَقَعَدَ فِي ظِلِّ جِدَارٍ - أَوْ قَالَ إِلَى جِدَارٍ - حَتَّى رَجَعْتُ إِلَيْهِ ‏.‏\hadithno{5203}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: The Messenger of Allah (ﷺ) came to us when I was a boy among the boys. He saluted us and took me by my hand. He then sent me with some message. He himself sat in the shadow of a wall, or he said: near a wall until I returned to him}}
\hadithdefcmd{abudawud}{5204}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي حُسَيْنٍ، سَمِعَهُ مِنْ، شَهْرِ بْنِ حَوْشَبٍ يَقُولُ أَخْبَرَتْهُ أَسْمَاءُ بِنْتُ يَزِيدَ، مَرَّ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم فِي نِسْوَةٍ فَسَلَّمَ عَلَيْنَا ‏.‏\hadithno{5204}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Asma', daughter of Yazid, said :the Prophet (ﷺ), passed us by when we were with some women and gave us a salutation}}
\hadithdefcmd{abudawud}{5205}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، قَالَ خَرَجْتُ مَعَ أَبِي إِلَى الشَّامِ فَجَعَلُوا يَمُرُّونَ بِصَوَامِعَ فِيهَا نَصَارَى فَيُسَلِّمُونَ عَلَيْهِمْ فَقَالَ أَبِي لاَ تَبْدَءُوهُمْ بِالسَّلاَمِ فَإِنَّ أَبَا هُرَيْرَةَ حَدَّثَنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبْدَءُوهُمْ بِالسَّلاَمِ وَإِذَا لَقِيتُمُوهُمْ فِي الطَّرِيقِ فَاضْطَرُّوهُمْ إِلَى أَضْيَقِ الطَّرِيقِ ‏"‏ ‏.‏\hadithno{5205}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2167)}\hadithtrans{Narrated AbuHurayrah: Suhayl ibn AbuSalih said: I went out with my father to Syria. The people passed by the cloisters in which there were Christians and began to salute them. My father said: Do not give them salutation first, for AbuHurayrah reported the Messenger of Allah (ﷺ) as saying: Do not salute them (Jews and Christians) first, and when you meet them on the road, force them to go to the narrowest part of it}}
\hadithdefcmd{abudawud}{5206}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْيَهُودَ إِذَا سَلَّمَ عَلَيْكُمْ أَحَدُهُمْ فَإِنَّمَا يَقُولُ السَّامُ عَلَيْكُمْ فَقُولُوا وَعَلَيْكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ مَالِكٌ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ وَرَوَاهُ الثَّوْرِيُّ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ قَالَ فِيهِ ‏"‏ وَعَلَيْكُمْ ‏"‏ ‏.‏\hadithno{5206}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (6257) Sahih Muslim (2164)}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: When one of the Jews greets you saying: Death may come upon you, reply: The same to you. Abu Dawud said: Malik b. 'Adb Allah b. Dinar transmitted it in a similar manner, and al-Thawri transmitted it from 'Abd Allah b. Dinar. He said in this version: The same to you}}
\hadithdefcmd{abudawud}{5207}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ أَصْحَابَ النَّبِيِّ، صلى الله عليه وسلم قَالُوا لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أَهْلَ الْكِتَابِ يُسَلِّمُونَ عَلَيْنَا فَكَيْفَ نَرُدُّ عَلَيْهِمْ قَالَ ‏ "‏ قُولُوا وَعَلَيْكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رِوَايَةُ عَائِشَةَ وَأَبِي عَبْدِ الرَّحْمَنِ الْجُهَنِيِّ وَأَبِي بَصْرَةَ يَعْنِي الْغِفَارِيَّ ‏.‏\hadithno{5207}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6258، 6024) Sahih Muslim (2163، 2165)}\hadithtrans{Anas said:The Companions of the prophet (ﷺ) said to the prophet (ﷺ): The people of the Book salute us. How should we reply to them? He said: say : the same to you}}
\hadithdefcmd{abudawud}{5208}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا بِشْرٌ، - يَعْنِيَانِ ابْنَ الْمُفَضَّلِ - عَنِ ابْنِ عَجْلاَنَ، عَنِ الْمَقْبُرِيِّ، - قَالَ مُسَدَّدٌ سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ - عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا انْتَهَى أَحَدُكُمْ إِلَى الْمَجْلِسِ فَلْيُسَلِّمْ فَإِذَا أَرَادَ أَنْ يَقُومَ فَلْيُسَلِّمْ فَلَيْسَتِ الأُولَى بِأَحَقَّ مِنَ الآخِرَةِ ‏"‏ ‏.‏\hadithno{5208}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When one of you comes to an assembly, he should give a salutation and if he feels inclined to get up, he should give a salutation, for the former is not more of a duty than the latter}}
\hadithdefcmd{abudawud}{5209}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ أَبِي غِفَارٍ، عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ، عَنْ أَبِي جُرَىٍّ الْهُجَيْمِيِّ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ عَلَيْكَ السَّلاَمُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏ "‏ لاَ تَقُلْ عَلَيْكَ السَّلاَمُ فَإِنَّ عَلَيْكَ السَّلاَمُ تَحِيَّةُ الْمَوْتَى ‏"‏ ‏.‏\hadithno{5209}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuJurayy al-Hujaymi: I came to the Prophet (ﷺ) and said: Upon you be peace, Messenger of Allah! He said: Do not say: Upon you be peace, for "Upon you be peace" is the salutation to the dead}}
\hadithdefcmd{abudawud}{5210}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ إِبْرَاهِيمَ الْجُدِّيُّ، حَدَّثَنَا سَعِيدُ بْنُ خَالِدٍ الْخُزَاعِيُّ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ الْمُفَضَّلِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه - قَالَ أَبُو دَاوُدَ رَفَعَهُ الْحَسَنُ بْنُ عَلِيٍّ - قَالَ ‏ "‏ يُجْزِئُ عَنِ الْجَمَاعَةِ، إِذَا مَرُّوا أَنْ يُسَلِّمَ، أَحَدُهُمْ وَيُجْزِئُ عَنِ الْجُلُوسِ أَنْ يَرُدَّ أَحَدُهُمْ ‏"‏ ‏.‏\hadithno{5210}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: AbuDawud said: Al-Hasan ibn Ali traced this tradition back to the Prophet (ﷺ): When people are passing by, it is enough if one of them gives a salutation on their behalf, and that it is enough for those who are sitting if one of them replies}}
\hadithdefcmd{abudawud}{5211}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي بَلْجٍ، عَنْ زَيْدٍ أَبِي الْحَكَمِ الْعَنَزِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا الْتَقَى الْمُسْلِمَانِ فَتَصَافَحَا وَحَمِدَا اللَّهَ عَزَّ وَجَلَّ وَاسْتَغْفَرَاهُ غُفِرَ لَهُمَا ‏"‏ ‏.‏\hadithno{5211}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Bara' ibn Azib: The Prophet (ﷺ) said: If two Muslims meet, shake hands, praise Allah, and ask Him for forgiveness, they will be forgiven}}
\hadithdefcmd{abudawud}{5212}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ، وَابْنُ، نُمَيْرٍ عَنِ الأَجْلَحِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمَيْنِ يَلْتَقِيَانِ فَيَتَصَافَحَانِ إِلاَّ غُفِرَ لَهُمَا قَبْلَ أَنْ يَفْتَرِقَا ‏"‏ ‏.‏\hadithno{5212}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Bara' ibn Azib: The Prophet (ﷺ) said: Two Muslims will not meet and shake hands having their sins forgiven them before they separate}}
\hadithdefcmd{abudawud}{5213}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا جَاءَ أَهْلُ الْيَمَنِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ جَاءَكُمْ أَهْلُ الْيَمَنِ وَهُمْ أَوَّلُ مَنْ جَاءَ بِالْمُصَافَحَةِ ‏"‏ ‏.‏\hadithno{5213}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: When the people of the Yemen came, the Messenger of Allah (ﷺ) said: The people of the Yemen have come to you and they are first to shake hands}}
\hadithdefcmd{abudawud}{5214}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا أَبُو الْحُسَيْنِ، - يَعْنِي خَالِدَ بْنَ ذَكْوَانَ - عَنْ أَيُّوبَ بْنِ بُشَيْرِ بْنِ كَعْبٍ الْعَدَوِيِّ، عَنْ رَجُلٍ، مِنْ عَنَزَةَ أَنَّهُ قَالَ لأَبِي ذَرٍّ حَيْثُ سُيِّرَ مِنَ الشَّامِ إِنِّي أُرِيدُ أَنْ أَسْأَلَكَ عَنْ حَدِيثٍ مِنْ حَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ إِذًا أُخْبِرَكَ بِهِ إِلاَّ أَنْ يَكُونَ سِرًّا ‏.‏ قُلْتُ إِنَّهُ لَيْسَ بِسِرٍّ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَافِحُكُمْ إِذَا لَقِيتُمُوهُ قَالَ مَا لَقِيتُهُ قَطُّ إِلاَّ صَافَحَنِي وَبَعَثَ إِلَىَّ ذَاتَ يَوْمٍ وَلَمْ أَكُنْ فِي أَهْلِي فَلَمَّا جِئْتُ أُخْبِرْتُ أَنَّهُ أَرْسَلَ إِلَىَّ فَأَتَيْتُهُ وَهُوَ عَلَى سَرِيرِهِ فَالْتَزَمَنِي فَكَانَتْ تِلْكَ أَجْوَدَ وَأَجْوَدَ ‏.‏\hadithno{5214}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuDharr: Ayyub ibn Bushayr ibn Ka'b al-Adawi quoted a man of Anazah who said that he asked AbuDharr when he left Syria: I wish to ask you about a tradition of the Messenger of Allah (ﷺ). He said: I shall tell you except that it is something secret. Did the Messenger of Allah (ﷺ) shake hands with you when you met him? He replied: I never met him without his shaking hands with me. One day he sent for me when I was not at home. When I came I was informed that he had sent for me. I came to him and found him on a couch. He embraced me and that was better and better}}
\hadithdefcmd{abudawud}{5215}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ أَهْلَ، قُرَيْظَةَ لَمَّا نَزَلُوا عَلَى حُكْمِ سَعْدٍ أَرْسَلَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم فَجَاءَ عَلَى حِمَارٍ أَقْمَرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قُومُوا إِلَى سَيِّدِكُمْ ‏"‏ ‏.‏ أَوْ ‏"‏ إِلَى خَيْرِكُمْ ‏"‏ ‏.‏ فَجَاءَ حَتَّى قَعَدَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5215}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4121) Sahih Muslim (1768)}\hadithtrans{Abu Sa’id al-Khudri said:When Banu Quraizah capitulated agreeing to accept Sa’d’s judgement, the Prophet (ﷺ) sent a messenger to him. When he came riding on a white ass, the prophet (ﷺ) said: stand up to (show respect to) your chief, or he said : “to the best of you”. He came and sat beside the Messenger of Allah (May peace be upon him)}}
\hadithdefcmd{abudawud}{5216}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، بِهَذَا الْحَدِيثِ قَالَ فَلَمَّا كَانَ قَرِيبًا مِنَ الْمَسْجِدِ قَالَ لِلأَنْصَارِ ‏ "‏ قُومُوا إِلَى سَيِّدِكُمْ ‏"‏ ‏.‏\hadithno{5216}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Shu’bah through a different chain of narrators. This version has :when he came near the mosque, he said to the Ansar; stand up showing respect to your chief}}
\hadithdefcmd{abudawud}{5217}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ مَيْسَرَةَ بْنِ حَبِيبٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ أُمِّ الْمُؤْمِنِينَ، عَائِشَةَ رضى الله عنها أَنَّهَا قَالَتْ مَا رَأَيْتُ أَحَدًا كَانَ أَشْبَهَ سَمْتًا وَهَدْيًا وَدَلاًّ - وَقَالَ الْحَسَنُ حَدِيثًا وَكَلاَمًا وَلَمْ يَذْكُرِ الْحَسَنُ السَّمْتَ وَالْهَدْىَ وَالدَّلَّ - بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فَاطِمَةَ كَرَّمَ اللَّهُ وَجْهَهَا كَانَتْ إِذَا دَخَلَتْ عَلَيْهِ قَامَ إِلَيْهَا فَأَخَذَ بِيَدِهَا وَقَبَّلَهَا وَأَجْلَسَهَا فِي مَجْلِسِهِ وَكَانَ إِذَا دَخَلَ عَلَيْهَا قَامَتْ إِلَيْهِ فَأَخَذَتْ بِيَدِهِ فَقَبَّلَتْهُ وَأَجْلَسَتْهُ فِي مَجْلِسِهَا ‏.‏\hadithno{5217}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I never saw anyone more like the Messenger of Allah (ﷺ) in respect of gravity, calm deportment, pleasant disposition - according to al-Hasan's version: in respect of talk and speech. Al-Hasan did not mention gravity, calm deportment, pleasant disposition - than Fatimah, may Allah honour her face. When she came to visit him (the Prophet) he got up to (welcome) her, took her by the hand, kissed her and made her sit where he was sitting; and when he went to visit her, she got up to (welcome) him, took him by the hand, kissed him, and made him sit where she was sitting}}
\hadithdefcmd{abudawud}{5218}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ الأَقْرَعَ بْنَ حَابِسٍ، أَبْصَرَ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يُقَبِّلُ حُسَيْنًا فَقَالَ إِنَّ لِي عَشْرَةً مِنَ الْوَلَدِ مَا فَعَلْتُ هَذَا بِوَاحِدٍ مِنْهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لاَ يَرْحَمُ لاَ يُرْحَمُ ‏"‏ ‏.‏\hadithno{5218}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5997) Sahih Muslim (2118)}\hadithtrans{Abu Hurairah said; Al-Aqra’ b. Habib saw that the Messenger of Allah(ﷺ) was kissing Husain. He said:I have ten children and I have never kissed any of them. The Messenger of Allah(ﷺ) said: He who does not show tenderness will not be shown tenderness}}
\hadithdefcmd{abudawud}{5219}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، رضى الله عنها قَالَتْ ثُمَّ قَالَ تَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏ "‏ أَبْشِرِي يَا عَائِشَةُ فَإِنَّ اللَّهَ قَدْ أَنْزَلَ عُذْرَكِ ‏"‏ ‏.‏ وَقَرَأَ عَلَيْهَا الْقُرْآنَ فَقَالَ أَبَوَاىَ قُومِي فَقَبِّلِي رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَتْ أَحْمَدُ اللَّهَ لاَ إِيَّاكُمَا ‏.‏\hadithno{5219}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘A’ishah said :the prophet (ﷺ) said; Good tidings to you, ‘A’ishah, for Allah Most High has revealed your innocence. He then recited to her the Quranic verses. Her parents said: Kiss the head of the Messenger of Allah (ﷺ). I said : Praise be to Allah, most High, not to you}}
\hadithdefcmd{abudawud}{5220}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ أَجْلَحَ، عَنِ الشَّعْبِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَلَقَّى جَعْفَرَ بْنَ أَبِي طَالِبٍ فَالْتَزَمَهُ وَقَبَّلَ مَا بَيْنَ عَيْنَيْهِ ‏.‏\hadithno{5220}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ash-Sha'bi: The Prophet (ﷺ) received Ja'far ibn AbuTalib, embraced him and kissed him between both of his eyes (forehead)}}
\hadithdefcmd{abudawud}{5221}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ إِيَاسِ بْنِ دَغْفَلٍ، قَالَ رَأَيْتُ أَبَا نَضْرَةَ قَبَّلَ خَدَّ الْحَسَنِ بْنِ عَلِيٍّ عَلَيْهِمَا السَّلاَمُ ‏.‏\hadithno{5221}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuNadrah: Ilyas ibn Dighfal said: I saw AbuNadrah kissing on the cheek of al-Hasan}}
\hadithdefcmd{abudawud}{5222}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَالِمٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ دَخَلْتُ مَعَ أَبِي بَكْرٍ أَوَّلَ مَا قَدِمَ الْمَدِينَةَ فَإِذَا عَائِشَةُ ابْنَتُهُ مُضْطَجِعَةٌ قَدْ أَصَابَتْهَا حُمَّى فَأَتَاهَا أَبُو بَكْرٍ فَقَالَ لَهَا كَيْفَ أَنْتِ يَا بُنَيَّةُ وَقَبَّلَ خَدَّهَا ‏.‏\hadithno{5222}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3918)}\hadithtrans{Narrated Al-Bara' ibn Azib: I went in with AbuBakr when he had newly come to Medina and he found his daughter Aisha lying down afflicted with fever. AbuBakr went to her, and saying: How are you, girlie? kissed her on the cheek}}
\hadithdefcmd{abudawud}{5223}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ حَدَّثَهُ وَذَكَرَ، قِصَّةً قَالَ فَدَنَوْنَا - يَعْنِي - مِنَ النَّبِيِّ صلى الله عليه وسلم فَقَبَّلْنَا يَدَهُ ‏.‏\hadithno{5223}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: Ibn Umar told a story and said: We then came near the Prophet (ﷺ) and kissed his hand}}
\hadithdefcmd{abudawud}{5224}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا خَالِدٌ، عَنْ حُصَيْنٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، - رَجُلٍ مِنَ الأَنْصَارِ - قَالَ بَيْنَمَا هُوَ يُحَدِّثُ الْقَوْمَ وَكَانَ فِيهِ مِزَاحٌ بَيْنَا يُضْحِكُهُمْ فَطَعَنَهُ النَّبِيُّ صلى الله عليه وسلم فِي خَاصِرَتِهِ بِعُودٍ فَقَالَ أَصْبِرْنِي ‏.‏ فَقَالَ ‏ "‏ اصْطَبِرْ ‏"‏ ‏.‏ قَالَ إِنَّ عَلَيْكَ قَمِيصًا وَلَيْسَ عَلَىَّ قَمِيصٌ ‏.‏ فَرَفَعَ النَّبِيُّ صلى الله عليه وسلم عَنْ قَمِيصِهِ فَاحْتَضَنَهُ وَجَعَلَ يُقَبِّلُ كَشْحَهُ قَالَ إِنَّمَا أَرَدْتُ هَذَا يَا رَسُولَ اللَّهِ ‏.‏\hadithno{5224}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Usayd ibn Hudayr,: AbdurRahman ibn AbuLayla, quoting Usayd ibn Hudayr, a man of the Ansar, said that while he was given to jesting and was talking to the people and making them laugh, the Prophet (ﷺ) poked him under the ribs with a stick. He said: Let me take retaliation. He said: Take retaliation. He said: You are wearing a shirt but I am not. The Prophet (ﷺ) then raised his shirt and the man embraced him and began to kiss his side. Then he said: This is what I wanted, Messenger of Allah}}
\hadithdefcmd{abudawud}{5225}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى بْنِ الطَّبَّاعِ، حَدَّثَنَا مَطَرُ بْنُ عَبْدِ الرَّحْمَنِ الأَعْنَقُ، حَدَّثَتْنِي أُمُّ أَبَانَ بِنْتُ الْوَازِعِ بْنِ زَارِعٍ، عَنْ جَدِّهَا، زَارِعٍ وَكَانَ فِي وَفْدِ عَبْدِ الْقَيْسِ قَالَ لَمَّا قَدِمْنَا الْمَدِينَةَ فَجَعَلْنَا نَتَبَادَرُ مِنْ رَوَاحِلِنَا فَنُقَبِّلُ يَدَ النَّبِيِّ صلى الله عليه وسلم وَرِجْلَهُ - قَالَ - وَانْتَظَرَ الْمُنْذِرُ الأَشَجُّ حَتَّى أَتَى عَيْبَتَهُ فَلَبِسَ ثَوْبَيْهِ ثُمَّ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ لَهُ ‏"‏ إِنَّ فِيكَ خَلَّتَيْنِ يُحِبُّهُمَا اللَّهُ الْحِلْمُ وَالأَنَاةُ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ أَنَا أَتَخَلَّقُ بِهِمَا أَمِ اللَّهُ جَبَلَنِي عَلَيْهِمَا قَالَ ‏"‏ بَلِ اللَّهُ جَبَلَكَ عَلَيْهِمَا ‏"‏ ‏.‏ قَالَ الْحَمْدُ لِلَّهِ الَّذِي جَبَلَنِي عَلَى خَلَّتَيْنِ يُحِبُّهُمَا اللَّهُ وَرَسُولُهُ ‏.‏\hadithno{5225}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated al-Wazi' ibn Zari': Umm Aban, daughter of al-Wazi' ibn Zari', quoting his grandfather, who was a member of the deputation of AbdulQays, said: When we came to Medina, we raced to be first to dismount and kiss the hand and foot of the Messenger of Allah (ﷺ). But al-Mundhir al-Ashajj waited until he came to the bundle of his clothes. He put on his two garments and then he went to the Prophet (ﷺ). He said to him: You have two characteristics which Allah likes: gentleness and deliberation. He asked: Have I acquired them or has Allah has created (them) my nature? He replied: No, Allah has created (them) in your nature. He then said: Praise be to Allah Who has created in my nature two characteristics which Allah and His Apostle like}}
\hadithdefcmd{abudawud}{5226}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا هِشَامٌ، عَنْ حَمَّادٍ، - يَعْنِيَانِ ابْنَ أَبِي سُلَيْمَانَ - عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَبَا ذَرٍّ ‏"‏ ‏.‏ فَقُلْتُ لَبَّيْكَ وَسَعْدَيْكَ يَا رَسُولَ اللَّهِ وَأَنَا فِدَاؤُكَ ‏.‏\hadithno{5226}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuDharr: The Prophet (ﷺ) addressed me, saying: O AbuDharr! I replied: At thy service and at thy pleasure, Messenger of Allah! may I be ransom for thee}}
\hadithdefcmd{abudawud}{5227}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، أَوْ غَيْرِهِ أَنَّ عِمْرَانَ بْنَ حُصَيْنٍ، قَالَ كُنَّا نَقُولُ فِي الْجَاهِلِيَّةِ أَنْعَمَ اللَّهُ بِكَ عَيْنًا وَأَنْعِمْ صَبَاحًا فَلَمَّا كَانَ الإِسْلاَمُ نُهِينَا عَنْ ذَلِكَ ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ قَالَ مَعْمَرٌ يُكْرَهُ أَنْ يَقُولَ الرَّجُلُ أَنْعَمَ اللَّهُ بِكَ عَيْنًا وَلاَ بَأْسَ أَنْ يَقُولَ أَنْعَمَ اللَّهُ عَيْنَكَ ‏.‏\hadithno{5227}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Imran ibn Husayn: In the pre-Islamic period we used to say: "May Allah make the eye happy for you," and "Good morning" but when Islam came, we were forbidden to say that. AbdurRazzaq said on the authority of Ma'mar: It is disapproved that a man should say: "May Allah make the eye happy for you," but there is no harm in saying: "May Allah make your eye happy}}
\hadithdefcmd{abudawud}{5228}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ الأَنْصَارِيِّ، قَالَ حَدَّثَنَا أَبُو قَتَادَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي سَفَرٍ لَهُ فَعَطِشُوا فَانْطَلَقَ سَرَعَانُ النَّاسِ فَلَزِمْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تِلْكَ اللَّيْلَةَ فَقَالَ ‏ "‏ حَفِظَكَ اللَّهُ بِمَا حَفِظْتَ بِهِ نَبِيَّهُ ‏"‏ ‏.‏\hadithno{5228}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (681)}\hadithtrans{Abu Qatadah said:The Prophet (ﷺ) was on journey. The people became thirsty, and they went quickly. I guarded the Messenger of Allah(ﷺ) on that night. He said: May Allah guard you for the reason you have guarded His Prophet}}
\hadithdefcmd{abudawud}{5229}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ أَبِي مِجْلَزٍ، قَالَ خَرَجَ مُعَاوِيَةُ عَلَى ابْنِ الزُّبَيْرِ وَابْنِ عَامِرٍ فَقَامَ ابْنُ عَامِرٍ وَجَلَسَ ابْنُ الزُّبَيْرِ فَقَالَ مُعَاوِيَةُ لاِبْنِ عَامِرٍ اجْلِسْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَحَبَّ أَنْ يَمْثُلَ لَهُ الرِّجَالُ قِيَامًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{5229}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Mu'awiyah: AbuMijlaz said: Mu'awiyah went out to Ibn az-Zubayr and Ibn Amir. Ibn Amir got up and Ibn az-Zubayr remained sitting. Mu'awiyah said to Ibn Amir: Sit down, for I heard the Messenger of Allah (ﷺ) say: Let him who likes people to stand up before him prepare his place in Hell}}
\hadithdefcmd{abudawud}{5230}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مِسْعَرٍ، عَنْ أَبِي الْعَنْبَسِ، عَنْ أَبِي الْعَدَبَّسِ، عَنْ أَبِي مَرْزُوقٍ، عَنْ أَبِي غَالِبٍ، عَنْ أَبِي أُمَامَةَ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُتَوَكِّئًا عَلَى عَصًا فَقُمْنَا إِلَيْهِ فَقَالَ ‏ "‏ لاَ تَقُومُوا كَمَا تَقُومُ الأَعَاجِمُ يُعَظِّمُ بَعْضُهَا بَعْضًا ‏"‏ ‏.‏\hadithno{5230}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuUmamah: The Messenger of Allah (ﷺ) came out to us leaning on a stick. We stood up to show respect to him. He said: Do not stand up as foreigners do for showing respect to one another}}
\hadithdefcmd{abudawud}{5231}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ غَالِبٍ، قَالَ إِنَّا لَجُلُوسٌ بِبَابِ الْحَسَنِ إِذْ جَاءَ رَجُلٌ فَقَالَ حَدَّثَنِي أَبِي عَنْ جَدِّي قَالَ بَعَثَنِي أَبِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ائْتِهِ فَأَقْرِئْهُ السَّلاَمَ ‏.‏ قَالَ فَأَتَيْتُهُ فَقُلْتُ إِنَّ أَبِي يُقْرِئُكَ السَّلاَمَ ‏.‏ فَقَالَ ‏ "‏ عَلَيْكَ وَعَلَى أَبِيكَ السَّلاَمُ ‏"‏ ‏.‏\hadithno{5231}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated A man: Ghalib said: When we were sitting at al-Hasan's door, a man came along. He said: My father told me on the authority of my grandfather, saying: My father sent me to the Messenger of Allah (ﷺ) and said: Go to him and give him a greeting. So I went to him and said: My father sends you a greeting. He said: Upon you and upon your father be peace}}
\hadithdefcmd{abudawud}{5232}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ أَبِي سَلَمَةَ، أَنَّ عَائِشَةَ، رضى الله عنها حَدَّثَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ إِنَّ جِبْرِيلَ يَقْرَأُ عَلَيْكِ السَّلاَمَ ‏"‏ ‏.‏ فَقَالَتْ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ ‏.‏\hadithno{5232}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6253) Sahih Muslim (2447)}\hadithtrans{‘A’ishah told that the Prophet(ﷺ) said to her:Gabriel gives you a greeting. Replying she said: Upon him be peace and grace of Allah}}
\hadithdefcmd{abudawud}{5233}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا يَعْلَى بْنُ عَطَاءٍ، عَنْ أَبِي هَمَّامٍ عَبْدِ اللَّهِ بْنِ يَسَارٍ، أَنَّ أَبَا عَبْدِ الرَّحْمَنِ الْفِهْرِيَّ، قَالَ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حُنَيْنًا فَسِرْنَا فِي يَوْمٍ قَائِظٍ شَدِيدِ الْحَرِّ فَنَزَلْنَا تَحْتَ ظِلِّ الشَّجَرَةِ فَلَمَّا زَالَتِ الشَّمْسُ لَبِسْتُ لأْمَتِي وَرَكِبْتُ فَرَسِي فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي فُسْطَاطِهِ فَقُلْتُ السَّلاَمُ عَلَيْكَ يَا رَسُولَ اللَّهِ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ قَدْ حَانَ الرَّوَاحُ فَقَالَ ‏"‏ أَجَلْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَا بِلاَلُ قُمْ ‏"‏ ‏.‏ فَثَارَ مِنْ تَحْتِ سَمُرَةٍ كَأَنَّ ظِلَّهُ ظِلُّ طَائِرٍ فَقَالَ لَبَّيْكَ وَسَعْدَيْكَ وَأَنَا فِدَاؤُكَ ‏.‏ فَقَالَ ‏"‏ أَسْرِجْ لِي الْفَرَسَ ‏"‏ ‏.‏ فَأَخْرَجَ سَرْجًا دَفَّتَاهُ مِنْ لِيفٍ لَيْسَ فِيهِ أَشَرٌ وَلاَ بَطَرٌ فَرَكِبَ وَرَكِبْنَا ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو عَبْدِ الرَّحْمَنِ الْفِهْرِيُّ لَيْسَ لَهُ إِلاَّ هَذَا الْحَدِيثُ وَهُوَ حَدِيثٌ نَبِيلٌ جَاءَ بِهِ حَمَّادُ بْنُ سَلَمَةَ ‏.‏\hadithno{5233}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuAbdurRahman al-Fihri: I was present with the Messenger of Allah at the battle of Hunayn. We travelled on a hot day when the heat was extreme. We halted under the shade of a tree. When the sun passed the meridian, I put on my coat of mail and rode on my horse. I came to the Messenger of Allah (ﷺ) who was in a tent. I said: Peace, Allah's mercy and His blessings be upon you! The time of departure has come. He said: Yes. He then said: Rise, Bilal. He jumped out from beneath a gum-acacia tree and its shade was like that of a bird. He said: I am at your service and at your pleasure, and I make myself a sacrifice for you. He said: Put the saddle on the horse for me. He then took out a saddle, both sides of which were stuffed with palm-leaves; it showed no arrogance and pride. So he rode and we also rode. He then mentioned the rest of the tradition. Abu Dawud said: Abu 'Abd al-Rahman al-Fihri did not transmit any tradition except this one. This is a tradition of an expert transmitted by Hammad b. Salamah}}
\hadithdefcmd{abudawud}{5234}{حَدَّثَنَا عِيسَى بْنُ إِبْرَاهِيمَ الْبِرَكِيُّ، وَسَمِعْتُهُ مِنْ أَبِي الْوَلِيدِ الطَّيَالِسِيِّ، وَأَنَا لِحَدِيثِ، عِيسَى أَضْبَطُ قَالَ حَدَّثَنَا عَبْدُ الْقَاهِرِ بْنُ السَّرِيِّ، - يَعْنِي السُّلَمِيَّ - حَدَّثَنَا ابْنُ كِنَانَةَ بْنِ عَبَّاسِ بْنِ مِرْدَاسٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ ضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ أَبُو بَكْرٍ أَوْ عُمَرُ أَضْحَكَ اللَّهُ سِنَّكَ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{5234}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Kinanah b. Abbas ibn Mirdas: The Messenger of Allah (ﷺ) laughed AbuBakr or Umar said to him: May Allah make your teeth laugh! He then mentioned the tradition}}
\hadithdefcmd{abudawud}{5235}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا حَفْصٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي السَّفَرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ مَرَّ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أُطَيِّنُ حَائِطًا لِي أَنَا وَأُمِّي فَقَالَ ‏"‏ مَا هَذَا يَا عَبْدَ اللَّهِ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ شَىْءٌ أُصْلِحُهُ فَقَالَ ‏"‏ الأَمْرُ أَسْرَعُ مِنْ ذَاكَ ‏"‏ ‏.‏\hadithno{5235}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) came upon us when my mother and I were plastering a wall of mine. He asked: What is this, Abdullah ? I replied: It is something I am repairing. He said! The matter is quicker for you than that}}
\hadithdefcmd{abudawud}{5236}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَهَنَّادٌ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِإِسْنَادِهِ بِهَذَا قَالَ مَرَّ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نُعَالِجُ خُصًّا لَنَا وَهَى فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَقُلْنَا خُصٌّ لَنَا وَهَى فَنَحْنُ نُصْلِحُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَرَى الأَمْرَ إِلاَّ أَعْجَلَ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{5236}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by al-A’mash through a different chain of narrators. This version has:The Messenger of Allah(ﷺ) came upon me when we were repairing our cottage that was broken. He asked: What is this? We replied: This cottage of ours has broken and we are repairing it. The Messenger of Allah(ﷺ) said: I see that the command is quicker than that}}
\hadithdefcmd{abudawud}{5237}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، قَالَ أَخْبَرَنِي إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ حَاطِبٍ الْقُرَشِيُّ، عَنْ أَبِي طَلْحَةَ الأَسَدِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ فَرَأَى قُبَّةً مُشْرِفَةً فَقَالَ ‏"‏ مَا هَذِهِ ‏"‏ ‏.‏ قَالَ لَهُ أَصْحَابُهُ هَذِهِ لِفُلاَنٍ - رَجُلٍ مِنَ الأَنْصَارِ - ‏.‏ قَالَ فَسَكَتَ وَحَمَلَهَا فِي نَفْسِهِ حَتَّى إِذَا جَاءَ صَاحِبُهَا رَسُولَ اللَّهِ صلى الله عليه وسلم يُسَلِّمُ عَلَيْهِ فِي النَّاسِ أَعْرَضَ عَنْهُ صَنَعَ ذَلِكَ مِرَارًا حَتَّى عَرَفَ الرَّجُلُ الْغَضَبَ فِيهِ وَالإِعْرَاضَ عَنْهُ فَشَكَا ذَلِكَ إِلَى أَصْحَابِهِ فَقَالَ وَاللَّهِ إِنِّي لأُنْكِرُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالُوا خَرَجَ فَرَأَى قُبَّتَكَ ‏.‏ قَالَ فَرَجَعَ الرَّجُلُ إِلَى قُبَّتِهِ فَهَدَمَهَا حَتَّى سَوَّاهَا بِالأَرْضِ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَلَمْ يَرَهَا قَالَ ‏"‏ مَا فَعَلَتِ الْقُبَّةُ ‏"‏ ‏.‏ قَالُوا شَكَا إِلَيْنَا صَاحِبُهَا إِعْرَاضَكَ عَنْهُ فَأَخْبَرْنَاهُ فَهَدَمَهَا فَقَالَ ‏"‏ أَمَا إِنَّ كُلَّ بِنَاءٍ وَبَالٌ عَلَى صَاحِبِهِ إِلاَّ مَا لاَ إِلاَّ مَا لاَ ‏"‏ ‏.‏ يَعْنِي مَا لاَ بُدَّ مِنْهُ ‏.‏\hadithno{5237}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: The Messenger of Allah (ﷺ) came out, and on seeing a high-domed building, he said: What is it? His companions replied to him: It belongs to so and so, one of the Ansar. He said: he said nothing but kept the matter in mind. When its owner came and gave him a greeting among the people, he turned away from him. When he had done this several times, the man realised that he was the cause of the anger and the rebuff. So he complained about it to his companions, saying: I swear by Allah that I cannot understand the Messenger of Allah (ﷺ). They said: He went out and saw your domed building. So the man returned to it and demolished it, levelling it to the ground. One day the Messenger of Allah (ﷺ) came out and did not see it. He asked: What has happened to the domed building? They replied: Its owner complained to us about your rebuff, and when we informed him about it, he demolished it. He said: Every building is a misfortune for its owner, except what cannot, except what cannot, meaning except that which is essential}}
\hadithdefcmd{abudawud}{5238}{حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ مُطَرِّفٍ الرُّؤَاسِيُّ، حَدَّثَنَا عِيسَى، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ دُكَيْنِ بْنِ سَعِيدٍ الْمُزَنِيِّ، قَالَ أَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَسَأَلْنَاهُ الطَّعَامَ فَقَالَ ‏ "‏ يَا عُمَرُ اذْهَبْ فَأَعْطِهِمْ ‏"‏ ‏.‏ فَارْتَقَى بِنَا إِلَى عِلِّيَّةٍ فَأَخَذَ الْمِفْتَاحَ مِنْ حُجْزَتِهِ فَفَتَحَ ‏.‏\hadithno{5238}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad}\hadithtrans{Narrated Dukayn ibn Sa'id al-Muzani: We came to the Prophet (ﷺ) and asked him for some corn. He said: Go, Umar, and give them. He ascended with us a room upstairs, took a key from his apartment and opened it}}
\hadithdefcmd{abudawud}{5239}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا أَبُو أُسَامَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عُثْمَانَ بْنِ أَبِي سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ حُبْشِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَطَعَ سِدْرَةً صَوَّبَ اللَّهُ رَأْسَهُ فِي النَّارِ ‏"‏ ‏.‏ سُئِلَ أَبُو دَاوُدَ عَنْ مَعْنَى هَذَا الْحَدِيثِ فَقَالَ هَذَا الْحَدِيثُ مُخْتَصَرٌ يَعْنِي مَنْ قَطَعَ سِدْرَةً فِي فَلاَةٍ يَسْتَظِلُّ بِهَا ابْنُ السَّبِيلِ وَالْبَهَائِمُ عَبَثًا وَظُلْمًا بِغَيْرِ حَقٍّ يَكُونُ لَهُ فِيهَا صَوَّبَ اللَّهُ رَأْسَهُ فِي النَّارِ ‏.‏\hadithno{5239}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Habashi: The Prophet (ﷺ) said: If anyone cuts the lote-tree, Allah brings him headlong into Hell. Abu Dawud was asked about the meaning of this tradition. He said: This is a brief tradition. It means that if anyone cuts uselessly, unjustly and without any right a lote-tree under the shade of which travellers and beasts take shelter, Allah will bring him into Hell headlong}}
\hadithdefcmd{abudawud}{5240}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، وَسَلَمَةُ، - يَعْنِي ابْنَ شَبِيبٍ - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ عُثْمَانَ بْنِ أَبِي سُلَيْمَانَ، عَنْ رَجُلٍ، مِنْ ثَقِيفٍ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، يَرْفَعُ الْحَدِيثَ إِلَى النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{5240}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{A similar report (as previous) was narrated from a man from Thaqif, from 'Urwah bin Az-Zubair, who attributed the Hadith to the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{5241}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، قَالاَ حَدَّثَنَا حَسَّانُ بْنُ إِبْرَاهِيمَ، قَالَ سَأَلْتُ هِشَامَ بْنَ عُرْوَةَ عَنْ قَطْعِ السِّدْرِ، وَهُوَ مُسْتَنِدٌ إِلَى قَصْرِ عُرْوَةَ فَقَالَ أَتَرَى هَذِهِ الأَبْوَابَ وَالْمَصَارِيعَ إِنَّمَا هِيَ مِنْ سِدْرِ عُرْوَةَ كَانَ عُرْوَةُ يَقْطَعُهُ مِنْ أَرْضِهِ وَقَالَ لاَ بَأْسَ بِهِ ‏.‏ زَادَ حُمَيْدٌ فَقَالَ هِيَ يَا عِرَاقِيُّ جِئْتَنِي بِبِدْعَةٍ قَالَ قُلْتُ إِنَّمَا الْبِدْعَةُ مِنْ قِبَلِكُمْ سَمِعْتُ مَنْ يَقُولُ بِمَكَّةَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ قَطَعَ السِّدْرَ ‏.‏ ثُمَّ سَاقَ مَعْنَاهُ ‏.‏\hadithno{5241}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hassan ibn Ibrahim: I asked Hisham ibn Urwah about the cutting of a lote-tree when he was leaning against the house of Urwah. He said: Do you not see these doors and leaves? These were made of the lote-tree of Urwah which Urwah used to cut from his hand? He said: There is no harm in it. Humayd's version adds: You have brought an innovation, O Iraqi! He said: The innovation is from you. I heard someone say at Mecca: The Messenger of Allah (ﷺ) cursed him who cuts a lote-tree. He then mentioned the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{5242}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ سَمِعْتُ أَبِي بُرَيْدَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ فِي الإِنْسَانِ ثَلاَثُمِائَةٍ وَسِتُّونَ مَفْصِلاً فَعَلَيْهِ أَنْ يَتَصَدَّقَ عَنْ كُلِّ مَفْصِلٍ مِنْهُ بِصَدَقَةٍ ‏"‏ ‏.‏ قَالُوا وَمَنْ يُطِيقُ ذَلِكَ يَا نَبِيَّ اللَّهِ قَالَ ‏"‏ النُّخَاعَةُ فِي الْمَسْجِدِ تَدْفِنُهَا وَالشَّىْءُ تُنَحِّيهِ عَنِ الطَّرِيقِ فَإِنْ لَمْ تَجِدْ فَرَكْعَتَا الضُّحَى تُجْزِئُكَ ‏"‏ ‏.‏\hadithno{5242}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Buraydah: I heard the Messenger of Allah (ﷺ) say: A human being has three hundred and sixty joints for each of which he must give alms. The people asked him: Who is capable of doing this ? He replied: It may be mucus in the mosque which you bury, and something which you remove from the road; but if you do not find such, two rak'ahs in the forenoon will be sufficient for you}}
\hadithdefcmd{abudawud}{5243}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، عَنْ عَبَّادِ بْنِ عَبَّادٍ، - وَهَذَا لَفْظُهُ وَهُوَ أَتَمُّ - عَنْ وَاصِلٍ، عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُصْبِحُ عَلَى كُلِّ سُلاَمَى مِنِ ابْنِ آدَمَ صَدَقَةٌ تَسْلِيمُهُ عَلَى مَنْ لَقِيَ صَدَقَةٌ وَأَمْرُهُ بِالْمَعْرُوفِ صَدَقَةٌ وَنَهْيُهُ عَنِ الْمُنْكَرِ صَدَقَةٌ وَإِمَاطَتُهُ الأَذَى عَنِ الطَّرِيقِ صَدَقَةٌ وَبُضْعَتُهُ أَهْلَهُ صَدَقَةٌ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ يَأْتِي شَهْوَتَهُ وَتَكُونُ لَهُ صَدَقَةٌ قَالَ ‏"‏ أَرَأَيْتَ لَوْ وَضَعَهَا فِي غَيْرِ حَقِّهَا أَكَانَ يَأْثَمُ ‏"‏ ‏.‏ قَالَ ‏"‏ وَيُجْزِئُ مِنْ ذَلِكَ كُلِّهِ رَكْعَتَانِ مِنَ الضُّحَى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَذْكُرْ حَمَّادٌ الأَمْرَ وَالنَّهْىَ ‏.‏\hadithno{5243}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuDharr: The Prophet (ﷺ) said: In the morning alms are due from every bone in man's fingers and toes. Salutation to everyone he meets is alms; enjoining good is alms; forbidding what is disreputable is alms; removing what is harmful from the road is alms; having sexual intercourse with his wife is alms. The people asked: He fulfils his desire, Messenger of Allah; is it alms? He replied: Tell me if he fulfilled his desire where he had no right, would he commit a sin ? He then said: Two rak'ahs which one prays in the forenoon serve instead of all that. Abu Dawud said: Hammad did not mention enjoining good and forbidding what is disreputable}}
\hadithdefcmd{abudawud}{5244}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ وَاصِلٍ، عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِي ذَرٍّ، بِهَذَا الْحَدِيثِ وَذَكَرَ النَّبِيَّ صلى الله عليه وسلم فِي وَسْطِهِ ‏.‏\hadithno{5244}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Dharr through a different chain of narrators. In this version the transmitter mentioned the Prophet(ﷺ) in the middle of the tradition}}
\hadithdefcmd{abudawud}{5245}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ نَزَعَ رَجُلٌ لَمْ يَعْمَلْ خَيْرًا قَطُّ غُصْنَ شَوْكٍ عَنِ الطَّرِيقِ إِمَّا كَانَ فِي شَجَرَةٍ فَقَطَعَهُ وَأَلْقَاهُ وَإِمَّا كَانَ مَوْضُوعًا فَأَمَاطَهُ فَشَكَرَ اللَّهُ لَهُ بِهَا فَأَدْخَلَهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{5245}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2472) Sahih Muslim (1914 After 2617)}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: A man never did a good deed but removed a thorny branch from the road; it was either in the tree and someone cut it and threw it on the road, or it was lying in it, he removed it. Allah accepted this good deed of his and brought him into Paradise}}
\hadithdefcmd{abudawud}{5246}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، رِوَايَةً وَقَالَ مَرَّةً يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ لاَ تَتْرُكُوا النَّارَ فِي بُيُوتِكُمْ حِينَ تَنَامُونَ ‏"‏ ‏.‏\hadithno{5246}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6293) Sahih Muslim (2015)}\hadithtrans{Salim quoting his father(Ibn ‘Umar) said( sometimes he traced back to the Prophet(ﷺ):Do not leave a fire burning in your houses while you are asleep}}
\hadithdefcmd{abudawud}{5247}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ التَّمَّارُ، حَدَّثَنَا عَمْرُو بْنُ طَلْحَةَ، حَدَّثَنَا أَسْبَاطٌ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَتْ فَأْرَةٌ فَأَخَذَتْ تَجُرُّ الْفَتِيلَةَ فَجَاءَتْ بِهَا فَأَلْقَتْهَا بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى الْخُمْرَةِ الَّتِي كَانَ قَاعِدًا عَلَيْهَا فَأَحْرَقَتْ مِنْهَا مِثْلَ مَوْضِعِ الدِّرْهَمِ فَقَالَ ‏ "‏ إِذَا نِمْتُمْ فَأَطْفِئُوا سُرُجَكُمْ فَإِنَّ الشَّيْطَانَ يَدُلُّ مِثْلَ هَذِهِ عَلَى هَذَا فَتَحْرِقَكُمْ ‏"‏ ‏.‏\hadithno{5247}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas said:A mouse came dragging a wick and dropped before the Messenger of Allah(ﷺ) on the mat on which he was sitting with the result that it burned a hole in it about the size of dirham. He (the prophet) said: When you go to sleep, extinguish your lamps, for the devil guides a creature like this to do thus and sets you on fire}}
\hadithdefcmd{abudawud}{5248}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا سَالَمْنَاهُنَّ مُنْذُ حَارَبْنَاهُنَّ وَمَنْ تَرَكَ شَيْئًا مِنْهُنَّ خِيفَةً فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{5248}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: We have not made peace with them since we fought with them, so he who leaves any of them alone through fear does not belong to us}}
\hadithdefcmd{abudawud}{5249}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ السُّكَّرِيُّ، عَنْ إِسْحَاقَ بْنِ يُوسُفَ، عَنْ شَرِيكٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْتُلُوا الْحَيَّاتِ كُلَّهُنَّ فَمَنْ خَافَ ثَأْرَهُنَّ فَلَيْسَ مِنِّي ‏"‏ ‏.‏\hadithno{5249}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: Kill all the snakes, and he who fears their revenge does not belong to me}}
\hadithdefcmd{abudawud}{5250}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا مُوسَى بْنُ مُسْلِمٍ، قَالَ سَمِعْتُ عِكْرِمَةَ، يَرْفَعُ الْحَدِيثَ فِيمَا أُرَى إِلَى ابْنِ عَبَّاسٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَرَكَ الْحَيَّاتِ مَخَافَةَ طَلَبِهِنَّ فَلَيْسَ مِنَّا مَا سَالَمْنَاهُنَّ مُنْذُ حَارَبْنَاهُنَّ ‏"‏ ‏.‏\hadithno{5250}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: He who leaves the snakes along through fear of their pursuit, does not belong to us. We have not made peace with them since we have fought with them}}
\hadithdefcmd{abudawud}{5251}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ مُوسَى الطَّحَّانِ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَابِطٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، أَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّا نُرِيدُ أَنْ نَكْنِسَ زَمْزَمَ وَإِنَّ فِيهَا مِنْ هَذِهِ الْجِنَّانِ - يَعْنِي الْحَيَّاتِ الصِّغَارَ - فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِقَتْلِهِنَّ ‏.‏\hadithno{5251}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Abbas ibn AbdulMuttalib: Al-Abbas said to the Messenger of Allah (ﷺ): We wish to sweep out Zamzam, but in it there are some of these Jinnan, meaning small snakes; so the Messenger of Allah (ﷺ) ordered that they should be killed}}
\hadithdefcmd{abudawud}{5252}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اقْتُلُوا الْحَيَّاتِ وَذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يَلْتَمِسَانِ الْبَصَرَ وَيُسْقِطَانِ الْحَبَلَ ‏"‏ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ يَقْتُلُ كُلَّ حَيَّةٍ وَجَدَهَا فَأَبْصَرَهُ أَبُو لُبَابَةَ أَوْ زَيْدُ بْنُ الْخَطَّابِ وَهُوَ يُطَارِدُ حَيَّةً فَقَالَ إِنَّهُ قَدْ نُهِيَ عَنْ ذَوَاتِ الْبُيُوتِ ‏.‏\hadithno{5252}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3297) Sahih Muslim (2233)}\hadithtrans{Ibn ‘Umar reported the Messenger of Allah(ﷺ) as saying:Kill snakes, kill those which have two streaks and those with small tails, for they obliterate the eyesight and cause miscarriage. Salim said: ‘Abd Allah(b. ‘Umar) used to kill every snake which he found. Abu Lubabah or Zaid b. al-Khattab saw him chasing a snake. He said: He(the Prophet) prohibited house-snakes}}
\hadithdefcmd{abudawud}{5253}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ أَبِي لُبَابَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ الْجِنَّانِ الَّتِي تَكُونُ فِي الْبُيُوتِ إِلاَّ أَنْ يَكُونَ ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يَخْطِفَانِ الْبَصَرَ وَيَطْرَحَانِ مَا فِي بُطُونِ النِّسَاءِ ‏.‏\hadithno{5253}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3298، 3312، 3313) Sahih Muslim (2233)}\hadithtrans{Abu Lubabah said:The Messenger of Allah(ﷺ) prohibited killing the jinnan(small snakes) that are in the house, except the one which have two streaks and the one with small tail, for they obliterate the eyesight and cause miscarriage}}
\hadithdefcmd{abudawud}{5254}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، وَجَدَ بَعْدَ ذَلِكَ - يَعْنِي بَعْدَ مَا حَدَّثَهُ أَبُو لُبَابَةَ - حَيَّةً فِي دَارِهِ فَأَمَرَ بِهَا فَأُخْرِجَتْ يَعْنِي إِلَى الْبَقِيعِ ‏.‏\hadithno{5254}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Nafi said:After that, that is, after Abu Lubabah had mentioned him this tradition, Ibn ‘Umar found a snake in his house; he commanded regarding it and it was driven away to al-Baqi}}
\hadithdefcmd{abudawud}{5255}{حَدَّثَنَا ابْنُ السَّرْحِ، وَأَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي أُسَامَةُ، عَنْ نَافِعٍ، فِي هَذَا الْحَدِيثِ قَالَ نَافِعٌ ثُمَّ رَأَيْتُهَا بَعْدُ فِي بَيْتِهِ ‏.‏\hadithno{5255}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim (2233)}\hadithtrans{The tradition mentioned above has also been transmitted by Nafi through a different chain of transmitters. In this version Nafi said:After that I saw it again in his house}}
\hadithdefcmd{abudawud}{5256}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ أَبِي يَحْيَى، قَالَ حَدَّثَنِي أَبِي أَنَّهُ، انْطَلَقَ هُوَ وَصَاحِبٌ لَهُ إِلَى أَبِي سَعِيدٍ يَعُودَانِهِ فَخَرَجْنَا مِنْ عِنْدِهِ فَلَقِينَا صَاحِبًا لَنَا وَهُوَ يُرِيدُ أَنْ يَدْخُلَ عَلَيْهِ فَأَقْبَلْنَا نَحْنُ فَجَلَسْنَا فِي الْمَسْجِدِ فَجَاءَ فَأَخْبَرَنَا أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْهَوَامَّ مِنَ الْجِنِّ فَمَنْ رَأَى فِي بَيْتِهِ شَيْئًا فَلْيُحَرِّجْ عَلَيْهِ ثَلاَثَ مَرَّاتٍ فَإِنْ عَادَ فَلْيَقْتُلْهُ فَإِنَّهُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{5256}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: Muhammad ibn AbuYahya said that his father told that he and his companion went to AbuSa'id al-Khudri to pay a sick visit to him. He said: Then we came out from him and met a companion of ours who wanted to go to him. We went ahead and sat in the mosque. He then came back and told us that he heard AbuSa'id al-Khudri say: The Messenger of Allah (ﷺ) said: Some snakes are jinn; so when anyone sees one of them in his house, he should give it a warning three times. If it return (after that), he should kill it, for it is a devil}}
\hadithdefcmd{abudawud}{5257}{حَدَّثَنَا يَزِيدُ بْنُ مَوْهَبٍ الرَّمْلِيُّ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ صَيْفِيٍّ أَبِي سَعِيدٍ، مَوْلَى الأَنْصَارِ عَنْ أَبِي السَّائِبِ، قَالَ أَتَيْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ فَبَيْنَا أَنَا جَالِسٌ، عِنْدَهُ سَمِعْتُ تَحْتَ، سَرِيرِهِ تَحْرِيكَ شَىْءٍ فَنَظَرْتُ فَإِذَا حَيَّةٌ فَقُمْتُ فَقَالَ أَبُو سَعِيدٍ مَا لَكَ فَقُلْتُ حَيَّةٌ هَا هُنَا ‏.‏ قَالَ فَتُرِيدُ مَاذَا قُلْتُ أَقْتُلُهَا ‏.‏ فَأَشَارَ إِلَى بَيْتٍ فِي دَارِهِ تِلْقَاءَ بَيْتِهِ فَقَالَ إِنَّ ابْنَ عَمٍّ لِي كَانَ فِي هَذَا الْبَيْتِ فَلَمَّا كَانَ يَوْمُ الأَحْزَابِ اسْتَأْذَنَ إِلَى أَهْلِهِ وَكَانَ حَدِيثَ عَهْدٍ بِعُرْسٍ فَأَذِنَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَرَهُ أَنْ يَذْهَبَ بِسِلاَحِهِ فَأَتَى دَارَهُ فَوَجَدَ امْرَأَتَهُ قَائِمَةً عَلَى بَابِ الْبَيْتِ فَأَشَارَ إِلَيْهَا بِالرُّمْحِ فَقَالَتْ لاَ تَعْجَلْ حَتَّى تَنْظُرَ مَا أَخْرَجَنِي ‏.‏ فَدَخَلَ الْبَيْتَ فَإِذَا حَيَّةٌ مُنْكَرَةٌ فَطَعَنَهَا بِالرُّمْحِ ثُمَّ خَرَجَ بِهَا فِي الرُّمْحِ تَرْتَكِضُ قَالَ فَلاَ أَدْرِي أَيُّهُمَا كَانَ أَسْرَعَ مَوْتًا الرَّجُلُ أَوِ الْحَيَّةُ فَأَتَى قَوْمُهُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالُوا ادْعُ اللَّهَ أَنْ يَرُدَّ صَاحِبَنَا ‏.‏ فَقَالَ ‏"‏ اسْتَغْفِرُوا لِصَاحِبِكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ نَفَرًا مِنَ الْجِنِّ أَسْلَمُوا بِالْمَدِينَةِ فَإِذَا رَأَيْتُمْ أَحَدًا مِنْهُمْ فَحَذِّرُوهُ ثَلاَثَ مَرَّاتٍ ثُمَّ إِنْ بَدَا لَكُمْ بَعْدُ أَنْ تَقْتُلُوهُ فَاقْتُلُوهُ بَعْدَ الثَّلاَثِ ‏"‏ ‏.‏\hadithno{5257}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (2236)}\hadithtrans{Abu al-Sa’ib said I went to visit Abu Sa’ld al-Khudri, and while I was sitting I heard a movement under under his couch. When I looked and found a snake there, I got up. Abu Sa’ld said:what is with you? I said : Here is a snake. He said : what do you want ? I said : I shall kill it. He then pointed to a room in his house in front of his room and said : My cousin (son of my uncle) was in this room. He asked his permission to go to his wife on the occasion of the battle of Troops (Ahzab), as he was recently married. The Messenger of Allah (May peace be upon him) gave him permission and ordered him to take his weapon with him. He came to his house and found his wife standing at the door of the house. When he pointed to her with the lance, she said; do not make haste till you see what has brought me out. He entered the house and found an ugly snake there. He pierced in the lance while it was quivering. He said : I do not know which of them died first, the man or the snake. His people then came to the Messenger of Allah (May peace be upon him) and said: supplicate Allah to restore our companion to life for us. He said : Ask forgiveness for your Companion. Then he said : In Medina a group of Jinn have embraced Islam, so when you see one of them, pronounce a waring to it three times and if it appears to you after that, kill it after three days}}
\hadithdefcmd{abudawud}{5258}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، بِهَذَا الْحَدِيثِ مُخْتَصَرًا قَالَ ‏ "‏ فَلْيُؤْذِنْهُ ثَلاَثًا فَإِنْ بَدَا لَهُ بَعْدُ فَلْيَقْتُلْهُ فَإِنَّهُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{5258}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2236)}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Ajilan through a different chain of narrators briefly. This version has:He should give it a warning three times. If it appears to him after that, he should kill it, for it is a devil}}
\hadithdefcmd{abudawud}{5259}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ صَيْفِيٍّ، مَوْلَى ابْنِ أَفْلَحَ قَالَ أَخْبَرَنِي أَبُو السَّائِبِ، مَوْلَى هِشَامِ بْنِ زُهْرَةَ أَنَّهُ دَخَلَ عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ فَذَكَرَ نَحْوَهُ وَأَتَمَّ مِنْهُ قَالَ ‏ "‏ فَآذِنُوهُ ثَلاَثَةَ أَيَّامٍ فَإِنْ بَدَا لَكُمْ بَعْدَ ذَلِكَ فَاقْتُلُوهُ فَإِنَّمَا هُوَ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{5259}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2236)}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Sa'id al-Khudri in a similar manner through a different chain of narrators. This version is more perfect. In this version he said :give it a warning for three days; if it appears to you after that, then kill it, for it is only a devil}}
\hadithdefcmd{abudawud}{5260}{حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، عَنْ عَلِيِّ بْنِ هَاشِمٍ، حَدَّثَنَا ابْنُ أَبِي لَيْلَى، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْ حَيَّاتِ الْبُيُوتِ فَقَالَ ‏ "‏ إِذَا رَأَيْتُمْ مِنْهُنَّ شَيْئًا فِي مَسَاكِنِكُمْ فَقُولُوا أَنْشُدُكُنَّ الْعَهْدَ الَّذِي أَخَذَ عَلَيْكُنَّ نُوحٌ أَنْشُدُكُنَّ الْعَهْدَ الَّذِي أَخَذَ عَلَيْكُنَّ سُلَيْمَانُ أَنْ لاَ تُؤْذُونَا فَإِنْ عُدْنَ فَاقْتُلُوهُنَّ ‏"‏ ‏.‏\hadithno{5260}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbdurRahman Ibn AbuLayla: The Messenger of Allah (ﷺ) was asked about the house-snakes. He said: When you see one of them in your dwelling, say: I adjure you by the covenant which Noah made with you, and I adjure you by the covenant which Solomon made with you not to harm us. Then if they come back, kill them}}
\hadithdefcmd{abudawud}{5261}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنِ ابْنِ مَسْعُودٍ، أَنَّهُ قَالَ اقْتُلُوا الْحَيَّاتِ كُلَّهَا إِلاَّ الْجَانَّ الأَبْيَضَ الَّذِي كَأَنَّهُ قَضِيبُ فِضَّةٍ ‏.‏ قَالَ أَبُو دَاوُدَ فَقَالَ لِي إِنْسَانٌ الْجَانُّ لاَ يَنْعَرِجُ فِي مِشْيَتِهِ فَإِذَا كَانَ هَذَا صَحِيحًا كَانَتْ عَلاَمَةً فِيهِ إِنْ شَاءَ اللَّهُ ‏.‏\hadithno{5261}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: Kill all the snakes except the little white one which looks like a silver wand. Abu Dawud said: A man said to me: A white snake does not wind in its movement. If it is correct, that is a sign in it, if Allah wills}}
\hadithdefcmd{abudawud}{5262}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الْوَزَغِ وَسَمَّاهُ فُوَيْسِقًا ‏.‏\hadithno{5262}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2238)}\hadithtrans{‘Amir b. Sa’d, quoting his father, said :The Messenger of Allah (May peace be upon him) ordered a gecko to be killed, and calling it a noxious little creature}}
\hadithdefcmd{abudawud}{5263}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَتَلَ وَزَغَةً فِي أَوَّلِ ضَرْبَةٍ فَلَهُ كَذَا وَكَذَا حَسَنَةً وَمَنْ قَتَلَهَا فِي الضَّرْبَةِ الثَّانِيَةِ فَلَهُ كَذَا وَكَذَا حَسَنَةً أَدْنَى مِنَ الأَوَّلِ وَمَنْ قَتَلَهَا فِي الضَّرْبَةِ الثَّالِثَةِ فَلَهُ كَذَا وَكَذَا حَسَنَةً أَدْنَى مِنَ الثَّانِيَةِ ‏"‏ ‏.‏\hadithno{5263}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2240)}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone kills a gecko with the first blow, such and such number of good deeds will be recorded for him, if he kills it with the second blow, such and such number of good deeds will be recorded for him less than the former; and if he kills it with the third blow, such and such number of good deeds will be recorded for him, less than the former}}
\hadithdefcmd{abudawud}{5264}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، عَنْ سُهَيْلٍ، قَالَ حَدَّثَنِي أَخِي، أَوْ أُخْتِي عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ فِي أَوَّلِ ضَرْبَةٍ سَبْعِينَ حَسَنَةً ‏"‏ ‏.‏\hadithno{5264}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2240)}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: For the first blow seventy good deeds will be recorded}}
\hadithdefcmd{abudawud}{5265}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنِ الْمُغِيرَةِ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ نَزَلَ نَبِيٌّ مِنَ الأَنْبِيَاءِ تَحْتَ شَجَرَةٍ فَلَدَغَتْهُ نَمْلَةٌ فَأَمَرَ بِجَهَازِهِ فَأُخْرِجَ مِنْ تَحْتِهَا ثُمَّ أَمَرَ بِهَا فَأُحْرِقَتْ فَأَوْحَى اللَّهُ إِلَيْهِ فَهَلاَّ نَمْلَةً وَاحِدَةً ‏"‏ ‏.‏\hadithno{5265}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3019) Sahih Muslim (2241)}\hadithtrans{Abu hurairah reported the prophet (peace be upon him) as saying :A prophet got down beneath a tree and he was stung by an ant. He ordered regarding the baggage and it was removed from beneath it. He then ordered regarding it and it was burnt. Allah then revealed to him : why not (just) one ant?}}
\hadithdefcmd{abudawud}{5266}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ نَمْلَةً قَرَصَتْ نَبِيًّا مِنَ الأَنْبِيَاءِ فَأَمَرَ بِقَرْيَةِ النَّمْلِ فَأُحْرِقَتْ فَأَوْحَى اللَّهُ إِلَيْهِ فِي أَنْ قَرَصَتْكَ نَمْلَةٌ أَهْلَكْتَ أُمَّةً مِنَ الأُمَمِ تُسَبِّحُ ‏"‏ ‏.‏\hadithno{5266}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Abu Hurairah reported Messenger of Allah (May peace be upon him) as saying :An ant stung a prophet. He ordered a colony of ants to be burned. Allah revealed to him : because an ant stung you, you have perished a community which glorifies Me}}
\hadithdefcmd{abudawud}{5267}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ أَرْبَعٍ مِنَ الدَّوَابِّ النَّمْلَةُ وَالنَّحْلَةُ وَالْهُدْهُدُ وَالصُّرَدُ ‏.‏\hadithno{5267}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) prohibited to kill four creatures: ants, bees, hoopoes, and sparrow-hawks}}
\hadithdefcmd{abudawud}{5268}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنِ ابْنِ سَعْدٍ، - قَالَ أَبُو دَاوُدَ وَهُوَ الْحَسَنُ بْنُ سَعْدٍ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَانْطَلَقَ لِحَاجَتِهِ فَرَأَيْنَا حُمَّرَةً مَعَهَا فَرْخَانِ فَأَخَذْنَا فَرْخَيْهَا فَجَاءَتِ الْحُمَّرَةُ فَجَعَلَتْ تُعَرِّشُ فَجَاءَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ فَجَعَ هَذِهِ بِوَلَدِهَا رُدُّوا وَلَدَهَا إِلَيْهَا ‏"‏ ‏.‏ وَرَأَى قَرْيَةَ نَمْلٍ قَدْ حَرَّقْنَاهَا فَقَالَ ‏"‏ مَنْ حَرَّقَ هَذِهِ ‏"‏ ‏.‏ قُلْنَا نَحْنُ ‏.‏ قَالَ ‏"‏ إِنَّهُ لاَ يَنْبَغِي أَنْ يُعَذِّبَ بِالنَّارِ إِلاَّ رَبُّ النَّارِ ‏"‏ ‏.‏\hadithno{5268}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{‘Abd al-Rahman b. ‘Abd Allah quoted his father as saying :When we were on a journey with the Messenger of Allah (ﷺ) and he had gone to releive himself, we saw a Hummarah with two young ones. We took the young ones. The Hummarah came and began to spread out its wings. Then the prophet (May peace be upon him) came and said : who has pained this young by the loss of her young? Give her young ones back to her. We also saw an ant-hill which we had burned. He asked? Who has burned this? We replied : we have. He said: it is not fitting that anyone but the lord of the fire should punish with fire}}
\hadithdefcmd{abudawud}{5269}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ خَالِدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عُثْمَانَ، أَنَّ طَبِيبًا، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ ضِفْدَعٍ يَجْعَلُهَا فِي دَوَاءٍ فَنَهَاهُ النَّبِيُّ صلى الله عليه وسلم عَنْ قَتْلِهَا ‏.‏\hadithno{5269}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated AbdurRahman ibn Uthman: When a physician consulted the Prophet (ﷺ) about putting frogs in medicine, he forbade him to kill them}}
\hadithdefcmd{abudawud}{5270}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عُقْبَةَ بْنِ صُهْبَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْخَذْفِ قَالَ ‏ "‏ إِنَّهُ لاَ يَصِيدُ صَيْدًا وَلاَ يَنْكَأُ عَدُوًّا وَإِنَّمَا يَفْقَأُ الْعَيْنَ وَيَكْسِرُ السِّنَّ ‏"‏ ‏.‏\hadithno{5270}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6220) Sahih Muslim (1954)}\hadithtrans{‘Abd b. Mughaffal said :The Messenger of Allah (ﷺ) prohibited throwing pebbles (in sport) saying : game is not caught by such means. Neither is an enemy injured, but it may sometimes put out an eye or break a tooth}}
\hadithdefcmd{abudawud}{5271}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، وَعَبْدُ الْوَهَّابِ بْنُ عَبْدِ الرَّحِيمِ الأَشْجَعِيُّ، قَالاَ حَدَّثَنَا مَرْوَانُ، حَدَّثَنَا مُحَمَّدُ بْنُ حَسَّانَ، - قَالَ عَبْدُ الْوَهَّابِ الْكُوفِيُّ - عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أُمِّ عَطِيَّةَ الأَنْصَارِيَّةِ، أَنَّ امْرَأَةً، كَانَتْ تَخْتِنُ بِالْمَدِينَةِ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُنْهِكِي فَإِنَّ ذَلِكَ أَحْظَى لِلْمَرْأَةِ وَأَحَبُّ إِلَى الْبَعْلِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رُوِيَ عَنْ عُبَيْدِ اللَّهِ بْنِ عَمْرٍو عَنْ عَبْدِ الْمَلِكِ بِمَعْنَاهُ وَإِسْنَادِهِ ‏.‏ قَالَ أَبُو دَاوُدَ لَيْسَ هُوَ بِالْقَوِيِّ وَقَدْ رُوِيَ مُرْسَلاً ‏.‏ قَالَ أَبُو دَاوُدَ وَمُحَمَّدُ بْنُ حَسَّانَ مَجْهُولٌ وَهَذَا الْحَدِيثُ ضَعِيفٌ ‏.‏\hadithno{5271}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Atiyyah al-Ansariyyah: A woman used to perform circumcision in Medina. The Prophet (ﷺ) said to her: Do not cut severely as that is better for a woman and more desirable for a husband. Abu Dawud said: It has been transmitted by 'Ubaid Allah b. 'Amr from 'Abd al-Malik to the same effect through a different chain. Abu Dawud said: It is not a strong tradition. It has been transmitted in mursal form (missing the link of the Companions) Abu Dawud said: Muhammad b. Hasan is obscure, and this tradition is weak}}
\hadithdefcmd{abudawud}{5272}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ عَنْ أَبِي الْيَمَانِ، عَنْ شَدَّادِ بْنِ أَبِي عَمْرِو بْنِ حِمَاسٍ، عَنْ أَبِيهِ، عَنْ حَمْزَةَ بْنِ أَبِي أُسَيْدٍ الأَنْصَارِيِّ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَهُوَ خَارِجٌ مِنَ الْمَسْجِدِ فَاخْتَلَطَ الرِّجَالُ مَعَ النِّسَاءِ فِي الطَّرِيقِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلنِّسَاءِ ‏ "‏ اسْتَأْخِرْنَ فَإِنَّهُ لَيْسَ لَكُنَّ أَنْ تَحْقُقْنَ الطَّرِيقَ عَلَيْكُنَّ بِحَافَاتِ الطَّرِيقِ ‏"‏ ‏.‏ فَكَانَتِ الْمَرْأَةُ تَلْتَصِقُ بِالْجِدَارِ حَتَّى إِنَّ ثَوْبَهَا لَيَتَعَلَّقُ بِالْجِدَارِ مِنْ لُصُوقِهَا بِهِ ‏.‏\hadithno{5272}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuUsayd al-Ansari: AbuUsayd heard the Messenger of Allah (ﷺ) say when he was coming out of the mosque, and men and women were mingled in the road: Draw back, for you must not walk in the middle of the road; keep to the sides of the road. Then women were keeping so close to the wall that their garments were rubbing against it}}
\hadithdefcmd{abudawud}{5273}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا أَبُو قُتَيْبَةَ، سَلْمُ بْنُ قُتَيْبَةَ عَنْ دَاوُدَ بْنِ أَبِي صَالِحٍ الْمُزَنِيِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَمْشِيَ - يَعْنِي الرَّجُلَ - بَيْنَ الْمَرْأَتَيْنِ ‏.‏\hadithno{5273}\hadithgrade{Al-Albani: Mawdu; Muhammad Muhyi Al-Din Abdul Hamid: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) prohibited that one, i.e. man, should walk between two women}}
\hadithdefcmd{abudawud}{5274}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، وَابْنُ السَّرْحِ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ يُؤْذِينِي ابْنُ آدَمَ يَسُبُّ الدَّهْرَ وَأَنَا الدَّهْرُ بِيَدِيَ الأَمْرُ أُقَلِّبُ اللَّيْلَ وَالنَّهَارَ ‏"‏ ‏.‏ قَالَ ابْنُ السَّرْحِ عَنِ ابْنِ الْمُسَيَّبِ مَكَانَ سَعِيدٍ ‏.‏ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{5274}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4826) Sahih Muslim (2246)}\hadithtrans{Abu Hurairah reported the prophet (ﷺ) as saying:Allah most high says : “The son of Adam injures me by abusing time, whereas I am time. Authority is in my hand. I alternate the night and the day”. Ibn al-Sarh said: “on the authority of Ibn al-Musayyab instead of Sa’id’}}
