% Auto-generated chapter 62 for bukhari
% Hadiths in this chapter: 120

\hadithdefcmd{bukhari}{3649}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ حَدَّثَنَا أَبُو سَعِيدٍ الْخُدْرِيُّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ فَيَغْزُو فِئَامٌ مِنَ النَّاسِ، فَيَقُولُونَ فِيكُمْ مَنْ صَاحَبَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَيَقُولُونَ نَعَمْ‏.‏ فَيُفْتَحُ لَهُمْ‏.‏ ثُمَّ يَأْتِي عَلَى النَّاسِ زَمَانٌ فَيَغْزُو فِئَامٌ مِنَ النَّاسِ، فَيُقَالُ هَلْ فِيكُمْ مَنْ صَاحَبَ أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَقُولُونَ نَعَمْ‏.‏ فَيُفْتَحُ لَهُمْ، ثُمَّ يَأْتِي عَلَى النَّاسِ زَمَانٌ فَيَغْزُو فِئَامٌ مِنَ النَّاسِ، فَيُقَالُ هَلْ فِيكُمْ مَنْ صَاحَبَ مَنْ صَاحَبَ أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَقُولُونَ نَعَمْ‏.‏ فَيُفْتَحُ لَهُمْ ‏"‏‏.‏\hadithno{3649}\hadithtrans{Narrated Abu Sa`id Al-Khudri:"Allah's Messenger (ﷺ) said, "A time will come upon the people, when a group of people will wage a holy war and it will be said, 'Is there amongst you anyone who has accompanied Allah's Messenger (ﷺ)?' They will say, 'Yes.' And so victory will be bestowed on them. Then a time will come upon the people when a group of people will wage a holy war, and it will be said, "Is there amongst you anyone who has accompanied the companions of Allah's Messenger (ﷺ)?' They will say, 'Yes.' And so victory will be bestowed on them. Then a time will come upon the people when a group of people will wage a holy war, and it will be said, "Is there amongst you anyone who has been in the company of the companions of the companions of Allah's Messenger (ﷺ) ?' They will say, 'Yes.' And victory will be bestowed on them}}
\hadithdefcmd{bukhari}{3650}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا النَّضْرُ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي جَمْرَةَ، سَمِعْتُ زَهْدَمَ بْنَ مُضَرِّبٍ، سَمِعْتُ عِمْرَانَ بْنَ حُصَيْنٍ ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ أُمَّتِي قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏‏.‏ قَالَ عِمْرَانُ فَلاَ أَدْرِي أَذَكَرَ بَعْدَ قَرْنِهِ قَرْنَيْنِ أَوْ ثَلاَثًا ‏"‏ ثُمَّ إِنَّ بَعْدَكُمْ قَوْمًا يَشْهَدُونَ وَلاَ يُسْتَشْهَدُونَ، وَيَخُونُونَ وَلاَ يُؤْتَمَنُونَ، وَيَنْذُرُونَ وَلاَ يَفُونَ، وَيَظْهَرُ فِيهِمُ السِّمَنُ ‏"‏‏.‏\hadithno{3650}\hadithtrans{Narrated `Imran bin Husain:"Allah's Messenger (ﷺ) said, 'The best of my followers are those living in my generation (i.e. my contemporaries). and then those who will follow the latter" `Imran added, "I do not remember whether he mentioned two or three generations after his generation, then the Prophet (ﷺ) added, 'There will come after you, people who will bear witness without being asked to do so, and will be treacherous and untrustworthy, and they will vow and never fulfill their vows, and fatness will appear among them}}
\hadithdefcmd{bukhari}{3651}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ النَّاسِ قَرْنِي، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ يَجِيءُ قَوْمٌ تَسْبِقُ شَهَادَةُ أَحَدِهِمْ يَمِينَهُ وَيَمِينُهُ شَهَادَتَهُ ‏"‏‏.‏ قَالَ إِبْرَاهِيمُ وَكَانُوا يَضْرِبُونَا عَلَى الشَّهَادَةِ وَالْعَهْدِ وَنَحْنُ صِغَارٌ‏.‏\hadithno{3651}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "The best people are those living in my generation, and then those who will follow them, and then those who will follow the latter. Then there will come some people who will bear witness before taking oaths, and take oaths before bearing witness." (Ibrahim, a sub-narrator said, "They used to beat us for witnesses and covenants when we were still children)}}
\hadithdefcmd{bukhari}{3652}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ اشْتَرَى أَبُو بَكْرٍ ـ رضى الله عنه ـ مِنْ عَازِبٍ رَحْلاً بِثَلاَثَةَ عَشَرَ دِرْهَمًا فَقَالَ أَبُو بَكْرٍ لِعَازِبٍ مُرِ الْبَرَاءَ فَلْيَحْمِلْ إِلَىَّ رَحْلِي‏.‏ فَقَالَ عَازِبٌ لاَ حَتَّى تُحَدِّثَنَا كَيْفَ صَنَعْتَ أَنْتَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ خَرَجْتُمَا مِنْ مَكَّةَ وَالْمُشْرِكُونَ يَطْلُبُونَكُمْ قَالَ ارْتَحَلْنَا مِنْ مَكَّةَ، فَأَحْيَيْنَا أَوْ سَرَيْنَا لَيْلَتَنَا وَيَوْمَنَا حَتَّى أَظْهَرْنَا وَقَامَ قَائِمُ الظَّهِيرَةِ، فَرَمَيْتُ بِبَصَرِي هَلْ أَرَى مِنْ ظِلٍّ فَآوِيَ إِلَيْهِ، فَإِذَا صَخْرَةٌ أَتَيْتُهَا فَنَظَرْتُ بَقِيَّةَ ظِلٍّ لَهَا فَسَوَّيْتُهُ، ثُمَّ فَرَشْتُ لِلنَّبِيِّ صلى الله عليه وسلم فِيهِ، ثُمَّ قُلْتُ لَهُ اضْطَجِعْ يَا نَبِيَّ اللَّهِ‏.‏ فَاضْطَجَعَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ انْطَلَقْتُ أَنْظُرُ مَا حَوْلِي، هَلْ أَرَى مِنَ الطَّلَبِ أَحَدًا فَإِذَا أَنَا بِرَاعِي غَنَمٍ يَسُوقُ غَنَمَهُ إِلَى الصَّخْرَةِ يُرِيدُ مِنْهَا الَّذِي أَرَدْنَا، فَسَأَلْتُهُ فَقُلْتُ لَهُ لِمَنْ أَنْتَ يَا غُلاَمُ قَالَ لِرَجُلٍ مِنْ قُرَيْشٍ سَمَّاهُ فَعَرَفْتُهُ‏.‏ فَقُلْتُ هَلْ فِي غَنَمِكَ مِنْ لَبَنٍ قَالَ نَعَمْ‏.‏ قُلْتُ فَهَلْ أَنْتَ حَالِبٌ لَبَنًا قَالَ نَعَمْ‏.‏ فَأَمَرْتُهُ فَاعْتَقَلَ شَاةً مِنْ غَنَمِهِ، ثُمَّ أَمَرْتُهُ أَنْ يَنْفُضَ ضَرْعَهَا مِنَ الْغُبَارِ، ثُمَّ أَمَرْتُهُ أَنْ يَنْفُضَ كَفَّيْهِ، فَقَالَ هَكَذَا ضَرَبَ إِحْدَى كَفَّيْهِ بِالأُخْرَى فَحَلَبَ لِي كُثْبَةً مِنْ لَبَنٍ، وَقَدْ جَعَلْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِدَاوَةً عَلَى فَمِهَا خِرْقَةٌ، فَصَبَبْتُ عَلَى اللَّبَنِ حَتَّى بَرَدَ أَسْفَلُهُ، فَانْطَلَقْتُ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَوَافَقْتُهُ قَدِ اسْتَيْقَظَ، فَقُلْتُ اشْرَبْ يَا رَسُولَ اللَّهِ‏.‏ فَشَرِبَ حَتَّى رَضِيتُ ثُمَّ قُلْتُ قَدْ آنَ الرَّحِيلُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ بَلَى ‏"‏‏.‏ فَارْتَحَلْنَا وَالْقَوْمُ يَطْلُبُونَا، فَلَمْ يُدْرِكْنَا أَحَدٌ مِنْهُمْ غَيْرُ سُرَاقَةَ بْنِ مَالِكِ بْنِ جُعْشُمٍ عَلَى فَرَسٍ لَهُ‏.‏ فَقُلْتُ هَذَا الطَّلَبُ قَدْ لَحِقَنَا يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ لاَ تَحْزَنْ إِنَّ اللَّهَ مَعَنَا ‏"‏‏.‏\hadithno{3652}\hadithtrans{Narrated Al-Bara':Abu Bakr bought a (camel) saddle from `Azib for thirteen Dirhams. Abu Bakr said to `Azib, "Tell Al- Bara' to carry the saddle for me." `Azib said, "No, unless you relate to me what happened to you and Allah's Messenger (ﷺ) when you left Mecca while the pagans were in search of you." Abu Bakr said, "We left Mecca and we traveled continuously for that night and the following day till it was midday. I looked (around) searching for shade to take as shelter, and suddenly I came across a rock, and found a little shade there. So I cleaned the place and spread a bed for the Prophet (ﷺ) in the shade and said to him, 'Lie down, O Allah's Messenger (ﷺ).' So the Prophet (ﷺ) lay down and I went out, looking around to see if there was any person pursuing us. Suddenly I saw a shepherd driving his sheep towards the rock, seeking what we had already sought from it. I asked him, 'To whom do you belong, O boy?' He said, 'I belong to a man from Quraish.' He named the man and I recognized him. I asked him, 'Is there any milk with your sheep?' He said, 'Yes.' I said, 'Will you then milk (some) for us?' He said, 'Yes.' Then I asked him to tie the legs of one of the sheep and clean its udder, and then ordered him to clean his hands from dust. Then the shepherd cleaned his hands by striking his hands against one another. After doing so, he milked a small amount of milk. I used to keep for Allah's Messenger (ﷺ) a leather water-container, the mouth of which was covered with a piece of cloth. I poured water on the milk container till its lower part was cold. Then I took the milk to the Prophet (ﷺ) whom I found awake. I said to him, 'Drink, O Allah's Messenger (ﷺ).' So he drank till I became pleased. Then I said, 'It is time for us to move, O Allah's Apostle!' He said, 'Yes.' So we set out while the people (i.e. Quraish pagans) were searching for us, but none found us except Suraqah bin Malik bin Ju`shum who was riding his horse. I said, 'These are our pursuers who have found us. O Allah's Messenger (ﷺ)!' He said, 'Do not grieve, for Allah is with us}}
\hadithdefcmd{bukhari}{3653}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا هَمَّامٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، عَنْ أَبِي بَكْرٍ ـ رضى الله عنه ـ قَالَ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم وَأَنَا فِي الْغَارِ لَوْ أَنَّ أَحَدَهُمْ نَظَرَ تَحْتَ قَدَمَيْهِ لأَبْصَرَنَا‏.‏ فَقَالَ ‏ "‏ مَا ظَنُّكَ يَا أَبَا بَكْرٍ بِاثْنَيْنِ اللَّهُ ثَالِثُهُمَا ‏"‏‏.‏\hadithno{3653}\hadithtrans{Narrated Abu Bakr:I said to the Prophet (ﷺ) while I was in the Cave. "If any of them should look under his feet, he would see us." He said, "O Abu Bakr! What do you think of two (persons) the third of whom is Allah?}}
\hadithdefcmd{bukhari}{3654}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا فُلَيْحٌ، قَالَ حَدَّثَنِي سَالِمٌ أَبُو النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ وَقَالَ ‏"‏ إِنَّ اللَّهَ خَيَّرَ عَبْدًا بَيْنَ الدُّنْيَا وَبَيْنَ مَا عِنْدَهُ فَاخْتَارَ ذَلِكَ الْعَبْدُ مَا عِنْدَ اللَّهِ ‏"‏‏.‏ قَالَ فَبَكَى أَبُو بَكْرٍ، فَعَجِبْنَا لِبُكَائِهِ أَنْ يُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ عَبْدٍ خُيِّرَ‏.‏ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُوَ الْمُخَيَّرُ وَكَانَ أَبُو بَكْرٍ أَعْلَمَنَا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ أَمَنِّ النَّاسِ عَلَىَّ فِي صُحْبَتِهِ وَمَالِهِ أَبَا بَكْرٍ، وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً غَيْرَ رَبِّي لاَتَّخَذْتُ أَبَا بَكْرٍ، وَلَكِنْ أُخُوَّةُ الإِسْلاَمِ وَمَوَدَّتُهُ، لاَ يَبْقَيَنَّ فِي الْمَسْجِد ِباب إِلاَّ سُدَّ، إِلاَّ باب أَبِي بَكْرٍ ‏"‏‏.‏\hadithno{3654}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) addressed the people saying, "Allah has given option to a slave to choose this world or what is with Him. The slave has chosen what is with Allah." Abu Bakr wept, and we were astonished at his weeping caused by what the Prophet (ﷺ) mentioned as to a Slave ( of Allah) who had been offered a choice, (we learned later on) that Allah's Messenger (ﷺ) himself was the person who was given the choice, and that Abu Bakr knew best of all of us. Allah's Messenger (ﷺ) added, "The person who has favored me most of all both with his company and wealth, is Abu Bakr. If I were to take a Khalil other than my Lord, I would have taken Abu Bakr as such, but (what relates us) is the Islamic brotherhood and friendliness. All the gates of the Mosque should be closed except the gate of Abu Bakr}}
\hadithdefcmd{bukhari}{3655}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنَّا نُخَيِّرُ بَيْنَ النَّاسِ فِي زَمَنِ النَّبِيِّ صلى الله عليه وسلم فَنُخَيِّرُ أَبَا بَكْرٍ، ثُمَّ عُمَرَ بْنَ الْخَطَّابِ، ثُمَّ عُثْمَانَ بْنَ عَفَّانَ رضى الله عنهم‏.‏\hadithno{3655}\hadithtrans{Narrated Ibn `Umar:We used to compare the people as to who was better during the lifetime of Allah's Messenger (ﷺ) . We used to regard Abu Bakr as the best, then `Umar, and then `Uthman}}
\hadithdefcmd{bukhari}{3656}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَلَوْ كُنْتُ مُتَّخِذًا مِنْ أُمَّتِي خَلِيلاً لاَتَّخَذْتُ، أَبَا بَكْرٍ وَلَكِنْ أَخِي وَصَاحِبِي ‏"‏‏.‏\hadithno{3656}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "If I were to take a Khalil, I would have taken Abu Bakr, but he is my brother and my companion (in Islam)}}
\hadithdefcmd{bukhari}{3657}{حَدَّثَنَا مُعَلَّى، وَمُوسَى، قَالاَ حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، وَقَالَ، ‏ "‏ لَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُهُ خَلِيلاً، وَلَكِنْ أُخُوَّةُ الإِسْلاَمِ أَفْضَلُ ‏"‏‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، مِثْلَهُ‏.‏\hadithno{3657}\hadithtrans{Narrated Aiyub:The Prophet (ﷺ) said, "If I were to take a Khalil, I would have taken him (i.e. Abu Bakr) as a Khalil, but the Islamic brotherhood is better}}
\hadithdefcmd{bukhari}{3658}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، قَالَ كَتَبَ أَهْلُ الْكُوفَةِ إِلَى ابْنِ الزُّبَيْرِ فِي الْجَدِّ‏.‏ فَقَالَ أَمَّا الَّذِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ مُتَّخِذًا مِنْ هَذِهِ الأُمَّةِ خَلِيلاً لاَتَّخَذْتُهُ ‏"‏‏.‏ أَنْزَلَهُ أَبًا يَعْنِي أَبَا بَكْرٍ‏.‏\hadithno{3658}\hadithtrans{Narrated `Abdullah bin Abi Mulaika:The people of Kufa sent a letter to Ibn Az-Zubair, asking about (the inheritance of) (paternal) grandfather. He replied that the right of the inheritance of (paternal) grandfather is the same as that of father if the father is dead) and added, "Allah's Messenger (ﷺ) said, ' If I were to take a Khalil from this nation, I would have taken him (i.e. Abu Bakr)}}
\hadithdefcmd{bukhari}{3659}{حَدَّثَنَا الْحُمَيْدِيُّ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ أَتَتِ امْرَأَةٌ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهَا أَنْ تَرْجِعَ إِلَيْهِ‏.‏ قَالَتْ أَرَأَيْتَ إِنْ جِئْتُ وَلَمْ أَجِدْكَ كَأَنَّهَا تَقُولُ الْمَوْتَ‏.‏ قَالَ عَلَيْهِ السَّلاَمُ ‏ "‏ إِنْ لَمْ تَجِدِينِي فَأْتِي أَبَا بَكْرٍ ‏"‏‏.‏\hadithno{3659}\hadithtrans{Narrated Jubair bin Mut`im:A woman came to the Prophet (ﷺ) who ordered her to return to him again. She said, "What if I came and did not find you?" as if she wanted to say, "If I found you dead?" The Prophet (ﷺ) said, "If you should not find me, go to Abu Bakr}}
\hadithdefcmd{bukhari}{3660}{حَدَّثَنِي أَحْمَدُ بْنُ أَبِي الطَّيِّبِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُجَالِدٍ، حَدَّثَنَا بَيَانُ بْنُ بِشْرٍ، عَنْ وَبَرَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ هَمَّامٍ، قَالَ سَمِعْتُ عَمَّارًا، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَا مَعَهُ إِلاَّ خَمْسَةُ أَعْبُدٍ وَامْرَأَتَانِ وَأَبُو بَكْرٍ‏.‏\hadithno{3660}\hadithtrans{Narrated `Ammar:I saw Allah's Messenger (ﷺ) and there was none with him but five slaves, two women and Abu Bakr (i.e. those were the only converts to Islam then)}}
\hadithdefcmd{bukhari}{3661}{حَدَّثَنِي هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَائِذِ اللَّهِ أَبِي إِدْرِيسَ، عَنْ أَبِي الدَّرْدَاءِ ـ رضى الله عنه ـ قَالَ كُنْتُ جَالِسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ أَقْبَلَ أَبُو بَكْرٍ آخِذًا بِطَرَفِ ثَوْبِهِ حَتَّى أَبْدَى عَنْ رُكْبَتِهِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمَّا صَاحِبُكُمْ فَقَدْ غَامَرَ ‏"‏‏.‏ فَسَلَّمَ، وَقَالَ إِنِّي كَانَ بَيْنِي وَبَيْنَ ابْنِ الْخَطَّابِ شَىْءٌ فَأَسْرَعْتُ إِلَيْهِ ثُمَّ نَدِمْتُ، فَسَأَلْتُهُ أَنْ يَغْفِرَ لِي فَأَبَى عَلَىَّ، فَأَقْبَلْتُ إِلَيْكَ فَقَالَ ‏"‏ يَغْفِرُ اللَّهُ لَكَ يَا أَبَا بَكْرٍ ‏"‏‏.‏ ثَلاَثًا، ثُمَّ إِنَّ عُمَرَ نَدِمَ فَأَتَى مَنْزِلَ أَبِي بَكْرٍ فَسَأَلَ أَثَمَّ أَبُو بَكْرٍ فَقَالُوا لاَ‏.‏ فَأَتَى إِلَى النَّبِيِّ صلى الله عليه وسلم، فَسَلَّمَ فَجَعَلَ وَجْهُ النَّبِيِّ صلى الله عليه وسلم يَتَمَعَّرُ حَتَّى أَشْفَقَ أَبُو بَكْرٍ، فَجَثَا عَلَى رُكْبَتَيْهِ فَقَالَ يَا رَسُولَ اللَّهِ، وَاللَّهِ أَنَا كُنْتُ أَظْلَمَ مَرَّتَيْنِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ بَعَثَنِي إِلَيْكُمْ فَقُلْتُمْ كَذَبْتَ‏.‏ وَقَالَ أَبُو بَكْرٍ صَدَقَ‏.‏ وَوَاسَانِي بِنَفْسِهِ وَمَالِهِ، فَهَلْ أَنْتُمْ تَارِكُو لِي صَاحِبِي ‏"‏‏.‏ مَرَّتَيْنِ فَمَا أُوذِيَ بَعْدَهَا‏.‏\hadithno{3661}\hadithtrans{Narrated Abu Ad-Darda:While I was sitting with the Prophet, Abu Bakr came, lifting up one corner of his garment uncovering his knee. The Prophet (ﷺ) said, "Your companion has had a quarrel." Abu Bakr greeted (the Prophet (ﷺ) ) and said, "O Allah's Messenger (ﷺ)! There was something (i.e. quarrel) between me and the Son of Al-Khattab. I talked to him harshly and then regretted that, and requested him to forgive me, but he refused. This is why I have come to you." The Prophet (ﷺ) said thrice, "O Abu Bakr! May Allah forgive you." In the meanwhile, `Umar regretted (his refusal of Abu Bakr's excuse) and went to Abu Bakr's house and asked if Abu Bakr was there. They replied in the negative. So he came to the Prophet (ﷺ) and greeted him, but signs of displeasure appeared on the face of the Prophet (ﷺ) till Abu Bakr pitied (`Umar), so he knelt and said twice, "O Allah's Messenger (ﷺ)! By Allah! I was more unjust to him (than he to me)." The Prophet (ﷺ) said, "Allah sent me (as a Prophet) to you (people) but you said (to me), 'You are telling a lie,' while Abu Bakr said, 'He has said the truth,' and consoled me with himself and his money." He then said twice, "Won't you then give up harming my companion?" After that nobody harmed Abu Bakr}}
\hadithdefcmd{bukhari}{3662}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، قَالَ خَالِدٌ الْحَذَّاءُ حَدَّثَنَا عَنْ أَبِي عُثْمَانَ، قَالَ حَدَّثَنِي عَمْرُو بْنُ الْعَاصِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَهُ عَلَى جَيْشِ ذَاتِ السَّلاَسِلِ، فَأَتَيْتُهُ فَقُلْتُ أَىُّ النَّاسِ أَحَبُّ إِلَيْكَ قَالَ ‏"‏ عَائِشَةُ ‏"‏‏.‏ فَقُلْتُ مِنَ الرِّجَالِ فَقَالَ ‏"‏ أَبُوهَا ‏"‏‏.‏ قُلْتُ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ عُمَرُ بْنُ الْخَطَّابِ ‏"‏‏.‏ فَعَدَّ رِجَالاً‏.‏\hadithno{3662}\hadithtrans{Narrated `Amr bin Al-As:The Prophet (ﷺ) deputed me to lead the Army of Dhat-as-Salasil. I came to him and said, "Who is the most beloved person to you?" He said, "`Aisha." I asked, "Among the men?" He said, "Her father." I said, "Who then?" He said, "Then `Umar bin Al-Khattab." He then named other men}}
\hadithdefcmd{bukhari}{3663}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ بَيْنَمَا رَاعٍ فِي غَنَمِهِ عَدَا عَلَيْهِ الذِّئْبُ، فَأَخَذَ مِنْهَا شَاةً، فَطَلَبَهُ الرَّاعِي، فَالْتَفَتَ إِلَيْهِ الذِّئْبُ فَقَالَ مَنْ لَهَا يَوْمَ السَّبُعِ، يَوْمَ لَيْسَ لَهَا رَاعٍ غَيْرِي، وَبَيْنَا رَجُلٌ يَسُوقُ بَقَرَةً قَدْ حَمَلَ عَلَيْهَا، فَالْتَفَتَتْ إِلَيْهِ فَكَلَّمَتْهُ فَقَالَتْ إِنِّي لَمْ أُخْلَقْ لِهَذَا، وَلَكِنِّي خُلِقْتُ لِلْحَرْثِ ‏"‏‏.‏ قَالَ النَّاسُ سُبْحَانَ اللَّهِ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَإِنِّي أُومِنُ بِذَلِكَ وَأَبُو بَكْرٍ وَعُمَرُ بْنُ الْخَطَّابِ رضى الله عنهما ‏"‏‏.‏\hadithno{3663}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "While a shepherd was amongst his sheep, a wolf attacked them and took away one sheep. When the shepherd chased the wolf, the wolf turned towards him and said, 'Who will be its guard on the day of wild animals when nobody except I will be its shepherd?' And while a man was driving a cow with a load on it, it turned towards him and spoke to him saying, 'I have not been created for this purpose, but for ploughing." The people said, "Glorified be Allah." The Prophet said, "But I believe in it and so do Abu Bakr and `Umar}}
\hadithdefcmd{bukhari}{3664}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي ابْنُ الْمُسَيَّبِ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُنِي عَلَى قَلِيبٍ عَلَيْهَا دَلْوٌ، فَنَزَعْتُ مِنْهَا مَا شَاءَ اللَّهُ، ثُمَّ أَخَذَهَا ابْنُ أَبِي قُحَافَةَ، فَنَزَعَ بِهَا ذَنُوبًا أَوْ ذَنُوبَيْنِ، وَفِي نَزْعِهِ ضَعْفٌ، وَاللَّهُ يَغْفِرُ لَهُ ضَعْفَهُ، ثُمَّ اسْتَحَالَتْ غَرْبًا، فَأَخَذَهَا ابْنُ الْخَطَّابِ، فَلَمْ أَرَ عَبْقَرِيًّا مِنَ النَّاسِ يَنْزِعُ نَزْعَ عُمَرَ، حَتَّى ضَرَبَ النَّاسُ بِعَطَنٍ ‏"‏‏.‏\hadithno{3664}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "While I was sleeping, I saw myself standing at a well, on it there was a bucket. I drew water from the well as much as Allah wished. Then Ibn Abi Quhafa (i.e. Abu Bakr) took the bucket from me and brought out one or two buckets (of water) and there was weakness in his drawing the water. May Allah forgive his weakness for him. Then the bucket turned into a very big one and Ibn Al-Khattab took it over and I had never seen such a mighty person amongst the people as him in performing such hard work, till the people drank to their satisfaction and watered their camels that knelt down there}}
\hadithdefcmd{bukhari}{3665}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ جَرَّ ثَوْبَهُ خُيَلاَءَ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ إِنَّ أَحَدَ شِقَّىْ ثَوْبِي يَسْتَرْخِي إِلاَّ أَنْ أَتَعَاهَدَ ذَلِكَ مِنْهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكَ لَسْتَ تَصْنَعُ ذَلِكَ خُيَلاَءَ ‏"‏ قَالَ مُوسَى فَقُلْتُ لِسَالِمٍ أَذَكَرَ عَبْدُ اللَّهِ مَنْ جَرَّ إِزَارَهُ قَالَ لَمْ أَسْمَعْهُ ذَكَرَ إِلاَّ ثَوْبَهُ‏.‏\hadithno{3665}\hadithtrans{Narrated `Abdullah bin `Umar:That Allah's Messenger (ﷺ) said, "Allah will not look on the Day of Judgment at him who drags his robe (behind him) out of pride." Abu Bakr said "One side of my robe slacks down unless I get very cautious about it." Allah's Messenger (ﷺ) said, "But you do not do that with pride}}
\hadithdefcmd{bukhari}{3666}{حَدَّثَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ مِنْ شَىْءٍ مِنَ الأَشْيَاءِ فِي سَبِيلِ اللَّهِ دُعِيَ مِنْ أَبْوَابِ ـ يَعْنِي الْجَنَّةَ ـ يَا عَبْدَ اللَّهِ هَذَا خَيْرٌ، فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ دُعِيَ مِنْ باب الصَّلاَةِ، وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ دُعِيَ مِنْ باب الْجِهَادِ، وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ دُعِيَ مِنْ باب الصَّدَقَةِ، وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ باب الصِّيَامِ، وَبَابِ الرَّيَّانِ ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ مَا عَلَى هَذَا الَّذِي يُدْعَى مِنْ تِلْكَ الأَبْوَابِ مِنْ ضَرُورَةٍ، وَقَالَ هَلْ يُدْعَى مِنْهَا كُلِّهَا أَحَدٌ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَعَمْ، وَأَرْجُو أَنْ تَكُونَ مِنْهُمْ يَا أَبَا بَكْرٍ ‏"‏‏.‏\hadithno{3666}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "Anybody who spends a pair of something in Allah's Cause will be called from all the gates of Paradise, "O Allah's slave! This is good.' He who is amongst those who pray will be called from the gate of the prayer (in Paradise) and he who is from the people of Jihad will be called from the gate of Jihad, and he who is from those' who give in charity (i.e. Zakat) will be called from the gate of charity, and he who is amongst those who observe fast will be called from the gate of fasting, the gate of Raiyan." Abu Bakr said, "He who is called from all those gates will need nothing," He added, "Will anyone be called from all those gates, O Allah's Messenger (ﷺ)?" He said, "Yes, and I hope you will be among those, O Abu Bakr}}
\hadithdefcmd{bukhari}{3668}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَاتَ وَأَبُو بَكْرٍ بِالسُّنْحِ ـ قَالَ إِسْمَاعِيلُ يَعْنِي بِالْعَالِيَةِ ـ فَقَامَ عُمَرُ يَقُولُ وَاللَّهِ مَا مَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَتْ وَقَالَ عُمَرُ وَاللَّهِ مَا كَانَ يَقَعُ فِي نَفْسِي إِلاَّ ذَاكَ وَلَيَبْعَثَنَّهُ اللَّهُ فَلَيَقْطَعَنَّ أَيْدِيَ رِجَالٍ وَأَرْجُلَهُمْ‏.‏ فَجَاءَ أَبُو بَكْرٍ فَكَشَفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَبَّلَهُ قَالَ بِأَبِي أَنْتَ وَأُمِّي طِبْتَ حَيًّا وَمَيِّتًا، وَالَّذِي نَفْسِي بِيَدِهِ لاَ يُذِيقُكَ اللَّهُ الْمَوْتَتَيْنِ أَبَدًا‏.‏ ثُمَّ خَرَجَ فَقَالَ أَيُّهَا الْحَالِفُ عَلَى رِسْلِكَ‏.‏ فَلَمَّا تَكَلَّمَ أَبُو بَكْرٍ جَلَسَ عُمَرُ‏.‏ فَحَمِدَ اللَّهَ أَبُو بَكْرٍ وَأَثْنَى عَلَيْهِ وَقَالَ أَلاَ مَنْ كَانَ يَعْبُدُ مُحَمَّدًا صلى الله عليه وسلم فَإِنَّ مُحَمَّدًا قَدْ مَاتَ، وَمَنْ كَانَ يَعْبُدُ اللَّهَ فَإِنَّ اللَّهَ حَىٌّ لاَ يَمُوتُ‏.‏ وَقَالَ ‏\{‏إِنَّكَ مَيِّتٌ وَإِنَّهُمْ مَيِّتُونَ‏\}‏ وَقَالَ ‏\{‏وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ قَدْ خَلَتْ مِنْ قَبْلِهِ الرُّسُلُ أَفَإِنْ مَاتَ أَوْ قُتِلَ انْقَلَبْتُمْ عَلَى أَعْقَابِكُمْ وَمَنْ يَنْقَلِبْ عَلَى عَقِبَيْهِ فَلَنْ يَضُرَّ اللَّهَ شَيْئًا وَسَيَجْزِي اللَّهُ الشَّاكِرِينَ‏\}‏ قَالَ فَنَشَجَ النَّاسُ يَبْكُونَ ـ قَالَ ـ وَاجْتَمَعَتِ الأَنْصَارُ إِلَى سَعْدِ بْنِ عُبَادَةَ فِي سَقِيفَةِ بَنِي سَاعِدَةَ فَقَالُوا مِنَّا أَمِيرٌ وَمِنْكُمْ أَمِيرٌ، فَذَهَبَ إِلَيْهِمْ أَبُو بَكْرٍ وَعُمَرُ بْنُ الْخَطَّابِ وَأَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ، فَذَهَبَ عُمَرُ يَتَكَلَّمُ فَأَسْكَتَهُ أَبُو بَكْرٍ، وَكَانَ عُمَرُ يَقُولُ وَاللَّهِ مَا أَرَدْتُ بِذَلِكَ إِلاَّ أَنِّي قَدْ هَيَّأْتُ كَلاَمًا قَدْ أَعْجَبَنِي خَشِيتُ أَنْ لاَ يَبْلُغَهُ أَبُو بَكْرٍ، ثُمَّ تَكَلَّمَ أَبُو بَكْرٍ فَتَكَلَّمَ أَبْلَغَ النَّاسِ فَقَالَ فِي كَلاَمِهِ نَحْنُ الأُمَرَاءُ وَأَنْتُمُ الْوُزَرَاءُ‏.‏ فَقَالَ حُبَابُ بْنُ الْمُنْذِرِ لاَ وَاللَّهِ لاَ نَفْعَلُ، مِنَّا أَمِيرٌ وَمِنْكُمْ أَمِيرٌ‏.‏ فَقَالَ أَبُو بَكْرٍ لاَ، وَلَكِنَّا الأُمَرَاءُ وَأَنْتُمُ الْوُزَرَاءُ هُمْ أَوْسَطُ الْعَرَبِ دَارًا، وَأَعْرَبُهُمْ أَحْسَابًا فَبَايِعُوا عُمَرَ أَوْ أَبَا عُبَيْدَةَ‏.‏ فَقَالَ عُمَرُ بَلْ نُبَايِعُكَ أَنْتَ، فَأَنْتَ سَيِّدُنَا وَخَيْرُنَا وَأَحَبُّنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَأَخَذَ عُمَرُ بِيَدِهِ فَبَايَعَهُ، وَبَايَعَهُ النَّاسُ، فَقَالَ قَائِلٌ قَتَلْتُمْ سَعْدَ بْنَ عُبَادَةَ‏.‏ فَقَالَ عُمَرُ قَتَلَهُ اللَّهُ‏.‏\hadithno{3668}\hadithtrans{Narrated 'Aisha: (the wife of the Prophet) Allah's Messenger (ﷺ) died while Abu Bakr was at a place called As-Sunah (Al-'Aliya) 'Umar stood up and said, "By Allah! Allah's Messenger (ﷺ) is not dead!" 'Umar (later on) said, "By Allah! Nothing occurred to my mind except that." He said, "Verily! Allah will resurrect him and he will cut the hands and legs of some men." Then Abu Bakr came and uncovered the face of Allah's Messenger (ﷺ), kissed him and said, "Let my mother and father be sacrificed for you, (O Allah's Messenger (ﷺ)), you are good in life and in death. By Allah in Whose Hands my life is, Allah will never make you taste death twice." Then he went out and said, "O oath-taker! Don't be hasty." When Abu Bakr spoke, 'Umar sat down. Abu Bakr praised and glorified Allah and said, No doubt! Whoever worshipped Muhammad, then Muhammad is dead, but whoever worshipped Allah, then Allah is Alive and shall never die." Then he recited Allah's Statement.:-- "(O Muhammad) Verily you will die, and they also will die." (39.30) He also recited:-- "Muhammad is no more than an Apostle; and indeed many Apostles have passed away, before him, If he dies Or is killed, will you then Turn back on your heels? And he who turns back On his heels, not the least Harm will he do to Allah And Allah will give reward to those Who are grateful." (3.144) The people wept loudly, and the Ansar were assembled with Sad bin 'Ubada in the shed of Bani Saida. They said (to the emigrants). "There should be one 'Amir from us and one from you." Then Abu Bakr, Umar bin Al-Khattab and Abu 'baida bin Al-Jarrah went to them. 'Umar wanted to speak but Abu Bakr stopped him. 'Umar later on used to say, "By Allah, I intended only to say something that appealed to me and I was afraid that Abu Bakr would not speak so well. Then Abu Bakr spoke and his speech was very eloquent. He said in his statement, "We are the rulers and you (Ansars) are the ministers (i.e. advisers)," Hubab bin Al-Mundhir said, "No, by Allah we won't accept this. But there must be a ruler from us and a ruler from you." Abu Bakr said, "No, we will be the rulers and you will be the ministers, for they (i.e. Quraish) are the best family amongst the 'Arabs and of best origin. So you should elect either 'Umar or Abu 'Ubaida bin Al-Jarrah as your ruler." 'Umar said (to Abu Bakr), "No but we elect you, for you are our chief and the best amongst us and the most beloved of all of us to Allah's Messenger (ﷺ)." So 'Umar took Abu Bakr's hand and gave the pledge of allegiance and the people too gave the pledge of allegiance to Abu Bakr. Someone said, "You have killed Sad bin Ubada." 'Umar said, "Allah has killed him}}
\hadithdefcmd{bukhari}{3670}{وَقَالَ عَبْدُ اللَّهِ بْنُ سَالِمٍ عَنِ الزُّبَيْدِيِّ، قَالَ عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ أَخْبَرَنِي الْقَاسِمُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ شَخَصَ بَصَرُ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ فِي الرَّفِيقِ الأَعْلَى ‏"‏‏.‏ ثَلاَثًا، وَقَصَّ الْحَدِيثَ، قَالَتْ فَمَا كَانَتْ مِنْ خُطْبَتِهِمَا مِنْ خُطْبَةٍ إِلاَّ نَفَعَ اللَّهُ بِهَا، لَقَدْ خَوَّفَ عُمَرُ النَّاسَ وَإِنَّ فِيهِمْ لَنِفَاقًا، فَرَدَّهُمُ اللَّهُ بِذَلِكَ‏.‏ ثُمَّ لَقَدْ بَصَّرَ أَبُو بَكْرٍ النَّاسَ الْهُدَى وَعَرَّفَهُمُ الْحَقَّ الَّذِي عَلَيْهِمْ وَخَرَجُوا بِهِ يَتْلُونَ ‏\{‏وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ قَدْ خَلَتْ مِنْ قَبْلِهِ الرُّسُلُ‏\}‏ إِلَى ‏\{‏الشَّاكِرِينَ‏\}‏\hadithno{3670}\hadithtrans{Aisha said (in another narration), ("When the Prophet (ﷺ) was on his death-bed) he looked up and said thrice, (Amongst) the Highest Companion (See Qur'an 4.69)' Aisha said, Allah benefited the people by their two speeches. 'Umar frightened the people some of whom were hypocrites whom Allah caused to abandon Islam because of 'Umar's speech. Then Abu Bakr led the people to True Guidance and acquainted them with the right path they were to follow so that they went out reciting:-- "Muhammad is no more than an Apostle and indeed many Apostles have passed away before him}}
\hadithdefcmd{bukhari}{3671}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا جَامِعُ بْنُ أَبِي رَاشِدٍ، حَدَّثَنَا أَبُو يَعْلَى، عَنْ مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ، قَالَ قُلْتُ لأَبِي أَىُّ النَّاسِ خَيْرٌ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو بَكْرٍ‏.‏ قُلْتُ ثُمَّ مَنْ قَالَ ثُمَّ عُمَرُ‏.‏ وَخَشِيتُ أَنْ يَقُولَ عُثْمَانُ قُلْتُ ثُمَّ أَنْتَ قَالَ مَا أَنَا إِلاَّ رَجُلٌ مِنَ الْمُسْلِمِينَ‏.‏\hadithno{3671}\hadithtrans{Narrated Muhammad bin Al-Hanafiya:I asked my father (`Ali bin Abi Talib), "Who are the best people after Allah's Messenger (ﷺ) ?" He said, "Abu Bakr." I asked, "Who then?" He said, "Then `Umar. " I was afraid he would say "Uthman, so I said, "Then you?" He said, "I am only an ordinary person}}
\hadithdefcmd{bukhari}{3672}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ، حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ أَوْ بِذَاتِ الْجَيْشِ انْقَطَعَ عِقْدٌ لِي، فَأَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْتِمَاسِهِ، وَأَقَامَ النَّاسُ مَعَهُ، وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ، فَأَتَى النَّاسُ أَبَا بَكْرٍ، فَقَالُوا أَلاَ تَرَى مَا صَنَعَتْ عَائِشَةُ أَقَامَتْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَبِالنَّاسِ مَعَهُ، وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ، فَجَاءَ أَبُو بَكْرٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاضِعٌ رَأْسَهُ عَلَى فَخِذِي قَدْ نَامَ، فَقَالَ حَبَسْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالنَّاسَ، وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ قَالَتْ فَعَاتَبَنِي، وَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ، وَجَعَلَ يَطْعُنُنِي بِيَدِهِ فِي خَاصِرَتِي، فَلاَ يَمْنَعُنِي مِنَ التَّحَرُّكِ إِلاَّ مَكَانُ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى فَخِذِي، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَصْبَحَ عَلَى غَيْرِ مَاءٍ فَأَنْزَلَ اللَّهُ آيَةَ التَّيَمُّمِ، فَتَيَمَّمُوا، فَقَالَ أُسَيْدُ بْنُ الْحُضَيْرِ مَا هِيَ بِأَوَّلِ بَرَكَتِكُمْ يَا آلَ أَبِي بَكْرٍ‏.‏ فَقَالَتْ عَائِشَةُ فَبَعَثْنَا الْبَعِيرَ الَّذِي كُنْتُ عَلَيْهِ فَوَجَدْنَا الْعِقْدَ تَحْتَهُ‏.‏\hadithno{3672}\hadithtrans{Narrated `Aisha:We went out with Allah's Messenger (ﷺ) on one of his journeys till we reached Al-Baida or Dhatul-Jaish where my necklace got broken (and lost). Allah's Messenger (ﷺ) stopped to search for it and the people too stopped with him. There was no water at that place and they had no water with them. So they went to Abu Bakr and said, "Don't you see what `Aisha has done? She has made Allah's Messenger (ﷺ) and the people stop where there is no water and they have no water with them. Abu Bakr came while Allah's Apostle was sleeping with his head on my thigh and said, "You detained Allah's Apostle and the people where there is no water and they have no water." He then admonished me and said what Allah wished and pinched me at my flanks with his hands, but I did not move because the head of Allah's Messenger (ﷺ) was on my thigh . Allah's Messenger (ﷺ) kept on sleeping till he got up in the morning and found no water. Then Allah revealed the Divine Verse of Tayammum, and the people performed Tayammum. Usaid bin Al-Hudair said. "O family of Abu Bakr! This is not the first blessing of yours." We urged the camel on which I was sitting to get up from its place and the necklace was found under it}}
\hadithdefcmd{bukhari}{3673}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ ذَكْوَانَ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا أَصْحَابِي، فَلَوْ أَنَّ أَحَدَكُمْ أَنْفَقَ مِثْلَ أُحُدٍ ذَهَبًا مَا بَلَغَ مُدَّ أَحَدِهِمْ وَلاَ نَصِيفَهُ ‏"‏‏.‏ تَابَعَهُ جَرِيرٌ وَعَبْدُ اللَّهِ بْنُ دَاوُدَ وَأَبُو مُعَاوِيَةَ وَمُحَاضِرٌ عَنِ الأَعْمَشِ‏.‏\hadithno{3673}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) said, "Do not abuse my companions for if any one of you spent gold equal to Uhud (in Allah's Cause) it would not be equal to a Mud or even a half Mud spent by one of them}}
\hadithdefcmd{bukhari}{3674}{حَدَّثَنَا مُحَمَّدُ بْنُ مِسْكِينٍ أَبُو الْحَسَنِ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا سُلَيْمَانُ، عَنْ شَرِيكِ بْنِ أَبِي نَمِرٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ أَخْبَرَنِي أَبُو مُوسَى الأَشْعَرِيُّ، أَنَّهُ تَوَضَّأَ فِي بَيْتِهِ ثُمَّ خَرَجَ، فَقُلْتُ لأَلْزَمَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم، وَلأَكُونَنَّ مَعَهُ يَوْمِي هَذَا‏.‏ قَالَ فَجَاءَ الْمَسْجِدَ، فَسَأَلَ عَنِ النَّبِيِّ صلى الله عليه وسلم فَقَالُوا خَرَجَ وَوَجَّهَ هَا هُنَا، فَخَرَجْتُ عَلَى إِثْرِهِ أَسْأَلُ عَنْهُ، حَتَّى دَخَلَ بِئْرَ أَرِيسٍ، فَجَلَسْتُ عِنْدَ الْبَابِ، وَبَابُهَا مِنْ جَرِيدٍ حَتَّى قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم حَاجَتَهُ، فَتَوَضَّأَ فَقُمْتُ إِلَيْهِ، فَإِذَا هُوَ جَالِسٌ عَلَى بِئْرِ أَرِيسٍ، وَتَوَسَّطَ قُفَّهَا، وَكَشَفَ عَنْ سَاقَيْهِ وَدَلاَّهُمَا فِي الْبِئْرِ، فَسَلَّمْتُ عَلَيْهِ ثُمَّ انْصَرَفْتُ، فَجَلَسْتُ عِنْدَ الْبَابِ، فَقُلْتُ لأَكُونَنَّ بَوَّابَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْيَوْمَ، فَجَاءَ أَبُو بَكْرٍ فَدَفَعَ الْبَابَ‏.‏ فَقُلْتُ مَنْ هَذَا فَقَالَ أَبُو بَكْرٍ‏.‏ فَقُلْتُ عَلَى رِسْلِكَ‏.‏ ثُمَّ ذَهَبْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا أَبُو بَكْرٍ يَسْتَأْذِنُ‏.‏ فَقَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَأَقْبَلْتُ حَتَّى قُلْتُ لأَبِي بَكْرٍ ادْخُلْ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُبَشِّرُكَ بِالْجَنَّةِ‏.‏ فَدَخَلَ أَبُو بَكْرٍ فَجَلَسَ عَنْ يَمِينِ رَسُولِ اللَّهِ صلى الله عليه وسلم مَعَهُ فِي الْقُفِّ، وَدَلَّى رِجْلَيْهِ فِي الْبِئْرِ، كَمَا صَنَعَ النَّبِيُّ صلى الله عليه وسلم، وَكَشَفَ عَنْ سَاقَيْهِ، ثُمَّ رَجَعْتُ فَجَلَسْتُ وَقَدْ تَرَكْتُ أَخِي يَتَوَضَّأُ وَيَلْحَقُنِي، فَقُلْتُ إِنْ يُرِدِ اللَّهُ بِفُلاَنٍ خَيْرًا ـ يُرِيدُ أَخَاهُ ـ يَأْتِ بِهِ‏.‏ فَإِذَا إِنْسَانٌ يُحَرِّكُ الْبَابَ‏.‏ فَقُلْتُ مَنْ هَذَا فَقَالَ عُمَرُ بْنُ الْخَطَّابِ‏.‏ فَقُلْتُ عَلَى رِسْلِكَ‏.‏ ثُمَّ جِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ، فَقُلْتُ هَذَا عُمَرُ بْنُ الْخَطَّابِ يَسْتَأْذِنُ‏.‏ فَقَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَجِئْتُ فَقُلْتُ ادْخُلْ وَبَشَّرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْجَنَّةِ‏.‏ فَدَخَلَ، فَجَلَسَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْقُفِّ عَنْ يَسَارِهِ، وَدَلَّى رِجْلَيْهِ فِي الْبِئْرِ، ثُمَّ رَجَعْتُ فَجَلَسْتُ، فَقُلْتُ إِنْ يُرِدِ اللَّهُ بِفُلاَنٍ خَيْرًا يَأْتِ بِهِ‏.‏ فَجَاءَ إِنْسَانٌ يُحَرِّكُ الْبَابَ، فَقُلْتُ مَنْ هَذَا فَقَالَ عُثْمَانُ بْنُ عَفَّانَ‏.‏ فَقُلْتُ عَلَى رِسْلِكَ‏.‏ فَجِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ‏.‏ فَقَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ عَلَى بَلْوَى تُصِيبُهُ ‏"‏ فَجِئْتُهُ فَقُلْتُ لَهُ ادْخُلْ وَبَشَّرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْجَنَّةِ عَلَى بَلْوَى تُصِيبُكَ‏.‏ فَدَخَلَ فَوَجَدَ الْقُفَّ قَدْ مُلِئَ، فَجَلَسَ وُجَاهَهُ مِنَ الشِّقِّ الآخَرِ‏.‏ قَالَ شَرِيكٌ قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ فَأَوَّلْتُهَا قُبُورَهُمْ‏.‏\hadithno{3674}\hadithtrans{Narrated Abu Musa Al-Ash`ari:I performed ablution in my house and then went out and said, "Today I shall stick to Allah's Messenger (ﷺ) and stay with him all this day of mine (in his service)." I went to the Mosque and asked about the Prophet . They said, "He had gone in this direction." So I followed his way, asking about him till he entered a place called Bir Aris. I sat at its gate that was made of date-palm leaves till the Prophet (ﷺ) finished answering the call of nature and performed ablution. Then I went up to him to see him sitting at the well of Aris at the middle of its edge with his legs uncovered, hanging in the well. I greeted him and went back and sat at the gate. I said, "Today I will be the gatekeeper of the Prophet." Abu Bakr came and pushed the gate. I asked, "Who is it?" He said, "Abu Bakr." I told him to wait, went in and said, "O Allah's Messenger (ﷺ)! Abu Bakr asks for permission to enter." He said, "Admit him and give him the glad tidings that he will be in Paradise." So I went out and said to Abu Bakr, "Come in, and Allah's Messenger (ﷺ) gives you the glad tidings that you will be in Paradise" Abu Bakr entered and sat on the right side of Allah's Messenger (ﷺ) on the built edge of the well and hung his legs n the well as the Prophet (ﷺ) did and uncovered his legs. I then returned and sat (at the gate). I had left my brother performing ablution and he intended to follow me. So I said (to myself). "If Allah wants good for so-and-so (i.e. my brother) He will bring him here." Suddenly somebody moved the door. I asked, "Who is it?" He said, "`Umar bin Al-Khattab." I asked him to wait, went to Allah's Messenger (ﷺ), greeted him and said, `Umar bin Al-Khattab asks the permission to enter." He said, "Admit him, and give him the glad tidings that he will be in Paradise." I went to "`Umar and said "Come in, and Allah's Messenger (ﷺ), gives you the glad tidings that you will be in Paradise." So he entered and sat beside Allah's Messenger (ﷺ) on the built edge of the well on the left side and hung his legs in the well. I returned and sat (at the gate) and said, (to myself), "If Allah wants good for so-and-so, He will bring him here." Somebody came and moved the door. I asked "Who is it?" He replied, "Uthman bin `Affan." I asked him to wait and went to the Prophet (ﷺ) and informed him. He said, "Admit him, and give him the glad tidings of entering Paradise, after a calamity that will befall him." So I went up to him and said to him, "Come in; Allah's Apostle gives you the glad tidings of entering Paradise after a calamity that will befall you. "Uthman then came in and found that the built edge of the well was occupied, so he sat opposite to the Prophet (ﷺ) on the other side. Sa`id bin Al-Musaiyab said, "I interpret this (narration) in terms of their graves}}
\hadithdefcmd{bukhari}{3675}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، أَنَّ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ حَدَّثَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَعِدَ أُحُدًا وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ فَرَجَفَ بِهِمْ فَقَالَ ‏ "‏ اثْبُتْ أُحُدُ فَإِنَّمَا عَلَيْكَ نَبِيٌّ وَصِدِّيقٌ وَشَهِيدَانِ ‏"‏‏.‏\hadithno{3675}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) once climbed the mountain of Uhud with Abu Bakr, `Umar and `Uthman. The mountain shook with them. The Prophet (ﷺ) said (to the mountain), "Be firm, O Uhud! For on you there are no more than a Prophet, a Siddiq and two martyrs}}
\hadithdefcmd{bukhari}{3676}{حَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ أَبُو عَبْدِ اللَّهِ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا صَخْرٌ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَمَا أَنَا عَلَى بِئْرٍ أَنْزِعُ مِنْهَا جَاءَنِي أَبُو بَكْرٍ وَعُمَرُ، فَأَخَذَ أَبُو بَكْرٍ الدَّلْوَ، فَنَزَعَ ذَنُوبًا أَوْ ذَنُوبَيْنِ وَفِي نَزْعِهِ ضَعْفٌ، وَاللَّهُ يَغْفِرُ لَهُ، ثُمَّ أَخَذَهَا ابْنُ الْخَطَّابِ مِنْ يَدِ أَبِي بَكْرٍ، فَاسْتَحَالَتْ فِي يَدِهِ غَرْبًا، فَلَمْ أَرَ عَبْقَرِيًّا مِنَ النَّاسِ يَفْرِي فَرِيَّهُ، فَنَزَعَ حَتَّى ضَرَبَ النَّاسُ بِعَطَنٍ ‏"‏‏.‏ قَالَ وَهْبٌ الْعَطَنُ مَبْرَكُ الإِبِلِ، يَقُولُ حَتَّى رَوِيَتِ الإِبِلُ فَأَنَاخَتْ‏.‏\hadithno{3676}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said. "While (in a dream), I was standing by a well, drawing water from it. Abu Bakr and `Umar came to me. Abu Bakr took the bucket (from me) and drew one or two buckets of water, and there was some weakness in his drawing. May Allah forgive him. Then Ibn Al-Khattab took the bucket from Abu Bakr, and the bucket turned into a very large one in his hands. I had never seen such a mighty person amongst the people as him in performing such hard work. He drew so much water that the people drank to their satisfaction and watered their camels." (Wahab, a sub-narrator said, "till their camels drank and knelt down)}}
\hadithdefcmd{bukhari}{3677}{حَدَّثَنِي الْوَلِيدُ بْنُ صَالِحٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عُمَرُ بْنُ سَعِيدِ بْنِ أَبِي الْحُسَيْنِ الْمَكِّيُّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ إِنِّي لَوَاقِفٌ فِي قَوْمٍ، فَدَعَوُا اللَّهَ لِعُمَرَ بْنِ الْخَطَّابِ وَقَدْ وُضِعَ عَلَى سَرِيرِهِ، إِذَا رَجُلٌ مِنْ خَلْفِي قَدْ وَضَعَ مِرْفَقَهُ عَلَى مَنْكِبِي، يَقُولُ رَحِمَكَ اللَّهُ، إِنْ كُنْتُ لأَرْجُو أَنْ يَجْعَلَكَ اللَّهُ مَعَ صَاحِبَيْكَ، لأَنِّي كَثِيرًا مِمَّا كُنْتُ أَسْمَعُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ كُنْتُ وَأَبُو بَكْرٍ وَعُمَرُ، وَفَعَلْتُ وَأَبُو بَكْرٍ وَعُمَرُ، وَانْطَلَقْتُ وَأَبُو بَكْرٍ وَعُمَرُ‏.‏ فَإِنْ كُنْتُ لأَرْجُو أَنْ يَجْعَلَكَ اللَّهُ مَعَهُمَا‏.‏ فَالْتَفَتُّ فَإِذَا هُوَ عَلِيُّ بْنُ أَبِي طَالِبٍ‏.‏\hadithno{3677}\hadithtrans{Narrated Ibn `Abbas:While I was standing amongst the people who were invoking Allah for `Umar bin Al-Khattab who was lying (dead) on his bed, a man behind me rested his elbows on my shoulder and said, "(O `Umar!) May Allah bestow His Mercy on you. I always hoped that Allah will keep you with your two companions, for I often heard Allah's Messenger (ﷺ) saying, "I, Abu Bakr and `Umar were (somewhere). I, Abu Bakr and `Umar did (something). I, Abu Bakr and `Umar set out.' So I hoped that Allah will keep you with both of them." I turned back to see that the speaker was `Ali bin Abi Talib}}
\hadithdefcmd{bukhari}{3678}{حَدَّثَنِي مُحَمَّدُ بْنُ يَزِيدَ الْكُوفِيُّ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو عَنْ أَشَدِّ، مَا صَنَعَ الْمُشْرِكُونَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ رَأَيْتُ عُقْبَةَ بْنَ أَبِي مُعَيْطٍ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يُصَلِّي، فَوَضَعَ رِدَاءَهُ فِي عُنُقِهِ فَخَنَقَهُ بِهِ خَنْقًا شَدِيدًا، فَجَاءَ أَبُو بَكْرٍ حَتَّى دَفَعَهُ عَنْهُ فَقَالَ أَتَقْتُلُونَ رَجُلاً أَنْ يَقُولَ رَبِّيَ اللَّهُ‏.‏ وَقَدْ جَاءَكُمْ بِالْبَيِّنَاتِ مِنْ رَبِّكُمْ‏.‏\hadithno{3678}\hadithtrans{Narrated `Urwa bin Az-Zubair:I asked `Abdullah bin `Amr, "What was the worst thing the pagans did to Allah's Messenger (ﷺ)?" He said, "I saw `Uqba bin Abi Mu'ait coming to the Prophet (ﷺ) while he was praying.' `Uqba put his sheet round the Prophet's neck and squeezed it very severely. Abu Bakr came and pulled `Uqba away from the Prophet and said, "Do you intend to kill a man just because he says: 'My Lord is Allah, and he has brought forth to you the Evident Signs from your Lord?}}
\hadithdefcmd{bukhari}{3679}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الْمَاجِشُونُ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ رَأَيْتُنِي دَخَلْتُ الْجَنَّةَ، فَإِذَا أَنَا بِالرُّمَيْصَاءِ امْرَأَةِ أَبِي طَلْحَةَ وَسَمِعْتُ خَشَفَةً، فَقُلْتُ مَنْ هَذَا فَقَالَ هَذَا بِلاَلٌ‏.‏ وَرَأَيْتُ قَصْرًا بِفِنَائِهِ جَارِيَةٌ، فَقُلْتُ لِمَنْ هَذَا فَقَالَ لِعُمَرَ‏.‏ فَأَرَدْتُ أَنْ أَدْخُلَهُ فَأَنْظُرَ إِلَيْهِ، فَذَكَرْتُ غَيْرَتَكَ ‏"‏‏.‏ فَقَالَ عُمَرُ بِأُمِّي وَأَبِي يَا رَسُولَ اللَّهِ أَعَلَيْكَ أَغَارُ\hadithno{3679}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "I saw myself (in a dream) entering Paradise, and behold! I saw Ar-Rumaisa', Abu Talha's wife. I heard footsteps. I asked, Who is it? Somebody said, 'It is Bilal ' Then I saw a palace and a lady sitting in its courtyard. I asked, 'For whom is this palace?' Somebody replied, 'It is for `Umar.' I intended to enter it and see it, but I thought of your (`Umar's) Ghira (and gave up the attempt)." `Umar said, "Let my parents be sacrificed for you, O Allah's Messenger (ﷺ)! How dare I think of my Ghira (self-respect) being offended by you?}}
\hadithdefcmd{bukhari}{3680}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ قَالَ ‏ "‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُنِي فِي الْجَنَّةِ، فَإِذَا امْرَأَةٌ تَتَوَضَّأُ إِلَى جَانِبِ قَصْرٍ، فَقُلْتُ لِمَنْ هَذَا الْقَصْرُ قَالُوا لِعُمَرَ فَذَكَرْتُ غَيْرَتَهُ فَوَلَّيْتُ مُدْبِرًا ‏"‏‏.‏ فَبَكَى وَقَالَ أَعَلَيْكَ أَغَارُ يَا رَسُولَ اللَّهِ\hadithno{3680}\hadithtrans{Narrated Abu Huraira:While we were with Allah's Messenger (ﷺ) he said, "While I was sleeping, I saw myself in Paradise, and suddenly I saw a woman performing ablution beside a palace. I asked, 'For whom is this palace?' They replied, 'It is for `Umar.' Then I remembered `Umar's Ghira (self-respect) and went away quickly." `Umar wept and said, O Allah's Messenger (ﷺ)! How dare I think of my ghira (self-respect) being offended by you?}}
\hadithdefcmd{bukhari}{3681}{حَدَّثَنِي مُحَمَّدُ بْنُ الصَّلْتِ أَبُو جَعْفَرٍ الْكُوفِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي حَمْزَةُ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا أَنَا نَائِمٌ شَرِبْتُ ـ يَعْنِي اللَّبَنَ ـ حَتَّى أَنْظُرُ إِلَى الرِّيِّ يَجْرِي فِي ظُفُرِي أَوْ فِي أَظْفَارِي، ثُمَّ نَاوَلْتُ عُمَرَ ‏"‏‏.‏ فَقَالُوا فَمَا أَوَّلْتَهُ قَالَ ‏"‏ الْعِلْمَ ‏"‏‏.‏\hadithno{3681}\hadithtrans{Narrated Hamza's father:Allah's Messenger (ﷺ) said, "While I was sleeping, I saw myself drinking (i.e. milk), and I was so contented that I saw the milk flowing through my nails. Then I gave (the milk) to `Umar." They (i.e. the companions of the Prophet) asked, "What do you interpret it?" He said, "Knowledge}}
\hadithdefcmd{bukhari}{3682}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ سَالِمٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أُرِيتُ فِي الْمَنَامِ أَنِّي أَنْزِعُ بِدَلْوِ بَكْرَةٍ عَلَى قَلِيبٍ، فَجَاءَ أَبُو بَكْرٍ فَنَزَعَ ذَنُوبًا أَوْ ذَنُوبَيْنِ نَزْعًا ضَعِيفًا، وَاللَّهُ يَغْفِرُ لَهُ، ثُمَّ جَاءَ عُمَرُ بْنُ الْخَطَّابِ فَاسْتَحَالَتْ غَرْبًا، فَلَمْ أَرَ عَبْقَرِيًّا يَفْرِي فَرِيَّهُ حَتَّى رَوِيَ النَّاسُ وَضَرَبُوا بِعَطَنٍ ‏"‏‏.‏ قَالَ ابْنُ جُبَيْرٍ الْعَبْقَرِيُّ عِتَاقُ الزَّرَابِيِّ‏.‏ وَقَالَ يَحْيَى الزَّرَابِيُّ الطَّنَافِسُ لَهَا خَمْلٌ رَقِيقٌ ‏\{‏مَبْثُوثَةٌ‏\}‏ كَثِيرَةٌ‏.‏\hadithno{3682}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "In a dream I saw myself drawing water from a well with a bucket. Abu Bakr came and drew a bucket or two weakly. May Allah forgive him. Then `Umar bin Al-Khattab came and the bucket turned into a very large one in his hands. I had never seen such a mighty person as he in doing such hard work till all the people drank to their satisfaction and watered their camels that knelt down there}}
\hadithdefcmd{bukhari}{3683}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ الْحَمِيدِ، أَنَّ مُحَمَّدَ بْنَ سَعْدٍ، أَخْبَرَهُ أَنَّ أَبَاهُ قَالَ ح حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ، عَنْ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، قَالَ اسْتَأْذَنَ عُمَرُ بْنُ الْخَطَّابِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم، وَعِنْدَهُ نِسْوَةٌ مِنْ قُرَيْشٍ يُكَلِّمْنَهُ وَيَسْتَكْثِرْنَهُ، عَالِيَةً أَصْوَاتُهُنَّ عَلَى صَوْتِهِ فَلَمَّا اسْتَأْذَنَ عُمَرُ بْنُ الْخَطَّابِ قُمْنَ فَبَادَرْنَ الْحِجَابَ فَأَذِنَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ عُمَرُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَضْحَكُ، فَقَالَ عُمَرُ أَضْحَكَ اللَّهُ سِنَّكَ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَجِبْتُ مِنْ هَؤُلاَءِ اللاَّتِي كُنَّ عِنْدِي فَلَمَّا سَمِعْنَ صَوْتَكَ ابْتَدَرْنَ الْحِجَابِ ‏"‏‏.‏ فَقَالَ عُمَرُ فَأَنْتَ أَحَقُّ أَنْ يَهَبْنَ يَا رَسُولَ اللَّهِ‏.‏ ثُمَّ قَالَ عُمَرُ يَا عَدُوَّاتِ أَنْفُسِهِنَّ، أَتَهَبْنَنِي وَلاَ تَهَبْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْنَ نَعَمْ، أَنْتَ أَفَظُّ وَأَغْلَظُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِيهًا يَا ابْنَ الْخَطَّابِ وَالَّذِي نَفْسِي بِيَدِهِ مَا لَقِيَكَ الشَّيْطَانُ سَالِكًا فَجًّا قَطُّ إِلاَّ سَلَكَ فَجًّا غَيْرَ فَجِّكَ ‏"‏‏.‏\hadithno{3683}\hadithtrans{Narrated Sa`d bin Abi Waqqas:`Umar bin Al-Khattab asked the permission of Allah's Messenger (ﷺ) to see him while some Quraishi women were sitting with him, talking to him and asking him for more expenses, raising their voices above the voice of Allah's Messenger (ﷺ). When `Umar asked for the permission to enter, the women quickly put on their veils. Allah'sf Apostle allowed him to enter and `Umar came in while Allah's Messenger (ﷺ) was smiling, `Umar said "O Allah's Apostle! May Allah always keep you smiling." The Prophet (ﷺ) said, "These women who have been here, roused my wonder, for as soon as they heard your voice, they quickly put on their veils. "`Umar said, "O Allah's Messenger (ﷺ)! You have more right to be feared by them than I." Then `Umar addressed the women saying, "O enemies of yourselves! You fear me more than you do Allah's Messenger (ﷺ) ?" They said, "Yes, for you are harsher and sterner than Allah's Messenger (ﷺ)." Then Allah's Messenger (ﷺ) said, "O Ibn Al-Khattab! By Him in Whose Hands my life is! Never does Satan find you going on a way, but he takes another way other than yours}}
\hadithdefcmd{bukhari}{3684}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، حَدَّثَنَا قَيْسٌ، قَالَ قَالَ عَبْدُ اللَّهِ مَا زِلْنَا أَعِزَّةً مُنْذُ أَسْلَمَ عُمَرُ‏.‏\hadithno{3684}\hadithtrans{Narrated `Abdullah:We have been powerful since `Umar embraced Islam}}
\hadithdefcmd{bukhari}{3685}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، حَدَّثَنَا عُمَرُ بْنُ سَعِيدٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ وُضِعَ عُمَرُ عَلَى سَرِيرِهِ، فَتَكَنَّفَهُ النَّاسُ يَدْعُونَ وَيُصَلُّونَ قَبْلَ أَنْ يُرْفَعَ، وَأَنَا فِيهِمْ، فَلَمْ يَرُعْنِي إِلاَّ رَجُلٌ آخِذٌ مَنْكِبِي، فَإِذَا عَلِيٌّ فَتَرَحَّمَ عَلَى عُمَرَ، وَقَالَ مَا خَلَّفْتَ أَحَدًا أَحَبَّ إِلَىَّ أَنْ أَلْقَى اللَّهَ بِمِثْلِ عَمَلِهِ مِنْكَ، وَايْمُ اللَّهِ، إِنْ كُنْتُ لأَظُنُّ أَنْ يَجْعَلَكَ اللَّهُ مَعَ صَاحِبَيْكَ، وَحَسِبْتُ أَنِّي كُنْتُ كَثِيرًا أَسْمَعُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ذَهَبْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ، وَدَخَلْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ، وَخَرَجْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ‏.‏\hadithno{3685}\hadithtrans{Narrated Ibn `Abbas:When (the dead body of) `Umar was put on his deathbed, the people gathered around him and invoked (Allah) and prayed for him before the body was taken away, and I was amongst them. Suddenly I felt somebody taking hold of my shoulder and found out that he was `Ali bin Abi Talib. `Ali invoked Allah's Mercy for `Umar and said, "O `Umar! You have not left behind you a person whose deeds I like to imitate and meet Allah with more than I like your deeds. By Allah! I always thought that Allah would keep you with your two companions, for very often I used to hear the Prophet (ﷺ) saying, 'I, Abu Bakr and `Umar went (somewhere); I, Abu Bakr and `Umar entered (somewhere); and I, Abu Bakr and `Umar went out}}
\hadithdefcmd{bukhari}{3686}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، وَقَالَ، لِي خَلِيفَةُ حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، وَكَهْمَسُ بْنُ الْمِنْهَالِ، قَالاَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ صَعِدَ النَّبِيُّ صلى الله عليه وسلم إِلَى أُحُدٍ وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ فَرَجَفَ بِهِمْ، فَضَرَبَهُ بِرِجْلِهِ، قَالَ ‏ "‏ اثْبُتْ أُحُدُ فَمَا عَلَيْكَ إِلاَّ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدَانِ ‏"‏‏.‏\hadithno{3686}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) ascended the mountain of Uhud and he was accompanied by Abu Bakr, `Umar and `Uthman. The mountain shook beneath them. The Prophet (ﷺ) hit it with his foot and said, "O Uhud ! Be firm, for on you there is none but a Prophet, a Siddiq and a martyr (i.e. and two martyrs)}}
\hadithdefcmd{bukhari}{3687}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ، هُوَ ابْنُ مُحَمَّدٍ أَنَّ زَيْدَ بْنَ أَسْلَمَ، حَدَّثَهُ عَنْ أَبِيهِ، قَالَ سَأَلَنِي ابْنُ عُمَرَ عَنْ بَعْضِ، شَأْنِهِ ـ يَعْنِي عُمَرَ ـ فَأَخْبَرْتُهُ‏.‏ فَقَالَ، مَا رَأَيْتُ أَحَدًا قَطُّ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ حِينَ قُبِضَ كَانَ أَجَدَّ وَأَجْوَدَ حَتَّى انْتَهَى مِنْ عُمَرَ بْنِ الْخَطَّابِ‏.‏\hadithno{3687}\hadithtrans{Narrated Aslam:Ibn `Umar asked me about some matters concerning `Umar. He said, "Since Allah's Messenger (ﷺ) died. I have never seen anybody more serious, hard working and generous than `Umar bin Al-Khattab (till the end of his life)}}
\hadithdefcmd{bukhari}{3688}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ السَّاعَةِ، فَقَالَ مَتَى السَّاعَةُ قَالَ ‏"‏ وَمَاذَا أَعْدَدْتَ لَهَا ‏"‏‏.‏ قَالَ لاَ شَىْءَ إِلاَّ أَنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ صلى الله عليه وسلم‏.‏ فَقَالَ ‏"‏ أَنْتَ مَعَ مَنْ أَحْبَبْتَ ‏"‏‏.‏ قَالَ أَنَسٌ فَمَا فَرِحْنَا بِشَىْءٍ فَرَحَنَا بِقَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ أَنْتَ مَعَ مَنْ أَحْبَبْتَ ‏"‏‏.‏ قَالَ أَنَسٌ فَأَنَا أُحِبُّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ، وَأَرْجُو أَنْ أَكُونَ مَعَهُمْ بِحُبِّي إِيَّاهُمْ، وَإِنْ لَمْ أَعْمَلْ بِمِثْلِ أَعْمَالِهِمْ‏.‏\hadithno{3688}\hadithtrans{Narrated Anas:A man asked the Prophet (ﷺ) about the Hour (i.e. Day of Judgment) saying, "When will the Hour be?" The Prophet (ﷺ) said, "What have you prepared for it?" The man said, "Nothing, except that I love Allah and His Apostle." The Prophet (ﷺ) said, "You will be with those whom you love." We had never been so glad as we were on hearing that saying of the Prophet (i.e., "You will be with those whom you love.") Therefore, I love the Prophet, Abu Bakr and `Umar, and I hope that I will be with them because of my love for them though my deeds are not similar to theirs}}
\hadithdefcmd{bukhari}{3689}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ كَانَ فِيمَا قَبْلَكُمْ مِنَ الأُمَمِ مُحَدَّثُونَ، فَإِنْ يَكُ فِي أُمَّتِي أَحَدٌ فَإِنَّهُ عُمَرُ ‏"‏‏.‏ زَادَ زَكَرِيَّاءُ بْنُ أَبِي زَائِدَةَ عَنْ سَعْدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدْ كَانَ فِيمَنْ كَانَ قَبْلَكُمْ مِنْ بَنِي إِسْرَائِيلَ رِجَالٌ يُكَلَّمُونَ مِنْ غَيْرِ أَنْ يَكُونُوا أَنْبِيَاءَ، فَإِنْ يَكُنْ مِنْ أُمَّتِي مِنْهُمْ أَحَدٌ فَعُمَرُ ‏"‏‏.‏ قال ابن عباس رضي الله عنهما: "من نبيِّ ولا محدَّث\hadithno{3689}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "Among the nations before you there used to be people who were inspired (though they were not prophets). And if there is any of such persons amongst my followers, it is 'Umar." Narrated Abu Huraira: The Prophet (ﷺ) said, "Among the nation of Bani Israel who lived before you, there were men who used to be inspired with guidance though they were not prophets, and if there is any of such persons amongst my followers, it is 'Umar}}
\hadithdefcmd{bukhari}{3690}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ قَالاَ سَمِعْنَا أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَيْنَمَا رَاعٍ فِي غَنَمِهِ عَدَا الذِّئْبُ فَأَخَذَ مِنْهَا شَاةً، فَطَلَبَهَا حَتَّى اسْتَنْقَذَهَا، فَالْتَفَتَ إِلَيْهِ الذِّئْبُ فَقَالَ لَهُ مَنْ لَهَا يَوْمَ السَّبُعِ، لَيْسَ لَهَا رَاعٍ غَيْرِي‏"‏‏.‏ فَقَالَ النَّاسُ سُبْحَانَ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَإِنِّي أُومِنُ بِهِ وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ وَمَا ثَمَّ أَبُو بَكْرٍ وَعُمَرُ‏.‏\hadithno{3690}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whilst a shepherd was amongst his sheep, a wolf attacked them and took away a sheep. The shepherd chased it and got that sheep freed from the wolf. The wolf turned towards the shepherd and said, 'Who will guard the sheep on the day of wild animals when it will have no shepherd except myself?" The people said, "Glorified be Allah." The Prophet (ﷺ) said, "But I believe in it and so do Abu Bakr and `Umar although Abu Bakr and `Umar were not present there (at the place of the event)}}
\hadithdefcmd{bukhari}{3691}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو أُمَامَةَ بْنُ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُ النَّاسَ عُرِضُوا عَلَىَّ وَعَلَيْهِمْ قُمُصٌ، فَمِنْهَا مَا يَبْلُغُ الثَّدْىَ، وَمِنْهَا مَا يَبْلُغُ دُونَ ذَلِكَ، وَعُرِضَ عَلَىَّ عُمَرُ وَعَلَيْهِ قَمِيصٌ اجْتَرَّهُ ‏"‏‏.‏ قَالُوا فَمَا أَوَّلْتَهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الدِّينَ ‏"‏‏.‏\hadithno{3691}\hadithtrans{Narrated Abu Sa`id Al-Khudri:I heard Allah's Messenger (ﷺ) saying, "While I was sleeping, the people were presented to me (in a dream). They were wearing shirts, some of which were merely covering their (chests). and some were a bit longer. `Umar was presented before me and his shirt was so long that he was dragging it." They asked, "How have you interpreted it, O Allah's Messenger (ﷺ)?" He said, "Religion}}
\hadithdefcmd{bukhari}{3692}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ لَمَّا طُعِنَ عُمَرُ جَعَلَ يَأْلَمُ، فَقَالَ لَهُ ابْنُ عَبَّاسٍ ـ وَكَأَنَّهُ يُجَزِّعُهُ ـ يَا أَمِيرَ الْمُؤْمِنِينَ، وَلَئِنْ كَانَ ذَاكَ لَقَدْ صَحِبْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَحْسَنْتَ صُحْبَتَهُ، ثُمَّ فَارَقْتَهُ وَهْوَ عَنْكَ رَاضٍ، ثُمَّ صَحِبْتَ أَبَا بَكْرٍ فَأَحْسَنْتَ صُحْبَتَهُ، ثُمَّ فَارَقْتَهُ وَهْوَ عَنْكَ رَاضٍ، ثُمَّ صَحِبْتَ صَحَبَتَهُمْ فَأَحْسَنْتَ صُحْبَتَهُمْ، وَلَئِنْ فَارَقْتَهُمْ لَتُفَارِقَنَّهُمْ وَهُمْ عَنْكَ رَاضُونَ‏.‏ قَالَ أَمَّا مَا ذَكَرْتَ مِنْ صُحْبَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرِضَاهُ، فَإِنَّمَا ذَاكَ مَنٌّ مِنَ اللَّهِ تَعَالَى مَنَّ بِهِ عَلَىَّ، وَأَمَّا مَا ذَكَرْتَ مِنْ صُحْبَةِ أَبِي بَكْرٍ وَرِضَاهُ، فَإِنَّمَا ذَاكَ مَنٌّ مِنَ اللَّهِ جَلَّ ذِكْرُهُ مَنَّ بِهِ عَلَىَّ، وَأَمَّا مَا تَرَى مِنْ جَزَعِي، فَهْوَ مِنْ أَجْلِكَ وَأَجْلِ أَصْحَابِكَ، وَاللَّهِ لَوْ أَنَّ لِي طِلاَعَ الأَرْضِ ذَهَبًا لاَفْتَدَيْتُ بِهِ مِنْ عَذَابِ اللَّهِ عَزَّ وَجَلَّ قَبْلَ أَنْ أَرَاهُ‏.‏ قَالَ حَمَّادُ بْنُ زَيْدٍ حَدَّثَنَا أَيُّوبُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ، دَخَلْتُ عَلَى عُمَرَ بِهَذَا‏.‏\hadithno{3692}\hadithtrans{Narrated Al-Miswar bin Makhrama:When `Umar was stabbed, he showed signs of agony. Ibn `Abbas, as if intending to encourage `Umar, said to him, "O Chief of the believers! Never mind what has happened to you, for you have been in the company of Allah's Messenger (ﷺ) and you kept good relations with him and you parted with him while he was pleased with you. Then you were in the company of Abu Bakr and kept good relations with him and you parted with him (i.e. he died) while he was pleased with you. Then you were in the company of the Muslims, and you kept good relations with them, and if you leave them, you will leave them while they are pleased with you." `Umar said, (to Ibn "Abbas), "As for what you have said about the company of Allah's Messenger (ﷺ) and his being pleased with me, it is a favor, Allah did to me; and as for what you have said about the company of Abu Bakr and his being pleased with me, it is a favor Allah did to me; and concerning my impatience which you see, is because of you and your companions. By Allah! If (at all) I had gold equal to the earth, I would have ransomed myself with it from the Punishment of Allah before I meet Him}}
\hadithdefcmd{bukhari}{3693}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنِي عُثْمَانُ بْنُ غِيَاثٍ، حَدَّثَنَا أَبُو عُثْمَانَ النَّهْدِيُّ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَائِطٍ مِنْ حِيطَانِ الْمَدِينَةِ، فَجَاءَ رَجُلٌ فَاسْتَفْتَحَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ افْتَحْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَفَتَحْتُ لَهُ، فَإِذَا أَبُو بَكْرٍ، فَبَشَّرْتُهُ بِمَا قَالَ النَّبِيُّ صلى الله عليه وسلم فَحَمِدَ اللَّهَ، ثُمَّ جَاءَ رَجُلٌ فَاسْتَفْتَحَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ افْتَحْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَفَتَحْتُ لَهُ، فَإِذَا هُوَ عُمَرُ، فَأَخْبَرْتُهُ بِمَا قَالَ النَّبِيُّ صلى الله عليه وسلم فَحَمِدَ اللَّهَ، ثُمَّ اسْتَفْتَحَ رَجُلٌ، فَقَالَ لِي ‏"‏ افْتَحْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ عَلَى بَلْوَى تُصِيبُهُ ‏"‏‏.‏ فَإِذَا عُثْمَانُ، فَأَخْبَرْتُهُ بِمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَحَمِدَ اللَّهَ ثُمَّ قَالَ اللَّهُ الْمُسْتَعَانُ‏.‏\hadithno{3693}\hadithtrans{Narrated Abu Musa:While I was with the Prophet (ﷺ) in one of the gardens of Medina, a man came and asked me to open the gate. The Prophet (ﷺ) said to me, "Open the gate for him and give him the glad tidings that he will enter Paradise." I opened (the gate) for him, and behold! It was Abu Bakr. I informed him of the glad tidings the Prophet (ﷺ) had said, and he praised Allah. Then another man came and asked me to open the gate. The Prophet (ﷺ) said to me "Open (the gate) and give him the glad tidings of entering Paradise." I opened (the gate) for him, and behold! It was `Umar. I informed him of what the Prophet (ﷺ) had said, and he praised Allah. Then another man came and asked me to open the gate. The Prophet (ﷺ) said to me. "Open (the gate) for him and inform him of the glad tidings, of entering Paradise with a calamity which will befall him. " Behold ! It was `Uthman, I informed him of what Allah's Messenger (ﷺ) had said. He praised Allah and said, "I seek Allah's Aid}}
\hadithdefcmd{bukhari}{3694}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي حَيْوَةُ، قَالَ حَدَّثَنِي أَبُو عَقِيلٍ، زُهْرَةُ بْنُ مَعْبَدٍ أَنَّهُ سَمِعَ جَدَّهُ عَبْدَ اللَّهِ بْنَ هِشَامٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم وَهْوَ آخِذٌ بِيَدِ عُمَرَ بْنِ الْخَطَّابِ‏.‏\hadithno{3694}\hadithtrans{Narrated `Abdullah bin Hisham:We were with the Prophet (ﷺ) while he was holding `Umar bin Al-Khattab by the hand}}
\hadithdefcmd{bukhari}{3695}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ حَائِطًا وَأَمَرَنِي بِحِفْظِ باب الْحَائِطِ، فَجَاءَ رَجُلٌ يَسْتَأْذِنُ، فَقَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَإِذَا أَبُو بَكْرٍ، ثُمَّ جَاءَ آخَرُ يَسْتَأْذِنُ فَقَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَإِذَا عُمَرُ، ثُمَّ جَاءَ آخَرُ يَسْتَأْذِنُ، فَسَكَتَ هُنَيْهَةً ثُمَّ قَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ عَلَى بَلْوَى سَتُصِيبُهُ ‏"‏‏.‏ فَإِذَا عُثْمَانُ بْنُ عَفَّانَ‏.‏ قَالَ حَمَّادٌ وَحَدَّثَنَا عَاصِمٌ الأَحْوَلُ، وَعَلِيُّ بْنُ الْحَكَمِ، سَمِعَا أَبَا عُثْمَانَ، يُحَدِّثُ عَنْ أَبِي مُوسَى، بِنَحْوِهِ، وَزَادَ فِيهِ عَاصِمٌ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ قَاعِدًا فِي مَكَانٍ فِيهِ مَاءٌ، قَدِ انْكَشَفَتْ عَنْ رُكْبَتَيْهِ أَوْ رُكْبَتِهِ، فَلَمَّا دَخَلَ عُثْمَانُ غَطَّاهَا‏.‏\hadithno{3695}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) entered a garden and ordered me to guard its gate. A man came and asked permission to enter. The Prophet (ﷺ) said, "Admit him and give him the glad tidings of entering Paradise." Behold! It was Abu Bakr. Another man came and asked the permission to enter. The Prophet (ﷺ) said, "Admit him and give him the glad tidings of entering Paradise." Behold! It was `Umar. Then another man came, asking the permission to enter. The Prophet (ﷺ) kept silent for a short while and then said, "Admit him and give him the glad tidings of entering Paradise with a calamity which will befall him." Behold! It was `Uthman bin `Affan. `Asim, in another narration, said that the Prophet (ﷺ) was sitting in a place where there was water, and he was uncovering both his knees or his knee, and when `Uthman entered, he covered them (or it)}}
\hadithdefcmd{bukhari}{3696}{حَدَّثَنِي أَحْمَدُ بْنُ شَبِيبِ بْنِ سَعِيدٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يُونُسَ، قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُرْوَةُ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَدِيِّ بْنِ الْخِيَارِ، أَخْبَرَهُ أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ وَعَبْدَ الرَّحْمَنِ بْنَ الأَسْوَدِ بْنِ عَبْدِ يَغُوثَ قَالاَ مَا يَمْنَعُكَ أَنْ تُكَلِّمَ عُثْمَانَ لأَخِيهِ الْوَلِيدِ فَقَدْ أَكْثَرَ النَّاسُ فِيهِ‏.‏ فَقَصَدْتُ لِعُثْمَانَ حَتَّى خَرَجَ إِلَى الصَّلاَةِ، قُلْتُ إِنَّ لِي إِلَيْكَ حَاجَةً، وَهِيَ نَصِيحَةٌ لَكَ‏.‏ قَالَ يَا أَيُّهَا الْمَرْءُ ـ قَالَ مَعْمَرٌ أُرَاهُ قَالَ ـ أَعُوذُ بِاللَّهِ مِنْكَ‏.‏ فَانْصَرَفْتُ، فَرَجَعْتُ إِلَيْهِمْ إِذْ جَاءَ رَسُولُ عُثْمَانَ فَأَتَيْتُهُ، فَقَالَ مَا نَصِيحَتُكَ فَقُلْتُ إِنَّ اللَّهَ سُبْحَانَهُ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ، وَأَنْزَلَ عَلَيْهِ الْكِتَابَ، وَكُنْتَ مِمَّنِ اسْتَجَابَ لِلَّهِ وَلِرَسُولِهِ، فَهَاجَرْتَ الْهِجْرَتَيْنِ، وَصَحِبْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَرَأَيْتَ هَدْيَهُ، وَقَدْ أَكْثَرَ النَّاسُ فِي شَأْنِ الْوَلِيدِ‏.‏ قَالَ أَدْرَكْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ لاَ وَلَكِنْ خَلَصَ إِلَىَّ مِنْ عِلْمِهِ مَا يَخْلُصُ إِلَى الْعَذْرَاءِ فِي سِتْرِهَا‏.‏ قَالَ أَمَّا بَعْدُ فَإِنَّ اللَّهَ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ، فَكُنْتُ مِمَّنِ اسْتَجَابَ لِلَّهِ وَلِرَسُولِهِ وَآمَنْتُ بِمَا بُعِثَ بِهِ، وَهَاجَرْتُ الْهِجْرَتَيْنِ كَمَا قُلْتَ، وَصَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَبَايَعْتُهُ، فَوَاللَّهِ مَا عَصَيْتُهُ وَلاَ غَشَشْتُهُ حَتَّى تَوَفَّاهُ اللَّهُ، ثُمَّ أَبُو بَكْرٍ مِثْلُهُ، ثُمَّ عُمَرُ مِثْلُهُ، ثُمَّ اسْتُخْلِفْتُ، أَفَلَيْسَ لِي مِنَ الْحَقِّ مِثْلُ الَّذِي لَهُمْ قُلْتُ بَلَى‏.‏ قَالَ فَمَا هَذِهِ الأَحَادِيثُ الَّتِي تَبْلُغُنِي عَنْكُمْ أَمَّا مَا ذَكَرْتَ مِنْ شَأْنِ الْوَلِيدِ، فَسَنَأْخُذُ فِيهِ بِالْحَقِّ إِنْ شَاءَ اللَّهُ، ثُمَّ دَعَا عَلِيًّا فَأَمَرَهُ أَنْ يَجْلِدَهُ فَجَلَدَهُ ثَمَانِينَ‏.‏\hadithno{3696}\hadithtrans{Narrated 'Ubaidullah bin `Adi bin Al-Khiyar:Al-Miswar bin Makhrama and `Abdur-Rahman bin Al-Aswad bin 'Abd Yaghuth said (to me), "What forbids you to talk to `Uthman about his brother Al-Walid because people have talked much about him?" So I went to `Uthman and when he went out for prayer I said (to him), "I have something to say to you and it is a piece of advice for you " `Uthman said, "O man, from you." (Ma`mar said: I see that he said, "I seek Refuge with Allah from you.") So I left him and went to them. Then the messenger of `Uthman came and I went to him (i.e. `Uthman), `Uthman asked, "What is your advice?" I replied, "Allah sent Muhammad with the Truth, and revealed the Divine Book (i.e. Qur'an) to him; and you were amongst those who followed Allah and His Apostle, and you participated in the two migrations (to Ethiopia and to Medina) and enjoyed the company of Allah's Messenger (ﷺ) and saw his way. No doubt, the people are talking much about Al-Walid." `Uthman said, "Did you receive your knowledge directly from Allah's Messenger (ﷺ) ?" I said, "No, but his knowledge did reach me and it reached (even) to a virgin in her seclusion." `Uthman said, "And then Allah sent Muhammad with the Truth and I was amongst those who followed Allah and His Apostle and I believed in what ever he (i.e. the Prophet) was sent with, and participated in two migrations, as you have said, and I enjoyed the company of Allah's Messenger (ﷺ) and gave the pledge of allegiance to him. By Allah! I never disobeyed him, nor did I cheat him till Allah took him unto Him. Then I treated Abu Bakr and then `Umar similarly and then I was made Caliph. So, don't I have rights similar to theirs?" I said, "Yes." He said, "Then what are these talks reaching me from you people? Now, concerning what you mentioned about the question of Al-Walid, Allah willing, I shall deal with him according to what is right." Then he called `Ali and ordered him to flog him, and `Ali flogged him (i.e. Al-Walid) eighty lashes}}
\hadithdefcmd{bukhari}{3697}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ بَزِيغٍ، حَدَّثَنَا شَاذَانُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ الْمَاجِشُونُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنَّا فِي زَمَنِ النَّبِيِّ صلى الله عليه وسلم لاَ نَعْدِلُ بِأَبِي بَكْرٍ أَحَدًا ثُمَّ عُمَرَ ثُمَّ عُثْمَانَ، ثُمَّ نَتْرُكُ أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم لاَ نُفَاضِلُ بَيْنَهُمْ‏.‏ تَابَعَهُ عَبْدُ اللَّهِ عَنْ عَبْدِ الْعَزِيزِ‏.‏\hadithno{3697}\hadithtrans{Narrated Ibn `Umar:During the lifetime of the Prophet (ﷺ) we considered Abu Bakr as peerless and then `Umar and then `Uthman (coming next to him in superiority) and then we used not to differentiate between the companions of the Prophet}}
\hadithdefcmd{bukhari}{3698}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عُثْمَانُ ـ هُوَ ابْنُ مَوْهَبٍ ـ قَالَ جَاءَ رَجُلٌ مَنْ أَهْلِ مِصْرَ حَجَّ الْبَيْتَ فَرَأَى قَوْمًا جُلُوسًا، فَقَالَ مَنْ هَؤُلاَءِ الْقَوْمُ قَالَ هَؤُلاَءِ قُرَيْشٌ‏.‏ قَالَ فَمَنِ الشَّيْخُ فِيهِمْ قَالُوا عَبْدُ اللَّهِ بْنُ عُمَرَ‏.‏ قَالَ يَا ابْنَ عُمَرَ إِنِّي سَائِلُكَ عَنْ شَىْءٍ فَحَدِّثْنِي هَلْ تَعْلَمُ أَنَّ عُثْمَانَ فَرَّ يَوْمَ أُحُدٍ قَالَ نَعَمْ‏.‏ قَالَ تَعْلَمُ أَنَّهُ تَغَيَّبَ عَنْ بَدْرٍ وَلَمْ يَشْهَدْ قَالَ نَعَمْ‏.‏ قَالَ تَعْلَمُ أَنَّهُ تَغَيَّبَ عَنْ بَيْعَةِ الرُّضْوَانِ فَلَمْ يَشْهَدْهَا قَالَ نَعَمْ‏.‏ قَالَ اللَّهُ أَكْبَرُ‏.‏ قَالَ ابْنُ عُمَرَ تَعَالَ أُبَيِّنْ لَكَ أَمَّا فِرَارُهُ يَوْمَ أُحُدٍ فَأَشْهَدُ أَنَّ اللَّهَ عَفَا عَنْهُ وَغَفَرَ لَهُ، وَأَمَّا تَغَيُّبُهُ عَنْ بَدْرٍ، فَإِنَّهُ كَانَتْ تَحْتَهُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَتْ مَرِيضَةً، فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ لَكَ أَجْرَ رَجُلٍ مِمَّنْ شَهِدَ بَدْرًا وَسَهْمَهُ ‏"‏‏.‏ وَأَمَّا تَغَيُّبُهُ عَنْ بَيْعَةِ الرُّضْوَانِ فَلَوْ كَانَ أَحَدٌ أَعَزَّ بِبَطْنِ مَكَّةَ مِنْ عُثْمَانَ لَبَعَثَهُ مَكَانَهُ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عُثْمَانَ وَكَانَتْ بَيْعَةُ الرُّضْوَانِ بَعْدَ مَا ذَهَبَ عُثْمَانُ إِلَى مَكَّةَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ الْيُمْنَى ‏"‏ هَذِهِ يَدُ عُثْمَانَ ‏"‏‏.‏ فَضَرَبَ بِهَا عَلَى يَدِهِ، فَقَالَ ‏"‏ هَذِهِ لِعُثْمَانَ ‏"‏‏.‏ فَقَالَ لَهُ ابْنُ عُمَرَ اذْهَبْ بِهَا الآنَ مَعَكَ‏.‏\hadithno{3698}\hadithtrans{Narrated `Uthman:(the son of Mawhab) An Egyptian who came and performed the Hajj to the Ka`ba saw some people sitting. He enquired, "Who are these people?" Somebody said, "They are the tribe of Quraish." He said, "Who is the old man sitting amongst them?" The people replied, "He is `Abdullah bin `Umar." He said, "O Ibn `Umar! I want to ask you about something; please tell me about it. Do you know that `Uthman fled away on the day (of the battle) of Uhud?" Ibn `Umar said, "Yes." The (Egyptian) man said, "Do you know that `Uthman was absent on the day (of the battle) of Badr and did not join it?" Ibn `Umar said, "Yes." The man said, "Do you know that he failed to attend the Ar Ridwan pledge and did not witness it (i.e. Hudaibiya pledge of allegiance)?" Ibn `Umar said, "Yes." The man said, "Allahu Akbar!" Ibn `Umar said, "Let me explain to you (all these three things). As for his flight on the day of Uhud, I testify that Allah has excused him and forgiven him; and as for his absence from the battle of Badr, it was due to the fact that the daughter of Allah's Messenger (ﷺ) was his wife and she was sick then. Allah's Messenger (ﷺ) said to him, "You will receive the same reward and share (of the booty) as anyone of those who participated in the battle of Badr (if you stay with her).' As for his absence from the Ar-Ridwan pledge of allegiance, had there been any person in Mecca more respectable than `Uthman (to be sent as a representative). Allah's Messenger (ﷺ) would have sent him instead of him. No doubt, Allah's Messenger (ﷺ) had sent him, and the incident of the Ar-Ridwan pledge of Allegiance happened after `Uthman had gone to Mecca. Allah's Messenger (ﷺ) held out his right hand saying, 'This is `Uthman's hand.' He stroke his (other) hand with it saying, 'This (pledge of allegiance) is on the behalf of `Uthman.' Then Ibn `Umar said to the man, 'Bear (these) excuses in mind with you}}
\hadithdefcmd{bukhari}{3699}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، أَنَّ أَنَسًا ـ رضى الله عنه ـ حَدَّثَهُمْ قَالَ صَعِدَ النَّبِيُّ صلى الله عليه وسلم أُحُدًا، وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ، فَرَجَفَ وَقَالَ ‏ "‏ اسْكُنْ أُحُدُ ـ أَظُنُّهُ ضَرَبَهُ بِرِجْلِهِ ـ فَلَيْسَ عَلَيْكَ إِلاَّ نَبِيٌّ وَصِدِّيقٌ وَشَهِيدَانِ ‏"‏‏.‏\hadithno{3699}\hadithtrans{Narrated Anas:The Prophet (ﷺ) ascended the mountain of Uhud and Abu Bakr, `Umar and `Uthman were accompanying him. The mountain gave a shake (i.e. trembled underneath them) . The Prophet (ﷺ) said, "O Uhud ! Be calm." I think that the Prophet (ﷺ) hit it with his foot, adding, "For upon you there are none but a Prophet, a Siddiq and two martyrs}}
\hadithdefcmd{bukhari}{3700}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ حُصَيْنٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ رَأَيْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ قَبْلَ أَنْ يُصَابَ بِأَيَّامٍ بِالْمَدِينَةِ وَقَفَ عَلَى حُذَيْفَةَ بْنِ الْيَمَانِ وَعُثْمَانَ بْنِ حُنَيْفٍ، قَالَ كَيْفَ فَعَلْتُمَا أَتَخَافَانِ أَنْ تَكُونَا قَدْ حَمَّلْتُمَا الأَرْضَ مَا لاَ تُطِيقُ قَالاَ حَمَّلْنَاهَا أَمْرًا هِيَ لَهُ مُطِيقَةٌ، مَا فِيهَا كَبِيرُ فَضْلٍ‏.‏ قَالَ انْظُرَا أَنْ تَكُونَا حَمَّلْتُمَا الأَرْضَ مَا لاَ تُطِيقُ، قَالَ قَالاَ لاَ‏.‏ فَقَالَ عُمَرُ لَئِنْ سَلَّمَنِي اللَّهُ لأَدَعَنَّ أَرَامِلَ أَهْلِ الْعِرَاقِ لاَ يَحْتَجْنَ إِلَى رَجُلٍ بَعْدِي أَبَدًا‏.‏ قَالَ فَمَا أَتَتْ عَلَيْهِ إِلاَّ رَابِعَةٌ حَتَّى أُصِيبَ‏.‏ قَالَ إِنِّي لَقَائِمٌ مَا بَيْنِي وَبَيْنَهُ إِلاَّ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ غَدَاةَ أُصِيبَ، وَكَانَ إِذَا مَرَّ بَيْنَ الصَّفَّيْنِ قَالَ اسْتَوُوا‏.‏ حَتَّى إِذَا لَمْ يَرَ فِيهِنَّ خَلَلاً تَقَدَّمَ فَكَبَّرَ، وَرُبَّمَا قَرَأَ سُورَةَ يُوسُفَ، أَوِ النَّحْلَ، أَوْ نَحْوَ ذَلِكَ، فِي الرَّكْعَةِ الأُولَى حَتَّى يَجْتَمِعَ النَّاسُ، فَمَا هُوَ إِلاَّ أَنْ كَبَّرَ فَسَمِعْتُهُ يَقُولُ قَتَلَنِي ـ أَوْ أَكَلَنِي ـ الْكَلْبُ‏.‏ حِينَ طَعَنَهُ، فَطَارَ الْعِلْجُ بِسِكِّينٍ ذَاتِ طَرَفَيْنِ لاَ يَمُرُّ عَلَى أَحَدٍ يَمِينًا وَلاَ شِمَالاً إِلاَّ طَعَنَهُ حَتَّى طَعَنَ ثَلاَثَةَ عَشَرَ رَجُلاً، مَاتَ مِنْهُمْ سَبْعَةٌ، فَلَمَّا رَأَى ذَلِكَ رَجُلٌ مِنَ الْمُسْلِمِينَ، طَرَحَ عَلَيْهِ بُرْنُسًا، فَلَمَّا ظَنَّ الْعِلْجُ أَنَّهُ مَأْخُوذٌ نَحَرَ نَفْسَهُ، وَتَنَاوَلَ عُمَرُ يَدَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ فَقَدَّمَهُ، فَمَنْ يَلِي عُمَرَ فَقَدْ رَأَى الَّذِي أَرَى، وَأَمَّا نَوَاحِي الْمَسْجِدِ فَإِنَّهُمْ لاَ يَدْرُونَ غَيْرَ أَنَّهُمْ قَدْ فَقَدُوا صَوْتَ عُمَرَ وَهُمْ يَقُولُونَ سُبْحَانَ اللَّهِ سُبْحَانَ اللَّهِ‏.‏ فَصَلَّى بِهِمْ عَبْدُ الرَّحْمَنِ صَلاَةً خَفِيفَةً، فَلَمَّا انْصَرَفُوا‏.‏ قَالَ يَا ابْنَ عَبَّاسٍ، انْظُرْ مَنْ قَتَلَنِي‏.‏ فَجَالَ سَاعَةً، ثُمَّ جَاءَ، فَقَالَ غُلاَمُ الْمُغِيرَةِ‏.‏ قَالَ الصَّنَعُ قَالَ نَعَمْ‏.‏ قَالَ قَاتَلَهُ اللَّهُ لَقَدْ أَمَرْتُ بِهِ مَعْرُوفًا، الْحَمْدُ لِلَّهِ الَّذِي لَمْ يَجْعَلْ مَنِيَّتِي بِيَدِ رَجُلٍ يَدَّعِي الإِسْلاَمَ، قَدْ كُنْتَ أَنْتَ وَأَبُوكَ تُحِبَّانِ أَنْ تَكْثُرَ الْعُلُوجُ بِالْمَدِينَةِ وَكَانَ ‏\{‏الْعَبَّاسُ‏\}‏ أَكْثَرَهُمْ رَقِيقًا‏.‏ فَقَالَ إِنْ شِئْتَ فَعَلْتُ‏.‏ أَىْ إِنْ شِئْتَ قَتَلْنَا‏.‏ قَالَ كَذَبْتَ، بَعْدَ مَا تَكَلَّمُوا بِلِسَانِكُمْ، وَصَلَّوْا قِبْلَتَكُمْ وَحَجُّوا حَجَّكُمْ فَاحْتُمِلَ إِلَى بَيْتِهِ فَانْطَلَقْنَا مَعَهُ، وَكَأَنَّ النَّاسَ لَمْ تُصِبْهُمْ مُصِيبَةٌ قَبْلَ يَوْمَئِذٍ، فَقَائِلٌ يَقُولُ لاَ بَأْسَ‏.‏ وَقَائِلٌ يَقُولُ أَخَافُ عَلَيْهِ، فَأُتِيَ بِنَبِيذٍ فَشَرِبَهُ فَخَرَجَ مِنْ جَوْفِهِ، ثُمَّ أُتِيَ بِلَبَنٍ فَشَرِبَهُ فَخَرَجَ مِنْ جُرْحِهِ، فَعَلِمُوا أَنَّهُ مَيِّتٌ، فَدَخَلْنَا عَلَيْهِ، وَجَاءَ النَّاسُ يُثْنُونَ عَلَيْهِ، وَجَاءَ رَجُلٌ شَابٌّ، فَقَالَ أَبْشِرْ يَا أَمِيرَ الْمُؤْمِنِينَ بِبُشْرَى اللَّهِ لَكَ مِنْ صُحْبَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدَمٍ فِي الإِسْلاَمِ مَا قَدْ عَلِمْتَ، ثُمَّ وَلِيتَ فَعَدَلْتَ، ثُمَّ شَهَادَةٌ‏.‏ قَالَ وَدِدْتُ أَنَّ ذَلِكَ كَفَافٌ لاَ عَلَىَّ وَلاَ لِي‏.‏ فَلَمَّا أَدْبَرَ، إِذَا إِزَارُهُ يَمَسُّ الأَرْضَ‏.‏ قَالَ رُدُّوا عَلَىَّ الْغُلاَمَ قَالَ ابْنَ أَخِي ارْفَعْ ثَوْبَكَ، فَإِنَّهُ أَبْقَى لِثَوْبِكَ وَأَتْقَى لِرَبِّكَ، يَا عَبْدَ اللَّهِ بْنَ عُمَرَ انْظُرْ مَا عَلَىَّ مِنَ الدَّيْنِ‏.‏ فَحَسَبُوهُ فَوَجَدُوهُ سِتَّةً وَثَمَانِينَ أَلْفًا أَوْ نَحْوَهُ، قَالَ إِنْ وَفَى لَهُ مَالُ آلِ عُمَرَ، فَأَدِّهِ مِنْ أَمْوَالِهِمْ، وَإِلاَّ فَسَلْ فِي بَنِي عَدِيِّ بْنِ كَعْبٍ، فَإِنْ لَمْ تَفِ أَمْوَالُهُمْ فَسَلْ فِي قُرَيْشٍ، وَلاَ تَعْدُهُمْ إِلَى غَيْرِهِمْ، فَأَدِّ عَنِّي هَذَا الْمَالَ، انْطَلِقْ إِلَى عَائِشَةَ أُمِّ الْمُؤْمِنِينَ فَقُلْ يَقْرَأُ عَلَيْكِ عُمَرُ السَّلاَمَ‏.‏ وَلاَ تَقُلْ أَمِيرُ الْمُؤْمِنِينَ‏.‏ فَإِنِّي لَسْتُ الْيَوْمَ لِلْمُؤْمِنِينَ أَمِيرًا، وَقُلْ يَسْتَأْذِنُ عُمَرُ بْنُ الْخَطَّابِ أَنْ يُدْفَنَ مَعَ صَاحِبَيْهِ‏.‏ فَسَلَّمَ وَاسْتَأْذَنَ، ثُمَّ دَخَلَ عَلَيْهَا، فَوَجَدَهَا قَاعِدَةً تَبْكِي فَقَالَ يَقْرَأُ عَلَيْكِ عُمَرُ بْنُ الْخَطَّابِ السَّلاَمَ وَيَسْتَأْذِنُ أَنْ يُدْفَنَ مَعَ صَاحِبَيْهِ‏.‏ فَقَالَتْ كُنْتُ أُرِيدُهُ لِنَفْسِي، وَلأُوثِرَنَّ بِهِ الْيَوْمَ عَلَى نَفْسِي‏.‏ فَلَمَّا أَقْبَلَ قِيلَ هَذَا عَبْدُ اللَّهِ بْنُ عُمَرَ قَدْ جَاءَ‏.‏ قَالَ ارْفَعُونِي، فَأَسْنَدَهُ رَجُلٌ إِلَيْهِ، فَقَالَ مَا لَدَيْكَ قَالَ الَّذِي تُحِبُّ يَا أَمِيرَ الْمُؤْمِنِينَ أَذِنَتْ‏.‏ قَالَ الْحَمْدُ لِلَّهِ، مَا كَانَ مِنْ شَىْءٍ أَهَمُّ إِلَىَّ مِنْ ذَلِكَ، فَإِذَا أَنَا قَضَيْتُ فَاحْمِلُونِي ثُمَّ سَلِّمْ فَقُلْ يَسْتَأْذِنُ عُمَرُ بْنُ الْخَطَّابِ، فَإِنْ أَذِنَتْ لِي فَأَدْخِلُونِي، وَإِنْ رَدَّتْنِي رُدُّونِي إِلَى مَقَابِرِ الْمُسْلِمِينَ‏.‏ وَجَاءَتْ أُمُّ الْمُؤْمِنِينَ حَفْصَةُ وَالنِّسَاءُ تَسِيرُ مَعَهَا، فَلَمَّا رَأَيْنَاهَا قُمْنَا، فَوَلَجَتْ عَلَيْهِ فَبَكَتْ عِنْدَهُ سَاعَةً، وَاسْتَأْذَنَ الرِّجَالُ، فَوَلَجَتْ دَاخِلاً لَهُمْ، فَسَمِعْنَا بُكَاءَهَا مِنَ الدَّاخِلِ‏.‏ فَقَالُوا أَوْصِ يَا أَمِيرَ الْمُؤْمِنِينَ اسْتَخْلِفْ‏.‏ قَالَ مَا أَجِدُ أَحَقَّ بِهَذَا الأَمْرِ مِنْ هَؤُلاَءِ النَّفَرِ أَوِ الرَّهْطِ الَّذِينَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ عَنْهُمْ رَاضٍ‏.‏ فَسَمَّى عَلِيًّا وَعُثْمَانَ وَالزُّبَيْرَ وَطَلْحَةَ وَسَعْدًا وَعَبْدَ الرَّحْمَنِ وَقَالَ يَشْهَدُكُمْ عَبْدُ اللَّهِ بْنُ عُمَرَ وَلَيْسَ لَهُ مِنَ الأَمْرِ شَىْءٌ ـ كَهَيْئَةِ التَّعْزِيَةِ لَهُ ـ فَإِنْ أَصَابَتِ الإِمْرَةُ سَعْدًا فَهْوَ ذَاكَ، وَإِلاَّ فَلْيَسْتَعِنْ بِهِ أَيُّكُمْ مَا أُمِّرَ، فَإِنِّي لَمْ أَعْزِلْهُ عَنْ عَجْزٍ وَلاَ خِيَانَةٍ وَقَالَ أُوصِي الْخَلِيفَةَ مِنْ بَعْدِي بِالْمُهَاجِرِينَ الأَوَّلِينَ أَنْ يَعْرِفَ لَهُمْ حَقَّهُمْ، وَيَحْفَظَ لَهُمْ حُرْمَتَهُمْ، وَأُوصِيهِ بِالأَنْصَارِ خَيْرًا، الَّذِينَ تَبَوَّءُوا الدَّارَ وَالإِيمَانَ مِنْ قَبْلِهِمْ، أَنْ يُقْبَلَ مِنْ مُحْسِنِهِمْ، وَأَنْ يُعْفَى عَنْ مُسِيئِهِمْ، وَأُوصِيهِ بِأَهْلِ الأَمْصَارِ خَيْرًا فَإِنَّهُمْ رِدْءُ الإِسْلاَمِ، وَجُبَاةُ الْمَالِ، وَغَيْظُ الْعَدُوِّ، وَأَنْ لاَ يُؤْخَذَ مِنْهُمْ إِلاَّ فَضْلُهُمْ عَنْ رِضَاهُمْ، وَأُوصِيهِ بِالأَعْرَابِ خَيْرًا، فَإِنَّهُمْ أَصْلُ الْعَرَبِ وَمَادَّةُ الإِسْلاَمِ أَنْ يُؤْخَذَ مِنْ حَوَاشِي أَمْوَالِهِمْ وَتُرَدَّ عَلَى فُقَرَائِهِمْ، وَأُوصِيهِ بِذِمَّةِ اللَّهِ وَذِمَّةِ رَسُولِهِ صلى الله عليه وسلم أَنْ يُوفَى لَهُمْ بِعَهْدِهِمْ، وَأَنْ يُقَاتَلَ مِنْ وَرَائِهِمْ، وَلاَ يُكَلَّفُوا إِلاَّ طَاقَتَهُمْ‏.‏ فَلَمَّا قُبِضَ خَرَجْنَا بِهِ فَانْطَلَقْنَا نَمْشِي فَسَلَّمَ عَبْدُ اللَّهِ بْنُ عُمَرَ قَالَ يَسْتَأْذِنُ عُمَرُ بْنُ الْخَطَّابِ‏.‏ قَالَتْ أَدْخِلُوهُ‏.‏ فَأُدْخِلَ، فَوُضِعَ هُنَالِكَ مَعَ صَاحِبَيْهِ، فَلَمَّا فُرِغَ مِنْ دَفْنِهِ اجْتَمَعَ هَؤُلاَءِ الرَّهْطُ، فَقَالَ عَبْدُ الرَّحْمَنِ اجْعَلُوا أَمْرَكُمْ إِلَى ثَلاَثَةٍ مِنْكُمْ‏.‏ فَقَالَ الزُّبَيْرُ قَدْ جَعَلْتُ أَمْرِي إِلَى عَلِيٍّ‏.‏ فَقَالَ طَلْحَةُ قَدْ جَعَلْتُ أَمْرِي إِلَى عُثْمَانَ‏.‏ وَقَالَ سَعْدٌ قَدْ جَعَلْتُ أَمْرِي إِلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ‏.‏ فَقَالَ عَبْدُ الرَّحْمَنِ أَيُّكُمَا تَبَرَّأَ مِنْ هَذَا الأَمْرِ فَنَجْعَلُهُ إِلَيْهِ، وَاللَّهُ عَلَيْهِ وَالإِسْلاَمُ لَيَنْظُرَنَّ أَفْضَلَهُمْ فِي نَفْسِهِ‏.‏ فَأُسْكِتَ الشَّيْخَانِ، فَقَالَ عَبْدُ الرَّحْمَنِ أَفَتَجْعَلُونَهُ إِلَىَّ، وَاللَّهُ عَلَىَّ أَنْ لاَ آلُوَ عَنْ أَفْضَلِكُمْ قَالاَ نَعَمْ، فَأَخَذَ بِيَدِ أَحَدِهِمَا فَقَالَ لَكَ قَرَابَةٌ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَالْقَدَمُ فِي الإِسْلاَمِ مَا قَدْ عَلِمْتَ، فَاللَّهُ عَلَيْكَ لَئِنْ أَمَّرْتُكَ لَتَعْدِلَنَّ، وَلَئِنْ أَمَّرْتُ عُثْمَانَ لَتَسْمَعَنَّ وَلَتُطِيعَنَّ‏.‏ ثُمَّ خَلاَ بِالآخَرِ فَقَالَ لَهُ مِثْلَ ذَلِكَ، فَلَمَّا أَخَذَ الْمِيثَاقَ قَالَ ارْفَعْ يَدَكَ يَا عُثْمَانُ‏.‏ فَبَايَعَهُ، فَبَايَعَ لَهُ عَلِيٌّ، وَوَلَجَ أَهْلُ الدَّارِ فَبَايَعُوهُ‏.‏\hadithno{3700}\hadithtrans{Narrated `Amr bin Maimun:I saw `Umar bin Al-Khattab a few days before he was stabbed in Medina. He was standing with Hudhaifa bin Al-Yaman and `Uthman bin Hunaif to whom he said, "What have you done? Do you think that you have imposed more taxation on the land (of As-Swad i.e. 'Iraq) than it can bear?" They replied, "We have imposed on it what it can bear because of its great yield." `Umar again said, "Check whether you have imposed on the land what it can not bear." They said, "No, (we haven't)." `Umar added, "If Allah should keep me alive I will let the widows of Iraq need no men to support them after me." But only four days had elapsed when he was stabbed (to death ). The day he was stabbed, I was standing and there was nobody between me and him (i.e. `Umar) except `Abdullah bin `Abbas. Whenever `Umar passed between the two rows, he would say, "Stand in straight lines." When he saw no defect (in the rows), he would go forward and start the prayer with Takbir. He would recite Surat Yusuf or An-Nahl or the like in the first rak`a so that the people may have the time to Join the prayer. As soon as he said Takbir, I heard him saying, "The dog has killed or eaten me," at the time he (i.e. the murderer) stabbed him. A non-Arab infidel proceeded on carrying a double-edged knife and stabbing all the persons he passed by on the right and left (till) he stabbed thirteen persons out of whom seven died. When one of the Muslims saw that, he threw a cloak on him. Realizing that he had been captured, the non-Arab infidel killed himself, `Umar held the hand of `Abdur-Rahman bin `Auf and let him lead the prayer. Those who were standing by the side of `Umar saw what I saw, but the people who were in the other parts of the Mosque did not see anything, but they lost the voice of `Umar and they were saying, "Subhan Allah! Subhan Allah! (i.e. Glorified be Allah)." `Abdur-Rahman bin `Auf led the people a short prayer. When they finished the prayer, `Umar said, "O Ibn `Abbas! Find out who attacked me." Ibn `Abbas kept on looking here and there for a short time and came to say. "The slave of Al Mughira." On that `Umar said, "The craftsman?" Ibn `Abbas said, "Yes." `Umar said, "May Allah curse him. I did not treat him unjustly. All the Praises are for Allah Who has not caused me to die at the hand of a man who claims himself to be a Muslim. No doubt, you and your father (Abbas) used to love to have more non-Arab infidels in Medina." Al-Abbas had the greatest number of slaves. Ibn `Abbas said to `Umar. "If you wish, we will do." He meant, "If you wish we will kill them." `Umar said, "You are mistaken (for you can't kill them) after they have spoken your language, prayed towards your Qibla, and performed Hajj like yours." Then `Umar was carried to his house, and we went along with him, and the people were as if they had never suffered a calamity before. Some said, "Do not worry (he will be Alright soon)." Some said, "We are afraid (that he will die)." Then an infusion of dates was brought to him and he drank it but it came out (of the wound) of his belly. Then milk was brought to him and he drank it, and it also came out of his belly. The people realized that he would die. We went to him, and the people came, praising him. A young man came saying, "O chief of the believers! Receive the glad tidings from Allah to you due to your company with Allah's Messenger (ﷺ) and your superiority in Islam which you know. Then you became the ruler (i.e. Caliph) and you ruled with justice and finally you have been martyred." `Umar said, "I wish that all these privileges will counterbalance (my shortcomings) so that I will neither lose nor gain anything." When the young man turned back to leave, his clothes seemed to be touching the ground. `Umar said, "Call the young man back to me." (When he came back) `Umar said, "O son of my brother! Lift your clothes, for this will keep your clothes clean and save you from the Punishment of your Lord." `Umar further said, "O `Abdullah bin `Umar! See how much I am in debt to others." When the debt was checked, it amounted to approximately eighty-six thousand. `Umar said, "If the property of `Umar's family covers the debt, then pay the debt thereof; otherwise request it from Bani `Adi bin Ka`b, and if that too is not sufficient, ask for it from Quraish tribe, and do not ask for it from any one else, and pay this debt on my behalf." `Umar then said (to `Abdullah), "Go to `Aisha (the mother of the believers) and say: "`Umar is paying his salutation to you. But don't say: 'The chief of the believers,' because today I am not the chief of the believers. And say: "`Umar bin Al-Khattab asks the permission to be buried with his two companions (i.e. the Prophet, and Abu Bakr)." `Abdullah greeted `Aisha and asked for the permission for entering, and then entered to her and found her sitting and weeping. He said to her, "`Umar bin Al-Khattab is paying his salutations to you, and asks the permission to be buried with his two companions." She said, "I had the idea of having this place for myself, but today I prefer `Umar to myself." When he returned it was said (to `Umar), "`Abdullah bin `Umar has come." `Umar said, "Make me sit up." Somebody supported him against his body and `Umar asked (`Abdullah), "What news do you have?" He said, "O chief of the believers! It is as you wish. She has given the permission." `Umar said, "Praise be to Allah, there was nothing more important to me than this. So when I die, take me, and greet `Aisha and say: "`Umar bin Al-Khattab asks the permission (to be buried with the Prophet (ﷺ) ), and if she gives the permission, bury me there, and if she refuses, then take me to the grave-yard of the Muslims." Then Hafsa (the mother of the believers) came with many other women walking with her. When we saw her, we went away. She went in (to `Umar) and wept there for sometime. When the men asked for permission to enter, she went into another place, and we heard her weeping inside. The people said (to `Umar), "O chief of the believers! Appoint a successor." `Umar said, "I do not find anyone more suitable for the job than the following persons or group whom Allah's Messenger (ﷺ) had been pleased with before he died." Then `Umar mentioned `Ali, `Uthman, Az-Zubair, Talha, Sa`d and `Abdur-Rahman (bin `Auf) and said, "Abdullah bin `Umar will be a witness to you, but he will have no share in the rule. His being a witness will compensate him for not sharing the right of ruling. If Sa`d becomes the ruler, it will be alright: otherwise, whoever becomes the ruler should seek his help, as I have not dismissed him because of disability or dishonesty." `Umar added, "I recommend that my successor takes care of the early emigrants; to know their rights and protect their honor and sacred things. I also recommend that he be kind to the Ansar who had lived in Medina before the emigrants and Belief had entered their hearts before them. I recommend that the (ruler) should accept the good of the righteous among them and excuse their wrong-doers, and I recommend that he should do good to all the people of the towns (Al-Ansar), as they are the protectors of Islam and the source of wealth and the source of annoyance to the enemy. I also recommend that nothing be taken from them except from their surplus with their consent. I also recommend that he do good to the 'Arab bedouin, as they are the origin of the 'Arabs and the material of Islam. He should take from what is inferior, amongst their properties and distribute that to the poor amongst them. I also recommend him concerning Allah's and His Apostle's protectees (i.e. Dhimmis) to fulfill their contracts and to fight for them and not to overburden them with what is beyond their ability." So when `Umar expired, we carried him out and set out walking. `Abdullah bin `Umar greeted (`Aisha) and said, "`Umar bin Al-Khattab asks for the permission." `Aisha said, "Bring him in." He was brought in and buried beside his two companions. When he was buried, the group (recommended by `Umar) held a meeting. Then `Abdur-Rahman said, " Reduce the candidates for rulership to three of you." Az-Zubair said, "I give up my right to `Ali." Talha said, "I give up my right to `Uthman." Sa`d said, 'I give up my right to `Abdur-Rahman bin `Auf." `Abdur-Rahman then said (to `Uthman and `Ali), "Now which of you is willing to give up his right of candidacy so that he may choose the better of the (remaining) two, bearing in mind that Allah and Islam will be his witnesses." So both the sheiks (i.e. `Uthman and `Ali) kept silent. `Abdur-Rahman said, "Will you both leave this matter to me, and I take Allah as my Witness that I will not choose but the better of you?" They said, "Yes." So `Abdur-Rahman took the hand of one of them (i.e. `Ali) and said, "You are related to Allah's Messenger (ﷺ) and one of the earliest Muslims as you know well. So I ask you by Allah to promise that if I select you as a ruler you will do justice, and if I select `Uthman as a ruler you will listen to him and obey him." Then he took the other (i.e. `Uthman) aside and said the same to him. When `Abdur-Rahman secured (their agreement to) this covenant, he said, "O `Uthman! Raise your hand." So he (i.e. `Abdur-Rahman) gave him (i.e. `Uthman) the solemn pledge, and then `Ali gave him the pledge of allegiance and then all the (Medina) people gave him the pledge of allegiance}}
\hadithdefcmd{bukhari}{3701}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لأُعْطِيَنَّ الرَّايَةَ غَدًا رَجُلاً يَفْتَحُ اللَّهُ عَلَى يَدَيْهِ ‏"‏ قَالَ فَبَاتَ النَّاسُ يَدُوكُونَ لَيْلَتَهُمْ أَيُّهُمْ يُعْطَاهَا فَلَمَّا أَصْبَحَ النَّاسُ، غَدَوْا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كُلُّهُمْ يَرْجُو أَنْ يُعْطَاهَا فَقَالَ ‏"‏ أَيْنَ عَلِيُّ بْنُ أَبِي طَالِبٍ ‏"‏‏.‏ فَقَالُوا يَشْتَكِي عَيْنَيْهِ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَأَرْسِلُوا إِلَيْهِ فَأْتُونِي بِهِ ‏"‏‏.‏ فَلَمَّا جَاءَ بَصَقَ فِي عَيْنَيْهِ، وَدَعَا لَهُ، فَبَرَأَ حَتَّى كَأَنْ لَمْ يَكُنْ بِهِ وَجَعٌ، فَأَعْطَاهُ الرَّايَةَ‏.‏ فَقَالَ عَلِيٌّ يَا رَسُولَ اللَّهِ أُقَاتِلُهُمْ حَتَّى يَكُونُوا مِثْلَنَا فَقَالَ ‏"‏ انْفُذْ عَلَى رِسْلِكَ حَتَّى تَنْزِلَ بِسَاحَتِهِمْ، ثُمَّ ادْعُهُمْ إِلَى الإِسْلاَمِ، وَأَخْبِرْهُمْ بِمَا يَجِبُ عَلَيْهِمْ مِنْ حَقِّ اللَّهِ فِيهِ، فَوَاللَّهِ لأَنْ يَهْدِيَ اللَّهُ بِكَ رَجُلاً وَاحِدًا خَيْرٌ لَكَ مِنْ أَنْ يَكُونَ لَكَ حُمْرُ النَّعَمِ ‏"‏‏.‏\hadithno{3701}\hadithtrans{Narrated Sahl bin Sa`d:Allah's Messenger (ﷺ) said, "Tomorrow I will give the flag to a man with whose leadership Allah will grant (the Muslims) victory." So the people kept on thinking the whole night as to who would be given the flag. The next morning the people went to Allah's Messenger (ﷺ) and every one of them hoped that he would be given the flag. The Prophet (ﷺ) said, "Where is `Ali bin Abi Talib?" The people replied, "He is suffering from eye trouble, O Allah's Messenger (ﷺ)." He said, "Send for him and bring him to me." So when `Ali came, the Prophet (ﷺ) spat in his eyes and invoked good on him, and he became alright as if he had no ailment. The Prophet (ﷺ) then gave him the flag. `Ali said, "O Allah's Messenger (ﷺ)! Shall I fight them (i.e. enemy) till they become like us?" The Prophet (ﷺ) said, "Proceed to them steadily till you approach near to them and then invite them to Islam and inform them of their duties towards Allah which Islam prescribes for them, for by Allah, if one man is guided on the right path (i.e. converted to Islam) through you, it would be better for you than (a great number of) red camels}}
\hadithdefcmd{bukhari}{3702}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمٌ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ، قَالَ كَانَ عَلِيٌّ قَدْ تَخَلَّفَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي خَيْبَرَ وَكَانَ بِهِ رَمَدٌ فَقَالَ أَنَا أَتَخَلَّفُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ عَلِيٌّ فَلَحِقَ بِالنَّبِيِّ صلى الله عليه وسلم، فَلَمَّا كَانَ مَسَاءُ اللَّيْلَةِ الَّتِي فَتَحَهَا اللَّهُ فِي صَبَاحِهَا، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأُعْطِيَنَّ الرَّايَةَ ـ أَوْ لَيَأْخُذَنَّ الرَّايَةَ ـ غَدًا رَجُلاً يُحِبُّهُ اللَّهُ وَرَسُولُهُ ـ أَوْ قَالَ يُحِبُّ اللَّهَ وَرَسُولَهُ ـ يَفْتَحُ اللَّهُ عَلَيْهِ ‏"‏‏.‏ فَإِذَا نَحْنُ بِعَلِيٍّ وَمَا نَرْجُوهُ، فَقَالُوا هَذَا عَلِيٌّ‏.‏ فَأَعْطَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَفَتَحَ اللَّهُ عَلَيْهِ‏.‏\hadithno{3702}\hadithtrans{Narrated Salama:`Ali happened to stay behind the Prophet (ﷺ) and (did not join him) during the battle of Khaibar for he was having eye trouble. Then he said, "How could I remain behind Allah's Messenger (ﷺ)?" So `Ali set out following the Prophet (ﷺ) , When it was the eve of the day in the morning of which Allah helped (the Muslims) to conquer it, Allah's Messenger (ﷺ) said, "I will give the flag (to a man), or tomorrow a man whom Allah and His Apostle love will take the flag," or said, "A man who loves Allah and His Apostle; and Allah will grant victory under his leadership." Suddenly came `Ali whom we did not expect. The people said, "This is `Ali." Allah's Messenger (ﷺ) gave him the flag and Allah granted victory under his leadership}}
\hadithdefcmd{bukhari}{3703}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، جَاءَ إِلَى سَهْلِ بْنِ سَعْدٍ فَقَالَ هَذَا فُلاَنٌ ـ لأَمِيرِ الْمَدِينَةِ ـ يَدْعُو عَلِيًّا عِنْدَ الْمِنْبَرِ‏.‏ قَالَ فَيَقُولُ مَاذَا قَالَ يَقُولُ لَهُ أَبُو تُرَابٍ‏.‏ فَضَحِكَ قَالَ وَاللَّهِ مَا سَمَّاهُ إِلاَّ النَّبِيُّ صلى الله عليه وسلم، وَمَا كَانَ لَهُ اسْمٌ أَحَبَّ إِلَيْهِ مِنْهُ‏.‏ فَاسْتَطْعَمْتُ الْحَدِيثَ سَهْلاً، وَقُلْتُ يَا أَبَا عَبَّاسٍ كَيْفَ قَالَ دَخَلَ عَلِيٌّ عَلَى فَاطِمَةَ ثُمَّ خَرَجَ فَاضْطَجَعَ فِي الْمَسْجِدِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَيْنَ ابْنُ عَمِّكِ ‏"‏‏.‏ قَالَتْ فِي الْمَسْجِدِ‏.‏ فَخَرَجَ إِلَيْهِ فَوَجَدَ رِدَاءَهُ قَدْ سَقَطَ عَنْ ظَهْرِهِ، وَخَلَصَ التُّرَابُ إِلَى ظَهْرِهِ، فَجَعَلَ يَمْسَحُ التُّرَابَ عَنْ ظَهْرِهِ فَيَقُولُ ‏"‏ اجْلِسْ يَا أَبَا تُرَابٍ ‏"‏‏.‏ مَرَّتَيْنِ‏.‏\hadithno{3703}\hadithtrans{Narrated Abu Hazim:A man came to Sahl bin Sa`d and said, "This is so-and-so," meaning the Governor of Medina, "He is calling `Ali bad names near the pulpit." Sahl asked, "What is he saying?" He (i.e. the man) replied, "He calls him (i.e. `Ali) Abu Turab." Sahl laughed and said, "By Allah, none but the Prophet (ﷺ) called him by this name and no name was dearer to `Ali than this." So I asked Sahl to tell me more, saying, "O Abu `Abbas! How (was this name given to `Ali)?" Sahl said, "`Ali went to Fatima and then came out and slept in the Mosque. The Prophet (ﷺ) asked Fatima, "Where is your cousin?" She said, "In the Mosque." The Prophet (ﷺ) went to him and found that his (i.e. `Ali's) covering sheet had slipped off his back and dust had soiled his back. The Prophet (ﷺ) started wiping the dust off his back and said twice, "Get up! O Abu Turab (i.e. O. man with the dust)}}
\hadithdefcmd{bukhari}{3704}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ أَبِي حَصِينٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، قَالَ جَاءَ رَجُلٌ إِلَى ابْنِ عُمَرَ، فَسَأَلَهُ عَنْ عُثْمَانَ،، فَذَكَرَ عَنْ مَحَاسِنِ، عَمَلِهِ، قَالَ لَعَلَّ ذَاكَ يَسُوؤُكَ‏.‏ قَالَ نَعَمْ‏.‏ قَالَ فَأَرْغَمَ اللَّهُ بِأَنْفِكَ‏.‏ ثُمَّ سَأَلَهُ عَنْ عَلِيٍّ، فَذَكَرَ مَحَاسِنَ عَمَلِهِ قَالَ هُوَ ذَاكَ، بَيْتُهُ أَوْسَطُ بُيُوتِ النَّبِيِّ صلى الله عليه وسلم‏.‏ ثُمَّ قَالَ لَعَلَّ ذَاكَ يَسُوؤُكَ‏.‏ قَالَ أَجَلْ‏.‏ قَالَ فَأَرْغَمَ اللَّهُ بِأَنْفِكَ، انْطَلِقْ فَاجْهَدْ عَلَىَّ جَهْدَكَ‏.‏\hadithno{3704}\hadithtrans{Narrated Sa`d bin 'Ubaida:A man came to Ibn `Umar and asked about `Uthman and Ibn `Umar mentioned his good deeds and said to the questioner. "Perhaps these facts annoy you?" The other said, "Yes." Ibn `Umar said, "May Allah stick your nose in the dust (i.e. degrade you)!' Then the man asked him about `Ali. Ibn `Umar mentioned his good deeds and said, "It is all true, and that is his house in the midst of the houses of the Prophet. Perhaps these facts have hurt you?" The questioner said, "Yes." Ibn `Umar said, "May Allah stick your nose in the dust (i.e. degrade you or make you do things which you hate) ! Go away and do whatever you can against me}}
\hadithdefcmd{bukhari}{3705}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، سَمِعْتُ ابْنَ أَبِي لَيْلَى، قَالَ حَدَّثَنَا عَلِيٌّ، أَنَّ فَاطِمَةَ، عَلَيْهَا السَّلاَمُ شَكَتْ مَا تَلْقَى مِنْ أَثَرِ الرَّحَا، فَأَتَى النَّبِيَّ صلى الله عليه وسلم سَبْىٌ، فَانْطَلَقَتْ فَلَمْ تَجِدْهُ، فَوَجَدَتْ عَائِشَةَ، فَأَخْبَرَتْهَا، فَلَمَّا جَاءَ النَّبِيُّ صلى الله عليه وسلم أَخْبَرَتْهُ عَائِشَةُ بِمَجِيءِ فَاطِمَةَ، فَجَاءَ النَّبِيُّ صلى الله عليه وسلم إِلَيْنَا، وَقَدْ أَخَذْنَا مَضَاجِعَنَا، فَذَهَبْتُ لأَقُومَ فَقَالَ ‏"‏ عَلَى مَكَانِكُمَا ‏"‏‏.‏ فَقَعَدَ بَيْنَنَا حَتَّى وَجَدْتُ بَرْدَ قَدَمَيْهِ عَلَى صَدْرِي وَقَالَ ‏"‏ أَلاَ أُعَلِّمُكُمَا خَيْرًا مِمَّا سَأَلْتُمَانِي إِذَا أَخَذْتُمَا مَضَاجِعَكُمَا تُكَبِّرَا أَرْبَعًا وَثَلاَثِينَ، وَتُسَبِّحَا ثَلاَثًا وَثَلاَثِينَ، وَتَحْمَدَا ثَلاَثَةً وَثَلاَثِينَ، فَهْوَ خَيْرٌ لَكُمَا مِنْ خَادِمٍ ‏"‏‏.‏\hadithno{3705}\hadithtrans{Narrated `Ali:Fatima complained of the suffering caused to her by the hand mill. Some Captives were brought to the Prophet, so she came to him but did not find him at home. `Aisha was present there to whom she told (of her desire for a servant). When the Prophet (ﷺ) came, Aisha informed him about Fatima's visit. `Ali added "So the Prophet (ﷺ) came to us, while we had gone to our bed. I wanted to get up but the Prophet (ﷺ) said, "Remain at your place". Then he sat down between us till I found the coolness of his feet on my chest. Then he said, "Shall I teach you a thing which is better than what you have asked me? When you go to bed, say, 'Allahu-Akbar' thirty-four times, and 'Subhan Allah thirty-three times, and 'Al hamdu-li l-lah thirty-three times for that is better for you both than a servant}}
\hadithdefcmd{bukhari}{3706}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدٍ، قَالَ سَمِعْتُ إِبْرَاهِيمَ بْنَ سَعْدٍ، عَنْ أَبِيهِ، قَالَ النَّبِيُّ صلى الله عليه وسلم لِعَلِيٍّ ‏ "‏ أَمَا تَرْضَى أَنْ تَكُونَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى ‏"‏‏.‏\hadithno{3706}\hadithtrans{And narrated Sad that the Prophet (ﷺ) said to 'Ali, "Will you not be pleased from this that you are to me like Aaron was to Moses?}}
\hadithdefcmd{bukhari}{3707}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ اقْضُوا كَمَا كُنْتُمْ تَقْضُونَ، فَإِنِّي أَكْرَهُ الاِخْتِلاَفَ حَتَّى يَكُونَ لِلنَّاسِ جَمَاعَةٌ، أَوْ أَمُوتَ كَمَا مَاتَ أَصْحَابِي‏.‏ فَكَانَ ابْنُ سِيرِينَ يَرَى أَنَّ عَامَّةَ مَا يُرْوَى عَلَى عَلِيٍّ الْكَذِبُ‏.‏\hadithno{3707}\hadithtrans{Narrated Ubaida: Ali said (to the people of 'Iraq), "Judge as you used to judge, for I hate differences (and I do my best ) till the people unite as one group, or I die as my companions have died}}
\hadithdefcmd{bukhari}{3708}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ دِينَارٍ أَبُو عَبْدِ اللَّهِ الْجُهَنِيُّ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّاسَ، كَانُوا يَقُولُونَ أَكْثَرَ أَبُو هُرَيْرَةَ‏.‏ وَإِنِّي كُنْتُ أَلْزَمُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِشِبَعِ بَطْنِي، حَتَّى لاَ آكُلُ الْخَمِيرَ، وَلاَ أَلْبَسُ الْحَبِيرَ، وَلاَ يَخْدُمُنِي فُلاَنٌ وَلاَ فُلاَنَةُ، وَكُنْتُ أُلْصِقُ بَطْنِي بِالْحَصْبَاءِ مِنَ الْجُوعِ، وَإِنْ كُنْتُ لأَسْتَقْرِئُ الرَّجُلَ الآيَةَ هِيَ مَعِي كَىْ يَنْقَلِبَ بِي فَيُطْعِمَنِي، وَكَانَ أَخْيَرَ النَّاسِ لِلْمِسْكِينِ جَعْفَرُ بْنُ أَبِي طَالِبٍ، كَانَ يَنْقَلِبُ بِنَا فَيُطْعِمُنَا مَا كَانَ فِي بَيْتِهِ، حَتَّى إِنْ كَانَ لَيُخْرِجُ إِلَيْنَا الْعُكَّةَ الَّتِي لَيْسَ فِيهَا شَىْءٌ، فَنَشُقُّهَا فَنَلْعَقُ مَا فِيهَا‏.‏\hadithno{3708}\hadithtrans{Narrated Abu Huraira:The people used to say, "Abu Huraira narrates too many narrations." In fact I used to keep close to Allah's Messenger (ﷺ) and was satisfied with what filled my stomach. I ate no leavened bread and dressed no decorated striped clothes, and never did a man or a woman serve me, and I often used to press my belly against gravel because of hunger, and I used to ask a man to recite a Qur'anic Verse to me although I knew it, so that he would take me to his home and feed me. And the most generous of all the people to the poor was Ja`far bin Abi Talib. He used to take us to his home and offer us what was available therein. He would even offer us an empty folded leather container (of butter) which we would split and lick whatever was in it}}
\hadithdefcmd{bukhari}{3709}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنِ الشَّعْبِيِّ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ إِذَا سَلَّمَ عَلَى ابْنِ جَعْفَرٍ قَالَ السَّلاَمُ عَلَيْكَ يَا ابْنَ ذِي الْجَنَاحَيْنِ‏.‏\hadithno{3709}\hadithtrans{Narrated Ash-Shu`bi:Whenever Ibn `Umar greeted Ibn Jafar, he used to say: "As-salamu-'Alaika (i.e. Peace be on you) O son of Dhu-l-Janahain (son of the two-winged person)}}
\hadithdefcmd{bukhari}{3710}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنِي أَبِي عَبْدُ اللَّهِ بْنُ الْمُثَنَّى، عَنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَنَسٍ، عَنْ أَنَسٍ ـ رضى الله عنه أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ إِذَا قَحَطُوا اسْتَسْقَى بِالْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، فَقَالَ اللَّهُمَّ إِنَّا كُنَّا نَتَوَسَّلُ إِلَيْكَ بِنَبِيِّنَا صلى الله عليه وسلم فَتَسْقِينَا، وَإِنَّا نَتَوَسَّلُ إِلَيْكَ بِعَمِّ نَبِيِّنَا فَاسْقِنَا‏.‏ قَالَ فَيُسْقَوْنَ‏.‏\hadithno{3710}\hadithtrans{Narrated Anas:Whenever there was drought, `Umar bin Al-Khattab used to ask Allah for rain through Al-`Abbas bin `Abdul Muttalib, saying, "O Allah! We used to request our Prophet to ask You for rain, and You would give us. Now we request the uncle of our Prophet to ask You for rain, so give us rain." And they would be given rain}}
\hadithdefcmd{bukhari}{3712}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ أَرْسَلَتْ إِلَى أَبِي بَكْرٍ تَسْأَلُهُ مِيرَاثَهَا مِنَ النَّبِيِّ صلى الله عليه وسلم فِيمَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم، تَطْلُبُ صَدَقَةَ النَّبِيِّ صلى الله عليه وسلم الَّتِي بِالْمَدِينَةِ وَفَدَكٍ وَمَا بَقِيَ مِنْ خُمُسِ خَيْبَرَ‏.‏ فَقَالَ أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ، مَا تَرَكْنَا فَهْوَ صَدَقَةٌ، إِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ مِنْ هَذَا الْمَالِ ـ يَعْنِي مَالَ اللَّهِ ـ لَيْسَ لَهُمْ أَنْ يَزِيدُوا عَلَى الْمَأْكَلِ ‏"‏‏.‏ وَإِنِّي وَاللَّهِ لاَ أُغَيِّرُ شَيْئًا مِنْ صَدَقَاتِ النَّبِيِّ صلى الله عليه وسلم الَّتِي كَانَتْ عَلَيْهَا فِي عَهْدِ النَّبِيِّ صلى الله عليه وسلم، وَلأَعْمَلَنَّ فِيهَا بِمَا عَمِلَ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ فَتَشَهَّدَ عَلِيٌّ، ثُمَّ قَالَ إِنَّا قَدْ عَرَفْنَا يَا أَبَا بَكْرٍ فَضِيلَتَكَ‏.‏ وَذَكَرَ قَرَابَتَهُمْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَحَقَّهُمْ‏.‏ فَتَكَلَّمَ أَبُو بَكْرٍ فَقَالَ وَالَّذِي نَفْسِي بِيَدِهِ، لَقَرَابَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَبُّ إِلَىَّ أَنْ أَصِلَ مِنْ قَرَابَتِي‏.‏\hadithno{3712}\hadithtrans{Narrated 'Aisha: Fatima sent somebody to Abu Bakr asking him to give her her inheritance from the Prophet (ﷺ) from what Allah had given to His Apostle through Fai (i.e. booty gained without fighting). She asked for the Sadaqa (i.e. wealth assigned for charitable purposes) of the Prophet (ﷺ) at Medina, and Fadak, and what remained of the Khumus (i.e., one-fifth) of the Khaibar booty. Abu Bakr said, "Allah's Messenger (ﷺ) said, 'We (Prophets), our property is not inherited, and whatever we leave is Sadaqa, but Muhammad's Family can eat from this property, i.e. Allah's property, but they have no right to take more than the food they need.' By Allah! I will not bring any change in dealing with the Sadaqa of the Prophet (and will keep them) as they used to be observed in his (i.e. the Prophet's) life-time, and I will dispose with it as Allah's Messenger (ﷺ) used to do," Then 'Ali said, "I testify that None has the right to be worshipped but Allah, and that Muhammad is His Apostle," and added, "O Abu Bakr! We acknowledge your superiority." Then he (i.e. 'Ali) mentioned their own relationship to Allah's Apostle and their right. Abu Bakr then spoke saying, "By Allah in Whose Hands my life is. I love to do good to the relatives of Allah's Apostle rather than to my own relatives}}
\hadithdefcmd{bukhari}{3713}{أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا شُعْبَةُ، عَنْ وَاقِدٍ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنِ ابْنِ عُمَرَ، عَنْ أَبِي بَكْرٍ ـ رضى الله عنهم ـ قَالَ ارْقُبُوا مُحَمَّدًا صلى الله عليه وسلم فِي أَهْلِ بَيْتِهِ‏.‏\hadithno{3713}\hadithtrans{Abu Bakr said: Look at Muhammad through his family (i.e. if you are no good to his family you are not good to him)}}
\hadithdefcmd{bukhari}{3714}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فَاطِمَةُ بَضْعَةٌ مِنِّي، فَمَنْ أَغْضَبَهَا أَغْضَبَنِي ‏"‏‏.‏\hadithno{3714}\hadithtrans{Narrated Al-Miswar bin Makhrama:Allah's Messenger (ﷺ) said, "Fatima is a part of me, and he who makes her angry, makes me angry}}
\hadithdefcmd{bukhari}{3716}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَعَا النَّبِيُّ صلى الله عليه وسلم فَاطِمَةَ ابْنَتَهُ فِي شَكْوَاهُ الَّذِي قُبِضَ فِيهَا، فَسَارَّهَا بِشَىْءٍ فَبَكَتْ، ثُمَّ دَعَاهَا فَسَارَّهَا فَضَحِكَتْ، قَالَتْ فَسَأَلْتُهَا عَنْ ذَلِكَ‏.‏ فَقَالَتْ سَارَّنِي النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَنِي أَنَّهُ يُقْبَضُ فِي وَجَعِهِ الَّذِي تُوُفِّيَ فِيهِ فَبَكَيْتُ، ثُمَّ سَارَّنِي فَأَخْبَرَنِي أَنِّي أَوَّلُ أَهْلِ بَيْتِهِ أَتْبَعُهُ فَضَحِكْتُ‏.‏\hadithno{3716}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) called his daughter Fatima during his illness in which he died, and told her a secret whereupon she wept. Then he called her again and told her a secret whereupon she laughed. When I asked her about that, she replied, "The Prophet (ﷺ) spoke to me in secret and informed me that he would die in the course of the illness during which he died, so I wept. He again spoke to me in secret and informed me that I would be the first of his family to follow him (after his death) and on that I laughed}}
\hadithdefcmd{bukhari}{3717}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ أَخْبَرَنِي مَرْوَانُ بْنُ الْحَكَمِ، قَالَ أَصَابَ عُثْمَانَ بْنَ عَفَّانَ رُعَافٌ شَدِيدٌ سَنَةَ الرُّعَافِ، حَتَّى حَبَسَهُ عَنِ الْحَجِّ وَأَوْصَى، فَدَخَلَ عَلَيْهِ رَجُلٌ مِنْ قُرَيْشٍ قَالَ اسْتَخْلِفْ‏.‏ قَالَ وَقَالُوهُ قَالَ نَعَمْ‏.‏ قَالَ وَمَنْ فَسَكَتَ، فَدَخَلَ عَلَيْهِ رَجُلٌ آخَرُ ـ أَحْسِبُهُ الْحَارِثَ ـ فَقَالَ اسْتَخْلِفْ‏.‏ فَقَالَ عُثْمَانُ وَقَالُوا فَقَالَ نَعَمْ‏.‏ قَالَ وَمَنْ هُوَ فَسَكَتَ قَالَ فَلَعَلَّهُمْ قَالُوا الزُّبَيْرَ قَالَ نَعَمْ‏.‏ قَالَ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهُ لَخَيْرُهُمْ مَا عَلِمْتُ، وَإِنْ كَانَ لأَحَبَّهُمْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3717}\hadithtrans{Narrated Marwan bin Al-Hakam:`Uthman bin `Affan was afflicted with severe nose-bleeding in the year when such illness was prevelant and that prevented him from performing Hajj, and (because of it) he made his will. A man from Quraish came to him and said, "Appoint your successor." `Uthman asked, "Did the people name him? (i.e. the successor) the man said, "Yes." `Uthman asked, "Who is that?" The man remained silent. Another man came to `Uthman and I think it was Al-Harith. He also said, "Appoint your successor." `Uthman asked, "Did the people name him?" The man replied "Yes." `Uthman said, "Who is that?" The man remained silent. `Uthman said, "Perhaps they have mentioned Az-Zubair?" The man said, "Yes." `Uthman said, "By Him in Whose Hands my life is, he is the best of them as I know, and the dearest of them to Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{3718}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، أَخْبَرَنِي أَبِي، سَمِعْتُ مَرْوَانَ، كُنْتُ عِنْدَ عُثْمَانَ، أَتَاهُ رَجُلٌ فَقَالَ اسْتَخْلِفْ‏.‏ قَالَ وَقِيلَ ذَاكَ قَالَ نَعَمْ، الزُّبَيْرُ‏.‏ قَالَ أَمَا وَاللَّهِ إِنَّكُمْ لَتَعْلَمُونَ أَنَّهُ خَيْرُكُمْ‏.‏ ثَلاَثًا‏.‏\hadithno{3718}\hadithtrans{Narrated Marwan bin Al-Hakam:While I was with `Uthman, a man came to him and said, "Appoint your successor." `Uthman said, "Has such successor been named?" He replied, "Yes, Az-Zubair." `Uthman said, thrice, "By Allah! Indeed you know that he is the best of you}}
\hadithdefcmd{bukhari}{3719}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ ـ هُوَ ابْنُ أَبِي سَلَمَةَ ـ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ لِكُلِّ نَبِيٍّ حَوَارِيًّا، وَإِنَّ حَوَارِيَّ الزُّبَيْرُ بْنُ الْعَوَّامِ ‏"‏‏.‏\hadithno{3719}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) said, "Every prophet used to have a Hawari (i.e. disciple), and my Hawari is Az-Zubair bin Al-`Awwam}}
\hadithdefcmd{bukhari}{3720}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا ‏\{‏عَبْدُ اللَّهِ‏\}‏ أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ كُنْتُ يَوْمَ الأَحْزَابِ جُعِلْتُ أَنَا وَعُمَرُ بْنُ أَبِي سَلَمَةَ، فِي النِّسَاءِ، فَنَظَرْتُ فَإِذَا أَنَا بِالزُّبَيْرِ، عَلَى فَرَسِهِ، يَخْتَلِفُ إِلَى بَنِي قُرَيْظَةَ مَرَّتَيْنِ أَوْ ثَلاَثًا، فَلَمَّا رَجَعْتُ قُلْتُ يَا أَبَتِ، رَأَيْتُكَ تَخْتَلِفُ‏.‏ قَالَ أَوَهَلْ رَأَيْتَنِي يَا بُنَىَّ قُلْتُ نَعَمْ‏.‏ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ يَأْتِ بَنِي قُرَيْظَةَ فَيَأْتِينِي بِخَبَرِهِمْ ‏"‏‏.‏ فَانْطَلَقْتُ، فَلَمَّا رَجَعْتُ جَمَعَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَوَيْهِ فَقَالَ ‏"‏ فِدَاكَ أَبِي وَأُمِّي ‏"‏‏.‏\hadithno{3720}\hadithtrans{Narrated `Abdullah bin Az-Zubair:During the battle of Al-Ahzab, I and `Umar bin Abi-Salama were kept behind with the women. Behold! I saw (my father) Az-Zubair riding his horse, going to and coming from Bani Quraiza twice or thrice. So when I came back I said, "O my father! I saw you going to and coming from Bani Quraiza?" He said, "Did you really see me, O my son?" I said, "Yes." He said, "Allah's Messenger (ﷺ) said, 'Who will go to Bani Quraiza and bring me their news?' So I went, and when I came back, Allah's Apostle mentioned for me both his parents saying, "Let my father and mother be sacrificed for you}}
\hadithdefcmd{bukhari}{3721}{حَدَّثَنَا عَلِيُّ بْنُ حَفْصٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ أَصْحَابَ النَّبِيِّ، صلى الله عليه وسلم قَالُوا لِلزُّبَيْرِ يَوْمَ الْيَرْمُوكِ أَلاَ تَشُدُّ فَنَشُدَّ مَعَكَ فَحَمَلَ عَلَيْهِمْ، فَضَرَبُوهُ ضَرْبَتَيْنِ عَلَى عَاتِقِهِ، بَيْنَهُمَا ضَرْبَةٌ ضُرِبَهَا يَوْمَ بَدْرٍ‏.‏ قَالَ عُرْوَةُ فَكُنْتُ أُدْخِلُ أَصَابِعِي فِي تِلْكَ الضَّرَبَاتِ أَلْعَبُ وَأَنَا صَغِيرٌ‏.‏\hadithno{3721}\hadithtrans{Narrated `Urwa:On the day of the battle of Al-Yarmuk, the companions of the Prophet (ﷺ) said to Az-Zubair, "Will you attack the enemy vigorously so that we may attack them along with you?" So Az-Zubair attacked them, and they inflicted two wounds over his shoulder, and in between these two wounds there was an old scar he had received on the day of the battle of Badr When I was a child, I used to insert my fingers into those scars in play}}
\hadithdefcmd{bukhari}{3722}{حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، عَنْ أَبِي عُثْمَانَ، قَالَ لَمْ يَبْقَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي بَعْضِ تِلْكَ الأَيَّامِ الَّتِي قَاتَلَ فِيهِنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم غَيْرُ طَلْحَةَ وَسَعْدٍ‏.‏ عَنْ حَدِيثِهِمَا‏.‏\hadithno{3722}\hadithtrans{Narrated Abu `Uthman:During one of the Ghazawat in which Allah's Messenger (ﷺ) was fighting, none remained with the Prophet (ﷺ) but Talha and Sa`d}}
\hadithdefcmd{bukhari}{3724}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا ابْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ،، قَالَ رَأَيْتُ يَدَ طَلْحَةَ الَّتِي وَقَى بِهَا النَّبِيَّ صلى الله عليه وسلم قَدْ شَلَّتْ‏.‏\hadithno{3724}\hadithtrans{Narrated Qais bin Abi Hazim:I saw Talha's paralyzed hand with which he had protected the Prophet (from an arrow)}}
\hadithdefcmd{bukhari}{3725}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ سَمِعْتُ سَعْدًا، يَقُولُ جَمَعَ لِي النَّبِيُّ صلى الله عليه وسلم أَبَوَيْهِ يَوْمَ أُحُدٍ‏.‏\hadithno{3725}\hadithtrans{Narrated Sa`d:On the day of the battle of Uhud the Prophet (ﷺ) mentioned for me both his parents (i.e. saying, "Let my parents be sacrificed for you)}}
\hadithdefcmd{bukhari}{3726}{حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هَاشِمُ بْنُ هَاشِمٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ لَقَدْ رَأَيْتُنِي وَأَنَا ثُلُثُ الإِسْلاَمِ،‏.‏\hadithno{3726}\hadithtrans{Narrated Sa`d:No doubt, (for some time) I stood for one-third of the Muslims}}
\hadithdefcmd{bukhari}{3727}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، حَدَّثَنَا هَاشِمُ بْنُ هَاشِمِ بْنِ عُتْبَةَ بْنِ أَبِي وَقَّاصٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ سَمِعْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ مَا أَسْلَمَ أَحَدٌ إِلاَّ فِي الْيَوْمِ الَّذِي أَسْلَمْتُ فِيهِ، وَلَقَدْ مَكَثْتُ سَبْعَةَ أَيَّامٍ وَإِنِّي لَثُلُثُ الإِسْلاَمِ‏.‏ تَابَعَهُ أَبُو أُسَامَةَ حَدَّثَنَا هَاشِمٌ‏.‏\hadithno{3727}\hadithtrans{Narrated Sa`d bin Abi Waqqas:No man embraced Islam before the day on which I embraced Islam, and no doubt, I remained for seven days as one third of the then extant Muslims}}
\hadithdefcmd{bukhari}{3728}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ سَعْدًا ـ رضى الله عنه ـ يَقُولُ إِنِّي لأَوَّلُ الْعَرَبِ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ، وَكُنَّا نَغْزُو مَعَ النَّبِيِّ صلى الله عليه وسلم وَمَا لَنَا طَعَامٌ إِلاَّ وَرَقُ الشَّجَرِ، حَتَّى إِنَّ أَحَدَنَا لَيَضَعُ كَمَا يَضَعُ الْبَعِيرُ أَوِ الشَّاةُ، مَا لَهُ خِلْطٌ، ثُمَّ أَصْبَحَتْ بَنُو أَسَدٍ تُعَزِّرُنِي عَلَى الإِسْلاَمِ، لَقَدْ خِبْتُ إِذًا وَضَلَّ عَمَلِي‏.‏ وَكَانُوا وَشَوْا بِهِ إِلَى عُمَرَ، قَالُوا لاَ يُحْسِنُ يُصَلِّي‏.‏\hadithno{3728}\hadithtrans{Narrated Qais:I heard Sa`d saying, "I was the first amongst the 'Arabs who shot an arrow for Allah's Cause. We used to fight along with the Prophet, while we had nothing to eat except the leaves of trees so that one's excrete would look like the excrete balls of camel or a sheep, containing nothing to mix them together. Today Banu Asad tribe blame me for not having understood Islam. I would be a loser if my deeds were in vain." Those people complained about Sa`d to `Umar, claiming that he did not offer his prayers perfectly}}
\hadithdefcmd{bukhari}{3729}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، قَالَ إِنَّ عَلِيًّا خَطَبَ بِنْتَ أَبِي جَهْلٍ، فَسَمِعَتْ بِذَلِكَ، فَاطِمَةُ، فَأَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَزْعُمُ قَوْمُكَ أَنَّكَ لاَ تَغْضَبُ لِبَنَاتِكَ، هَذَا عَلِيٌّ نَاكِحٌ بِنْتَ أَبِي جَهْلٍ، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَمِعْتُهُ حِينَ تَشَهَّدَ يَقُولُ ‏"‏ أَمَّا بَعْدُ أَنْكَحْتُ أَبَا الْعَاصِ بْنَ الرَّبِيعِ، فَحَدَّثَنِي وَصَدَقَنِي، وَإِنَّ فَاطِمَةَ بَضْعَةٌ مِنِّي، وَإِنِّي أَكْرَهُ أَنْ يَسُوءَهَا، وَاللَّهِ لاَ تَجْتَمِعُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَبِنْتُ عَدُوِّ اللَّهِ عِنْدَ رَجُلٍ وَاحِدٍ ‏"‏‏.‏ فَتَرَكَ عَلِيٌّ الْخِطْبَةَ‏.‏ وَزَادَ مُحَمَّدُ بْنُ عَمْرِو بْنِ حَلْحَلَةَ عَنِ ابْنِ شِهَابٍ عَنْ عَلِيٍّ عَنْ مِسْوَرٍ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم وَذَكَرَ صِهْرًا لَهُ مِنْ بَنِي عَبْدِ شَمْسٍ فَأَثْنَى عَلَيْهِ فِي مُصَاهَرَتِهِ إِيَّاهُ فَأَحْسَنَ قَالَ ‏"‏ حَدَّثَنِي فَصَدَقَنِي، وَوَعَدَنِي فَوَفَى لِي ‏"‏‏.‏\hadithno{3729}\hadithtrans{Narrated Al-Miswar bin Makhrama:`Ali demanded the hand of the daughter of Abu Jahl. Fatima heard of this and went to Allah's Messenger (ﷺ) saying, "Your people think that you do not become angry for the sake of your daughters as `Ali is now going to marry the daughter of Abu Jahl. "On that Allah's Messenger (ﷺ) got up and after his recitation of Tashah-hud. I heard him saying, "Then after! I married one of my daughters to Abu Al-`As bin Al- Rabi` (the husband of Zainab, the daughter of the Prophet (ﷺ) ) before Islam and he proved truthful in whatever he said to me. No doubt, Fatima is a part of me, I hate to see her being troubled. By Allah, the daughter of Allah's Messenger (ﷺ) and the daughter of Allah's Enemy cannot be the wives of one man." So `Ali gave up that engagement. 'Al-Miswar further said: I heard the Prophet (ﷺ) talking and he mentioned a son-in-law of his belonging to the tribe of Bani `Abd-Shams. He highly praised him concerning that relationship and said (whenever) he spoke to me, he spoke the truth, and whenever he promised me, he fulfilled his promise}}
\hadithdefcmd{bukhari}{3730}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم بَعْثًا، وَأَمَّرَ عَلَيْهِمْ أُسَامَةَ بْنَ زَيْدٍ، فَطَعَنَ بَعْضُ النَّاسِ فِي إِمَارَتِهِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنْ تَطْعُنُوا فِي إِمَارَتِهِ فَقَدْ كُنْتُمْ تَطْعُنُونَ فِي إِمَارَةِ أَبِيهِ مِنْ قَبْلُ، وَايْمُ اللَّهِ، إِنْ كَانَ لَخَلِيقًا لِلإِمَارَةِ، وَإِنْ كَانَ لَمِنْ أَحَبِّ النَّاسِ إِلَىَّ، وَإِنَّ هَذَا لَمِنْ أَحَبِّ النَّاسِ إِلَىَّ بَعْدَهُ ‏"‏‏.‏\hadithno{3730}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) sent an army under the command of Usama bin Zaid. When some people criticized his leadership, the Prophet (ﷺ) said, "If you are criticizing Usama's leadership, you used to criticize his father's leadership before. By Allah! He was worthy of leadership and was one of the dearest persons to me, and (now) this (i.e. Usama) is one of the dearest to me after him (i.e. Zaid)}}
\hadithdefcmd{bukhari}{3731}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَ عَلَىَّ قَائِفٌ وَالنَّبِيُّ صلى الله عليه وسلم شَاهِدٌ، وَأُسَامَةُ بْنُ زَيْدٍ وَزَيْدُ بْنُ حَارِثَةَ مُضْطَجِعَانِ، فَقَالَ إِنَّ هَذِهِ الأَقْدَامَ بَعْضُهَا مِنْ بَعْضٍ‏.‏ قَالَ فَسُرَّ بِذَلِكَ النَّبِيُّ صلى الله عليه وسلم وَأَعْجَبَهُ، فَأَخْبَرَ بِهِ عَائِشَةَ‏.‏\hadithno{3731}\hadithtrans{Narrated `Urwa:Aisha said, "A Qaif (i.e. one skilled in recognizing the lineage of a person through Physiognomy and through examining the body parts of an infant) came to me while the Prophet (ﷺ) was present, and Usama bin Zaid and Zaid bin Haritha were Lying asleep. The Qa'if said. These feet (of Usama and his father) are of persons belonging to the same lineage.' " The Prophet (ﷺ) was pleased with that saying which won his admiration, and he told `Aisha of it}}
\hadithdefcmd{bukhari}{3732}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ قُرَيْشًا، أَهَمَّهُمْ شَأْنُ الْمَخْزُومِيَّةِ، فَقَالُوا مَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ بْنُ زَيْدٍ، حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3732}\hadithtrans{Narrated 'Aisha: The people of the Quraish tribe were worried about the Makhzumiya woman. They said. "Nobody dare speak to him (i.e. the Prophet (ﷺ) ) except Usama bin Zaid as he is the most beloved to Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{3733}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ ذَهَبْتُ أَسْأَلُ الزُّهْرِيَّ عَنْ حَدِيثِ الْمَخْزُومِيَّةِ، فَصَاحَ بِي، قُلْتُ لِسُفْيَانَ فَلَمْ تَحْتَمِلْهُ عَنْ أَحَدٍ قَالَ وَجَدْتُهُ فِي كِتَابٍ كَانَ كَتَبَهُ أَيُّوبُ بْنُ مُوسَى عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ امْرَأَةً مِنْ بَنِي مَخْزُومٍ سَرَقَتْ، فَقَالُ��ا مَنْ يُكَلِّمُ فِيهَا النَّبِيَّ صلى الله عليه وسلم فَلَمْ يَجْتَرِئْ أَحَدٌ أَنْ يُكَلِّمَهُ، فَكَلَّمَهُ أُسَامَةُ بْنُ زَيْدٍ، فَقَالَ ‏ "‏ إِنَّ بَنِي إِسْرَائِيلَ كَانَ إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ، وَإِذَا سَرَقَ الضَّعِيفُ قَطَعُوهُ، لَوْ كَانَتْ فَاطِمَةُ لَقَطَعْتُ يَدَهَا ‏"‏‏.‏\hadithno{3733}\hadithtrans{Aisha said, "A woman from Bani Makhzumiya committed a theft and the people said, 'Who can intercede with the Prophet (ﷺ) for her?' So nobody dared speak to him (i.e. the Prophet) but Usama bin Zaid spoke to him. The Prophet said, 'If a reputable man amongst the children of Bani Israel committed a theft, they used to forgive him, but if a poor man committed a theft, they would cut his hand. But I would cut even the hand of Fatima (i.e. the daughter of the Prophet) if she committed a theft}}
\hadithdefcmd{bukhari}{3734}{حَدَّثَنِي الْحَسَنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَبَّادٍ، يَحْيَى بْنُ عَبَّادٍ حَدَّثَنَا الْمَاجِشُونُ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ نَظَرَ ابْنُ عُمَرَ يَوْمًا وَهْوَ فِي الْمَسْجِدِ إِلَى رَجُلٍ يَسْحَبُ ثِيَابَهُ فِي نَاحِيَةٍ مِنَ الْمَسْجِدِ فَقَالَ انْظُرْ مَنْ هَذَا لَيْتَ هَذَا عِنْدِي‏.‏ قَالَ لَهُ إِنْسَانٌ أَمَا تَعْرِفُ هَذَا يَا أَبَا عَبْدِ الرَّحْمَنِ هَذَا مُحَمَّدُ بْنُ أُسَامَةَ، قَالَ فَطَأْطَأَ ابْنُ عُمَرَ رَأْسَهُ، وَنَقَرَ بِيَدَيْهِ فِي الأَرْضِ، ثُمَّ قَالَ لَوْ رَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَحَبَّهُ‏.‏\hadithno{3734}\hadithtrans{Narrated `Abdullah bin Dinar:One day Ibn `Umar, while in the Mosque, looked at a man who was dragging his clothes while walking in one of the corners of the Mosque He said, "See who is that. I wish he was near to me." Somebody then said (to Ibn `Umar), "Don't you know him, O Abu `Abdur-Rahman? He is Muhammad bin Usama." On that Ibn `Umar bowed his head and dug the earth with his hands and then, said, "If Allah's Messenger (ﷺ) saw him, he would have loved him}}
\hadithdefcmd{bukhari}{3735}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا أَبُو عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ حَدَّثَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَأْخُذُهُ وَالْحَسَنَ فَيَقُولُ ‏ "‏ اللَّهُمَّ أَحِبَّهُمَا فَإِنِّي أُحِبُّهُمَا ‏"‏‏.‏\hadithno{3735}\hadithtrans{Narrated Usama bin Zaid: That the Prophet (ﷺ) used to take him (i.e. Usama) and Al-Hasan (in his lap) and say: "O Allah! Love them, as I love them}}
\hadithdefcmd{bukhari}{3736}{وَقَالَ نُعَيْمٌ عَنِ ابْنِ الْمُبَارَكِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي مَوْلًى، لأُسَامَةَ بْنِ زَيْدٍ‏.‏ أَنَّ الْحَجَّاجَ بْنَ أَيْمَنَ ابْنِ أُمِّ أَيْمَنَ،، وَكَانَ، أَيْمَنُ ابْنُ أُمِّ أَيْمَنَ أَخَا أُسَامَةَ لأُمِّهِ، وَهْوَ رَجُلٌ مِنَ الأَنْصَارِ، فَرَآهُ ابْنُ عُمَرَ لَمْ يُتِمَّ رُكُوعَهُ وَلاَ سُجُودَهُ فَقَالَ أَعِدْ‏.‏\hadithno{3736}\hadithtrans{The freed slave of Usama bin Zaid said, "Al-Hajjaj bin Aiman bin Um Aiman and Aiman Ibn Um Aiman was Usama's brother from the maternal side, and he was one of the Ansar. He was seen by Ibn 'Umar not performing his bowing and prostrations in a perfect manner. So Ibn 'Umar told him to repeat his prayer}}
\hadithdefcmd{bukhari}{3737}{قَالَ أَبُو عَبْدِ اللَّهِ وَحَدَّثَنِي سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي حَرْمَلَةُ، مَوْلَى أُسَامَةَ بْنِ زَيْدٍ أَنَّهُ بَيْنَمَا هُوَ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ إِذْ دَخَلَ الْحَجَّاجُ بْنُ أَيْمَنَ فَلَمْ يُتِمَّ رُكُوعَهُ وَلاَ سُجُودَهُ، فَقَالَ أَعِدْ‏.‏ فَلَمَّا وَلَّى قَالَ لِي ابْنُ عُمَرَ مَنْ هَذَا قُلْتُ الْحَجَّاجُ بْنُ أَيْمَنَ ابْنِ أُمِّ أَيْمَنَ‏.‏ فَقَالَ ابْنُ عُمَرَ لَوْ رَأَى هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم لأَحَبَّهُ، فَذَكَرَ حُبَّهُ وَمَا وَلَدَتْهُ أُمُّ أَيْمَنَ‏.‏ قَالَ وَحَدَّثَنِي بَعْضُ أَصْحَابِي عَنْ سُلَيْمَانَ وَكَانَتْ حَاضِنَةَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3737}\hadithtrans{Harmala, the freed slave of Usama bin Zaid said that while he was in the company of 'Abdullah bin 'Umar, Al-Hajjaj bin Aiman came in and (while praying) he did not perform his bowing and prostrations properly. So Ibn 'Umar told him to repeat his prayer. When he went away, Ibn 'Umar asked me, "Who is he?" I said, "Al-Hajjaj bin Um Aiman." Ibn 'Umar said, "If Allah's Messenger (ﷺ) saw him, he would have loved him." Then Ibn 'Umar mentioned the love of the Prophet (ﷺ) for the children of Um Aiman. Sulaiman said that Um Aiman was one of the nurses of the Prophet}}
\hadithdefcmd{bukhari}{3739}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ الرَّجُلُ فِي حَيَاةِ النَّبِيِّ صلى الله عليه وسلم إِذَا رَأَى رُؤْيَا قَصَّهَا عَلَى النَّبِيِّ صلى الله عليه وسلم، فَتَمَنَّيْتُ أَنْ أَرَى رُؤْيَا أَقُصُّهَا عَلَى النَّبِيِّ صلى الله عليه وسلم، وَكُنْتُ غُلاَمًا أَعْزَبَ، وَكُنْتُ أَنَامُ فِي الْمَسْجِدِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَرَأَيْتُ فِي الْمَنَامِ كَأَنَّ مَلَكَيْنِ أَخَذَانِي فَذَهَبَا بِي إِلَى النَّارِ، فَإِذَا هِيَ مَطْوِيَّةٌ كَطَىِّ الْبِئْرِ، فَإِذَا لَهَا قَرْنَانِ كَقَرْنَىِ الْبِئْرِ، وَإِذَا فِيهَا نَاسٌ قَدْ عَرَفْتُهُمْ، فَجَعَلْتُ أَقُولُ أَعُوذُ بِاللَّهِ مِنَ النَّارِ، أَعُوذُ بِاللَّهِ مِنَ النَّارِ‏.‏ فَلَقِيَهُمَا مَلَكٌ آخَرُ فَقَالَ لِي لَنْ تُرَاعَ‏. فَقَصَصْتُهَا عَلَى حَفْصَةَ‏.‏ فَقَصَّتْهَا حَفْصَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ نِعْمَ الرَّجُلُ عَبْدُ اللَّهِ، لَوْ كَانَ يُصَلِّي بِاللَّيْلِ ‏"‏‏.‏ قَالَ سَالِمٌ فَكَانَ عَبْدُ اللَّهِ لاَ يَنَامُ مِنَ اللَّيْلِ إِلاَّ قَلِيلاً‏.‏\hadithno{3739}\hadithtrans{Narrated Ibn `Umar:If a man saw a dream during the lifetime of the Prophet (ﷺ) he would narrate it to the Prophet. Once I wished to see a dream and narrate it to the Prophet (ﷺ) I was young, unmarried, and used to sleep in the Mosque during the lifetime of the Prophet. I dreamt that two angels took me and went away with me towards the (Hell) Fire which looked like a well with the inside walls built up, and had two side-walls like those of a well. There I saw some people in it whom I knew. I started saying, "I seek Refuge with Allah from the (Hell) Fire, I seek Refuge with Allah from the (Hell) Fire." Then another angel met the other two and said to me, "Do not be afraid." I narrated my dream to Hafsa who, in her turn, narrated it to the Prophet. He said, "What an excellent man `Abdullah is if he only observes the night prayer." (Salim, a sub-narrator said, "Abdullah used not to sleep at night but very little hence forward)}}
\hadithdefcmd{bukhari}{3740}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنْ أُخْتِهِ، حَفْصَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ إِنَّ عَبْدَ اللَّهِ رَجُلٌ صَالِحٌ ‏"‏‏.‏\hadithno{3740}\hadithtrans{Narrated Ibn `Umar from Hafsa his sister:That the Prophet (ﷺ) had said to her, "`Abdullah is a pious man}}
\hadithdefcmd{bukhari}{3742}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِسْرَائِيلُ، عَنِ الْمُغِيرَةِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ،، قَالَ قَدِمْتُ الشَّأْمَ فَصَلَّيْتُ رَكْعَتَيْنِ، ثُمَّ قُلْتُ اللَّهُمَّ يَسِّرْ لِي جَلِيسًا صَالِحًا، فَأَتَيْتُ قَوْمًا فَجَلَسْتُ إِلَيْهِمْ، فَإِذَا شَيْخٌ قَدْ جَاءَ حَتَّى جَلَسَ إِلَى جَنْبِي، قُلْتُ مَنْ هَذَا قَالُوا أَبُو الدَّرْدَاءِ‏.‏ فَقُلْتُ إِنِّي دَعَوْتُ اللَّهَ أَنْ يُيَسِّرَ لِي جَلِيسًا صَالِحًا فَيَسَّرَكَ لِي، قَالَ مِمَّنْ أَنْتَ قُلْتُ مِنْ أَهْلِ الْكُوفَةِ‏.‏ قَالَ أَوَلَيْسَ عِنْدَكُمُ ابْنُ أُمِّ عَبْدٍ صَاحِبُ النَّعْلَيْنِ وَالْوِسَادِ وَالْمِطْهَرَةِ وَفِيكُمُ الَّذِي أَجَارَهُ اللَّهُ مِنَ الشَّيْطَانِ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم أَوَلَيْسَ فِيكُمْ صَاحِبُ سِرِّ النَّبِيِّ صلى الله عليه وسلم الَّذِي لاَ يَعْلَمُ أَحَدٌ غَيْرُهُ ثُمَّ قَالَ كَيْفَ يَقْرَأُ عَبْدُ اللَّهِ ‏\{‏وَاللَّيْلِ إِذَا يَغْشَى‏\}‏، فَقَرَأْتُ عَلَيْهِ ‏\{‏وَاللَّيْلِ إِذَا يَغْشَى * وَالنَّهَارِ إِذَا تَجَلَّى * وَالذَّكَرِ وَالأُنْثَى‏\}‏‏.‏ قَالَ وَاللَّهِ لَقَدْ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ فِيهِ إِلَى فِيَّ‏.‏\hadithno{3742}\hadithtrans{Narrated 'Alqama:I went to Sham and offered a two-rak`at prayer and then said, "O Allah! Bless me with a good pious companion." So I went to some people and sat with them. An old man came and sat by my side. I asked, "Who is he?" They replied, "(He is) Abu-Ad-Darda.' I said (to him), "I prayed to Allah to bless me with a pious companion and He sent you to me." He asked me, "From where are you?" I replied, "From the people of Al-Kufa." He said, "Isn't there amongst you Ibn Um `Abd, the one who used to carry the shoes, the cushion(or pillow) and the water for ablution? Is there amongst you the one whom Allah gave Refuge from Satan through the request of His Prophet. Is there amongst you the one who keeps the secrets of the Prophet (ﷺ) which nobody knows except him?" Abu Darda further asked, "How does `Abdullah (bin Mas`ud) recite the Sura starting with, 'By the Night as it conceals (the light)." (92.1) Then I recited before him: 'By the Night as it envelops: And by the Day as it appears in brightness; And by male and female.' (91.1-3) On this Abu Ad-Darda' said, "By Allah, the Prophet (ﷺ) made me recite the Sura in this way while I was listening to him (reciting it)}}
\hadithdefcmd{bukhari}{3743}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، قَالَ ذَهَبَ عَلْقَمَةُ إِلَى الشَّأْمِ، فَلَمَّا دَخَلَ الْمَسْجِدَ قَالَ اللَّهُمَّ يَسِّرْ لِي جَلِيسًا صَالِحًا‏.‏ فَجَلَسَ إِلَى أَبِي الدَّرْدَاءِ فَقَالَ أَبُو الدَّرْدَاءِ مِمَّنْ أَنْتَ قَالَ مِنْ أَهْلِ الْكُوفَةِ‏.‏ قَالَ أَلَيْسَ فِيكُمْ ـ أَوْ مِنْكُمْ ـ صَاحِبُ السِّرِّ الَّذِي لاَ يَعْلَمُهُ غَيْرُهُ يَعْنِي حُذَيْفَةَ‏.‏ قَالَ قُلْتُ بَلَى‏.‏ قَالَ أَلَيْسَ فِيكُمُ ـ أَوْ مِنْكُمُ ـ الَّذِي أَجَارَهُ اللَّهُ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم يَعْنِي مِنَ الشَّيْطَانِ، يَعْنِي عَمَّارًا‏.‏ قُلْتُ بَلَى‏.‏ قَالَ أَلَيْسَ فِيكُمْ ـ أَوْ مِنْكُمْ ـ صَاحِبُ السِّوَاكِ أَوِ السِّرَارِ قَالَ بَلَى‏.‏ قَالَ كَيْفَ كَانَ عَبْدُ اللَّهِ يَقْرَأُ ‏\{‏وَاللَّيْلِ إِذَا يَغْشَى * وَالنَّهَارِ إِذَا تَجَلَّى‏\}‏ قُلْتُ ‏\{‏وَالذَّكَرِ وَالأُنْثَى‏\}‏‏.‏ قَالَ مَا زَالَ بِي هَؤُلاَءِ حَتَّى كَادُوا يَسْتَنْزِلُونِي عَنْ شَىْءٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3743}\hadithtrans{Narrated Ibrahim:'Alqama went to Sham and when he entered the mosque, he said, "O Allah ! Bless me with a pious companion." So he sat with Abu Ad-Darda. Abu Ad-Darda' asked him, "Where are you from?" 'Alqama replied, "From the people of Kufa." Abu Ad-Darda said, "Isn't there amongst you the Keeper of the secret which nobody else knows i.e. Hudhaifa?" Al-qama said, "Yes." Then Abu Ad-Darda further said, "Isn't there amongst you the person whom Allah gave Refuge from Satan through the invocation of His Prophet namely `Ammar?" Alqama replied in the affirmative Abu Ad-Darda said, "Isn't there amongst you the person who carries the Siwak (or the Secret) (i.e. of the Prophet (ﷺ) namely `Abdullah bin Mas'ud)?" Alqama said, "Yes." Then Abu Ad-Darda asked, "How (Abdullah bin Masud) used to recite the Sura starting with: "By the night as it envelopes; By the day as it appears in brightness?" (92.1-2). Alqama said "And by male and female." Abu Ad-Darda then said, "These people (of Sham) tried hard to make me accept something other than what I had heard from the Prophet}}
\hadithdefcmd{bukhari}{3744}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِكُلِّ أُمَّةٍ أَمِينًا، وَإِنَّ أَمِينَنَا أَيَّتُهَا الأُمَّةُ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ ‏"‏‏.‏\hadithno{3744}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, " Every nation has an extremely trustworthy man, and the trustworthy man of this (i.e. Muslim) nation is Abu 'Ubaida bin Al-Jarrah}}
\hadithdefcmd{bukhari}{3745}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لأَهْلِ نَجْرَانَ ‏ "‏ لأَبْعَثَنَّ ـ يَعْنِي عَلَيْكُمْ ـ يَعْنِي أَمِينًا ـ حَقَّ أَمِينٍ ‏"‏‏.‏ فَأَشْرَفَ أَصْحَابُهُ، فَبَعَثَ أَبَا عُبَيْدَةَ رضى الله عنه‏.‏\hadithno{3745}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) said to the people of Najran, "I will send you the most trustworthy man." (Every one of) the companions of the Prophet (ﷺ) was looking forward (to be that person). He then sent Abu 'Ubaida}}
\hadithdefcmd{bukhari}{3746}{حَدَّثَنَا صَدَقَةُ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، حَدَّثَنَا أَبُو مُوسَى، عَنِ الْحَسَنِ، سَمِعَ أَبَا بَكْرَةَ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَالْحَسَنُ إِلَى جَنْبِهِ، يَنْظُرُ إِلَى النَّاسِ مَرَّةً وَإِلَيْهِ مَرَّةً، وَيَقُولُ ‏ "‏ ابْنِي هَذَا سَيِّدٌ، وَلَعَلَّ اللَّهَ أَنْ يُصْلِحَ بِهِ بَيْنَ فِئَتَيْنِ مِنَ الْمُسْلِمِينَ ‏"‏‏.‏\hadithno{3746}\hadithtrans{Narrated Abu Bakra:I heard the Prophet (ﷺ) talking at the pulpit while Al-Hasan was sitting beside him, and he (i.e. the Prophet ) was once looking at the people and at another time Al-Hasan, and saying, "This son of mine is a Saiyid (i.e. chief) and perhaps Allah will bring about an agreement between two sects of the Muslims through him}}
\hadithdefcmd{bukhari}{3747}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنَا أَبُو عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَأْخُذُهُ وَالْحَسَنَ وَيَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أُحِبُّهُمَا فَأَحِبَّهُمَا ‏"‏‏.‏ أَوْ كَمَا قَالَ‏.‏\hadithno{3747}\hadithtrans{Narrated Usama bin Zaid:That the Prophet (ﷺ) used to take him and Al-Hasan, and used to say, "O Allah! I love them, so please love them," or said something similar}}
\hadithdefcmd{bukhari}{3748}{حَدَّثَنِي مُحَمَّدُ بْنُ الْحُسَيْنِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُحَمَّدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أُتِيَ عُبَيْدُ اللَّهِ بْنُ زِيَادٍ بِرَأْسِ الْحُسَيْنِ ـ عَلَيْهِ السَّلاَمُ ـ فَجُعِلَ فِي طَسْتٍ، فَجَعَلَ يَنْكُتُ، وَقَالَ فِي حُسْنِهِ شَيْئًا‏.‏ فَقَالَ أَنَسٌ كَانَ أَشْبَهَهُمْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم، وَكَانَ مَخْضُوبًا بِالْوَسْمَةِ‏.‏\hadithno{3748}\hadithtrans{Narrated Muhammad:Anas bin Malik said, "The head of Al-Husain was brought to 'Ubaidullah bin Ziyad and was put in a tray, and then Ibn Ziyad started playing with a stick at the nose and mouth of Al-Husain's head and saying something about his handsome features." Anas then said (to him), "Al-Husain resembled the Prophet more than the others did." Anas added, "His (i.e. Al-Husain's) hair was dyed with Wasma (i.e. a kind of plant used as a dye)}}
\hadithdefcmd{bukhari}{3749}{حَدَّثَنَا حَجَّاجُ بْنُ الْمِنْهَالِ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَدِيٌّ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَالْحَسَنُ عَلَى عَاتِقِهِ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أُحِبُّهُ فَأَحِبَّهُ ‏"‏‏.‏\hadithno{3749}\hadithtrans{Narrated Al-Bara:I saw the Prophet (ﷺ) carrying Al-Hasan on his shoulder an saying, "O Allah! I love him, so please love him}}
\hadithdefcmd{bukhari}{3750}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنِي عُمَرُ بْنُ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ رَأَيْتُ أَبَا بَكْرٍ ـ رضى الله عنه ـ وَحَمَلَ الْحَسَنَ وَهْوَ يَقُولُ بِأَبِي شَبِيهٌ بِالنَّبِيِّ، لَيْسَ شَبِيهٌ بِعَلِيٍّ‏.‏ وَعَلِيٌّ يَضْحَكُ‏.‏\hadithno{3750}\hadithtrans{Narrated `Uqba bin Al-Harith:I saw Abu Bakr carrying Al-Hasan and saying, "Let my father be sacrificed for you; you resemble the Prophet and not `Ali," while `Ali was laughing at this}}
\hadithdefcmd{bukhari}{3751}{حَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، وَصَدَقَةُ، قَالاَ أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ وَاقِدِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ أَبُو بَكْرٍ ارْقُبُوا مُحَمَّدًا صلى الله عليه وسلم فِي أَهْلِ بَيْتِهِ‏.‏\hadithno{3751}\hadithtrans{Narrated Ibn `Umar:Abu Bakr used to say, "Look after Muhammad (ﷺ) in (looking after) his family}}
\hadithdefcmd{bukhari}{3752}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ،‏.‏ وَقَالَ عَبْدُ الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَنَسٌ، قَالَ لَمْ يَكُنْ أَحَدٌ أَشْبَهَ بِالنَّبِيِّ صلى الله عليه وسلم مِنَ الْحَسَنِ بْنِ عَلِيٍّ‏.‏\hadithno{3752}\hadithtrans{Narrated Anas:None resembled the Prophet (ﷺ) more than Al-Hasan bin `Ali did}}
\hadithdefcmd{bukhari}{3753}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ أَبِي يَعْقُوبَ، سَمِعْتُ ابْنَ أَبِي نُعْمٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، وَسَأَلَهُ، عَنِ الْمُحْرِمِ،، قَالَ شُعْبَةُ أَحْسِبُهُ يَقْتُلُ الذُّبَابَ فَقَالَ أَهْلُ الْعِرَاقِ يَسْأَلُونَ عَنِ الذُّبَابِ وَقَدْ قَتَلُوا ابْنَ ابْنَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ هُمَا رَيْحَانَتَاىَ مِنَ الدُّنْيَا ‏"‏‏.‏\hadithno{3753}\hadithtrans{Narrated Ibn Abi Nu'm:A person asked `Abdullah bin `Umar whether a Muslim could kill flies. I heard him saying (in reply). "The people of Iraq are asking about the killing of flies while they themselves murdered the son of the daughter of Allah's Messenger (ﷺ) . The Prophet (ﷺ) said, They (i.e. Hasan and Husain) are my two sweet basils in this world}}
\hadithdefcmd{bukhari}{3754}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، أَخْبَرَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كَانَ عُمَرُ يَقُولُ أَبُو بَكْرٍ سَيِّدُنَا، وَأَعْتَقَ سَيِّدَنَا‏.‏ يَعْنِي بِلاَلاً‏.‏\hadithno{3754}\hadithtrans{Narrated Jabir bin `Abdullah:`Umar used to say, "Abu Bakr is our chief, and he manumitted our chief," meaning Bilal}}
\hadithdefcmd{bukhari}{3755}{حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ عُبَيْدٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، أَنَّ بِلاَلاً، قَالَ لأَبِي بَكْرٍ إِنْ كُنْتَ إِنَّمَا اشْتَرَيْتَنِي لِنَفْسِكَ فَأَمْسِكْنِي، وَإِنْ كُنْتَ إِنَّمَا اشْتَرَيْتَنِي لِلَّهِ فَدَعْنِي وَعَمَلَ اللَّهِ‏.‏\hadithno{3755}\hadithtrans{Narrated Qais:Bilal said to Abu Bakr, "If you have bought me for yourself then keep me (for yourself), but if you have bought me for Allah's Sake, then leave me for Allah's Work}}
\hadithdefcmd{bukhari}{3756}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ،، قَالَ ضَمَّنِي النَّبِيُّ صلى الله عليه وسلم إِلَى صَدْرِهِ وَقَالَ ‏ "‏ اللَّهُمَّ عَلِّمْهُ الْحِكْمَةَ ‏"‏‏.‏\hadithno{3756}\hadithtrans{Narrated Ibn `Abbas:Once the Prophet (ﷺ) embraced me (pressed me to his chest) and said, "O Allah, teach him wisdom (i.e. the understanding of the knowledge of Qur'an)}}
\hadithdefcmd{bukhari}{3756p2}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، وَقَالَ، ‏ "‏ عَلِّمْهُ الْكِتَابَ ‏"‏‏.‏ حَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، عَنْ خَالِدٍ، مِثْلَهُ‏.‏ وَالْحِكْمَةُ الْإِصَابَةُ فِي غَيْرِ النُّبُوَّةِ\hadithno{3756.2}\hadithtrans{Narrated 'Abdul Warith: The same but said, "O Allah, teach him (Ibn Abbas) the Book (i.e. the understanding of the knowledge of Qur'an)." Narrated Khalid: As above}}
\hadithdefcmd{bukhari}{3757}{حَدَّثَنَا أَحْمَدُ بْنُ وَاقِدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَنَسٍ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم نَعَى زَيْدًا وَجَعْفَرًا وَابْنَ رَوَاحَةَ لِلنَّاسِ قَبْلَ أَنْ يَأْتِيَهُمْ خَبَرُهُمْ، فَقَالَ ‏ "‏ أَخَذَ الرَّايَةَ زَيْدٌ فَأُصِيبَ، ثُمَّ أَخَذَ جَعْفَرٌ فَأُصِيبَ، ثُمَّ أَخَذَ ابْنُ رَوَاحَةَ فَأُصِيبَ ـ وَعَيْنَاهُ تَذْرِفَانِ ـ حَتَّى أَخَذَ سَيْفٌ مِنْ سُيُوفِ اللَّهِ حَتَّى فَتَحَ اللَّهُ عَلَيْهِمْ ‏"‏‏.‏\hadithno{3757}\hadithtrans{Narrated Anas:The Prophet (ﷺ) had informed the people about the death of Zaid, Ja`far and Ibn Rawaha before the news of their death reached them. He said with his eyes flowing with tears, "Zaid took the flag and was martyred; then Ja`far took the flag and was martyred, and then Ibn Rawaha took the flag and was martyred. Finally the flag was taken by one of Allah's Swords (i.e. Khalid bin Al-Walid) and Allah gave them (i.e. the Muslims) victory}}
\hadithdefcmd{bukhari}{3758}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، قَالَ ذُكِرَ عَبْدُ اللَّهِ عِنْدَ عَبْدِ اللَّهِ بْنِ عَمْرٍو، فَقَالَ ذَاكَ رَجُلٌ لاَ أَزَالُ أُحِبُّهُ بَعْدَ مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اسْتَقْرِئُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، فَبَدَأَ بِهِ، وَسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ، وَأُبَىِّ بْنِ كَعْبٍ، وَمُعَاذِ بْنِ جَبَلٍ ‏"‏‏.‏ قَالَ لاَ أَدْرِي بَدَأَ بِأُبَىٍّ أَوْ بِمُعَاذٍ‏.‏\hadithno{3758}\hadithtrans{Narrated Masruq:`Abdullah (bin Mas`ud) was mentioned before `Abdullah bin `Amr. The latter said, "That is a man I continue to love because I heard Allah's Messenger (ﷺ) saying, ' Learn the recitation of the Qur'an from (any of these) four persons: `Abdullah bin Masud, Salim the freed slave of Abu Hudhaifa, Ubai bin Ka`b, and Mu`adh bin Jabal." I do not remember whether he mentioned Ubai first or Mu`adh}}
\hadithdefcmd{bukhari}{3760}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ سَمِعْتُ مَسْرُوقًا، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ فَاحِشًا وَلاَ مُتَفَحِّشًا وَقَالَ ‏"‏ إِنَّ مِنْ أَحَبِّكُمْ إِلَىَّ أَحْسَنَكُمْ أَخْلاَقًا ‏"‏‏.‏ وَقَالَ ‏"‏ اسْتَقْرِئُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، وَسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ، وَأُبَىِّ بْنِ كَعْبٍ، وَمُعَاذِ بْنِ جَبَلٍ ‏"‏‏.‏\hadithno{3760}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) neither talked in an insulting manner nor did he ever speak evil intentionally. He used to say, "The most beloved to me amongst you is the one who has the best character and manners." He added, " Learn the Qur'an from (any of these) four persons. `Abdullah bin Mas`ud, Salim the freed slave of Abu Hudhaifa, Ubai bin Ka`b, and Mu`adh bin Jabal}}
\hadithdefcmd{bukhari}{3761}{حَدَّثَنَا مُوسَى، عَنْ أَبِي عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، دَخَلْتُ الشَّأْمَ فَصَلَّيْتُ رَكْعَتَيْنِ، فَقُلْتُ اللَّهُمَّ يَسِّرْ لِي جَلِيسًا‏.‏ فَرَأَيْتُ شَيْخًا مُقْبِلاً، فَلَمَّا دَنَا قُلْتُ أَرْجُو أَنْ يَكُونَ اسْتَجَابَ‏.‏ قَالَ مِنْ أَيْنَ أَنْتَ قُلْتُ مِنْ أَهْلِ الْكُوفَةِ‏.‏ قَالَ أَفَلَمْ يَكُنْ فِيكُمْ صَاحِبُ النَّعْلَيْنِ وَالْوِسَادِ وَالْمِطْهَرَةِ أَوَلَمْ يَكُنْ فِيكُمُ الَّذِي أُجِيرَ مِنَ الشَّيْطَانِ أَوَلَمْ يَكُنْ فِيكُمْ صَاحِبُ السِّرِّ الَّذِي لاَ يَعْلَمُهُ غَيْرُهُ كَيْفَ قَرَأَ ابْنُ أُمِّ عَبْدٍ ‏\{‏وَاللَّيْلِ‏\}‏ فَقَرَأْتُ ‏\{‏وَاللَّيْلِ إِذَا يَغْشَى * وَالنَّهَارِ إِذَا تَجَلَّى * وَالذَّكَرِ وَالأُنْثَى‏\}‏‏.‏ قَالَ أَقْرَأَنِيهَا النَّبِيُّ صلى الله عليه وسلم فَاهُ إِلَى فِيَّ، فَمَا زَالَ هَؤُلاَءِ حَتَّى كَادُوا يَرُدُّونِي‏.‏\hadithno{3761}\hadithtrans{Narrated Alqama:I went to Sham and was offering a two-rak`at prayer; I said, "O Allah! Bless me with a (pious) companion." Then I saw an old man coming towards me, and when he came near I said, (to myself), "I hope Allah has given me my request." The man asked (me), "Where are you from?" I replied, "I am from the people of Kufa." He said, "Weren't there amongst you the Carrier of the (Prophet's) shoes, Siwak and the ablution water container? Weren't there amongst you the man who was given Allah's Refuge from the Satan? And weren't there amongst you the man who used to keep the (Prophet's) secrets which nobody else knew? How did Ibn Um `Abd (i.e. `Abdullah bin Mas`ud) use to recite Surat-al-lail (the Night:92)?" I recited:-- "By the Night as it envelops By the Day as it appears in brightness. And by male and female." (92.1- 3) On that, Abu Darda said, "By Allah, the Prophet (ﷺ) made me read the Verse in this way after listening to him, but these people (of Sham) tried their best to let me say something different}}
\hadithdefcmd{bukhari}{3762}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ،، قَالَ سَأَلْنَا حُذَيْفَةَ عَنْ رَجُلٍ، قَرِيبِ السَّمْتِ وَالْهَدْىِ مِنَ النَّبِيِّ صلى الله عليه وسلم حَتَّى نَأْخُذَ عَنْهُ فَقَالَ مَا أَعْرِفُ أَحَدًا أَقْرَبَ سَمْتًا وَهَدْيًا وَدَلاًّ بِالنَّبِيِّ صلى الله عليه وسلم مِنِ ابْنِ أُمِّ عَبْدٍ‏.‏\hadithno{3762}\hadithtrans{Narrated `Abdur-Rahman bin Yazid:We asked Hudhaifa to tell us of a person resembling (to some extent) the Prophet (ﷺ) in good appearance and straight forward behavior so that we may learn from him (good manners and acceptable conduct). Hudhaifa replied, "I do not know anybody resembling the Prophet (to some extent) in appearance and conduct more than Ibn Um `Abd}}
\hadithdefcmd{bukhari}{3763}{حَدَّثَنِي مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ بْنِ أَبِي إِسْحَاقَ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِي إِسْحَاقَ، قَالَ حَدَّثَنِي الأَسْوَدُ بْنُ يَزِيدَ، قَالَ سَمِعْتُ أَبَا مُوسَى الأَشْعَرِيَّ ـ رضى الله عنه ـ يَقُولُ قَدِمْتُ أَنَا وَأَخِي مِنَ الْيَمَنِ، فَمَكُثْنَا حِينًا مَا نُرَى إِلاَّ أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ رَجُلٌ مِنْ أَهْلِ بَيْتِ النَّبِيِّ صلى الله عليه وسلم، لِمَا نَرَى مِنْ دُخُولِهِ وَدُخُولِ أُمِّهِ عَلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3763}\hadithtrans{Narrated Abu Musa Al-Ash`ari:My brother and I came from Yemen, and for some time we continued to consider `Abdullah bin Mas`ud as one of the members of the family of the Prophet (ﷺ) because we used to see him and his mother going in the house of the Prophet (ﷺ) very often}}
\hadithdefcmd{bukhari}{3764}{حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ، حَدَّثَنَا الْمُعَافَى، عَنْ عُثْمَانَ بْنِ الأَسْوَدِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ أَوْتَرَ مُعَاوِيَةُ بَعْدَ الْعِشَاءِ بِرَكْعَةٍ وَعِنْدَهُ مَوْلًى لاِبْنِ عَبَّاسٍ، فَأَتَى ابْنَ عَبَّاسٍ فَقَالَ دَعْهُ، فَإِنَّهُ صَحِبَ رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3764}\hadithtrans{Narrated Ibn Abu Mulaika:Muawiya offered one rak`a witr prayer after the `Isha prayer, and at that time a freed slave of Ibn `Abbas was present. He (i.e. the slave) went to Ibn `Abbas (and told him that Muawiya offered one rak`a witr prayer). Ibn `Abbas said, "Leave him, for he was in the company of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{3765}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، قِيلَ لاِبْنِ عَبَّاسٍ هَلْ لَكَ فِي أَمِيرِ الْمُؤْمِنِينَ مُعَاوِيَةَ، فَإِنَّهُ مَا أَوْتَرَ إِلاَّ بِوَاحِدَةٍ‏.‏ قَالَ إِنَّهُ فَقِيهٌ‏.‏\hadithno{3765}\hadithtrans{Narrated Ibn Abi Mulaika:Somebody said to Ibn `Abbas, "Can you speak to the chief of the believers Mu`awiyah, as he does not pray except one rak`a as witr?" Ibn `Abbas replied, "He is a Faqih (i.e. a learned man who can give religious verdicts)}}
\hadithdefcmd{bukhari}{3766}{حَدَّثَنِي عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ حُمْرَانَ بْنَ أَبَانَ، عَنْ مُعَاوِيَةَ ـ رضى الله عنه ـ قَالَ إِنَّكُمْ لَتُصَلُّونَ صَلاَةً لَقَدْ صَحِبْنَا النَّبِيَّ صلى الله عليه وسلم فَمَا رَأَيْنَاهُ يُصَلِّيهَا، وَلَقَدْ نَهَى عَنْهُمَا، يَعْنِي الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ‏.‏\hadithno{3766}\hadithtrans{Narrated Humran bin Aban:Muawiya said (to the people), "You offer a prayer which we, who were the companions of the Prophet (ﷺ) never saw the Prophet (ﷺ) offering, and he forbade its offering," i.e. the two rak`at after the compulsory `Asr prayer}}
\hadithdefcmd{bukhari}{3767}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فَاطِمَةُ بَضْعَةٌ مِنِّي، فَمَنْ أَغْضَبَهَا أَغْضَبَنِي ‏"‏‏.‏\hadithno{3767}\hadithtrans{Narrated Al-Miswar bin Makhrama:Allah's Messenger (ﷺ) said, "Fatima is a part of me, and whoever makes her angry, makes me angry}}
\hadithdefcmd{bukhari}{3768}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَبُو سَلَمَةَ إِنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا ‏ "‏ يَا عَائِشَ، هَذَا جِبْرِيلُ يُقْرِئُكِ السَّلاَمَ ‏"‏‏.‏ فَقُلْتُ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، تَرَى مَا لاَ أَرَى‏.‏ تُرِيدُ رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3768}\hadithtrans{Narrated Abu Salama:`Aisha said, "Once Allah's Messenger (ﷺ) said (to me), 'O Aish (`Aisha)! This is Gabriel greeting you.' I said, 'Peace and Allah's Mercy and Blessings be on him, you see what I don't see' " She was addressing Allah's Apostle}}
\hadithdefcmd{bukhari}{3769}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، قَالَ وَحَدَّثَنَا عَمْرٌو، أَخْبَرَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ مُرَّةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَمَلَ مِنَ الرِّجَالِ كَثِيرٌ، وَلَمْ يَكْمُلْ مِنَ النِّسَاءِ إِلاَّ مَرْيَمُ بِنْتُ عِمْرَانَ، وَآسِيَةُ امْرَأَةُ فِرْعَوْنَ، وَفَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏‏.‏\hadithno{3769}\hadithtrans{Narrated Abu Musa Al-Ash`ari:Allah's Messenger (ﷺ) said, "Many amongst men attained perfection but amongst women none attained the perfection except Mary, the daughter of `Imran and Asiya, the wife of Pharaoh. And the superiority of `Aisha to other women is like the superiority of Tharid (i.e. an Arabic dish) to other meals}}
\hadithdefcmd{bukhari}{3770}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ فَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى الطَّعَامِ ‏"‏‏.‏\hadithno{3770}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "The superiority of `Aisha over other women is like the superiority of Tharid to other meals}}
\hadithdefcmd{bukhari}{3771}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّ عَائِشَةَ، اشْتَكَتْ، فَجَاءَ ابْنُ عَبَّاسٍ فَقَالَ يَا أُمَّ الْمُؤْمِنِينَ، تَقْدَمِينَ عَلَى فَرَطِ صِدْقٍ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَى أَبِي بَكْرٍ‏.‏\hadithno{3771}\hadithtrans{Narrated Al-Qasim bin Muhammad:Once `Aisha became sick and Ibn `Abbas went to see her and said, "O mother of the believers! You are leaving for truthful fore-runners i.e. for Allah's Messenger (ﷺ) and Abu Bakr}}
\hadithdefcmd{bukhari}{3772}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، سَمِعْتُ أَبَا وَائِلٍ، قَالَ لَمَّا بَعَثَ عَلِيٌّ عَمَّارًا وَالْحَسَنَ إِلَى الْكُوفَةِ لِيَسْتَنْفِرَهُمْ خَطَبَ عَمَّارٌ فَقَالَ إِنِّي لأَعْلَمُ أَنَّهَا زَوْجَتُهُ فِي الدُّنْيَا وَالآخِرَةِ، وَلَكِنَّ اللَّهَ ابْتَلاَكُمْ لِتَتَّبِعُوهُ أَوْ إِيَّاهَا‏.‏\hadithno{3772}\hadithtrans{Narrated Abu Wail:When `Ali sent `Ammar and Al-Hasan to (the people of) Kufa to urge them to fight, `Ammar addressed them saying, "I know that she (i.e. `Aisha) is the wife of the Prophet (ﷺ) in this world and in the Hereafter (world to come), but Allah has put you to test, whether you will follow Him (i.e. Allah) or her}}
\hadithdefcmd{bukhari}{3773}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّهَا اسْتَعَارَتْ مِنْ أَسْمَاءَ قِلاَدَةً فَهَلَكَتْ، فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاسًا مِنْ أَصْحَابِهِ فِي طَلَبِهَا، فَأَدْرَكَتْهُمُ الصَّلاَةُ، فَصَلَّوْا بِغَيْرِ وُضُوءٍ، فَلَمَّا أَتَوُا النَّبِيَّ صلى الله عليه وسلم شَكَوْا ذَلِكَ إِلَيْهِ، فَنَزَلَتْ آيَةُ التَّيَمُّمِ‏.‏ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ جَزَاكِ اللَّهُ خَيْرًا، فَوَاللَّهِ مَا نَزَلَ بِكِ أَمْرٌ قَطُّ إِلاَّ جَعَلَ اللَّهُ لَكِ مِنْهُ مَخْرَجًا، وَجَعَلَ لِلْمُسْلِمِينَ فِيهِ بَرَكَةً‏.‏\hadithno{3773}\hadithtrans{Narrated `Aisha:That she borrowed a necklace from Asma' and it was lost. Allah's Messenger (ﷺ) sent some of his companions to look for it. During their journey the time of prayer was due and they prayed without ablution. When they returned to the Prophet (ﷺ) they complained about it. So the Divine Verse of Tayammum was revealed. Usaid bin Hudair said (to `Aisha), "May Allah reward you handsomely. By Allah, whenever you have a difficulty, Allah took you out of it and brought with it, a Blessing for the Muslims}}
\hadithdefcmd{bukhari}{3774}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا كَانَ فِي مَرَضِهِ، جَعَلَ يَدُورُ فِي نِسَائِهِ وَيَقُولُ ‏ "‏ أَيْنَ أَنَا غَدًا أَيْنَ أَنَا غَدًا ‏"‏‏.‏ حِرْصًا عَلَى بَيْتِ عَائِشَةَ، قَالَتْ عَائِشَةُ فَلَمَّا كَانَ يَوْمِي سَكَنَ‏.‏\hadithno{3774}\hadithtrans{Narrated Hisham's father:When Allah's Messenger (ﷺ) was in his fatal illness, he started visiting his wives and saying, "Where will I be tomorrow?" He was anxious to be in `Aisha's home. `Aisha said, "So when it was my day, the Prophet became silent (no longer asked the question)}}
\hadithdefcmd{bukhari}{3775}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ،، قَالَ كَانَ النَّاسُ يَتَحَرَّوْنَ بِهَدَايَاهُمْ يَوْمَ عَائِشَةَ قَالَتْ عَائِشَةُ فَاجْتَمَعَ صَوَاحِبِي إِلَى أُمِّ سَلَمَةَ، فَقُلْنَ يَا أُمَّ سَلَمَةَ، وَاللَّهِ إِنَّ النَّاسَ يَتَحَرَّوْنَ بِهَدَايَاهُمْ يَوْمَ عَائِشَةَ، وَإِنَّا نُرِيدُ الْخَيْرَ كَمَا تُرِيدُهُ عَائِشَةُ، فَمُرِي رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَأْمُرَ النَّاسَ أَنْ يُهْدُوا إِلَيْهِ حَيْثُ مَا كَانَ أَوْ حَيْثُ مَا دَارَ، قَالَتْ فَذَكَرَتْ ذَلِكَ أُمُّ سَلَمَةَ لِلنَّبِيِّ صلى الله عليه وسلم قَالَتْ فَأَعْرَضَ عَنِّي، فَلَمَّا عَادَ إِلَىَّ ذَكَرْتُ لَهُ ذَاكَ فَأَعْرَضَ عَنِّي، فَلَمَّا كَانَ فِي الثَّالِثَةِ ذَكَرْتُ لَهُ فَقَالَ ‏ "‏ يَا أُمَّ سَلَمَةَ لاَ تُؤْذِينِي فِي عَائِشَةَ، فَإِنَّهُ وَاللَّهِ مَا نَزَلَ عَلَىَّ الْوَحْىُ وَأَنَا فِي لِحَافِ امْرَأَةٍ مِنْكُنَّ غَيْرِهَا ‏"‏‏.‏\hadithno{3775}\hadithtrans{Narrated Hisham's father:The people used to send presents to the Prophet (ﷺ) on the day of `Aisha's turn. `Aisha said, "My companions (i.e. the other wives of the Prophet) gathered in the house of Um Salama and said, "O Um Salama! By Allah, the people choose to send presents on the day of `Aisha's turn and we too, love the good (i.e. presents etc.) as `Aisha does. You should tell Allah's Messenger (ﷺ) to tell the people to send their presents to him wherever he may be, or wherever his turn may be." Um Salama said that to the Prophet and he turned away from her, and when the Prophet (ﷺ) returned to her (i.e. Um Salama), she repeated the same, and the Prophet (ﷺ) again turned away, and when she told him the same for the third time, the Prophet (ﷺ) said, "O Um Salama! Don't trouble me by harming `Aisha, for by Allah, the Divine Inspiration never came to me while I was under the blanket of any woman amongst you except her}}
