% Auto-generated chapter 9 for abudawud
% Hadiths in this chapter: 145

\hadithdefcmd{abudawud}{1556}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاسْتُخْلِفَ أَبُو بَكْرٍ بَعْدَهُ وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ قَالَ عُمَرُ بْنُ الْخَطَّابِ لأَبِي بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ وَاللَّهِ لَوْ مَنَعُونِي عِقَالاً كَانُوا يُؤَدُّونَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهِ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ اللَّهَ عَزَّ وَجَلَّ قَدْ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ - قَالَ - فَعَرَفْتُ أَنَّهُ الْحَقُّ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ أَبُو عُبَيْدَةَ مَعْمَرُ بْنُ الْمُثَنَّى الْعِقَالُ صَدَقَةُ سَنَةٍ وَالْعِقَالاَنِ صَدَقَةُ سَنَتَيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ رَبَاحُ بْنُ زَيْدٍ وَعَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ بِإِسْنَادِهِ وَقَالَ بَعْضُهُمْ عِقَالاً ‏.‏ وَرَوَاهُ ابْنُ وَهْبٍ عَنْ يُونُسَ قَالَ عَنَاقًا ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ شُعَيْبُ بْنُ أَبِي حَمْزَةَ وَمَعْمَرٌ وَالزُّبَيْدِيُّ عَنِ الزُّهْرِيِّ فِي هَذَا الْحَدِيثِ لَوْ مَنَعُونِي عَنَاقًا ‏.‏ وَرَوَى عَنْبَسَةُ عَنْ يُونُسَ عَنِ الزُّهْرِيِّ فِي هَذَا الْحَدِيثِ قَالَ عَنَاقًا ‏.‏\hadithno{1556}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7284، 7285) Sahih Muslim (20)}\hadithtrans{Abu Hurairah said When the Messenger of Allah(ﷺ) died and Abu Bakr was made his successor after him and certain Arab clans apostatized. Umar bin Al Khattab said to Abu Bakr How can you fight with the people until they say “There is no God but Allah” so whoever says “There is no God but Allah”, he has protected his property and his person from me except for what is due from him, and his reckoning is left to allah. Abu Bak replied I swear by Allah that I will certainly fight with those who make a distinction between prayer and zakat, for zakat is what is due from property. I swear by Allah that if they were to refuse me a rope of camel (or a female kid, according to another version)which they used to pay the Messenger of Allah, I will fight with them over the refusal of it. Umar bin Al Khattab said I swear by Allah, I clearly saw Allah had made Abu Bakr feel justified in tighting and I recognized that it was right. Abu Dawud said This tradition has been transmitted by Rabah bin Zaid from Ma’mar and Al Zaubaidi from Al Zuhri has “If they were to refuse me a female kid.” The version transmitted by ‘Anbasah from Yunus on the authority of Al Zuhri has “a female kid”}}
\hadithdefcmd{abudawud}{1557}{حَدَّثَنَا ابْنُ السَّرْحِ، وَسُلَيْمَانُ بْنُ دَاوُدَ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ قَالَ أَبُو بَكْرٍ إِنَّ حَقَّهُ أَدَاءُ الزَّكَاةِ وَقَالَ عِقَالاً ‏.‏\hadithno{1557}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7284، 7285) Sahih Muslim (20)}\hadithtrans{This tradition has also been transmitted by Al Zuhri through a different chain of narrators. This version has “Abu Bakr said its due is the payment of zakat.” He used the word “a rope of a Camel”}}
\hadithdefcmd{abudawud}{1558}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{1558}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1447) Sahih Muslim (979)}\hadithtrans{Abu Sa’id Al Khudri reported:That the Apostle of Allaah(ﷺ) as saying No sadaqah(zakat) is payable on less than five camels, on less than five ounces of silver and on less than five camel loads(wasq)}}
\hadithdefcmd{abudawud}{1559}{حَدَّثَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الرَّقِّيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا إِدْرِيسُ بْنُ يَزِيدَ الأَوْدِيُّ، عَنْ عَمْرِو بْنِ مُرَّةَ الْجَمَلِيِّ، عَنْ أَبِي الْبَخْتَرِيِّ الطَّائِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، يَرْفَعُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ زَكَاةٌ ‏"‏ ‏.‏ وَالْوَسْقُ سِتُّونَ مَخْتُومًا ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو الْبَخْتَرِيِّ لَمْ يَسْمَعْ مِنْ أَبِي سَعِيدٍ ‏.‏\hadithno{1559}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: There is no zakat payable (on grain or dates) on less than five camel-loads. The wasq (one camel-load) measures sixty sa' in weight}}
\hadithdefcmd{abudawud}{1560}{حَدَّثَنَا مُحَمَّدُ بْنُ قُدَامَةَ بْنِ أَعْيَنَ، حَدَّثَنَا جَرِيرٌ، عَنِ الْمُغِيرَةِ، عَنْ إِبْرَاهِيمَ، قَالَ الْوَسْقُ سِتُّونَ صَاعًا مَخْتُومًا بِالْحَجَّاجِيِّ ‏.‏\hadithno{1560}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Ibrahim said The wasq contained sixty sa’s stamped with the stamp of Al Hajjaj}}
\hadithdefcmd{abudawud}{1561}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا صُرَدُ بْنُ أَبِي الْمَنَازِلِ، قَالَ سَمِعْتُ حَبِيبًا الْمَالِكِيَّ، قَالَ قَالَ رَجُلٌ لِعِمْرَانَ بْنِ حُصَيْنٍ يَا أَبَا نُجَيْدٍ إِنَّكُمْ لَتُحَدِّثُونَنَا بِأَحَادِيثَ مَا نَجِدُ لَهَا أَصْلاً فِي الْقُرْآنِ ‏.‏ فَغَضِبَ عِمْرَانُ وَقَالَ لِلرَّجُلِ أَوَجَدْتُمْ فِي كُلِّ أَرْبَعِينَ دِرْهَمًا دِرْهَمٌ وَمِنْ كُلِّ كَذَا وَكَذَا شَاةً شَاةٌ وَمِنْ كُلِّ كَذَا وَكَذَا بَعِيرًا كَذَا وَكَذَا أَوَجَدْتُمْ هَذَا فِي الْقُرْآنِ قَالَ لاَ ‏.‏ قَالَ فَعَنْ مَنْ أَخَذْتُمْ هَذَا أَخَذْتُمُوهُ عَنَّا وَأَخَذْنَاهُ عَنْ نَبِيِّ اللَّهِ صلى الله عليه وسلم وَذَكَرَ أَشْيَاءَ نَحْوَ هَذَا ‏.‏\hadithno{1561}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Habib al-Maliki said:A man said to Imran ibn Husayn: AbuNujayd, you narrate to us traditions whose basis we do not find in the Qur'an. Thereupon, Imran got angry and said to the man: Do you find in the Qur'an that one dirham is due on forty dirhams (as Zakat), and one goat is due on such-and-such number of goats, and one camel will be due on such-and-such number of camels? He replied: No. He said: From whom did you take it? You took it from us, from the Messenger of Allah (ﷺ). He mentioned many similar things}}
\hadithdefcmd{abudawud}{1562}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا سُلَيْمَانُ بْنُ مُوسَى أَبُو دَاوُدَ، حَدَّثَنَا جَعْفَرُ بْنُ سَعْدِ بْنِ سَمُرَةَ بْنِ جُنْدُبٍ، حَدَّثَنِي خُبَيْبُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، سُلَيْمَانَ عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ أَمَّا بَعْدُ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُنَا أَنْ نُخْرِجَ الصَّدَقَةَ مِنَ الَّذِي نُعِدُّ لِلْبَيْعِ ‏.‏\hadithno{1562}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: The Messenger of Allah (ﷺ) used to order us to pay the sadaqah (zakat) on what we prepared for trade}}
\hadithdefcmd{abudawud}{1563}{حَدَّثَنَا أَبُو كَامِلٍ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، - الْمَعْنَى - أَنَّ خَالِدَ بْنَ الْحَارِثِ، حَدَّثَهُمْ حَدَّثَنَا حُسَيْنٌ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ امْرَأَةً، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَعَهَا ابْنَةٌ لَهَا وَفِي يَدِ ابْنَتِهَا مَسَكَتَانِ غَلِيظَتَانِ مِنْ ذَهَبٍ فَقَالَ لَهَا ‏"‏ أَتُعْطِينَ زَكَاةَ هَذَا ‏"‏ ‏.‏ قَالَتْ لاَ ‏.‏ قَالَ ‏"‏ أَيَسُرُّكِ أَنْ يُسَوِّرَكِ اللَّهُ بِهِمَا يَوْمَ الْقِيَامَةِ سِوَارَيْنِ مِنْ نَارٍ ‏"‏ ‏.‏ قَالَ فَخَلَعَتْهُمَا فَأَلْقَتْهُمَا إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَالَتْ هُمَا لِلَّهِ عَزَّ وَجَلَّ وَلِرَسُولِهِ ‏.‏\hadithno{1563}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib on his father's authority said that his grandfather reported: A woman came to the Messenger of Allah (ﷺ) and she was accompanied by her daughter who wore two heavy gold bangles in her hands. He said to her: Do you pay zakat on them? She said: No. He then said: Are you pleased that Allah may put two bangles of fire on your hands? Thereupon she took them off and placed them before the Prophet (ﷺ) saying: They are for Allah and His Apostle}}
\hadithdefcmd{abudawud}{1564}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا عَتَّابٌ، - يَعْنِي ابْنَ بَشِيرٍ - عَنْ ثَابِتِ بْنِ عَجْلاَنَ، عَنْ عَطَاءٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كُنْتُ أَلْبَسُ أَوْضَاحًا مِنْ ذَهَبٍ فَقُلْتُ يَا رَسُولَ اللَّهِ أَكَنْزٌ هُوَ فَقَالَ ‏ "‏ مَا بَلَغَ أَنْ تُؤَدَّى زَكَاتُهُ فَزُكِّيَ فَلَيْسَ بِكَنْزٍ ‏"‏ ‏.‏\hadithno{1564}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: I used to wear gold ornaments. I asked: Is that a treasure (kanz), Messenger of Allah? He replied: whatever reaches a quantity on which zakat is payable is not a treasure (kanz) when the zakat is paid}}
\hadithdefcmd{abudawud}{1565}{حَدَّثَنَا مُحَمَّدُ بْنُ إِدْرِيسَ الرَّازِيُّ، حَدَّثَنَا عَمْرُو بْنُ الرَّبِيعِ بْنِ طَارِقٍ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، أَنَّ مُحَمَّدَ بْنَ عَمْرِو بْنِ عَطَاءٍ، أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادِ بْنِ الْهَادِ، أَنَّهُ قَالَ دَخَلْنَا عَلَى عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَأَى فِي يَدِي فَتَخَاتٍ مِنْ وَرِقٍ فَقَالَ ‏"‏ مَا هَذَا يَا عَائِشَةُ ‏"‏ ‏.‏ فَقُلْتُ صَنَعْتُهُنَّ أَتَزَيَّنُ لَكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ أَتُؤَدِّينَ زَكَاتَهُنَّ ‏"‏ ‏.‏ قُلْتُ لاَ أَوْ مَا شَاءَ اللَّهُ ‏.‏ قَالَ ‏"‏ هُوَ حَسْبُكِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{1565}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated ‘Abdallah bin Shaddad bin Al Had :We entered upon A’ishah, wife of the Prophet (ﷺ). She said The Apostle of Allaah (ﷺ) entered upon me and saw two silver rings in my hand. He asked What is this, Aishah? I said I have made two ornaments myself for you, Messenger of Allah (ﷺ). He asked Do you pay zakat on them? I said No or I said Whatever Allah willed. He said this is sufficient for you (to take you) to the Hell fire}}
\hadithdefcmd{abudawud}{1566}{حَدَّثَنَا صَفْوَانُ بْنُ صَالِحٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عُمَرَ بْنِ يَعْلَى، فَذَكَرَ الْحَدِيثَ نَحْوَ حَدِيثِ الْخَاتَمِ ‏.‏ قِيلَ لِسُفْيَانَ كَيْفَ تُزَكِّيهِ قَالَ تَضُمُّهُ إِلَى غَيْرِهِ ‏.‏\hadithno{1566}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition has also been narrated by ‘Umar bin Ya’la through a different chain of narrators, like the tradition of ring. Sufyan, a narrator, was asked How do you pay zakat on it. He said You may combine it with other (ornaments)}}
\hadithdefcmd{abudawud}{1567}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، قَالَ أَخَذْتُ مِنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَنَسٍ كِتَابًا زَعَمَ أَنَّ أَبَا بَكْرٍ، كَتَبَهُ لأَنَسٍ وَعَلَيْهِ خَاتَمُ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ بَعَثَهُ مُصَدِّقًا وَكَتَبَهُ لَهُ فَإِذَا فِيهِ ‏"‏ هَذِهِ فَرِيضَةُ الصَّدَقَةِ الَّتِي فَرَضَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمُسْلِمِينَ الَّتِي أَمَرَ اللَّهُ عَزَّ وَجَلَّ بِهَا نَبِيَّهُ صلى الله عليه وسلم فَمَنْ سُئِلَهَا مِنَ الْمُسْلِمِينَ عَلَى وَجْهِهَا فَلْيُعْطِهَا وَمَنْ سُئِلَ فَوْقَهَا فَلاَ يُعْطِهِ فِيمَا دُونَ خَمْسٍ وَعِشْرِينَ مِنَ الإِبِلِ الْغَنَمُ فِي كُلِّ خَمْسِ ذَوْدٍ شَاةٌ ‏.‏ فَإِذَا بَلَغَتْ خَمْسًا وَعِشْرِينَ فَفِيهَا بِنْتُ مَخَاضٍ إِلَى أَنْ تَبْلُغَ خَمْسًا وَثَلاَثِينَ فَإِنْ لَمْ يَكُنْ فِيهَا بِنْتُ مَخَاضٍ فَابْنُ لَبُونٍ ذَكَرٌ فَإِذَا بَلَغَتْ سِتًّا وَثَلاَثِينَ فَفِيهَا بِنْتُ لَبُونٍ إِلَى خَمْسٍ وَأَرْبَعِينَ فَإِذَا بَلَغَتْ سِتًّا وَأَرْبَعِينَ فَفِيهَا حِقَّةٌ طَرُوقَةُ الْفَحْلِ إِلَى سِتِّينَ فَإِذَا بَلَغَتْ إِحْدَى وَسِتِّينَ فَفِيهَا جَذَعَةٌ إِلَى خَمْسٍ وَسَبْعِينَ فَإِذَا بَلَغَتْ سِتًّا وَسَبْعِينَ فَفِيهَا ابْنَتَا لَبُونٍ إِلَى تِسْعِينَ فَإِذَا بَلَغَتْ إِحْدَى وَتِسْعِينَ فَفِيهَا حِقَّتَانِ طَرُوقَتَا الْفَحْلِ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ عَلَى عِشْرِينَ وَمِائَةٍ فَفِي كُلِّ أَرْبَعِينَ بِنْتُ لَبُونٍ وَفِي كُلِّ خَمْسِينَ حِقَّةٌ فَإِذَا تَبَايَنَ أَسْنَانُ الإِبِلِ فِي فَرَائِضِ الصَّدَقَاتِ فَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْجَذَعَةِ وَلَيْسَتْ عِنْدَهُ جَذَعَةٌ وَعِنْدَهُ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ وَأَنْ يَجْعَلَ مَعَهَا شَاتَيْنِ - إِنِ اسْتَيْسَرَتَا لَهُ - أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَتْ عِنْدَهُ حِقَّةٌ وَعِنْدَهُ جَذَعَةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَ عِنْدَهُ حِقَّةٌ وَعِنْدَهُ ابْنَةُ لَبُونٍ فَإِنَّهَا تُقْبَلُ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ مِنْ هَا هُنَا لَمْ أَضْبِطْهُ عَنْ مُوسَى كَمَا أُحِبُّ ‏"‏ وَيَجْعَلُ مَعَهَا شَاتَيْنِ - إِنِ اسْتَيْسَرَتَا لَهُ - أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ بِنْتِ لَبُونٍ وَلَيْسَ عِنْدَهُ إِلاَّ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ إِلَى هَا هُنَا ثُمَّ أَتْقَنْتُهُ ‏"‏ وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ ابْنَةِ لَبُونٍ وَلَيْسَ عِنْدَهُ إِلاَّ بِنْتُ مَخَاضٍ فَإِنَّهَا تُقْبَلُ مِنْهُ وَشَاتَيْنِ أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ ابْنَةِ مَخَاضٍ وَلَيْسَ عِنْدَهُ إِلاَّ ابْنُ لَبُونٍ ذَكَرٌ فَإِنَّهُ يُقْبَلُ مِنْهُ وَلَيْسَ مَعَهُ شَىْءٌ وَمَنْ لَمْ يَكُنْ عِنْدَهُ إِلاَّ أَرْبَعٌ فَلَيْسَ فِيهَا شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا وَفِي سَائِمَةِ الْغَنَمِ إِذَا كَانَتْ أَرْبَعِينَ فَفِيهَا شَاةٌ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ عَلَى عِشْرِينَ وَمِائَةٍ فَفِيهَا شَاتَانِ إِلَى أَنْ تَبْلُغَ مِائَتَيْنِ فَإِذَا زَادَتْ عَلَى مِائَتَيْنِ فَفِيهَا ثَلاَثُ شِيَاهٍ إِلَى أَنْ تَبْلُغَ ثَلاَثَمِائَةٍ فَإِذَا زَادَتْ عَلَى ثَلاَثِمِائَةٍ فَفِي كُلِّ مِائَةِ شَاةٍ شَاةٌ وَلاَ يُؤْخَذُ فِي الصَّدَقَةِ هَرِمَةٌ وَلاَ ذَاتُ عَوَارٍ مِنَ الْغَنَمِ وَلاَ تَيْسُ الْغَنَمِ إِلاَّ أَنْ يَشَاءَ الْمُصَّدِّقُ وَلاَ يُجْمَعُ بَيْنَ مُفْتَرِقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ خَشْيَةَ الصَّدَقَةِ وَمَا كَانَ مِنْ خَلِيطَيْنِ فَإِنَّهُمَا يَتَرَاجَعَانِ بَيْنَهُمَا بِالسَّوِيَّةِ فَإِنْ لَمْ تَبْلُغْ سَائِمَةُ الرَّجُلِ أَرْبَعِينَ فَلَيْسَ فِيهَا شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا وَفِي الرِّقَةِ رُبْعُ الْعُشْرِ فَإِنْ لَمْ يَكُنِ الْمَالُ إِلاَّ تِسْعِينَ وَمِائَةً فَلَيْسَ فِيهَا شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا ‏"‏ ‏.‏\hadithno{1567}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1448)}\hadithtrans{Narrated Hammad : I took a letter from Thumamah bin ‘Abd Allah bin Anas. He presumed that Abu Bakr had written it for Anas when he sent him (to Al Bahrain) as a collector of zakat. This (letter) was stamped with the stamp of the Messenger of Allah(ﷺ) and was written by Abu Bakr for him(Anas). This letter goes “This is the obligatory sadaqah(zakat) which the Messenger of Allah(ﷺ) imposed on Muslims which Allah commanded his Prophet(ﷺ) to impose. Those Muslims who are asked for the proper amount must give it, but those who are asked for more than that must not give it. For less than twenty five Camels a goat is to be given for every five Camels. When they reach twenty five to thirty five, a she Camel in her second year is to be given. If there is no she Camel in her second year, a male Camel in its third year is to be given. When they reach thirty six to forty five, a she Camel in her third year is to be given. When they reach forty six to sixty , a she Camel in her fourth year which is ready to be covered by a stallion is to be given. When they reach sixty one to seventy five, a she Camel in her fifth year is to be given. When they reach seventy six to ninety, two she Camel in their third year are to be given. When they reach ninety one to a hundred and twenty, two she Camels in their fourth year are ready to be covered by a stallion are to be given. When they exceed a hundred and twenty, a she Camel in her third year is to be given for every forty and a she Camel in her fourth year for every fifty(Camels). In case the ages of the Camel vary in the payment of obligatory sadaqah(zakat) If anyone whose Camels reach the number on which a she Camel in her fifth year is payable does not possess one but possess one in her fourth year, that will be accepted from him along with two goats if he can conveniently give them, or else twenty dirhams. If anyone whose Camels reach the number on which a she Camel in her fourth year is payable does not possess but possesses one in her fifth year, that will be accepted from him, and the collector must give him twenty dirhams or two goats. If anyone whose Camels reach the number on which a she Camel in her fourth year is payable possesses only one in her third year, that will be accepted from him.” Abu Dawud said From here I could not retain accurately from Musa as I liked “And he must give along with it two goats if he can conveniently give them, or else twenty dirhams. If anyone whose Camels reach the number on which a she Camel in her third year is payable possesses only one in her fourth year, that will be accepted from him.” Abu Dawud said (I was doubtful) up to here, and retained correctly onward “and the collector must give him twenty dirhams or two goats. If anyone whose Camels reach the number on which a she Camel in her third year is payable does not possess one but possesses one in her second year, that will be accepted from him, but he must give two goats or twenty dirhams. Anyone whose Camels reach the number on which a she Camel in her second year is payable does not possess one but possesses a male Camel in its third year, that will be accepted from him, and nothing extra will be demanded along with it. If anyone possesses only four Camels, no zakat will be payable on them unless their owner wishes. If the numbers of the pasturing goats reach forty to one hundred and twenty, one goat is to be given. Over one hundred and twenty up to two hundred, two goats are to be given. If they exceed two hundred reaching three hundred, three goats are to be given. If they exceed three hundred, a goat is to be for every hundred. An old sheep, one with a defect in the eye, or a male goat is not to be accepted as sadaqah (zakat) unless the collector wishes. Those which are in separate flocks are not to be brought together and those which are in one flock are not to be separated from fear of sadaqah(zakat). Regarding what belongs to two partners, they can make claims for restitution from one another with equity, If a man’s pasturing animals are less than forty, no sadaqah(zakat) is due on them unless their owner wishes. On sliver dirhams a fortieth is payable, but if there are only a hundred and ninety, nothing is payable unless their owner wishes.”}}
\hadithdefcmd{abudawud}{1568}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ كَتَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم كِتَابَ الصَّدَقَةِ فَلَمْ يُخْرِجْهُ إِلَى عُمَّالِهِ حَتَّى قُبِضَ فَقَرَنَهُ بِسَيْفِهِ فَعَمِلَ بِهِ أَبُو بَكْرٍ حَتَّى قُبِضَ ثُمَّ عَمِلَ بِهِ عُمَرُ حَتَّى قُبِضَ فَكَانَ فِيهِ ‏ "‏ فِي خَمْسٍ مِنَ الإِبِلِ شَاةٌ وَفِي عَشْرٍ شَاتَانِ وَفِي خَمْسَ عَشَرَةَ ثَلاَثُ شِيَاهٍ وَفِي عِشْرِينَ أَرْبَعُ شِيَاهٍ وَفِي خَمْسٍ وَعِشْرِينَ ابْنَةُ مَخَاضٍ إِلَى خَمْسٍ وَثَلاَثِينَ فَإِنْ زَادَتْ وَاحِدَةً فَفِيهَا ابْنَةُ لَبُونٍ إِلَى خَمْسٍ وَأَرْبَعِينَ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا حِقَّةٌ إِلَى سِتِّينَ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا جَذَعَةٌ إِلَى خَمْسٍ وَسَبْعِينَ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا ابْنَتَا لَبُونٍ إِلَى تِسْعِينَ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا حِقَّتَانِ إِلَى عِشْرِينَ وَمِائَةٍ فَإِنْ كَانَتِ الإِبِلُ أَكْثَرَ مِنْ ذَلِكَ فَفِي كُلِّ خَمْسِينَ حِقَّةٌ وَفِي كُلِّ أَرْبَعِينَ ابْنَةُ لَبُونٍ وَفِي الْغَنَمِ فِي كُلِّ أَرْبَعِينَ شَاةً شَاةٌ إِلَى عِشْرِينَ وَمِائَةٍ فَإِنْ زَادَتْ وَاحِدَةً فَشَاتَانِ إِلَى مِائَتَيْنِ فَإِنْ زَادَتْ وَاحِدَةً عَلَى الْمِائَتَيْنِ فَفِيهَا ثَلاَثُ شِيَاهٍ إِلَى ثَلاَثِمِائَةٍ فَإِنْ كَانَتِ الْغَنَمُ أَكْثَرَ مِنْ ذَلِكَ فَفِي كُلِّ مِائَةِ شَاةٍ شَاةٌ وَلَيْسَ فِيهَا شَىْءٌ حَتَّى تَبْلُغَ الْمِائَةَ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ وَلاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ مَخَافَةَ الصَّدَقَةِ وَمَا كَانَ مِنْ خَلِيطَيْنِ فَإِنَّهُمَا يَتَرَاجَعَانِ بَيْنَهُمَا بِالسَّوِيَّةِ وَلاَ يُؤْخَذُ فِي الصَّدَقَةِ هَرِمَةٌ وَلاَ ذَاتُ عَيْبٍ ‏"‏ ‏.‏ قَالَ وَقَالَ الزُّهْرِيُّ إِذَا جَاءَ الْمُصَدِّقُ قُسِمَتِ الشَّاءُ أَثْلاَثًا ثُلُثًا شِرَارًا وَثُلُثًا خِيَارًا وَثُلُثًا وَسَطًا فَأَخَذَ الْمُصَدِّقُ مِنَ الْوَسَطِ وَلَمْ يَذْكُرِ الزُّهْرِيُّ الْبَقَرَ ‏.‏\hadithno{1568}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) wrote a letter about sadaqah (zakat) but he died before he could send it to his governors. He had kept it with his sword. So AbuBakr acted upon it till he died, and then Umar acted upon it till he died. It contained: "For five camels one goat is to be given; for ten camels two goats are to be given; for fifteen camels three goats are to be given; for twenty camels four goats are to be given; for twenty-five to thirty-five camels a she-camel in her second year is to be given. If the number exceeds by one up to seventy camels, a she-camel in her fourth year is to be given; if they exceed by one up to seventy-five camels, a she-camel in her fifth year is to be given; if they exceed by one up to ninety camels, two she-camels in their third year are to be given; if they exceed by one up to one hundred and twenty, two she-camels in their fourth year are to be given. If the camels are more than this, a she-camel in her fourth year is to be given for every fifty camels, and a she-camel in her third year is to be given for every forty camels. For forty to one hundred and twenty goats one goat is to be given; if they exceed by one up to two hundred, two goats are to be given. If they exceed by one up to three hundred, three goats are to be given; if the goats are more than this, one goat for every hundred goats is to be given. Nothing is payable until they reach one hundred. Those which are in one flock are not to be separated, and those which are in separate flocks are not be brought together from fear of sadaqah (zakat). Regarding that which belongs to two partners, they can make claims for restitution from each other with equity. An old goat and a defective one are not to be accepted as sadaqah (zakat)." Az-Zuhri said: When the collector comes, the goats will be apportioned into three flocks: one containing bad, the second good, and the third moderate. The collector will take zakat from the moderate. Az-Zuhri did not mention the cows (to be apportioned in three flocks)}}
\hadithdefcmd{abudawud}{1569}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ الْوَاسِطِيُّ، أَخْبَرَنَا سُفْيَانُ بْنُ حُسَيْنٍ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ ‏ "‏ فَإِنْ لَمْ تَكُنِ ابْنَةُ مَخَاضٍ فَابْنُ لَبُونٍ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ كَلاَمَ الزُّهْرِيِّ ‏.‏\hadithno{1569}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Therefore said tradition has also been transmitted by Sufyan bin Husain through a different chain of narrators and to the same effect. This version adds “If there is no she Camel in her second year, a she Camel in her third year is to be given.” This does not mention the words of Al Zuhri}}
\hadithdefcmd{abudawud}{1570}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ هَذِهِ نُسْخَةُ كِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّذِي كَتَبَهُ فِي الصَّدَقَةِ وَهِيَ عِنْدَ آلِ عُمَرَ بْنِ الْخَطَّابِ قَالَ ابْنُ شِهَابٍ أَقْرَأَنِيهَا سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ فَوَعَيْتُهَا عَلَى وَجْهِهَا وَهِيَ الَّتِي انْتَسَخَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ مِنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ وَسَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ فَذَكَرَ الْحَدِيثَ قَالَ ‏"‏ فَإِذَا كَانَتْ إِحْدَى وَعِشْرِينَ وَمِائَةً فَفِيهَا ثَلاَثُ بَنَاتِ لَبُونٍ حَتَّى تَبْلُغَ تِسْعًا وَعِشْرِينَ وَمِائَةً فَإِذَا كَانَتْ ثَلاَثِينَ وَمِائَةً فَفِيهَا بِنْتَا لَبُونٍ وَحِقَّةٌ حَتَّى تَبْلُغَ تِسْعًا وَثَلاَثِينَ وَمِائَةً فَإِذَا كَانَتْ أَرْبَعِينَ وَمِائَةً فَفِيهَا حِقَّتَانِ وَبِنْتُ لَبُونٍ حَتَّى تَبْلُغَ تِسْعًا وَأَرْبَعِينَ وَمِائَةً فَإِذَا كَانَتْ خَمْسِينَ وَمِائَةً فَفِيهَا ثَلاَثُ حِقَاقٍ حَتَّى تَبْلُغَ تِسْعًا وَخَمْسِينَ وَمِائَةً فَإِذَا كَانَتْ سِتِّينَ وَمِائَةً فَفِيهَا أَرْبَعُ بَنَاتِ لَبُونٍ حَتَّى تَبْلُغَ تِسْعًا وَسِتِّينَ وَمِائَةً فَإِذَا كَانَتْ سَبْعِينَ وَمِائَةً فَفِيهَا ثَلاَثُ بَنَاتِ لَبُونٍ وَحِقَّةٌ حَتَّى تَبْلُغَ تِسْعًا وَسَبْعِينَ وَمِائَةً فَإِذَا كَانَتْ ثَمَانِينَ وَمِائَةً فَفِيهَا حِقَّتَانِ وَابْنَتَا لَبُونٍ حَتَّى تَبْلُغَ تِسْعًا وَثَمَانِينَ وَمِائَةً فَإِذَا كَانَتْ تِسْعِينَ وَمِائَةً فَفِيهَا ثَلاَثُ حِقَاقٍ وَبِنْتُ لَبُونٍ حَتَّى تَبْلُغَ تِسْعًا وَتِسْعِينَ وَمِائَةً فَإِذَا كَانَتْ مِائَتَيْنِ فَفِيهَا أَرْبَعُ حِقَاقٍ أَوْ خَمْسُ بَنَاتِ لَبُونٍ أَىُّ السِّنَّيْنِ وُجِدَتْ أُخِذَتْ وَفِي سَائِمَةِ الْغَنَمِ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ سُفْيَانَ بْنِ حُسَيْنٍ وَفِيهِ ‏"‏ وَلاَ يُؤْخَذُ فِي الصَّدَقَةِ هَرِمَةٌ وَلاَ ذَاتُ عَوَارٍ مِنَ الْغَنَمِ وَلاَ تَيْسُ الْغَنَمِ إِلاَّ أَنْ يَشَاءَ الْمُصَّدِّقُ ‏"‏ ‏.‏\hadithno{1570}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Shihab (Al Zuhri) said This is the copy of the letter of the Messenger of Allah(ﷺ), which he had written about sadaqah(zakat). This was in the custody of the descendants of ‘Umar bin Al Khattab. Ibn Shihab said Salim bin Abdallah bin Umar read it to me and I memorized it properly. Umar bin Abdul Aziz got it copied from ‘Abdallah, ‘Abdallah bin Umar and Salim bin ‘Abdallah bin ‘Umar. He (Ibn Shihab) then narrated the tradition like the former(i.e., up to one hundred and twenty camels). He further said if they (the camels) reach one hundred and twenty one to one hundred and twenty nine, three she camels in their third year are to be given. When they reach one hundred and thirty to one hundred and thirty nine, two she camels in their third year and one she Camel in her fourth year are to be given. When they reach one hundred and forty to one hundred and forty nine, two she camels in their fourth year and one she Camel in her third year are to be given. When they reach one hundred and fifty to one hundred and fifty nine, three she camels in their fourth year are to be given. When they reach one hundred and sixty to one hundred and sixty nine four she camels in their fourth year are to be given. When they reach one hundred and seventy to one hundred and seventy nine, three she camels in their third year and one she Camel in her fourth year are to be given. When they reach one hundred and eighty to one hundred and eighty nine, two she camels in their fourth year and two she Camel in their third year are to be given. When they reach one hundred and ninety to one hundred and ninety nine, three she camels in their fourth year and one she Camel in her third year are to be given. When they reach two hundred, four she camels in their fourth year or five she Camels in their third year, camels of whichever age are available, are to be accepted. For the pasturing goats, he narrated the tradition similar to that transmitted by Sufyan bin Husain. This version adds “An old goat, one with defect in the eye or a male goat is not to be accepted in sadaqah(zakat) unless the collector wishes.”}}
\hadithdefcmd{abudawud}{1571}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ قَالَ مَالِكٌ وَقَوْلُ عُمَرَ بْنِ الْخَطَّابِ - رضى الله عنه لاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ ‏.‏ هُوَ أَنْ يَكُونَ لِكُلِّ رَجُلٍ أَرْبَعُونَ شَاةً فَإِذَا أَظَلَّهُمُ الْمُصَدِّقُ جَمَعُوهَا لِئَلاَّ يَكُونَ فِيهَا إِلاَّ شَاةٌ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ ‏.‏ أَنَّ الْخَلِيطَيْنِ إِذَا كَانَ لِكُلِّ وَاحِدٍ مِنْهُمَا مِائَةُ شَاةٍ وَشَاةٌ فَيَكُونُ عَلَيْهِمَا فِيهَا ثَلاَثُ شِيَاهٍ فَإِذَا أَظَلَّهُمَا الْمُصَدِّقُ فَرَّقَا غَنَمَهُمَا فَلَمْ يَكُنْ عَلَى كُلِّ وَاحِدٍ مِنْهُمَا إِلاَّ شَاةٌ فَهَذَا الَّذِي سَمِعْتُ فِي ذَلِكَ ‏.‏\hadithno{1571}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Malik:The statement of Umar bin Al Khattab “Those which are in separate flocks are not to be brought together and those which are in one flock are not to be separated” means Two persons had forty goats each ; when the collector came they brought them together in one flock so that only one goat could be given. The phrase “those which are in one flock are not to be separated” means If two partners possessed one hundred and one goats each, three goats were to be given by each of them. When the collector came they separated their goats. Thus only one goat was to be given by each of them. This is what I heard on this subject}}
\hadithdefcmd{abudawud}{1572}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، وَعَنِ الْحَارِثِ الأَعْوَرِ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ زُهَيْرٌ أَحْسَبُهُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ هَاتُوا رُبْعَ الْعُشُورِ مِنْ كُلِّ أَرْبَعِينَ دِرْهَمًا دِرْهَمٌ وَلَيْسَ عَلَيْكُمْ شَىْءٌ حَتَّى تَتِمَّ مِائَتَىْ دِرْهَمٍ فَإِذَا كَانَتْ مِائَتَىْ دِرْهَمٍ فَفِيهَا خَمْسَةُ دَرَاهِمَ فَمَا زَادَ فَعَلَى حِسَابِ ذَلِكَ وَفِي الْغَنَمِ فِي كُلِّ أَرْبَعِينَ شَاةً شَاةٌ فَإِنْ لَمْ يَكُنْ إِلاَّ تِسْعًا وَثَلاَثِينَ فَلَيْسَ عَلَيْكَ فِيهَا شَىْءٌ ‏"‏ ‏.‏ وَسَاقَ صَدَقَةَ الْغَنَمِ مِثْلَ الزُّهْرِيِّ قَالَ ‏"‏ وَفِي الْبَقَرِ فِي كُلِّ ثَلاَثِينَ تَبِيعٌ وَفِي الأَرْبَعِينَ مُسِنَّةٌ وَلَيْسَ عَلَى الْعَوَامِلِ شَىْءٌ وَفِي الإِبِلِ ‏"‏ ‏.‏ فَذَكَرَ صَدَقَتَهَا كَمَا ذَكَرَ الزُّهْرِيُّ قَالَ ‏"‏ وَفِي خَمْسٍ وَعِشْرِينَ خَمْسَةٌ مِنَ الْغَنَمِ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا ابْنَةُ مَخَاضٍ فَإِنْ لَمْ تَكُنْ بِنْتُ مَخَاضٍ فَابْنُ لَبُونٍ ذَكَرٌ إِلَى خَمْسٍ وَثَلاَثِينَ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا بِنْتُ لَبُونٍ إِلَى خَمْسٍ وَأَرْبَعِينَ فَإِذَا زَادَتْ وَاحِدَةً فَفِيهَا حِقَّةٌ طَرُوقَةُ الْجَمَلِ إِلَى سِتِّينَ ‏"‏ ‏.‏ ثُمَّ سَاقَ مِثْلَ حَدِيثِ الزُّهْرِيِّ قَالَ ‏"‏ فَإِذَا زَادَتْ وَاحِدَةً - يَعْنِي وَاحِدَةً وَتِسْعِينَ - فَفِيهَا حِقَّتَانِ طَرُوقَتَا الْجَمَلِ إِلَى عِشْرِينَ وَمِائَةٍ فَإِنْ كَانَتِ الإِبِلُ أَكْثَرَ مِنْ ذَلِكَ فَفِي كُلِّ خَمْسِينَ حِقَّةٌ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ وَلاَ يُجْمَعُ بَيْنَ مُفْتَرِقٍ خَشْيَةَ الصَّدَقَةِ وَلاَ تُؤْخَذُ فِي الصَّدَقَةِ هَرِمَةٌ وَلاَ ذَاتُ عَوَارٍ وَلاَ تَيْسٌ إِلاَّ أَنْ يَشَاءَ الْمُصَّدِّقُ وَفِي النَّبَاتِ مَا سَقَتْهُ الأَنْهَارُ أَوْ سَقَتِ السَّمَاءُ الْعُشْرُ وَمَا سَقَى الْغَرْبُ فَفِيهِ نِصْفُ الْعُشْرِ ‏"‏ ‏.‏ وَفِي حَدِيثِ عَاصِمٍ وَالْحَارِثِ ‏"‏ الصَّدَقَةُ فِي كُلِّ عَامٍ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ أَحْسَبُهُ قَالَ ‏"‏ مَرَّةً ‏"‏ ‏.‏ وَفِي حَدِيثِ عَاصِمٍ ‏"‏ إِذَا لَمْ يَكُنْ فِي الإِبِلِ ابْنَةُ مَخَاضٍ وَلاَ ابْنُ لَبُونٍ فَعَشَرَةُ دَرَاهِمَ أَوْ شَاتَانِ ‏"‏ ‏.‏\hadithno{1572}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Harith al-A'war reported from Ali. Zuhayr said:I think, the Prophet (ﷺ) said: "Pay a fortieth. A dirham is payable on every forty, but you are not liable for payment until you have accumulated two hundred dirhams. When you have two hundred dirhams, five dirhams are payable, and that proportion is applicable to larger amounts. "Regarding sheep, for every forty sheep up to one hundred and twenty, one sheep is due. But if you possess only thirty-nine, nothing is payable on them." He further narrated the tradition about the sadaqah (zakat) on sheep like that of az-Zuhri. "Regarding cattle, a yearling bull calf is payable for every thirty, and a cow in her third year for forty, and nothing is payable on working animals. Regarding (the zakat on) camels, he mentioned the rates that az-Zuhri mentioned in his tradition. He said: "For twenty-five camels, five sheep are to be paid. If they exceed by one, a she-camel in her second year is to be given. If there is no she-camel in her second year, a male camel in its third year is to be given, up to thirty-five. If they exceed by one a she-camel in her third year is to be given, up to forty-five. If they exceed by one, a she-camel in her fourth year which is ready to be covered by a bull-camel is to be given." He then transmitted the rest of the tradition like that of az-Zuhri. He continued: If they exceed by one, i.e. they are ninety-one to hundred and twenty, two she-camels in their fourth year, which are ready to be covered by a bull-camel, are to be given. If there are more camels than that, a she-camel in her fourth year is to be given for every fifty. Those which are in one flock are not to be separated, and those which are separate are not to be brought together. An old sheep, one with a defect in the eye, or a billy goat is not to be accepted as a sadaqah unless the collector is willing. As regards agricultural produce, a tenth is payable on that which is watered by rivers or rain, and a twentieth on that which is watered by draught camels." The version of Asim and al-Harith says: "Sadaqah (zakat) is payable every year." Zuhayr said: I think he said "Once a year". The version of Asim has the words: "If a she-camel in her second year is not available among the camels, nor is there a bull-camel in its third year, ten dirhams or two goats are to be given}}
\hadithdefcmd{abudawud}{1573}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، وَسَمَّى، آخَرَ عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، وَالْحَارِثِ الأَعْوَرِ، عَنْ عَلِيٍّ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم بِبَعْضِ أَوَّلِ هَذَا الْحَدِيثِ قَالَ ‏"‏ فَإِذَا كَانَتْ لَكَ مِائَتَا دِرْهَمٍ وَحَالَ عَلَيْهَا الْحَوْلُ فَفِيهَا خَمْسَةُ دَرَاهِمَ وَلَيْسَ عَلَيْكَ شَىْءٌ - يَعْنِي فِي الذَّهَبِ - حَتَّى يَكُونَ لَكَ عِشْرُونَ دِينَارًا فَإِذَا كَانَ لَكَ عِشْرُونَ دِينَارًا وَحَالَ عَلَيْهَا الْحَوْلُ فَفِيهَا نِصْفُ دِينَارٍ فَمَا زَادَ فَبِحِسَابِ ذَلِكَ ‏"‏ ‏.‏ قَالَ فَلاَ أَدْرِي أَعَلِيٌّ يَقُولُ فَبِحِسَابِ ذَلِكَ ‏.‏ أَوْ رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏"‏ وَلَيْسَ فِي مَالٍ زَكَاةٌ حَتَّى يَحُولَ عَلَيْهِ الْحَوْلُ ‏"‏ ‏.‏ إِلاَّ أَنَّ جَرِيرًا قَالَ ابْنُ وَهْبٍ يَزِيدُ فِي الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لَيْسَ فِي مَالٍ زَكَاةٌ حَتَّى يَحُولَ عَلَيْهِ الْحَوْلُ ‏"‏ ‏.‏\hadithno{1573}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: "When you possess two hundred dirhams and one year passes on them, five dirhams are payable. Nothing is incumbent on you, that is, on gold, till it reaches twenty dinars. When you possess twenty dinars and one year passes on them, half a dinar is payable. Whatever exceeds, that will be reckoned properly." (The narrator said: I do not remember whether the words "that will be reckoned properly" were uttered by All himself or he attributed them to the Prophet (ﷺ). No zakat is payable on property till a year passes on it. But Jarir said: Ibn Wahb (sub-narrator) added to this tradition from the Prophet (ﷺ): "No zakat is payable on property until a year passes away on it}}
\hadithdefcmd{abudawud}{1574}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ عَفَوْتُ عَنِ الْخَيْلِ وَالرَّقِيقِ فَهَاتُوا صَدَقَةَ الرِّقَةِ مِنْ كُلِّ أَرْبَعِينَ دِرْهَمًا دِرْهَمٌ وَلَيْسَ فِي تِسْعِينَ وَمِائَةٍ شَىْءٌ فَإِذَا بَلَغَتْ مِائَتَيْنِ فَفِيهَا خَمْسَةُ دَرَاهِمَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ الأَعْمَشُ عَنْ أَبِي إِسْحَاقَ كَمَا قَالَ أَبُو عَوَانَةَ وَرَوَاهُ شَيْبَانُ أَبُو مُعَاوِيَةَ وَإِبْرَاهِيمُ بْنُ طَهْمَانَ عَنْ أَبِي إِسْحَاقَ عَنِ الْحَارِثِ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى حَدِيثَ النُّفَيْلِيِّ شُعْبَةُ وَسُفْيَانُ وَغَيْرُهُمَا عَنْ أَبِي إِسْحَاقَ عَنْ عَاصِمٍ عَنْ عَلِيٍّ لَمْ يَرْفَعُوهُ أَوْقَفُوهُ عَلَى عَلِيٍّ ‏.‏\hadithno{1574}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: I have given exemption regarding horses and slaves; with regard to coins, however, you must pay a dirham for every forty (dirhams), but nothing is payable on one hundred and ninety. When the total reaches two hundred, five dirhams are payable. Abu Dawud said: Al-A'mash transmitted this tradition from Abu Ishaq like the one transmitted by Abu 'Awanah. This tradition has also been narrated by Shaiban, Abu Mu'awiyah and Ibrahim b. Tahman from Abu Ishaq from al-Harith on the authority of 'Ali from the Prophet (ﷺ) to the same effect. The tradition reported by al-Nufail has also been narrated by Shu'bah, Sufyan, and others from Abu Ishaq from 'Asim from 'Ali, But they did not attribute it to the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1575}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا بَهْزُ بْنُ حَكِيمٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا أَبُو أُسَامَةَ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ فِي كُلِّ سَائِمَةِ إِبِلٍ فِي أَرْبَعِينَ بِنْتُ لَبُونٍ وَلاَ يُفَرَّقُ إِبِلٌ عَنْ حِسَابِهَا مَنْ أَعْطَاهَا مُؤْتَجِرًا ‏"‏ ‏.‏ قَالَ ابْنُ الْعَلاَءِ ‏"‏ مُؤْتَجِرًا بِهَا ‏"‏ ‏.‏ ‏"‏ فَلَهُ أَجْرُهَا وَمَنْ مَنَعَهَا فَإِنَّا آخِذُوهَا وَشَطْرَ مَالِهِ عَزْمَةً مِنْ عَزَمَاتِ رَبِّنَا عَزَّ وَجَلَّ لَيْسَ لآلِ مُحَمَّدٍ مِنْهَا شَىْءٌ ‏"‏ ‏.‏\hadithno{1575}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz b Hakim reported from his grandfather:The Messenger of Allah (ﷺ) said: For forty pasturing camels, one she-camel in her third year is to be given. The camels are not to be separated from reckoning. He who pays zakat with the intention of getting reward will be rewarded. If anyone evades zakat, we shall take half the property from him as a due from the dues of our Lord, the Exalted. There is no share in it (zakat) of the descendants of Muhammad (ﷺ)}}
\hadithdefcmd{abudawud}{1576}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مُعَاذٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا وَجَّهَهُ إِلَى الْيَمَنِ أَمَرَهُ أَنْ يَأْخُذَ مِنَ الْبَقَرِ مِنْ كُلِّ ثَلاَثِينَ تَبِيعًا أَوْ تَبِيعَةً وَمِنْ كُلِّ أَرْبَعِينَ مُسِنَّةً وَمِنْ كُلِّ حَالِمٍ - يَعْنِي مُحْتَلِمًا - دِينَارًا أَوْ عِدْلَهُ مِنَ الْمَعَافِرِ ثِيَابٌ تَكُونُ بِالْيَمَنِ ‏.‏\hadithno{1576}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: When the Prophet (ﷺ) sent him to the Yemen, he ordered him to take a male or a female calf a year old for every thirty cattle and a cow in its third year for every forty, and one dinar for every adult (unbeliever as a poll-tax) or cloths of equivalent value manufactured in the Yemen}}
\hadithdefcmd{abudawud}{1577}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَالنُّفَيْلِيُّ، وَابْنُ الْمُثَنَّى، قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ مُعَاذٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1577}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{This tradition has also been transmitted by Mu’adh through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{1578}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ بَعَثَهُ النَّبِيُّ صلى الله عليه وسلم إِلَى الْيَمَنِ فَذَكَرَ مِثْلَهُ لَمْ يَذْكُرْ ثِيَابًا تَكُونُ بِالْيَمَنِ ‏.‏ وَلاَ ذَكَرَ يَعْنِي مُحْتَلِمًا ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ جَرِيرٌ وَيَعْلَى وَمَعْمَرٌ وَشُعْبَةُ وَأَبُو عَوَانَةَ وَيَحْيَى بْنُ سَعِيدٍ عَنِ الأَعْمَشِ عَنْ أَبِي وَائِلٍ عَنْ مَسْرُوقٍ - قَالَ يَعْلَى وَمَعْمَرٌ - عَنْ مُعَاذٍ مِثْلَهُ ‏.‏\hadithno{1578}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu’adh bin Jabal :that the Prophet (ﷺ) sent him to Yemen. He then narrated the tradition something similar. He did not mention in this version cloths made in the Yemen nor did he refer to adult (unbelievers). Abu Dawud said This tradition has been transmitted by Jarir, Ya’la, Ma’mar, Abu ‘Awanahand Yahya bin Sa’id from Al A’mash, from Abu Wa’il, on the authority of Masruq, and from Ya’la and Ma’mar on the authority of Mu’adh to the same effect}}
\hadithdefcmd{abudawud}{1579}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ هِلاَلِ بْنِ خَبَّابٍ، عَنْ مَيْسَرَةَ أَبِي صَالِحٍ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ سِرْتُ أَوْ قَالَ أَخْبَرَنِي مَنْ، سَارَ مَعَ مُصَدِّقِ النَّبِيِّ صلى الله عليه وسلم فَإِذَا فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنْ لاَ تَأْخُذْ مِنْ رَاضِعِ لَبَنٍ وَلاَ تَجْمَعْ بَيْنَ مُفْتَرِقٍ وَلاَ تُفَرِّقْ بَيْنَ مُجْتَمِعٍ ‏"‏ ‏.‏ وَكَانَ إِنَّمَا يَأْتِي الْمِيَاهَ حِينَ تَرِدُ الْغَنَمُ فَيَقُولُ أَدُّوا صَدَقَاتِ أَمْوَالِكُمْ ‏.‏ قَالَ فَعَمَدَ رَجُلٌ مِنْهُمْ إِلَى نَاقَةٍ كَوْمَاءَ - قَالَ - قُلْتُ يَا أَبَا صَالِحٍ مَا الْكَوْمَاءُ قَالَ عَظِيمَةُ السَّنَامِ - قَالَ - فَأَبَى أَنْ يَقْبَلَهَا قَالَ إِنِّي أُحِبُّ أَنْ تَأْخُذَ خَيْرَ إِبِلِي ‏.‏ قَالَ فَأَبَى أَنْ يَقْبَلَهَا قَالَ فَخَطَمَ لَهُ أُخْرَى دُونَهَا فَأَبَى أَنْ يَقْبَلَهَا ثُمَّ خَطَمَ لَهُ أُخْرَى دُونَهَا فَقَبِلَهَا وَقَالَ إِنِّي آخِذُهَا وَأَخَافُ أَنْ يَجِدَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ لِي عَمَدْتَ إِلَى رَجُلٍ فَتَخَيَّرْتَ عَلَيْهِ إِبِلَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ هُشَيْمٌ عَنْ هِلاَلِ بْنِ خَبَّابٍ نَحْوَهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ لاَ يُفَرِّقْ ‏"‏ ‏.‏\hadithno{1579}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Suwayd ibn Ghaflah said:I went myself or someone who accompanied the collector of the Prophet (ﷺ) told me: It was recorded in the document written by the Messenger of Allah (ﷺ) not to accept a milking goat or she-camel or a (suckling) baby (as zakat on animals); and those which are in separate flocks are not to be brought together, and those which are in one flock are not to be separated. The collector used to visit the water-hole when the sheep went there and say: Pay the sadaqah (zakat) on your property. The narrator said: A man wanted to give him his high-humped camel (kawma'). The narrator (Hilal) asked: What is kawma', AbuSalih? He said: A camel a high hump. The narrator continued: He (the collector) refused to accept it. He said: I wish you could take the best of my camels. He refused to accept it. He then brought another camel lower in quality than the previous one. He refused to accept it too. He then brought another camel lower in quality than the previous one. He accepted it, saying: I shall take it, but I am afraid the Messenger of Allah (ﷺ) might be angry with me, saying to me: You have purposely taken from a man a camel of your choice. Abu Dawud said: This tradition has also been narrated by Hushaim from Hilal bin Khabbab to the same effect. But he said: Those which are in one flock are not to be separated}}
\hadithdefcmd{abudawud}{1580}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا شَرِيكٌ، عَنْ عُثْمَانَ بْنِ أَبِي زُرْعَةَ، عَنْ أَبِي لَيْلَى الْكِنْدِيِّ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ أَتَانَا مُصَدِّقُ النَّبِيِّ صلى الله عليه وسلم فَأَخَذْتُ بِيَدِهِ وَقَرَأْتُ فِي عَهْدِهِ ‏"‏ لاَ يُجْمَعُ بَيْنَ مُفْتَرِقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ خَشْيَةَ الصَّدَقَةِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ ‏"‏ رَاضِعَ لَبَنٍ ‏"‏ ‏.‏\hadithno{1580}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Suwaid bin Ghaflah reported The collector of the Prophet (ﷺ) came to us. I caught hold of his hand and read in the document that the goods were not to be combined nor were they to be separated for fear of zakat. There is no mention of milch animals in this tradition}}
\hadithdefcmd{abudawud}{1581}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا وَكِيعٌ، عَنْ زَكَرِيَّا بْنِ إِسْحَاقَ الْمَكِّيِّ، عَنْ عَمْرِو بْنِ أَبِي سُفْيَانَ الْجُمَحِيِّ، عَنْ مُسْلِمِ بْنِ ثَفِنَةَ الْيَشْكُرِيِّ، - قَالَ الْحَسَنُ رَوْحٌ يَقُولُ مُسْلِمُ بْنُ شُعْبَةَ - قَالَ اسْتَعْمَلَ نَافِعُ بْنُ عَلْقَمَةَ أَبِي عَلَى عِرَافَةِ قَوْمِهِ فَأَمَرَهُ أَنْ يُصَدِّقَهُمْ قَالَ فَبَعَثَنِي أَبِي فِي طَائِفَةٍ مِنْهُمْ فَأَتَيْتُ شَيْخًا كَبِيرًا يُقَالُ لَهُ سَعْرُ بْنُ دَيْسَمٍ فَقُلْتُ إِنَّ أَبِي بَعَثَنِي إِلَيْكَ - يَعْنِي لأُصَدِّقَكَ - قَالَ ابْنَ أَخِي وَأَىَّ نَحْوٍ تَأْخُذُونَ قُلْتُ نَخْتَارُ حَتَّى إِنَّا نَتَبَيَّنُ ضُرُوعَ الْغَنَمِ ‏.‏ قَالَ ابْنَ أَخِي فَإِنِّي أُحَدِّثُكَ أَنِّي كُنْتُ فِي شِعْبٍ مِنْ هَذِهِ الشِّعَابِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَنَمٍ لِي فَجَاءَنِي رَجُلاَنِ عَلَى بَعِيرٍ فَقَالاَ لِي إِنَّا رَسُولاَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَيْكَ لِتُؤَدِّيَ صَدَقَةَ غَنَمِكَ ‏.‏ فَقُلْتُ مَا عَلَىَّ فِيهَا فَقَالاَ شَاةٌ ‏.‏ فَأَعْمِدُ إِلَى شَاةٍ قَدْ عَرَفْتُ مَكَانَهَا مُمْتَلِئَةً مَحْضًا وَشَحْمًا فَأَخْرَجْتُهَا إِلَيْهِمَا ‏.‏ فَقَالاَ هَذِهِ شَاةُ الشَّافِعِ وَقَدْ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَأْخُذَ شَافِعًا ‏.‏ قُلْتُ فَأَىَّ شَىْءٍ تَأْخُذَانِ قَالاَ عَنَاقًا جَذَعَةً أَوْ ثَنِيَّةً ‏.‏ قَالَ فَأَعْمِدُ إِلَى عَنَاقٍ مُعْتَاطٍ ‏.‏ وَالْمُعْتَاطُ الَّتِي لَمْ تَلِدْ وَلَدًا وَقَدْ حَانَ وِلاَدُهَا فَأَخْرَجْتُهَا إِلَيْهِمَا فَقَالاَ نَاوِلْنَاهَا ‏.‏ فَجَعَلاَهَا مَعَهُمَا عَلَى بَعِيرِهِمَا ثُمَّ انْطَلَقَا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَبُو عَاصِمٍ عَنْ زَكَرِيَّاءَ قَالَ أَيْضًا مُسْلِمُ بْنُ شُعْبَةَ ‏.‏ كَمَا قَالَ رَوْحٌ ‏.‏\hadithno{1581}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muslim ibn Shu'bah said:Nafi' ibn Alqamah appointed my father as charge d'affaires of his tribe, and commanded him to collect sadaqah (zakat) from them. My father sent me to a group of them; so I came to an aged man called Sa'r ibn Disam I said: My father has sent me to you to collect zakat from you. He asked: What kind of animals will you take, my nephew? I replied: We shall select the sheep and examine their udders. He said: My nephew, I shall narrate a tradition to you. I lived on one of these steppes during the time of the Messenger of Allah (ﷺ) along with my sheep. Two people riding a camel came to me. They said to me: We are messengers of the Messenger of Allah (ﷺ), sent to you so that you may pay the sadaqah (zakat) on your sheep. I asked: What is due from me for them? They said: One goat. I went to a goat which I knew was full of milk and fat, and I brought it to them. They said: This is a pregnant goat. The Messenger of Allah (ﷺ) prohibited us to accept a pregnant goat. I asked: What will you take then? They said: A goat in its second year or a goat in its third year. I then went to a goat which had not given birth to any kid, but it was going to do so. I brought it to them. They said: Give it to us. They took it on the camel and went away. Abu Dawud said: Abu 'Asim transmitted this tradition from Zakariyya. He said: Muslim bin Shu'bah is a narrator in the chain of this tradition as reported by the narrator Rawh}}
\hadithdefcmd{abudawud}{1582}{حَدَّثَنَا مُحَمَّدُ بْنُ يُونُسَ النَّسَائِيُّ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، بِإِسْنَادِهِ بِهَذَا الْحَدِيثِ قَالَ مُسْلِمُ بْنُ شُعْبَةَ ‏.‏ قَالَ فِيهِ وَالشَّافِعُ الَّتِي فِي بَطْنِهَا الْوَلَدُ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَرَأْتُ فِي كِتَابِ عَبْدِ اللَّهِ بْنِ سَالِمٍ بِحِمْصَ عِنْدَ آلِ عَمْرِو بْنِ الْحَارِثِ الْحِمْصِيِّ عَنِ الزُّبَيْدِيِّ قَالَ وَأَخْبَرَنِي يَحْيَى بْنُ جَابِرٍ عَنْ جُبَيْرِ بْنِ نُفَيْرٍ عَنْ عَبْدِ اللَّهِ بْنِ مُعَاوِيَةَ الْغَاضِرِيِّ - مِنْ غَاضِرَةِ قَيْسٍ - قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ثَلاَثٌ مَنْ فَعَلَهُنَّ فَقَدْ طَعِمَ طَعْمَ الإِيمَانِ مَنْ عَبَدَ اللَّهَ وَحْدَهُ وَأَنَّهُ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَعْطَى زَكَاةَ مَالِهِ طَيِّبَةً بِهَا نَفْسُهُ رَافِدَةً عَلَيْهِ كُلَّ عَامٍ وَلاَ يُعْطِي الْهَرِمَةَ وَلاَ الدَّرِنَةَ وَلاَ الْمَرِيضَةَ وَلاَ الشَّرَطَ اللَّئِيمَةَ وَلَكِنْ مِنْ وَسَطِ أَمْوَالِكُمْ فَإِنَّ اللَّهَ لَمْ يَسْأَلْكُمْ خَيْرَهُ وَلَمْ يَأْمُرْكُمْ بِشَرِّهِ ‏"‏ ‏.‏\hadithno{1582}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{This tradition has also been narrated by Zakariyya bin Ishaq through his chain of narrators. In this version Mulsim bin Shu'bah said:Shafi' means a goat which has a baby in its womb. Abu Dawud said: I read in a document possessed by Abdullah ibn Salim at Hims: Abdullah ibn Mu'awiyah al-Ghadiri reported the Prophet (ﷺ) as saying: He who performs three things will have the taste of the faith. (They are:) One who worships Allah alone and one believes that there is no god but Allah; and one who pays the zakat on his property agreeably every year. One should not give an aged animal, nor one suffering from itch or ailing, and one most condemned, but one should give animals of medium quality, for Allah did not demand from you the best of your animals, nor did He command you to give the animals of worst quality}}
\hadithdefcmd{abudawud}{1583}{حَدَّثَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَعْدِ بْنِ زُرَارَةَ، عَنْ عُمَارَةَ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم مُصَدِّقًا فَمَرَرْتُ بِرَجُلٍ فَلَمَّا جَمَعَ لِي مَالَهُ لَمْ أَجِدْ عَلَيْهِ فِيهِ إِلاَّ ابْنَةَ مَخَاضٍ فَقُلْتُ لَهُ أَدِّ ابْنَةَ مَخَاضٍ فَإِنَّهَا صَدَقَتُكَ ‏.‏ فَقَالَ ذَاكَ مَا لاَ لَبَنَ فِيهِ وَلاَ ظَهْرَ وَلَكِنْ هَذِهِ نَاقَةٌ فَتِيَّةٌ عَظِيمَةٌ سَمِينَةٌ فَخُذْهَا ‏.‏ فَقُلْتُ لَهُ مَا أَنَا بِآخِذٍ مَا لَمْ أُومَرْ بِهِ وَهَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْكَ قَرِيبٌ فَإِنْ أَحْبَبْتَ أَنْ تَأْتِيَهُ فَتَعْرِضَ عَلَيْهِ مَا عَرَضْتَ عَلَىَّ فَافْعَلْ فَإِنْ قَبِلَهُ مِنْكَ قَبِلْتُهُ وَإِنْ رَدَّهُ عَلَيْكَ رَدَدْتُهُ ‏.‏ قَالَ فَإِنِّي فَاعِلٌ فَخَرَجَ مَعِي وَخَرَجَ بِالنَّاقَةِ الَّتِي عَرَضَ عَلَىَّ حَتَّى قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ يَا نَبِيَّ اللَّهِ أَتَانِي رَسُولُكَ لِيَأْخُذَ مِنِّي صَدَقَةَ مَالِي وَايْمُ اللَّهِ مَا قَامَ فِي مَالِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ رَسُولُهُ قَطُّ قَبْلَهُ فَجَمَعْتُ لَهُ مَالِي فَزَعَمَ أَنَّ مَا عَلَىَّ فِيهِ ابْنَةُ مَخَاضٍ وَذَلِكَ مَا لاَ لَبَنَ فِيهِ وَلاَ ظَهْرَ وَقَدْ عَرَضْتُ عَلَيْهِ نَاقَةً فَتِيَّةً عَظِيمَةً لِيَأْخُذَهَا فَأَبَى عَلَىَّ وَهَا هِيَ ذِهِ قَدْ جِئْتُكَ بِهَا يَا رَسُولَ اللَّهِ ‏.‏ خُذْهَا فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ذَاكَ الَّذِي عَلَيْكَ فَإِنْ تَطَوَّعْتَ بِخَيْرٍ آجَرَكَ اللَّهُ فِيهِ وَقَبِلْنَاهُ مِنْكَ ‏"‏ ‏.‏ قَالَ فَهَا هِيَ ذِهِ يَا رَسُولَ اللَّهِ قَدْ جِئْتُكَ بِهَا فَخُذْهَا ‏.‏ قَالَ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَبْضِهَا وَدَعَا لَهُ فِي مَالِهِ بِالْبَرَكَةِ ‏.‏\hadithno{1583}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ubayy ibn Ka'b: The Messenger of Allah (ﷺ) commissioned me as a collector of zakat. I visited a man. When he had collected his property of camels, I found that a she-camel in her second year was due from him. I said to him: Pay a she-camel in her second year, for she is to be paid as sadaqah (zakat) by you. He said: That one is not worthy of milking and riding. Here is another she-camel which is young, grand and fat. So take it. I said to him: I shall not take an animal for which I have not been commanded. The Messenger of Allah (ﷺ) is here near to you. If you like, go to him, and present to him what you presented to me. Do that; if he accepts it from you, I shall accept it; if he rejects it, I shall reject it. He said: I shall do it. He accompanied me and took with him the she-camel which he had presented to me. We came to the Messenger of Allah (ﷺ). He said to him: Prophet of Allah, your messenger came to me to collect zakat on my property. By Allah, neither the Messenger of Allah nor his messenger has ever seen my property before. I gathered my property (camels), and he estimated that a she-camel in her second year would be payable by me. But that has neither milk nor is it worth riding. So I presented to him a grand young she-camel for acceptance as zakat. But he has refused to take her. Look, she is here; I have brought her to you, Messenger of Allah. Take her. The Messenger of Allah (ﷺ) said: That is what is due from you. If you give voluntarily a better (animal) Allah will give a reward to you for it. We accept her from you. She is here, Messenger of Allah; I have brought her to you. So take her. The Messenger of Allah (ﷺ) then ordered me to take possession of it, and he prayed for a blessing on his property}}
\hadithdefcmd{abudawud}{1584}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ الْمَكِّيُّ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيِّ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ مُعَاذًا إِلَى الْيَمَنِ فَقَالَ ‏ "‏ إِنَّكَ تَأْتِي قَوْمًا أَهْلَ كِتَابٍ فَادْعُهُمْ إِلَى شَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ فَإِنْ هُمْ أَطَاعُوكَ لِذَلِكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ افْتَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ فَإِنْ هُمْ أَطَاعُوكَ لِذَلِكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ افْتَرَضَ عَلَيْهِمْ صَدَقَةً فِي أَمْوَالِهِمْ تُؤْخَذُ مِنْ أَغْنِيَائِهِمْ وَتُرَدُّ فِي فُقَرَائِهِمْ فَإِنْ هُمْ أَطَاعُوكَ لِذَلِكَ فَإِيَّاكَ وَكَرَائِمَ أَمْوَالِهِمْ وَاتَّقِ دَعْوَةَ الْمَظْلُومِ فَإِنَّهَا لَيْسَ بَيْنَهَا وَبَيْنَ اللَّهِ حِجَابٌ ‏"‏ ‏.‏\hadithno{1584}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2448) Sahih Muslim (19)}\hadithtrans{Narrated Ibn 'Abbas:said When the Messenger of Allah(ﷺ) sent Mu’adh to Yemen, he said to him You are going to a people who are people of the book. So call them to bear witness that there is no diety but Allah, and that I am the Messenger of Allah. If they obey you in this respect, tell them that Allah has prescribed five prayers on them every day and night. If they obey you in this regard tell them that Allah has prescribed sadaqah(zakat) on their property and returned it to their poor. If they obey you in this respect, do not take the best of their property. Beware of the curse of the oppressed, for there is no curtain between it and Allah}}
\hadithdefcmd{abudawud}{1585}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُعْتَدِي فِي الصَّدَقَةِ كَمَانِعِهَا ‏"‏ ‏.‏\hadithno{1585}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: He who collects more sadaqah than is due is like him who refuses to pay it}}
\hadithdefcmd{abudawud}{1586}{حَدَّثَنَا مَهْدِيُّ بْنُ حَفْصٍ، وَمُحَمَّدُ بْنُ عُبَيْدٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ رَجُلٍ، يُقَالُ لَهُ دَيْسَمٌ - وَقَالَ ابْنُ عُبَيْدٍ مِنْ بَنِي سَدُوسٍ - عَنْ بَشِيرِ بْنِ الْخَصَاصِيَةِ، - قَالَ ابْنُ عُبَيْدٍ فِي حَدِيثِهِ وَمَا كَانَ اسْمُهُ بَشِيرًا - وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَمَّاهُ بَشِيرًا قَالَ قُلْنَا إِنَّ أَهْلَ الصَّدَقَةِ يَعْتَدُونَ عَلَيْنَا أَفَنَكْتُمْ مِنْ أَمْوَالِنَا بِقَدْرِ مَا يَعْتَدُونَ عَلَيْنَا فَقَالَ ‏ "‏ لاَ ‏"‏ ‏.‏\hadithno{1586}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Bashir ibn al-Khasasiyyah: (Ibn Ubayd said in the version of his tradition that his name was not Bashir, but (it was) the Messenger of Allah (ﷺ) (who had) named him Bashir) We said: (to the Messenger of Allah): The collectors of sadaqah collect more than is due; can we hide our property to that proportion? He replied: "No}}
\hadithdefcmd{abudawud}{1587}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَيَحْيَى بْنُ مُوسَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، بِإِسْنَادِهِ وَمَعْنَاهُ إِلاَّ أَنَّهُ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّ أَصْحَابَ الصَّدَقَةِ يَعْتَدُونَ ‏.‏ قَالَ أَبُو دَاوُدَ رَفَعَهُ عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ ‏.‏\hadithno{1587}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition has also been narrated by Ayyub through a different chain of narrators to the same effect. This version adds We said Messenger of Allah(ﷺ) the collectors of sadaqah collect more than is due from us. Abu Dawud said ‘Abd Al Razzaq narrated this tradition from Ma’mar attributing it to the Prophet(ﷺ)}}
\hadithdefcmd{abudawud}{1588}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، عَنْ أَبِي الْغُصْنِ، عَنْ صَخْرِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جَابِرِ بْنِ عَتِيكٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سَيَأْتِيكُمْ رَكْبٌ مُبَغَّضُونَ فَإِذَا جَاءُوكُمْ فَرَحِّبُوا بِهِمْ وَخَلُّوا بَيْنَهُمْ وَبَيْنَ مَا يَبْتَغُونَ فَإِنْ عَدَلُوا فَلأَنْفُسِهِمْ وَإِنْ ظَلَمُوا فَعَلَيْهَا وَأَرْضُوهُمْ فَإِنَّ تَمَامَ زَكَاتِكُمْ رِضَاهُمْ وَلْيَدْعُوا لَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو الْغُصْنِ هُوَ ثَابِتُ بْنُ قَيْسِ بْنِ غُصْنٍ ‏.‏\hadithno{1588}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Atik: The Prophet (ﷺ) said: Riders who are objects of dislike to you will come to you, but you must welcome them when they come to you, and give them a free hand regarding what they desire. If they are just, they will receive credit for it, but if they are unjust, they will be held responsible. Please them, for the perfection of your zakat consists in their good pleasure, and let them ask a blessing for you . Abu Dawud said: The name of the narrator Abu al-Ghusn is Thabit bin Qais bin Ghusn}}
\hadithdefcmd{abudawud}{1589}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ يَعْنِي ابْنَ زِيَادٍ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، - وَهَذَا حَدِيثُ أَبِي كَامِلٍ - عَنْ مُحَمَّدِ بْنِ أَبِي إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ هِلاَلٍ الْعَبْسِيُّ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَ نَاسٌ - يَعْنِي مِنَ الأَعْرَابِ - إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا إِنَّ نَاسًا مِنَ الْمُصَدِّقِينَ يَأْتُونَا فَيَظْلِمُونَا ‏.‏ قَالَ فَقَالَ ‏"‏ أَرْضُوا مُصَدِّقِيكُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَإِنْ ظَلَمُونَا قَالَ ‏"‏ أَرْضُوا مُصَدِّقِيكُمْ ‏"‏ ‏.‏ زَادَ عُثْمَانُ ‏"‏ وَإِنْ ظُلِمْتُمْ ‏"‏ ‏.‏ قَالَ أَبُو كَامِلٍ فِي حَدِيثِهِ قَالَ جَرِيرٌ مَا صَدَرَ عَنِّي مُصَدِّقٌ بَعْدَ مَا سَمِعْتُ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ وَهُوَ عَنِّي رَاضٍ ‏.‏\hadithno{1589}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (989)}\hadithtrans{Jabir bin ‘Abdallah told of some people, meaning nomadic Arabs, who came to the Messenger of Allah (ﷺ) and said Collectors of zakat come to us and act unjustly. He said please those who collect the sadaqah from you. They asked Even if they wrong us, Messenger of Allah? He replied Please those who collect sadaqah from you. The version of ‘Uthman adds “Even if you are wronged”. Abu Kamil said in this version “Jarir said No collector of zakat returned from me since I heard this from the Messenger of Allah(ﷺ), but he was pleased with me.”}}
\hadithdefcmd{abudawud}{1590}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، وَأَبُو الْوَلِيدِ الطَّيَالِسِيُّ، - الْمَعْنَى - قَالاَ أَخْبَرَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ كَانَ أَبِي مِنْ أَصْحَابِ الشَّجَرَةِ وَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَتَاهُ قَوْمٌ بِصَدَقَتِهِمْ قَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ فُلاَنٍ ‏"‏ ‏.‏ قَالَ فَأَتَاهُ أَبِي بِصَدَقَتِهِ فَقَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ أَبِي أَوْفَى ‏"‏ ‏.‏\hadithno{1590}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1497) Sahih Muslim (1078)}\hadithtrans{Narrated ‘Abdallah bin Abi Awfa :My father was one of those Companions who took the oath of allegiance at the hand of the Prophet (ﷺ) beneath the tree. The Prophet (ﷺ) said when the people brought him their sadaqah : O Allah, bless the family of so and so. When my father brought him his sadaqah he said O Allah bless the family of Abu Awfa}}
\hadithdefcmd{abudawud}{1591}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ جَلَبَ وَلاَ جَنَبَ وَلاَ تُؤْخَذُ صَدَقَاتُهُمْ إِلاَّ فِي دُورِهِمْ ‏"‏ ‏.‏\hadithno{1591}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib, on his father's authority, said that his grandfather reported the Prophet (ﷺ) as saying:There is to be no collecting of sadaqah (zakat) from a distance, nor must people who own property remove it far away, and their sadaqahs are to be received in their dwelling}}
\hadithdefcmd{abudawud}{1592}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ سَمِعْتُ أَبِي يَقُولُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، فِي قَوْلِهِ ‏ "‏ لاَ جَلَبَ وَلاَ جَنَبَ ‏"‏ ‏.‏ قَالَ أَنْ تُصَدَّقَ الْمَاشِيَةُ فِي مَوَاضِعِهَا وَلاَ تُجْلَبُ إِلَى الْمُصَدِّقِ وَالْجَنَبُ عَنْ غَيْرِ هَذِهِ الْفَرِيضَةِ أَيْضًا لاَ يُجْنَبُ أَصْحَابُهَا يَقُولُ وَلاَ يَكُونُ الرَّجُلُ بِأَقْصَى مَوَاضِعِ أَصْحَابِ الصَّدَقَةِ فَتُجْنَبُ إِلَيْهِ وَلَكِنْ تُؤْخَذُ فِي مَوْضِعِهِ ‏.‏\hadithno{1592}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Explaining the meaning of Jalab and janab Muhammad bin Ishaq said The meaning of jalab said is that the zakat of animals should be collected at their places (dwellings), and they (animals) should not be pulled to the collector of zakat. The meaning of janab is that the animals are removed at a distance (from the collector). The owners of the animals should do so. The collector of zakat should not stay at a distance from the places of the people who bring their animals to him. The zakat should be collected in its place}}
\hadithdefcmd{abudawud}{1593}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، - رضى الله عنه - حَمَلَ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ فَوَجَدَهُ يُبَاعُ فَأَرَادَ أَنْ يَبْتَاعَهُ فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ لاَ تَبْتَعْهُ وَلاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏ ‏.‏\hadithno{1593}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2636) Sahih Muslim (1620)}\hadithtrans{Narrated ‘Abdallah bin Umar :‘Umar bin Al Khattab gave a horse as alms in the way of Allah. He then found it being sold, and intended to buy it. So he asked the Messenger of Allah (ﷺ) about this. He said Do not buy it, and do not take back your sadaqah}}
\hadithdefcmd{abudawud}{1594}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ يَحْيَى بْنِ فَيَّاضٍ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ رَجُلٍ، عَنْ مَكْحُولٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِي الْخَيْلِ وَالرَّقِيقِ زَكَاةٌ إِلاَّ زَكَاةُ الْفِطْرِ فِي الرَّقِيقِ ‏"‏ ‏.‏\hadithno{1594}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah: The Prophet (ﷺ) said: No sadaqah is due on a horse or a slave except that given at the breaking of the fast (at the end of Ramadan)}}
\hadithdefcmd{abudawud}{1595}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي عَبْدِهِ وَلاَ فِي فَرَسِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{1595}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1463) Sahih Muslim (982)}\hadithtrans{Narrated Abu Hurairah :The Messenger of Allah(ﷺ) as saying No sadaqah is due from a Muslim on his slave or his horse}}
\hadithdefcmd{abudawud}{1596}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدِ بْنِ الْهَيْثَمِ الأَيْلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِيمَا سَقَتِ السَّمَاءُ وَالأَنْهَارُ وَالْعُيُونُ أَوْ كَانَ بَعْلاً الْعُشْرُ وَفِيمَا سُقِيَ بِالسَّوَانِي أَوِ النَّضْحِ نِصْفُ الْعُشْرِ ‏"‏ ‏.‏\hadithno{1596}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1483)}\hadithtrans{Narrated ‘Abdallah bin Umar :The Messenger of Allah(ﷺ) as saying A tenth is payable on what is watered by rain or rivers or brooks or from underground moisture and a twentieth on what is watered by draught camels}}
\hadithdefcmd{abudawud}{1597}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِيمَا سَقَتِ الأَنْهَارُ وَالْعُيُونُ الْعُشْرُ وَمَا سُقِيَ بِالسَّوَانِي فَفِيهِ نِصْفُ الْعُشْرِ ‏"‏ ‏.‏\hadithno{1597}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (981)}\hadithtrans{Narrated Jabir bin ‘Abdallah :The Messenger of Allah(ﷺ) as saying A tenth is payable on what is watered by rivers and brooks or from underground moisture and a twentieth on what is watered by draught camels}}
\hadithdefcmd{abudawud}{1598}{حَدَّثَنَا الْهَيْثَمُ بْنُ خَالِدٍ الْجُهَنِيُّ، وَحُسَيْنُ بْنُ الأَسْوَدِ الْعِجْلِيُّ، قَالاَ قَالَ وَكِيعٌ الْبَعْلُ الْكَبُوسُ الَّذِي يَنْبُتُ مِنْ مَاءِ السَّمَاءِ ‏.‏ قَالَ ابْنُ الأَسْوَدِ وَقَالَ يَحْيَى يَعْنِي ابْنَ آدَمَ سَأَلْتُ أَبَا إِيَاسٍ الأَسَدِيَّ عَنِ الْبَعْلِ فَقَالَ الَّذِي يُسْقَى بِمَاءِ السَّمَاءِ ‏.‏ وَقَالَ النَّضْرُ بْنُ شُمَيْلٍ الْبَعْلُ مَاءُ الْمَطَرِ ‏.‏\hadithno{1598}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Waki’ said Ba’l means the agricultural crop which grows by the rain water. Ibn Al Aswad said and Yahya, that is, Ibn Adam said I asked Abu Iyas al Asadi (about this word ba’l). He replied What is watered by rain}}
\hadithdefcmd{abudawud}{1599}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ سُلَيْمَانَ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَهُ إِلَى الْيَمَنِ فَقَالَ ‏ "‏ خُذِ الْحَبَّ مِنَ الْحَبِّ وَالشَّاةَ مِنَ الْغَنَمِ وَالْبَعِيرَ مِنَ الإِبِلِ وَالْبَقَرَةَ مِنَ الْبَقَرِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ شَبَّرْتُ قِثَّاءَةً بِمِصْرَ ثَلاَثَةَ عَشَرَ شِبْرًا وَرَأَيْتُ أُتْرُجَّةً عَلَى بَعِيرٍ بِقِطْعَتَيْنِ قُطِعَتْ وَصُيِّرَتْ عَلَى مِثْلِ عِدْلَيْنِ ‏.‏\hadithno{1599}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: When the Messenger of Allah (ﷺ) sent him to the Yemen, he said (to him): Collect corn from the corn, sheep from the sheep, camel from the camels, and cow from the cows. Abu Dawud said: In Egypt I saw a cucumber thirteen spans in length and a citron cut into two pieces loaded on a camel like two loads}}
\hadithdefcmd{abudawud}{1600}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، عَنْ عَمْرِو بْنِ الْحَارِثِ الْمِصْرِيِّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ هِلاَلٌ - أَحَدُ بَنِي مُتْعَانَ - إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِعُشُورِ نَحْلٍ لَهُ وَكَانَ سَأَلَهُ أَنْ يَحْمِيَ لَهُ وَادِيًا يُقَالُ لَهُ سَلَبَةُ فَحَمَى لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَلِكَ الْوَادِي فَلَمَّا وُلِّيَ عُمَرُ بْنُ الْخَطَّابِ - رضى الله عنه - كَتَبَ سُفْيَانُ بْنُ وَهْبٍ إِلَى عُمَرَ بْنِ الْخَطَّابِ يَسْأَلُهُ عَنْ ذَلِكَ فَكَتَبَ عُمَرُ رضى الله عنه إِنْ أَدَّى إِلَيْكَ مَا كَانَ يُؤَدِّي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ عُشُورِ نَحْلِهِ لَهُ فَاحْمِ لَهُ سَلَبَةَ وَإِلاَّ فَإِنَّمَا هُوَ ذُبَابُ غَيْثٍ يَأْكُلُهُ مَنْ يَشَاءُ ‏.‏\hadithno{1600}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib, on his father's authority, said that his grandfather reported:Hilal, a man from the tribe of Banu Mat'an brought a tenth of honey which he possessed in beehives to the Messenger of Allah (ﷺ). He asked him (the apostle of Allah) to give the wood known as Salabah as a protected (or restricted) land. The Messenger of Allah (ﷺ) gave him that wood as a protected land. When Umar ibn al-Khattab succeeded, Sufyan ibn Wahb wrote to Umar asking him about this wood. Umar ibn al-Khattab wrote to him: If he (Hilal) pays you the tithe on honey what he used to pay to the Messenger of Allah (ﷺ), leave the protected land of Salabah in his possession; otherwise those bees are like those of any wood; anyone can take the honey as he likes}}
\hadithdefcmd{abudawud}{1601}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا الْمُغِيرَةُ، - وَنَسَبَهُ إِلَى عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ الْمَخْزُومِيِّ - قَالَ حَدَّثَنِي أَبِي، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ شَبَابَةَ، - بَطْنٌ مِنْ فَهْمٍ - فَذَكَرَ نَحْوَهُ قَالَ مِنْ كُلِّ عَشْرِ قِرَبٍ قِرْبَةٌ وَقَالَ سُفْيَانُ بْنُ عَبْدِ اللَّهِ الثَّقَفِيُّ قَالَ وَكَانَ يُحَمِّي لَهُمْ وَادِيَيْنِ زَادَ فَأَدَّوْا إِلَيْهِ مَا كَانُوا يُؤَدُّونَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَحَمَّى لَهُمْ وَادِيَيْهِمْ ‏.‏\hadithno{1601}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib, on his father's authority, said that his grandfather reported:That was Banu Shababah, a sub-clan of the tribe Fahm. The narrator then transmitted the tradition something similar. He added:(They used to pay) one bag (of honey) out of ten bags. Sufyan ibn Abdullah ath-Thaqafi gave them two woods as protected lands. They used to give as much honey (as zakat) as they gave to the Messenger of Allah (ﷺ). He (Sufyan) used to protect their woods}}
\hadithdefcmd{abudawud}{1602}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ الْمُؤَذِّنُ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ بَطْنًا، مِنْ فَهْمٍ بِمَعْنَى الْمُغِيرَةِ قَالَ مِنْ عَشْرِ قِرَبٍ قِرْبَةٌ ‏.‏ وَقَالَ وَادِيَيْنِ لَهُمْ ‏.‏\hadithno{1602}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Amr bin Shu’aib said on the authority of his father that his grandfather reported a sub clan of Fahm. He then narrated the tradition like that of the narrator Al Mughirah. This version has “(They used to give) sadaqah out of ten bags (of honey).” He also added “Two woods of theirs”}}
\hadithdefcmd{abudawud}{1603}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ السَّرِيِّ النَّاقِطُ، حَدَّثَنَا بِشْرُ بْنُ مَنْصُورٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَتَّابِ بْنِ أَسِيدٍ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُخْرَصَ الْعِنَبُ كَمَا يُخْرَصُ النَّخْلُ وَتُؤْخَذُ زَكَاتُهُ زَبِيبًا كَمَا تُؤْخَذُ زَكَاةُ النَّخْلِ تَمْرًا ‏.‏\hadithno{1603}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Attab ibn Usayd: The Messenger of Allah (ﷺ) commanded to estimate vines (for collecting zakat) as palm-trees are estimated. The zakat is to be paid in raisins as the zakat on palm trees is paid in dried dates}}
\hadithdefcmd{abudawud}{1604}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنْ مُحَمَّدِ بْنِ صَالِحٍ التَّمَّارِ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَسَعِيدٌ لَمْ يَسْمَعْ مِنْ عَتَّابٍ شَيْئًا ‏.‏\hadithno{1604}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The Above-mentioned tradition has also been narrated by Ibn Shihab through a different chain of narrators to the same effects}}
\hadithdefcmd{abudawud}{1605}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَسْعُودٍ، قَالَ جَاءَ سَهْلُ بْنُ أَبِي حَثْمَةَ إِلَى مَجْلِسِنَا قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا خَرَصْتُمْ فَخُذُوا وَدَعُوا الثُّلُثَ فَإِنْ لَمْ تَدَعُوا أَوْ تَجِدُوا الثُّلُثَ فَدَعُوا الرُّبُعَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْخَارِصُ يَدَعُ الثُّلُثَ لِلْحِرْفَةِ ‏.‏\hadithno{1605}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{AbdurRahman ibn Mas'ud said:Sahl ibn Abu Hathmah came to our gathering. He said: The Messenger of Allah (ﷺ) commanding us said: When you estimate take them leaving a third, and if you do not leave or find a third, leave a quarter}}
\hadithdefcmd{abudawud}{1606}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أُخْبِرْتُ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ وَهِيَ تَذْكُرُ شَأْنَ خَيْبَرَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَبْعَثُ عَبْدَ اللَّهِ بْنَ رَوَاحَةَ إِلَى يَهُودِ خَيْبَرَ فَيَخْرِصُ النَّخْلَ حِينَ يَطِيبُ قَبْلَ أَنْ يُؤْكَلَ مِنْهُ ‏.‏\hadithno{1606}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Describing the conquest of Khaybar Aisha said: The Prophet (ﷺ) used to send Abdullah ibn Rawahah to the Jews of Khaybar, and he would make an estimate of the palm trees when the fruit was in good condition before any of it was eaten}}
\hadithdefcmd{abudawud}{1607}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبَّادٌ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، عَنْ أَبِيهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْجُعْرُورِ وَلَوْنِ الْحُبَيْقِ أَنْ يُؤْخَذَا فِي الصَّدَقَةِ ‏.‏ قَالَ الزُّهْرِيُّ لَوْنَيْنِ مِنْ تَمْرِ الْمَدِينَةِ ‏.‏ قَالَ أَبُو دَاوُدَ وَأَسْنَدَهُ أَيْضًا أَبُو الْوَلِيدِ عَنْ سُلَيْمَانَ بْنِ كَثِيرٍ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{1607}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Umamah bin Sahl reported on the authority of his father:The Messenger of Allah (ﷺ) prohibited to accept ja'rur and habiq dates as zakat. Az-Zuhri said: These are two kinds of the dates of Medina. Abu Dawud said: This has also been transmited by Abu al-Walid from Sulaiman bin Kathir from Az-Zuhri}}
\hadithdefcmd{abudawud}{1608}{حَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ الأَنْطَاكِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي الْقَطَّانَ - عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، حَدَّثَنِي صَالِحُ بْنُ أَبِي عَرِيبٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ، عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْجِدَ وَبِيَدِهِ عَصًا وَقَدْ عَلَّقَ رَجُلٌ مِنَّا قِنًا حَشَفًا فَطَعَنَ بِالْعَصَا فِي ذَلِكَ الْقِنْوِ وَقَالَ ‏"‏ لَوْ شَاءَ رَبُّ هَذِهِ الصَّدَقَةِ تَصَدَّقَ بِأَطْيَبَ مِنْهَا ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِنَّ رَبَّ هَذِهِ الصَّدَقَةِ يَأْكُلُ الْحَشَفَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1608}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Awf ibn Malik: The Messenger of Allah (ﷺ) entered upon us in the mosque, and he had a stick in his hand. A man hung there a bunch of hashaf. He struck the bunch with the stick, and said: If the owner of this sadaqah (alms) wishes to give a better one than it, he would give. The owner of this sadaqah will eat hashaf on the Day of Judgment}}
\hadithdefcmd{abudawud}{1609}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ السَّمَرْقَنْدِيُّ، قَالاَ حَدَّثَنَا مَرْوَانُ، قَالَ عَبْدُ اللَّهِ حَدَّثَنَا أَبُو يَزِيدَ الْخَوْلاَنِيُّ، - وَكَانَ شَيْخَ صِدْقٍ وَكَانَ ابْنُ وَهْبٍ يَرْوِي عَنْهُ - حَدَّثَنَا سَيَّارُ بْنُ عَبْدِ الرَّحْمَنِ، - قَالَ مَحْمُودٌ الصَّدَفِيُّ - عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ الْفِطْرِ طُهْرَةً لِلصَّائِمِ مِنَ اللَّغْوِ وَالرَّفَثِ وَطُعْمَةً لِلْمَسَاكِينِ مَنْ أَدَّاهَا قَبْلَ الصَّلاَةِ فَهِيَ زَكَاةٌ مَقْبُولَةٌ وَمَنْ أَدَّاهَا بَعْدَ الصَّلاَةِ فَهِيَ صَدَقَةٌ مِنَ الصَّدَقَاتِ ‏.‏\hadithno{1609}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) prescribed the sadaqah (alms) relating to the breaking of the fast as a purification of the fasting from empty and obscene talk and as food for the poor. If anyone pays it before the prayer (of 'Id), it will be accepted as zakat. If anyone pays it after the prayer, that will be a sadaqah like other sadaqahs (alms)}}
\hadithdefcmd{abudawud}{1610}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِزَكَاةِ الْفِطْرِ أَنْ تُؤَدَّى قَبْلَ خُرُوجِ النَّاسِ إِلَى الصَّلاَةِ ‏.‏ قَالَ فَكَانَ ابْنُ عُمَرَ يُؤَدِّيهَا قَبْلَ ذَلِكَ بِالْيَوْمِ وَالْيَوْمَيْنِ ‏.‏\hadithno{1610}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1509) Sahih Muslim (986)}\hadithtrans{Ibn ‘Umar said :The Messenger of Allah(ﷺ) commanded us that the end of Ramadan when the fasting is closed sadaqah(alms) should be paid before the people went to prayer. ‘Abd Allah b. ‘Umar used to pay it one or two days before}}
\hadithdefcmd{abudawud}{1611}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، - وَقَرَأَهُ عَلَى مَالِكٍ أَيْضًا - عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَضَ زَكَاةَ الْفِطْرِ - قَالَ فِيهِ فِيمَا قَرَأَهُ عَلَىَّ مَالِكٌ - زَكَاةُ الْفِطْرِ مِنْ رَمَضَانَ صَاعٌ مِنْ تَمْرٍ أَوْ صَاعٌ مِنْ شَعِيرٍ عَلَى كُلِّ حُرٍّ أَوْ عَبْدٍ ذَكَرٍ أَوْ أُنْثَى مِنَ الْمُسْلِمِينَ ‏.‏\hadithno{1611}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1504) Sahih Muslim (984)}\hadithtrans{Ibn ‘Umar said :The Messenger of Allah(ﷺ) prescribed as zakat payable by slave and freeman, male and female, among the muslims on closing the fast of Ramadan one sa of dried dates or one sa’ of barley. (This tradition was read out byu ‘Abd Allah b. Maslamah to Malik)}}
\hadithdefcmd{abudawud}{1612}{حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدِ بْنِ السَّكَنِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَهْضَمٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عُمَرَ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ الْفِطْرِ صَاعًا فَذَكَرَ بِمَعْنَى مَالِكٍ زَادَ وَالصَّغِيرِ وَالْكَبِيرِ وَأَمَرَ بِهَا أَنْ تُؤَدَّى قَبْلَ خُرُوجِ النَّاسِ إِلَى الصَّلاَةِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَبْدُ اللَّهِ الْعُمَرِيُّ عَنْ نَافِعٍ بِإِسْنَادِهِ قَالَ عَلَى كُلِّ مُسْلِمٍ وَرَوَاهُ سَعِيدٌ الْجُمَحِيُّ عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ قَالَ فِيهِ مِنَ الْمُسْلِمِينَ وَالْمَشْهُورُ عَنْ عُبَيْدِ اللَّهِ لَيْسَ فِيهِ مِنَ الْمُسْلِمِينَ ‏.‏\hadithno{1612}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1503) Sahih Muslim (984)}\hadithtrans{Abd’ Allah b. Umar said :The Messenger of Allah(ﷺ)prescribed the sadaqah at the end of Ramadan one sa’. The narrator then transmitted the tradition like the one narrated by Malik. This version adds : “Young and old. He gave command that this should be paid before the people went out to prayers.” Abu Dawud said : ‘Abd Allah al-‘Umari narrated it from Nafi’ through his chain : “on every Muslim.” The version of Sa’id al-Jumahi has : “Among the Muslims.” The well-known version transmitted by ‘Ubaid Allah does not mention the words “among the Muslims”}}
\hadithdefcmd{abudawud}{1613}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ يَحْيَى بْنَ سَعِيدٍ، وَبِشْرَ بْنَ الْمُفَضَّلِ، حَدَّثَاهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ فَرَضَ صَدَقَةَ الْفِطْرِ صَاعًا مِنْ شَعِيرٍ أَوْ تَمْرٍ عَلَى الصَّغِيرِ وَالْكَبِيرِ وَالْحُرِّ وَالْمَمْلُوكِ زَادَ مُوسَى وَالذَّكَرِ وَالأُنْثَى ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ فِيهِ أَيُّوبُ وَعَبْدُ اللَّهِ - يَعْنِي الْعُمَرِيَّ - فِي حَدِيثِهِمَا عَنْ نَافِعٍ ذَكَرٍ أَوْ أُنْثَى ‏.‏ أَيْضًا ‏.‏\hadithno{1613}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn ‘Umar said :The Messenger of Allah(ﷺ) prescribed sadaqah at the end of Ramadan one sa’ of barley and dried dates, payable by young and old freeman and slave. The version of Musa adds : “ male and female”. Abu Dawud said : the words “male and female” narrated, by Ayyub and ‘Abd Allah al Umar were narrated in their version on the authority of Nafi’}}
\hadithdefcmd{abudawud}{1614}{حَدَّثَنَا الْهَيْثَمُ بْنُ خَالِدٍ الْجُهَنِيُّ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كَانَ النَّاسُ يُخْرِجُونَ صَدَقَةَ الْفِطْرِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم صَاعًا مِنْ شَعِيرٍ أَوْ تَمْرٍ أَوْ سُلْتٍ أَوْ زَبِيبٍ ‏.‏ قَالَ قَالَ عَبْدُ اللَّهِ فَلَمَّا كَانَ عُمَرُ - رضى الله عنه - وَكَثُرَتِ الْحِنْطَةُ جَعَلَ عُمَرُ نِصْفَ صَاعِ حِنْطَةٍ مَكَانَ صَاعٍ مِنْ تِلْكَ الأَشْيَاءِ ‏.‏\hadithno{1614}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The people during the lifetime of the Messenger of Allah (ﷺ) used to bring forth the sadaqah at the end of Ramadan when closing the fast one sa' of barley whose straw is removed, or of raisins. Abdullah said: When Umar (Allah be pleased with him) succeeded, and the wheat became abundant, Umar prescribed half a sa' of wheat instead of all these things}}
\hadithdefcmd{abudawud}{1615}{حَدَّثَنَا مُسَدَّدٌ، وَسُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، قَالَ قَالَ عَبْدُ اللَّهِ فَعَدَلَ النَّاسُ بَعْدُ نِصْفَ صَاعٍ مِنْ بُرٍّ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ يُعْطِي التَّمْرَ فَأَعْوَزَ أَهْلَ الْمَدِينَةِ التَّمْرُ عَامًا فَأَعْطَى الشَّعِيرَ ‏.‏\hadithno{1615}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1511) Sahih Muslim (984)}\hadithtrans{Abd’ Allah(b. 'Umar) said “The people then began to pay half a sa’ of wheat later on. The narrator said :'Abd Allah (b. Umar) use to pay dried dates as sadaqah one year the people of Medina lacked dried dates, hence he paid barley}}
\hadithdefcmd{abudawud}{1616}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا دَاوُدُ، - يَعْنِي ابْنَ قَيْسٍ - عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نُخْرِجُ إِذْ كَانَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ الْفِطْرِ عَنْ كُلِّ صَغِيرٍ وَكَبِيرٍ حُرٍّ أَوْ مَمْلُوكٍ صَاعًا مِنْ طَعَامٍ أَوْ صَاعًا مِنْ أَقِطٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ زَبِيبٍ فَلَمْ نَزَلْ نُخْرِجُهُ حَتَّى قَدِمَ مُعَاوِيَةُ حَاجًّا أَوْ مُعْتَمِرًا فَكَلَّمَ النَّاسَ عَلَى الْمِنْبَرِ فَكَانَ فِيمَا كَلَّمَ بِهِ النَّاسَ أَنْ قَالَ إِنِّي أَرَى أَنَّ مُدَّيْنِ مِنْ سَمْرَاءِ الشَّامِ تَعْدِلُ صَاعًا مِنْ تَمْرٍ فَأَخَذَ النَّاسُ بِذَلِكَ ‏.‏ فَقَالَ أَبُو سَعِيدٍ فَأَمَّا أَنَا فَلاَ أَزَالُ أُخْرِجُهُ أَبَدًا مَا عِشْتُ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ عُلَيَّةَ وَعَبْدَةُ وَغَيْرُهُمَا عَنِ ابْنِ إِسْحَاقَ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ حَكِيمِ بْنِ حِزَامٍ عَنْ عِيَاضٍ عَنْ أَبِي سَعِيدٍ بِمَعْنَاهُ وَذَكَرَ رَجُلٌ وَاحِدٌ فِيهِ عَنِ ابْنِ عُلَيَّةَ أَوْ صَاعَ حِنْطَةٍ ‏.‏ وَلَيْسَ بِمَحْفُوظٍ ‏.‏\hadithno{1616}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1505) Sahih Muslim (985)}\hadithtrans{Abu sa’id al-khudri said :When the Messenger of Allah(May peace be upon him) lived among us, we use to bring forth zakat, on closing the fast of Ramadan one sa’ of grain or of cheese, or of barley, or of dried dates, or of raisens, payable by every young and old freeman and slave. We continued to pay this till mu-awayah came to perform Haj or Umra and he spoke to the people on the pulpit. What he said to the people was : I think that Mudds of the wheat of syrria is equivalent to one sa’ of dried dates. So the people adopted it. Abu sa’id said : But I continued to pay one sa’ of wheat as long as I lived on. Abu Dawud said : this tradition has also been transmitted by Abu sa’id through a different chain of narrators to the same effect. A man has narrated in this version from Ibn-Ulayyah one sa’ of wheat. But this version is not guarded}}
\hadithdefcmd{abudawud}{1617}{حَدَّثَنَا مُسَدَّدٌ، أَخْبَرَنَا إِسْمَاعِيلُ، لَيْسَ فِيهِ ذِكْرُ الْحِنْطَةِ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَدْ ذَكَرَ مُعَاوِيَةُ بْنُ هِشَامٍ فِي هَذَا الْحَدِيثِ عَنِ الثَّوْرِيِّ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عِيَاضٍ، عَنْ أَبِي سَعِيدٍ، ‏ "‏ نِصْفَ صَاعٍ مِنْ بُرٍّ ‏"‏ ‏.‏ وَهُوَ وَهَمٌ مِنْ مُعَاوِيَةَ بْنِ هِشَامٍ أَوْ مِمَّنْ رَوَاهُ عَنْهُ ‏.‏\hadithno{1617}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition has also been transmitted by Abu Sa’id through a different chain of narrators. This version adds :“Half a sa’ of wheat “. But this is a misunderstanding on the part of muawayah b. Hisham and of those who narrated from him}}
\hadithdefcmd{abudawud}{1618}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى، أَخْبَرَنَا سُفْيَانُ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، سَمِعَ عِيَاضًا، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ لاَ أُخْرِجُ أَبَدًا إِلاَّ صَاعًا إِنَّا كُنَّا نُخْرِجُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم صَاعَ تَمْرٍ أَوْ شَعِيرٍ أَوْ أَقِطٍ أَوْ زَبِيبٍ هَذَا حَدِيثُ يَحْيَى زَادَ سُفْيَانُ أَوْ صَاعًا مِنْ دَقِيقٍ قَالَ حَامِدٌ فَأَنْكَرُوا عَلَيْهِ فَتَرَكَهُ سُفْيَانُ ‏.‏ قَالَ أَبُو دَاوُدَ فَهَذِهِ الزِّيَادَةُ وَهَمٌ مِنِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{1618}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'id al-Khudri: I shall always pay one sa'. We used to pay during the lifetime of the Messenger of Allah (ﷺ) one sa' of dried dates or of barley, or of cheese, or of raisins. This is the version of Yahya. Sufyan added in his version: "or one sa' of flour." The narrator Hamid (ibn Yahya) said: The people objected to this (addition); Sufyan then left it. Abu Dawud said: This addition is a misunderstanding on the part of Ibn Uyainah}}
\hadithdefcmd{abudawud}{1619}{حَدَّثَنَا مُسَدَّدٌ، وَسُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ النُّعْمَانِ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، - قَالَ مُسَدَّدٌ عَنْ ثَعْلَبَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي صُعَيْرٍ، - عَنْ أَبِيهِ، - وَقَالَ سُلَيْمَانُ بْنُ دَاوُدَ عَبْدُ اللَّهِ بْنُ ثَعْلَبَةَ أَوْ ثَعْلَبَةُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي صُعَيْرٍ عَنْ أَبِيهِ، - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَاعٌ مِنْ بُرٍّ أَوْ قَمْحٍ عَلَى كُلِّ اثْنَيْنِ صَغِيرٍ أَوْ كَبِيرٍ حُرٍّ أَوْ عَبْدٍ ذَكَرٍ أَوْ أُنْثَى أَمَّا غَنِيُّكُمْ فَيُزَكِّيهِ اللَّهُ وَأَمَّا فَقِيرُكُمْ فَيَرُدُّ اللَّهُ عَلَيْهِ أَكْثَرَ مِمَّا أَعْطَاهُ ‏"‏ ‏.‏ زَادَ سُلَيْمَانُ فِي حَدِيثِهِ غَنِيٍّ أَوْ فَقِيرٍ ‏.‏\hadithno{1619}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abd Allah b. Tha'labah or Tha'labah bin 'Abd Allah bin Abu Su'air reported on his father's authority that the Messenger of Allah (ﷺ) said:One sa' of wheat is to be taken from every two, young or old, freeman or slave, male or female. Those of you who are rich will be purified by Allah, and those of you who are poor will have more than they gave returned by Him to them. Sulayman added in his version: "rich or poor}}
\hadithdefcmd{abudawud}{1620}{حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ الدَّرَابَجِرْدِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا بَكْرٌ، - هُوَ ابْنُ وَائِلٍ - عَنِ الزُّهْرِيِّ، عَنْ ثَعْلَبَةَ بْنِ عَبْدِ اللَّهِ، أَوْ قَالَ عَبْدِ اللَّهِ بْنِ ثَعْلَبَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ بَكْرٍ الْكُوفِيِّ، قَالَ مُحَمَّدُ بْنُ يَحْيَى هُوَ بَكْرُ بْنُ وَائِلِ بْنِ دَاوُدَ أَنَّ الزُّهْرِيَّ، حَدَّثَهُمْ عَنْ عَبْدِ اللَّهِ بْنِ ثَعْلَبَةَ بْنِ صُعَيْرٍ، عَنْ أَبِيهِ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَطِيبًا فَأَمَرَ بِصَدَقَةِ الْفِطْرِ صَاعِ تَمْرٍ أَوْ صَاعِ شَعِيرٍ عَنْ كُلِّ رَأْسٍ زَادَ عَلِيٌّ فِي حَدِيثِهِ أَوْ صَاعِ بُرٍّ أَوْ قَمْحٍ بَيْنَ اثْنَيْنِ - ثُمَّ اتَّفَقَا - عَنِ الصَّغِيرِ وَالْكَبِيرِ وَالْحُرِّ وَالْعَبْدِ ‏.‏\hadithno{1620}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abd Allah bin Tha'labah ibn Su'ayr reported on the authority of his father:The Messenger of Allah (ﷺ) stood and gave a sermon; he commanded to give sadaqah, at the end of Ramadan when the fasting is closed, one sa' of dried dates or of barley payable by every person. The narrator Ali added in his version: "or one sa' of wheat to be taken from every two." Both the chains of narrators are then agreed upon the version: "payable by young and old, freeman and slave}}
\hadithdefcmd{abudawud}{1621}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ وَقَالَ ابْنُ شِهَابٍ قَالَ عَبْدُ اللَّهِ بْنُ ثَعْلَبَةَ قَالَ ابْنُ صَالِحٍ قَالَ الْعَدَوِيُّ وَإِنَّمَا هُوَ الْعُذْرِيُّ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ قَبْلَ الْفِطْرِ بِيَوْمَيْنِ بِمَعْنَى حَدِيثِ الْمُقْرِئِ ‏.‏\hadithno{1621}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abd Allah b. Tha’labah said (the narrator Ahmad b. salih said :He, i.e “Abd al-Razzaq, said : He is ‘Adawl. Abu Dawud said : Ahmed b. Salih said : He is ‘Adhri): The Messenger of Allah (May peace be upon him) delivered a speech before the closing fast (‘Id) by two days. He then transmitted the tradition like that of al Muqri (‘Abd Allah b. Yazid)}}
\hadithdefcmd{abudawud}{1622}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سَهْلُ بْنُ يُوسُفَ، قَالَ حُمَيْدٌ أَخْبَرَنَا عَنِ الْحَسَنِ، قَالَ خَطَبَ ابْنُ عَبَّاسٍ رَحِمَهُ اللَّهُ فِي آخِرِ رَمَضَانَ عَلَى مِنْبَرِ الْبَصْرَةِ فَقَالَ أَخْرِجُوا صَدَقَةَ صَوْمِكُمْ فَكَأَنَّ النَّاسَ لَمْ يَعْلَمُوا فَقَالَ مَنْ هَا هُنَا مِنْ أَهْلِ الْمَدِينَةِ قُومُوا إِلَى إِخْوَانِكُمْ فَعَلِّمُوهُمْ فَإِنَّهُمْ لاَ يَعْلَمُونَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَذِهِ الصَّدَقَةَ صَاعًا مِنْ تَمْرٍ أَوْ شَعِيرٍ أَوْ نِصْفَ صَاعٍ مِنْ قَمْحٍ عَلَى كُلِّ حُرٍّ أَوْ مَمْلُوكٍ ذَكَرٍ أَوْ أُنْثَى صَغِيرٍ أَوْ كَبِيرٍ فَلَمَّا قَدِمَ عَلِيٌّ - رضى الله عنه - رَأَى رُخْصَ السِّعْرِ قَالَ قَدْ أَوْسَعَ اللَّهُ عَلَيْكُمْ فَلَوْ جَعَلْتُمُوهُ صَاعًا مِنْ كُلِّ شَىْءٍ ‏.‏ قَالَ حُمَيْدٌ وَكَانَ الْحَسَنُ يَرَى صَدَقَةَ رَمَضَانَ عَلَى مَنْ صَامَ ‏.‏\hadithno{1622}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Hasan said:Ibn Abbas preached towards the end of Ramadan on the pulpit (in the mosque) of al-Basrah. He said: Bring forth the sadaqah relating to your fast. The people, as it were, could not understand. Which of the people of Medina are present here? Stand for your brethren, and teach them, for they do not know. The Messenger of Allah (ﷺ) prescribed this sadaqah as one sa' of dried dates or barley, or half a sa' of wheat payable by every freeman or slave, male or female, young or old. When Ali came (to Basrah), he found that price had come down. He said: Allah has given prosperity to you, so give one sa' of everything (as sadaqah). The narrator Humayd said: Al-Hasan maintained that the sadaqah at the end of Ramadan was due on a person who fasted}}
\hadithdefcmd{abudawud}{1623}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، حَدَّثَنَا شَبَابَةُ، عَنْ وَرْقَاءَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم عُمَرَ بْنَ الْخَطَّابِ عَلَى الصَّدَقَةِ فَمَنَعَ ابْنُ جَمِيلٍ وَخَالِدُ بْنُ الْوَلِيدِ وَالْعَبَّاسُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا يَنْقِمُ ابْنُ جَمِيلٍ إِلاَّ أَنْ كَانَ فَقِيرًا فَأَغْنَاهُ اللَّهُ وَأَمَّا خَالِدُ بْنُ الْوَلِيدِ فَإِنَّكُمْ تَظْلِمُونَ خَالِدًا فَقَدِ احْتَبَسَ أَدْرَاعَهُ وَأَعْتُدَهُ فِي سَبِيلِ اللَّهِ وَأَمَّا الْعَبَّاسُ عَمُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهِيَ عَلَىَّ وَمِثْلُهَا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَمَا شَعَرْتَ أَنَّ عَمَّ الرَّجُلِ صِنْوُ الأَبِ ‏"‏ ‏.‏ أَوْ ‏"‏ صِنْوُ أَبِيهِ ‏"‏ ‏.‏\hadithno{1623}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1468) Sahih Muslim (983)}\hadithtrans{Abu Hurairah said :The Prophet(ﷺ) sent Umar b. al-Khattab to collect sadaqa (All the people paid the zakat but ibn-jamil, Khalid b. al-walid and al-abbas refused. So the Messenger of Allah(ﷺ) said : Ibn-jamil is not (so much) objecting, but he was poor and Allah enriched him. As for Khalid b. Walid, you are wronging him, for he has kept back his courts of mail and weapons to use them in Allah’s path. As for al-Abbas, the uncle of the Messenger of Allah(May peace be upon him), I shall be responsible for it and an equal amount along with it. Then he said did you not know(Umar) that a man’s paternal uncle is of the same stock as the father or his father?}}
\hadithdefcmd{abudawud}{1624}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، عَنِ الْحَجَّاجِ بْنِ دِينَارٍ، عَنِ الْحَكَمِ، عَنْ حُجَيَّةَ، عَنْ عَلِيٍّ، أَنَّ الْعَبَّاسَ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم فِي تَعْجِيلِ صَدَقَتِهِ قَبْلَ أَنْ تَحِلَّ فَرَخَّصَ لَهُ فِي ذَلِكَ ‏.‏ قَالَ مَرَّةً فَأَذِنَ لَهُ فِي ذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى هَذَا الْحَدِيثَ هُشَيْمٌ عَنْ مَنْصُورِ بْنِ زَاذَانَ عَنِ الْحَكَمِ عَنِ الْحَسَنِ بْنِ مُسْلِمٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَحَدِيثُ هُشَيْمٍ أَصَحُّ ‏.‏\hadithno{1624}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: Al-Abbas asked the Prophet (ﷺ) about paying the sadaqah (his zakat) in advance before it became due, and he gave permission to do that. Abu Dawud said: This tradition has also been transmitted by Hushaim through a different chain of narrators. The version of Hushaim is more sound}}
\hadithdefcmd{abudawud}{1625}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا أَبِي، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ عَطَاءٍ، مَوْلَى عِمْرَانَ بْنِ حُصَيْنٍ عَنْ أَبِيهِ، أَنَّ زِيَادًا، أَوْ بَعْضَ الأُمَرَاءِ بَعَثَ عِمْرَانَ بْنَ حُصَيْنٍ عَلَى الصَّدَقَةِ فَلَمَّا رَجَعَ قَالَ لِعِمْرَانَ أَيْنَ الْمَالُ قَالَ وَلِلْمَالِ أَرْسَلْتَنِي أَخَذْنَاهَا مِنْ حَيْثُ كُنَّا نَأْخُذُهَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَوَضَعْنَاهَا حَيْثُ كُنَّا نَضَعُهَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1625}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibrahim ibn Ata, the client of Imran ibn Husayn, reported on the authority of his father:Ziyad, or some other governor, sent Imran ibn Husayn to collect sadaqah (i.e. zakat). When he returned, he asked Imran: Where is the property? He replied: Did you send me to bring the property? We collected it from where we used to collect in the lifetime of the Messenger of Allah (ﷺ), and we spent it where we used to spend during the time of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{1626}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ سَأَلَ وَلَهُ مَا يُغْنِيهِ جَاءَتْ يَوْمَ الْقِيَامَةِ خُمُوشٌ - أَوْ خُدُوشٌ - أَوْ كُدُوحٌ - فِي وَجْهِهِ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ وَمَا الْغِنَى قَالَ ‏"‏ خَمْسُونَ دِرْهَمًا أَوْ قِيمَتُهَا مِنَ الذَّهَبِ ‏"‏ ‏.‏ قَالَ يَحْيَى فَقَالَ عَبْدُ اللَّهِ بْنُ عُثْمَانَ لِسُفْيَانَ حِفْظِي أَنَّ شُعْبَةَ لاَ يَرْوِي عَنْ حَكِيمِ بْنِ جُبَيْرٍ فَقَالَ سُفْيَانُ فَقَدْ حَدَّثَنَاهُ زُبَيْدٌ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ ‏.‏\hadithno{1626}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: He who begs (from people) when he is affluent will come on the Day of Resurrection with scrapes, scratchings, or lacerations on his face. He was asked: What constitutes affluence, Messenger of Allah? He replied:It is fifty dirhams or its value in gold. The narrator Yahya said: Abdullah ibn Sufyan said to Sufyan: I remember that Shu'bah does not narrate from Hakim ibn Jubayr. Sufyan said: Zubayr transmitted to us this tradition from Muhammad ibn AbdurRahman ibn Yazid}}
\hadithdefcmd{abudawud}{1627}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رَجُلٍ، مِنْ بَنِي أَسَدٍ أَنَّهُ قَالَ نَزَلْتُ أَنَا وَأَهْلِي، بِبَقِيعِ الْغَرْقَدِ فَقَالَ لِي أَهْلِي اذْهَبْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَلْهُ لَنَا شَيْئًا نَأْكُلُهُ فَجَعَلُوا يَذْكُرُونَ مِنْ حَاجَتِهِمْ فَذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَجَدْتُ عِنْدَهُ رَجُلاً يَسْأَلُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ أَجِدُ مَا أُعْطِيكَ ‏"‏ ‏.‏ فَتَوَلَّى الرَّجُلُ عَنْهُ وَهُوَ مُغْضَبٌ وَهُوَ يَقُولُ لَعَمْرِي إِنَّكَ لَتُعْطِي مَنْ شِئْتَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَغْضَبُ عَلَىَّ أَنْ لاَ أَجِدَ مَا أُعْطِيهِ مَنْ سَأَلَ مِنْكُمْ وَلَهُ أُوقِيَّةٌ أَوْ عَدْلُهَا فَقَدْ سَأَلَ إِلْحَافًا ‏"‏ ‏.‏ قَالَ الأَسَدِيُّ فَقُلْتُ لَلَقِحَةٌ لَنَا خَيْرٌ مِنْ أُوقِيَّةٍ وَالأُوقِيَّةُ أَرْبَعُونَ دِرْهَمًا ‏.‏ قَالَ فَرَجَعْتُ وَلَمْ أَسْأَلْهُ فَقَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ شَعِيرٌ أَوْ زَبِيبٌ فَقَسَمَ لَنَا مِنْهُ - أَوْ كَمَا قَالَ - حَتَّى أَغْنَانَا اللَّهُ ‏.‏ قَالَ أَبُو دَاوُدَ هَكَذَا رَوَاهُ الثَّوْرِيُّ كَمَا قَالَ مَالِكٌ ‏.‏\hadithno{1627}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Ata’ b. Yasar said :A man from Banu Asad said : I and my family alighted at Baqi al-Gharqad. My wife said to me : Go the Messenger of Allah(ﷺ) and beg something from him for our eating, and made a mention of there need. So I went to the Messenger of Allah(May peace be upon him). I found with a man who was begging from him and he was saying to him: I have nothing to give you. The man turned away from him in anger while he was saying: By my life, you give anyone you wish. The Messenger of Allah(May peace be upon him) said : He’s anger with me, for I have nothing to give him. If any of you begs when he has an Uqiyah or its equivalent, he has begged immoderately. The man of Banu Asad said : So I said : The she camel of ours is better than an uqiyah, while an uqiyah is equivalent to 40 Dirhams. I therefore returned and did not beg from him. Afterwards some barley and raisins where brought to the Messenger of Allah (May peace be upon him). He gave us a share from them (or as he reported)till Allah, the Exalted, made us self-sufficient(i.e well off). Abu Dawud said: Al-Thawri narrated it as Malik narrated}}
\hadithdefcmd{abudawud}{1628}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الرِّجَالِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ‏ "‏ مَنْ سَأَلَ وَلَهُ قِيمَةُ أُوقِيَّةٍ فَقَدْ أَلْحَفَ ‏"‏ ‏.‏ فَقُلْتُ نَاقَتِي الْيَاقُوتَةُ هِيَ خَيْرٌ مِنْ أُوقِيَّةٍ ‏.‏ قَالَ هِشَامٌ خَيْرٌ مِنْ أَرْبَعِينَ دِرْهَمًا فَرَجَعْتُ فَلَمْ أَسْأَلْهُ شَيْئًا زَادَ هِشَامٌ فِي حَدِيثِهِ وَكَانَتِ الأُوقِيَّةُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْبَعِينَ دِرْهَمًا ‏.‏\hadithno{1628}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: If anyone begs when he has something equivalent to an uqiyah in value, he has begged immoderately. So I said: My she-camel, Yaqutah, is better than an uqiyah. The version of Hisham goes: "better than forty dirhams. So I returned and did not beg anything from him." Hisham added in his version: "An uqiyah during the time of the Messenger of Allah (ﷺ) was equivalent to forty dirhams}}
\hadithdefcmd{abudawud}{1629}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مِسْكِينٌ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُهَاجِرِ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي كَبْشَةَ السَّلُولِيِّ، حَدَّثَنَا سَهْلُ ابْنُ الْحَنْظَلِيَّةِ، قَالَ قَدِمَ عَلَى رَسُولِ اللَّهِ عُيَيْنَةُ بْنُ حِصْنٍ وَالأَقْرَعُ بْنُ حَابِسٍ فَسَأَلاَهُ فَأَمَرَ لَهُمَا بِمَا سَأَلاَ وَأَمَرَ مُعَاوِيَةَ فَكَتَبَ لَهُمَا بِمَا سَأَلاَ فَأَمَّا الأَقْرَعُ فَأَخَذَ كِتَابَهُ فَلَفَّهُ فِي عِمَامَتِهِ وَانْطَلَقَ وَأَمَّا عُيَيْنَةُ فَأَخَذَ كِتَابَهُ وَأَتَى النَّبِيَّ صلى الله عليه وسلم مَكَانَهُ فَقَالَ يَا مُحَمَّدُ أَتَرَانِي حَامِلاً إِلَى قَوْمِي كِتَابًا لاَ أَدْرِي مَا فِيهِ كَصَحِيفَةِ الْمُتَلَمِّسِ ‏.‏ فَأَخْبَرَ مُعَاوِيَةُ بِقَوْلِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ سَأَلَ وَعِنْدَهُ مَا يُغْنِيهِ فَإِنَّمَا يَسْتَكْثِرُ مِنَ النَّارِ ‏"‏ ‏.‏ وَقَالَ النُّفَيْلِيُّ فِي مَوْضِعٍ آخَرَ ‏"‏ مِنْ جَمْرِ جَهَنَّمَ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ وَمَا يُغْنِيهِ وَقَالَ النُّفَيْلِيُّ فِي مَوْضِعٍ آخَرَ وَمَا الْغِنَى الَّذِي لاَ تَنْبَغِي مَعَهُ الْمَسْأَلَةُ قَالَ ‏"‏ قَدْرُ مَا يُغَدِّيهِ وَيُعَشِّيهِ ‏"‏ ‏.‏ وَقَالَ النُّفَيْلِيُّ فِي مَوْضِعٍ آخَرَ ‏"‏ أَنْ يَكُونَ لَهُ شِبَعُ يَوْمٍ وَلَيْلَةٍ أَوْ لَيْلَةٍ وَيَوْمٍ ‏"‏ ‏.‏ وَكَانَ حَدَّثَنَا بِهِ مُخْتَصِرًا عَلَى هَذِهِ الأَلْفَاظِ الَّتِي ذُكِرَتْ ‏.‏\hadithno{1629}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Sahl ibn Hanzaliyyah: Uyaynah ibn Hisn and Aqra' ibn Habis came to the Messenger of Allah (ﷺ). They begged from him. He commanded to give them what they begged. He ordered Mu'awiyah to write a document to give what they begged. Aqra' took his document, wrapped it in his turban, and went away. As for Uyaynah, he took his document and came to the Prophet (ﷺ) at his home, and said to him: Muhammad, do you see me? I am taking a document to my people, but I do not know what it contains, just like the document of al-Mutalammis. Mu'awiyah informed the Messenger of Allah (ﷺ) of his statement. Thereupon the Messenger of Allah (ﷺ) said: He who begs (from people) when he has sufficient is simply asking for a large amount of Hell-fire. (An-Nufayl (a transmitter) said elsewhere: "embers of Hell".) They asked: Messenger of Allah, what is a sufficiency? (Elsewhere an-Nufayl said: What is a sufficiency which makes begging unfitting?) He replied: It is that which would provide a morning and an evening meal. (Elsewhere an-Nufayl said: It is when one has enough for a day and night, or for a night and a day.) He (an-Nufayl) narrated to us this tradition briefly in the words that I have mentioned}}
\hadithdefcmd{abudawud}{1630}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ عُمَرَ بْنِ غَانِمٍ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادٍ، أَنَّهُ سَمِعَ زِيَادَ بْنَ نُعَيْمٍ الْحَضْرَمِيَّ، أَنَّهُ سَمِعَ زِيَادَ بْنَ الْحَارِثِ الصُّدَائِيَّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَبَايَعْتُهُ فَذَكَرَ حَدِيثًا طَوِيلاً قَالَ فَأَتَاهُ رَجُلٌ فَقَالَ أَعْطِنِي مِنَ الصَّدَقَةِ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ تَعَالَى لَمْ يَرْضَ بِحُكْمِ نَبِيٍّ وَلاَ غَيْرِهِ فِي الصَّدَقَاتِ حَتَّى حَكَمَ فِيهَا هُوَ فَجَزَّأَهَا ثَمَانِيَةَ أَجْزَاءٍ فَإِنْ كُنْتَ مِنْ تِلْكَ الأَجْزَاءِ أَعْطَيْتُكَ حَقَّكَ ‏"‏ ‏.‏\hadithno{1630}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ziyad ibn al-Harith as-Suda'i: I came to the Messenger of Allah (ﷺ) and swore allegiance to him, and after telling a long story he said: Then a man came to him and said: Give me some of the sadaqah (alms). The Messenger of Allah (ﷺ) said: Allah is not pleased with a Prophet's or anyone else's decision about sadaqat till He has given a decision about them Himself. He has divided those entitled to them into eight categories, so if you come within those categories, I shall give you what you desire}}
\hadithdefcmd{abudawud}{1631}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ الْمِسْكِينُ الَّذِي تَرُدُّهُ التَّمْرَةُ وَالتَّمْرَتَانِ وَالأُكْلَةُ وَالأُكْلَتَانِ وَلَكِنَّ الْمِسْكِينَ الَّذِي لاَ يَسْأَلُ النَّاسَ شَيْئًا وَلاَ يَفْطِنُونَ بِهِ فَيُعْطُونَهُ ‏"‏ ‏.‏\hadithno{1631}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported Messenger of Allah (May peace be upon him) as saying :The poor man(miskin) is not one who is admitted (by the people) with one or two dates or with one or two morsels but is one, who does not beg anything from his people and is not taken notice of so that alms may be given to him}}
\hadithdefcmd{abudawud}{1632}{حَدَّثَنَا مُسَدَّدٌ، وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ، وَأَبُو كَامِلٍ - الْمَعْنَى - قَالُوا حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِثْلَهُ قَالَ ‏"‏ وَلَكِنَّ الْمِسْكِينَ الْمُتَعَفِّفُ ‏"‏ ‏.‏ زَادَ مُسَدَّدٌ فِي حَدِيثِهِ ‏"‏ لَيْسَ لَهُ مَا يَسْتَغْنِي بِهِ الَّذِي لاَ يَسْأَلُ وَلاَ يُعْلَمُ بِحَاجَتِهِ فَيُتَصَدَّقُ عَلَيْهِ فَذَاكَ الْمَحْرُومُ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مُسَدَّدٌ ‏"‏ الْمُتَعَفِّفُ الَّذِي لاَ يَسْأَلُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا مُحَمَّدُ بْنُ ثَوْرٍ وَعَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ جَعَلاَ الْمَحْرُومَ مِنْ كَلاَمِ الزُّهْرِيِّ وَهَذَا أَصَحُّ ‏.‏\hadithno{1632}\hadithgrade{Al-Albani: Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) said something similar as mentioned in the preceding tradition. This version adds: But the poor man (miskin) who abstains from begging from the people is one (according to the version of Musaddad who does not get enough so that he may not beg from the people, nor is his need known to the people, so that alms be given to him. This is the one who has been deprived. Musaddad did not mention the words "one who avoids begging from the people." Abu Dawud said: This tradition has been transmitted by Muhammad bin Thawr and 'Abd al-Razzaq on the authority of Ma'mar. They mentioned that the word "deprived" is the statement of al-Zuhri, and this is more sound)}}
\hadithdefcmd{abudawud}{1633}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَدِيِّ بْنِ الْخِيَارِ، قَالَ أَخْبَرَنِي رَجُلاَنِ، أَنَّهُمَا أَتَيَا النَّبِيَّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ وَهُوَ يَقْسِمُ الصَّدَقَةَ فَسَأَلاَهُ مِنْهَا فَرَفَعَ فِينَا الْبَصَرَ وَخَفَضَهُ فَرَآنَا جَلْدَيْنِ فَقَالَ ‏ "‏ إِنْ شِئْتُمَا أَعْطَيْتُكُمَا وَلاَ حَظَّ فِيهَا لِغَنِيٍّ وَلاَ لِقَوِيٍّ مُكْتَسِبٍ ‏"‏ ‏.‏\hadithno{1633}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ubaydullah ibn Adl ibn al-Khiyar: Two men informed me that they went to the Prophet (ﷺ) when he was at the Farewell Pilgrimage while he was distributing the sadaqah and asked him for some of it. He looked us up and down, and seeing that we were robust, he said: If you wish, I shall give you something, but there is nothing spare in it for a rich man or for one who is strong and able to earn a living}}
\hadithdefcmd{abudawud}{1634}{حَدَّثَنَا عَبَّادُ بْنُ مُوسَى الأَنْبَارِيُّ الْخُتَّلِيُّ، حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - قَالَ أَخْبَرَنِي أَبِي، عَنْ رَيْحَانَ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَحِلُّ الصَّدَقَةُ لِغَنِيٍّ وَلاَ لِذِي مِرَّةٍ سَوِيٍّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ سُفْيَانُ عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ كَمَا قَالَ إِبْرَاهِيمُ وَرَوَاهُ شُعْبَةُ عَنْ سَعْدٍ قَالَ ‏"‏ لِذِي مِرَّةٍ قَوِيٍّ ‏"‏ ‏.‏ وَالأَحَادِيثُ الأُخَرُ عَنِ النَّبِيِّ صلى الله عليه وسلم بَعْضُهَا ‏"‏ لِذِي مِرَّةٍ قَوِيٍّ ‏"‏ ‏.‏ وَبَعْضُهَا ‏"‏ لِذِي مِرَّةٍ سَوِيٍّ ‏"‏ ‏.‏ وَقَالَ عَطَاءُ بْنُ زُهَيْرٍ إِنَّهُ لَقِيَ عَبْدَ اللَّهِ بْنَ عَمْرٍو فَقَالَ إِنَّ الصَّدَقَةَ لاَ تَحِلُّ لِقَوِيٍّ وَلاَ لِذِي مِرَّةٍ سَوِيٍّ ‏.‏\hadithno{1634}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr : The Prophet (ﷺ) said: Sadaqah may not be given to a rich man or to one who has strength and is sound in limbs. Abu Dawud said: This tradition has been transmitted by Sufyan from Sa'd bin Ibrahim like the tradition narrated by Ibrahim. The version of Shu'bah from Sa'd has: "for a man who has strength and is robust." The other version of this tradition from the Prophet (ﷺ) have the words "for a man who has strength and is robust." Others have "for a man who has strength and is sound in limbs." 'Ata bin Zuhair said that he had met 'Abd Allah bin 'Amr who said: "Sadaqah is not lawful for a strong man nor for a man who has strength and is sound in limbs}}
\hadithdefcmd{abudawud}{1635}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَحِلُّ الصَّدَقَةُ لِغَنِيٍّ إِلاَّ لِخَمْسَةٍ لِغَازٍ فِي سَبِيلِ اللَّهِ أَوْ لِعَامِلٍ عَلَيْهَا أَوْ لِغَارِمٍ أَوْ لِرَجُلٍ اشْتَرَاهَا بِمَالِهِ أَوْ لِرَجُلٍ كَانَ لَهُ جَارٌ مِسْكِينٌ فَتُصُدِّقَ عَلَى الْمِسْكِينِ فَأَهْدَاهَا الْمِسْكِينُ لِلْغَنِيِّ ‏"‏ ‏.‏\hadithno{1635}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ata ibn Yasar: The Prophet (ﷺ) said: Sadaqah may not be given to rich man, with the exception of five classes: One who fights in Allah's path, or who collects it, or a debtor, or a man who buys it with his money, or a man who has a poor neighbour who has been given sadaqah and gives a present to the rich man}}
\hadithdefcmd{abudawud}{1636}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ ابْنُ عُيَيْنَةَ عَنْ زَيْدٍ كَمَا قَالَ مَالِكٌ وَرَوَاهُ الثَّوْرِيُّ عَنْ زَيْدٍ قَالَ حَدَّثَنِي الثَّبْتُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1636}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by abu-Said al-Khudri to the same effect to a different chain of narrators, attributing it to the Messenger of Allah (May peace be upon him). Abu-Dawud said :Ibn ‘Uyainah reported from Zaid, from whom Malik narrated and Thwari narrated from Zaid that an authentic narrator reported from the Messenger of Allah (May peace be upon him)}}
\hadithdefcmd{abudawud}{1637}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا الْفِرْيَابِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عِمْرَانَ الْبَارِقِيِّ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحِلُّ الصَّدَقَةُ لِغَنِيٍّ إِلاَّ فِي سَبِيلِ اللَّهِ أَوِ ابْنِ السَّبِيلِ أَوْ جَارٍ فَقِيرٍ يُتَصَدَّقُ عَلَيْهِ فَيُهْدِي لَكَ أَوْ يَدْعُوكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ فِرَاسٌ وَابْنُ أَبِي لَيْلَى عَنْ عَطِيَّةَ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1637}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu-Said reported :Messenger of Allah (May peace be upon him) said : Sadaqah is not lawful for a rich person except what comes as a result of Jihad or what a poor neighbor gifts you out of the sadaqah given to him, or he entertains you in a feast. Abu-Dawud said : This has been transmitted by Abu- Said through a different chain of narrators in a similar way}}
\hadithdefcmd{abudawud}{1638}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنِي سَعِيدُ بْنُ عُبَيْدٍ الطَّائِيُّ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، زَعَمَ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ يُقَالُ لَهُ سَهْلُ بْنُ أَبِي حَثْمَةَ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَدَاهُ بِمِائَةٍ مِنْ إِبِلِ الصَّدَقَةِ - يَعْنِي دِيَةَ الأَنْصَارِيِّ الَّذِي قُتِلَ بِخَيْبَرَ ‏.‏\hadithno{1638}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Basheer b. Yasar said that a man from the Ansar called Sahi b. abu-Hatmah told him that Messenger of Allah (May peace be upon him) gave one Hundred camels to him a blood-wit from among the camels of sadaqah, i.e a blood-wit for the Ansari who was killed at Khaibar}}
\hadithdefcmd{abudawud}{1639}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ زَيْدِ بْنِ عُقْبَةَ الْفَزَارِيِّ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَسَائِلُ كُدُوحٌ يَكْدَحُ بِهَا الرَّجُلُ وَجْهَهُ فَمَنْ شَاءَ أَبْقَى عَلَى وَجْهِهِ وَمَنْ شَاءَ تَرَكَ إِلاَّ أَنْ يَسْأَلَ الرَّجُلُ ذَا سُلْطَانٍ أَوْ فِي أَمْرٍ لاَ يَجِدُ مِنْهُ بُدًّا ‏"‏ ‏.‏\hadithno{1639}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) said: Acts of begging are lacerations with which a man disfigures his face, so he who wishes may preserve his self-respect, and he who wishes may abandon it; but this does not apply to one who begs from a ruler, or in a situation which makes it necessary}}
\hadithdefcmd{abudawud}{1640}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هَارُونَ بْنِ رِيَابٍ، قَالَ حَدَّثَنِي كِنَانَةُ بْنُ نُعَيْمٍ الْعَدَوِيُّ، عَنْ قَبِيصَةَ بْنِ مُخَارِقٍ الْهِلاَلِيِّ، قَالَ تَحَمَّلْتُ حَمَالَةً فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَقِمْ يَا قَبِيصَةُ حَتَّى تَأْتِيَنَا الصَّدَقَةُ فَنَأْمُرَ لَكَ بِهَا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَا قَبِيصَةُ إِنَّ الْمَسْأَلَةَ لاَ تَحِلُّ إِلاَّ لأَحَدِ ثَلاَثَةٍ رَجُلٌ تَحَمَّلَ حَمَالَةً فَحَلَّتْ لَهُ الْمَسْأَلَةُ فَسَأَلَ حَتَّى يُصِيبَهَا ثُمَّ يُمْسِكُ وَرَجُلٌ أَصَابَتْهُ جَائِحَةٌ فَاجْتَاحَتْ مَالَهُ فَحَلَّتْ لَهُ الْمَسْأَلَةُ فَسَأَلَ حَتَّى يُصِيبَ قِوَامًا مِنْ عَيْشٍ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ سِدَادًا مِنْ عَيْشٍ ‏"‏ ‏.‏ ‏"‏ وَرَجُلٌ أَصَابَتْهُ فَاقَةٌ حَتَّى يَقُولَ ثَلاَثَةٌ مِنْ ذَوِي الْحِجَا مِنْ قَوْمِهِ قَدْ أَصَابَتْ فُلاَنًا الْفَاقَةُ فَحَلَّتْ لَهُ الْمَسْأَلَةُ فَسَأَلَ حَتَّى يُصِيبَ قِوَامًا مِنْ عَيْشٍ - أَوْ سِدَادًا مِنْ عَيْشٍ - ثُمَّ يُمْسِكُ وَمَا سِوَاهُنَّ مِنَ الْمَسْأَلَةِ يَا قَبِيصَةُ سُحْتٌ يَأْكُلُهَا صَاحِبُهَا سُحْتًا ‏"‏ ‏.‏\hadithno{1640}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1044)}\hadithtrans{Qabisah b. Mukhiriq al-Hilali said :I became a guarantor for a payment, and I came to Messenger of Allah (May peace be upon him). He said: Wait till I receive the sadaqah and I shall order it to be given to you. He then said : Begging, Qabisah, is allowable only to one of three classes: a man who has become a guarantor for a payment to whom begging is allowed till he gets it, after which he must stop (begging); a man who has been stricken by a calamity and it destroys his property to whom begging is allowed till he gets what will support life (or he said, what will provide a reasonable subsistence); and a man who has been smitten by poverty, about whom three intelligent members of his people confirm by saying: So and so has been smitten by poverty, to such a person begging is allowed till be gets what will support life (or he said, what will provide a reasonable subsistence), after which he must stop (begging). Any other reason for begging, Qabisah, is forbidden, and one who engages in such consumes it as a thing which is forbidden}}
\hadithdefcmd{abudawud}{1641}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَخْضَرِ بْنِ عَجْلاَنَ، عَنْ أَبِي بَكْرٍ الْحَنَفِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ أَتَى النَّبِيَّ صلى الله عليه وسلم يَسْأَلُهُ فَقَالَ ‏"‏ أَمَا فِي بَيْتِكَ شَىْءٌ ‏"‏ ‏.‏ قَالَ بَلَى حِلْسٌ نَلْبَسُ بَعْضَهُ وَنَبْسُطُ بَعْضَهُ وَقَعْبٌ نَشْرَبُ فِيهِ مِنَ الْمَاءِ ‏.‏ قَالَ ‏"‏ ائْتِنِي بِهِمَا ‏"‏ ‏.‏ فَأَتَاهُ بِهِمَا فَأَخَذَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ وَقَالَ ‏"‏ مَنْ يَشْتَرِي هَذَيْنِ ‏"‏ ‏.‏ قَالَ رَجُلٌ أَنَا آخُذُهُمَا بِدِرْهَمٍ ‏.‏ قَالَ ‏"‏ مَنْ يَزِيدُ عَلَى دِرْهَمٍ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا قَالَ رَجُلٌ أَنَا آخُذُهُمَا بِدِرْهَمَيْنِ ‏.‏ فَأَعْطَاهُمَا إِيَّاهُ وَأَخَذَ الدِّرْهَمَيْنِ وَأَعْطَاهُمَا الأَنْصَارِيَّ وَقَالَ ‏"‏ اشْتَرِ بِأَحَدِهِمَا طَعَامًا فَانْبِذْهُ إِلَى أَهْلِكَ وَاشْتَرِ بِالآخَرِ قَدُومًا فَأْتِنِي بِهِ ‏"‏ ‏.‏ فَأَتَاهُ بِهِ فَشَدَّ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم عُودًا بِيَدِهِ ثُمَّ قَالَ لَهُ ‏"‏ اذْهَبْ فَاحْتَطِبْ وَبِعْ وَلاَ أَرَيَنَّكَ خَمْسَةَ عَشَرَ يَوْمًا ‏"‏ ‏.‏ فَذَهَبَ الرَّجُلُ يَحْتَطِبُ وَيَبِيعُ فَجَاءَ وَقَدْ أَصَابَ عَشَرَةَ دَرَاهِمَ فَاشْتَرَى بِبَعْضِهَا ثَوْبًا وَبِبَعْضِهَا طَعَامًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا خَيْرٌ لَكَ مِنْ أَنْ تَجِيءَ الْمَسْأَلَةُ نُكْتَةً فِي وَجْهِكَ يَوْمَ الْقِيَامَةِ إِنَّ الْمَسْأَلَةَ لاَ تَصْلُحُ إِلاَّ لِثَلاَثَةٍ لِذِي فَقْرٍ مُدْقِعٍ أَوْ لِذِي غُرْمٍ مُفْظِعٍ أَوْ لِذِي دَمٍ مُوجِعٍ ‏"‏ ‏.‏\hadithno{1641}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: A man of the Ansar came to the Prophet (ﷺ) and begged from him. He (the Prophet) asked: Have you nothing in your house? He replied: Yes, a piece of cloth, a part of which we wear and a part of which we spread (on the ground), and a wooden bowl from which we drink water. He said: Bring them to me. He then brought these articles to him and he (the Prophet) took them in his hands and asked: Who will buy these? A man said: I shall buy them for one dirham. He said twice or thrice: Who will offer more than one dirham? A man said: I shall buy them for two dirhams. He gave these to him and took the two dirhams and, giving them to the Ansari, he said: Buy food with one of them and hand it to your family, and buy an axe and bring it to me. He then brought it to him. The Messenger of Allah (ﷺ) fixed a handle on it with his own hands and said: Go, gather firewood and sell it, and do not let me see you for a fortnight. The man went away and gathered firewood and sold it. When he had earned ten dirhams, he came to him and bought a garment with some of them and food with the others. The Messenger of Allah (ﷺ) then said: This is better for you than that begging should come as a spot on your face on the Day of Judgment. Begging is right only for three people: one who is in grinding poverty, one who is seriously in debt, or one who is responsible for compensation and finds it difficult to pay}}
\hadithdefcmd{abudawud}{1642}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ رَبِيعَةَ، - يَعْنِي ابْنَ يَزِيدَ - عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي مُسْلِمٍ الْخَوْلاَنِيِّ، قَالَ حَدَّثَنِي الْحَبِيبُ الأَمِينُ، أَمَّا هُوَ إِلَىَّ فَحَبِيبٌ وَأَمَّا هُوَ عِنْدِي فَأَمِينٌ عَوْفُ بْنُ مَالِكٍ قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَبْعَةً أَوْ ثَمَانِيَةً أَوْ تِسْعَةً فَقَالَ ‏"‏ أَلاَ تُبَايِعُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏ وَكُنَّا حَدِيثَ عَهْدٍ بِبَيْعَةٍ قُلْنَا قَدْ بَايَعْنَاكَ حَتَّى قَالَهَا ثَلاَثًا فَبَسَطْنَا أَيْدِيَنَا فَبَايَعْنَاهُ فَقَالَ قَائِلٌ يَا رَسُولَ اللَّهِ إِنَّا قَدْ بَايَعْنَاكَ فَعَلاَمَ نُبَايِعُكَ قَالَ ‏"‏ أَنْ تَعْبُدُوا اللَّهَ وَلاَ تُشْرِكُوا بِهِ شَيْئًا وَتُصَلُّوا الصَّلَوَاتِ الْخَمْسَ وَتَسْمَعُوا وَتُطِيعُوا ‏"‏ ‏.‏ وَأَسَرَّ كَلِمَةً خُفْيَةً قَالَ ‏"‏ وَلاَ تَسْأَلُوا النَّاسَ شَيْئًا ‏"‏ ‏.‏ قَالَ فَلَقَدْ كَانَ بَعْضُ أُولَئِكَ النَّفَرِ يَسْقُطُ سَوْطُهُ فَمَا يَسْأَلُ أَحَدًا أَنْ يُنَاوِلَهُ إِيَّاهُ ‏.‏ قَالَ أَبُو دَاوُدَ حَدِيثُ هِشَامٍ لَمْ يَرْوِهِ إِلاَّ سَعِيدٌ ‏.‏\hadithno{1642}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1043)}\hadithtrans{Awf b. Malik said :We were with Messenger of Allah (May peace be upon him), seven or eight or nine. He said : Do you take the oath of allegiance to the Messenger of Allah (May peace be upon him), and we shortly took the oath of allegiance. We said: we have already taken the oath of allegiance to you. He repeated the same words three times. We then stretched our hands and took the oath of allegiance to him. A man (or us) said : We took the oath of allegiance to you; now on what should we take the oath of allegiance, Messenger of Allah ? He replied: That you should worship Allah, do not associate anything with Him, offer five times prayer, listen and obey. He uttered a word quietly : And do not beg from the people. When the whip fell on the ground, none of that group asked anyone to pick up the whip for him. Abu Dawud said : The version of Hisham was not narrated by anyone except Sa'id}}
\hadithdefcmd{abudawud}{1643}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ أَبِي الْعَالِيَةِ، عَنْ ثَوْبَانَ، قَالَ وَكَانَ ثَوْبَانُ مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَكَفَّلَ لِي أَنْ لاَ يَسْأَلَ النَّاسَ شَيْئًا وَأَتَكَفَّلَ لَهُ بِالْجَنَّةِ ‏"‏ ‏.‏ فَقَالَ ثَوْبَانُ أَنَا ‏.‏ فَكَانَ لاَ يَسْأَلُ أَحَدًا شَيْئًا ‏.‏\hadithno{1643}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Thawban, the client of the Messenger of Allah (May peace be upon him), reported him as saying :If anyone guarantees me that he will not beg from people, I will guarantee him Paradise. Thawban said : I (will not beg). He never asked anyone for anything}}
\hadithdefcmd{abudawud}{1644}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ نَاسًا، مِنَ الأَنْصَارِ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَاهُمْ ثُمَّ سَأَلُوهُ فَأَعْطَاهُمْ حَتَّى إِذَا نَفِدَ مَا عِنْدَهُ قَالَ ‏ "‏ مَا يَكُونُ عِنْدِي مِنْ خَيْرٍ فَلَنْ أَدَّخِرَهُ عَنْكُمْ وَمَنْ يَسْتَعْفِفْ يُعِفَّهُ اللَّهُ وَمَنْ يَسْتَغْنِ يُغْنِهِ اللَّهُ وَمَنْ يَتَصَبَّرْ يُصَبِّرْهُ اللَّهُ وَمَا أَعْطَى اللَّهُ أَحَدًا مِنْ عَطَاءٍ أَوْسَعَ مِنَ الصَّبْرِ ‏"‏ ‏.‏\hadithno{1644}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1469) Sahih Muslim (1053)}\hadithtrans{Abu Said al-Khudri said :Some of the Ansar begged from the Messenger of Allah (May peace be upon him) and he gave them something. They later begged from him again and he gave them something so that what he had was exhausted. He then said :What I have I shall never store away from you but Allah will strengthen the abstinence of him who abstains, will give a satisfaction to him who wants to be satisfied, and will strengthen the endurance of him who shows endurance. No one has been given a more ample gift than endurance}}
\hadithdefcmd{abudawud}{1645}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، ح حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ حَبِيبٍ أَبُو مَرْوَانَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، - وَهَذَا حَدِيثُهُ - عَنْ بَشِيرِ بْنِ سَلْمَانَ، عَنْ سَيَّارٍ أَبِي حَمْزَةَ، عَنْ طَارِقٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَصَابَتْهُ فَاقَةٌ فَأَنْزَلَهَا بِالنَّاسِ لَمْ تُسَدَّ فَاقَتُهُ وَمَنْ أَنْزَلَهَا بِاللَّهِ أَوْشَكَ اللَّهُ لَهُ بِالْغِنَى إِمَّا بِمَوْتٍ عَاجِلٍ أَوْ غِنًى عَاجِلٍ ‏"‏ ‏.‏\hadithno{1645}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: If one who is afflicted with poverty refers it to me, his poverty will not be brought to an end; but if one refers it to Allah, He will soon give him sufficiency, either by a speedy death or by a sufficiency which comes later}}
\hadithdefcmd{abudawud}{1646}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ مُسْلِمِ بْنِ مَخْشِيٍّ، عَنِ ابْنِ الْفِرَاسِيِّ، أَنَّ الْفِرَاسِيَّ، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَسْأَلُ يَا رَسُولَ اللَّهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ وَإِنْ كُنْتَ سَائِلاً لاَ بُدَّ فَاسْأَلِ الصَّالِحِينَ ‏"‏ ‏.‏\hadithno{1646}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn al-Firasi: Al-Firasi asked the Messenger of Allah (ﷺ): May I beg, Messenger of Allah? The Prophet (ﷺ) said: No, but if there is no escape from it, beg from the upright}}
\hadithdefcmd{abudawud}{1647}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنِ ابْنِ السَّاعِدِيِّ، قَالَ اسْتَعْمَلَنِي عُمَرُ - رضى الله عنه - عَلَى الصَّدَقَةِ فَلَمَّا فَرَغْتُ مِنْهَا وَأَدَّيْتُهَا إِلَيْهِ أَمَرَ لِي بِعُمَالَةٍ فَقُلْتُ إِنَّمَا عَمِلْتُ لِلَّهِ وَأَجْرِي عَلَى اللَّهِ ‏.‏ قَالَ خُذْ مَا أُعْطِيتَ فَإِنِّي قَدْ عَمِلْتُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَمَّلَنِي فَقُلْتُ مِثْلَ قَوْلِكَ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُعْطِيتَ شَيْئًا مِنْ غَيْرِ أَنْ تَسْأَلَهُ فَكُلْ وَتَصَدَّقْ ‏"‏ ‏.‏\hadithno{1647}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7163) Sahih Muslim (1045)}\hadithtrans{Ibn al-Saidi said :Umar employed me to collect the sadaqah. When I finished doing so and gave it to him, he ordered payment to be given to me. I said: I did only for Allah’s sake, and my reward will come from Allah. He said: Take what you are given, for I acted (as a collector) during the time of the Messenger of Allah (May peace be upon him) and he assigned me a payment. Thereupon, I said the same kind of thing as you have said, to which Messenger of Allah (May peace be upon him) said: When you are given something without asking for it, you should use it for your own purpose and as sadaqah}}
\hadithdefcmd{abudawud}{1648}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ عَلَى الْمِنْبَرِ وَهُوَ يَذْكُرُ الصَّدَقَةَ وَالتَّعَفُّفَ مِنْهَا وَالْمَسْأَلَةَ ‏"‏ الْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى وَالْيَدُ الْعُلْيَا الْمُنْفِقَةُ وَالسُّفْلَى السَّائِلَةُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ اخْتُلِفَ عَلَى أَيُّوبَ عَنْ نَافِعٍ فِي هَذَا الْحَدِيثِ قَالَ عَبْدُ الْوَارِثِ ‏"‏ الْيَدُ الْعُلْيَا الْمُتَعَفِّفَةُ ‏"‏ ‏.‏ وَقَالَ أَكْثَرُهُمْ عَنْ حَمَّادِ بْنِ زَيْدٍ عَنْ أَيُّوبَ ‏"‏ الْيَدُ الْعُلْيَا الْمُنْفِقَةُ ‏"‏ ‏.‏ وَقَالَ وَاحِدٌ عَنْ حَمَّادٍ ‏"‏ الْمُتَعَفِّفَةُ ‏"‏ ‏.‏\hadithno{1648}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1429) Sahih Muslim (1033)}\hadithtrans{Abd Allah b. ‘Umar reported that the Messenger of Allah (May peace be upon him) said when he was on the pulpit speaking of sadaqah and abstention from it and begging :the upper hand is better than the lower one, the upper being the one which bestows and the lower which begs. Abu Dawud said : The version of this tradition narrated by Ayyub from Nafi is disputed. The narrator `Abd al-Warith said in his version : `The upper hand is the one which abstains from begging;” but most of the narrators have narrated from Hammad b. Zaid from Ayyub the words “ The upper hand is the one which bestows.” A narrator from Hammad said in his version “the one which abstains from begging.”}}
\hadithdefcmd{abudawud}{1649}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ التَّيْمِيُّ، حَدَّثَنِي أَبُو الزَّعْرَاءِ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِيهِ، مَالِكِ بْنِ نَضْلَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الأَيْدِي ثَلاَثَةٌ فَيَدُ اللَّهِ الْعُلْيَا وَيَدُ الْمُعْطِي الَّتِي تَلِيهَا وَيَدُ السَّائِلِ السُّفْلَى فَأَعْطِ الْفَضْلَ وَلاَ تَعْجِزْ عَنْ نَفْسِكَ ‏"‏ ‏.‏\hadithno{1649}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Malik ibn Nadlah: The Prophet (ﷺ) said: Hands are of three types: Allah's hand is the upper one; the bestower's hand is the one near it; the beggar's hand is the lower one. So bestow what is surplus, and do not submit yourself to the demand of your soul}}
\hadithdefcmd{abudawud}{1650}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي رَافِعٍ، عَنْ أَبِي رَافِعٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ رَجُلاً عَلَى الصَّدَقَةِ مِنْ بَنِي مَخْزُومٍ فَقَالَ لأَبِي رَافِعٍ اصْحَبْنِي فَإِنَّكَ تُصِيبُ مِنْهَا ‏.‏ قَالَ حَتَّى آتِيَ النَّبِيَّ صلى الله عليه وسلم فَأَسْأَلَهُ فَأَتَاهُ فَسَأَلَهُ فَقَالَ ‏ "‏ مَوْلَى الْقَوْمِ مِنْ أَنْفُسِهِمْ وَإِنَّا لاَ تَحِلُّ لَنَا الصَّدَقَةُ ‏"‏ ‏.‏\hadithno{1650}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuRafi': The Prophet (ﷺ) sent a man of the Banu Makhzum to collect sadaqah. He said to AbuRafi': Accompany me so that you may get some of it. He said: (I cannot take it) until I go to the Prophet (ﷺ) and ask him. Then he went to him and asked him. He said: The sadaqah is not lawful for us, and the client of a people is treated as one of them}}
\hadithdefcmd{abudawud}{1651}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَمُرُّ بِالتَّمْرَةِ الْعَائِرَةِ فَمَا يَمْنَعُهُ مِنْ أَخْذِهَا إِلاَّ مَخَافَةُ أَنْ تَكُونَ صَدَقَةً ‏.‏\hadithno{1651}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas said :The Messenger of Allah (May peace be upon him) came upon a date on the road; he would not take it for fear of being a part of the sadaqah}}
\hadithdefcmd{abudawud}{1652}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا أَبِي، عَنْ خَالِدِ بْنِ قَيْسٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَجَدَ تَمْرَةً فَقَالَ ‏ "‏ لَوْلاَ أَنِّي أَخَافُ أَنْ تَكُونَ صَدَقَةً لأَكَلْتُهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ هِشَامٌ عَنْ قَتَادَةَ هَكَذَا ‏.‏\hadithno{1652}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2055) Sahih Muslim (1071)}\hadithtrans{Anas said:Messenger of Allah (May peace be upon him) found a date and said: Were it not that I fear it may be part of the sadaqah, I would eat it}}
\hadithdefcmd{abudawud}{1653}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ بَعَثَنِي أَبِي إِلَى النَّبِيِّ صلى الله عليه وسلم فِي إِبِلٍ أَعْطَاهَا إِيَّاهُ مِنَ الصَّدَقَةِ ‏.‏\hadithno{1653}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: My father sent me to the Prophet (ﷺ) to take the camels which he had given him from among those of sadaqah}}
\hadithdefcmd{abudawud}{1654}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا مُحَمَّدٌ، - هُوَ ابْنُ أَبِي عُبَيْدَةَ - عَنْ أَبِيهِ، عَنِ الأَعْمَشِ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، نَحْوَهُ زَادَ أَبِي يُبْدِلُهَا لَهُ ‏.‏\hadithno{1654}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition has also been transmitted by Ibn Abbas through a different chain of narrators in a similar manner. This version adds :“My father exchanged them for him”}}
\hadithdefcmd{abudawud}{1655}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِلَحْمٍ قَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالُوا شَىْءٌ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{1655}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1495) Sahih Muslim (1074)}\hadithtrans{Anas said when some meat was brought to the Prophet (SAWS), he asked What is this? He was told this is a thing (meat), which was given as sadaqah to Barirah. Thereupon, he said it is sadaqah for her and a gift to us}}
\hadithdefcmd{abudawud}{1656}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، بُرَيْدَةَ أَنَّ امْرَأَةً، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كُنْتُ تَصَدَّقْتُ عَلَى أُمِّي بِوَلِيدَةٍ وَإِنَّهَا مَاتَتْ وَتَرَكَتْ تِلْكَ الْوَلِيدَةَ ‏.‏ قَالَ ‏ "‏ قَدْ وَجَبَ أَجْرُكِ وَرَجَعَتْ إِلَيْكِ فِي الْمِيرَاثِ ‏"‏ ‏.‏\hadithno{1656}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1149)}\hadithtrans{Buraidah said A woman came to the Messenger of Allah (SAWS) and said I gave a slave girl as sadaqah to my mother who has now died and has left that slave girl. He said your reward is sure and the inheritance has given her back to you}}
\hadithdefcmd{abudawud}{1657}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا نَعُدُّ الْمَاعُونَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَارِيَةَ الدَّلْوِ وَالْقِدْرِ ‏.‏\hadithno{1657}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: During the time of the Messenger of Allah (ﷺ) we used to consider ma'un (this of daily use) lending a bucket and cooking-pot}}
\hadithdefcmd{abudawud}{1658}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ صَاحِبِ كَنْزٍ لاَ يُؤَدِّي حَقَّهُ إِلاَّ جَعَلَهُ اللَّهُ يَوْمَ الْقِيَامَةِ يُحْمَى عَلَيْهَا فِي نَارِ جَهَنَّمَ فَتُكْوَى بِهَا جَبْهَتُهُ وَجَنْبُهُ وَظَهْرُهُ حَتَّى يَقْضِيَ اللَّهُ تَعَالَى بَيْنَ عِبَادِهِ فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ مِمَّا تَعُدُّونَ ثُمَّ يُرَى سَبِيلُهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ وَمَا مِنْ صَاحِبِ غَنَمٍ لاَ يُؤَدِّي حَقَّهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَوْفَرَ مَا كَانَتْ فَيُبْطَحُ لَهَا بِقَاعٍ قَرْقَرٍ فَتَنْطَحُهُ بِقُرُونِهَا وَتَطَؤُهُ بِأَظْلاَفِهَا لَيْسَ فِيهَا عَقْصَاءُ وَلاَ جَلْحَاءُ كُلَّمَا مَضَتْ أُخْرَاهَا رُدَّتْ عَلَيْهِ أُولاَهَا حَتَّى يَحْكُمَ اللَّهُ بَيْنَ عِبَادِهِ فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ مِمَّا تَعُدُّونَ ثُمَّ يُرَى سَبِيلُهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ وَمَا مِنْ صَاحِبِ إِبِلٍ لاَ يُؤَدِّي حَقَّهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَوْفَرَ مَا كَانَتْ فَيُبْطَحُ لَهَا بِقَاعٍ قَرْقَرٍ فَتَطَؤُهُ بِأَخْفَافِهَا كُلَّمَا مَضَتْ عَلَيْهِ أُخْرَاهَا رُدَّتْ عَلَيْهِ أُولاَهَا حَتَّى يَحْكُمَ اللَّهُ تَعَالَى بَيْنَ عِبَادِهِ فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ مِمَّا تَعُدُّونَ ثُمَّ يُرَى سَبِيلُهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ ‏"‏ ‏.‏\hadithno{1658}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (987)}\hadithtrans{Abu Hurairah reported that Messenger of Allah (SWAS) as saying If any owner of treasure (gold and silver) does not pay what is due on it, Allah will make it heated in the Hell fire on the Day of Judgment, and his side, forehead and back will be cauterized with it until Allah gives His Judgment among mankind during a day whose extent will be fifty thousand years of your count and he sees whether his path is to take him to Paradise or to Hell. If any owner does not pay zakat on them, the sheep wilkl appear on the Day or Judgment most strong and in great number, a soft sandy plain will be spread out for them ; they will gore him with their horns and trample him with their hoofs; there will be none of them with twisted horns or without horns. As often as the last of them passes him, the first of them will be brought back to him, until Allah pronounces His Judgment among mankind during a day whose extent will be fifty thousand years that you count, and he sees whether his path is to take him to Paradise or to Hell. If any owner of camels does not pay what is due on them, they will appear in on the Day or Judgment most strong and in great number, a soft sandy plain will be spread out for them ; they will gore him with their horns and trample him with their hoofs; there will be none of them with twisted horns or without horns. As often as the last of them passes him, the first of them will be brought back to him, until Allah pronounces His Judgment among mankind during a day whose extent will be fifty thousand years that you count, and he sees whether his path is to take him to Paradise or to Hell}}
\hadithdefcmd{abudawud}{1659}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ فِي قِصَّةِ الإِبِلِ بَعْدَ قَوْلِهِ ‏"‏ لاَ يُؤَدِّي حَقَّهَا ‏"‏ ‏.‏ قَالَ ‏"‏ وَمِنْ حَقِّهَا حَلْبُهَا يَوْمَ وِرْدِهَا ‏"‏ ‏.‏\hadithno{1659}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2371) Sahih Muslim (987)}\hadithtrans{The above mentioned tradition has also been transmitted by Abu Hurairah through a different chain of narrators in a similar manner from the Prophet (SAWS). This version adds after the words “does not pay what is due on them” in the description of the camels the words “ One thing which is due being to milk them when they come down to drink water.”}}
\hadithdefcmd{abudawud}{1660}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي عُمَرَ الْغُدَانِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم نَحْوَ هَذِهِ الْقِصَّةِ فَقَالَ لَهُ - يَعْنِي لأَبِي هُرَيْرَةَ - فَمَا حَقُّ الإِبِلِ قَالَ تُعْطِي الْكَرِيمَةَ وَتَمْنَحُ الْغَزِيرَةَ وَتُفْقِرُ الظَّهْرَ وَتُطْرِقُ الْفَحْلَ وَتَسْقِي اللَّبَنَ ‏.‏\hadithno{1660}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: I heard the Messenger of Allah (ﷺ) as saying something similar to this tradition. He (the narrator) said to AbuHurayrah: What is due on camels? He replied: That you should give the best of your camels (in the path of Allah), that you lend a milch she-camel, you lend your mount for riding, that you lend the stallion for covering, and that you give the milk (to the people) for drinking}}
\hadithdefcmd{abudawud}{1661}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ قَالَ أَبُو الزُّبَيْرِ سَمِعْتُ عُبَيْدَ بْنَ عُمَيْرٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ مَا حَقُّ الإِبِلِ فَذَكَرَ نَحْوَهُ زَادَ ‏ "‏ وَإِعَارَةُ دَلْوِهَا ‏"‏ ‏.‏\hadithno{1661}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (988)}\hadithtrans{The aforesaid tradition has also been transmitted by ‘Ubaid bin ‘ Umair through a different chain of narrators. This version goes:A man asked: Messenger of Allah (ﷺ), what is due on camels? He replied in a similar way. This version adds "and to lend its udders.”}}
\hadithdefcmd{abudawud}{1662}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، حَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ مِنْ كُلِّ جَادِّ عَشَرَةِ أَوْسُقٍ مِنَ التَّمْرِ بِقِنْوٍ يُعَلَّقُ فِي الْمَسْجِدِ لِلْمَسَاكِينِ ‏.‏\hadithno{1662}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Jabir bin ‘Abdallah said The bProphet (SWAS) commanded that he who plucks ten wasqs of dates from date palms should hang a bunch of dates in the mosque for the poor}}
\hadithdefcmd{abudawud}{1663}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا أَبُو الأَشْهَبِ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَيْنَمَا نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ إِذْ جَاءَ رَجُلٌ عَلَى نَاقَةٍ لَهُ فَجَعَلَ يَصْرِفُهَا يَمِينًا وَشِمَالاً فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ عِنْدَهُ فَضْلُ ظَهْرٍ فَلْيَعُدْ بِهِ عَلَى مَنْ لاَ ظَهْرَ لَهُ وَمَنْ كَانَ عِنْدَهُ فَضْلُ زَادٍ فَلْيَعُدْ بِهِ عَلَى مَنْ لاَ زَادَ لَهُ ‏"‏ ‏.‏ حَتَّى ظَنَنَّا أَنَّهُ لاَ حَقَّ لأَحَدٍ مِنَّا فِي الْفَضْلِ ‏.‏\hadithno{1663}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1728)}\hadithtrans{Abu Sa’id al-Khudri said While we were traveling along with the Messenger of Allah (ﷺ) a man came to him on his she camel, and began to drive her right and left. The Messenger of Allah (ﷺ) said he who has a spare riding beast should give it to him who has no riding beast; and he who has surplus equipment should give it to who has no equipment. We thought that none of us had a right in surplus property}}
\hadithdefcmd{abudawud}{1664}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى الْمُحَارِبِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا غَيْلاَنُ، عَنْ جَعْفَرِ بْنِ إِيَاسٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَالَّذِينَ يَكْنِزُونَ الذَّهَبَ وَالْفِضَّةَ ‏\}‏ قَالَ كَبُرَ ذَلِكَ عَلَى الْمُسْلِمِينَ فَقَالَ عُمَرُ - رضى الله عنه أَنَا أُفَرِّجُ عَنْكُمْ ‏.‏ فَانْطَلَقَ فَقَالَ يَا نَبِيَّ اللَّهِ إِنَّهُ كَبُرَ عَلَى أَصْحَابِكَ هَذِهِ الآيَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ لَمْ يَفْرِضِ الزَّكَاةَ إِلاَّ لِيُطَيِّبَ مَا بَقِيَ مِنْ أَمْوَالِكُمْ وَإِنَّمَا فَرَضَ الْمَوَارِيثَ لِتَكُونَ لِمَنْ بَعْدَكُمْ ‏"‏ ‏.‏ فَكَبَّرَ عُمَرُ ثُمَّ قَالَ لَهُ ‏"‏ أَلاَ أُخْبِرُكَ بِخَيْرِ مَا يَكْنِزُ الْمَرْءُ الْمَرْأَةُ الصَّالِحَةُ إِذَا نَظَرَ إِلَيْهَا سَرَّتْهُ وَإِذَا أَمَرَهَا أَطَاعَتْهُ وَإِذَا غَابَ عَنْهَا حَفِظَتْهُ ‏"‏ ‏.‏\hadithno{1664}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: When this verse was revealed: "And those who hoard gold and silver," the Muslims were grieved about it. Umar said: I shall dispel your care. He, therefore, went and said: Prophet of Allah, your Companions were grieved by this verse. The Messenger of Allah (ﷺ) said: Allah has made zakat obligatory simply to purify your remaining property, and He made inheritances obligatory that they might come to those who survive you. Umar then said: Allah is most great. He then said to him: Let me inform you about the best a man hoards; it is a virtuous woman who pleases him when he looks at her, obeys him when he gives her a command, and guards his interests when he is away from her}}
\hadithdefcmd{abudawud}{1665}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا مُصْعَبُ بْنُ مُحَمَّدِ بْنِ شُرَحْبِيلَ، حَدَّثَنِي يَعْلَى بْنُ أَبِي يَحْيَى، عَنْ فَاطِمَةَ بِنْتِ حُسَيْنٍ، عَنْ حُسَيْنِ بْنِ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِلسَّائِلِ حَقٌّ وَإِنْ جَاءَ عَلَى فَرَسٍ ‏"‏ ‏.‏\hadithno{1665}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn Abu Talib: The Prophet (ﷺ) said: A beggar has the right though he may be riding (a horse)}}
\hadithdefcmd{abudawud}{1666}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا زُهَيْرٌ، عَنْ شَيْخٍ، قَالَ رَأَيْتُ سُفْيَانَ عِنْدَهُ عَنْ فَاطِمَةَ بِنْتِ حُسَيْنٍ، عَنْ أَبِيهَا، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1666}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The above mentioned tradition has also been transmitted by 'Ali through a different chain of narrators in a similar manner from the Prophet(ﷺ)}}
\hadithdefcmd{abudawud}{1667}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بُجَيْدٍ، عَنْ جَدَّتِهِ أُمِّ بُجَيْدٍ، وَكَانَتْ، مِمَّنْ بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَّهَا قَالَتْ لَهُ يَا رَسُولَ اللَّهِ صَلَّى اللَّهُ عَلَيْكَ إِنَّ الْمِسْكِينَ لَيَقُومُ عَلَى بَابِي فَمَا أَجِدُ لَهُ شَيْئًا أُعْطِيهِ إِيَّاهُ ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ لَمْ تَجِدِي لَهُ شَيْئًا تُعْطِينَهُ إِيَّاهُ إِلاَّ ظِلْفًا مُحْرَقًا فَادْفَعِيهِ إِلَيْهِ فِي يَدِهِ ‏"‏ ‏.‏\hadithno{1667}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Bujayd: She took the oath of allegiance to the Messenger of Allah (ﷺ) and said to him: Messenger of Allah, a poor man stands at my door, but I find nothing to give him. The Messenger of Allah (ﷺ) said to her: If you do not find anything to give him, put something in his hand, even though it should be a burnt hoof}}
\hadithdefcmd{abudawud}{1668}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ، قَالَتْ قَدِمَتْ عَلَىَّ أُمِّي رَاغِبَةً فِي عَهْدِ قُرَيْشٍ وَهِيَ رَاغِمَةٌ مُشْرِكَةٌ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي قَدِمَتْ عَلَىَّ وَهِيَ رَاغِمَةٌ مُشْرِكَةٌ أَفَأَصِلُهَا قَالَ ‏ "‏ نَعَمْ فَصِلِي أُمَّكِ ‏"‏ ‏.‏\hadithno{1668}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2620) Sahih Muslim (1003)}\hadithtrans{Asma‘ said My mother came to me seeking some act of kindness from me during the treaty of the Quraish (at Hudaibiyyah). While she hated Islam and she was a polytheist. I said Messenger of Allah (ﷺ), my mother has come to me while she hates Islam and she is a disbeliever. May I do an act of kindness to her? He replied Yes, do an act of kindness to her}}
\hadithdefcmd{abudawud}{1669}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا كَهْمَسٌ، عَنْ سَيَّارِ بْنِ مَنْظُورٍ، - رَجُلٍ مِنْ بَنِي فَزَارَةَ - عَنْ أَبِيهِ، عَنِ امْرَأَةٍ، يُقَالُ لَهَا بُهَيْسَةُ عَنْ أَبِيهَا، قَالَتِ اسْتَأْذَنَ أَبِي النَّبِيَّ صلى الله عليه وسلم فَدَخَلَ بَيْنَهُ وَبَيْنَ قَمِيصِهِ فَجَعَلَ يُقَبِّلُ وَيَلْتَزِمُ ثُمَّ قَالَ يَا رَسُولَ اللَّهِ مَا الشَّىْءُ الَّذِي لاَ يَحِلُّ مَنْعُهُ قَالَ ‏"‏ الْمَاءُ ‏"‏ ‏.‏ قَالَ يَا نَبِيَّ اللَّهِ مَا الشَّىْءُ الَّذِي لاَ يَحِلُّ مَنْعُهُ قَالَ ‏"‏ الْمِلْحُ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَا الشَّىْءُ الَّذِي لاَ يَحِلُّ مَنْعُهُ قَالَ ‏"‏ أَنْ تَفْعَلَ الْخَيْرَ خَيْرٌ لَكَ ‏"‏ ‏.‏\hadithno{1669}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif}\hadithtrans{Buhaysah reported on the authority of his father:My father sought permission from the Prophet (ﷺ). (When permission was granted and he came near him) he lifted his shirt, and began to kiss him and embrace him (out of love for him). He asked: Messenger of Allah, what is the thing which it is unlawful to refuse? He replied: Water. He again asked: Prophet of Allah, what is the thing which it is unlawful to refuse? He replied: Salt. He again asked: Prophet of Allah, what is the thing which it is unlawful to refuse? He said: To do good is better for you}}
\hadithdefcmd{abudawud}{1670}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ السَّهْمِيُّ، حَدَّثَنَا مُبَارَكُ بْنُ فَضَالَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَلْ مِنْكُمْ أَحَدٌ أَطْعَمَ الْيَوْمَ مِسْكِينًا ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ رضى الله عنه - دَخَلْتُ الْمَسْجِدَ فَإِذَا أَنَا بِسَائِلٍ يَسْأَلُ فَوَجَدْتُ كِسْرَةَ خُبْزٍ فِي يَدِ عَبْدِ الرَّحْمَنِ فَأَخَذْتُهَا مِنْهُ فَدَفَعْتُهَا إِلَيْهِ ‏.‏\hadithno{1670}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abd al-Rahman bin Abu Bakr (may Allah be pleased with him) said The Messenger of Allah (ﷺ) asked Is there anyone of you who provided food to a poor man today? Abu Bakr said I entered the mosque where a beggar was begging ; I found a piece of bread in the hand of ‘Abdal-Rahman which I took and gave it to him}}
\hadithdefcmd{abudawud}{1671}{حَدَّثَنَا أَبُو الْعَبَّاسِ الْقِلَّوْرِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِسْحَاقَ الْحَضْرَمِيُّ، عَنْ سُلَيْمَانَ بْنِ مُعَاذٍ التَّيْمِيِّ، حَدَّثَنَا ابْنُ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُسْأَلُ بِوَجْهِ اللَّهِ إِلاَّ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{1671}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: Nothing but Paradise must be begged for Allah's sake}}
\hadithdefcmd{abudawud}{1672}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اسْتَعَاذَ بِاللَّهِ فَأَعِيذُوهُ وَمَنْ سَأَلَ بِاللَّهِ فَأَعْطُوهُ وَمَنْ دَعَاكُمْ فَأَجِيبُوهُ وَمَنْ صَنَعَ إِلَيْكُمْ مَعْرُوفًا فَكَافِئُوهُ فَإِنْ لَمْ تَجِدُوا مَا تُكَافِئُونَهُ فَادْعُوا لَهُ حَتَّى تَرَوْا أَنَّكُمْ قَدْ كَافَأْتُمُوهُ ‏"‏ ‏.‏\hadithno{1672}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: If anyone seeks protection in Allah's name, grant him protection; if anyone begs in Allah's name, give him something; if anyone gives you an invitation, accept it; and if anyone does you a kindness, recompense him; but if you have not the means to do so, pray for him until you feel that you have compensated him}}
\hadithdefcmd{abudawud}{1673}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَ رَجُلٌ بِمِثْلِ بَيْضَةٍ مِنْ ذَهَبٍ فَقَالَ يَا رَسُولَ اللَّهِ أَصَبْتُ هَذِهِ مِنْ مَعْدِنٍ فَخُذْهَا فَهِيَ صَدَقَةٌ مَا أَمْلِكُ غَيْرَهَا ‏.‏ فَأَعْرَضَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ أَتَاهُ مِنْ قِبَلِ رُكْنِهِ الأَيْمَنِ فَقَالَ مِثْلَ ذَلِكَ فَأَعْرَضَ عَنْهُ ثُمَّ أَتَاهُ مِنْ قِبَلِ رُكْنِهِ الأَيْسَرِ فَأَعْرَضَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ أَتَاهُ مِنْ خَلْفِهِ فَأَخَذَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَحَذَفَهُ بِهَا فَلَوْ أَصَابَتْهُ لأَوْجَعَتْهُ أَوْ لَعَقَرَتْهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْتِي أَحَدُكُمْ بِمَا يَمْلِكُ فَيَقُولُ هَذِهِ صَدَقَةٌ ثُمَّ يَقْعُدُ يَسْتَكِفُّ النَّاسَ خَيْرُ الصَّدَقَةِ مَا كَانَ عَنْ ظَهْرِ غِنًى ‏"‏ ‏.‏\hadithno{1673}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah Al-Ansari: While we were sitting with the Messenger of Allah (ﷺ) a man brought him some gold equal in weight to an egg, and said: Messenger of Allah, I have got this from a mine; take it; it is sadaqah. I have no more than this. The Messenger of Allah (ﷺ) turned his attention from him. Then he came to him from his right side and repeated the same words. But he (the Prophet) turned his attention from him. He then came to him from his left side and repeated the same words. But he (again) turned his attention from him. He then came to him from behind. The Messenger of Allah (ﷺ) took it and threw it away. Had it hit him, it would have hurt him or wounded him. The Messenger of Allah (ﷺ) said: One of you brings all that he possesses and says: This is sadaqah. Then he sits down and spreads his hand before the people. The best sadaqah is that which leaves a competence}}
\hadithdefcmd{abudawud}{1674}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنِ ابْنِ إِسْحَاقَ، بِإِسْنَادِهِ وَمَعْنَاهُ زَادَ ‏ "‏ خُذْ عَنَّا مَالَكَ لاَ حَاجَةَ لَنَا بِهِ ‏"‏ ‏.‏\hadithno{1674}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The above mentioned tradition has also been transmitted by Ibn Ishaq through a different chain of narrators to the same effect. This version adds "have your property with you from us. We have no need of it}}
\hadithdefcmd{abudawud}{1675}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدٍ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ دَخَلَ رَجُلٌ الْمَسْجِدَ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم النَّاسَ أَنْ يَطْرَحُوا ثِيَابًا فَطَرَحُوا فَأَمَرَ لَهُ مِنْهَا بِثَوْبَيْنِ ثُمَّ حَثَّ عَلَى الصَّدَقَةِ فَجَاءَ فَطَرَحَ أَحَدَ الثَّوْبَيْنِ فَصَاحَ بِهِ وَقَالَ ‏ "‏ خُذْ ثَوْبَكَ ‏"‏ ‏.‏\hadithno{1675}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Sa'id al-Khudri: A man entered the mosque. The Prophet (ﷺ) commanded the people to throw their clothes as sadaqah. Thereupon they threw their clothes (as sadaqah). He then asked him to take two clothes from them. He reprimanded him and said: Take your clothe}}
\hadithdefcmd{abudawud}{1676}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ خَيْرَ الصَّدَقَةِ مَا تَرَكَ غِنًى أَوْ تُصُدِّقَ بِهِ عَنْ ظَهْرِ غِنًى وَابْدَأْ بِمَنْ تَعُولُ ‏"‏ ‏.‏\hadithno{1676}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5355)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying The best sadaqah is that which leaves a competence ; and begin with those for whom you are responsible}}
\hadithdefcmd{abudawud}{1677}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، قَالاَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ يَحْيَى بْنِ جَعْدَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏ "‏ جُهْدُ الْمُقِلِّ وَابْدَأْ بِمَنْ تَعُولُ ‏"‏ ‏.‏\hadithno{1677}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported I asked Messenger of Allah (ﷺ), What kind of sadaqah is most excellent? He replied What a man with little property can afford to give; and begin with those for whom you are responsible}}
\hadithdefcmd{abudawud}{1678}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - وَهَذَا حَدِيثُهُ - قَالاَ حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، - رضى الله عنه - يَقُولُ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا أَنْ نَتَصَدَّقَ فَوَافَقَ ذَلِكَ مَالاً عِنْدِي فَقُلْتُ الْيَوْمَ أَسْبِقُ أَبَا بَكْرٍ إِنْ سَبَقْتُهُ يَوْمًا فَجِئْتُ بِنِصْفِ مَالِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَبْقَيْتَ لأَهْلِكَ ‏"‏ ‏.‏ قُلْتُ مِثْلَهُ ‏.‏ قَالَ وَأَتَى أَبُو بَكْرٍ - رضى الله عنه - بِكُلِّ مَا عِنْدَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَبْقَيْتَ لأَهْلِكَ ‏"‏ ‏.‏ قَالَ أَبْقَيْتُ لَهُمُ اللَّهَ وَرَسُولَهُ ‏.‏ قُلْتُ لاَ أُسَابِقُكَ إِلَى شَىْءٍ أَبَدًا ‏.‏\hadithno{1678}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umar ibn al-Khattab: The Messenger of Allah (ﷺ) commanded us one day to give sadaqah. At that time I had some property. I said: Today I shall surpass AbuBakr if I surpass him any day. I, therefore, brought half my property. The Messenger of Allah (ﷺ) asked: What did you leave for your family? I replied: The same amount. AbuBakr brought all that he had with him. The Messenger of Allah (ﷺ) asked him: What did you leave for your family? He replied: I left Allah and His Apostle for them. I said: I shall never compete you in anything}}
\hadithdefcmd{abudawud}{1679}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ سَعِيدٍ، أَنَّ سَعْدًا، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَىُّ الصَّدَقَةِ أَعْجَبُ إِلَيْكَ قَالَ ‏ "‏ الْمَاءُ ‏"‏ ‏.‏\hadithno{1679}\hadithgrade{Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Sa’id reported Sa’d came to the Prophet (SWAS) and asked him Which sadaqah do you like most? He replied Water}}
\hadithdefcmd{abudawud}{1680}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَالْحَسَنِ، عَنْ سَعْدِ بْنِ عُبَادَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{1680}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{The above mentioned tradition has also been narrated by Sa’d bin ‘Ubadah from the Prophet (ﷺ) in the same manner}}
\hadithdefcmd{abudawud}{1681}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ رَجُلٍ، عَنْ سَعْدِ بْنِ عُبَادَةَ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمَّ سَعْدٍ مَاتَتْ فَأَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏ "‏ الْمَاءُ ‏"‏ ‏.‏ قَالَ فَحَفَرَ بِئْرًا وَقَالَ هَذِهِ لأُمِّ سَعْدٍ ‏.‏\hadithno{1681}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd ibn Ubadah: Sa'd asked: Messenger of Allah, Umm Sa'd has died; what form of sadaqah is best? He replied: Water (is best). He dug a well and said: It is for Umm Sa'd}}
\hadithdefcmd{abudawud}{1682}{حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ إِبْرَاهِيمَ بْنِ إِشْكَابَ، حَدَّثَنَا أَبُو بَدْرٍ، حَدَّثَنَا أَبُو خَالِدٍ، - الَّذِي كَانَ يَنْزِلُ فِي بَنِي دَالاَنَ - عَنْ نُبَيْحٍ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا مُسْلِمٍ كَسَا مُسْلِمًا ثَوْبًا عَلَى عُرْىٍ كَسَاهُ اللَّهُ مِنْ خُضْرِ الْجَنَّةِ وَأَيُّمَا مُسْلِمٍ أَطْعَمَ مُسْلِمًا عَلَى جُوعٍ أَطْعَمَهُ اللَّهُ مِنْ ثِمَارِ الْجَنَّةِ وَأَيُّمَا مُسْلِمٍ سَقَى مُسْلِمًا عَلَى ظَمَإٍ سَقَاهُ اللَّهُ مِنَ الرَّحِيقِ الْمَخْتُومِ ‏"‏ ‏.‏\hadithno{1682}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'id (al-Khudri): The Prophet (ﷺ) said: If any Muslim clothes a Muslim when he is naked, Allah will clothe him with some green garments of Paradise; if any Muslim feeds a Muslim when he is hungry, Allah will feed him with some of the fruits of Paradise; and if any Muslim gives a Muslim drink when he is thirsty, Allah will give him some of the pure wine which is sealed to drink}}
\hadithdefcmd{abudawud}{1683}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا إِسْرَائِيلُ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى، - وَهَذَا حَدِيثُ مُسَدَّدٍ وَهُوَ أَتَمُّ - عَنِ الأَوْزَاعِيِّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ أَبِي كَبْشَةَ السَّلُولِيِّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْبَعُونَ خَصْلَةً أَعْلاَهُنَّ مَنِيحَةُ الْعَنْزِ مَا يَعْمَلُ رَجُلٌ بِخَصْلَةٍ مِنْهَا رَجَاءَ ثَوَابِهَا وَتَصْدِيقَ مَوْعُودِهَا إِلاَّ أَدْخَلَهُ اللَّهُ بِهَا الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ فِي حَدِيثِ مُسَدَّدٍ قَالَ حَسَّانُ فَعَدَدْنَا مَا دُونَ مَنِيحَةِ الْعَنْزِ مِنْ رَدِّ السَّلاَمِ وَتَشْمِيتِ الْعَاطِسِ وَإِمَاطَةِ الأَذَى عَنِ الطَّرِيقِ وَنَحْوِهِ فَمَا اسْتَطَعْنَا أَنْ نَبْلُغَ خَمْسَ عَشْرَةَ خَصْلَةً ‏.‏\hadithno{1683}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2631)}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: There are forty characteristics; the highest of them is to give a goat on loan (for benefiting from its milk). If any man carries out any of those characteristics with the hope of getting a reward and testifying to the promise for it, Allah will admit him to Paradise for it. Abu Dawud said: In the version of Musaddad, Hassan said: So we counted other characteristics than lending the goat: to return the greeting, to respond to sneezing, and remove things which cause annoyance to the people from their path, and similar other things. We could not reach fifteen characteristics}}
\hadithdefcmd{abudawud}{1684}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْخَازِنَ الأَمِينَ - الَّذِي يُعْطِي مَا أُمِرَ بِهِ كَامِلاً مُوَفَّرًا طَيِّبَةً بِهِ نَفْسُهُ حَتَّى يَدْفَعَهُ إِلَى الَّذِي أُمِرَ لَهُ بِهِ - أَحَدُ الْمُتَصَدِّقَيْنِ ‏"‏ ‏.‏\hadithno{1684}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1438) Sahih Muslim (1023)}\hadithtrans{Abu Musa reported The Messenger of Allah (ﷺ) as saying The faithful trustee who gives what he is commanded completely and in full with a good will, and delivers it to the one whom he was told to give it, is one of the two who gives sadaqah}}
\hadithdefcmd{abudawud}{1685}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ بَيْتِ زَوْجِهَا غَيْرَ مُفْسِدَةٍ كَانَ لَهَا أَجْرُ مَا أَنْفَقَتْ وَلِزَوْجِهَا أَجْرُ مَا اكْتَسَبَ وَلِخَازِنِهِ مِثْلُ ذَلِكَ لاَ يَنْقُصُ بَعْضُهُمْ أَجْرَ بَعْضٍ ‏"‏ ‏.‏\hadithno{1685}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1425) Sahih Muslim (1024)}\hadithtrans{A’ishah reported The Messenger of Allah (ﷺ) as saying When a woman gives (some of the property) from her husband’s house, not wasting it, she will have her reward for what she has spent, and her husband will have his for what he earned. The said applies to a trustee. In no respect does the one diminish the reward of the other}}
\hadithdefcmd{abudawud}{1686}{حَدَّثَنَا مُحَمَّدُ بْنُ سَوَّارٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ زِيَادِ بْنِ جُبَيْرٍ، عَنْ سَعْدٍ، قَالَ لَمَّا بَايَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم النِّسَاءَ قَامَتِ امْرَأَةٌ جَلِيلَةٌ كَأَنَّهَا مِنْ نِسَاءِ مُضَرَ فَقَالَتْ يَا نَبِيَّ اللَّهِ إِنَّا كَلٌّ عَلَى آبَائِنَا وَأَبْنَائِنَا - قَالَ أَبُو دَاوُدَ وَأُرَى فِيهِ وَأَزْوَاجِنَا - فَمَا يَحِلُّ لَنَا مِنْ أَمْوَالِهِمْ فَقَالَ ‏ "‏ الرَّطْبُ تَأْكُلْنَهُ وَتُهْدِينَهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الرَّطْبُ الْخُبْزُ وَالْبَقْلُ وَالرُّطَبُ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا رَوَاهُ الثَّوْرِيُّ عَنْ يُونُسَ ‏.‏\hadithno{1686}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sa’d said When the Messenger of Allah (SWAS) took the oath of allegiance from woman, a woman of high rank, who seemed to be one of the women of Mudar, rose and said Prophet of Allah (SWAS), we are dependant on our parents, our sons. (Abu Dawud said I think (this version) has the word “ and our husbands”. ) So what part of their property can be spent lawfully? He said Fresh food which you eat and give as a present. Abu Dawud said The Arabic word ratb means bread, vegetables and fresh dates. Abu Dawud said Al-Thawri transmitted from Yunus in a similar manner}}
\hadithdefcmd{abudawud}{1687}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ كَسْبِ زَوْجِهَا مِنْ غَيْرِ أَمْرِهِ فَلَهَا نِصْفُ أَجْرِهِ ‏"‏ ‏.‏\hadithno{1687}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5360) Sahih Muslim (1026)}\hadithtrans{Abu Hurairah reported The Messenger of Allah (ﷺ) as saying When a woman gives something her husband has earned without being commanded by him to do so, she has half his reward}}
\hadithdefcmd{abudawud}{1688}{حَدَّثَنَا مُحَمَّدُ بْنُ سَوَّارٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدَةُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، فِي الْمَرْأَةِ تَصَدَّقُ مِنْ بَيْتِ زَوْجِهَا قَالَ لاَ إِلاَّ مِنْ قُوتِهَا وَالأَجْرُ بَيْنَهُمَا وَلاَ يَحِلُّ لَهَا أَنْ تَصَدَّقَ مِنْ مَالِ زَوْجِهَا إِلاَّ بِإِذْنِهِ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا يُضَعِّفُ حَدِيثَ هَمَّامٍ ‏.‏\hadithno{1688}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Ata said Abu Hurairah was asked Whether a woman could give sadaqah from the house (property) of her husband. He replied `No’. She can give it from her maintenance. The reward will be divided between them. It is not lawful for her to give sadaqah from her husband’s property without his permission. Abu Dawud said This version weakens the version narrated by Hammam (bin Munabbih)}}
\hadithdefcmd{abudawud}{1689}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ لَمَّا نَزَلَتْ ‏\{‏ لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ ‏\}‏ قَالَ أَبُو طَلْحَةَ يَا رَسُولَ اللَّهِ أَرَى رَبَّنَا يَسْأَلُنَا مِنْ أَمْوَالِنَا فَإِنِّي أُشْهِدُكَ أَنِّي قَدْ جَعَلْتُ أَرْضِي بِأَرِيحَاءَ لَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْعَلْهَا فِي قَرَابَتِكَ ‏"‏ ‏.‏ فَقَسَمَهَا بَيْنَ حَسَّانَ بْنِ ثَابِتٍ وَأُبَىِّ بْنِ كَعْبٍ ‏.‏ قَالَ أَبُو دَاوُدَ بَلَغَنِي عَنِ الأَنْصَارِيِّ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ قَالَ أَبُو طَلْحَةَ زَيْدُ بْنُ سَهْلِ بْنِ الأَسْوَدِ بْنِ حَرَامِ بْنِ عَمْرِو بْنِ زَيْدِ مَنَاةَ بْنِ عَدِيِّ بْنِ عَمْرِو بْنِ مَالِكِ بْنِ النَّجَّارِ وَحَسَّانُ بْنُ ثَابِتِ بْنِ الْمُنْذِرِ بْنِ حَرَامٍ يَجْتَمِعَانِ إِلَى حَرَامٍ وَهُوَ الأَبُ الثَّالِثُ وَأُبَىُّ بْنُ كَعْبِ بْنِ قَيْسِ بْنِ عَتِيكِ بْنِ زَيْدِ بْنِ مُعَاوِيَةَ بْنِ عَمْرِو بْنِ مَالِكِ بْنِ النَّجَّارِ فَعَمْرٌو يَجْمَعُ حَسَّانَ وَأَبَا طَلْحَةَ وَأُبَيًّا ‏.‏ قَالَ الأَنْصَارِيُّ بَيْنَ أُبَىٍّ وَأَبِي طَلْحَةَ سِتَّةُ آبَاءٍ ‏.‏\hadithno{1689}\hadithgrade{Al-Albani: Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (998)}\hadithtrans{Anas said When the verse “You will never attain righteousness until you give freely of what you love" came down, Abu Talhah said Messenger of Allah (ﷺ), I think our Lord asks us for our property. I call you as witness that I dedicate my land at Ariha ‘to Him’. The Messenger of Allah (ﷺ) said to him Divide it among your nearest relatives. So he divided it among Hassan bin Thabit and Ubayy bin Ka’b. Abu Dawud said I have been gold by an Ansari Muhammad bin ‘Abdallah that the name of Abu Talhah is Zaid bin Sahal bin al-Aswad bin Haram bin ‘Amar bin Zaid bin Manat bin ‘Adi bin ‘Amr bin Malik bin al-Najjar; and Hassan bin Tabit is son of al-Mundhir in al-Haram. Thus both of them (Abu Talhah and Hassan) have their common link in Haram who is the third great grandfather. Ubbay bin Ka’b is son of Qais bin ‘Atik bin Zaid bin Mu’awiyah bin ‘Amr bin Malik bin al-Najjar. Thus the common tie between Hassan, Abu Talhah and Ubbay is ‘Amr (bin Malik). The Ansari said between Ubbay and Abi Talhah there are six great grandfathers}}
\hadithdefcmd{abudawud}{1690}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَتْ لِي جَارِيَةٌ فَأَعْتَقْتُهَا فَدَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏ "‏ آجَرَكِ اللَّهُ أَمَا إِنَّكِ لَوْ كُنْتِ أَعْطَيْتِهَا أَخْوَالَكِ كَانَ أَعْظَمَ لأَجْرِكِ ‏"‏ ‏.‏\hadithno{1690}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Maimunah, wife of the Probhet (ﷺ) said :I had a slave girl and I set her free. When the Prophet (ﷺ) entered upon me, I informed him (of this). He said : May Allah give reward for it; if you had given her to your maternal uncles, it would have increased your reward}}
\hadithdefcmd{abudawud}{1691}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَ النَّبِيُّ صلى الله عليه وسلم بِالصَّدَقَةِ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ عِنْدِي دِينَارٌ ‏.‏ فَقَالَ ‏"‏ تَصَدَّقْ بِهِ عَلَى نَفْسِكَ ‏"‏ ‏.‏ قَالَ عِنْدِي آخَرُ ‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهِ عَلَى وَلَدِكَ ‏"‏ ‏.‏ قَالَ عِنْدِي آخَرُ ‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهِ عَلَى زَوْجَتِكَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ زَوْجِكَ ‏"‏ ‏.‏ قَالَ عِنْدِي آخَرُ ‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهِ عَلَى خَادِمِكَ ‏"‏ ‏.‏ قَالَ عِنْدِي آخَرُ ‏.‏ قَالَ ‏"‏ أَنْتَ أَبْصَرُ ‏"‏ ‏.‏\hadithno{1691}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) commanded to give sadaqah. A man said: Messenger of Allah, I have a dinar. He said: Spend it on yourself. He again said: I have another. He said: Spend it on your children. He again said: I have another. He said: Spend it on your wife. He again said: I have another. He said: Spend it on your servant. He finally said: I have another. He replied: You know best (what to do with it)}}
\hadithdefcmd{abudawud}{1692}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ وَهْبِ بْنِ جَابِرٍ الْخَيْوَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَفَى بِالْمَرْءِ إِثْمًا أَنْ يُضَيِّعَ مَنْ يَقُوتُ ‏"‏ ‏.‏\hadithno{1692}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abd Allah bin ‘Amr reported the Messenger of Allah (ﷺ) as saying :It is sufficient sin for a man that he neglects him whom he maintains}}
\hadithdefcmd{abudawud}{1693}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَيَعْقُوبُ بْنُ كَعْبٍ، - وَهَذَا حَدِيثُهُ - قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَرَّهُ أَنْ يُبْسَطَ لَهُ فِي رِزْقِهِ وَيُنْسَأَ لَهُ فِي أَثَرِهِ فَلْيَصِلْ رَحِمَهُ ‏"‏ ‏.‏\hadithno{1693}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2067) Sahih Muslim (2557)}\hadithtrans{Anas reported the Messenger of Allah (ﷺ) as saying :Anyone who is pleased that his sustenance is expanded and his age extended should do kindness to his near relatives}}
\hadithdefcmd{abudawud}{1694}{حَدَّثَنَا مُسَدَّدٌ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ أَنَا الرَّحْمَنُ وَهِيَ الرَّحِمُ شَقَقْتُ لَهَا اسْمًا مِنَ اسْمِي مَنْ وَصَلَهَا وَصَلْتُهُ وَمَنْ قَطَعَهَا بَتَتُّهُ ‏"‏ ‏.‏\hadithno{1694}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbdurRahman ibn Awf: I heard the Messenger of Allah (ﷺ) say: Allah the Exalted has said: I am Compassionate, and this has been derived from mercy. I have derived its name from My name. If anyone joins it, I shall join him, and if anyone cuts it off, I shall cut him off}}
\hadithdefcmd{abudawud}{1695}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي أَبُو سَلَمَةَ، أَنَّ الرَّدَّادَ اللَّيْثِيَّ، أَخْبَرَهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏\hadithno{1695}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The above mentioned tradition has also been narrated by `Abd al-Rahman bin ‘Awf from the Messenger of Allah (SWAS) through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{1696}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ قَاطِعُ رَحِمٍ ‏"‏ ‏.‏\hadithno{1696}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5984) Sahih Muslim (2556)}\hadithtrans{Jubair bin Mut’im reported on the authority of his father:The Prophet(ﷺ) said: Anyone who cuts off relationship from his nearest relatives will not enter Paradise}}
\hadithdefcmd{abudawud}{1697}{حَدَّثَنَا ابْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، وَالْحَسَنِ بْنِ عَمْرٍو، وَفِطْرٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، - قَالَ سُفْيَانُ وَلَمْ يَرْفَعْهُ سُلَيْمَانُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَرَفَعَهُ فِطْرٌ وَالْحَسَنُ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ الْوَاصِلُ بِالْمُكَافِئِ وَلَكِنَّ الْوَاصِلَ هُوَ الَّذِي إِذَا قُطِعَتْ رَحِمُهُ وَصَلَهَا ‏"‏ ‏.‏\hadithno{1697}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5991)}\hadithtrans{Abd Allah bin `Amr said :(Sufyan said : The version of the narrator Sulaiman does not go back to The Prophet (SAWS). Fitr and al-Hasan reported from him ) : The Messenger of Allah (SAWS) said : One who compensates is not a man who unites relationship : but the man who unites relationship is the one who joins it when the relationship is cut off}}
\hadithdefcmd{abudawud}{1698}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِيَّاكُمْ وَالشُّحَّ فَإِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ بِالشُّحِّ أَمَرَهُمْ بِالْبُخْلِ فَبَخَلُوا وَأَمَرَهُمْ بِالْقَطِيعَةِ فَقَطَعُوا وَأَمَرَهُمْ بِالْفُجُورِ فَفَجَرُوا ‏"‏ ‏.‏\hadithno{1698}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) preached and said: Abstain from avarice, for those who had been before you were annihilated due to avarice. It (avarice) commanded them to show niggardliness; it commanded them to cut off their relationship with their nearest relatives, so they cut off. It commanded them to show profligacy, so they showed it}}
\hadithdefcmd{abudawud}{1699}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا أَيُّوبُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، حَدَّثَتْنِي أَسْمَاءُ بِنْتُ أَبِي بَكْرٍ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَا لِي شَىْءٌ إِلاَّ مَا أَدْخَلَ عَلَىَّ الزُّبَيْرُ بَيْتَهُ أَفَأُعْطِي مِنْهُ قَالَ ‏ "‏ أَعْطِي وَلاَ تُوكِي فَيُوكِيَ عَلَيْكِ ‏"‏ ‏.‏\hadithno{1699}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Asma, daughter of Abu Bakr, said :I said : Messenger of Allah(SAWS), I have nothing of my own except what al-Zubair (her husband) brings to me in his house: should I spend out of it? He said : Give and do not hoard so your sustenance will be hoarded}}
\hadithdefcmd{abudawud}{1700}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا أَيُّوبُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، أَنَّهَا ذَكَرَتْ عِدَّةً مِنْ مَسَاكِينَ - قَالَ أَبُو دَاوُدَ وَقَالَ غَيْرُهُ أَوْ عِدَّةً مِنْ صَدَقَةٍ - فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعْطِي وَلاَ تُحْصِي فَيُحْصِيَ عَلَيْكِ ‏"‏ ‏.‏\hadithno{1700}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Mulaykah reported:Aisha counted a number of indigents. AbuDawud said: The other version has: She counted a number of sadaqahs. The Messenger of Allah (ﷺ) said: Give and do not calculate, so calculation will be made against you}}
