% Auto-generated chapter 10 for tirmidhi
% Hadiths in this chapter: 115

\hadithdefcmd{tirmidhi}{965}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُصِيبُ الْمُؤْمِنَ شَوْكَةٌ فَمَا فَوْقَهَا إِلاَّ رَفَعَهُ اللَّهُ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ وَأَبِي عُبَيْدَةَ بْنِ الْجَرَّاحِ وَأَبِي هُرَيْرَةَ وَأَبِي أُمَامَةَ وَأَبِي سَعِيدٍ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَسَدِ بْنِ كُرْزٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَعَبْدِ الرَّحْمَنِ بْنِ أَزْهَرَ وَأَبِي مُوسَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{965}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Aishah narrated that:The Messenger of Allah said: "The believer is not afflicted by the prick of a thorn or what is worse (or greater) than that, except that by it Allah raises him in rank and removes sin from him}}
\hadithdefcmd{tirmidhi}{966}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ شَيْءٍ يُصِيبُ الْمُؤْمِنَ مِنْ نَصَبٍ وَلاَ حَزَنٍ وَلاَ وَصَبٍ حَتَّى الْهَمُّ يَهُمُّهُ إِلاَّ يُكَفِّرُ اللَّهُ بِهِ عَنْهُ سَيِّئَاتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ فِي هَذَا الْبَابِ ‏.‏ قَالَ وَسَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ لَمْ يُسْمَعْ فِي الْهَمِّ أَنَّهُ يَكُونُ كَفَّارَةً إِلاَّ فِي هَذَا الْحَدِيثِ ‏.‏ قَالَ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{966}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri (may Allah be pleased with him) narrated that:The Messenger of Allah said: "Nothing afflicts the believer, whether fatigue, grief, disease - even a worry that concerns him - except that by it, Allah removes something from his bad deeds}}
\hadithdefcmd{tirmidhi}{967}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمُسْلِمَ إِذَا عَادَ أَخَاهُ الْمُسْلِمَ لَمْ يَزَلْ فِي خُرْفَةِ الْجَنَّةِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي مُوسَى وَالْبَرَاءِ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ثَوْبَانَ حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى أَبُو غِفَارٍ وَعَاصِمٌ الأَحْوَلُ هَذَا الْحَدِيثَ عَنْ أَبِي قِلاَبَةَ عَنْ أَبِي الأَشْعَثِ عَنْ أَبِي أَسْمَاءَ عَنْ ثَوْبَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يَقُولُ مَنْ رَوَى هَذَا الْحَدِيثَ عَنْ أَبِي الأَشْعَثِ عَنْ أَبِي أَسْمَاءَ فَهُوَ أَصَحُّ ‏.‏ قَالَ مُحَمَّدٌ وَأَحَادِيثُ أَبِي قِلاَبَةَ إِنَّمَا هِيَ عَنْ أَبِي أَسْمَاءَ إِلاَّ هَذَا الْحَدِيثَ فَهُوَ عِنْدِي عَنْ أَبِي الأَشْعَثِ عَنْ أَبِي أَسْمَاءَ ‏.‏\hadithno{967}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Thawban narrated that :the Prophet said: "Indeed the Muslim remains in the Khurfah (harvest) of Paradise while he visits his brother Muslim}}
\hadithdefcmd{tirmidhi}{968}{حَدَّثَنَا مُحَمَّدُ بْنُ وَزِيرٍ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَزَادَ فِيهِ قِيلَ مَا خُرْفَةُ الْجَنَّةِ قَالَ ‏ "‏ جَنَاهَا ‏"‏ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ خَالِدٍ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي الأَشْعَثِ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَاهُ بَعْضُهُمْ عَنْ حَمَّادِ بْنِ زَيْدٍ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{968}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{(Another chain) from Thawban who narrated that:The Prophet said similarly, but he added in it: "They said: 'What is the Khurfah of Paradise?' And he said: "Its harvest}}
\hadithdefcmd{tirmidhi}{969}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ ثُوَيْرٍ، هُوَ ابْنُ أَبِي فَاخِتَةَ عَنْ أَبِيهِ، قَالَ أَخَذَ عَلِيٌّ بِيَدِي قَالَ انْطَلِقْ بِنَا إِلَى الْحَسَنِ نَعُودُهُ ‏.‏ فَوَجَدْنَا عِنْدَهُ أَبَا مُوسَى فَقَالَ عَلِيٌّ عَلَيْهِ السَّلاَمُ أَعَائِدًا جِئْتَ يَا أَبَا مُوسَى أَمْ زَائِرًا فَقَالَ لاَ بَلْ عَائِدًا ‏.‏ فَقَالَ عَلِيٌّ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ مُسْلِمٍ يَعُودُ مُسْلِمًا غُدْوَةً إِلاَّ صَلَّى عَلَيْهِ سَبْعُونَ أَلْفَ مَلَكٍ حَتَّى يُمْسِيَ وَإِنْ عَادَهُ عَشِيَّةً إِلاَّ صَلَّى عَلَيْهِ سَبْعُونَ أَلْفَ مَلَكٍ حَتَّى يُصْبِحَ وَكَانَ لَهُ خَرِيفٌ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَقَدْ رُوِيَ عَنْ عَلِيٍّ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ مِنْهُمْ مَنْ وَقَفَهُ وَلَمْ يَرْفَعْهُ ‏.‏ وَأَبُو فَاخِتَةَ اسْمُهُ سَعِيدُ بْنُ عِلاَقَةَ ‏.‏\hadithno{969}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Thuwair [and he is Ibn Abi Fakhitah] narrated that :His father said: "Ali took me by the hand and said: 'Come with us to pay a visit to Al-Hasan.' So we found that Abu Musa was with him.' Ali - peace be upon him - said: 'O Abu Musa! Did you come to visit (the sick) or merely (stop by to) visit?' He said: 'No, to visit (the sick).' So Ali said: 'I heard the Messenger of Allah saying: "No Muslim visits (the sick) Muslims in the morning, except that sevety-thousand angels, sent Salat upon him until the evening, and he does not visit at night except that seventy thousand angels sent Salat upon him until the morning, and there will be a garden for him in Paradise}}
\hadithdefcmd{tirmidhi}{970}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ مُضَرِّبٍ، قَالَ دَخَلْتُ عَلَى خَبَّابٍ وَقَدِ اكْتَوَى فِي بَطْنِهِ فَقَالَ مَا أَعْلَمُ أَحَدًا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم لَقِيَ مِنَ الْبَلاَءِ مَا لَقِيتُ لَقَدْ كُنْتُ وَمَا أَجِدُ دِرْهَمًا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَفِي نَاحِيَةٍ مِنْ بَيْتِي أَرْبَعُونَ أَلْفًا وَلَوْلاَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا - أَوْ نَهَى - أَنْ نَتَمَنَّى الْمَوْتَ لَتَمَنَّيْتُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي هُرَيْرَةَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ خَبَّابٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدُكُمُ الْمَوْتَ لِضُرٍّ نَزَلَ بِهِ وَلْيَقُلِ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏."‏\hadithno{970}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Harithah bin Mudarrib said:"I entered upon Khabab and he had been cauterized on his stomach. He said: 'I do not know any of the Companions of the Prophet who met with the trial I have met with. Indeed I could not find a Dirham during the time of the Prophet, and (now) outside my house there are forty thousand. If it were not that the Messenger of Allah forbade us' - or: 'forbade' - 'from wishing for death, then I would wish for it}}
\hadithdefcmd{tirmidhi}{971}{حَدَّثَنَا بِذَلِكَ عَلِيُّ بْنُ حُجْرٍ أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ عَنْ أَنَسِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{971}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{Anas bin Malik narrated that:The Prophet said that (a Hadith similar to no)}}
\hadithdefcmd{tirmidhi}{972}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الْبَصْرِيُّ الصَّوَّافُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ جِبْرِيلَ، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ اشْتَكَيْتَ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ بِاسْمِ اللَّهِ أَرْقِيكَ مِنْ كُلِّ شَيْءٍ يُؤْذِيكَ مِنْ شَرِّ كُلِّ نَفْسٍ وَعَيْنِ حَاسِدٍ بِاسْمِ اللَّهِ أَرْقِيكَ وَاللَّهُ يَشْفِيكَ ‏.‏\hadithno{972}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sa'eed narrated that:Jibril came to the Prophet and said: "O Muhammad! Are you suffering?" He said: "Yes." He said: "In the Name of Allah, I recite a prayer (Ruqyah) over you, from the evil of every person and evil eye. In the Name of Allah I recite a prayer (Ruqyah) over you, may Allah cure you}}
\hadithdefcmd{tirmidhi}{973}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، قَالَ دَخَلْتُ أَنَا وَثَابِتٌ الْبُنَانِيُّ، عَلَى أَنَسِ بْنِ مَالِكٍ فَقَالَ ثَابِتٌ يَا أَبَا حَمْزَةَ اشْتَكَيْتُ ‏.‏ فَقَالَ أَنَسٌ أَفَلاَ أَرْقِيكَ بِرُقْيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ بَلَى ‏.‏ قَالَ ‏ "‏ اللَّهُمَّ رَبَّ النَّاسِ مُذْهِبَ الْبَاسِ اشْفِ أَنْتَ الشَّافِي لاَ شَافِيَ إِلاَّ أَنْتَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَسَأَلْتُ أَبَا زُرْعَةَ عَنْ هَذَا الْحَدِيثِ فَقُلْتُ لَهُ رِوَايَةُ عَبْدِ الْعَزِيزِ عَنْ أَبِي نَضْرَةَ عَنْ أَبِي سَعِيدٍ أَصَحُّ أَوْ حَدِيثُ عَبْدِ الْعَزِيزِ عَنْ أَنَسٍ قَالَ كِلاَهُمَا صَحِيحٌ ‏.‏ وَرَوَى عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ عَنْ أَبِيهِ عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ عَنْ أَبِي نَضْرَةَ عَنْ أَبِي سَعِيدٍ وَعَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ عَنْ أَنَسٍ ‏.‏\hadithno{973}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdul-Aziz bin Suhaib said:"Thabit Al-Bunani and I entered upon Anas bin Malik, and Thabit said: 'O Abu Hamzah! I am suffering from an illness. So Anas said: 'Shall I not recite the Ruqyah of the Messenger of Allah over you?' He said: 'Why, yes.' He said: 'O Allah! Lord of mankind, removed the harm, and cure (him). Indeed You are the One Who cures, there is none who cures except you, a cure that leaves no disease}}
\hadithdefcmd{tirmidhi}{974}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ يَبِيتُ لَيْلَتَيْنِ وَلَهُ شَيْءٌ يُوصِي فِيهِ إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ أَبِي أَوْفَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{974}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that:The Messenger of Allah said: "A Muslim man has no right to spend two nights while he has something to will, except while his will is recorded with him}}
\hadithdefcmd{tirmidhi}{975}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ سَعْدِ بْنِ مَالِكٍ، قَالَ عَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَرِيضٌ فَقَالَ ‏"‏ أَوْصَيْتَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ بِكَمْ ‏"‏ ‏.‏ قُلْتُ بِمَالِي كُلِّهِ فِي سَبِيلِ اللَّهِ ‏.‏ قَالَ ‏"‏ فَمَا تَرَكْتَ لِوَلَدِكَ ‏"‏ ‏.‏ قُلْتُ هُمْ أَغْنِيَاءُ بِخَيْرٍ ‏.‏ قَالَ ‏"‏ أَوْصِ بِالْعُشْرِ ‏"‏ ‏.‏ فَمَا زِلْتُ أُنَاقِصُهُ حَتَّى قَالَ ‏"‏ أَوْصِ بِالثُّلُثِ وَالثُّلُثُ كَثِيرٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَنَحْنُ نَسْتَحِبُّ أَنْ يَنْقُصَ مِنَ الثُّلُثِ لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالثُّلُثُ كَثِيرٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَعْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ وَقَدْ رُوِيَ عَنْهُ ‏"‏ وَالثُّلُثُ كَبِيرٌ ‏"‏ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ أَنْ يُوصِيَ الرَّجُلُ بِأَكْثَرَ مِنَ الثُّلُثِ وَيَسْتَحِبُّونَ أَنْ يَنْقُصَ مِنَ الثُّلُثِ ‏.‏ قَالَ سُفْيَانُ الثَّوْرِيُّ كَانُوا يَسْتَحِبُّونَ فِي الْوَصِيَّةِ الْخُمُسَ دُونَ الرُّبُعِ وَالرُّبُعَ دُونَ الثُّلُثِ وَمَنْ أَوْصَى بِالثُّلُثِ فَلَمْ يَتْرُكْ شَيْئًا وَلاَ يَجُوزُ لَهُ إِلاَّ الثُّلُثُ ‏.‏\hadithno{975}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sa'd bin Malik said:"The Messenger of Allah came to visit me while I was sick. He said: 'Do you have a will?' I said: 'Yes.' He said: 'For how much?' I said: 'All of my wealth, for the cause of Allah.' He said: 'What did you leave for your children?'" He (Sa'd) said: "They are rich in goodness.' He said: 'Will a tenth.'" He (Sa'd) said: "He (pbuh) continued decreasing it until he said: 'Will a third, and a third is too great.'" (One of the narrators:) Abdur-Rahman said: "We considered it recommended that it be less than a third, since the Messenger of Allah said: 'And a third is too great}}
\hadithdefcmd{tirmidhi}{976}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ الْبَصْرِيُّ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَقِّنُوا مَوْتَاكُمْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأُمِّ سَلَمَةَ وَعَائِشَةَ وَجَابِرٍ وَسُعْدَى الْمُرِّيَّةِ وَهِيَ امْرَأَةُ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{976}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sa'eed Al-Khudri narrated that:The Prophet said: "Instruct your dying to say: (La illaha illallah) 'None has the right to be worshipped but Allah}}
\hadithdefcmd{tirmidhi}{977}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا حَضَرْتُمُ الْمَرِيضَ أَوِ الْمَيِّتَ فَقُولُوا خَيْرًا فَإِنَّ الْمَلاَئِكَةَ يُؤَمِّنُونَ عَلَى مَا تَقُولُونَ ‏"‏ ‏.‏ قَالَتْ فَلَمَّا مَاتَ أَبُو سَلَمَةَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سَلَمَةَ مَاتَ ‏.‏ قَالَ ‏"‏ فَقُولِي اللَّهُمَّ اغْفِرْ لِي وَلَهُ وَأَعْقِبْنِي مِنْهُ عُقْبَى حَسَنَةً ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ فَأَعْقَبَنِي اللَّهُ مِنْهُ مَنْ هُوَ خَيْرٌ مِنْهُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى شَقِيقٌ هُوَ ابْنُ سَلَمَةَ أَبُو وَائِلٍ الأَسَدِيُّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُمِّ سَلَمَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَانَ يُسْتَحَبُّ أَنْ يُلَقَّنَ الْمَرِيضُ عِنْدَ الْمَوْتِ قَوْلَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا قَالَ ذَلِكَ مَرَّةً فَمَا لَمْ يَتَكَلَّمْ بَعْدَ ذَلِكَ فَلاَ يَنْبَغِي أَنْ يُلَقَّنَ وَلاَ يُكْثَرَ عَلَيْهِ فِي هَذَا ‏.‏ وَرُوِيَ عَنِ ابْنِ الْمُبَارَكِ أَنَّهُ لَمَّا حَضَرَتْهُ الْوَفَاةُ جَعَلَ رَجُلٌ يُلَقِّنُهُ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَكْثَرَ عَلَيْهِ فَقَالَ لَهُ عَبْدُ اللَّهِ إِذَا قُلْتُ مَرَّةً فَأَنَا عَلَى ذَلِكَ مَا لَمْ أَتَكَلَّمْ بِكَلاَمٍ ‏.‏ وَإِنَّمَا مَعْنَى قَوْلِ عَبْدِ اللَّهِ إِنَّمَا أَرَادَ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ آخِرُ قَوْلِهِ لاَ إِلَهَ إِلاَّ اللَّهُ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{977}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Umm Salamah narrated:"The Messenger of Allah said to us: 'When you attend to the sick or dying then say only good, for indeed the angels say "Amin" to what you say.'" She said: "When Abu Salamah died I went to the Prophet and said: 'O Messenger of Allah! Abu Salamah has died.' He said: 'Then say: "O Allah forgive me and him, and give me a good replacement for him." She said: "I said tat, and Allah gave a replace that was better than him: The Messenger of Allah}}
\hadithdefcmd{tirmidhi}{978}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ مُوسَى بْنِ سَرْجِسَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ بِالْمَوْتِ وَعِنْدَهُ قَدَحٌ فِيهِ مَاءٌ وَهُوَ يُدْخِلُ يَدَهُ فِي الْقَدَحِ ثُمَّ يَمْسَحُ وَجْهَهُ بِالْمَاءِ ثُمَّ يَقُولُ ‏"‏ اللَّهُمَّ أَعِنِّي عَلَى غَمَرَاتِ الْمَوْتِ ‏"‏ ‏.‏ أَوْ ‏"‏ سَكَرَاتِ الْمَوْتِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{978}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated:"I saw the Messenger of Allah while he was dying. He had a cup with water in it, he put his hand in the cup then wiped his face with the water, then said: 'O Allah! Help me with the throes of death and the agony of death}}
\hadithdefcmd{tirmidhi}{979}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَغْدَادِيُّ، حَدَّثَنَا مُبَشِّرُ بْنُ إِسْمَاعِيلَ الْحَلَبِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، عَنْ عَائِشَةَ، قَالَتْ مَا أَغْبِطُ أَحَدًا بِهَوْنِ مَوْتٍ بَعْدَ الَّذِي رَأَيْتُ مِنْ شِدَّةِ مَوْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ سَأَلْتُ أَبَا زُرْعَةَ عَنْ هَذَا الْحَدِيثِ وَقُلْتُ لَهُ مَنْ عَبْدُ الرَّحْمَنِ بْنُ الْعَلاَءِ فَقَالَ هُوَ ابْنُ الْعَلاَءِ بْنِ اللَّجْلاَجِ ‏.‏ وَإِنَّمَا عَرَّفَهُ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{979}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Aishah narrated:"I was not envious of anyone whose death was easy after I saw the severity the death of the Messenger of Allah}}
\hadithdefcmd{tirmidhi}{980}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حُسَامُ بْنُ الْمِصَكِّ، قَالَ حَدَّثَنَا أَبُو مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ نَفْسَ الْمُؤْمِنِ تَخْرُجُ رَشْحًا وَلاَ أُحِبُّ مَوْتًا كَمَوْتِ الْحِمَارِ ‏"‏ ‏.‏ قِيلَ وَمَا مَوْتُ الْحِمَارِ قَالَ ‏"‏ مَوْتُ الْفَجْأَةِ ‏"‏ ‏.‏\hadithno{980}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Alqamah narrated:"I heard Abdullah saying: 'I heard the Messenger of Allah saying: "The believer's soul seeps out, and I do not like the death like that of a donkey." They said: "And what is the death of a donkey?" He said: "A sudden death}}
\hadithdefcmd{tirmidhi}{981}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا مُبَشِّرُ بْنُ إِسْمَاعِيلَ الْحَلَبِيُّ، عَنْ تَمَّامِ بْنِ نَجِيحٍ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ حَافِظَيْنِ رَفَعَا إِلَى اللَّهِ مَا حَفِظَا مِنْ لَيْلٍ أَوْ نَهَارٍ فَيَجِدُ اللَّهُ فِي أَوَّلِ الصَّحِيفَةِ وَفِي آخِرِ الصَّحِيفَةِ خَيْرًا إِلاَّ قَالَ اللَّهُ تَعَالَى أُشْهِدُكُمْ أَنِّي قَدْ غَفَرْتُ لِعَبْدِي مَا بَيْنَ طَرَفَىِ الصَّحِيفَةِ ‏"‏ ‏.‏\hadithno{981}\hadithgrade{Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that:The Messenger of Allah said: "There is nothing that the two Guardian Angels raise to Allah that they have preserved in a day or night, and Allah finds good in the beginning of the scroll and in the end of the scroll, except that Allah Most High says: 'Bear witness that I have forgiven my servant for what is included in the scroll}}
\hadithdefcmd{tirmidhi}{982}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُؤْمِنُ يَمُوتُ بِعَرَقِ الْجَبِينِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ لا نَعْرِفُ لِقَتَادَةَ سَمَاعًا مِنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ ‏.‏\hadithno{982}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Buraidah narrated from his father, that:The Prophet said: "The believer dies with sweat on his brow}}
\hadithdefcmd{tirmidhi}{983}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ الْكُوفِيُّ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ الْبَزَّازُ الْبَغْدَادِيُّ، قَالاَ حَدَّثَنَا سَيَّارٌ، هُوَ ابْنُ حَاتِمٍ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَى شَابٍّ وَهُوَ فِي الْمَوْتِ فَقَالَ ‏"‏ كَيْفَ تَجِدُكَ ‏"‏ ‏.‏ قَالَ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنِّي أَرْجُو اللَّهَ وَإِنِّي أَخَافُ ذُنُوبِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَجْتَمِعَانِ فِي قَلْبِ عَبْدٍ فِي مِثْلِ هَذَا الْمَوْطِنِ إِلاَّ أَعْطَاهُ اللَّهُ مَا يَرْجُو وَآمَنَهُ مِمَّا يَخَافُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ ثَابِتٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{983}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Thabit narrated from Anas, that:The Prophet entered upon a young man while he was dying. So he said: "How do you feel?" He said: "By Allah! O Messenger of Allah! Indeed I hope in Allah and I fear from my sins." So the Messenger of Allah said: "These two will not be gathered in a worshipper's heart at a time such as this, except that Allah will grant him what he hopes and make him safe from what he fears}}
\hadithdefcmd{tirmidhi}{984}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا حَكَّامُ بْنُ سَلْمٍ، وَهَارُونُ بْنُ الْمُغِيرَةِ، عَنْ عَنْبَسَةَ، عَنْ أَبِي حَمْزَةَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ وَالنَّعْىَ فَإِنَّ النَّعْىَ مِنْ عَمَلِ الْجَاهِلِيَّةِ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ وَالنَّعْىُ أَذَانٌ بِالْمَيِّتِ ‏.‏ وَفِي الْبَابِ عَنْ حُذَيْفَةَ ‏.‏\hadithno{984}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah narrated that:The Prophet said: "Beware of An-Na'i, for indeed announcing one's death is from the deeds of Jahliyyah}}
\hadithdefcmd{tirmidhi}{985}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْوَلِيدِ الْعَدَنِيُّ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ أَبِي حَمْزَةَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، نَحْوَهُ وَلَمْ يَرْفَعْهُ وَلَمْ يَذْكُرْ فِيهِ وَالنَّعْىُ أَذَانٌ بِالْمَيِّتِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ عَنْبَسَةَ عَنْ أَبِي حَمْزَةَ ‏.‏ وَأَبُو حَمْزَةَ هُوَ مَيْمُونٌ الأَعْوَرُ وَلَيْسَ هُوَ بِالْقَوِيِّ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ النَّعْىَ وَالنَّعْىُ عِنْدَهُمْ أَنْ يُنَادَى فِي النَّاسِ أَنَّ فُلاَنًا مَاتَ لِيَشْهَدُوا جَنَازَتَهُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ بَأْسَ أَنْ يُعْلِمَ أَهْلَ قَرَابَتِهِ وَإِخْوَانَهُ ‏.‏ وَرُوِيَ عَنْ إِبْرَاهِيمَ أَنَّهُ قَالَ لاَ بَأْسَ بِأَنْ يُعْلِمَ الرَّجُلُ قَرَابَتَهُ ‏.‏\hadithno{985}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{(Another chain) from Abdullah :(from the Prophet) similar (to no. 984), but he did not narrate it in Marfu form, and he did not mention in it: "An-Na'i is announcing of one's death}}
\hadithdefcmd{tirmidhi}{986}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ بَكْرِ بْنِ خُنَيْسٍ، حَدَّثَنَا حَبِيبُ بْنُ سُلَيْمٍ الْعَبْسِيُّ، عَنْ بِلاَلِ بْنِ يَحْيَى الْعَبْسِيِّ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، قَالَ إِذَا مِتُّ فَلاَ تُؤْذِنُوا بِي أَحَدًا إِنِّي أَخَافُ أَنْ يَكُونَ نَعْيًا فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ النَّعْىِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{986}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Bilal bin Yahya Al-Absiy narrated that:Hudaifah (bin Al-Yaman) said: "When I do not announce about me to anyone, indeed I fear that it would be An-Na'i, and I heard the Messenger of Allah prohibiting from An-Na'i}}
\hadithdefcmd{tirmidhi}{987}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّبْرُ فِي الصَّدْمَةِ الأُولَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{987}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas narrated that:The Messenger of Allah said: "(Real) Patience is at the first stroke of the calamity}}
\hadithdefcmd{tirmidhi}{988}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّبْرُ عِنْدَ الصَّدْمَةِ الأُولَى ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{988}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated that:The Messenger of Alllah said: "(Real) Patience is at the first stroke of the calamity}}
\hadithdefcmd{tirmidhi}{989}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَبَّلَ عُثْمَانَ بْنَ مَظْعُونٍ وَهُوَ مَيِّتٌ وَهُوَ يَبْكِي ‏.‏ أَوْ قَالَ عَيْنَاهُ تَذْرِفَانِ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَجَابِرٍ وَعَائِشَةَ قَالُوا إِنَّ أَبَا بَكْرٍ قَبَّلَ النَّبِيَّ صلى الله عليه وسلم وَهُوَ مَيِّتٌ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{989}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Al-Qasim bin Muhammad narrated from Aishah:"The Prophet kissed Uthman bin Maz'un when he died, and he was crying." Or, he (one of the narrators) said: "His eyes were brimming with tears}}
\hadithdefcmd{tirmidhi}{990}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا خَالِدٌ، وَمَنْصُورٌ، وَهِشَامٌ، فَأَمَّا خَالِدٌ وَهِشَامٌ فَقَالاَ عَنْ مُحَمَّدٍ وَحَفْصَةَ وَقَالَ مَنْصُورٌ عَنْ مُحَمَّدٍ عَنْ أُمِّ عَطِيَّةَ قَالَتْ تُوُفِّيَتْ إِحْدَى بَنَاتِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ اغْسِلْنَهَا وِتْرًا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ وَاغْسِلْنَهَا بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَلْقَى إِلَيْنَا حِقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا بِهِ ‏"‏ ‏.‏ قَالَ هُشَيْمٌ وَفِي حَدِيثِ غَيْرِ هَؤُلاَءِ وَلاَ أَدْرِي وَلَعَلَّ هِشَامًا مِنْهُمْ قَالَتْ وَضَفَّرْنَا شَعْرَهَا ثَلاَثَةَ قُرُونٍ ‏.‏ قَالَ هُشَيْمٌ أَظُنُّهُ قَالَ فَأَلْقَيْنَاهُ خَلْفَهَا ‏.‏ قَالَ هُشَيْمٌ فَحَدَّثَنَا خَالِدٌ مِنْ بَيْنِ الْقَوْمِ عَنْ حَفْصَةَ وَمُحَمَّدٍ عَنْ أُمِّ عَطِيَّةَ قَالَتْ وَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أُمِّ سُلَيْمٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُمِّ عَطِيَّةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَقَدْ رُوِيَ عَنْ إِبْرَاهِيمَ النَّخَعِيِّ أَنَّهُ قَالَ غُسْلُ الْمَيِّتِ كَالْغُسْلِ مِنَ الْجَنَابَةِ ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ لَيْسَ لِغُسْلِ الْمَيِّتِ عِنْدَنَا حَدٌّ مُؤَقَّتٌ وَلَيْسَ لِذَلِكَ صِفَةٌ مَعْلُومَةٌ وَلَكِنْ يُطَهَّرُ ‏.‏ وَقَالَ الشَّافِعِيُّ إِنَّمَا قَالَ مَالِكٌ قَوْلاً مُجْمَلاً يُغَسَّلُ وَيُنْقَى وَإِذَا أُنْقِيَ الْمَيِّتُ بِمَاءٍ قَرَاحٍ أَوْ مَاءٍ غَيْرِهِ أَجْزَأَ ذَلِكَ مِنْ غُسْلِهِ وَلَكِنْ أَحَبُّ إِلَىَّ أَنْ يُغْسَلَ ثَلاَثًا فَصَاعِدًا لاَ يُنْقَصُ عَنْ ثَلاَثٍ لِمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا ‏"‏ ‏.‏ وَإِنْ أَنْقَوْا فِي أَقَلَّ مِنْ ثَلاَثِ مَرَّاتٍ أَجْزَأَ وَلاَ يَرَى أَنَّ قَوْلَ النَّبِيِّ صلى الله عليه وسلم إِنَّمَا هُوَ عَلَى مَعْنَى الإِنْقَاءِ ثَلاَثًا أَوْ خَمْسًا وَلَمْ يُؤَقِّتْ ‏.‏ وَكَذَلِكَ قَالَ الْفُقَهَاءُ وَهُمْ أَعْلَمُ بِمَعَانِي الْحَدِيثِ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ وَتَكُونُ الْغَسَلاَتُ بِمَاءٍ وَسِدْرٍ وَيَكُونُ فِي الآخِرَةِ شَيْءٌ مِنْ كَافُورٍ ‏.‏\hadithno{990}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Umm Atiyyah narrated:"One of the daughters of the Prophet died, so he said: 'Wash her an odd number of times, three, or five, or more than that as you see fit. Wash her with water and Sidr, and in the last (washing) add camphor, or something from camphor. When you are finished then inform me.' When we finished we informed him so he gave us his waist-sheet and said 'Wrap her in it}}
\hadithdefcmd{tirmidhi}{991}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، وَشَبَابَةُ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ خُلَيْدِ بْنِ جَعْفَرٍ، سَمِعَ أَبَا نَضْرَةَ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَطْيَبُ الطِّيبِ الْمِسْكُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{991}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sa'eed Al-Khudri narrated that:The Messenger of Allah said: "The best scent is the perfume of musk}}
\hadithdefcmd{tirmidhi}{992}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ شُعْبَةَ، عَنْ خُلَيْدِ بْنِ جَعْفَرٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنِ الْمِسْكِ فَقَالَ ‏ "‏ هُوَ أَطْيَبُ طِيبِكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ الْمِسْكَ لِلْمَيِّتِ ‏.‏ قَالَ وَقَدْ رَوَاهُ الْمُسْتَمِرُّ بْنُ الرَّيَّانِ أَيْضًا عَنْ أَبِي نَضْرَةَ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ عَلِيٌّ قَالَ يَحْيَى بْنُ سَعِيدٍ الْمُسْتَمِرُّ بْنُ الرَّيَّانِ ثِقَةٌ ‏.‏ قَالَ يَحْيَى خُلَيْدُ بْنُ جَعْفَرٍ ثِقَةٌ ‏.‏\hadithno{992}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed narrated that:The Prophet was asked about musk and he said: "It is the best of your perfumes}}
\hadithdefcmd{tirmidhi}{993}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْ غُسْلِهِ الْغُسْلُ وَمِنْ حَمْلِهِ الْوُضُوءُ ‏"‏ ‏.‏ يَعْنِي الْمَيِّتَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ مَوْقُوفًا ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الَّذِي يُغَسِّلُ الْمَيِّتَ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِذَا غَسَّلَ مَيِّتًا فَعَلَيْهِ الْغُسْلُ ‏.‏ وَقَالَ بَعْضُهُمْ عَلَيْهِ الْوُضُوءُ ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ أَسْتَحِبُّ الْغُسْلَ مِنْ غُسْلِ الْمَيِّتِ وَلاَ أَرَى ذَلِكَ وَاجِبًا ‏.‏ وَهَكَذَا قَالَ الشَّافِعِيُّ ‏.‏ وَقَالَ أَحْمَدُ مَنْ غَسَّلَ مَيِّتًا أَرْجُو أَنْ لاَ يَجِبَ عَلَيْهِ الْغُسْلُ وَأَمَّا الْوُضُوءُ فَأَقَلُّ مَا قِيلَ فِيهِ ‏.‏ وَقَالَ إِسْحَاقُ لاَ بُدَّ مِنَ الْوُضُوءِ ‏.‏ قَالَ وَقَدْ رُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ أَنَّهُ قَالَ لاَ بَأْسَ أَنْ لاَ يَغْتَسِلَ وَلاَ يَتَوَضَّأَ مَنْ غَسَّلَ الْمَيِّتَ ‏.‏\hadithno{993}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "Ghusl for one who washed him and Wudu for one who carried himm}}
\hadithdefcmd{tirmidhi}{994}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَسُوا مِنْ ثِيَابِكُمُ الْبَيَاضَ فَإِنَّهَا مِنْ خَيْرِ ثِيَابِكُمْ وَكَفِّنُوا فِيهَا مَوْتَاكُمْ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ سَمُرَةَ وَابْنِ عُمَرَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي يَسْتَحِبُّهُ أَهْلُ الْعِلْمِ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ أَحَبُّ إِلَىَّ أَنْ يُكَفَّنَ فِي ثِيَابِهِ الَّتِي كَانَ يُصَلِّي فِيهَا ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ أَحَبُّ الثِّيَابِ إِلَيْنَا أَنْ يُكَفَّنَ فِيهَا الْبَيَاضُ وَيُسْتَحَبُّ حُسْنُ الْكَفَنِ ‏.‏\hadithno{994}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated that:The Messenger of Allah said: "Wear the white among your garments, for indeed they are among the best of your garments, and shroud your dead in them}}
\hadithdefcmd{tirmidhi}{995}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا وَلِيَ أَحَدُكُمْ أَخَاهُ فَلْيُحَسِّنْ كَفَنَهُ ‏"‏ ‏.‏ وَفِيهِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ قَالَ سَلاَّمُ بْنُ أَبِي مُطِيعٍ فِي قَوْلِهِ ‏"‏ وَلْيُحَسِّنْ أَحَدُكُمْ كَفَنَ أَخِيهِ ‏"‏ قَالَ هُوَ الصِّفَاقُ لَيْسَ بِالْمُرْتَفِعِ ‏.‏\hadithno{995}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Abu Qatadah narrated that:The Messenger of Allah said: "When one of you shrouds his brother, then let him use the best of his shrouds}}
\hadithdefcmd{tirmidhi}{996}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُفِّنَ النَّبِيُّ صلى الله عليه وسلم فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ يَمَانِيَةٍ لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ ‏.‏ قَالَ فَذَكَرُوا لِعَائِشَةَ قَوْلَهُمْ فِي ثَوْبَيْنِ وَبُرْدِ حِبَرَةٍ ‏.‏ فَقَالَتْ قَدْ أُتِيَ بِالْبُرْدِ وَلَكِنَّهُمْ رَدُّوهُ وَلَمْ يُكَفِّنُوهُ فِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{996}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Hisham bin Urwah narrated from his father that:Aishah said: "The Prophet was shrouded in three white Yemeni cloths, there was no shirt nor turban among them." He said: "So they mentioned the saying of the others to Aishah, that there were two garments and a Habir Burd. She said: 'A Burd was brought, but they refused it and they did not shroud him in it}}
\hadithdefcmd{tirmidhi}{997}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، عَنْ زَائِدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَفَّنَ حَمْزَةَ بْنَ عَبْدِ الْمُطَّلِبِ فِي نَمِرَةٍ فِي ثَوْبٍ وَاحِدٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ فِي كَفَنِ النَّبِيِّ صلى الله عليه وسلم رِوَايَاتٌ مُخْتَلِفَةٌ وَحَدِيثُ عَائِشَةَ أَصَحُّ الأَحَادِيثِ الَّتِي رُوِيَتْ فِي كَفَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالْعَمَلُ عَلَى حَدِيثِ عَائِشَةَ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ قَالَ سُفْيَانُ الثَّوْرِيُّ يُكَفَّنُ الرَّجُلُ فِي ثَلاَثِ أَثْوَابٍ إِنْ شِئْتَ فِي قَمِيصٍ وَلِفَافَتَيْنِ وَإِنْ شِئْتَ فِي ثَلاَثِ لَفَائِفَ وَيُجْزِئُ ثَوْبٌ وَاحِدٌ إِنْ لَمْ يَجِدُوا ثَوْبَيْنِ وَالثَّوْبَانِ يُجْزِيَانِ وَالثَّلاَثَةُ لِمَنْ وَجَدَهَا أَحَبُّ إِلَيْهِمْ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالُوا تُكَفَّنُ الْمَرْأَةُ فِي خَمْسَةِ أَثْوَابٍ ‏.‏\hadithno{997}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin Abdullah narrated:"The Messenger of Allah shrouded Hamzah bin Abdul-Muttalib in one cloth of Namirah}}
\hadithdefcmd{tirmidhi}{998}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ جَعْفَرِ بْنِ خَالِدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ لَمَّا جَاءَ نَعْىُ جَعْفَرٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اصْنَعُوا لأَهْلِ جَعْفَرٍ طَعَامًا فَإِنَّهُ قَدْ جَاءَهُمْ مَا يَشْغَلُهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ كَانَ بَعْضُ أَهْلِ الْعِلْمِ يَسْتَحِبُّ أَنْ يُوَجَّهَ إِلَى أَهْلِ الْمَيِّتِ شَيْءٌ لِشُغْلِهِمْ بِالْمُصِيبَةِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ قَالَ أَبُو عِيسَى وَجَعْفَرُ بْنُ خَالِدٍ هُوَ ابْنُ سَارَةَ وَهُوَ ثِقَةٌ رَوَى عَنْهُ ابْنُ جُرَيْجٍ ‏.‏\hadithno{998}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Ja'far said:"When the news of the death of Ja'far came, the Prophet said: 'Prepare some food for the family of Ja'far, for indeed something has happened to them that will keep them busy}}
\hadithdefcmd{tirmidhi}{999}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي زُبَيْدٌ الأَيَامِيُّ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنَّا مَنْ شَقَّ الْجُيُوبَ وَضَرَبَ الْخُدُودَ وَدَعَا بِدَعْوَةِ الْجَاهِلِيَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{999}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah narrated that:The Prophet said: "He who slaps (his) cheeks, tears (his) clothes and calls with the call of the Jahliyyah is not one of us}}
\hadithdefcmd{tirmidhi}{1000}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا قُرَّانُ بْنُ تَمَّامٍ الأَسَدِيُّ، وَمَرْوَانُ بْنُ مُعَاوِيَةَ، وَيَزِيدُ بْنُ هَارُونَ، عَنْ سَعِيدِ بْنِ عُبَيْدٍ الطَّائِيِّ، عَنْ عَلِيِّ بْنِ رَبِيعَةَ الأَسَدِيِّ، قَالَ مَاتَ رَجُلٌ مِنَ الأَنْصَارِ يُقَالُ لَهُ قَرَظَةُ بْنُ كَعْبٍ فَنِيحَ عَلَيْهِ فَجَاءَ الْمُغِيرَةُ بْنُ شُعْبَةُ فَصَعِدَ الْمِنْبَرَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَقَالَ مَا بَالُ النَّوْحِ فِي الإِسْلاَمِ أَمَا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ نِيحَ عَلَيْهِ عُذِّبَ بِمَا نِيحَ عَلَيْهِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَأَبِي مُوسَى وَقَيْسِ بْنِ عَاصِمٍ وَأَبِي هُرَيْرَةَ وَجُنَادَةَ بْنِ مَالِكٍ وَأَنَسٍ وَأُمِّ عَطِيَّةَ وَسَمُرَةَ وَأَبِي مَالِكٍ الأَشْعَرِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْمُغِيرَةِ حَدِيثٌ غَرِيبٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1000}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ali bin Rabi'ah Al-Asadi said:"A man died among the Ansar named Qarazah bin Ka'b, and he was being wailed over. So Al-Mughirah bin Shu'bah came and ascended the Minbar. He uttered thanks and praise to Allah and said: "As for the gravity of wailing in Islam, indeed I heard the Messenger of Allah saying: 'The one who is wailed over is punished as long as he is being wailed over}}
\hadithdefcmd{tirmidhi}{1001}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، وَالْمَسْعُودِيُّ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ أَبِي الرَّبِيعِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْبَعٌ فِي أُمَّتِي مِنْ أَمْرِ الْجَاهِلِيَّةِ لَنْ يَدَعَهُنَّ النَّاسُ النِّيَاحَةُ وَالطَّعْنُ فِي الأَحْسَابِ وَالْعَدْوَى أَجْرَبَ بَعِيرٌ فَأَجْرَبَ مِائَةَ بَعِيرٍ مَنْ أَجْرَبَ الْبَعِيرَ الأَوَّلَ وَالأَنْوَاءُ مُطِرْنَا بِنَوْءِ كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1001}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"There are four matters in my nation that are from the matters of Jahiliyyah which the people will not leave: Wailing, slandering one's lineage, Al-Adwa - a camel gets mange, so one hundred camels get mange - but who gave the first camel mange? And Al-Anwa (saying): "We got rain because of this or that celestial positioning}}
\hadithdefcmd{tirmidhi}{1002}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَيِّتُ يُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ الْبُكَاءَ عَلَى الْمَيِّتِ قَالُوا الْمَيِّتُ يُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏.‏ وَذَهَبُوا إِلَى هَذَا الْحَدِيثِ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ أَرْجُو إِنْ كَانَ يَنْهَاهُمْ فِي حَيَاتِهِ أَنْ لاَ يَكُونَ عَلَيْهِ مِنْ ذَلِكَ شَيْءٌ ‏.‏\hadithno{1002}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umar bin Al-Khattab narrated that:The Messenger of Allah said: "The deceased is punished for the crying of his family over him}}
\hadithdefcmd{tirmidhi}{1003}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ عَمَّارٍ، حَدَّثَنِي أَسِيدُ بْنُ أَبِي أَسِيدٍ، أَنَّ مُوسَى بْنَ أَبِي مُوسَى الأَشْعَرِيِّ، أَخْبَرَهُ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مَيِّتٍ يَمُوتُ فَيَقُومُ بَاكِيهِ فَيَقُولُ وَاجَبَلاَهُ وَاسَيِّدَاهُ أَوْ نَحْوَ ذَلِكَ إِلاَّ وُكِّلَ بِهِ مَلَكَانِ يَلْهَزَانِهِ أَهَكَذَا كُنْتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1003}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Musa bin Abi Musa Al-Asha'ri narrated from his father that:The Messenger of Allah said: "No one dies and they stand over him crying and saying: 'O what a great man he was! O how respectful he was!' except that two angels are appointed for him to poke him (saying): 'Is that you?}}
\hadithdefcmd{tirmidhi}{1004}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ الْمُهَلَّبِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْمَيِّتُ يُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ يَرْحَمُهُ اللَّهُ لَمْ يَكْذِبْ وَلَكِنَّهُ وَهِمَ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِرَجُلٍ مَاتَ يَهُودِيًّا ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ وَإِنَّ أَهْلَهُ لَيَبْكُونَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَقَرَظَةَ بْنِ كَعْبٍ وَأَبِي هُرَيْرَةَ وَابْنِ مَسْعُودٍ وَأُسَامَةَ بْنِ زَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَائِشَةَ ‏.‏ وَقَدْ ذَهَبَ أَهْلُ الْعِلْمِ إِلَى هَذَا وَتَأَوَّلُوا هَذِهِ الآيَةَ (ألَّا تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى ‏)‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{1004}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Yahya bin Abdur-Rahman narrated from Ibn Umar that:The Prophet said: "The deceased is punished for the crying of his family over him." So, Aishah said: "May Allah have mercy upon him. He has not lied, but he is mistaken. It is only that the Messenger of Allah said about a Jewish man who died: 'The deceased is being punished and his family is crying over him}}
\hadithdefcmd{tirmidhi}{1005}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَخَذَ النَّبِيُّ صلى الله عليه وسلم بِيَدِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ فَانْطَلَقَ بِهِ إِلَى ابْنِهِ إِبْرَاهِيمَ فَوَجَدَهُ يَجُودُ بِنَفْسِهِ فَأَخَذَهُ النَّبِيُّ صلى الله عليه وسلم فَوَضَعَهُ فِي حِجْرِهِ فَبَكَى فَقَالَ لَهُ عَبْدُ الرَّحْمَنِ أَتَبْكِي أَوَلَمْ تَكُنْ نَهَيْتَ عَنِ الْبُكَاءِ قَالَ ‏ "‏ لاَ وَلَكِنْ نَهَيْتُ عَنْ صَوْتَيْنِ أَحْمَقَيْنِ فَاجِرَيْنِ صَوْتٍ عِنْدَ مُصِيبَةٍ خَمْشِ وُجُوهٍ وَشَقِّ جُيُوبٍ وَرَنَّةِ شَيْطَانٍ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ كَلاَمٌ أَكْثَرُ مِنْ هَذَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1005}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Jabir bin Abdullah narrated:"The Prophet took Abdur-Rahman bin Awf by the hand and went with him to his son Ibrahim. He found him in his last breaths, so he took him and put him on his lap and cried. Abdur-Rahman said to him: 'You cry? Didn't you prohibit (your followers) from crying?' He said: 'No. But I prohibited two foolish immoral voices: A voice during a calamity while clawing at one's face and tearing one's clothes, and Shaitan's scream.'" And there is more that is stated in the Hadith}}
\hadithdefcmd{tirmidhi}{1006}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، قَالَ وَحَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، سَمِعَتْ عَائِشَةَ، وَذُكِرَ، لَهَا أَنَّ ابْنَ عُمَرَ، يَقُولُ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ الْحَىِّ عَلَيْهِ ‏.‏ فَقَالَتْ عَائِشَةُ غَفَرَ اللَّهُ لأَبِي عَبْدِ الرَّحْمَنِ أَمَا إِنَّهُ لَمْ يَكْذِبْ وَلَكِنَّهُ نَسِيَ أَوْ أَخْطَأَ إِنَّمَا مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى يَهُودِيَّةٍ يُبْكَى عَلَيْهَا فَقَالَ ‏ "‏ إِنَّهُمْ لَيَبْكُونَ عَلَيْهَا وَإِنَّهَا لَتُعَذَّبُ فِي قَبْرِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{1006}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Abi Bakr - and he is Ibn Muhammad bin Amr bin Hazm - narrated from his father, that:Amrah informed him that she heard Aishah, while it was being mentioned to her that Ibn Umar had said that the deceased would be punished for the crying of the living (over him). So Aishah said: 'May Allah forgive Abu Abdur-Rahman. He has not lied, but he is mistaken in the understanding. Rather, the Messenger of Allah passed by a Jewish woman who was being cried over, so he said: 'They are crying over her and she is being punished in her grave}}
\hadithdefcmd{tirmidhi}{1007}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَحْمَدُ بْنُ مَنِيعٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ يَمْشُونَ أَمَامَ الْجَنَازَةِ ‏.‏\hadithno{1007}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Salim narrated that:His father said: "I saw the Prophet, Abu Bakr, and Umar walking in front of the funeral}}
\hadithdefcmd{tirmidhi}{1008}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، عَنْ هَمَّامٍ، عَنْ مَنْصُورٍ، وَبَكْرٍ الْكُوفِيِّ، وَزِيَادٍ، وَسُفْيَانَ، كُلُّهُمْ يَذْكُرُ أَنَّهُ سَمِعَهُ مِنَ الزُّهْرِيِّ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِيهِ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ يَمْشُونَ أَمَامَ الْجَنَازَةِ ‏.‏\hadithno{1008}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Salim bin Abdullah narrated that his father said:"I saw the Prophet, Abu Bakr, and Umar walking in front of the funeral}}
\hadithdefcmd{tirmidhi}{1009}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ يَمْشُونَ أَمَامَ الْجَنَازَةِ ‏.‏ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي سَالِمٌ أَنَّ أَبَاهُ كَانَ يَمْشِي أَمَامَ الْجَنَازَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ هَكَذَا رَوَاهُ ابْنُ جُرَيْجٍ وَزِيَادُ بْنُ سَعْدٍ وَغَيْرُ وَاحِدٍ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ نَحْوَ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏ وَرَوَى مَعْمَرٌ وَيُونُسُ بْنُ يَزِيدَ وَمَالِكٌ وَغَيْرُ وَاحِدٍ مِنَ الْحُفَّاظِ عَنِ الزُّهْرِيِّ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَمْشِي أَمَامَ الْجَنَازَةِ ‏.‏ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي سَالِمٌ أَنَّ أَبَاهُ كَانَ يَمْشِي أَمَامَ الْجَنَازَةِ ‏.‏ وَأَهْلُ الْحَدِيثِ كُلُّهُمْ يَرَوْنَ أَنَّ الْحَدِيثَ الْمُرْسَلَ فِي ذَلِكَ أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ يَحْيَى بْنَ مُوسَى يَقُولُ قَالَ عَبْدُ الرَّزَّاقِ قَالَ ابْنُ الْمُبَارَكِ حَدِيثُ الزُّهْرِيِّ فِي هَذَا مُرْسَلٌ أَصَحُّ مِنْ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏ قَالَ ابْنُ الْمُبَارَكِ وَأَرَى ابْنَ جُرَيْجٍ أَخَذَهُ عَنِ ابْنِ عُيَيْنَةَ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى هَمَّامُ بْنُ يَحْيَى هَذَا الْحَدِيثَ عَنْ زِيَادٍ وَهُوَ ابْنُ سَعْدٍ وَمَنْصُورٍ وَبَكْرٍ وَسُفْيَانَ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ ‏.‏ وَإِنَّمَا هُوَ سُفْيَانُ بْنُ عُيَيْنَةَ رَوَى عَنْهُ هَمَّامٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْمَشْىِ أَمَامَ الْجَنَازَةِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْمَشْىَ أَمَامَهَا أَفْضَلُ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ ‏.‏ قَالَ وَحَدِيثُ أَنَسٍ فِي هَذَا الْبَابِ غَيْرُ مَحْفُوظٍ ‏.‏\hadithno{1009}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Az-Zuhri said:"The Prophet, Abu Bakr, and Umar would walk in front of the funeral." Az-Zuhri said: "Salim informed me that his father would walk in front of the funeral}}
\hadithdefcmd{tirmidhi}{1010}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ وَعُثْمَانَ كَانُوا يَمْشُونَ أَمَامَ الْجَنَازَةِ ‏.‏ قَالَ أَبُو عِيسَى سَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ هَذَا حَدِيثٌ خَطَأٌ أَخْطَأَ فِيهِ مُحَمَّدُ بْنُ بَكْرٍ وَإِنَّمَا يُرْوَى هَذَا الْحَدِيثُ عَنْ يُونُسَ عَنِ الزُّهْرِيِّ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ كَانُوا يَمْشُونَ أَمَامَ الْجَنَازَةِ ‏.‏ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي سَالِمٌ أَنَّ أَبَاهُ كَانَ يَمْشِي أَمَامَ الْجَنَازَةِ ‏.‏ قَالَ مُحَمَّدٌ وَهَذَا أَصَحُّ ‏.‏\hadithno{1010}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik narrated:"The Messenger of Allah would walk in front of the funeral, as did Abu Bakr, Umar and Uthman}}
\hadithdefcmd{tirmidhi}{1011}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، عَنْ شُعْبَةَ، عَنْ يَحْيَى، إِمَامِ بَنِي تَيْمِ اللَّهِ عَنْ أَبِي مَاجِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ سَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمَشْىِ خَلْفَ الْجَنَازَةِ فَقَالَ ‏ "‏ مَا دُونَ الْخَبَبِ فَإِنْ كَانَ خَيْرًا عَجَّلْتُمُوهُ وَإِنْ كَانَ شَرًّا فَلاَ يُبَعَّدُ إِلاَّ أَهْلُ النَّارِ الْجَنَازَةُ مَتْبُوعَةٌ وَلاَ تَتْبَعُ وَلَيْسَ مِنْهَا مَنْ تَقَدَّمَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ يُعْرَفُ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يُضَعِّفُ حَدِيثَ أَبِي مَاجِدٍ هَذَا ‏.‏ وَقَالَ مُحَمَّدٌ قَالَ الْحُمَيْدِيُّ قَالَ ابْنُ عُيَيْنَةَ قِيلَ لِيَحْيَى مَنْ أَبُو مَاجِدٍ هَذَا قَالَ طَائِرٌ طَارَ فَحَدَّثَنَا ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِلَى هَذَا رَأَوْا أَنَّ الْمَشْىَ خَلْفَهَا أَفْضَلُ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَإِسْحَاقُ ‏.‏ قَالَ إِنَّ أَبَا مَاجِدٍ رَجُلٌ مَجْهُولٌ لاَ يُعْرَفُ إِنَّمَا يُرْوَى عَنْهُ حَدِيثَانِ عَنِ ابْنِ مَسْعُودٍ ‏.‏ وَيَحْيَى إِمَامُ بَنِي تَيْمِ اللَّهِ ثِقَةٌ يُكْنَى أَبَا الْحَارِثِ وَيُقَالُ لَهُ يَحْيَى الْجَابِرُ وَيُقَالُ لَهُ يَحْيَى الْمُجْبِرُ أَيْضًا وَهُوَ كُوفِيٌّ رَوَى لَهُ شُعْبَةُ وَسُفْيَانُ الثَّوْرِيُّ وَأَبُو الأَحْوَصِ وَسُفْيَانُ بْنُ عُيَيْنَةَ ‏.‏\hadithno{1011}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Yahya, the Imam of Banu Taimillah, narrated from Abu Majid :From Abdullah bin Mas'ud who said: "We asked the Messenger of Allah about walking behind the funeral. He said: 'Less than a trot. For if he was good, then you will be hastening him to it (goodness), and if he was evil, then it id only an inhabitant of the Fire that is being taken away." The funeral is (to be) followed. The one who precedes it shall not have the reward of those who follow it}}
\hadithdefcmd{tirmidhi}{1012}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مَرْيَمَ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ ثَوْبَانَ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي جَنَازَةٍ فَرَأَى نَاسًا رُكْبَانًا فَقَالَ ‏ "‏ أَلاَ تَسْتَحْيُونَ إِنَّ مَلاَئِكَةَ اللَّهِ عَلَى أَقْدَامِهِمْ وَأَنْتُمْ عَلَى ظُهُورِ الدَّوَابِّ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ وَجَابِرِ بْنِ سَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ثَوْبَانَ قَدْ رُوِيَ عَنْهُ مَوْقُوفًا قَالَ مُحَمَّدٌ الْمَوْقُوفُ مِنْهُ أَصَحُّ ‏.‏\hadithno{1012}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Thawban narrated:"We went with the Prophet (following) a funeral. He saw people riding so he said: 'Are you not ashamed? Indeed Allah's angels are on their feet, while you are on the backs of your beasts}}
\hadithdefcmd{tirmidhi}{1013}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي جَنَازَةِ أَبِي الدَّحْدَاحِ وَهُوَ عَلَى فَرَسٍ لَهُ يَسْعَى وَنَحْنُ حَوْلَهُ وَهُوَ يَتَوَقَّصُ بِهِ ‏.‏\hadithno{1013}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir bin Samurah narrated:"We were with the Prophet (following) the funeral of Ibn Ad-Dahbah, and he was on a horse that was walking quickly, and we were around him, and he was trotting}}
\hadithdefcmd{tirmidhi}{1014}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْهَاشِمِيُّ، حَدَّثَنَا أَبُو قُتَيْبَةَ، عَنِ الْجَرَّاحِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اتَّبَعَ جَنَازَةَ أَبِي الدَّحْدَاحِ مَاشِيًا وَرَجَعَ عَلَى فَرَسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1014}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir bin Samurah narrated:"The Prophet followed the funeral of Ibn Ad-Dahdah walking and he returned on horseback}}
\hadithdefcmd{tirmidhi}{1015}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْرِعُوا بِالْجَنَازَةِ فَإِنْ يَكُنْ خَيْرًا تُقَدِّمُوهَا إِلَيْهِ وَإِنْ يَكُنْ شَرًّا تَضَعُوهُ عَنْ رِقَابِكُمْ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1015}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "Hurry up with the funeral (procession) for if it was good, you are advancing it to good, and if it was evil, then you are taking it off your necks}}
\hadithdefcmd{tirmidhi}{1016}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو صَفْوَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى حَمْزَةَ يَوْمَ أُحُدٍ فَوَقَفَ عَلَيْهِ فَرَآهُ قَدْ مُثِّلَ بِهِ فَقَالَ ‏"‏ لَوْلاَ أَنْ تَجِدَ صَفِيَّةُ فِي نَفْسِهَا لَتَرَكْتُهُ حَتَّى تَأْكُلَهُ الْعَافِيَةُ حَتَّى يُحْشَرَ يَوْمَ الْقِيَامَةِ مِنْ بُطُونِهَا ‏"‏ ‏.‏ قَالَ ثُمَّ دَعَا بِنَمِرَةٍ فَكَفَّنَهُ فِيهَا فَكَانَتْ إِذَا مُدَّتْ عَلَى رَأْسِهِ بَدَتْ رِجْلاَهُ وَإِذَا مُدَّتْ عَلَى رِجْلَيْهِ بَدَا رَأْسُهُ ‏.‏ قَالَ فَكَثُرَ الْقَتْلَى وَقَلَّتِ الثِّيَابُ ‏.‏ قَالَ فَكُفِّنَ الرَّجُلُ وَالرَّجُلاَنِ وَالثَّلاَثَةُ فِي الثَّوْبِ الْوَاحِدِ ثُمَّ يُدْفَنُونَ فِي قَبْرٍ وَاحِدٍ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْأَلُ عَنْهُمْ ‏"‏ أَيُّهُمْ أَكْثَرُ قُرْآنًا ‏"‏ ‏.‏ فَيُقَدِّمُهُ إِلَى الْقِبْلَةِ ‏.‏ قَالَ فَدَفَنَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَمْ يُصَلِّ عَلَيْهِمْ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَنَسٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ النَّمِرَةُ الْكِسَاءُ الْخَلَقُ ‏.‏ وَقَدْ خُولِفَ أُسَامَةُ بْنُ زَيْدٍ فِي رِوَايَةِ هَذَا الْحَدِيثِ فَرَوَى اللَّيْثُ بْنُ سَعْدٍ عَنِ ابْنِ شِهَابٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ وَرَوَى مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عَبْدِ اللَّهِ بْنِ ثَعْلَبَةَ عَنْ جَابِرٍ ‏.‏ وَلاَ نَعْلَمُ أَحَدًا ذَكَرَهُ عَنِ الزُّهْرِيِّ عَنْ أَنَسٍ إِلاَّ أُسَامَةَ بْنَ زَيْدٍ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ حَدِيثُ اللَّيْثِ عَنِ ابْنِ شِهَابٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ عَنْ جَابِرٍ أَصَحُّ ‏.‏\hadithno{1016}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated:"The Messenger of Allah came to Hamza on the Day of Uhud, he stood over him and saw that he had been mutilated. He said: Had it not been that Safiyyah would be distressed, then I would have left him to be eaten by the beasts until he was gathered on the Day of Judgment from their stomachs." He said: "Then he called for a Namirah to shroud him with. When it was extended over his head, it left his feet exposed, and when it was extended over his feet, it left his head exposed." He said: "There were many dead and few cloths." He said: "One, two and three men were shrouded in one cloth and buried in one grave." He said: "So the Messenger of Allah was asking which of them knew the most Quran, so he could put him toward the Qibalh." He said: "So the Messenger of Allah buried them and he did not perform (funeral prayers) for them}}
\hadithdefcmd{tirmidhi}{1017}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُسْلِمٍ الأَعْوَرِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُ الْمَرِيضَ وَيَشْهَدُ الْجَنَازَةَ وَيَرْكَبُ الْحِمَارَ وَيُجِيبُ دَعْوَةَ الْعَبْدِ وَكَانَ يَوْمَ بَنِي قُرَيْظَةَ عَلَى حِمَارٍ مَخْطُومٍ بِحَبْلٍ مِنْ لِيفٍ عَلَيْهِ إِكَافُ لِيفٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُسْلِمٍ عَنْ أَنَسٍ ‏.‏ وَمُسْلِمٌ الأَعْوَرُ يُضَعَّفُ وَهُوَ مُسْلِمُ بْنُ كَيْسَانَ الْمُلاَئِيُّ تُكُلِّمَ فِيهِ وَقَدْ رَوَى عَنْهُ شُعْبَةُ وَسُفْيَانُ ‏.‏\hadithno{1017}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated:"The Messenger of Allah would visit the sick, attend the funerals, ride a donkey, accept the invitation of a slave, and on the Day of Banu Quraizah he was on a donkey muzzled with a cord of fibers and a pack-saddle made of fibers}}
\hadithdefcmd{tirmidhi}{1018}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم اخْتَلَفُوا فِي دَفْنِهِ فَقَالَ أَبُو بَكْرٍ سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم شَيْئًا مَا نَسِيتُهُ قَالَ ‏ "‏ مَا قَبَضَ اللَّهُ نَبِيًّا إِلاَّ فِي الْمَوْضِعِ الَّذِي يُحِبُّ أَنْ يُدْفَنَ فِيهِ ‏"‏ ‏.‏ ادْفِنُوهُ فِي مَوْضِعِ فِرَاشِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ الْمُلَيْكِيُّ يُضَعَّفُ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ فَرَوَاهُ ابْنُ عَبَّاسٍ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا ‏.‏\hadithno{1018}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:"When the Messenger of Allah died, they disagreed over where to bury him. So Abu Bakr said: 'I heard the Messenger of Allah saying something which I have not forgotten, he said: "Allah does not take (the life of ) a Prophet except at the location in which He wants him to be buried.'" So they buried him at the spot of his bed}}
\hadithdefcmd{tirmidhi}{1019}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ عِمْرَانَ بْنِ أَنَسٍ الْمَكِّيِّ، عَنْ عَطَاءٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اذْكُرُوا مَحَاسِنَ مَوْتَاكُمْ وَكُفُّوا عَنْ مَسَاوِيهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ سَمِعْتُ مُحَمَّدًا يَقُولُ عِمْرَانُ بْنُ أَنَسٍ الْمَكِّيُّ مُنْكَرُ الْحَدِيثِ وَرَوَى بَعْضُهُمْ عَنْ عَطَاءٍ عَنْ عَائِشَةَ ‏.‏ قَالَ وَعِمْرَانُ بْنُ أَبِي أَنَسٍ مِصْرِيٌّ أَقْدَمُ وَأَثْبَتُ مِنْ عِمْرَانَ بْنِ أَنَسٍ الْمَكِّيِّ ‏.‏\hadithno{1019}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated that:The Messenger of Allah said: "Mention good things about your dead, and refrain from (mentioning) their evil}}
\hadithdefcmd{tirmidhi}{1020}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، عَنْ بِشْرِ بْنِ رَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ سُلَيْمَانَ بْنِ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اتَّبَعَ الْجَنَازَةَ لَمْ يَقْعُدْ حَتَّى تُوضَعَ فِي اللَّحْدِ فَعَرَضَ لَهُ حَبْرٌ فَقَالَ هَكَذَا نَصْنَعُ يَا مُحَمَّدُ ‏.‏ قَالَ فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ خَالِفُوهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَبِشْرُ بْنُ رَافِعٍ لَيْسَ بِالْقَوِيِّ فِي الْحَدِيثِ ‏.‏\hadithno{1020}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ubadah bin As-Samit said:"When the Messenger of Allah follows a corpse, he would not sit until (the deceased was) placed in the Lahd. A rabbi came upon him and said: 'This is what we do, O Muhammad'" He said: "So the Messenger of Allah sat, and he said: 'Differ from them}}
\hadithdefcmd{tirmidhi}{1021}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي سِنَانٍ، قَالَ دَفَنْتُ ابْنِي سِنَانًا وَأَبُو طَلْحَةَ الْخَوْلاَنِيُّ جَالِسٌ عَلَى شَفِيرِ الْقَبْرِ فَلَمَّا أَرَدْتُ الْخُرُوجَ أَخَذَ بِيَدِي فَقَالَ أَلاَ أُبَشِّرُكَ يَا أَبَا سِنَانٍ ‏.‏ قُلْتُ بَلَى ‏.‏ فَقَالَ حَدَّثَنِي الضَّحَّاكُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَرْزَبٍ عَنْ أَبِي مُوسَى الأَشْعَرِيِّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَاتَ وَلَدُ الْعَبْدِ قَالَ اللَّهُ لِمَلاَئِكَتِهِ قَبَضْتُمْ وَلَدَ عَبْدِي ‏.‏ فَيَقُولُونَ نَعَمْ ‏.‏ فَيَقُولُ قَبَضْتُمْ ثَمَرَةَ فُؤَادِهِ ‏.‏ فَيَقُولُونَ نَعَمْ ‏.‏ فَيَقُولُ مَاذَا قَالَ عَبْدِي فَيَقُولُونَ حَمِدَكَ وَاسْتَرْجَعَ ‏.‏ فَيَقُولُ اللَّهُ ابْنُوا لِعَبْدِي بَيْتًا فِي الْجَنَّةِ وَسَمُّوهُ بَيْتَ الْحَمْدِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1021}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Sinan said:"I buried my son Sinan and Abu Talhah Al-Khawlani was sitting on the rim of the grave. When I wanted to leave he took me by my hand and said: 'Shall I not inform you of some good new O Abu Sinan!' I said: 'Of course.' He said: 'Ad-Dahhak bin Abdur-Rahman bin Arzab narrated to me, from Abu Musa Al-Ash'ari: "The Messenger of Allah said: 'When a child of the slave (of Allah) died, Allah says to the angels: "Have you taken the fruits of his work." They reply: "Yes." So He says: "What did My slave say?" They reply: "He praised you and mentioned that to You is the return." So Allah says: "Build a house in Paradise for My slave, and name it 'the house of praise}}
\hadithdefcmd{tirmidhi}{1022}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى النَّجَاشِيِّ فَكَبَّرَ أَرْبَعًا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَابْنِ أَبِي أَوْفَى وَجَابِرٍ وَيَزِيدَ بْنِ ثَابِتٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى وَيَزِيدُ بْنُ ثَابِتٍ هُوَ أَخُو زَيْدِ بْنِ ثَابِتٍ وَهُوَ أَكْبَرُ مِنْهُ شَهِدَ بَدْرًا وَزَيْدٌ لَمْ يَشْهَدْ بَدْرًا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَرَوْنَ التَّكْبِيرَ عَلَى الْجَنَازَةِ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1022}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"The Prophet prayed and in the funeral prayer he for An-Najashi, said four Takbir}}
\hadithdefcmd{tirmidhi}{1023}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ كَانَ زَيْدُ بْنُ أَرْقَمَ يُكَبِّرُ عَلَى جَنَائِزِنَا أَرْبَعًا وَإِنَّهُ كَبَّرَ عَلَى جَنَازَةٍ خَمْسًا فَسَأَلْنَاهُ عَنْ ذَلِكَ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكَبِّرُهَا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْدِ بْنِ أَرْقَمَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ رَأَوُا التَّكْبِيرَ عَلَى الْجَنَازَةِ خَمْسًا ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ إِذَا كَبَّرَ الإِمَامُ عَلَى الْجَنَازَةِ خَمْسًا فَإِنَّهُ يُتَّبَعُ الإِمَامُ ‏.‏\hadithno{1023}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdur-Rahman bin Abi Laila said:"Zaid bin Arqam would say four Takbir for our funerals. (Once) he said five Takbir for a funeral so we asked him about that and he said: 'The Messenger of Allah would say those Takbir}}
\hadithdefcmd{tirmidhi}{1024}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا هِقْلُ بْنُ زِيَادٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو إِبْرَاهِيمَ الأَشْهَلِيُّ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا صَلَّى عَلَى الْجَنَازَةِ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِحَيِّنَا وَمَيِّتِنَا وَشَاهِدِنَا وَغَائِبِنَا وَصَغِيرِنَا وَكَبِيرِنَا وَذَكَرِنَا وَأُنْثَانَا ‏"‏ ‏.‏ قَالَ يَحْيَى وَحَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ ذَلِكَ وَزَادَ فِيهِ ‏"‏ اللَّهُمَّ مَنْ أَحْيَيْتَهُ مِنَّا فَأَحْيِهِ عَلَى الإِسْلاَمِ وَمَنْ تَوَفَّيْتَهُ مِنَّا فَتَوَفَّهُ عَلَى الإِيمَانِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَعَائِشَةَ وَأَبِي قَتَادَةَ وَعَوْفِ بْنِ مَالِكٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ وَالِدِ أَبِي إِبْرَاهِيمَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى هِشَامٌ الدَّسْتَوَائِيُّ وَعَلِيُّ بْنُ الْمُبَارَكِ هَذَا الْحَدِيثَ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَرَوَى عِكْرِمَةُ بْنُ عَمَّارٍ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَحَدِيثُ عِكْرِمَةَ بْنِ عَمَّارٍ غَيْرُ مَحْفُوظٍ وَعِكْرِمَةُ رُبَّمَا يَهِمُ فِي حَدِيثِ يَحْيَى ‏.‏ وَرُوِيَ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ مُحَمَّدًا يَقُولُ أَصَحُّ الرِّوَايَاتِ فِي هَذَا حَدِيثُ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ أَبِي إِبْرَاهِيمَ الأَشْهَلِيِّ عَنْ أَبِيهِ ‏.‏ وَسَأَلْتُهُ عَنِ اسْمِ أَبِي إِبْرَاهِيمَ فَلَمْ يَعْرِفْهُ ‏.‏\hadithno{1024}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Ibrahim Al-Ashhali narrated :from his father who said: "When the Messenger of Allah would perform the Salat for the funeral he would said: (Allahammaghfir li-hayyina wa mayyittina, wa shahidina wa gha'ibina, wa saghirina wa kabirina, wa dhakarina wa unthana) 'O Allah! Forgive our living and our deceased, our present and our absent, our young and our old, our male and our female}}
\hadithdefcmd{tirmidhi}{1025}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى مَيِّتٍ فَفَهِمْتُ مِنْ صَلاَتِهِ عَلَيْهِ ‏ "‏ اللَّهُمَّ اغْفِرْ لَهُ وَارْحَمْهُ وَاغْسِلْهُ بِالْبَرَدِ وَاغْسِلْهُ كَمَا يُغْسَلُ الثَّوْبُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ هَذَا الْحَدِيثُ ‏.‏\hadithno{1025}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Awf bin Malik said:"I heard the Messenger of Allah, while he was performing Salat for a deceased person. I could hear him saying in his prayer: (Allahummagfir lahu, war hamhu, waghsilhu bil-baradi (waghsilhu) kama yughsaluth-thawb) 'O Allah! Forgive him, have mercy upon him, and wash him with (snow or ice) (and wash him) just as a garment is washed}}
\hadithdefcmd{tirmidhi}{1026}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُثْمَانَ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ عَلَى الْجَنَازَةِ بِفَاتِحَةِ الْكِتَابِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ شَرِيكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ لَيْسَ إِسْنَادُهُ بِذَلِكَ الْقَوِيِّ ‏.‏ إِبْرَاهِيمُ بْنُ عُثْمَانَ هُوَ أَبُو شَيْبَةَ الْوَاسِطِيُّ مُنْكَرُ الْحَدِيثِ ‏.‏ وَالصَّحِيحُ عَنِ ابْنِ عَبَّاسٍ قَوْلُهُ مِنَ السُّنَّةِ الْقِرَاءَةُ عَلَى الْجَنَازَةِ بِفَاتِحَةِ الْكِتَابِ ‏.‏\hadithno{1026}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet recited Fatihatil-Kitab for a funeral (prayer)." (Da'if Jiddan)}}
\hadithdefcmd{tirmidhi}{1027}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ طَلْحَةَ بْنِ عَوْفٍ، أَنَّ ابْنَ عَبَّاسٍ، صَلَّى عَلَى جَنَازَةٍ فَقَرَأَ بِفَاتِحَةِ الْكِتَابِ فَقُلْتُ لَهُ فَقَالَ إِنَّهُ مِنَ السُّنَّةِ أَوْ مِنْ تَمَامِ السُّنَّةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَخْتَارُونَ أَنْ يُقْرَأَ بِفَاتِحَةِ الْكِتَابِ بَعْدَ التَّكْبِيرَةِ الأُولَى ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يُقْرَأُ فِي الصَّلاَةِ عَلَى الْجَنَازَةِ إِنَّمَا هُوَ ثَنَاءٌ عَلَى اللَّهِ وَالصَّلاَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَالدُّعَاءُ لِلْمَيِّتِ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَغَيْرِهِ مِنْ أَهْلِ الْكُوفَةِ ‏.‏ وَطَلْحَةُ بْنُ عَبْدِ اللَّهِ بْنِ عَوْفٍ هُوَ ابْنُ أَخِي عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ رَوَى عَنْهُ الزُّهْرِيُّ ‏.‏\hadithno{1027}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Talhah bin Abdullah bin Awf narrated:"Ibn Abbas performed Salat for a funeral and he recited Fatihatil-Kitab. So I asked him about it and he said: 'It is from the Sunnah' or, 'From the completeness of the Sunnah}}
\hadithdefcmd{tirmidhi}{1028}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، وَيُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدِ بْنِ عَبْدِ اللَّهِ الْيَزَنِيِّ، قَالَ كَانَ مَالِكُ بْنُ هُبَيْرَةَ إِذَا صَلَّى عَلَى جَنَازَةٍ فَتَقَالَّ النَّاسَ عَلَيْهَا جَزَّأَهُمْ ثَلاَثَةَ أَجْزَاءٍ ثُمَّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى عَلَيْهِ ثَلاَثَةُ صُفُوفٍ فَقَدْ أَوْجَبَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأُمِّ حَبِيبَةَ وَأَبِي هُرَيْرَةَ وَمَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مَالِكِ بْنِ هُبَيْرَةَ حَدِيثٌ حَسَنٌ هَكَذَا رَوَاهُ غَيْرُ وَاحِدٍ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ ‏.‏ وَرَوَى إِبْرَاهِيمُ بْنُ سَعْدٍ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ هَذَا الْحَدِيثَ وَأَدْخَلَ بَيْنَ مَرْثَدٍ وَمَالِكِ بْنِ هُبَيْرَةَ رَجُلاً ‏.‏ وَرِوَايَةُ هَؤُلاَءِ أَصَحُّ عِنْدَنَا ‏.‏\hadithno{1028}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Marthan bin Abdullah Al-Yazani narrated:"When Malik bin Hubairah performed Salat for a funeral and the people were few he would divide them into three groups (rows) then say: 'The Messenger of Allah said: "For whomever three rows perform Salat, then it is granted}}
\hadithdefcmd{tirmidhi}{1029}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، ‏.‏ وَحَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، رَضِيعٌ كَانَ لِعَائِشَةَ - عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَمُوتُ أَحَدٌ مِنَ الْمُسْلِمِينَ فَتُصَلِّي عَلَيْهِ أُمَّةٌ مِنَ الْمُسْلِمِينَ يَبْلُغُونَ أَنْ يَكُونُوا مِائَةً فَيَشْفَعُوا لَهُ إِلاَّ شُفِّعُوا فِيهِ ‏"‏ ‏.‏ وَقَالَ عَلِيُّ بْنُ حُجْرٍ فِي حَدِيثِهِ ‏"‏ مِائَةً فَمَا فَوْقَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ أَوْقَفَهُ بَعْضُهُمْ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{1029}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated that:The Prophet said: "No one among the Muslim dies, and Salat is performed for him by a community of Muslims reaching one hundred, and they intercede (supplicate) for him, except that their intercession for him is accepted." In his narration, 'Ali bin Hujr said: "One hundred or more than that}}
\hadithdefcmd{tirmidhi}{1030}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ مُوسَى بْنِ عُلَىِّ بْنِ رَبَاحٍ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ ثَلاَثُ سَاعَاتٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَانَا أَنْ نُصَلِّيَ فِيهِنَّ أَوْ نَقْبُرَ فِيهِنَّ مَوْتَانَا حِينَ تَطْلُعُ الشَّمْسُ بَازِغَةً حَتَّى تَرْتَفِعَ وَحِينَ يَقُومُ قَائِمُ الظَّهِيرَةِ حَتَّى تَمِيلَ وَحِينَ تَضَيَّفُ الشَّمْسُ لِلْغُرُوبِ حَتَّى تَغْرُبَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَكْرَهُونَ الصَّلاَةَ عَلَى الْجَنَازَةِ فِي هَذِهِ السَّاعَاتِ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ مَعْنَى هَذَا الْحَدِيثِ أَنْ نَقْبُرَ فِيهِنَّ مَوْتَانَا ‏.‏ يَعْنِي الصَّلاَةَ عَلَى الْجَنَازَةِ ‏.‏ وَكَرِهَ الصَّلاَةَ عَلَى الْجَنَازَةِ عِنْدَ طُلُوعِ الشَّمْسِ وَعِنْدَ غُرُوبِهَا وَإِذَا انْتَصَفَ النَّهَارُ حَتَّى تَزُولَ الشَّمْسُ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ الشَّافِعِيُّ لاَ بَأْسَ بِالصَّلاَةِ عَلَى الْجَنَازَةِ فِي السَّاعَاتِ الَّتِي تُكْرَهُ فِيهِنَّ الصَّلاَةُ ‏.‏\hadithno{1030}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Uqbah bin Amir Al-Juhni narrated:"There are three times that the Messenger of Allah prohibited us from performing Salat in, burying our dead in: When the sun's rising appears until it has risen up; when the sun is at the zenith until it passes, and when the sun begins its setting, until it has set}}
\hadithdefcmd{tirmidhi}{1031}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ ابْنُ بِنْتِ أَزْهَرَ السَّمَّانِ الْبَصْرِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ سَعِيدِ بْنِ عُبَيْدِ اللَّهِ، حَدَّثَنَا أَبِي، عَنْ زِيَادِ بْنِ جُبَيْرِ بْنِ حَيَّةَ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الرَّاكِبُ خَلْفَ الْجَنَازَةِ وَالْمَاشِي حَيْثُ شَاءَ مِنْهَا وَالطِّفْلُ يُصَلَّى عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ رَوَاهُ إِسْرَائِيلُ وَغَيْرُ وَاحِدٍ عَنْ سَعِيدِ بْنِ عُبَيْدِ اللَّهِ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ قَالُوا يُصَلَّى عَلَى الطِّفْلِ وَإِنْ لَمْ يَسْتَهِلَّ بَعْدَ أَنْ يُعْلَمَ أَنَّهُ خُلِقَ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1031}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Mughirah bin Shu'bah narrated that:The Prophet said: "The rider is to be behind the funeral (procession), and the walker where he wishes, and the child should be prayed over}}
\hadithdefcmd{tirmidhi}{1032}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ الْوَاسِطِيُّ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ الْمَكِّيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الطِّفْلُ لاَ يُصَلَّى عَلَيْهِ وَلاَ يَرِثُ وَلاَ يُورَثُ حَتَّى يَسْتَهِلَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ قَدِ اضْطَرَبَ النَّاسُ فِيهِ فَرَوَاهُ بَعْضُهُمْ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مَرْفُوعًا ‏.‏ وَرَوَى أَشْعَثُ بْنُ سَوَّارٍ وَغَيْرُ وَاحِدٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ مَوْقُوفًا ‏.‏ وَرَوَى مُحَمَّدُ بْنُ إِسْحَاقَ عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ عَنْ جَابِرٍ مَوْقُوفًا ‏.‏ وَكَأَنَّ هَذَا أَصَحُّ مِنَ الْحَدِيثِ الْمَرْفُوعِ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا قَالُوا لاَ يُصَلَّى عَلَى الطِّفْلِ حَتَّى يَسْتَهِلَّ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ ‏.‏\hadithno{1032}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated that:The Prophet said: "The child is not prayed over, nor does he inherit, nor is he inherited from until one is sure he was alive at birth}}
\hadithdefcmd{tirmidhi}{1033}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ الْوَاحِدِ بْنِ حَمْزَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى سُهَيْلِ ابْنِ بَيْضَاءَ فِي الْمَسْجِدِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ قَالَ الشَّافِعِيُّ قَالَ مَالِكٌ لاَ يُصَلَّى عَلَى الْمَيِّتِ فِي الْمَسْجِدِ ‏.‏ وَقَالَ الشَّافِعِيُّ يُصَلَّى عَلَى الْمَيِّتِ فِي الْمَسْجِدِ ‏.‏ وَاحْتَجَّ بِهَذَا الْحَدِيثِ ‏.‏\hadithno{1033}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"The Messenger of Allah performed Salat over Suhail bin Al-Baida in the Masjid}}
\hadithdefcmd{tirmidhi}{1034}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، عَنْ سَعِيدِ بْنِ عَامِرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي غَالِبٍ، قَالَ صَلَّيْتُ مَعَ أَنَسِ بْنِ مَالِكٍ عَلَى جَنَازَةِ رَجُلٍ فَقَامَ حِيَالَ رَأْسِهِ ثُمَّ جَاءُوا بِجَنَازَةِ امْرَأَةٍ مِنْ قُرَيْشٍ فَقَالُوا يَا أَبَا حَمْزَةَ صَلِّ عَلَيْهَا ‏.‏ فَقَامَ حِيَالَ وَسَطِ السَّرِيرِ ‏.‏ فَقَالَ لَهُ الْعَلاَءُ بْنُ زِيَادٍ هَكَذَا رَأَيْتَ النَّبِيَّ صلى الله عليه وسلم قَامَ عَلَى الْجَنَازَةِ مُقَامَكَ مِنْهَا وَمِنَ الرَّجُلِ مُقَامَكَ مِنْهُ قَالَ نَعَمْ ‏.‏ فَلَمَّا فَرَغَ قَالَ احْفَظُوا ‏.‏ وَفِي الْبَابِ عَنْ سَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رَوَى غَيْرُ وَاحِدٍ عَنْ هَمَّامٍ مِثْلَ هَذَا ‏.‏ وَرَوَى وَكِيعٌ هَذَا الْحَدِيثَ عَنْ هَمَّامٍ فَوَهِمَ فِيهِ فَقَالَ عَنْ غَالِبٍ عَنْ أَنَسٍ ‏.‏ وَالصَّحِيحُ عَنْ أَبِي غَالِبٍ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ وَغَيْرُ وَاحِدٍ عَنْ أَبِي غَالِبٍ مِثْلَ رِوَايَةِ هَمَّامٍ ‏.‏ وَاخْتَلَفُوا فِي اسْمِ أَبِي غَالِبٍ هَذَا فَقَالَ بَعْضُهُمْ يُقَالُ اسْمُهُ نَافِعٌ وَيُقَالُ رَافِعٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1034}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Ghalib narrated:"I prayed for the funeral of a man with Anas bin Malik, so he stood parallel to his head. Then they came with the body of a woman from the Quraish. They said: 'O Abu Hamzah perform the prayer for her.' So he stood parallel to her waist. Al-Ala bin Ziyad said to him: 'Is this how you saw the Messenger of Allah standing in the place for the funeral as you did for her, and for a place that you stood for the man?' He said: 'Yes.' When he was finished he said: 'Remember (this)}}
\hadithdefcmd{tirmidhi}{1035}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، وَالْفَضْلُ بْنُ مُوسَى، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى امْرَأَةٍ فَقَامَ وَسَطَهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ عَنْ حُسَيْنٍ الْمُعَلِّمِ ‏.‏\hadithno{1035}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Samurah bin Jundab narrated:"The Prophet prayed over a woman, so he stood at her middle}}
\hadithdefcmd{tirmidhi}{1036}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ فِي الثَّوْبِ الْوَاحِدِ ثُمَّ يَقُولُ ‏"‏ أَيُّهُمَا أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏ ‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى أَحَدِهِمَا قَدَّمَهُ فِي اللَّحْدِ وَقَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَأَمَرَ بِدَفْنِهِمْ فِي دِمَائِهِمْ وَلَمْ يُصَلِّ عَلَيْهِمْ وَلَمْ يُغَسَّلُوا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ الزُّهْرِيِّ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنِ الزُّهْرِيِّ عَنْ عَبْدِ اللَّهِ بْنِ ثَعْلَبَةَ بْنِ أَبِي صُعَيْرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَمِنْهُمْ مَنْ ذَكَرَهُ عَنْ جَابِرٍ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الصَّلاَةِ عَلَى الشَّهِيدِ فَقَالَ بَعْضُهُمْ لاَ يُصَلَّى عَلَى الشَّهِيدِ ‏.‏ وَهُوَ قَوْلُ أَهْلِ الْمَدِينَةِ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ ‏.‏ وَقَالَ بَعْضُهُمْ يُصَلَّى عَلَى الشَّهِيدِ ‏.‏ وَاحْتَجُّوا بِحَدِيثِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى عَلَى حَمْزَةَ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَبِهِ يَقُولُ إِسْحَاقُ ‏.‏\hadithno{1036}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdur-Rahman bin Ka'b bin Malik narrated that:Jabir bin Abdullah informed him that the Prophet had put two men together in one cloth from those who were killed at (the battle of) Uhud, then he said: "Which of them memorized the more of the Qur'an?" When one of them was indicated to him, he put him in the Lahd (first) and said: "I am a witness for those people on the Day of Judgment." And he ordered that they be buried in their blood, and that they not be prayed over, nor washed}}
\hadithdefcmd{tirmidhi}{1037}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا الشَّيْبَانِيُّ، حَدَّثَنَا الشَّعْبِيُّ، أَخْبَرَنِي مَنْ، رَأَى النَّبِيَّ صلى الله عليه وسلم وَرَأَى قَبْرًا مُنْتَبِذًا فَصَفَّ أَصْحَابَهُ خَلْفَهُ فَصَلَّى عَلَيْهِ فَقِيلَ لَهُ مَنْ أَخْبَرَكَهُ فَقَالَ ابْنُ عَبَّاسٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَبُرَيْدَةَ وَيَزِيدَ بْنِ ثَابِتٍ وَأَبِي هُرَيْرَةَ وَعَامِرِ بْنِ رَبِيعَةَ وَأَبِي قَتَادَةَ وَسَهْلِ بْنِ حُنَيْفٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يُصَلَّى عَلَى الْقَبْرِ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ إِذَا دُفِنَ الْمَيِّتُ وَلَمْ يُصَلَّ عَلَيْهِ صُلِّيَ عَلَى الْقَبْرِ ‏.‏ وَرَأَى ابْنُ الْمُبَارَكِ الصَّلاَةَ عَلَى الْقَبْرِ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ يُصَلَّى عَلَى الْقَبْرِ إِلَى شَهْرٍ ‏.‏ وَقَالاَ أَكْثَرُ مَا سَمِعْنَا عَنِ ابْنِ الْمُسَيَّبِ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى قَبْرِ أُمِّ سَعْدِ بْنِ عُبَادَةَ بَعْدَ شَهْرٍ ‏.‏\hadithno{1037}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ash-Shaibani narrated that:Ash-Sha'bi said: "I was informed by one who saw the Prophet: He (pbuh) saw a solitary grave, s he lined his Companions (behind him) to pray over it." It was said to him (Ash-Sha'bi): "Who informed you?" He said: "Ibn Abbas}}
\hadithdefcmd{tirmidhi}{1038}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أُمَّ سَعْدٍ، مَاتَتْ وَالنَّبِيُّ صلى الله عليه وسلم غَائِبٌ فَلَمَّا قَدِمَ صَلَّى عَلَيْهَا وَقَدْ مَضَى لِذَلِكَ شَهْرٌ ‏.‏\hadithno{1038}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sa'eedbin Musayyab narrated:"Umm Sa'd died while the Prophet was absent. So when he arrived he performed Salat over her, and a month had already passed}}
\hadithdefcmd{tirmidhi}{1039}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ وَحُمَيْدُ بْنُ مَسْعَدَةَ قَالاَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَخَاكُمُ النَّجَاشِيَّ قَدْ مَاتَ فَقُومُوا فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَقُمْنَا فَصَفَفْنَا كَمَا يُصَفُّ عَلَى الْمَيِّتِ وَصَلَّيْنَا عَلَيْهِ كَمَا يُصَلَّى عَلَى الْمَيِّتِ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَأَبِي سَعِيدٍ وَحُذَيْفَةَ بْنِ أَسِيدٍ وَجَرِيرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَاهُ أَبُو قِلاَبَةَ عَنْ عَمِّهِ أَبِي الْمُهَلَّبِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ وَأَبُو الْمُهَلَّبِ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو وَيُقَالُ مُعَاوِيَةُ بْنُ عَمْرٍو ‏.‏\hadithno{1039}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Imran bin Husain narrated that :the Prophet said: "Indeed your brother An-Najashi has died. So stand to perform Salat for him." He (Imran) said: "We stood and lined up just as the deceased is lined up for, and we prayed for him just as the deceased is prayed for}}
\hadithdefcmd{tirmidhi}{1040}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى عَلَى جَنَازَةٍ فَلَهُ قِيرَاطٌ وَمَنْ تَبِعَهَا حَتَّى يُقْضَى دَفْنُهَا فَلَهُ قِيرَاطَانِ أَحَدُهُمَا أَوْ أَصْغَرُهُمَا مِثْلُ أُحُدٍ ‏"‏ ‏.‏ فَذَكَرْتُ ذَلِكَ لاِبْنِ عُمَرَ فَأَرْسَلَ إِلَى عَائِشَةَ فَسَأَلَهَا عَنْ ذَلِكَ فَقَالَتْ صَدَقَ أَبُو هُرَيْرَةَ ‏.‏ فَقَالَ ابْنُ عُمَرَ لَقَدْ فَرَّطْنَا فِي قَرَارِيطَ كَثِيرَةٍ ‏.‏ وَفِي الْبَابِ عَنِ الْبَرَاءِ وَعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي سَعِيدٍ وَأُبَىِّ بْنِ كَعْبٍ وَابْنِ عُمَرَ وَثَوْبَانَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏\hadithno{1040}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "Whoever performs the funeral prayer then he will get a reward equal to a Qirat. Whoever follows it until it is buried then he will get a reward equal to two Qirat, one of them, or the least of them, is similar to Uhud (mountain)." This was mentioned to Ibn Umar, so he sent a message to Aishah to ask her about that, and she said: "Abu Hurairah has told the truth." So Ibn Umar said: "We have missed many Qirat}}
\hadithdefcmd{tirmidhi}{1041}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، قَالَ سَمِعْتُ أَبَا الْمُهَزَّمِ، قَالَ صَحِبْتُ أَبَا هُرَيْرَةَ عَشْرَ سِنِينَ فَسَمِعْتُهُ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ تَبِعَ جَنَازَةً وَحَمَلَهَا ثَلاَثَ مَرَّاتٍ فَقَدْ قَضَى مَا عَلَيْهِ مِنْ حَقِّهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَاهُ بَعْضُهُمْ بِهَذَا الإِسْنَادِ وَلَمْ يَرْفَعْهُ ‏.‏ وَأَبُو الْمُهَزَّمِ اسْمُهُ يَزِيدُ بْنُ سُفْيَانَ وَضَعَّفَهُ شُعْبَةُ ‏.‏\hadithno{1041}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Muhazzim said:"I accompanied Abu Hurairah for ten years, and I heard him saying: 'I heard the Messenger of Allah saying: "Whoever follows a funeral, and carries it three times, then he has fulfilled the right that is required from him}}
\hadithdefcmd{tirmidhi}{1042}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ عَامِرِ بْنِ رَبِيعَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عَامِرِ بْنِ رَبِيعَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا لَهَا حَتَّى تُخَلِّفَكُمْ أَوْ تُوضَعَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَجَابِرٍ وَسَهْلِ بْنِ حُنَيْفٍ وَقَيْسِ بْنِ سَعْدٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَامِرِ بْنِ رَبِيعَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1042}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Amir bin Rabi'ah narrated that:The Messenger of Allah said: "Whenever you see a funeral (procession), stand up until it goes ahead of you or it is put down}}
\hadithdefcmd{tirmidhi}{1043}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ الْحُلْوَانِيُّ، قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا لَهَا فَمَنْ تَبِعَهَا فَلاَ يَقْعُدَنَّ حَتَّى تُوضَعَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ فِي هَذَا الْبَابِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ قَالاَ مَنْ تَبِعَ جَنَازَةً فَلاَ يَقْعُدَنَّ حَتَّى تُوضَعَ عَنْ أَعْنَاقِ الرِّجَالِ ‏.‏ وَقَدْ رُوِيَ عَنْ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّهُمْ كَانُوا يَتَقَدَّمُونَ الْجَنَازَةَ فَيَقْعُدُونَ قَبْلَ أَنْ تَنْتَهِيَ إِلَيْهِمُ الْجَنَازَةُ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{1043}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed Al-Khudri narrated that:The Messenger of Allah said: "Whenever you see a funeral (procession), stand up (for it). Whoever follows it, then do not sit down until it is put down}}
\hadithdefcmd{tirmidhi}{1044}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ وَاقِدٍ، وَهُوَ ابْنُ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ مَسْعُودِ بْنِ الْحَكَمِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّهُ ذُكِرَ الْقِيَامُ فِي الْجَنَائِزِ حَتَّى تُوضَعَ فَقَالَ عَلِيٌّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَعَدَ ‏.‏ وَفِي الْبَابِ عَنِ الْحَسَنِ بْنِ عَلِيٍّ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِيهِ رِوَايَةُ أَرْبَعَةٍ مِنَ التَّابِعِينَ بَعْضُهُمْ عَنْ بَعْضٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ قَالَ الشَّافِعِيُّ وَهَذَا أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ ‏.‏ وَهَذَا الْحَدِيثُ نَاسِخٌ لِلْحَدِيثِ الأَوَّلِ ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا ‏"‏ ‏.‏ وَقَالَ أَحْمَدُ إِنْ شَاءَ قَامَ وَإِنْ شَاءَ لَمْ يَقُمْ ‏.‏ وَاحْتَجَّ بِأَنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ رُوِيَ عَنْهُ أَنَّهُ قَامَ ثُمَّ قَعَدَ ‏.‏ وَهَكَذَا قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ ‏.‏ قَالَ أَبُو عِيسَى مَعْنَى قَوْلِ عَلِيٍّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْجَنَازَةِ ثُمَّ قَعَدَ ‏.‏ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا رَأَى الْجَنَازَةَ قَامَ ثُمَّ تَرَكَ ذَلِكَ بَعْدُ فَكَانَ لاَ يَقُومُ إِذَا رَأَى الْجَنَازَةَ ‏.‏\hadithno{1044}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Mas'ud bin Al-Hakim narrated that standing for the funeral (procession) until it is put down was mentioned, and 'Ali bin Abi Talib mentioned and 'Ali bin Abi Talib said:"The Messenger of Allah (ﷺ) stood, then (later) he sat". (Sahih) There are narrations on this topic from Al-Hasan bin 'Ali, and Ibn 'Abbas. Abu Eisa said: The Hadith of 'Ali is a Hasan Sahih Hadith, regarding which there are narrations from four of the Tabi'in narrating it from each other. This is acted upon according to some of the people of knowledge. Ash-Shafi'i said: "This is the most correct thing on this topic" This Hadith abrogates first Hadith: "Whenever you see a funeral (procession), stand up [for it]." Ahmad said: "If he wants, he stands, and if he wants, he does not stand." His proof is that it has been reported that the Prophet (ﷺ) stood, then sat, and this is what Ishaq bin Ibrahim said. (Abu Eisa said:) As for the saying of 'Ali: The Prophet (ﷺ) stood for the funeral and then sat, he means that the Prophet (ﷺ) would stand when he saw a funeral (procession), then he did not do so later, so he would not stand when he saw the funeral (procession)}}
\hadithdefcmd{tirmidhi}{1045}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَنَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، وَيُوسُفُ بْنُ مُوسَى الْقَطَّانُ الْبَغْدَادِيُّ، قَالُوا حَدَّثَنَا حَكَّامُ بْنُ سَلْمٍ، عَنْ عَلِيِّ بْنِ عَبْدِ الأَعْلَى، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اللَّحْدُ لَنَا وَالشَّقُّ لِغَيْرِنَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ وَعَائِشَةَ وَابْنِ عُمَرَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1045}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that:The Prophet said: "The Lahd is for us and the hole is for other than us}}
\hadithdefcmd{tirmidhi}{1046}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، حَدَّثَنَا الْحَجَّاجُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أُدْخِلَ الْمَيِّتُ الْقَبْرَ - وَقَالَ أَبُو خَالِدٍ مَرَّةً إِذَا وُضِعَ الْمَيِّتُ فِي لَحْدِهِ قَالَ مَرَّةً ‏"‏ بِسْمِ اللَّهِ وَبِاللَّهِ وَعَلَى مِلَّةِ رَسُولِ اللَّهِ ‏"‏ ‏.‏ وَقَالَ مَرَّةً ‏"‏ بِسْمِ اللَّهِ وَبِاللَّهِ وَعَلَى سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ أَبُو الصِّدِّيقِ النَّاجِيُّ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَدْ رُوِيَ عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ عَنِ ابْنِ عُمَرَ مَوْقُوفًا أَيْضًا ‏.‏\hadithno{1046}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Umar narrated:"When he Prophet put the deceased in the grave" He said: And Abu Khalid (one of the narrators) said [one time]: "When he placed the deceased in the Lahd" - "He said one time: 'In the Name of Allah, by His command and upon the Millah of the Messenger of Allah.' and one time he said: 'In the Name of Allah, by His command and upon the Sunnah of the Messenger of Allah}}
\hadithdefcmd{tirmidhi}{1047}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ الْبَصْرِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ فَرْقَدٍ، قَالَ سَمِعْتُ جَعْفَرَ بْنَ مُحَمَّدٍ، عَنْ أَبِيهِ، قَالَ الَّذِي أَلْحَدَ قَبْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَبُو طَلْحَةَ وَالَّذِي أَلْقَى الْقَطِيفَةَ تَحْتَهُ شُقْرَانُ مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ جَعْفَرٌ وَأَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي رَافِعٍ قَالَ سَمِعْتُ شُقْرَانَ يَقُولُ أَنَا وَاللَّهِ طَرَحْتُ الْقَطِيفَةَ تَحْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْقَبْرِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ شُقْرَانَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى عَلِيُّ بْنُ الْمَدِينِيِّ عَنْ عُثْمَانَ بْنِ فَرْقَدٍ هَذَا الْحَدِيثَ ‏.‏\hadithno{1047}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ja'far bin Muhammad narrated that:His father said: "The one who made the Lahd in the grave of the Messenger of Allah was Abu Talhah. And the one who placed the velvet cloth under him was Shuqran a freed slave of Messenger of Allah}}
\hadithdefcmd{tirmidhi}{1048}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ أَبِي حَمْزَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جُعِلَ فِي قَبْرِ النَّبِيِّ صلى الله عليه وسلم قَطِيفَةٌ حَمْرَاءُ ‏.‏ قَالَ وَقَالَ مُحَمَّدُ بْنُ بَشَّارٍ فِي مَوْضِعٍ آخَرَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَيَحْيَى، عَنْ شُعْبَةَ، عَنْ أَبِي جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏.‏ وَهَذَا أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى شُعْبَةُ، عَنْ أَبِي حَمْزَةَ الْقَصَّابِ، وَاسْمُهُ، عِمْرَانُ بْنُ أَبِي عَطَاءٍ وَرُوِيَ عَنْ أَبِي جَمْرَةَ الضُّبَعِيِّ، وَاسْمُهُ، نَصْرُ بْنُ عِمْرَانَ وَكِلاَهُمَا مِنْ أَصْحَابِ ابْنِ عَبَّاسٍ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ كَرِهَ أَنْ يُلْقَى، تَحْتَ الْمَيِّتِ فِي الْقَبْرِ شَيْءٌ ‏.‏ وَإِلَى هَذَا ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1048}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Abbas narrated:"A red velvet cloth was placed in the grave of the Prophet}}
\hadithdefcmd{tirmidhi}{1049}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي وَائِلٍ، أَنَّ عَلِيًّا، قَالَ لأَبِي الْهَيَّاجِ الأَسَدِيِّ أَبْعَثُكَ عَلَى مَا بَعَثَنِي بِهِ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَنْ لا�� تَدَعَ قَبْرًا مُشْرِفًا إِلاَّ سَوَّيْتَهُ وَلاَ تِمْثَالاً إِلاَّ طَمَسْتَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ يَكْرَهُونَ أَنْ يُرْفَعَ الْقَبْرُ فَوْقَ الأَرْضِ ‏.‏ قَالَ الشَّافِعِيُّ أَكْرَهُ أَنْ يُرْفَعَ الْقَبْرُ إِلاَّ بِقَدْرِ مَا يُعْرَفُ أَنَّهُ قَبْرٌ لِكَيْلاَ يُوطَأَ وَلاَ يُجْلَسَ عَلَيْهِ ‏.‏\hadithno{1049}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Wa'il narrated:"Ali said to Abu Al-Hayyaj Al-Asadi: 'I am dispatching you with what the Prophet dispatched me: "That you not leave an elevated grave without leveling it, nor an image without erasing it}}
\hadithdefcmd{tirmidhi}{1050}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، عَنْ أَبِي مَرْثَدٍ الْغَنَوِيِّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَجْلِسُوا عَلَى الْقُبُورِ وَلاَ تُصَلُّوا إِلَيْهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَمْرِو بْنِ حَزْمٍ وَبَشِيرِ ابْنِ الْخَصَاصِيَةِ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{1050}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Marthan Al-Ghanawi narrated that:The Prophet said: "Do not sit on the graves nor perform Salat towards them}}
\hadithdefcmd{tirmidhi}{1051}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، وَأَبُو عَمَّارٍ قَالاَ أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، عَنْ أَبِي مَرْثَدٍ الْغَنَوِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَلَيْسَ فِيهِ عَنْ أَبِي إِدْرِيسَ وَهَذَا الصَّحِيحُ ‏.‏ قَالَ أَبُو عِيسَى قَالَ مُحَمَّدٌ وَحَدِيثُ ابْنِ الْمُبَارَكِ خَطَأٌ أَخْطَأَ فِيهِ ابْنُ الْمُبَارَكِ وَزَادَ فِيهِ عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ وَإِنَّمَا هُوَ بُسْرُ بْنُ عُبَيْدِ اللَّهِ عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ هَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ وَلَيْسَ فِيهِ عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ وَبُسْرُ بْنُ عُبَيْدِ اللَّهِ قَدْ سَمِعَ مِنْ وَاثِلَةَ بْنِ الأَسْقَعِ ‏.‏\hadithno{1051}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Abu Marthad Al-Ghanawi :from the Prophet, similar (to no. 1050), but it does not contain "From Abu Idris" and this is what is correct}}
\hadithdefcmd{tirmidhi}{1052}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ أَبُو عَمْرٍو الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ تُجَصَّصَ الْقُبُورُ وَأَنْ يُكْتَبَ عَلَيْهَا وَأَنْ يُبْنَى عَلَيْهَا وَأَنْ تُوطَأَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرٍ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ مِنْهُمُ الْحَسَنُ الْبَصْرِيُّ فِي تَطْيِينِ الْقُبُورِ ‏.‏ وَقَالَ الشَّافِعِيُّ لاَ بَأْسَ أَنْ يُطَيَّنَ الْقَبْرُ ‏.‏\hadithno{1052}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir narrated:"The Messenger of Allah prohibited plastering graves, writing on them, building over them, and treading on them}}
\hadithdefcmd{tirmidhi}{1053}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الصَّلْتِ، عَنْ أَبِي كُدَيْنَةَ، عَنْ قَابُوسِ بْنِ أَبِي ظَبْيَانَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقُبُورِ الْمَدِينَةِ فَأَقْبَلَ عَلَيْهِمْ بِوَجْهِهِ فَقَالَ ‏ "‏ السَّلاَمُ عَلَيْكُمْ يَا أَهْلَ الْقُبُورِ يَغْفِرُ اللَّهُ لَنَا وَلَكُمْ أَنْتُمْ سَلَفُنَا وَنَحْنُ بِالأَثَرِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو كُدَيْنَةَ اسْمُهُ يَحْيَى بْنُ الْمُهَلَّبِ وَأَبُو ظَبْيَانَ اسْمُهُ حُصَيْنُ بْنُ جُنْدُبٍ ‏.‏\hadithno{1053}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah passed by the graves of Al-Madinah, so he turned his face towards them and said: (As-Salamu alaikum ya ahlul-qubur! Yaghfirul-lahu lana wa lakun, antum salafuna wa nahnu bil-athar.) 'Peace be upon you O inhabitants of the grave! May Allah forgive us and you; you are our predecessors and we are to follow you}}
\hadithdefcmd{tirmidhi}{1054}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، قَالُوا حَدَّثَنَا أَبُو عَاصِمٍ النَّبِيلُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ كُنْتُ نَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَقَدْ أُذِنَ لِمُحَمَّدٍ فِي زِيَارَةِ قَبْرِ أُمِّهِ فَزُورُوهَا فَإِنَّهَا تُذَكِّرُ الآخِرَةَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَابْنِ مَسْعُودٍ وَأَنَسٍ وَأَبِي هُرَيْرَةَ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بُرَيْدَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ بِزِيَارَةِ الْقُبُورِ بَأْسًا ‏.‏ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1054}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sulaiman bin Buraidah narrated from his father that:The Messenger of Allah said: "I had prohibited you from visiting the graves. But Muhammad was permitted to visit the grave of his mother: so visit them, for they will remind you of the Hereafter}}
\hadithdefcmd{tirmidhi}{1055}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، قَالَ تُوُفِّيَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ بِحُبْشِيٍّ ‏.‏ قَالَ فَحُمِلَ إِلَى مَكَّةَ فَدُفِنَ فِيهَا فَلَمَّا قَدِمَتْ عَائِشَةُ أَتَتْ قَبْرَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ فَقَالَتْ وَكُنَّا كَنَدْمَانَىْ جَذِيمَةَ حِقْبَةً مِنَ الدَّهْرِ حَتَّى قِيلَ لَنْ يَتَصَدَّعَا فَلَمَّا تَفَرَّقْنَا كَأَنِّي وَمَالِكًا لِطُولِ اجْتِمَاعٍ لَمْ نَبِتْ لَيْلَةً مَعَا ثُمَّ قَالَتْ وَاللَّهِ لَوْ حَضَرْتُكَ مَا دُفِنْتَ إِلاَّ حَيْثُ مُتَّ وَلَوْ شَهِدْتُكَ مَا زُرْتُكَ ‏.‏\hadithno{1055}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Abi Mulaikah said:"Abdur-Rahman bin Abi Bakr died in Al-Hubshi" He said: "He was carried to Makkah to be buried there. So when Aishah arrived she went to the grave of Abdur-Rahman bin Abi Bakr and she said: "We were like two drinking companions of Jadhimah for such a long time that they would say: 'They will never part.' So when we were separated it was as if I and Malik - due to the length of unity - never spent a night together}}
\hadithdefcmd{tirmidhi}{1056}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ زَوَّارَاتِ الْقُبُورِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَحَسَّانَ بْنِ ثَابِتٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَأَى بَعْضُ أَهْلِ الْعِلْمِ أَنَّ هَذَا كَانَ قَبْلَ أَنْ يُرَخِّصَ النَّبِيُّ صلى الله عليه وسلم فِي زِيَارَةِ الْقُبُورِ فَلَمَّا رَخَّصَ دَخَلَ فِي رُخْصَتِهِ الرِّجَالُ وَالنِّسَاءُ ‏.‏ وَقَالَ بَعْضُهُمْ إِنَّمَا كُرِهَ زِيَارَةُ الْقُبُورِ لِلنِّسَاءِ لِقِلَّةِ صَبْرِهِنَّ وَكَثْرَةِ جَزَعِهِنَّ ‏.‏\hadithno{1056}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated:"Indeed the Messenger of Allah cursed the women who visit the graves}}
\hadithdefcmd{tirmidhi}{1057}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَمُحَمَّدُ بْنُ عَمْرٍو السَّوَّاقُ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، عَنِ الْمِنْهَالِ بْنِ خَلِيفَةَ، عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ قَبْرًا لَيْلاً فَأُسْرِجَ لَهُ سِرَاجٌ فَأَخَذَهُ مِنْ قِبَلِ الْقِبْلَةِ وَقَالَ ‏ "‏ رَحِمَكَ اللَّهُ إِنْ كُنْتَ لأَوَّاهًا تَلاَّءً لِلْقُرْآنِ ‏"‏ ‏.‏ وَكَبَّرَ عَلَيْهِ أَرْبَعًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَيَزِيدَ بْنِ ثَابِتٍ وَهُوَ أَخُو زَيْدِ بْنِ ثَابِتٍ أَكْبَرُ مِنْهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا وَقَالُوا يُدْخَلُ الْمَيِّتُ الْقَبْرَ مِنْ قِبَلِ الْقِبْلَةِ ‏.‏ وَقَالَ بَعْضُهُمْ يُسَلُّ سَلاًّ ‏.‏ وَرَخَّصَ أَكْثَرُ أَهْلِ الْعِلْمِ فِي الدَّفْنِ بِاللَّيْلِ ‏.‏\hadithno{1057}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet entered a grave during the night, so a torch was lit for him. He took it (the deceased) in from the direction of the Qiblah, and he said: 'May Allah have mercy upon you, you were often invoking (Allah) by reciting the Qur'an.' And he said: 'Allahu Akbar four times}}
\hadithdefcmd{tirmidhi}{1058}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ مُرَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِجَنَازَةٍ فَأَثْنَوْا عَلَيْهَا خَيْرًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَنْتُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَكَعْبِ بْنِ عُجْرَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1058}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated:"A funeral (procession) passed by the Messenger of Allah and they were praising him with good statements. So the Messenger of Allah said: 'Granted.' Then he said: 'You are Allah's witnesses on the earth}}
\hadithdefcmd{tirmidhi}{1059}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، وَهَارُونُ بْنُ عَبْدِ اللَّهِ الْبَزَّازُ، قَالاَ حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي الْفُرَاتِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، قَالَ قَدِمْتُ الْمَدِينَةَ فَجَلَسْتُ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَمَرُّوا بِجَنَازَةٍ فَأَثْنَوْا عَلَيْهَا خَيْرًا فَقَالَ عُمَرُ وَجَبَتْ ‏.‏ فَقُلْتُ لِعُمَرَ وَمَا وَجَبَتْ قَالَ أَقُولُ كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ مُسْلِمٍ يَشْهَدُ لَهُ ثَلاَثَةٌ إِلاَّ وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ قُلْنَا وَاثْنَانِ قَالَ ‏"‏ وَاثْنَانِ ‏"‏ ‏.‏ قَالَ وَلَمْ نَسْأَلْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْوَاحِدِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الأَسْوَدِ الدِّيلِيُّ اسْمُهُ ظَالِمُ بْنُ عَمْرِو بْنِ سُفْيَانَ ‏.‏\hadithno{1059}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Al-Aswad Ad-Dill narrated:"I arrived in Al-Madinah and while I was sitting with Umar bin Al-Khattab they passed by with a funeral, over (a person) whom they were praising with good. Umar said: 'Granted.' I said to Umar: 'What is granted?' He said: 'I said as the Messenger of Allah said: "There is no Muslim about whom three bear witness, except that he is granted Paradise." He said: "And two (as well)." He said: 'We did not ask the Messenger of Allah about one}}
\hadithdefcmd{tirmidhi}{1060}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، ح وَحَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمُوتُ لأَحَدٍ مِنَ الْمُسْلِمِينَ ثَلاَثَةٌ مِنَ الْوَلَدِ فَتَمَسَّهُ النَّارُ إِلاَّ تَحِلَّةَ الْقَسَمِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَمُعَاذٍ وَكَعْبِ بْنِ مَالِكٍ وَعُتْبَةَ بْنِ عَبْدٍ وَأُمِّ سُلَيْمٍ وَجَابِرٍ وَأَنَسٍ وَأَبِي ذَرٍّ وَابْنِ مَسْعُودٍ وَأَبِي ثَعْلَبَةَ الأَشْجَعِيِّ وَابْنِ عَبَّاسٍ وَعُقْبَةَ بْنِ عَامِرٍ وَأَبِي سَعِيدٍ وَقُرَّةَ بْنِ إِيَاسٍ الْمُزَنِيِّ ‏.‏ قَالَ وَأَبُو ثَعْلَبَةَ الأَشْجَعِيُّ لَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم حَدِيثٌ وَاحِدٌ هُوَ هَذَا الْحَدِيثُ وَلَيْسَ هُوَ الْخُشَنِيَّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1060}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "Any Muslim who has lost three of his children will not be touched by the Fire, except for what will fulfill the oath}}
\hadithdefcmd{tirmidhi}{1061}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، حَدَّثَنَا الْعَوَّامُ بْنُ حَوْشَبٍ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ عَنْ أَبِي عُبَيْدَةَ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قَدَّمَ ثَلاَثَةً لَمْ يَبْلُغُوا الْحُلُمَ كَانُوا لَهُ حِصْنًا حَصِينًا مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو ذَرٍّ قَدَّمْتُ اثْنَيْنِ ‏.‏ قَالَ ‏"‏ وَاثْنَيْنِ ‏"‏ ‏.‏ فَقَالَ أُبَىُّ بْنُ كَعْبٍ سَيِّدُ الْقُرَّاءِ قَدَّمْتُ وَاحِدًا قَالَ ‏"‏ وَوَاحِدًا وَلَكِنْ إِنَّمَا ذَاكَ عِنْدَ الصَّدْمَةِ الأُولَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَأَبُو عُبَيْدَةَ لَمْ يَسْمَعْ مِنْ أَبِيهِ ‏.‏\hadithno{1061}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated that:The Messenger of Allah said: "Whoever has three that precede him (in death) while they did not reach the age of puberty, then they will be a well-fortified fortress for him against the Fire}}
\hadithdefcmd{tirmidhi}{1062}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَأَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى الْبَصْرِيُّ قَالاَ حَدَّثَنَا عَبْدُ رَبِّهِ بْنُ بَارِقٍ الْحَنَفِيُّ، قَالَ سَمِعْتُ جَدِّي أَبَا أُمِّي، سِمَاكَ بْنَ الْوَلِيدِ الْحَنَفِيَّ يُحَدِّثُ أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يُحَدِّثُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ كَانَ لَهُ فَرَطَانِ مِنْ أُمَّتِي أَدْخَلَهُ اللَّهُ بِهِمَا الْجَنَّةَ ‏"‏ ‏.‏ فَقَالَتْ لَهُ عَائِشَةُ فَمَنْ كَانَ لَهُ فَرَطٌ مِنْ أُمَّتِكَ قَالَ ‏"‏ وَمَنْ كَانَ لَهُ فَرَطٌ يَا مُوَفَّقَةُ ‏"‏ ‏.‏ قَالَتْ فَمَنْ لَمْ يَكُنْ لَهُ فَرَطٌ مِنْ أُمَّتِكَ قَالَ ‏"‏ فَأَنَا فَرَطُ أُمَّتِي لَنْ يُصَابُوا بِمِثْلِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ رَبِّهِ بْنِ بَارِقٍ وَقَدْ رَوَى عَنْهُ غَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْمُرَابِطِيُّ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، أَنْبَأَنَا عَبْدُ رَبِّهِ بْنُ بَارِقٍ، فَذَكَرَ نَحْوَهُ ‏.‏ وَسِمَاكُ بْنُ الْوَلِيدِ هُوَ أَبُو زُمَيْلٍ الْحَنَفِيُّ ‏.‏\hadithno{1062}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdurabbih bin Bariq Al-Hanafi said:"I heard my grandfather, the father of my mother, Simak bin Al-Walid Al-Hanadi narrating, that he heard Ibn Abbas narrated, that he heard the Messenger of Allah saying: "Whoever has two predecessors (in death) among my Ummah, then Allah will admit them into Paradise."So Aishah said to him: "What about one from your Ummar who has one precessor?" He (pbuh) said: "And whoever has one predecessor O Muwaffaqqah!" So she said: "What about one who does not have a predecessor from your Ummah?" He said: "I am the predecessor for my Ummah: you will never suffer (in grief) for (the loss of) anyone similar to me}}
\hadithdefcmd{tirmidhi}{1063}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّهَدَاءُ خَمْسٌ الْمَطْعُونُ وَالْمَبْطُونُ وَالْغَرِقُ وَصَاحِبُ الْهَدْمِ وَالشَّهِيدُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَصَفْوَانَ بْنِ أُمَيَّةَ وَجَابِرِ بْنِ عَتِيكٍ وَخَالِدِ بْنِ عُرْفُطَةَ وَسُلَيْمَانَ بْنِ صُرَدٍ وَأَبِي مُوسَى وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1063}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "The martyrs are five: Those who die of the plague, stomach illness, drowning, being crushed, and the martyr in the cause of Allah}}
\hadithdefcmd{tirmidhi}{1064}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ الْكُوفِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو سِنَانٍ الشَّيْبَانِيُّ، عَنْ أَبِي إِسْحَاقَ السَّبِيعِيِّ، قَالَ قَالَ سُلَيْمَانُ بْنُ صُرَدٍ لِخَالِدِ بْنِ عُرْفُطَةَ أَوْ خَالِدٌ لِسُلَيْمَانَ أَمَا سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَتَلَهُ بَطْنُهُ لَمْ يُعَذَّبْ فِي قَبْرِهِ ‏"‏ ‏.‏ فَقَالَ أَحَدُهُمَا لِصَاحِبِهِ نَعَمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ فِي هَذَا الْبَابِ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{1064}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Ishaq As-Sabi'i said:"Sulaiman bin Surad said to Khalid bin Urfutah - or, Khalid said to Sulaiman - 'Did you hear the Messenger of Allah saying: "Whoever is killed by his stomach then he will not be punished in the grave"?' One of them said to the other: "Yes}}
\hadithdefcmd{tirmidhi}{1065}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ذَكَرَ الطَّاعُونَ فَقَالَ ‏ "‏ بَقِيَّةُ رِجْزٍ - أَوْ عَذَابٍ أُرْسِلَ عَلَى طَائِفَةٍ مِنْ بَنِي إِسْرَائِيلَ فَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا مِنْهَا وَإِذَا وَقَعَ بِأَرْضٍ وَلَسْتُمْ بِهَا فَلاَ تَهْبِطُوا عَلَيْهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدٍ وَخُزَيْمَةَ بْنِ ثَابِتٍ وَعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَجَابِرٍ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُسَامَةَ بْنِ زَيْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1065}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Usamah bin Zaid narrated that:The Prophet mentioned the plague and said: "It is an abiding punishment or chastisement that was sent upon a group of the children of Isra'il. So when it occurs in a land while you are in it, then do not leave it. And when it occurs in a land while you are not in it, then do not enter it}}
\hadithdefcmd{tirmidhi}{1066}{حَدَّثَنَا أَحْمَدُ بْنُ مِقْدَامٍ أَبُو الأَشْعَثِ الْعِجْلِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي مُوسَى وَأَبِي هُرَيْرَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُبَادَةَ بْنِ الصَّامِتِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1066}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ubadah bin As-Samit narrated that:The Prophet said: "Whoever loves to meet Allah, then Allah loves to meet him. And whoever dislikes meeting Allah, then Allah dislikes meeting him}}
\hadithdefcmd{tirmidhi}{1067}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، أَنَّهَا ذَكَرَتْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ كُلُّنَا نَكْرَهُ الْمَوْتَ ‏.‏ قَالَ ‏"‏ لَيْسَ ذَلِكَ وَلَكِنَّ الْمُؤْمِنَ إِذَا بُشِّرَ بِرَحْمَةِ اللَّهِ وَرِضْوَانِهِ وَجَنَّتِهِ أَحَبَّ لِقَاءَ اللَّهِ وَأَحَبَّ اللَّهُ لِقَاءَهُ وَإِنَّ الْكَافِرَ إِذَا بُشِّرَ بِعَذَابِ اللَّهِ وَسَخَطِهِ كَرِهَ لِقَاءَ اللَّهِ وَكَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1067}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sa'd bin Hisham narrated that:Aishah mentioned that the Messenger of Allah said: "Whoever loves to meet Allah, then Allah loves to meet him. And whoever dislikes meeting Allah, then Allah dislikes meeting him." She said: "O Messenger of Allah! All of us dislike death." He said: "It is not like that. But when the believer is given the good news of Allah's mercy, His pleasure, and His Paradise, then he loves to meet Allah and Allah loves to meet him. Whereas when the disbeliever is given the news of Allah's punishment and His wrath, he dislikes meeting Allah, and Allah dislikes meeting him}}
\hadithdefcmd{tirmidhi}{1068}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْرَائِيلُ، وَشَرِيكٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ رَجُلاً، قَتَلَ نَفْسَهُ فَلَمْ يُصَلِّ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا فَقَالَ بَعْضُهُمْ يُصَلَّى عَلَى كُلِّ مَنْ صَلَّى إِلَى الْقِبْلَةِ وَعَلَى قَاتِلِ النَّفْسِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَإِسْحَاقَ ‏.‏ وَقَالَ أَحْمَدُ لاَ يُصَلِّي الإِمَامُ عَلَى قَاتِلِ النَّفْسِ وَيُصَلِّي عَلَيْهِ غَيْرُ الإِمَامِ ‏.‏\hadithno{1068}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir bin Samurah narrated:"A man killed himself, so the Prophet did not perform Salat over him}}
\hadithdefcmd{tirmidhi}{1069}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي قَتَادَةَ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِرَجُلٍ لِيُصَلِّيَ عَلَيْهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ فَإِنَّ عَلَيْهِ دَيْنًا ‏"‏ ‏.‏ قَالَ أَبُو قَتَادَةَ هُوَ عَلَىَّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بِالْوَفَاءِ ‏"‏ ‏.‏ قَالَ بِالْوَفَاءِ ‏.‏ فَصَلَّى عَلَيْهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَسَلَمَةَ بْنِ الأَكْوَعِ وَأَسْمَاءَ بِنْتِ يَزِيدَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي قَتَادَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1069}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Abi Qatadah narrated from his father that:The Prophet was brought a (deceased) man to perform Salat over. So the Prophet said: "Pray for your companion; for indeed he had a debt upon him." Abu Qatadah said: "It shall be upon me." So the Messenger of Allah said: "To pay it off?" (He said: "To pay it off.") So he performed the prayer for him}}
\hadithdefcmd{tirmidhi}{1070}{حَدَّثَنَا أَبُو الْفَضْلِ، مَكْتُومُ بْنُ الْعَبَّاسِ التِّرْمِذِيُّ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ صَالِحٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُؤْتَى بِالرَّجُلِ الْمُتَوَفَّى عَلَيْهِ الدَّيْنُ فَيَقُولُ ‏"‏ هَلْ تَرَكَ لِدَيْنِهِ مِنْ قَضَاءٍ ‏"‏ ‏.‏ فَإِنْ حُدِّثَ أَنَّهُ تَرَكَ وَفَاءً صَلَّى عَلَيْهِ وَإِلاَّ قَالَ لِلْمُسْلِمِينَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ فَلَمَّا فَتَحَ اللَّهُ عَلَيْهِ الْفُتُوحَ قَامَ فَقَالَ ‏"‏ أَنَا أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ فَمَنْ تُوُفِّيَ مِنَ الْمُسْلِمِينَ فَتَرَكَ دَيْنًا عَلَىَّ قَضَاؤُهُ وَمَنْ تَرَكَ مَالاً فَهُوَ لِوَرَثَتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ يَحْيَى بْنُ بُكَيْرٍ وَغَيْرُ وَاحِدٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ نَحْوَ حَدِيثِ عَبْدِ اللَّهِ بْنِ صَالِحٍ ‏.‏\hadithno{1070}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"A deceased man would be brought to the Messenger of Allah while a debt was due upon him. So he would say: 'Has he left anything to pay off his debt?' If he was told that he had left something to pay it then he would pray (the funeral prayer) for him. Otherwise he would tell the Muslims: 'Pray for your companion.' So when Allah granted him the victories, he stood and said: 'I am more worthy in the case of the believers than they themselves are. So whoever among the believers dies and leaves a debt behind, then it is up to me to fulfill it. And whoever leaves wealth behind, then it is for his heirs}}
\hadithdefcmd{tirmidhi}{1071}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قُبِرَ الْمَيِّتُ - أَوْ قَالَ أَحَدُكُمْ أَتَاهُ مَلَكَانِ أَسْوَدَانِ أَزْرَقَانِ يُقَالُ لأَحَدِهِمَا الْمُنْكَرُ وَالآخَرُ النَّكِيرُ فَيَقُولاَنِ مَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ فَيَقُولُ مَا كَانَ يَقُولُ هُوَ عَبْدُ اللَّهِ وَرَسُولُهُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏ فَيَقُولاَنِ قَدْ كُنَّا نَعْلَمُ أَنَّكَ تَقُولُ هَذَا ‏.‏ ثُمَّ يُفْسَحُ لَهُ فِي قَبْرِهِ سَبْعُونَ ذِرَاعًا فِي سَبْعِينَ ثُمَّ يُنَوَّرُ لَهُ فِيهِ ثُمَّ يُقَالُ لَهُ نَمْ ‏.‏ فَيَقُولُ أَرْجِعُ إِلَى أَهْلِي فَأُخْبِرُهُمْ فَيَقُولاَنِ نَمْ كَنَوْمَةِ الْعَرُوسِ الَّذِي لاَ يُوقِظُهُ إِلاَّ أَحَبُّ أَهْلِهِ إِلَيْهِ ‏.‏ حَتَّى يَبْعَثَهُ اللَّهُ مِنْ مَضْجَعِهِ ذَلِكَ ‏.‏ وَإِنْ كَانَ مُنَافِقًا قَالَ سَمِعْتُ النَّاسَ يَقُولُونَ فَقُلْتُ مِثْلَهُ لاَ أَدْرِي ‏.‏ فَيَقُولاَنِ قَدْ كُنَّا نَعْلَمُ أَنَّكَ تَقُولُ ذَلِكَ ‏.‏ فَيُقَالُ لِلأَرْضِ الْتَئِمِي عَلَيْهِ ‏.‏ فَتَلْتَئِمُ عَلَيْهِ ‏.‏ فَتَخْتَلِفُ فِيهَا أَضْلاَعُهُ فَلاَ يَزَالُ فِيهَا مُعَذَّبًا حَتَّى يَبْعَثَهُ اللَّهُ مِنْ مَضْجَعِهِ ذَلِكَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَزَيْدِ بْنِ ثَابِتٍ وَابْنِ عَبَّاسٍ وَالْبَرَاءِ بْنِ عَازِبٍ وَأَبِي أَيُّوبَ وَأَنَسٍ وَجَابِرٍ وَعَائِشَةَ وَأَبِي سَعِيدٍ كُلُّهُمْ رَوَوْا عَنِ النَّبِيِّ صلى الله عليه وسلم فِي عَذَابِ الْقَبْرِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1071}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "When the deceased - or he said when one of you - is buried, two angels, black and blue (eyed\_ come to him. One of them is called Al-Munkar, and the other An-Nakir. They say: 'What did you used to say about this man?' So he says what he was saying (before death) 'He is Allah's slave and His Messenger. I testify that none has the right to be worshipped but Allah and that Muhammad is His slave and His Messenger.' So they say: 'We knew that you would say this.' Then his grave is expanded to seventy by seventy cubits, then it is illuminated for him. Then it is said to him: 'Sleep.' So he said: 'Can I return to my family to inform them?' They say: 'Sleep as a newlywed, whom none awakens but the dearest of his family.' Until Allah resurrects him from his resting place.""If he was a hypocrite he would say: 'I heard people saying something, so I said the same; I do not know.' So they said: 'We knew you would say that.' So the earth is told: 'Constrict him.' So it constricts around him, squeezing his ribs together. He continues being punished like that until Allah resurrects him from his resting place}}
\hadithdefcmd{tirmidhi}{1072}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَاتَ الْمَيِّتُ عُرِضَ عَلَيْهِ مَقْعَدُهُ بِالْغَدَاةِ وَالْعَشِيِّ فَإِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَمِنْ أَهْلِ الْجَنَّةِ وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ ثُمَّ يُقَالُ هَذَا مَقْعَدُكَ حَتَّى يَبْعَثَكَ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1072}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that:The Messenger of Allah said: "When a person dies, he is shown his place [both in the morning and the evening]. If he is one of the people of Paradise; he is shown his place among the people of Paradise, and if he one of the people of the Fire; he is shown his place among the people of the Fire. Then it is said to him: 'This is your place until Allah resurrects you on the Day of Judgment}}
\hadithdefcmd{tirmidhi}{1073}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا عَلِيُّ بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا وَاللَّهِ، مُحَمَّدُ بْنُ سُوقَةَ عَنْ إِبَرْاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ عَزَّى مُصَابًا فَلَهُ مِثْلُ أَجْرِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ عَلِيِّ بْنِ عَاصِمٍ ‏.‏ وَرَوَى بَعْضُهُمْ عَنْ مُحَمَّدِ بْنِ سُوقَةَ بِهَذَا الإِسْنَادِ مِثْلَهُ مَوْقُوفًا وَلَمْ يَرْفَعْهُ ‏.‏ وَيُقَالُ أَكْثَرُ مَا ابْتُلِيَ بِهِ عَلِيُّ بْنُ عَاصِمٍ بِهَذَا الْحَدِيثِ نَقَمُوا عَلَيْهِ ‏.‏\hadithno{1073}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah narrated that:The Prophet said: "Whoever consoles a person with an affliction, then he gets the same reward as him}}
\hadithdefcmd{tirmidhi}{1074}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَأَبُو عَامِرٍ الْعَقَدِيُّ قَالاَ حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ رَبِيعَةَ بْنِ سَيْفٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمٍ يَمُوتُ يَوْمَ الْجُمُعَةِ أَوْ لَيْلَةَ الْجُمُعَةِ إِلاَّ وَقَاهُ اللَّهُ فِتْنَةَ الْقَبْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَلَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ ‏.‏ رَبِيعَةُ بْنُ سَيْفٍ إِنَّمَا يَرْوِي عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَلاَ نَعْرِفُ لِرَبِيعَةَ بْنِ سَيْفٍ سَمَاعًا مِنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{1074}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Amr narrated that:The Messenger of Allah said: "No Muslim dies on the day of Friday, nor the night of Friday, except that Allah protects him from the trials of the grave}}
\hadithdefcmd{tirmidhi}{1075}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ سَعِيدِ بْنِ عَبْدِ اللَّهِ الْجُهَنِيِّ، عَنْ مُحَمَّدِ بْنِ عُمَرَ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ يَا عَلِيُّ ثَلاَثٌ لاَ تُؤَخِّرْهَا الصَّلاَةُ إِذَا آنَتْ وَالْجَنَازَةُ إِذَا حَضَرَتْ وَالأَيِّمُ إِذَا وَجَدْتَ لَهَا كُفْؤًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَمَا أَرَى إِسْنَادَهُ بِمُتَّصِلٍ ‏.‏\hadithno{1075}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Ali bin Abi Talib narrated that:The Messenger of Allah said to him: "O Ali! Three are not to be delayed: Salat when it is due, the funeral when it is presented, and (marriage) for the single woman when someone compatible is found}}
\hadithdefcmd{tirmidhi}{1076}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُؤَدِّبُ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَتْنَا أُمُّ الأَسْوَدِ، عَنْ مُنْيَةَ بِنْتِ عُبَيْدِ بْنِ أَبِي بَرْزَةَ، عَنْ جَدِّهَا أَبِي بَرْزَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَزَّى ثَكْلَى كُسِيَ بُرْدًا فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏\hadithno{1076}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Barzah narrated that :The Messenger of Allah said: "Whoever consoles a bereaved mother, he will be clothes with a Burd in Paradise}}
\hadithdefcmd{tirmidhi}{1077}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبَانَ الْوَرَّاقُ، عَنْ يَحْيَى بْنِ يَعْلَى الأَسْلَمِيِّ، عَنْ أَبِي فَرْوَةَ، يَزِيدَ بْنِ سِنَانٍ عَنْ زَيْدٍ، وَهُوَ ابْنُ أَبِي أُنَيْسَةَ عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهُ صلى الله عليه وسلم كَبَّرَ عَلَى جَنَازَةٍ فَرَفَعَ يَدَيْهِ فِي أَوَّلِ تَكْبِيرَةٍ وَوَضَعَ الْيُمْنَى عَلَى الْيُسْرَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا فَرَأَى أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنْ يَرْفَعَ الرَّجُلُ يَدَيْهِ فِي كُلِّ تَكْبِيرَةٍ عَلَى الْجَنَازَةِ ‏.‏ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يَرْفَعُ يَدَيْهِ إِلاَّ فِي أَوَّلِ مَرَّةٍ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏ وَذُكِرَ عَنِ ابْنِ الْمُبَارَكِ أَنَّهُ قَالَ فِي الصَّلاَةِ عَلَى الْجَنَازَةِ لاَ يَقْبِضُ يَمِينَهُ عَلَى شِمَالِهِ ‏.‏ وَرَأَى بَعْضُ أَهْلِ الْعِلْمِ أَنْ يَقْبِضَ بِيَمِينِهِ عَلَى شِمَالِهِ كَمَا يَفْعَلُ فِي الصَّلاَةِ ‏.‏ قَالَ أَبُو عِيسَى يَقْبِضُ أَحَبُّ إِلَىَّ ‏.‏\hadithno{1077}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah said, 'Allahu Akbar' over the deceased, so he raised his hands with the first Takbir, and he placed his right (hand) over his left}}
\hadithdefcmd{tirmidhi}{1078}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَفْسُ الْمُؤْمِنِ مُعَلَّقَةٌ بِدَيْنِهِ حَتَّى يُقْضَى عَنْهُ ‏"‏ ‏.‏\hadithno{1078}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "The believer's soul is suspended by his debt until it is settled for him}}
\hadithdefcmd{tirmidhi}{1079}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نَفْسُ الْمُؤْمِنِ مُعَلَّقَةٌ بِدَيْنِهِ حَتَّى يُقْضَى عَنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَهُوَ أَصَحُّ مِنَ الأَوَّلِ ‏.‏\hadithno{1079}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Another chain) Abu Hurairah narrated that:The Messenger of Allah said: "The believer's soul is suspended by his debt until it is settled for him}}
