% Auto-generated chapter 10 for bukhari
% Hadiths in this chapter: 266

\hadithdefcmd{bukhari}{603}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ ذَكَرُوا النَّارَ وَالنَّاقُوسَ، فَذَكَرُوا الْيَهُودَ وَالنَّصَارَى، فَأُمِرَ بِلاَلٌ أَنْ يَشْفَعَ الأَذَانَ وَأَنْ يُوتِرَ الإِقَامَةَ‏.‏\hadithno{603}\hadithtrans{Narrated Anas:The people mentioned the fire and the bell (they suggested those as signals to indicate the starting of prayers), and by that they mentioned the Jews and the Christians. Then Bilal was ordered to pronounce Adhan for the prayer by saying its wordings twice, and for the Iqama (the call for the actual standing for the prayers in rows) by saying its wordings once. (Iqama is pronounced when the people are ready for the prayer)}}
\hadithdefcmd{bukhari}{604}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي نَافِعٌ، أَنَّ ابْنَ عُمَرَ، كَانَ يَقُولُ كَانَ الْمُسْلِمُونَ حِينَ قَدِمُوا الْمَدِينَةَ يَجْتَمِعُونَ فَيَتَحَيَّنُونَ الصَّلاَةَ، لَيْسَ يُنَادَى لَهَا، فَتَكَلَّمُوا يَوْمًا فِي ذَلِكَ، فَقَالَ بَعْضُهُمْ اتَّخِذُوا نَاقُوسًا مِثْلَ نَاقُوسِ النَّصَارَى‏.‏ وَقَالَ بَعْضُهُمْ بَلْ بُوقًا مِثْلَ قَرْنِ الْيَهُودِ‏.‏ فَقَالَ عُمَرُ أَوَلاَ تَبْعَثُونَ رَجُلاً يُنَادِي بِالصَّلاَةِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا بِلاَلُ قُمْ فَنَادِ بِالصَّلاَةِ ‏"‏‏.‏\hadithno{604}\hadithtrans{Narrated Ibn `Umar:When the Muslims arrived at Medina, they used to assemble for the prayer, and used to guess the time for it. During those days, the practice of Adhan for the prayers had not been introduced yet. Once they discussed this problem regarding the call for prayer. Some people suggested the use of a bell like the Christians, others proposed a trumpet like the horn used by the Jews, but `Umar was the first to suggest that a man should call (the people) for the prayer; so Allah's Messenger (ﷺ) ordered Bilal to get up and pronounce the Adhan for prayers}}
\hadithdefcmd{bukhari}{605}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ سِمَاكِ بْنِ عَطِيَّةَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ أُمِرَ بِلاَلٌ أَنْ يَشْفَعَ، الأَذَانَ وَأَنْ يُوتِرَ الإِقَامَةَ إِلاَّ الإِقَامَةَ‏.‏\hadithno{605}\hadithtrans{Narrated Anas:Bilal was ordered to repeat the wording of the Adhan for prayers twice, and to pronounce the wording of the Iqama once except "Qad-qamat-is-salat}}
\hadithdefcmd{bukhari}{606}{حَدَّثَنَا مُحَمَّدٌ، قَالَ أَخْبَرَنَا عَبْدُ الْوَهَّابِ، قَالَ أَخْبَرَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا كَثُرَ النَّاسُ قَالَ ـ ذَكَرُوا ـ أَنْ يَعْلَمُوا وَقْتَ الصَّلاَةِ بِشَىْءٍ يَعْرِفُونَهُ، فَذَكَرُوا أَنْ يُورُوا نَارًا أَوْ يَضْرِبُوا نَاقُوسًا، فَأُمِرَ بِلاَلٌ أَنْ يَشْفَعَ الأَذَانَ وَأَنْ يُوتِرَ الإِقَامَةَ‏.‏\hadithno{606}\hadithtrans{Narrated Anas bin Malik:When the number of Muslims increased they discussed the question as to how to know the time for the prayer by some familiar means. Some suggested that a fire be lit (at the time of the prayer) and others put forward the proposal to ring the bell. Bilal was ordered to pronounce the wording of Adhan twice and of the Iqama once only}}
\hadithdefcmd{bukhari}{607}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ أُمِرَ بِلاَلٌ أَنْ يَشْفَعَ، الأَذَانَ، وَأَنْ يُوتِرَ الإِقَامَةَ‏.‏ قَالَ إِسْمَاعِيلُ فَذَكَرْتُ لأَيُّوبَ فَقَالَ إِلاَّ الإِقَامَةَ‏.‏\hadithno{607}\hadithtrans{Narrated Abu Qilaba:Anas said, "Bilal was ordered to pronounce the wording of Adhan twice and of Iqama once only." The sub narrator Isma`il said, "I mentioned that to Aiyub and he added (to that), "Except Iqama (i.e. Qad-qamat-is-salat which should be said twice)}}
\hadithdefcmd{bukhari}{608}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نُودِيَ لِلصَّلاَةِ أَدْبَرَ الشَّيْطَانُ وَلَهُ ضُرَاطٌ حَتَّى لاَ يَسْمَعَ التَّأْذِينَ، فَإِذَا قَضَى النِّدَاءَ أَقْبَلَ، حَتَّى إِذَا ثُوِّبَ بِالصَّلاَةِ أَدْبَرَ، حَتَّى إِذَا قَضَى التَّثْوِيبَ أَقْبَلَ حَتَّى يَخْطُرَ بَيْنَ الْمَرْءِ وَنَفْسِهِ، يَقُولُ اذْكُرْ كَذَا، اذْكُرْ كَذَا‏.‏ لِمَا لَمْ يَكُنْ يَذْكُرُ، حَتَّى يَظَلَّ الرَّجُلُ لاَ يَدْرِي كَمْ صَلَّى ‏"‏‏.‏\hadithno{608}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the Adhan is pronounced Satan takes to his heels and passes wind with noise during his flight in order not to hear the Adhan. When the Adhan is completed he comes back and again takes to his heels when the Iqama is pronounced and after its completion he returns again till he whispers into the heart of the person (to divert his attention from his prayer) and makes him remember things which he does not recall to his mind before the prayer and that causes him to forget how much he has prayed}}
\hadithdefcmd{bukhari}{609}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ الأَنْصَارِيِّ، ثُمَّ الْمَازِنِيِّ عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ قَالَ لَهُ ‏ "‏ إِنِّي أَرَاكَ تُحِبُّ الْغَنَمَ وَالْبَادِيَةَ، فَإِذَا كُنْتَ فِي غَنَمِكَ أَوْ بَادِيَتِكَ فَأَذَّنْتَ بِالصَّلاَةِ فَارْفَعْ صَوْتَكَ بِالنِّدَاءِ، فَإِنَّهُ لاَ يَسْمَعُ مَدَى صَوْتِ الْمُؤَذِّنِ جِنٌّ وَلاَ إِنْسٌ وَلاَ شَىْءٌ إِلاَّ شَهِدَ لَهُ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{609}\hadithtrans{Narrated `Abdur-Rahman:Abu Sa`id Al-Khudri told my father, "I see you liking sheep and the wilderness. So whenever you are with your sheep or in the wilderness and you want to pronounce Adhan for the prayer raise your voice in doing so, for whoever hears the Adhan, whether a human being, a jinn or any other creature, will be a witness for you on the Day of Resurrection." Abu Sa`id added, "I heard it (this narration) from Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{610}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا غَزَا بِنَا قَوْمًا لَمْ يَكُنْ يَغْزُو بِنَا حَتَّى يُصْبِحَ وَيَنْظُرَ، فَإِنْ سَمِعَ أَذَانًا كَفَّ عَنْهُمْ، وَإِنْ لَمْ يَسْمَعْ أَذَانًا أَغَارَ عَلَيْهِمْ، قَالَ فَخَرَجْنَا إِلَى خَيْبَرَ فَانْتَهَيْنَا إِلَيْهِمْ لَيْلاً، فَلَمَّا أَصْبَحَ وَلَمْ يَسْمَعْ أَذَانًا رَكِبَ وَرَكِبْتُ خَلْفَ أَبِي طَلْحَةَ، وَإِنَّ قَدَمِي لَتَمَسُّ قَدَمَ النَّبِيِّ صلى الله عليه وسلم‏.‏ قَالَ فَخَرَجُوا إِلَيْنَا بِمَكَاتِلِهِمْ وَمَسَاحِيهِمْ فَلَمَّا رَأَوُا النَّبِيَّ صلى الله عليه وسلم قَالُوا مُحَمَّدٌ وَاللَّهِ، مُحَمَّدٌ وَالْخَمِيسُ‏.‏ قَالَ فَلَمَّا رَآهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُ أَكْبَرُ، اللَّهُ أَكْبَرُ، خَرِبَتْ خَيْبَرُ، إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏‏.‏\hadithno{610}\hadithtrans{Narrated Humaid:Anas bin Malik said, "Whenever the Prophet (ﷺ) went out with us to fight (in Allah's cause) against any nation, he never allowed us to attack till morning and he would wait and see: if he heard Adhan he would postpone the attack and if he did not hear Adhan he would attack them." Anas added, "We reached Khaibar at night and in the morning when he did not hear the Adhan for the prayer, he (the Prophet ) rode and I rode behind Abi Talha and my foot was touching that of the Prophet. The inhabitants of Khaibar came out with their baskets and spades and when they saw the Prophet (ﷺ) they shouted 'Muhammad! By Allah, Muhammad and his army.' When Allah's Messenger (ﷺ) saw them, he said, "Allahu-Akbar! Allahu-Akbar! Khaibar is ruined. Whenever we approach a (hostile) nation (to fight), then evil will be the morning of those who have been warned}}
\hadithdefcmd{bukhari}{611}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمُ النِّدَاءَ فَقُولُوا مِثْلَ ما يَقُولُ الْمُؤَذِّنُ ‏"‏‏.‏\hadithno{611}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "Whenever you hear the Adhan, say what the Mu'adh-dhin is saying}}
\hadithdefcmd{bukhari}{612}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، قَالَ حَدَّثَنِي عِيسَى بْنُ طَلْحَةَ، أَنَّهُ سَمِعَ مُعَاوِيَةَ، يَوْمًا فَقَالَ مِثْلَهُ إِلَى قَوْلِهِ ‏ "‏ وَأَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏"‏‏.‏\hadithno{612}\hadithtrans{Narrated `Isa bin Talha:that he had heard Muawiya repeating the words of Adhan up to "Wa ash-hadu anna Muhammadan rasulul-lah (and I testify that Muhammad is Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{613}{حَدَّثَنَا إِسْحَاقُ بْنُ رَاهَوَيْهِ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، نَحْوَهُ‏.‏ قَالَ يَحْيَى وَحَدَّثَنِي بَعْضُ، إِخْوَانِنَا أَنَّهُ قَالَ لَمَّا قَالَ حَىَّ عَلَى الصَّلاَةِ‏.‏ قَالَ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ‏.‏ وَقَالَ هَكَذَا سَمِعْنَا نَبِيَّكُمْ صلى الله عليه وسلم يَقُولُ‏.‏\hadithno{613}\hadithtrans{Narrated Yahya as above (586) and added:"Some of my companions told me that Hisham had said, "When the Mu'adh-dhin said, "Haiyi `alassala (come for the prayer)." Muawiya said, "La hawla wala quwata illa billah (There is neither might nor any power except with Allah)" and added, "We heard your Prophet saying the same}}
\hadithdefcmd{bukhari}{614}{حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يَسْمَعُ النِّدَاءَ اللَّهُمَّ رَبَّ هَذِهِ الدَّعْوَةِ التَّامَّةِ وَالصَّلاَةِ الْقَائِمَةِ آتِ مُحَمَّدًا الْوَسِيلَةَ وَالْفَضِيلَةَ وَابْعَثْهُ مَقَامًا مَحْمُودًا الَّذِي وَعَدْتَهُ، حَلَّتْ لَهُ شَفَاعَتِي يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{614}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "Whoever after listening to the Adhan says, 'Allahumma Rabba hadhihi-dda` watit-tammah, was-salatil qa'imah, ati Muhammadan al-wasilata wal-fadilah, wa b`ath-hu maqaman mahmudan-il-ladhi wa`adtahu' [O Allah! Lord of this perfect call (perfect by not ascribing partners to You) and of the regular prayer which is going to be established, give Muhammad the right of intercession and illustriousness, and resurrect him to the best and the highest place in Paradise that You promised him (of)], then my intercession for him will be allowed on the Day of Resurrection}}
\hadithdefcmd{bukhari}{615}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ، ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا عَلَيْهِ لاَسْتَهَمُوا، وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ، وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏‏.‏\hadithno{615}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If the people knew the reward for pronouncing the Adhan and for standing in the first row (in congregational prayers) and found no other way to get that except by drawing lots they would draw lots, and if they knew the reward of the Zuhr prayer (in the early moments of its stated time) they would race for it (go early) and if they knew the reward of `Isha' and Fajr (morning) prayers in congregation, they would come to offer them even if they had to crawl}}
\hadithdefcmd{bukhari}{616}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، وَعَبْدِ الْحَمِيدِ، صَاحِبِ الزِّيَادِيِّ وَعَاصِمٍ الأَحْوَلِ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ قَالَ خَطَبَنَا ابْنُ عَبَّاسٍ فِي يَوْمٍ رَدْغٍ، فَلَمَّا بَلَغَ الْمُؤَذِّنُ حَىَّ عَلَى الصَّلاَةِ‏.‏ فَأَمَرَهُ أَنْ يُنَادِيَ الصَّلاَةُ فِي الرِّحَالِ‏.‏ فَنَظَرَ الْقَوْمُ بَعْضُهُمْ إِلَى بَعْضٍ فَقَالَ فَعَلَ هَذَا مَنْ هُوَ خَيْرٌ مِنْهُ وَإِنَّهَا عَزْمَةٌ‏.‏\hadithno{616}\hadithtrans{Narrated `Abdullah bin Al-Harith:Once on a rainy muddy day, Ibn `Abbas delivered a sermon in our presence and when the Mu'adhdhin pronounced the Adhan and said, "Haiyi `ala-s-sala(t) (come for the prayer)" Ibn `Abbas ordered him to say 'Pray at your homes.' The people began to look at each other (surprisingly). Ibn `Abbas said. "It was done by one who was much better than I (i.e. the Prophet (ﷺ) or his Mu'adh-dhin), and it is a license}}
\hadithdefcmd{bukhari}{617}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ، فَكُلُوا وَاشْرَبُوا حَتَّى يُنَادِيَ ابْنُ أُمِّ مَكْتُومٍ ‏"‏‏.‏ ثُمَّ قَالَ وَكَانَ رَجُلاً أَعْمَى لاَ يُنَادِي حَتَّى يُقَالَ لَهُ أَصْبَحْتَ أَصْبَحْتَ‏.‏\hadithno{617}\hadithtrans{Narrated Salim bin `Abdullah:My father said that Allah's Apostle said, "Bilal pronounces 'Adhan at night, so keep on eating and drinking (Suhur) till Ibn Um Maktum pronounces Adhan." Salim added, "He was a blind man who would not pronounce the Adhan unless he was told that the day had dawned}}
\hadithdefcmd{bukhari}{618}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ أَخْبَرَتْنِي حَفْصَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اعْتَكَفَ الْمُؤَذِّنُ لِلصُّبْحِ وَبَدَا الصُّبْحُ صَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ قَبْلَ أَنْ تُقَامَ الصَّلاَةُ‏.‏\hadithno{618}\hadithtrans{Narrated Hafsa:When the Mu'adh-dhin pronounced the Adhan for Fajr prayer and the dawn became evident the Prophet ordered a two rak`at light prayer (Sunna) before the Iqama of the compulsory (congregational) prayer}}
\hadithdefcmd{bukhari}{619}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي رَكْعَتَيْنِ خَفِيفَتَيْنِ بَيْنَ النِّدَاءِ وَالإِقَامَةِ مِنْ صَلاَةِ الصُّبْحِ‏.‏\hadithno{619}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to offer two light rak`at between the Adhan and the Iqama of the Fajr prayer}}
\hadithdefcmd{bukhari}{620}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ بِلاَلاً يُنَادِي بِلَيْلٍ، فَكُلُوا وَاشْرَبُوا حَتَّى يُنَادِيَ ابْنُ أُمِّ مَكْتُومٍ ‏"‏‏.‏\hadithno{620}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Bilal pronounces the Adhan at night, so keep on eating and drinking (Suhur) till Ibn Um Maktum pronounces the Adhan}}
\hadithdefcmd{bukhari}{621}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْنَعَنَّ أَحَدَكُمْ ـ أَوْ أَحَدًا مِنْكُمْ ـ أَذَانُ بِلاَلٍ مِنْ سَحُورِهِ، فَإِنَّهُ يُؤَذِّنُ ـ أَوْ يُنَادِي ـ بِلَيْلٍ، لِيَرْجِعَ قَائِمَكُمْ وَلِيُنَبِّهَ نَائِمَكُمْ، وَلَيْسَ أَنْ يَقُولَ الْفَجْرُ أَوِ الصُّبْحُ ‏"‏‏.‏ وَقَالَ بِأَصَابِعِهِ وَرَفَعَهَا إِلَى فَوْقُ وَطَأْطَأَ إِلَى أَسْفَلُ حَتَّى يَقُولَ هَكَذَا‏.‏ وَقَالَ زُهَيْرٌ بِسَبَّابَتَيْهِ إِحْدَاهُمَا فَوْقَ الأُخْرَى ثُمَّ مَدَّهَا عَنْ يَمِينِهِ وَشِمَالِهِ‏.‏\hadithno{621}\hadithtrans{Narrated `Abdullah bin Mas`ud:The Prophet (ﷺ) said, "The Adhan pronounced by Bilal should not stop you from taking Suhur, for he pronounces the Adhan at night, so that the one offering the late night prayer (Tahajjud) from among you might hurry up and the sleeping from among you might wake up. It does not mean that dawn or morning has started." Then he (the Prophet) pointed with his fingers and raised them up (towards the sky) and then lowered them (towards the earth) like this (Ibn Mas`ud imitated the gesture of the Prophet). Az-Zuhri gestured with his two index fingers which he put on each other and then stretched them to the right and left. These gestures illustrate the way real dawn appears. It spreads left and right horizontally. The dawn that appears in the high sky and lowers down is not the real dawn}}
\hadithdefcmd{bukhari}{623}{حَدَّثَنَا إِسْحَاقُ، قَالَ أَخْبَرَنَا أَبُو أُسَامَةَ، قَالَ عُبَيْدُ اللَّهِ حَدَّثَنَا عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ،‏.‏ وَعَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ‏.‏ ح وَحَدَّثَنِي يُوسُفُ بْنُ عِيسَى الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا الْفَضْلُ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ، فَكُلُوا وَاشْرَبُوا حَتَّى يُؤَذِّنَ ابْنُ أُمِّ مَكْتُومٍ ‏"‏‏.‏\hadithno{623}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Bilal pronounces the Adhan at night, so eat and drink (Suhur) till Ibn Um Maktum pronounces the Adhan}}
\hadithdefcmd{bukhari}{624}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ الْجُرَيْرِيِّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ الْمُزَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَ كُلِّ أَذَانَيْنِ صَلاَةٌ ـ ثَلاَثًا ـ لِمَنْ شَاءَ ‏"‏‏.‏\hadithno{624}\hadithtrans{Narrated `Abdullah bin Mughaffal Al-Muzani:Allah's Messenger (ﷺ) said thrice, "There is a prayer between the two Adhans (Adhan and Iqama)," and added, "For the one who wants to pray}}
\hadithdefcmd{bukhari}{625}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَمْرَو بْنَ عَامِرٍ الأَنْصَارِيَّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ الْمُؤَذِّنُ إِذَا أَذَّنَ قَامَ نَاسٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يَبْتَدِرُونَ السَّوَارِيَ حَتَّى يَخْرُجَ النَّبِيُّ صلى الله عليه وسلم وَهُمْ كَذَلِكَ يُصَلُّونَ الرَّكْعَتَيْنِ قَبْلَ الْمَغْرِبِ، وَلَمْ يَكُنْ بَيْنَ الأَذَانِ وَالإِقَامَةِ شَىْءٌ‏.‏ قَالَ عُثْمَانُ بْنُ جَبَلَةَ وَأَبُو دَاوُدَ عَنْ شُعْبَةَ لَمْ يَكُنْ بَيْنَهُمَا إِلاَّ قَلِيلٌ‏.‏\hadithno{625}\hadithtrans{Narrated Anas bin Malik:"When the Mu'adh-dhin pronounced the Adhan, some of the companions of the Prophet (ﷺ) would proceed to the pillars of the mosque (for the prayer) till the Prophet (ﷺ) arrived and in this way they used to pray two rak`at before the Maghrib prayer. There used to be a little time between the Adhan and the Iqama." Shu`ba said, "There used to be a very short interval between the two (Adhan and Iqama)}}
\hadithdefcmd{bukhari}{626}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَكَتَ الْمُؤَذِّنُ بِالأُولَى مِنْ صَلاَةِ الْفَجْرِ قَامَ فَرَكَعَ رَكْعَتَيْنِ خَفِيفَتَيْنِ قَبْلَ صَلاَةِ الْفَجْرِ بَعْدَ أَنْ يَسْتَبِينَ الْفَجْرُ، ثُمَّ اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ حَتَّى يَأْتِيَهُ الْمُؤَذِّنُ لِلإِقَامَةِ‏.‏\hadithno{626}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to pray two light rak`at before the morning (compulsory) prayer after the day dawned and the Mu'adh-dhin had finished his Adhan. He then would lie on his right side till the Mu'adh-dhin came to pronounce the Iqama}}
\hadithdefcmd{bukhari}{627}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا كَهْمَسُ بْنُ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بَيْنَ كُلِّ أَذَانَيْنِ صَلاَةٌ بَيْنَ كُلِّ أَذَانَيْنِ صَلاَةٌ ـ ثُمَّ قَالَ فِي الثَّالِثَةِ ـ لِمَنْ شَاءَ ‏"‏‏.‏\hadithno{627}\hadithtrans{Narrated `Abdullah bin Mughaffal:The prophet said, "There is a prayer between the two Adhans (Adhan and Iqama), there is a prayer between the two Adhans." And then while saying it the third time he added, "For the one who wants to (pray)}}
\hadithdefcmd{bukhari}{628}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي نَفَرٍ مِنْ قَوْمِي فَأَقَمْنَا عِنْدَهُ عِشْرِينَ لَيْلَةً، وَكَانَ رَحِيمًا رَفِيقًا، فَلَمَّا رَأَى شَوْقَنَا إِلَى أَهَالِينَا قَالَ ‏ "‏ ارْجِعُوا فَكُونُوا فِيهِمْ وَعَلِّمُوهُمْ وَصَلُّوا، فَإِذَا حَضَرَتِ الصَّلاَةُ فَلْيُؤَذِّنْ لَكُمْ أَحَدُكُمْ وَلْيَؤُمَّكُمْ أَكْبَرُكُمْ ‏"‏‏.‏\hadithno{628}\hadithtrans{Narrated Malik bin Huwairith:I came to the Prophet (ﷺ) with some men from my tribe and stayed with him for twenty nights. He was kind and merciful to us. When he realized our longing for our families, he said to us, "Go back and stay with your families and teach them the religion, and offer the prayer and one of you should pronounce the Adhan for the prayer when its time is due and the oldest one amongst you should lead the prayer}}
\hadithdefcmd{bukhari}{629}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْمُهَاجِرِ أَبِي الْحَسَنِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ أَبِي ذَرٍّ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَأَرَادَ الْمُؤَذِّنُ أَنْ يُؤَذِّنَ فَقَالَ لَهُ ‏"‏ أَبْرِدْ ‏"‏‏.‏ ثُمَّ أَرَادَ أَنْ يُؤَذِّنَ فَقَالَ لَهُ ‏"‏ أَبْرِدْ ‏"‏‏.‏ ثُمَّ أَرَادَ أَنْ يُؤَذِّنَ‏.‏ فَقَالَ لَهُ ‏"‏ أَبْرِدْ ‏"‏‏.‏ حَتَّى سَاوَى الظِّلُّ التُّلُولَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏\{‏إِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ‏\}‏\hadithno{629}\hadithtrans{Narrated Abu Dhar:We were in the company of the Prophet (ﷺ) on a journey and the Mu'adh-dhin wanted to pronounce the Adhan for the (Zuhr) prayer. The Prophet (ﷺ) said to him, "Let it become cooler." Then he again wanted to pronounce the Adhan but the Prophet; said to him, "Let it become cooler." The Mu'adh-dhin again wanted to pronounce the Adhan for the prayer but the Prophet (ﷺ) said, "Let it become cooler," till the shadows of the hillocks become equal to their sizes. The Prophet (ﷺ) added, "The severity of the heat is from the raging of Hell}}
\hadithdefcmd{bukhari}{630}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ أَتَى رَجُلاَنِ النَّبِيَّ صلى الله عليه وسلم يُرِيدَانِ السَّفَرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَنْتُمَا خَرَجْتُمَا فَأَذِّنَا ثُمَّ أَقِيمَا ثُمَّ لِيَؤُمَّكُمَا أَكْبَرُكُمَا ‏"‏‏.‏\hadithno{630}\hadithtrans{Narrated Malik bin Huwairith:Two men came to the Prophet (ﷺ) with the intention of a journey. The Prophet (ﷺ) said, "When (both of) you set out, pronounce Adhan and then Iqama and the oldest of you should lead the prayer}}
\hadithdefcmd{bukhari}{631}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، قَالَ حَدَّثَنَا مَالِكٌ، أَتَيْنَا إِلَى النَّبِيِّ صلى الله عليه وسلم وَنَحْنُ شَبَبَةٌ مُتَقَارِبُونَ، فَأَقَمْنَا عِنْدَهُ عِشْرِينَ يَوْمًا وَلَيْلَةً، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَحِيمًا رَفِيقًا، فَلَمَّا ظَنَّ أَنَّا قَدِ اشْتَهَيْنَا أَهْلَنَا أَوْ قَدِ اشْتَقْنَا سَأَلَنَا عَمَّنْ تَرَكْنَا بَعْدَنَا فَأَخْبَرْنَاهُ قَالَ ‏ "‏ ارْجِعُوا إِلَى أَهْلِيكُمْ فَأَقِيمُوا فِيهِمْ وَعَلِّمُوهُمْ وَمُرُوهُمْ ـ وَذَكَرَ أَشْيَاءَ أَحْفَظُهَا أَوْ لاَ أَحْفَظُهَا ـ وَصَلُّوا كَمَا رَأَيْتُمُونِي أُصَلِّي، فَإِذَا حَضَرَتِ الصَّلاَةُ فَلْيُؤَذِّنْ لَكُمْ أَحَدُكُمْ وَلْيَؤُمَّكُمْ أَكْبَرُكُمْ ‏"‏‏.‏\hadithno{631}\hadithtrans{Narrated Malik:We came to the Prophet (ﷺ) and stayed with him for twenty days and nights. We were all young and of about the same age. The Prophet (ﷺ) was very kind and merciful. When he realized our longing for our families, he asked about our homes and the people there and we told him. Then he asked us to go back to our families and stay with them and teach them (the religion) and to order them to do good things. He also mentioned some other things which I have (remembered or [??] ) forgotten. The Prophet (ﷺ) then added, "Pray as you have seen me praying and when it is the time for the prayer one of you should pronounce the Adhan and the oldest of you should lead the prayer}}
\hadithdefcmd{bukhari}{632}{حَدَّثَنَا مُسَدَّدٌ، قَالَ أَخْبَرَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، قَالَ حَدَّثَنِي نَافِعٌ، قَالَ أَذَّنَ ابْنُ عُمَرَ فِي لَيْلَةٍ بَارِدَةٍ بِضَجْنَانَ ثُمَّ قَالَ صَلُّوا فِي رِحَالِكُمْ، فَأَخْبَرَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ مُؤَذِّنًا يُؤَذِّنُ، ثُمَّ يَقُولُ عَلَى إِثْرِهِ، أَلاَ صَلُّوا فِي الرِّحَالِ‏.‏ فِي اللَّيْلَةِ الْبَارِدَةِ أَوِ الْمَطِيرَةِ فِي السَّفَرِ‏.‏\hadithno{632}\hadithtrans{Narrated Nafi`:Once in a cold night, Ibn `Umar pronounced the Adhan for the prayer at Dajnan (the name of a mountain) and then said, "Pray at your homes", and informed us that Allah's Messenger (ﷺ) used to tell the Mu'adh-dhin to pronounce Adhan and say, "Pray at your homes" at the end of the Adhan on a rainy or a very cold night during the journey}}
\hadithdefcmd{bukhari}{633}{حَدَّثَنَا إِسْحَاقُ، قَالَ أَخْبَرَنَا جَعْفَرُ بْنُ عَوْنٍ، قَالَ حَدَّثَنَا أَبُو الْعُمَيْسِ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِالأَبْطَحِ فَجَاءَهُ بِلاَلٌ فَآذَنَهُ بِالصَّلاَةِ، ثُمَّ خَرَجَ بِلاَلٌ بِالْعَنَزَةِ حَتَّى رَكَزَهَا بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالأَبْطَحِ وَأَقَامَ الصَّلاَةَ‏.‏\hadithno{633}\hadithtrans{Narrated `Aun bin Abi Juhaifa:My father said, "I saw Allah's Messenger (ﷺ) at a place called Al-Abtah. Bilal came and informed him about the prayer and then came out with a short spear (or stick) and planted it in front of Allah's Messenger (ﷺ) at Al-Abtah and pronounced the Iqama}}
\hadithdefcmd{bukhari}{634}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، أَنَّهُ رَأَى بِلاَلاً يُؤَذِّنُ فَجَعَلْتُ أَتَتَبَّعُ فَاهُ هَا هُنَا وَهَا هُنَا بِالأَذَانِ‏.‏\hadithno{634}\hadithtrans{Narrated `Aun bin Abi Juhaifa:My father said, "I saw Bilal turning his face from side to side while pronouncing the Adhan for the prayer}}
\hadithdefcmd{bukhari}{635}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ بَيْنَمَا نَحْنُ نُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم إِذْ سَمِعَ جَلَبَةَ رِجَالٍ فَلَمَّا صَلَّى قَالَ ‏"‏ مَا شَأْنُكُمْ ‏"‏‏.‏ قَالُوا اسْتَعْجَلْنَا إِلَى الصَّلاَةِ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلُوا، إِذَا أَتَيْتُمُ الصَّلاَةَ فَعَلَيْكُمْ بِالسَّكِينَةِ، فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَأَتِمُّوا ‏"‏‏.‏\hadithno{635}\hadithtrans{Narrated `Abdullah bin Abi Qatada:My father said, "While we were praying with the Prophet (ﷺ) he heard the noise of some people. After the prayer he said, 'What is the matter?' They replied 'We were hurrying for the prayer.' He said, 'Do not make haste for the prayer, and whenever you come for the prayer, you should come with calmness, and pray whatever you get (with the people) and complete the rest which you have missed}}
\hadithdefcmd{bukhari}{636}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَعَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمُ الإِقَامَةَ فَامْشُوا إِلَى الصَّلاَةِ، وَعَلَيْكُمْ بِالسَّكِينَةِ وَالْوَقَارِ وَلاَ تُسْرِعُوا، فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَأَتِمُّوا ‏"‏‏.‏\hadithno{636}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When you hear the Iqama, proceed to offer the prayer with calmness and solemnity and do not make haste. And pray whatever you are able to pray and complete whatever you have missed}}
\hadithdefcmd{bukhari}{637}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ كَتَبَ إِلَىَّ يَحْيَى عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَقُومُوا حَتَّى تَرَوْنِي ‏"‏‏.‏\hadithno{637}\hadithtrans{Narrated `Abdullah bin Abi Qatada:My father said. "Allah's Messenger (ﷺ) said, 'If the Iqama is pronounced then do not stand for the prayer till you see me (in front of you)}}
\hadithdefcmd{bukhari}{638}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَقُومُوا حَتَّى تَرَوْنِي وَعَلَيْكُمْ بِالسَّكِينَةِ ‏"‏‏.‏ تَابَعَهُ عَلِيُّ بْنُ الْمُبَارَكِ‏.‏\hadithno{638}\hadithtrans{Narrated `Abdullah bin Abi Qatada: My father said, "Allah's Messenger (ﷺ) said, 'If the Iqama is pronounced, then do not stand for the prayer till you see me (in front of you) and do it calmly}}
\hadithdefcmd{bukhari}{639}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ وَقَدْ أُقِيمَتِ الصَّلاَةُ وَعُدِّلَتِ الصُّفُوفُ، حَتَّى إِذَا قَامَ فِي مُصَلاَّهُ انْتَظَرْنَا أَنْ يُكَبِّرَ انْصَرَفَ قَالَ ‏ "‏ عَلَى مَكَانِكُمْ ‏"‏‏.‏ فَمَكَثْنَا عَلَى هَيْئَتِنَا حَتَّى خَرَجَ إِلَيْنَا يَنْطُفُ رَأْسُهُ مَاءً وَقَدِ اغْتَسَلَ‏.‏\hadithno{639}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) went out (of the mosque) when the Iqama had been pronounced and the rows straightened. The Prophet (ﷺ) stood at his Musalla (praying place) and we waited for the Prophet (ﷺ) to begin the prayer with Takbir. He left and asked us to remain in our places. We kept on standing till the Prophet returned and the water was trickling from his head for he had taken a bath (of Janaba)}}
\hadithdefcmd{bukhari}{640}{حَدَّثَنَا إِسْحَاقُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُقِيمَتِ الصَّلاَةُ فَسَوَّى النَّاسُ صُفُوفَهُمْ، فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَقَدَّمَ وَهْوَ جُنُبٌ ثُمَّ قَالَ ‏ "‏ عَلَى مَكَانِكُمْ ‏"‏‏.‏ فَرَجَعَ فَاغْتَسَلَ ثُمَّ خَرَجَ وَرَأْسُهُ يَقْطُرُ مَاءً فَصَلَّى بِهِمْ‏.‏\hadithno{640}\hadithtrans{Narrated Abu Huraira:Once Iqama was pronounced and the people had straightened the rows, Allah's Messenger (ﷺ) went forward (to lead the prayer) but he was Junub, so he said, "Remain in your places." And he went out, took a bath and returned with water trickling from his head. Then he led the prayer}}
\hadithdefcmd{bukhari}{641}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، يَقُولُ أَخْبَرَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَاءَهُ عُمَرُ بْنُ الْخَطَّابِ يَوْمَ الْخَنْدَقِ فَقَالَ يَا رَسُولَ اللَّهِ، وَاللَّهِ مَا كِدْتُ أَنْ أُصَلِّيَ حَتَّى كَادَتِ الشَّمْسُ تَغْرُبُ، وَذَلِكَ بَعْدَ مَا أَفْطَرَ الصَّائِمُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ مَا صَلَّيْتُهَا ‏"‏ فَنَزَلَ النَّبِيُّ صلى الله عليه وسلم إِلَى بُطْحَانَ وَأَنَا مَعَهُ فَتَوَضَّأَ ثُمَّ صَلَّى ـ يَعْنِي الْعَصْرَ ـ بَعْدَ مَا غَرَبَتِ الشَّمْسُ، ثُمَّ صَلَّى بَعْدَهَا الْمَغْرِبَ‏.‏\hadithno{641}\hadithtrans{Narrated Jabir bin `Abdullah:On the day of Al-Khandaq (the trench), `Umar bin Al-Khattab went to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! By Allah, I could not pray (the `Asr) till the sun had set." `Umar told this to the Prophet at the time when a fasting person had done Iftar (taken his meals). The Prophet (ﷺ) then went to Buthan and I was with him. He performed ablution and offered the `Asr prayer after the sun had set and then the Maghrib prayer}}
\hadithdefcmd{bukhari}{642}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ أُقِيمَتِ الصَّلاَةُ وَالنَّبِيُّ صلى الله عليه وسلم يُنَاجِي رَجُلاً فِي جَانِبِ الْمَسْجِدِ، فَمَا قَامَ إِلَى الصَّلاَةِ حَتَّى نَامَ الْقَوْمُ‏.‏\hadithno{642}\hadithtrans{Narrated Anas:Once the Iqama was pronounced and the Prophet (ﷺ) was talking to a man (in a low voice) in a corner of the mosque and he did not lead the prayer till (some of) the people had slept (dozed in a sitting posture)}}
\hadithdefcmd{bukhari}{643}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا حُمَيْدٌ، قَالَ سَأَلْتُ ثَابِتًا الْبُنَانِيَّ عَنِ الرَّجُلِ، يَتَكَلَّمُ بَعْدَ مَا تُقَامُ الصَّلاَةُ فَحَدَّثَنِي عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أُقِيمَتِ الصَّلاَةُ فَعَرَضَ لِلنَّبِيِّ صلى الله عليه وسلم رَجُلٌ فَحَبَسَهُ بَعْدَ مَا أُقِيمَتِ الصَّلاَةُ‏.‏\hadithno{643}\hadithtrans{Narrated Anas bin Malik:Once Iqama was pronounced a man came to the Prophet (ﷺ) and detained him (from the prayer)}}
\hadithdefcmd{bukhari}{644}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ هَمَمْتُ أَنْ آمُرَ بِحَطَبٍ فَيُحْطَبَ، ثُمَّ آمُرَ بِالصَّلاَةِ فَيُؤَذَّنَ لَهَا، ثُمَّ آمُرَ رَجُلاً فَيَؤُمَّ النَّاسَ، ثُمَّ أُخَالِفَ إِلَى رِجَالٍ فَأُحَرِّقَ عَلَيْهِمْ بُيُوتَهُمْ، وَالَّذِي نَفْسِي بِيَدِهِ لَوْ يَعْلَمُ أَحَدُهُمْ أَنَّهُ يَجِدُ عَرْقًا سَمِينًا أَوْ مِرْمَاتَيْنِ حَسَنَتَيْنِ لَشَهِدَ الْعِشَاءَ ‏"‏‏.‏\hadithno{644}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "By Him in Whose Hand my soul is I was about to order for collecting firewood (fuel) and then order Someone to pronounce the Adhan for the prayer and then order someone to lead the prayer then I would go from behind and burn the houses of men who did not present themselves for the (compulsory congregational) prayer. By Him, in Whose Hands my soul is, if anyone of them had known that he would get a bone covered with good meat or two (small) pieces of meat present in between two ribs, he would have turned up for the `Isha' prayer}}
\hadithdefcmd{bukhari}{645}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الْجَمَاعَةِ تَفْضُلُ صَلاَةَ الْفَذِّ بِسَبْعٍ وَعِشْرِينَ دَرَجَةً ‏"‏‏.‏\hadithno{645}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "The prayer in congregation is twenty seven times superior to the prayer offered by a person alone}}
\hadithdefcmd{bukhari}{646}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا اللَّيْثُ، حَدَّثَنِي ابْنُ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ صَلاَةُ الْجَمَاعَةِ تَفْضُلُ صَلاَةَ الْفَذِّ بِخَمْسٍ وَعِشْرِينَ دَرَجَةً ‏"‏‏.‏\hadithno{646}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "The prayer in congregation is twenty five times superior to the prayer offered by a person alone}}
\hadithdefcmd{bukhari}{647}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ الرَّجُلِ فِي الْجَمَاعَةِ تُضَعَّفُ عَلَى صَلاَتِهِ فِي بَيْتِهِ وَفِي سُوقِهِ خَمْسًا وَعِشْرِينَ ضِعْفًا، وَذَلِكَ أَنَّهُ إِذَا تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ، ثُمَّ خَرَجَ إِلَى الْمَسْجِدِ لاَ يُخْرِجُهُ إِلاَّ الصَّلاَةُ، لَمْ يَخْطُ خَطْوَةً إِلاَّ رُفِعَتْ لَهُ بِهَا دَرَجَةٌ، وَحُطَّ عَنْهُ بِهَا خَطِيئَةٌ، فَإِذَا صَلَّى لَمْ تَزَلِ الْمَلاَئِكَةُ تُصَلِّي عَلَيْهِ مَا دَامَ فِي مُصَلاَّهُ اللَّهُمَّ صَلِّ عَلَيْهِ، اللَّهُمَّ ارْحَمْهُ‏.‏ وَلاَ يَزَالُ أَحَدُكُمْ فِي صَلاَةٍ مَا انْتَظَرَ الصَّلاَةَ ‏"‏‏.‏\hadithno{647}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The reward of the prayer offered by a person in congregation is twenty five times greater than that of the prayer offered in one's house or in the market (alone). And this is because if he performs ablution and does it perfectly and then proceeds to the mosque with the sole intention of praying, then for every step he takes towards the mosque, he is upgraded one degree in reward and his one sin is taken off (crossed out) from his accounts (of deeds). When he offers his prayer, the angels keep on asking Allah's Blessings and Allah's forgiveness for him as long as he is (staying) at his Musalla. They say, 'O Allah! Bestow Your blessings upon him, be Merciful and kind to him.' And one is regarded in prayer as long as one is waiting for the prayer}}
\hadithdefcmd{bukhari}{648}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ تَفْضُلُ صَلاَةُ الْجَمِيعِ صَلاَةَ أَحَدِكُمْ وَحْدَهُ بِخَمْسٍ وَعِشْرِينَ جُزْءًا، وَتَجْتَمِعُ مَلاَئِكَةُ اللَّيْلِ وَمَلاَئِكَةُ النَّهَارِ فِي صَلاَةِ الْفَجْرِ ‏"‏‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ فَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏إِنَّ قُرْآنَ الْفَجْرِ كَانَ مَشْهُودًا‏\}‏\hadithno{648}\hadithtrans{Narrated Abu Salama bin `Abdur Rahman:Abu Huraira said, "I heard Allah's Messenger (ﷺ) saying, 'The reward of a prayer in congregation is twenty five times greater than that of a prayer offered by a person alone. The angels of the night and the angels of the day gather at the time of Fajr prayer.' " Abu Huraira then added, "Recite the Holy Book if you wish, for "Indeed, the recitation of the Qur'an in the early dawn (Fajr prayer) is ever witnessed." (17:)}}
\hadithdefcmd{bukhari}{649}{قَالَ شُعَيْبٌ وَحَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ تَفْضُلُهَا بِسَبْعٍ وَعِشْرِينَ دَرَجَةً‏.‏\hadithno{649}\hadithtrans{Narrated `Abdullah bin `Umar:The reward of the congregational prayer is twenty seven times greater (than that of the prayer offered by a person alone)}}
\hadithdefcmd{bukhari}{650}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ سَالِمًا، قَالَ سَمِعْتُ أُمَّ الدَّرْدَاءِ، تَقُولُ دَخَلَ عَلَىَّ أَبُو الدَّرْدَاءِ وَهْوَ مُغْضَبٌ فَقُلْتُ مَا أَغْضَبَكَ فَقَالَ وَاللَّهِ مَا أَعْرِفُ مِنْ أُمَّةِ مُحَمَّدٍ صلى الله عليه وسلم شَيْئًا إِلاَّ أَنَّهُمْ يُصَلُّونَ جَمِيعًا‏.‏\hadithno{650}\hadithtrans{Narrated Salim:I heard Um Ad-Darda' saying, "Abu Ad-Darda' entered the house in an angry mood. I said to him. 'What makes you angry?' He replied, 'By Allah! I do not find the followers of Muhammad doing those good things (which they used to do before) except the offering of congregational prayer." (This happened in the last days of Abu Ad-Darda' during the rule of `Uthman)}}
\hadithdefcmd{bukhari}{651}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَعْظَمُ النَّاسِ أَجْرًا فِي الصَّلاَةِ أَبْعَدُهُمْ فَأَبْعَدُهُمْ مَمْشًى، وَالَّذِي يَنْتَظِرُ الصَّلاَةَ حَتَّى يُصَلِّيَهَا مَعَ الإِمَامِ أَعْظَمُ أَجْرًا مِنَ الَّذِي يُصَلِّي ثُمَّ يَنَامُ ‏"‏‏.‏\hadithno{651}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "The people who get tremendous reward for the prayer are those who are farthest away (from the mosque) and then those who are next farthest and so on. Similarly one who waits to pray with the Imam has greater reward than one who prays and goes to bed}}
\hadithdefcmd{bukhari}{654}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ وَجَدَ غُصْنَ شَوْكٍ عَلَى الطَّرِيقِ فَأَخَّرَهُ، فَشَكَرَ اللَّهُ لَهُ، فَغَفَرَ لَهُ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ الشُّهَدَاءُ خَمْسَةٌ الْمَطْعُونُ، وَالْمَبْطُونُ، وَالْغَرِيقُ، وَصَاحِبُ الْهَدْمِ، وَالشَّهِيدُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ وَقَالَ ‏"‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا لاَسْتَهَمُوا عَلَيْهِ ‏"‏‏.‏ ‏"‏ وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ، وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏‏.‏\hadithno{654}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "While a man was going on a way, he saw a thorny branch and removed it from the way and Allah became pleased by his action and forgave him for that." Then the Prophet (ﷺ) said, "Five are martyrs: One who dies of plague, one who dies of an Abdominal disease, one who dies of drowning, one who is buried alive (and) dies and one who is killed in Allah's cause." (The Prophet (ﷺ) further said, "If the people knew the reward for pronouncing the Adhan and for standing in the first row (in the congregational prayer) and found no other way to get it except by drawing lots they would do so, and if they knew the reward of offering the Zuhr prayer early (in its stated time), they would race for it and if they knew the reward for `Isha' and Fajr prayers in congregation, they would attend them even if they were to crawl}}
\hadithdefcmd{bukhari}{656}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا بَنِي سَلِمَةَ أَلاَ تَحْتَسِبُونَ آثَارَكُمْ ‏"‏‏.‏ وَقَالَ مُجَاهِدٌ فِي قَوْلِهِ ‏\{‏وَنَكْتُبُ مَا قَدَّمُوا وَآثَارَهُمْ‏\}‏ قَالَ خُطَاهُمْ‏.‏ وَقَالَ ابْنُ أَبِي مَرْيَمَ أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنِي حُمَيْدٌ، حَدَّثَنِي أَنَسٌ، أَنَّ بَنِي سَلِمَةَ، أَرَادُوا أَنْ يَتَحَوَّلُوا، عَنْ مَنَازِلِهِمْ، فَيَنْزِلُوا قَرِيبًا مِنَ النَّبِيِّ صلى الله عليه وسلم قَالَ فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُعْرُوا ‏\{‏الْمَدِينَةَ‏\}‏ فَقَالَ ‏"‏ أَلاَ تَحْتَسِبُونَ آثَارَكُمْ ‏"‏‏.‏ قَالَ مُجَاهِدٌ خُطَاهُمْ آثَارُهُمْ أَنْ يُمْشَى فِي الأَرْضِ بِأَرْجُلِهِمْ‏.‏\hadithno{656}\hadithtrans{Narrated Humaid:Anas said, "The Prophet (ﷺ) said, 'O Bani Salima! Don't you think that for every step of yours (that you take towards the mosque) there is a reward (while coming for prayer)?" Mujahid said: "Regarding Allah's Statement: "We record that which they have sent before (them), and their traces" (36.12). 'Their traces' means 'their steps.' " And Anas said that the people of Bani Salima wanted to shift to a place near the Prophet (ﷺ) but Allah's Messenger (ﷺ) disliked the idea of leaving their houses uninhabited and said, "Don't you think that you will get the reward for your footprints." Mujahid said, "Their foot prints mean their foot steps and their going on foot}}
\hadithdefcmd{bukhari}{657}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي أَبُو صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَ صَلاَةٌ أَثْقَلَ عَلَى الْمُنَافِقِينَ مِنَ الْفَجْرِ وَالْعِشَاءِ، وَلَوْ يَعْلَمُونَ مَا فِيهِمَا لأَتَوْهُمَا وَلَوْ حَبْوًا، لَقَدْ هَمَمْتُ أَنْ آمُرَ الْمُؤَذِّنَ فَيُقِيمَ، ثُمَّ آمُرَ رَجُلاً يَؤُمُّ النَّاسَ، ثُمَّ آخُذَ شُعَلاً مِنْ نَارٍ فَأُحَرِّقَ عَلَى مَنْ لاَ يَخْرُجُ إِلَى الصَّلاَةِ بَعْدُ ‏"‏‏.‏\hadithno{657}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "No prayer is heavier upon the hypocrites than the Fajr and the `Isha' prayers and if they knew what is in them (in reward), they would have attended them, even if (it was) crawling. Certainly, I felt the urge to order the Mu'adh-dhin (call-maker) so that he would pronounce Iqama, then order a man to lead the people (in prayer), then take a flame of fire so that I burn (the houses) upon those who had not left for the prayer yet}}
\hadithdefcmd{bukhari}{658}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا حَضَرَتِ الصَّلاَةُ فَأَذِّنَا وَأَقِيمَا، ثُمَّ لِيَؤُمَّكُمَا أَكْبَرُكُمَا ‏"‏‏.‏\hadithno{658}\hadithtrans{Narrated Malik bin Huwairith:Prophet said (to two persons), "Whenever the prayer time becomes due, you should pronounce Adhan and then Iqama and the older of you should lead the prayer}}
\hadithdefcmd{bukhari}{659}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَلاَئِكَةُ تُصَلِّي عَلَى أَحَدِكُمْ مَا دَامَ فِي مُصَلاَّهُ مَا لَمْ يُحْدِثْ اللَّهُمَّ اغْفِرْ لَهُ، اللَّهُمَّ ارْحَمْهُ‏.‏ لاَ يَزَالُ أَحَدُكُمْ فِي صَلاَةٍ مَا دَامَتِ الصَّلاَةُ تَحْبِسُهُ، لاَ يَمْنَعُهُ أَنْ يَنْقَلِبَ إِلَى أَهْلِهِ إِلاَّ الصَّلاَةُ ‏"‏‏.‏\hadithno{659}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The angels keep on asking for Allah's Blessing and Forgiveness for anyone of you as long as he is at his Musalla (praying place) and does not do Hadath (passes wind). The angels say, 'O Allah! Forgive him and be Merciful to him.' Each one of you is in the prayer as long as he is waiting for the prayer and nothing but the prayer detains him from going to his family}}
\hadithdefcmd{bukhari}{660}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ سَبْعَةٌ يُظِلُّهُمُ اللَّهُ فِي ظِلِّهِ يَوْمَ لاَ ظِلَّ إِلاَّ ظِلُّهُ الإِمَامُ الْعَادِلُ، وَشَابٌّ نَشَأَ فِي عِبَادَةِ رَبِّهِ، وَرَجُلٌ قَلْبُهُ مُعَلَّقٌ فِي الْمَسَاجِدِ، وَرَجُلاَنِ تَحَابَّا فِي اللَّهِ اجْتَمَعَا عَلَيْهِ وَتَفَرَّقَا عَلَيْهِ، وَرَجُلٌ طَلَبَتْهُ امْرَأَةٌ ذَاتُ مَنْصِبٍ وَجَمَالٍ فَقَالَ إِنِّي أَخَافُ اللَّهَ‏.‏ وَرَجُلٌ تَصَدَّقَ أَخْفَى حَتَّى لاَ تَعْلَمَ شِمَالُهُ مَا تُنْفِقُ يَمِينُهُ، وَرَجُلٌ ذَكَرَ اللَّهَ خَالِيًا فَفَاضَتْ عَيْنَاهُ ‏"‏‏.‏\hadithno{660}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah will give shade, to seven, on the Day when there will be no shade but His. (These seven persons are) a just ruler, a youth who has been brought up in the worship of Allah (i.e. worships Allah sincerely from childhood), a man whose heart is attached to the mosques (i.e. to pray the compulsory prayers in the mosque in congregation), two persons who love each other only for Allah's sake and they meet and part in Allah's cause only, a man who refuses the call of a charming woman of noble birth for illicit intercourse with her and says: I am afraid of Allah, a man who gives charitable gifts so secretly that his left hand does not know what his right hand has given (i.e. nobody knows how much he has given in charity), and a person who remembers Allah in seclusion and his eyes are then flooded with tears}}
\hadithdefcmd{bukhari}{661}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، قَالَ سُئِلَ أَنَسٌ هَلِ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا فَقَالَ نَعَمْ، أَخَّرَ لَيْلَةً صَلاَةَ الْعِشَاءِ إِلَى شَطْرِ اللَّيْلِ، ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ بَعْدَ مَا صَلَّى فَقَالَ ‏ "‏ صَلَّى النَّاسُ وَرَقَدُوا وَلَمْ تَزَالُوا فِي صَلاَةٍ مُنْذُ انْتَظَرْتُمُوهَا ‏"‏‏.‏ قَالَ فَكَأَنِّي أَنْظُرُ إِلَى وَبِيصِ خَاتَمِهِ‏.‏\hadithno{661}\hadithtrans{Narrated Humaid:Anas was asked, "Did Allah's Messenger (ﷺ) wear a ring?" He said, "Yes. Once he delayed the `Isha' prayer till midnight and after the prayer, he faced us and said, 'The people prayed and have slept and you remained in prayer as long as you waited for it.' " Anas added, "As if I were just now observing the glitter of his ring}}
\hadithdefcmd{bukhari}{662}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَخْبَرَنَا مُحَمَّدُ بْنُ مُطَرِّفٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ غَدَا إِلَى الْمَسْجِدِ وَرَاحَ أَعَدَّ اللَّهُ لَهُ نُزُلَهُ مِنَ الْجَنَّةِ كُلَّمَا غَدَا أَوْ رَاحَ ‏"‏‏.‏\hadithno{662}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah will prepare for him who goes to the mosque (every) morning and in the afternoon (for the congregational prayer) an honorable place in Paradise with good hospitality for (what he has done) every morning and afternoon goings}}
\hadithdefcmd{bukhari}{663}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ ابْنِ بُحَيْنَةَ، قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِرَجُلٍ‏.‏ قَالَ وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي سَعْدُ بْنُ إِبْرَاهِيمَ، قَالَ سَمِعْتُ حَفْصَ بْنَ عَاصِمٍ، قَالَ سَمِعْتُ رَجُلاً، مِنَ الأَزْدِ يُقَالُ لَهُ مَالِكٌ ابْنُ بُحَيْنَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً وَقَدْ أُقِيمَتِ الصَّلاَةُ يُصَلِّي رَكْعَتَيْنِ، فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَثَ بِهِ النَّاسُ، وَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصُّبْحَ أَرْبَعًا، الصُّبْحَ أَرْبَعًا ‏"‏‏.‏ تَابَعَهُ غُنْدَرٌ وَمُعَاذٌ عَنْ شُعْبَةَ فِي مَالِكٍ‏.‏ وَقَالَ ابْنُ إِسْحَاقَ عَنْ سَعْدٍ عَنْ حَفْصٍ عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ‏.‏ وَقَالَ حَمَّادٌ أَخْبَرَنَا سَعْدٌ عَنْ حَفْصٍ عَنْ مَالِكٍ‏.‏\hadithno{663}\hadithtrans{Narrated Malik Ibn Buhaina:Allah's Messenger (ﷺ) passed by a man praying two rak`at after the Iqama (had been pronounced). When Allah's Messenger (ﷺ) completed the prayer, the people gathered around him (the Prophet) or that man and Allah's Messenger (ﷺ) said to him (protesting), Are there four rak`at in Fajr prayer? Are there four rak`at in Fajr prayer?}}
\hadithdefcmd{bukhari}{664}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، قَالَ الأَسْوَدُ قَالَ كُنَّا عِنْدَ عَائِشَةَ ـ رضى الله عنها ـ فَذَكَرْنَا الْمُوَاظَبَةَ عَلَى الصَّلاَةِ وَالتَّعْظِيمَ لَهَا، قَالَتْ لَمَّا مَرِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَرَضَهُ الَّذِي مَاتَ فِيهِ، فَحَضَرَتِ الصَّلاَةُ فَأُذِّنَ، فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏‏.‏ فَقِيلَ لَهُ إِنَّ أَبَا بَكْرٍ رَجُلٌ أَسِيفٌ، إِذَا قَامَ فِي مَقَامِكَ لَمْ يَسْتَطِعْ أَنْ يُصَلِّيَ بِالنَّاسِ، وَأَعَادَ فَأَعَادُوا لَهُ، فَأَعَادَ الثَّالِثَةَ فَقَالَ ‏"‏ إِنَّكُنَّ صَوَاحِبُ يُوسُفَ، مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏‏.‏ فَخَرَجَ أَبُو بَكْرٍ فَصَلَّى، فَوَجَدَ النَّبِيُّ صلى الله عليه وسلم مِنْ نَفْسِهِ خِفَّةً، فَخَرَجَ يُهَادَى بَيْنَ رَجُلَيْنِ كَأَنِّي أَنْظُرُ رِجْلَيْهِ تَخُطَّانِ مِنَ الْوَجَعِ، فَأَرَادَ أَبُو بَكْرٍ أَنْ يَتَأَخَّرَ، فَأَوْمَأَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم أَنْ مَكَانَكَ، ثُمَّ أُتِيَ بِهِ حَتَّى جَلَسَ إِلَى جَنْبِهِ‏.‏ قِيلَ لِلأَعْمَشِ وَكَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي وَأَبُو بَكْرٍ يُصَلِّي بِصَلاَتِهِ، وَالنَّاسُ يُصَلُّونَ بِصَلاَةِ أَبِي بَكْرٍ فَقَالَ بِرَأْسِهِ نَعَمْ‏.‏ رَوَاهُ أَبُو دَاوُدَ عَنْ شُعْبَةَ عَنِ الأَعْمَشِ بَعْضَهُ‏.‏ وَزَادَ أَبُو مُعَاوِيَةَ جَلَسَ عَنْ يَسَارِ أَبِي بَكْرٍ فَكَانَ أَبُو بَكْرٍ يُصَلِّي قَائِمًا‏.‏\hadithno{664}\hadithtrans{Narrated Al-Aswad:"We were with `Aisha discussing the regularity of offering the prayer and dignifying it. She said, 'When Allah's Messenger (ﷺ) fell sick with the fatal illness and when the time of prayer became due and Adhan was pronounced, he said, 'Tell Abu Bakr to lead the people in prayer.' He was told that Abu Bakr was a softhearted man and would not be able to lead the prayer in his place. The Prophet (ﷺ) gave the same order again but he was given the same reply. He gave the order for the third time and said, 'You (women) are the companions of Joseph. Tell Abu Bakr to lead the prayer.' So Abu Bakr came out to lead the prayer. In the meantime the condition of the Prophet (ﷺ) improved a bit and he came out with the help of two men one on each side. As if I was observing his legs dragging on the ground owing to the disease. Abu Bakr wanted to retreat but the Prophet (ﷺ) beckoned him to remain at his place and the Prophet (ﷺ) was brought till he sat beside Abu Bakr." Al-A`mash was asked, "Was the Prophet (ﷺ) praying and Abu Bakr following him, and were the people following Abu Bakr in that prayer?" Al- A`mash replied in the affirmative with a nod of his head. Abu Muawiya said, "The Prophet (ﷺ) was sitting on the left side of Abu Bakr who was praying while standing}}
\hadithdefcmd{bukhari}{665}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، قَالَ قَالَتْ عَائِشَةُ لَمَّا ثَقُلَ النَّبِيُّ صلى الله عليه وسلم وَاشْتَدَّ وَجَعُهُ اسْتَأْذَنَ أَزْوَاجَهُ أَنْ يُمَرَّضَ فِي بَيْتِي فَأَذِنَّ لَهُ، فَخَرَجَ بَيْنَ رَجُلَيْنِ تَخُطُّ رِجْلاَهُ الأَرْضَ، وَكَانَ بَيْنَ الْعَبَّاسِ وَرَجُلٍ آخَرَ‏.‏ قَالَ عُبَيْدُ اللَّهِ فَذَكَرْتُ ذَلِكَ لاِبْنِ عَبَّاسٍ مَا قَالَتْ عَائِشَةُ فَقَالَ لِي وَهَلْ تَدْرِي مَنِ الرَّجُلُ الَّذِي لَمْ تُسَمِّ عَائِشَةُ قُلْتُ لاَ‏.‏ قَالَ هُوَ عَلِيُّ بْنُ أَبِي طَالِبٍ‏.‏\hadithno{665}\hadithtrans{Narrated `Aisha:"When the Prophet (ﷺ) became seriously ill and his disease became aggravated he asked for permission from his wives to be nursed in my house and he was allowed. He came out with the help of two men and his legs were dragging on the ground. He was between Al-`Abbas and another man." 'Ubaidullah said, "I told Ibn `Abbas what `Aisha had narrated and he said, 'Do you know who was the (second) man whose name `Aisha did not mention'" I said, 'No.' Ibn `Abbas said, 'He was `Ali Ibn Abi Talib}}
\hadithdefcmd{bukhari}{666}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، أَذَّنَ بِالصَّلاَةِ فِي لَيْلَةٍ ذَاتِ بَرْدٍ وَرِيحٍ ثُمَّ قَالَ أَلاَ صَلُّوا فِي الرِّحَالِ‏.‏ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ الْمُؤَذِّنَ إِذَا كَانَتْ لَيْلَةٌ ذَاتُ بَرْدٍ وَمَطَرٍ يَقُولُ أَلاَ صَلُّوا فِي الرِّحَالِ‏.‏\hadithno{666}\hadithtrans{Narrated Nafi`:Once on a very cold and stormy night, Ibn `Umar pronounced the Adhan for the prayer and then said, "Pray in your homes." He (Ibn `Umar) added. "On very cold and rainy nights Allah's Messenger (ﷺ) used to order the Mu'adh-dhin to say, 'Pray in your homes}}
\hadithdefcmd{bukhari}{667}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ الأَنْصَارِيِّ، أَنَّ عِتْبَانَ بْنَ مَالِكٍ، كَانَ يَؤُمُّ قَوْمَهُ وَهْوَ أَعْمَى، وَأَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ، إِنَّهَا تَكُونُ الظُّلْمَةُ وَالسَّيْلُ وَأَنَا رَجُلٌ ضَرِيرُ الْبَصَرِ، فَصَلِّ يَا رَسُولَ اللَّهِ فِي بَيْتِي مَكَانًا أَتَّخِذُهُ مُصَلًّى، فَجَاءَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ ‏"‏‏.‏ فَأَشَارَ إِلَى مَكَانٍ مِنَ الْبَيْتِ، فَصَلَّى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{667}\hadithtrans{Narrated Mahmud bin Rabi` Al-Ansari:`Itban bin Malik used to lead his people (tribe) in prayer and was a blind man, he said to Allah's Apostle , "O Allah's Messenger (ﷺ)! At times it is dark and flood water is flowing (in the valley) and I am a blind man, so please pray at a place in my house so that I can take it as a Musalla (praying place)." So Allah's Messenger (ﷺ) went to his house and said, "Where do you like me to pray?" 'Itban pointed to a place in his house and Allah's Messenger (ﷺ), offered the prayer there}}
\hadithdefcmd{bukhari}{668}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ، صَاحِبُ الزِّيَادِيِّ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الْحَارِثِ، قَالَ خَطَبَنَا ابْنُ عَبَّاسٍ فِي يَوْمٍ ذِي رَدْغٍ، فَأَمَرَ الْمُؤَذِّنَ لَمَّا بَلَغَ حَىَّ عَلَى الصَّلاَةِ‏.‏ قَالَ قُلِ الصَّلاَةُ فِي الرِّحَالِ، فَنَظَرَ بَعْضُهُمْ إِلَى بَعْضٍ، فَكَأَنَّهُمْ أَنْكَرُوا فَقَالَ كَأَنَّكُمْ أَنْكَرْتُمْ هَذَا إِنَّ هَذَا فَعَلَهُ مَنْ هُوَ خَيْرٌ مِنِّي ـ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ـ إِنَّهَا عَزْمَةٌ، وَإِنِّي كَرِهْتُ أَنْ أُحْرِجَكُمْ‏.‏ وَعَنْ حَمَّادٍ عَنْ عَاصِمٍ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ عَنِ ابْنِ عَبَّاسٍ نَحْوَهُ، غَيْرَ أَنَّهُ قَالَ كَرِهْتُ أَنْ أُؤَثِّمَكُمْ، فَتَجِيئُونَ تَدُوسُونَ الطِّينَ إِلَى رُكَبِكُمْ‏.‏\hadithno{668}\hadithtrans{Narrated `Abdullah bin Al-Harith:Ibn `Abbas addressed us on a (rainy and) muddy day and when the Mu'adh-dhin said, "Come for the prayer" Ibn `Abbas ordered him to say, "Pray in your homes." The people began to look at one another with surprise as if they did not like it. Ibn `Abbas said, "It seems that you thought ill of it but no doubt it was done by one who was better than I (i.e. the Prophet). It (the prayer) is a strict order and I disliked to bring you out." Ibn `Abbas narrated the same as above but he said, "I did not like you to make you sinful (in refraining from coming to the mosque) and to come (to the mosque) covered with mud up to the knees}}
\hadithdefcmd{bukhari}{669}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ فَقَالَ جَاءَتْ سَحَابَةٌ فَمَطَرَتْ حَتَّى سَالَ السَّقْفُ، وَكَانَ مِنْ جَرِيدِ النَّخْلِ، فَأُقِيمَتِ الصَّلاَةُ، فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْجُدُ فِي الْمَاءِ وَالطِّينِ، حَتَّى رَأَيْتُ أَثَرَ الطِّينِ فِي جَبْهَتِهِ‏.‏\hadithno{669}\hadithtrans{Narrated Abu Sa`id Al-Khudri:A cloud came and it rained till the roof started leaking and in those days the roof used to be of the branches of date-palms. Iqama was pronounced and I saw Allah's Messenger (ﷺ) prostrating in water and mud and even I saw the mark of mud on his forehead}}
\hadithdefcmd{bukhari}{670}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا أَنَسُ بْنُ سِيرِينَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ رَجُلٌ مِنَ الأَنْصَارِ إِنِّي لاَ أَسْتَطِيعُ الصَّلاَةَ مَعَكَ‏.‏ وَكَانَ رَجُلاً ضَخْمًا، فَصَنَعَ لِلنَّبِيِّ صلى الله عليه وسلم طَعَامًا فَدَعَاهُ إِلَى مَنْزِلِهِ، فَبَسَطَ لَهُ حَصِيرًا وَنَضَحَ طَرَفَ الْحَصِيرِ، صَلَّى عَلَيْهِ رَكْعَتَيْنِ‏.‏ فَقَالَ رَجُلٌ مِنْ آلِ الْجَارُودِ لأَنَسٍ أَكَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الضُّحَى قَالَ مَا رَأَيْتُهُ صَلاَّهَا إِلاَّ يَوْمَئِذٍ‏.‏\hadithno{670}\hadithtrans{Narrated Anas bin Seereen:I heard Anas saying, "A man from Ansar said to the Prophet, 'I cannot pray with you (in congregation).' He was a very fat man and he prepared a meal for the Prophet (ﷺ) and invited him to his house. He spread out a mat for the Prophet, and washed one of its sides with water, and the Prophet (ﷺ) prayed two rak`at on it." A man from the family of Al-Jaruid [??] asked, "Did the Prophet (ﷺ) used to pray the Duha (forenoon) prayer?" Anas said, "I did not see him praying the Duha prayer except on that day}}
\hadithdefcmd{bukhari}{671}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، سَمِعْتُ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا وُضِعَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ ‏"‏‏.‏\hadithno{671}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "If supper is served, and Iqama is pronounced one should start with the supper}}
\hadithdefcmd{bukhari}{672}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قُدِّمَ الْعَشَاءُ فَابْدَءُوا بِهِ قَبْلَ أَنْ تُصَلُّوا صَلاَةَ الْمَغْرِبِ، وَلاَ تَعْجَلُوا عَنْ عَشَائِكُمْ ‏"‏‏.‏\hadithno{672}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "If the supper is served start having it before praying the Maghrib prayer and do not be hasty in finishing it}}
\hadithdefcmd{bukhari}{673}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وُضِعَ عَشَاءُ أَحَدِكُمْ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ، وَلاَ يَعْجَلْ حَتَّى يَفْرُغَ مِنْهُ ‏"‏‏.‏ وَكَانَ ابْنُ عُمَرَ يُوضَعُ لَهُ الطَّعَامُ وَتُقَامُ الصَّلاَةُ فَلاَ يَأْتِيهَا حَتَّى يَفْرُغَ، وَإِنَّهُ لَيَسْمَعُ قِرَاءَةَ الإِمَامِ‏.‏\hadithno{673}\hadithtrans{Narrated Nafi`:Ibn `Umar said, "Allah's Messenger (ﷺ) said, 'If the supper is served for anyone of you and the Iqama is pronounced, start with the supper and don't be in haste (and carry on eating) till you finish it." If food was served for Ibn `Umar and Iqama was pronounced, he never came to the prayer till he finished it (i.e. food) in spite of the fact that he heard the recitation (of the Qur'an) by the Imam (in the prayer)}}
\hadithdefcmd{bukhari}{674}{وَقَالَ زُهَيْرٌ وَوَهْبُ بْنُ عُثْمَانَ عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ أَحَدُكُمْ عَلَى الطَّعَامِ فَلاَ يَعْجَلْ حَتَّى يَقْضِيَ حَاجَتَهُ مِنْهُ، وَإِنْ أُقِيمَتِ الصَّلاَةُ ‏"‏‏.‏ رَوَاهُ إِبْرَاهِيمُ بْنُ الْمُنْذِرِ عَنْ وَهْبِ بْنِ عُثْمَانَ، وَوَهْبٌ مَدِينِيٌّ‏.‏\hadithno{674}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "If anyone of you is having his meals, he should not hurry up till he is satisfied even if the prayer has been started}}
\hadithdefcmd{bukhari}{675}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي جَعْفَرُ بْنُ عَمْرِو بْنِ أُمَيَّةَ، أَنَّ أَبَاهُ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُ ذِرَاعًا يَحْتَزُّ مِنْهَا، فَدُعِيَ إِلَى الصَّلاَةِ فَقَامَ فَطَرَحَ السِّكِّينَ، فَصَلَّى وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{675}\hadithtrans{Narrated Ja`far bin `Amr bin Umaiya:My father said, "I saw Allah's Messenger (ﷺ) eating a piece of meat from the shoulder of a sheep and he was called for the prayer. He stood up, put down the knife and prayed but did not perform ablution}}
\hadithdefcmd{bukhari}{676}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا الْحَكَمُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالَ سَأَلْتُ عَائِشَةَ مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَصْنَعُ فِي بَيْتِهِ قَالَتْ كَانَ يَكُونُ فِي مِهْنَةِ أَهْلِهِ ـ تَعْنِي خِدْمَةَ أَهْلِهِ ـ فَإِذَا حَضَرَتِ الصَّلاَةُ خَرَجَ إِلَى الصَّلاَةِ‏.‏\hadithno{676}\hadithtrans{Narrated Al-Aswad:That he asked `Aisha "What did the Prophet (ﷺ) use to do in his house?" She replied, "He used to keep himself busy serving his family and when it was the time for prayer he would go for it}}
\hadithdefcmd{bukhari}{677}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، قَالَ جَاءَنَا مَالِكُ بْنُ الْحُوَيْرِثِ فِي مَسْجِدِنَا هَذَا فَقَالَ إِنِّي لأُصَلِّي بِكُمْ، وَمَا أُرِيدُ الصَّلاَةَ، أُصَلِّي كَيْفَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُصَلِّي‏.‏ فَقُلْتُ لأَبِي قِلاَبَةَ كَيْفَ كَانَ يُصَلِّي قَالَ مِثْلَ شَيْخِنَا هَذَا‏.‏ قَالَ وَكَانَ شَيْخًا يَجْلِسُ إِذَا رَفَعَ رَأْسَهُ مِنَ السُّجُودِ قَبْلَ أَنْ يَنْهَضَ فِي الرَّكْعَةِ الأُولَى‏.‏\hadithno{677}\hadithtrans{Narrated Aiyub:Abu Qilaba said, "Malik bin Huwairith came to this Mosque of ours and said, 'I pray in front of you and my aim is not to lead the prayer but to show you the way in which the Prophet (ﷺ) used to pray.' " I asked Abu Qilaba, "How did he use to pray?' " He replied, "(The Prophet (ﷺ) used to pray) like this Sheikh of ours and the Sheikh used to sit for a while after the prostration, before getting up after the first rak`a}}
\hadithdefcmd{bukhari}{678}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، قَالَ حَدَّثَنِي أَبُو بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ مَرِضَ النَّبِيُّ صلى الله عليه وسلم فَاشْتَدَّ مَرَضُهُ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ إِنَّهُ رَجُلٌ رَقِيقٌ، إِذَا قَامَ مَقَامَكَ لَمْ يَسْتَطِعْ أَنْ يُصَلِّيَ بِالنَّاسِ‏.‏ قَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ فَعَادَتْ فَقَالَ ‏"‏ مُرِي أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ، فَإِنَّكُنَّ صَوَاحِبُ يُوسُفَ ‏"‏‏.‏ فَأَتَاهُ الرَّسُولُ فَصَلَّى بِالنَّاسِ فِي حَيَاةِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{678}\hadithtrans{Narrated Abu Musa:"The Prophet (ﷺ) became sick and when his disease became aggravated, he said, "Tell Abu Bakr to lead the prayer." `Aisha said, "He is a softhearted man and would not be able to lead the prayer in your place." The Prophet (ﷺ) said again, "Tell Abu Bakr to lead the people in prayer." She repeated the same reply but he said, "Tell Abu Bakr to lead the people in prayer. You are the companions of Joseph." So the messenger went to Abu Bakr (with that order) and he led the people in prayer in the lifetime of the Prophet}}
\hadithdefcmd{bukhari}{679}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي مَرَضِهِ ‏"‏ مُرُوا أَبَا بَكْرٍ يُصَلِّي بِالنَّاسِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ قُلْتُ إِنَّ أَبَا بَكْرٍ إِذَا قَامَ فِي مَقَامِكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ، فَمُرْ عُمَرَ فَلْيُصَلِّ لِلنَّاسِ‏.‏ فَقَالَتْ عَائِشَةُ فَقُلْتُ لِحَفْصَةَ قُولِي لَهُ إِنَّ أَبَا بَكْرٍ إِذَا قَامَ فِي مَقَامِكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ، فَمُرْ عُمَرَ فَلْيُصَلِّ لِلنَّاسِ‏.‏ فَفَعَلَتْ حَفْصَةُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَهْ، إِنَّكُنَّ لأَنْتُنَّ صَوَاحِبُ يُوسُفَ، مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ لِلنَّاسِ ‏"‏‏.‏ فَقَالَتْ حَفْصَةُ لِعَائِشَةَ مَا كُنْتُ لأُصِيبَ مِنْكِ خَيْرًا‏.‏\hadithno{679}\hadithtrans{Narrated `Aisha:the mother of the believers: Allah's Messenger (ﷺ) in his illness said, "Tell Abu Bakr to lead the people in prayer." I said to him, "If Abu Bakr stands in your place, the people would not hear him owing to his (excessive) weeping. So please order `Umar to lead the prayer." `Aisha added I said to Hafsa, "Say to him: If Abu Bakr should lead the people in the prayer in your place, the people would not be able to hear him owing to his weeping; so please, order `Umar to lead the prayer." Hafsa did so but Allah's Apostle said, "Keep quiet! You are verily the Companions of Joseph. Tell Abu Bakr to lead the people in the prayer. " Hafsa said to `Aisha, "I never got anything good from you}}
\hadithdefcmd{bukhari}{680}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ الأَنْصَارِيُّ ـ وَكَانَ تَبِعَ النَّبِيَّ صلى الله عليه وسلم وَخَدَمَهُ وَصَحِبَهُ أَنَّ أَبَا بَكْرٍ كَانَ يُصَلِّي لَهُمْ فِي وَجَعِ النَّبِيِّ صلى الله عليه وسلم الَّذِي تُوُفِّيَ فِيهِ، حَتَّى إِذَا كَانَ يَوْمُ الاِثْنَيْنِ وَهُمْ صُفُوفٌ فِي الصَّلاَةِ، فَكَشَفَ النَّبِيُّ صلى الله عليه وسلم سِتْرَ الْحُجْرَةِ يَنْظُرُ إِلَيْنَا، وَهْوَ قَائِمٌ كَأَنَّ وَجْهَهُ وَرَقَةُ مُصْحَفٍ، ثُمَّ تَبَسَّمَ يَضْحَكُ، فَهَمَمْنَا أَنْ نَفْتَتِنَ مِنَ الْفَرَحِ بِرُؤْيَةِ النَّبِيِّ صلى الله عليه وسلم، فَنَكَصَ أَبُو بَكْرٍ عَلَى عَقِبَيْهِ لِيَصِلَ الصَّفَّ، وَظَنَّ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَارِجٌ إِلَى الصَّلاَةِ، فَأَشَارَ إِلَيْنَا النَّبِيُّ صلى الله عليه وسلم أَنْ أَتِمُّوا صَلاَتَكُمْ، وَأَرْخَى السِّتْرَ، فَتُوُفِّيَ مِنْ يَوْمِهِ‏.‏\hadithno{680}\hadithtrans{Narrated Az-Zuhri:Anas bin Malik Al-Ansari, told me, "Abu Bakr used to lead the people in prayer during the fatal illness of the Prophet (ﷺ) till it was Monday. When the people aligned (in rows) for the prayer the Prophet (ﷺ) lifted the curtain of his house and started looking at us and was standing at that time. His face was (glittering) like a page of the Qur'an and he smiled cheerfully. We were about to be put to trial for the pleasure of seeing the Prophet, Abu Bakr retreated to join the row as he thought that the Prophet (ﷺ) would lead the prayer. The Prophet (ﷺ) beckoned us to complete the prayer and he let the curtain fall. On the same day he died}}
\hadithdefcmd{bukhari}{681}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ لَمْ يَخْرُجِ النَّبِيُّ صلى الله عليه وسلم ثَلاَثًا، فَأُقِيمَتِ الصَّلاَةُ، فَذَهَبَ أَبُو بَكْرٍ يَتَقَدَّمُ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم بِالْحِجَابِ فَرَفَعَهُ، فَلَمَّا وَضَحَ وَجْهُ النَّبِيِّ صلى الله عليه وسلم مَا نَظَرْنَا مَنْظَرًا كَانَ أَعْجَبَ إِلَيْنَا مِنْ وَجْهِ النَّبِيِّ صلى الله عليه وسلم حِينَ وَضَحَ لَنَا، فَأَوْمَأَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ إِلَى أَبِي بَكْرٍ أَنْ يَتَقَدَّمَ، وَأَرْخَى النَّبِيُّ صلى الله عليه وسلم الْحِجَابَ، فَلَمْ يُقْدَرْ عَلَيْهِ حَتَّى مَاتَ‏.‏\hadithno{681}\hadithtrans{Narrated Anas:The Prophet (ﷺ) did not come out for three days. The people stood for the prayer and Abu Bakr went ahead to lead the prayer. (In the meantime) the Prophet (ﷺ) caught hold of the curtain and lifted it. When the face of the Prophet (ﷺ) appeared we had never seen a scene more pleasing than the face of the Prophet (ﷺ) as it appeared then. The Prophet (ﷺ) beckoned to Abu Bakr to lead the people in the prayer and then let the curtain fall. We did not see him (again) till he died}}
\hadithdefcmd{bukhari}{682}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ، أَنَّهُ أَخْبَرَهُ عَنْ أَبِيهِ، قَالَ لَمَّا اشْتَدَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَجَعُهُ قِيلَ لَهُ فِي الصَّلاَةِ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ إِنَّ أَبَا بَكْرٍ رَجُلٌ رَقِيقٌ، إِذَا قَرَأَ غَلَبَهُ الْبُكَاءُ‏.‏ قَالَ ‏"‏ مُرُوهُ فَيُصَلِّي ‏"‏ فَعَاوَدَتْهُ‏.‏ قَالَ ‏"‏ مُرُوهُ فَيُصَلِّي، إِنَّكُنَّ صَوَاحِبُ يُوسُفَ ‏"‏‏.‏ تَابَعَهُ الزُّبَيْدِيُّ وَابْنُ أَخِي الزُّهْرِيِّ وَإِسْحَاقُ بْنُ يَحْيَى الْكَلْبِيُّ عَنِ الزُّهْرِيِّ‏.‏ وَقَالَ عُقَيْلٌ وَمَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ حَمْزَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{682}\hadithtrans{Narrated Hamza bin `Abdullah:My father said, "When Allah's Messenger (ﷺ) became seriously ill, he was told about the prayer. He said, 'Tell Abu Bakr to lead the people in the prayer.' `Aisha said, 'Abu Bakr is a softhearted man and he would be overpowered by his weeping if he recited the Qur'an.' He said to them, 'Tell him (Abu Bakr) to lead the prayer. The same reply was given to him. He said again, 'Tell him to lead the prayer. You (women) are the companions of Joseph}}
\hadithdefcmd{bukhari}{683}{حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا ابْنُ نُمَيْرٍ، قَالَ أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا بَكْرٍ أَنْ يُصَلِّيَ بِالنَّاسِ فِي مَرَضِهِ، فَكَانَ يُصَلِّي بِهِمْ‏.‏ قَالَ عُرْوَةُ فَوَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي نَفْسِهِ خِفَّةً، فَخَرَجَ فَإِذَا أَبُو بَكْرٍ يَؤُمُّ النَّاسَ، فَلَمَّا رَآهُ أَبُو بَكْرٍ اسْتَأْخَرَ، فَأَشَارَ إِلَيْهِ أَنْ كَمَا أَنْتَ، فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِذَاءَ أَبِي بَكْرٍ إِلَى جَنْبِهِ، فَكَانَ أَبُو بَكْرٍ يُصَلِّي بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ يُصَلُّونَ بِصَلاَةِ أَبِي بَكْرٍ‏.‏\hadithno{683}\hadithtrans{Narrated Hisham ibn `Urwa's father:`Aisha said, "Allah's Messenger (ﷺ) ordered Abu Bakr to lead the people in the prayer during his illness and so he led them in prayer." `Urwa, a sub narrator, added, "Allah's Messenger (ﷺ) felt a bit relieved and came out and Abu Bakr was leading the people. When Abu Bakr saw the Prophet (ﷺ) he retreated but the Prophet beckoned him to remain there. Allah's Messenger (ﷺ) sat beside Abu Bakr. Abu Bakr was following the prayer of Allah's Messenger (ﷺ) and the people were following the prayer of Abu Bakr}}
\hadithdefcmd{bukhari}{684}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَهَبَ إِلَى بَنِي عَمْرِو بْنِ عَوْفٍ لِيُصْلِحَ بَيْنَهُمْ فَحَانَتِ الصَّلاَةُ فَجَاءَ الْمُؤَذِّنُ إِلَى أَبِي بَكْرٍ فَقَالَ أَتُصَلِّي لِلنَّاسِ فَأُقِيمَ قَالَ نَعَمْ‏.‏ فَصَلَّى أَبُو بَكْرٍ، فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ فِي الصَّلاَةِ، فَتَخَلَّصَ حَتَّى وَقَفَ فِي الصَّفِّ، فَصَفَّقَ النَّاسُ ـ وَكَانَ أَبُو بَكْرٍ لاَ يَلْتَفِتُ فِي صَلاَتِهِ ـ فَلَمَّا أَكْثَرَ النَّاسُ التَّصْفِيقَ الْتَفَتَ فَرَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم، فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنِ امْكُثْ مَكَانَكَ، فَرَفَعَ أَبُو بَكْرٍ ـ رضى الله عنه ـ يَدَيْهِ، فَحَمِدَ اللَّهَ عَلَى مَا أَمَرَهُ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ ذَلِكَ، ثُمَّ اسْتَأْخَرَ أَبُو بَكْرٍ حَتَّى اسْتَوَى فِي الصَّفِّ، وَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى، فَلَمَّا انْصَرَفَ قَالَ ‏"‏ يَا أَبَا بَكْرٍ مَا مَنَعَكَ أَنْ تَثْبُتَ إِذْ أَمَرْتُكَ ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ مَا كَانَ لاِبْنِ أَبِي قُحَافَةَ أَنْ يُصَلِّيَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لِي رَأَيْتُكُمْ أَكْثَرْتُمُ التَّصْفِيقَ مَنْ رَابَهُ شَىْءٌ فِي صَلاَتِهِ فَلْيُسَبِّحْ، فَإِنَّهُ إِذَا سَبَّحَ الْتُفِتَ إِلَيْهِ، وَإِنَّمَا التَّصْفِيقُ لِلنِّسَاءِ ‏"‏‏.‏\hadithno{684}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:Allah's Messenger (ﷺ) went to establish peace among Bani `Amr bin `Auf. In the meantime the time of prayer was due and the Mu'adh-dhin went to Abu Bakr and said, "Will you lead the prayer, so that I may pronounce the Iqama?" Abu Bakr replied in the affirmative and led the prayer. Allah's Messenger (ﷺ) came while the people were still praying and he entered the rows of the praying people till he stood in the (first row). The people clapped their hands. Abu Bakr never glanced sideways in his prayer but when the people continued clapping, Abu Bakr looked and saw Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) beckoned him to stay at his place. Abu Bakr raised his hands and thanked Allah for that order of Allah's Messenger (ﷺ) and then he retreated till he reached the first row. Allah's Messenger (ﷺ) went forward and led the prayer. When Allah's Messenger (ﷺ) finished the prayer, he said, "O Abu Bakr! What prevented you from staying when I ordered you to do so?" Abu Bakr replied, "How can Ibn Abi Quhafa (Abu Bakr) dare to lead the prayer in the presence of Allah's Messenger (ﷺ)?" Then Allah's Messenger (ﷺ) said, "Why did you clap so much? If something happens to anyone during his prayer he should say Subhan Allah. If he says so he will be attended to, for clapping is for women}}
\hadithdefcmd{bukhari}{685}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ قَدِمْنَا عَلَى النَّبِيِّ صلى الله عليه وسلم وَنَحْنُ شَبَبَةٌ، فَلَبِثْنَا عِنْدَهُ نَحْوًا مِنْ عِشْرِينَ لَيْلَةً، وَكَانَ النَّبِيُّ صلى الله عليه وسلم رَحِيمًا فَقَالَ ‏ "‏ لَوْ رَجَعْتُمْ إِلَى بِلاَدِكُمْ فَعَلَّمْتُمُوهُمْ، مُرُوهُمْ فَلْيُصَلُّوا صَلاَةَ كَذَا فِي حِينِ كَذَا، وَصَلاَةَ كَذَا فِي حِينِ كَذَا، وَإِذَا حَضَرَتِ الصَّلاَةُ فَلْيُؤَذِّنْ لَكُمْ أَحَدُكُمْ، وَلْيَؤُمَّكُمْ أَكْبَرُكُمْ ‏"‏‏.‏\hadithno{685}\hadithtrans{Narrated Malik bin Huwairith:We went to the Prophet (ﷺ) and we were all young men and stayed with him for about twenty nights. The Prophet (ﷺ) was very merciful. He said, "When you return home, impart religious teachings to your families and tell them to offer perfectly such and such a prayer at such and such a time and such and such a prayer at such and such a time. And at the time of the prayer one of you should pronounce the Adhan and the oldest of you should lead the prayer}}
\hadithdefcmd{bukhari}{686}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ، قَالَ سَمِعْتُ عِتْبَانَ بْنَ مَالِكٍ الأَنْصَارِيَّ، قَالَ اسْتَأْذَنَ النَّبِيُّ صلى الله عليه وسلم فَأَذِنْتُ لَهُ فَقَالَ ‏ "‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ مِنْ بَيْتِكَ ‏"‏‏.‏ فَأَشَرْتُ لَهُ إِلَى الْمَكَانِ الَّذِي أُحِبُّ، فَقَامَ وَصَفَفْنَا خَلْفَهُ ثُمَّ سَلَّمَ وَسَلَّمْنَا‏.‏\hadithno{686}\hadithtrans{Narrated `Itban bin Malik Al-Ansari:The Prophet (came to my house and) asked permission for entering and I allowed him. He asked, "Where do you like me to pray in your house?" I pointed to a place which I liked. He stood up for prayer and we aligned behind him and he finished the prayer with Taslim and we did the same}}
\hadithdefcmd{bukhari}{687}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَقُلْتُ أَلاَ تُحَدِّثِينِي عَنْ مَرَضِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ بَلَى، ثَقُلَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏‏.‏ قُلْنَا لاَ، هُمْ يَنْتَظِرُونَكَ‏.‏ قَالَ ‏"‏ ضَعُوا لِي مَاءً فِي الْمِخْضَبِ ‏"‏‏.‏ قَالَتْ فَفَعَلْنَا فَاغْتَسَلَ فَذَهَبَ لِيَنُوءَ فَأُغْمِيَ عَلَيْهِ، ثُمَّ أَفَاقَ فَقَالَ صلى الله عليه وسلم ‏"‏ أَصَلَّى النَّاسُ ‏"‏‏.‏ قُلْنَا لاَ، هُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ ضَعُوا لِي مَاءً فِي الْمِخْضَبِ ‏"‏‏.‏ قَالَتْ فَقَعَدَ فَاغْتَسَلَ، ثُمَّ ذَهَبَ لِيَنُوءَ فَأُغْمِيَ عَلَيْهِ، ثُمَّ أَفَاقَ فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏‏.‏ قُلْنَا لاَ، هُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ ضَعُوا لِي مَاءً فِي الْمِخْضَبِ ‏"‏، فَقَعَدَ فَاغْتَسَلَ، ثُمَّ ذَهَبَ لِيَنُوءَ فَأُغْمِيَ عَلَيْهِ، ثُمَّ أَفَاقَ فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏‏.‏ فَقُلْنَا لاَ، هُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ ـ وَالنَّاسُ عُكُوفٌ فِي الْمَسْجِدِ يَنْتَظِرُونَ النَّبِيَّ عَلَيْهِ السَّلاَمُ لِصَلاَةِ الْعِشَاءِ الآخِرَةِ ـ فَأَرْسَلَ النَّبِيُّ صلى الله عليه وسلم إِلَى أَبِي بَكْرٍ بِأَنْ يُصَلِّيَ بِالنَّاسِ، فَأَتَاهُ الرَّسُولُ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ أَنْ تُصَلِّيَ بِالنَّاسِ‏.‏ فَقَالَ أَبُو بَكْرٍ ـ وَكَانَ رَجُلاً رَقِيقًا ـ يَا عُمَرُ صَلِّ بِالنَّاسِ‏.‏ فَقَالَ لَهُ عُمَرُ أَنْتَ أَحَقُّ بِذَلِكَ‏.‏ فَصَلَّى أَبُو بَكْرٍ تِلْكَ الأَيَّامَ، ثُمَّ إِنَّ النَّبِيَّ صلى الله عليه وسلم وَجَدَ مِنْ نَفْسِهِ خِفَّةً فَخَرَجَ بَيْنَ رَجُلَيْنِ أَحَدُهُمَا الْعَبَّاسُ لِصَلاَةِ الظُّهْرِ، وَأَبُو بَكْرٍ يُصَلِّي بِالنَّاسِ، فَلَمَّا رَآهُ أَبُو بَكْرٍ ذَهَبَ لِيَتَأَخَّرَ فَأَوْمَأَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم بِأَنْ لاَ يَتَأَخَّرَ‏.‏ قَالَ ‏"‏ أَجْلِسَانِي إِلَى جَنْبِهِ ‏"‏‏.‏ فَأَجْلَسَاهُ إِلَى جَنْبِ أَبِي بَكْرٍ‏.‏ قَالَ فَجَعَلَ أَبُو بَكْرٍ يُصَلِّي وَهْوَ يَأْتَمُّ بِصَلاَةِ النَّبِيِّ صلى الله عليه وسلم وَالنَّاسُ بِصَلاَةِ أَبِي بَكْرٍ، وَالنَّبِيُّ صلى الله عليه وسلم قَاعِدٌ‏.‏ قَالَ عُبَيْدُ اللَّهِ فَدَخَلْتُ عَلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَقُلْتُ لَهُ أَلاَ أَعْرِضُ عَلَيْكَ مَا حَدَّثَتْنِي عَائِشَةُ عَنْ مَرَضِ النَّبِيِّ صلى الله عليه وسلم قَالَ هَاتِ‏.‏ فَعَرَضْتُ عَلَيْهِ حَدِيثَهَا، فَمَا أَنْكَرَ مِنْهُ شَيْئًا، غَيْرَ أَنَّهُ قَالَ أَسَمَّتْ لَكَ الرَّجُلَ الَّذِي كَانَ مَعَ الْعَبَّاسِ قُلْتُ لاَ‏.‏ قَالَ هُوَ عَلِيٌّ‏.‏\hadithno{687}\hadithtrans{Narrated 'Ubaidullah Ibn `Abdullah bin `Utba:I went to `Aisha and asked her to describe to me the illness of Allah's Messenger (ﷺ). `Aisha said, "Yes. The Prophet became seriously ill and asked whether the people had prayed. We replied, 'No. O Allah's Apostle! They are waiting for you.' He added, 'Put water for me in a trough." `Aisha added, "We did so. He took a bath and tried to get up but fainted. When he recovered, he again asked whether the people had prayed. We said, 'No, they are waiting for you. O Allah's Messenger (ﷺ),' He again said, 'Put water in a trough for me.' He sat down and took a bath and tried to get up but fainted again. Then he recovered and said, 'Have the people prayed?' We replied, 'No, they are waiting for you. O Allah's Apostle.' He said, 'Put water for me in the trough.' Then he sat down and washed himself and tried to get up but he fainted. When he recovered, he asked, 'Have the people prayed?' We said, 'No, they are waiting for you. O Allah's Messenger (ﷺ)! The people were in the mosque waiting for the Prophet (ﷺ) for the `Isha prayer. The Prophet (ﷺ) sent for Abu Bakr to lead the people in the prayer. The messenger went to Abu Bakr and said, 'Allah's Messenger (ﷺ) orders you to lead the people in the prayer.' Abu Bakr was a softhearted man, so he asked `Umar to lead the prayer but `Umar replied, 'You are more rightful.' So Abu Bakr led the prayer in those days. When the Prophet (ﷺ) felt a bit better, he came out for the Zuhr prayer with the help of two persons one of whom was Al-`Abbas. while Abu Bakr was leading the people in the prayer. When Abu Bakr saw him he wanted to retreat but the Prophet (ﷺ) beckoned him not to do so and asked them to make him sit beside Abu Bakr and they did so. Abu Bakr was following the Prophet (in the prayer) and the people were following Abu Bakr. The Prophet (prayed) sitting." 'Ubaidullah added "I went to `Abdullah bin `Abbas and asked him, Shall I tell you what Aisha has told me about the fatal illness of the Prophet?' Ibn `Abbas said, 'Go ahead. I told him her narration and he did not deny anything of it but asked whether `Aisha told me the name of the second person (who helped the Prophet (ﷺ) ) along with Al-Abbas. I said. 'No.' He said, 'He was `Ali (Ibn Abi Talib)}}
\hadithdefcmd{bukhari}{688}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِهِ وَهْوَ شَاكٍ، فَصَلَّى جَالِسًا وَصَلَّى وَرَاءَهُ قَوْمٌ قِيَامًا، فَأَشَارَ إِلَيْهِمْ أَنِ اجْلِسُوا، فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ، فَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا رَفَعَ فَارْفَعُوا، وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا ‏"‏‏.‏\hadithno{688}\hadithtrans{Narrated Aisha:the mother of the believers: Allah's Messenger (ﷺ) during his illness prayed at his house while sitting whereas some people prayed behind him standing. The Prophet (ﷺ) beckoned them to sit down. On completion of the prayer, he said, 'The Imam is to be followed: bow when he bows, raise up your heads (stand erect) when he raises his head and when he says, 'Sami`a l-lahu liman hamidah' (Allah heard those who sent praises to Him) say then 'Rabbana wa laka l-hamd' (O our Lord! All the praises are for You), and if he prays sitting then pray sitting}}
\hadithdefcmd{bukhari}{689}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ فَرَسًا فَصُرِعَ عَنْهُ، فَجُحِشَ شِقُّهُ الأَيْمَنُ، فَصَلَّى صَلاَةً مِنَ الصَّلَوَاتِ وَهْوَ قَاعِدٌ، فَصَلَّيْنَا وَرَاءَهُ قُعُودًا، فَلَمَّا انْصَرَفَ قَالَ ‏"‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ، فَإِذَا صَلَّى قَائِمًا فَصَلُّوا قِيَامًا، فَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا رَفَعَ فَارْفَعُوا، وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ‏.‏ وَإِذَا صَلَّى قَائِمًا فَصَلُّوا قِيَامًا، وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا أَجْمَعُونَ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ الْحُمَيْدِيُّ قَوْلُهُ ‏"‏ إِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا ‏"‏‏.‏ هُوَ فِي مَرَضِهِ الْقَدِيمِ، ثُمَّ صَلَّى بَعْدَ ذَلِكَ النَّبِيُّ صلى الله عليه وسلم جَالِسًا وَالنَّاسُ خَلْفَهُ قِيَامًا، لَمْ يَأْمُرْهُمْ بِالْقُعُودِ، وَإِنَّمَا يُؤْخَذُ بِالآخِرِ فَالآخِرِ مِنْ فِعْلِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{689}\hadithtrans{Narrated Anas bin Malik:Once Allah's Messenger (ﷺ) rode a horse and fell down and the right side (of his body) was injured. He offered one of the prayers while sitting and we also prayed behind him sitting. When he completed the prayer, he said, "The Imam is to be followed. Pray standing if he prays standing and bow when he bows; rise when he rises; and if he says, 'Sami`a l-lahu-liman hamidah, say then, 'Rabbana wa laka lhamd' and pray standing if he prays standing and pray sitting (all of you) if he prays sitting." Humaid said: The saying of the Prophet (ﷺ) "Pray sitting, if he (Imam) prays sitting" was said in his former illness (during his early life) but the Prophet (ﷺ) prayed sitting afterwards (in the last illness) and the people were praying standing behind him and the Prophet (ﷺ) did not order them to sit. We should follow the latest actions of the Prophet}}
\hadithdefcmd{bukhari}{690}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ يَزِيدَ، قَالَ حَدَّثَنِي الْبَرَاءُ ـ وَهْوَ غَيْرُ كَذُوبٍ ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ لَمْ يَحْنِ أَحَدٌ مِنَّا ظَهْرَهُ حَتَّى يَقَعَ النَّبِيُّ صلى الله عليه وسلم سَاجِدًا، ثُمَّ نَقَعُ سُجُودًا بَعْدَهُ‏.‏\hadithno{690}\hadithtrans{Narrated Al-Bara:(and he was not a liar) When Allah's Messenger (ﷺ) said, "Sami`a l-lahu liman hamidah" none of us bent his back (for prostration) till the Prophet (ﷺ) prostrated and then we would prostrate after him}}
\hadithdefcmd{bukhari}{690p2}{حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، نَحْوَهُ بِهَذَا‏.‏\hadithno{690.2}\hadithtrans{Narrated Abu 'Is-haq:As above}}
\hadithdefcmd{bukhari}{691}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَمَا يَخْشَى أَحَدُكُمْ ـ أَوْ لاَ يَخْشَى أَحَدُكُمْ ـ إِذَا رَفَعَ رَأْسَهُ قَبْلَ الإِمَامِ أَنْ يَجْعَلَ اللَّهُ رَأْسَهُ رَأْسَ حِمَارٍ أَوْ يَجْعَلَ اللَّهُ صُورَتَهُ صُورَةَ حِمَارٍ ‏"‏‏.‏\hadithno{691}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Isn't he who raises his head before the Imam afraid that Allah may transform his head into that of a donkey or his figure (face) into that of a donkey?}}
\hadithdefcmd{bukhari}{692}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَمَّا قَدِمَ الْمُهَاجِرُونَ الأَوَّلُونَ الْعُصْبَةَ ـ مَوْضِعٌ بِقُبَاءٍ ـ قَبْلَ مَقْدَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ يَؤُمُّهُمْ سَالِمٌ مَوْلَى أَبِي حُذَيْفَةَ، وَكَانَ أَكْثَرَهُمْ قُرْآنًا‏.‏\hadithno{692}\hadithtrans{Narrated Ibn `Umar:When the earliest emigrants came to Al-`Usba [??] a place in Quba', before the arrival of the Prophet- Salim, the slave of Abu Hudhaifa, who knew the Qur'an more than the others used to lead them in prayer}}
\hadithdefcmd{bukhari}{693}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي أَبُو التَّيَّاحِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اسْمَعُوا وَأَطِيعُوا، وَإِنِ اسْتُعْمِلَ حَبَشِيٌّ كَأَنَّ رَأْسَهُ زَبِيبَةٌ ‏"‏‏.‏\hadithno{693}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Listen and obey (your chief) even if an Ethiopian whose head is like a raisin were made your chief}}
\hadithdefcmd{bukhari}{694}{حَدَّثَنَا الْفَضْلُ بْنُ سَهْلٍ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى الأَشْيَبُ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُصَلُّونَ لَكُمْ، فَإِنْ أَصَابُوا فَلَكُمْ، وَإِنْ أَخْطَئُوا فَلَكُمْ وَعَلَيْهِمْ ‏"‏‏.‏\hadithno{694}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If the Imam leads the prayer correctly then he and you will receive the rewards but if he makes a mistake (in the prayer) then you will receive the reward for the prayer and the sin will be his}}
\hadithdefcmd{bukhari}{695}{قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ لَنَا مُحَمَّدُ بْنُ يُوسُفَ حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَدِيِّ بْنِ خِيَارٍ، أَنَّهُ دَخَلَ عَلَى عُثْمَانَ بْنِ عَفَّانَ ـ رضى الله عنه ـ وَهْوَ مَحْصُورٌ فَقَالَ إِنَّكَ إِمَامُ عَامَّةٍ، وَنَزَلَ بِكَ مَا تَرَى وَيُصَلِّي لَنَا إِمَامُ فِتْنَةٍ وَنَتَحَرَّجُ‏.‏ فَقَالَ الصَّلاَةُ أَحْسَنُ مَا يَعْمَلُ النَّاسُ، فَإِذَا أَحْسَنَ النَّاسُ فَأَحْسِنْ مَعَهُمْ، وَإِذَا أَسَاءُوا فَاجْتَنِبْ إِسَاءَتَهُمْ‏.‏ وَقَالَ الزُّبَيْدِيُّ قَالَ الزُّهْرِيُّ لاَ نَرَى أَنْ يُصَلَّى خَلْفَ الْمُخَنَّثِ إِلاَّ مِنْ ضَرُورَةٍ لاَ بُدَّ مِنْهَا‏.‏\hadithno{695}\hadithtrans{Narrated 'Ubaid-Ullah bin Adi bin Khiyar:I went to 'Uthman bin Affan while he was besieged, and said to him, "You are the chief of all Muslims in general and you see what has befallen you. We are led in the Salat (prayer) by a leader of Al-Fitan (trials and afflictions etc.) and we are afraid of being sinful in following him." 'Uthman said. "As-Salat (the prayers) is the best of all deeds so when the people do good deeds do the same with them and when they do bad deeds, avoid those bad deeds." Az-Zuhri said, "In our opinion one should not offer Salat behind an effeminate person unless there is no alternative}}
\hadithdefcmd{bukhari}{696}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبَانَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، قَالَ النَّبِيُّ صلى الله عليه وسلم لأَبِي ذَرٍّ ‏ "‏ اسْمَعْ وَأَطِعْ، وَلَوْ لِحَبَشِيٍّ كَأَنَّ رَأْسَهُ زَبِيبَةٌ ‏"‏‏.‏\hadithno{696}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said to Abu-Dhar, "Listen and obey (your chief) even if he is an Ethiopian with a head like a raisin}}
\hadithdefcmd{bukhari}{697}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بِتُّ فِي بَيْتِ خَالَتِي مَيْمُونَةَ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْعِشَاءَ، ثُمَّ جَاءَ فَصَلَّى أَرْبَعَ رَكَعَاتٍ ثُمَّ نَامَ، ثُمَّ قَامَ فَجِئْتُ فَقُمْتُ عَنْ يَسَارِهِ، فَجَعَلَنِي عَنْ يَمِينِهِ، فَصَلَّى خَمْسَ رَكَعَاتٍ، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ نَامَ حَتَّى سَمِعْتُ غَطِيطَهُ ـ أَوْ قَالَ خَطِيطَهُ ـ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ‏.‏\hadithno{697}\hadithtrans{Narrated Ibn `Abbas:Once I passed the night in the house of my aunt Maimuna. Allah's Messenger (ﷺ) offered the `Isha' prayer and then came to the house and offered four rak`at and slept. Later on, he woke up and stood for the prayer and I stood on his left side. He drew me to his right and prayed five rak`at and then two. He then slept till I heard him snoring (or heard his breath sounds). Afterwards he went out for the morning prayer}}
\hadithdefcmd{bukhari}{698}{حَدَّثَنَا أَحْمَدُ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنَا عَمْرٌو، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ نِمْتُ عِنْدَ مَيْمُونَةَ وَالنَّبِيُّ صلى الله عليه وسلم عِنْدَهَا تِلْكَ اللَّيْلَةَ، فَتَوَضَّأَ ثُمَّ قَامَ يُصَلِّي، فَقُمْتُ عَلَى يَسَارِهِ، فَأَخَذَنِي فَجَعَلَنِي عَنْ يَمِينِهِ، فَصَلَّى ثَلاَثَ عَشْرَةَ رَكْعَةً، ثُمَّ نَامَ حَتَّى نَفَخَ ـ وَكَانَ إِذَا نَامَ نَفَخَ ـ ثُمَّ أَتَاهُ الْمُؤَذِّنُ، فَخَرَجَ فَصَلَّى وَلَمْ يَتَوَضَّأْ‏.‏ قَالَ عَمْرٌو فَحَدَّثْتُ بِهِ بُكَيْرًا فَقَالَ حَدَّثَنِي كُرَيْبٌ بِذَلِكَ‏.‏\hadithno{698}\hadithtrans{Narrated Ibn `Abbas:One night I slept at the house of (my aunt) Maimuna and the Prophet (ﷺ) was there on that night. He performed ablution and stood up for the prayer. I joined him and stood on his left side but he drew me to his right and prayed thirteen rak`at and then slept till I heard his breath sounds. And whenever he slept, he used to breathe with audible sounds. The Mu'adh-dhin came to the Prophet (ﷺ) and he went out and prayed the morning prayer) without repeating the ablution}}
\hadithdefcmd{bukhari}{699}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ عِنْدَ خَالَتِي فَقَامَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ، فَقُمْتُ أُصَلِّي مَعَهُ فَقُمْتُ عَنْ يَسَارِهِ، فَأَخَذَ بِرَأْسِي فَأَقَامَنِي عَنْ يَمِينِهِ‏.‏\hadithno{699}\hadithtrans{Narrated Ibn `Abbas:Once I passed the night in the house of my aunt Maimuna. The Prophet (ﷺ) stood for the night prayer and I joined him and stood on his left side but he drew me to his right by holding me by the head}}
\hadithdefcmd{bukhari}{700}{حَدَّثَنَا مُسْلِمٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، كَانَ يُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ يَرْجِعُ فَيَؤُمُّ قَوْمَهُ‏.‏\hadithno{700}\hadithtrans{Narrated Mu`adh bin Jabal:I used to pray the `Isha prayer with the Prophet (ﷺ) and then go to lead my people in the prayer}}
\hadithdefcmd{bukhari}{701}{وَحَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ كَانَ مُعَاذُ بْنُ جَبَلٍ يُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ يَرْجِعُ فَيَؤُمُّ قَوْمَهُ، فَصَلَّى الْعِشَاءَ فَقَرَأَ بِالْبَقَرَةِ، فَانْصَرَفَ الرَّجُلُ، فَكَأَنَّ مُعَاذًا تَنَاوَلَ مِنْهُ، فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ فَتَّانٌ فَتَّانٌ فَتَّانٌ ‏"‏ ثَلاَثَ مِرَارٍ أَوْ قَالَ ‏"‏ فَاتِنًا فَاتِنًا فَاتِنٌ ‏"‏ وَأَمَرَهُ بِسُورَتَيْنِ مِنْ أَوْسَطِ الْمُفَصَّلِ‏.‏ قَالَ عَمْرٌو لاَ أَحْفَظُهُمَا‏.‏\hadithno{701}\hadithtrans{Narrated `Amr:Jabir bin `Abdullah said, "Mu`adh bin Jabal used to pray with the Prophet (ﷺ) and then go to lead his people in prayer Once he led the `Isha' prayer and recited Surat "Al-Baqara." Somebody left the prayer and Mu`adh criticized him. The news reached the Prophet (ﷺ) and he said to Mu`adh, 'You are putting the people to trial,' and repeated it thrice (or said something similar) and ordered him to recite two medium Suras of Mufassal." (`Amr said that he had forgotten the names of those Suras)}}
\hadithdefcmd{bukhari}{702}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ سَمِعْتُ قَيْسًا، قَالَ أَخْبَرَنِي أَبُو مَسْعُودٍ، أَنَّ رَجُلاً، قَالَ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنِّي لأَتَأَخَّرُ عَنْ صَلاَةِ الْغَدَاةِ مِنْ أَجْلِ فُلاَنٍ مِمَّا يُطِيلُ بِنَا‏.‏ فَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي مَوْعِظَةٍ أَشَدَّ غَضَبًا مِنْهُ يَوْمَئِذٍ ثُمَّ قَالَ ‏ "‏ إِنَّ مِنْكُمْ مُنَفِّرِينَ، فَأَيُّكُمْ مَا صَلَّى بِالنَّاسِ فَلْيَتَجَوَّزْ، فَإِنَّ فِيهِمُ الضَّعِيفَ وَالْكَبِيرَ وَذَا الْحَاجَةِ ‏"‏‏.‏\hadithno{702}\hadithtrans{Narrated Abu Mas`ud:A man came and said, "O Allah's Messenger (ﷺ)! By Allah, I keep away from the morning prayer only because So and so prolongs the prayer when he leads us in it." The narrator said, "I never saw Allah's Apostle more furious in giving advice than he was at that time. He then said, "Some of you make people dislike good deeds (the prayer). So whoever among you leads the people in prayer should shorten it because among them are the weak, the old and the needy}}
\hadithdefcmd{bukhari}{703}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ لِلنَّاسِ فَلْيُخَفِّفْ، فَإِنَّ مِنْهُمُ الضَّعِيفَ وَالسَّقِيمَ وَالْكَبِيرَ، وَإِذَا صَلَّى أَحَدُكُمْ لِنَفْسِهِ فَلْيُطَوِّلْ مَا شَاءَ ‏"‏‏.‏\hadithno{703}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If anyone of you leads the people in the prayer, he should shorten it for amongst them are the weak, the sick and the old; and if anyone among you prays alone then he may prolong (the prayer) as much as he wishes}}
\hadithdefcmd{bukhari}{704}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنِّي لأَتَأَخَّرُ عَنِ الصَّلاَةِ فِي الْفَجْرِ مِمَّا يُطِيلُ بِنَا فُلاَنٌ فِيهَا‏.‏ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا رَأَيْتُهُ غَضِبَ فِي مَوْضِعٍ كَانَ أَشَدَّ غَضَبًا مِنْهُ يَوْمَئِذٍ ثُمَّ قَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّ مِنْكُمْ مُنَفِّرِينَ، فَمَنْ أَمَّ النَّاسَ فَلْيَتَجَوَّزْ، فَإِنَّ خَلْفَهُ الضَّعِيفَ وَالْكَبِيرَ وَذَا الْحَاجَةِ ‏"‏‏.‏\hadithno{704}\hadithtrans{Narrated Abu Mas`ud:A man came and said, "O Allah's Messenger (ﷺ)! I keep away from the morning prayer because so-and-so (Imam) prolongs it too much." Allah's Messenger (ﷺ) became furious and I had never seen him more furious than he was on that day. The Prophet (ﷺ) said, "O people! Some of you make others dislike the prayer, so whoever becomes an Imam he should shorten the prayer, as behind him are the weak, the old and the needy}}
\hadithdefcmd{bukhari}{705}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا مُحَارِبُ بْنُ دِثَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ الأَنْصَارِيَّ، قَالَ أَقْبَلَ رَجُلٌ بِنَاضِحَيْنِ وَقَدْ جَنَحَ اللَّيْلُ، فَوَافَقَ مُعَاذًا يُصَلِّي، فَتَرَكَ نَاضِحَهُ وَأَقْبَلَ إِلَى مُعَاذٍ، فَقَرَأَ بِسُورَةِ الْبَقَرَةِ أَوِ النِّسَاءِ، فَانْطَلَقَ الرَّجُلُ، وَبَلَغَهُ أَنَّ مُعَاذًا نَالَ مِنْهُ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَشَكَا إِلَيْهِ مُعَاذًا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا مُعَاذُ أَفَتَّانٌ أَنْتَ ـ أَوْ فَاتِنٌ ثَلاَثَ مِرَارٍ ـ فَلَوْلاَ صَلَّيْتَ بِسَبِّحِ اسْمَ رَبِّكَ، وَالشَّمْسِ وَضُحَاهَا، وَاللَّيْلِ إِذَا يَغْشَى، فَإِنَّهُ يُصَلِّي وَرَاءَكَ الْكَبِيرُ وَالضَّعِيفُ وَذُو الْحَاجَةِ ‏"‏‏.‏ أَحْسِبُ هَذَا فِي الْحَدِيثِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَتَابَعَهُ سَعِيدُ بْنُ مَسْرُوقٍ وَمِسْعَرٌ وَالشَّيْبَانِيُّ‏.‏ قَالَ عَمْرٌو وَعُبَيْدُ اللَّهِ بْنُ مِقْسَمٍ وَأَبُو الزُّبَيْرِ عَنْ جَابِرٍ قَرَأَ مُعَاذٌ فِي الْعِشَاءِ بِالْبَقَرَةِ‏.‏ وَتَابَعَهُ الأَعْمَشُ عَنْ مُحَارِبٍ‏.‏\hadithno{705}\hadithtrans{Narrated Jabir bin `Abdullah Al-Ansari:Once a man was driving two Nadihas (camels used for agricultural purposes) and night had fallen. He found Mu`adh praying so he made his camel kneel and joined Mu`adh in the prayer. The latter recited Surat 'Al-Baqara" or Surat "An-Nisa", (so) the man left the prayer and went away. When he came to know that Mu`adh had criticized him, he went to the Prophet, and complained against Mu`adh. The Prophet said thrice, "O Mu`adh ! Are you putting the people to trial?" It would have been better if you had recited "Sabbih Isma Rabbika-l-A`la (87)", Wash-shamsi wa duhaha (91)", or "Wal-laili idha yaghsha (92)", for the old, the weak and the needy pray behind you." Jabir said that Mu`adh recited Sura Al-Baqara in the `Isha' prayer}}
\hadithdefcmd{bukhari}{706}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُوجِزُ الصَّلاَةَ وَيُكْمِلُهَا‏.‏\hadithno{706}\hadithtrans{Narrated Anas:The Prophet (ﷺ) used to pray a short prayer (in congregation) but used to offer it in a perfect manner}}
\hadithdefcmd{bukhari}{707}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ أَبِي قَتَادَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي لأَقُومُ فِي الصَّلاَةِ أُرِيدُ أَنْ أُطَوِّلَ فِيهَا، فَأَسْمَعُ بُكَاءَ الصَّبِيِّ، فَأَتَجَوَّزُ فِي صَلاَتِي كَرَاهِيَةَ أَنْ أَشُقَّ عَلَى أُمِّهِ ‏"‏‏.‏ تَابَعَهُ بِشْرُ بْنُ بَكْرٍ وَابْنُ الْمُبَارَكِ وَبَقِيَّةُ عَنِ الأَوْزَاعِيِّ‏.‏\hadithno{707}\hadithtrans{Narrated `Abdullah bin 'Abi Qatada:My father said, "The Prophet (ﷺ) said, 'When I stand for prayer, I intend to prolong it but on hearing the cries of a child, I cut it short, as I dislike to trouble the child's mother}}
\hadithdefcmd{bukhari}{708}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ مَا صَلَّيْتُ وَرَاءَ إِمَامٍ قَطُّ أَخَفَّ صَلاَةً وَلاَ أَتَمَّ مِنَ النَّبِيِّ صلى الله عليه وسلم، وَإِنْ كَانَ لَيَسْمَعُ بُكَاءَ الصَّبِيِّ فَيُخَفِّفُ مَخَافَةَ أَنْ تُفْتَنَ أُمُّهُ‏.‏\hadithno{708}\hadithtrans{Narrated Anas bin Malik:I never prayed behind any Imam a prayer lighter and more perfect than that behind the Prophet (ﷺ) and he used to cut short the prayer whenever he heard the cries of a child lest he should put the child's mother to trial}}
\hadithdefcmd{bukhari}{709}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي لأَدْخُلُ فِي الصَّلاَةِ وَأَنَا أُرِيدُ إِطَالَتَهَا، فَأَسْمَعُ بُكَاءَ الصَّبِيِّ، فَأَتَجَوَّزُ فِي صَلاَتِي مِمَّا أَعْلَمُ مِنْ شِدَّةِ وَجْدِ أُمِّهِ مِنْ بُكَائِهِ ‏"‏‏.‏\hadithno{709}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "When I start the prayer I intend to prolong it, but on hearing the cries of a child, I cut short the prayer because I know that the cries of the child will incite its mother's passions}}
\hadithdefcmd{bukhari}{710}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي لأَدْخُلُ فِي الصَّلاَةِ فَأُرِيدُ إِطَالَتَهَا، فَأَسْمَعُ بُكَاءَ الصَّبِيِّ، فَأَتَجَوَّزُ مِمَّا أَعْلَمُ مِنْ شِدَّةِ وَجْدِ أُمِّهِ مِنْ بُكَائِهِ ‏"‏‏.‏ وَقَالَ مُوسَى حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسٌ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ‏.‏\hadithno{710}\hadithtrans{Narrated Anas bin Malik:The Prophet, said, "Whenever I start the prayer I intend to prolong it, but on hearing the cries of a child, I cut short the prayer because I know that the cries of the child will incite its mother's passions}}
\hadithdefcmd{bukhari}{711}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَأَبُو النُّعْمَانِ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ، قَالَ كَانَ مُعَاذٌ يُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ يَأْتِي قَوْمَهُ فَيُصَلِّي بِهِمْ‏.‏\hadithno{711}\hadithtrans{Narrated Jabir bin `Abdullah:Mu`adh used to pray with the Prophet (ﷺ) and then go and lead his people (tribe) in the prayer}}
\hadithdefcmd{bukhari}{712}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا مَرِضَ النَّبِيُّ صلى الله عليه وسلم مَرَضَهُ الَّذِي مَاتَ فِيهِ أَتَاهُ بِلاَلٌ يُؤْذِنُهُ بِالصَّلاَةِ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ ‏"‏‏.‏ قُلْتُ إِنَّ أَبَا بَكْرٍ رَجُلٌ أَسِيفٌ، إِنْ يَقُمْ مَقَامَكَ يَبْكِي فَلاَ يَقْدِرُ عَلَى الْقِرَاءَةِ‏.‏ قَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ ‏"‏‏.‏ فَقُلْتُ مِثْلَهُ فَقَالَ فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏"‏ إِنَّكُنَّ صَوَاحِبُ يُوسُفَ، مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ ‏"‏‏.‏ فَصَلَّى وَخَرَجَ النَّبِيُّ صلى الله عليه وسلم يُهَادَى بَيْنَ رَجُلَيْنِ، كَأَنِّي أَنْظُرُ إِلَيْهِ يَخُطُّ بِرِجْلَيْهِ الأَرْضَ، فَلَمَّا رَآهُ أَبُو بَكْرٍ ذَهَبَ يَتَأَخَّرُ، فَأَشَارَ إِلَيْهِ أَنْ صَلِّ، فَتَأَخَّرَ أَبُو بَكْرٍ ـ رضى الله عنه ـ وَقَعَدَ النَّبِيُّ صلى الله عليه وسلم إِلَى جَنْبِهِ، وَأَبُو بَكْرٍ يُسْمِعُ النَّاسَ التَّكْبِيرَ‏.‏ تَابَعَهُ مُحَاضِرٌ عَنِ الأَعْمَشِ‏.‏\hadithno{712}\hadithtrans{Narrated `Aisha:When the Prophet, became ill in his fatal illness, Someone came to inform him about the prayer, and the Prophet (ﷺ) told him to tell Abu Bakr to lead the people in the prayer. I said, "Abu Bakr is a softhearted man and if he stands for the prayer in your place, he would weep and would not be able to recite the Qur'an." The Prophet (ﷺ) said, "Tell Abu Bakr to lead the prayer." I said the same as before. He (repeated the same order and) on the third or the fourth time he said, "You are the companions of Joseph. Tell Abu Bakr to lead the prayer." So Abu Bakr led the prayer and meanwhile the Prophet (ﷺ) felt better and came out with the help of two men; as if I see him just now dragging his feet on the ground. When Abu Bakr saw him, he tried to retreat but the Prophet (ﷺ) beckoned him to carry on. Abu Bakr retreated a bit and the Prophet (ﷺ) sat on his (left) side. Abu Bakr was repeating the Takbir (Allahu Akbar) of Allah's Messenger (ﷺ) for the people to hear}}
\hadithdefcmd{bukhari}{713}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا ثَقُلَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَاءَ بِلاَلٌ يُؤْذِنُهُ بِالصَّلاَةِ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ أَنْ يُصَلِّيَ بِالنَّاسِ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ، إِنَّ أَبَا بَكْرٍ رَجُلٌ أَسِيفٌ، وَإِنَّهُ مَتَى مَا يَقُمْ مَقَامَكَ لاَ يُسْمِعُ النَّاسَ، فَلَوْ أَمَرْتَ عُمَرَ‏.‏ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ يُصَلِّي بِالنَّاسِ ‏"‏‏.‏ فَقُلْتُ لِحَفْصَةَ قُولِي لَهُ إِنَّ أَبَا بَكْرٍ رَجُلٌ أَسِيفٌ، وَإِنَّهُ مَتَى يَقُمْ مَقَامَكَ لاَ يُسْمِعِ النَّاسَ، فَلَوْ أَمَرْتَ عُمَرَ‏.‏ قَالَ ‏"‏ إِنَّكُنَّ لأَنْتُنَّ صَوَاحِبُ يُوسُفَ، مُرُوا أَبَا بَكْرٍ أَنْ يُصَلِّيَ بِالنَّاسِ ‏"‏‏.‏ فَلَمَّا دَخَلَ فِي الصَّلاَةِ وَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي نَفْسِهِ خِفَّةً، فَقَامَ يُهَادَى بَيْنَ رَجُلَيْنِ، وَرِجْلاَهُ يَخُطَّانِ فِي الأَرْضِ حَتَّى دَخَلَ الْمَسْجِدَ، فَلَمَّا سَمِعَ أَبُو بَكْرٍ حِسَّهُ ذَهَبَ أَبُو بَكْرٍ يَتَأَخَّرُ، فَأَوْمَأَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم، فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى جَلَسَ عَنْ يَسَارِ أَبِي بَكْرٍ، فَكَانَ أَبُو بَكْرٍ يُصَلِّي قَائِمًا، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي قَاعِدًا، يَقْتَدِي أَبُو بَكْرٍ بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ مُقْتَدُونَ بِصَلاَةِ أَبِي بَكْرٍ رضى الله عنه‏.‏\hadithno{713}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) became seriously ill, Bilal came to him for the prayer. He said, "Tell Abu Bakr to lead the people in the prayer." I said, "O Allah's Messenger (ﷺ)! Abu Bakr is a softhearted man and if he stands in your place, he would not be able to make the people hear him. Will you order `Umar (to lead the prayer)?" The Prophet (ﷺ) said, "Tell Abu Bakr to lead the people in the prayer." Then I said to Hafsa, "Tell him, Abu Bakr is a softhearted man and if he stands in his place, he would not be able to make the people hear him. Would you order `Umar to lead the prayer?' " Hafsa did so. The Prophet (ﷺ) said, "Verily you are the companions of Joseph. Tell Abu Bakr to lead the people in the prayer." So Abu Bakr stood for the prayer. In the meantime Allah's Messenger (ﷺ) felt better and came out with the help of two persons and both of his legs were dragging on the ground till he entered the mosque. When Abu Bakr heard him coming, he tried to retreat but Allah's Messenger (ﷺ) beckoned him to carry on. The Prophet (ﷺ) sat on his left side. Abu Bakr was praying while standing and Allah's Messenger (ﷺ) was leading the prayer while sitting. Abu Bakr was following the Prophet (ﷺ) and the people were following Abu Bakr (in the prayer)}}
\hadithdefcmd{bukhari}{714}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْصَرَفَ مِنَ اثْنَتَيْنِ، فَقَالَ لَهُ ذُو الْيَدَيْنِ أَقَصُرَتِ الصَّلاَةُ أَمْ نَسِيتَ يَا رَسُولَ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏‏.‏ فَقَالَ النَّاسُ نَعَمْ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى اثْنَتَيْنِ أُخْرَيَيْنِ ثُمَّ سَلَّمَ، ثُمَّ كَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ‏.‏\hadithno{714}\hadithtrans{Narrated Abu Huraira:Once Allah's Messenger (ﷺ) prayed two rak`at (instead of four) and finished his prayer. Dhul-Yadain asked him whether the prayer had been reduced or whether he had forgotten. Allah's Messenger (ﷺ) asked the people whether Dhul-Yadain was telling the truth. The people replied in the affirmative. Then Allah's Apostle stood up, offered the remaining two rak`at and then finished his prayer with Taslim and then said, "Allahu Akbar." He followed it with two prostrations like ordinary prostrations or a bit longer}}
\hadithdefcmd{bukhari}{715}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ رَكْعَتَيْنِ، فَقِيلَ صَلَّيْتَ رَكْعَتَيْنِ‏.‏ فَصَلَّى رَكْعَتَيْنِ، ثُمَّ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَيْنِ‏.‏\hadithno{715}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) prayed two rak`at of Zuhr prayer (instead of four) and he was told that he had prayed two rak`at only. Then he prayed two more rak`at and finished them with the Taslim followed by two prostrations}}
\hadithdefcmd{bukhari}{716}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي مَرَضِهِ ‏"‏ مُرُوا أَبَا بَكْرٍ يُصَلِّي بِالنَّاسِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ قُلْتُ إِنَّ أَبَا بَكْرٍ إِذَا قَامَ فِي مَقَامِكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ، فَمُرْ عُمَرَ فَلْيُصَلِّ‏.‏ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ لِلنَّاسِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ لِحَفْصَةَ قُولِي لَهُ إِنَّ أَبَا بَكْرٍ إِذَا قَامَ فِي مَقَامِكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ، فَمُرْ عُمَرَ فَلْيُصَلِّ لِلنَّاسِ‏.‏ فَفَعَلَتْ حَفْصَةُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَهْ، إِنَّكُنَّ لأَنْتُنَّ صَوَاحِبُ يُوسُفَ، مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ لِلنَّاسِ ‏"‏‏.‏ قَالَتْ حَفْصَةُ لِعَائِشَةَ مَا كُنْتُ لأُصِيبَ مِنْكِ خَيْرًا‏.‏\hadithno{716}\hadithtrans{Narrated `Aisha:the mother of the faithful believers: Allah's Messenger (ﷺ) in his last illness said, "Tell Abu Bakr to lead the people in the prayer." I said, "If Abu Bakr stood in your place, he would not be able to make the people hear him owing to his weeping. So please order `Umar to lead the prayer." He said, "Tell Abu Bakr to lead the people in the prayer." I said to Hafsa, "Say to him, 'Abu Bakr is a softhearted man and if he stood in your place he would not be able to make the people hear him owing to his weeping. So order `Umar to lead the people in the prayer.' " Hafsa did so but Allah's Messenger (ﷺ) said, "Keep quiet. Verily you are the companions of (Prophet) Joseph. Tell Abu Bakr to lead the people in the prayer." Hafsa said to me, "I never got any good from you}}
\hadithdefcmd{bukhari}{717}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ مُرَّةَ، قَالَ سَمِعْتُ سَالِمَ بْنَ أَبِي الْجَعْدِ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَتُسَوُّنَّ صُفُوفَكُمْ أَوْ لَيُخَالِفَنَّ اللَّهُ بَيْنَ وُجُوهِكُمْ ‏"‏‏.‏\hadithno{717}\hadithtrans{Narrated An-Nu`man bin 'Bashir:The Prophet (ﷺ) said, "Straighten your rows or Allah will alter your faces}}
\hadithdefcmd{bukhari}{718}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَقِيمُوا الصُّفُوفَ فَإِنِّي أَرَاكُمْ خَلْفَ ظَهْرِي ‏"‏‏.‏\hadithno{718}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Straighten your rows, for I see you from behind my back}}
\hadithdefcmd{bukhari}{719}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي رَجَاءٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا زَائِدَةُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، حَدَّثَنَا أَنَسٌ، قَالَ أُقِيمَتِ الصَّلاَةُ فَأَقْبَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَجْهِهِ فَقَالَ ‏ "‏ أَقِيمُوا صُفُوفَكُمْ وَتَرَاصُّوا، فَإِنِّي أَرَاكُمْ مِنْ وَرَاءِ ظَهْرِي ‏"‏‏.‏\hadithno{719}\hadithtrans{Narrated Anas bin Malik:Once the Iqama was pronounced and Allah's Messenger (ﷺ) faced us and said, "Straighten your rows and stand closer together, for I see you from behind my back}}
\hadithdefcmd{bukhari}{721}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الشُّهَدَاءُ الْغَرِقُ وَالْمَطْعُونُ وَالْمَبْطُونُ وَالْهَدْمُ ‏"‏‏.‏ وَقَالَ ‏"‏ وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا ‏\{‏إِلَيْهِ‏\}‏ وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا، وَلَوْ يَعْلَمُونَ مَا فِي الصَّفِّ الْمُقَدَّمِ لاَسْتَهَمُوا ‏"‏‏.‏\hadithno{721}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Martyrs are those who die because of drowning, plague, an Abdominal disease, or of being buried alive by a falling building." And then he added, "If the people knew the Reward for the Zuhr prayer in its early time, they would race for it. If they knew the reward for the `Isha' and the Fajr prayers in congregation, they would join them even if they had to crawl. If they knew the reward for the first row, they would draw lots for it}}
\hadithdefcmd{bukhari}{722}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَلاَ تَخْتَلِفُوا عَلَيْهِ، فَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا رَبَّنَا لَكَ الْحَمْدُ‏.‏ وَإِذَا سَجَدَ فَاسْجُدُوا، وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا أَجْمَعُونَ، وَأَقِيمُوا الصَّفَّ فِي الصَّلاَةِ، فَإِنَّ إِقَامَةَ الصَّفِّ مِنْ حُسْنِ الصَّلاَةِ ‏"‏‏.‏\hadithno{722}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Imam is (appointed) to be followed. So do not differ from him, bow when he bows, and say, "Rabbana-lakal hamd" if he says "Sami`a l-lahu liman hamidah"; and if he prostrates, prostrate (after him), and if he prays sitting, pray sitting all together, and straighten the rows for the prayer, as the straightening of the rows is amongst those things which make your prayer a correct and perfect one. (See Hadith No)}}
\hadithdefcmd{bukhari}{723}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ سَوُّوا صُفُوفَكُمْ فَإِنَّ تَسْوِيَةَ الصُّفُوفِ مِنْ إِقَامَةِ الصَّلاَةِ ‏"‏‏.‏\hadithno{723}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Straighten your rows as the straightening of rows is essential for a perfect and correct prayer}}
\hadithdefcmd{bukhari}{724}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، قَالَ أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا سَعِيدُ بْنُ عُبَيْدٍ الطَّائِيُّ، عَنْ بُشَيْرِ بْنِ يَسَارٍ الأَنْصَارِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَدِمَ الْمَدِينَةَ فَقِيلَ لَهُ مَا أَنْكَرْتَ مِنَّا مُنْذُ يَوْمِ عَهِدْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ مَا أَنْكَرْتُ شَيْئًا إِلاَّ أَنَّكُمْ لاَ تُقِيمُونَ الصُّفُوفَ‏.‏ وَقَالَ عُقْبَةُ بْنُ عُبَيْدٍ عَنْ بُشَيْرِ بْنِ يَسَارٍ قَدِمَ عَلَيْنَا أَنَسُ بْنُ مَالِكٍ الْمَدِينَةَ بِهَذَا‏.‏\hadithno{724}\hadithtrans{Narrated Anas bin Malik:I arrived at Medina and was asked whether I found any change since the days of Allah's Messenger (ﷺ). I said, "I have not found any change except that you do not stand in alignment in your prayers}}
\hadithdefcmd{bukhari}{725}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَقِيمُوا صُفُوفَكُمْ فَإِنِّي أَرَاكُمْ مِنْ وَرَاءِ ظَهْرِي ‏"‏‏.‏ وَكَانَ أَحَدُنَا يُلْزِقُ مَنْكِبَهُ بِمَنْكِبِ صَاحِبِهِ وَقَدَمَهُ بِقَدَمِهِ‏.‏\hadithno{725}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Straighten your rows for I see you from behind my back." Anas added, "Everyone of us used to put his shoulder with the shoulder of his companion and his foot with the foot of his companion}}
\hadithdefcmd{bukhari}{726}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا دَاوُدُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَقُمْتُ عَنْ يَسَارِهِ، فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَأْسِي مِنْ وَرَائِي، فَجَعَلَنِي عَنْ يَمِينِهِ، فَصَلَّى وَرَقَدَ فَجَاءَهُ الْمُؤَذِّنُ، فَقَامَ وَصَلَّى وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{726}\hadithtrans{Narrated Ibn `Abbas:I prayed with the Prophet (ﷺ) one night and stood on his left side. Allah's Messenger (ﷺ) caught hold of my head from behind and drew me to his right and then offered the prayer and slept. Later the Mu'adh-dhin came and the Prophet (ﷺ) stood up for prayer without performing ablution}}
\hadithdefcmd{bukhari}{727}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِسْحَاقَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَلَّيْتُ أَنَا وَيَتِيمٌ، فِي بَيْتِنَا خَلْفَ النَّبِيِّ صلى الله عليه وسلم وَأُمِّي أُمُّ سُلَيْمٍ خَلْفَنَا‏.‏\hadithno{727}\hadithtrans{Narrated Anas bin Malik:One night an orphan and I offered the prayers behind the Prophet (ﷺ) in my house and my mother (Um Sulaim) was standing behind us (by herself forming a row)}}
\hadithdefcmd{bukhari}{728}{حَدَّثَنَا مُوسَى، حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ، حَدَّثَنَا عَاصِمٌ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قُمْتُ لَيْلَةً أُصَلِّي عَنْ يَسَارِ النَّبِيِّ صلى الله عليه وسلم فَأَخَذَ بِيَدِي أَوْ بِعَضُدِي حَتَّى أَقَامَنِي عَنْ يَمِينِهِ، وَقَالَ بِيَدِهِ مِنْ وَرَائِي‏.‏\hadithno{728}\hadithtrans{Narrated Ibn `Abbas:One night I stood to the left of the Prophet (ﷺ) in the prayer but he caught hold of me by the hand or by the shoulder (arm) till he made me stand on his right and beckoned with his hand (for me) to go from behind (him). (Al-Kashmaihani [??] , Fath-ul-Bari}}
\hadithdefcmd{bukhari}{729}{حَدَّثَنَا مُحَمَّدٌ، قَالَ أَخْبَرَنَا عَبْدَةُ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ فِي حُجْرَتِهِ، وَجِدَارُ الْحُجْرَةِ قَصِيرٌ، فَرَأَى النَّاسُ شَخْصَ النَّبِيِّ صلى الله عليه وسلم فَقَامَ أُنَاسٌ يُصَلُّونَ بِصَلاَتِهِ، فَأَصْبَحُوا فَتَحَدَّثُوا بِذَلِكَ، فَقَامَ لَيْلَةَ الثَّانِيَةِ، فَقَامَ مَعَهُ أُنَاسٌ يُصَلُّونَ بِصَلاَتِهِ، صَنَعُوا ذَلِكَ لَيْلَتَيْنِ أَوْ ثَلاَثَةً، حَتَّى إِذَا كَانَ بَعْدَ ذَلِكَ جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَخْرُجْ، فَلَمَّا أَصْبَحَ ذَكَرَ ذَلِكَ النَّاسُ فَقَالَ ‏ "‏ إِنِّي خَشِيتُ أَنْ تُكْتَبَ عَلَيْكُمْ صَلاَةُ اللَّيْلِ ‏"‏‏.‏\hadithno{729}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to pray in his room at night. As the wall of the room was low, the people saw him and some of them stood up to follow him in the prayer. In the morning they spread the news. The following night the Prophet (ﷺ) stood for the prayer and the people followed him. This went on for two or three nights. Thereupon Allah's Messenger (ﷺ) did not stand for the prayer the following night, and did not come out. In the morning, the people asked him about it. He replied, that he way afraid that the night prayer might become compulsory}}
\hadithdefcmd{bukhari}{730}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لَهُ حَصِيرٌ يَبْسُطُهُ بِالنَّهَارِ، وَيَحْتَجِرُهُ بِاللَّيْلِ، فَثَابَ إِلَيْهِ نَاسٌ، فَصَلَّوْا وَرَاءَهُ‏.‏\hadithno{730}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) had a mat which he used to spread during the day and use as a curtain at night. So a number of people gathered at night facing it and prayed behind him}}
\hadithdefcmd{bukhari}{731}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ حُجْرَةً ـ قَالَ حَسِبْتُ أَنَّهُ قَالَ ـ مِنْ حَصِيرٍ فِي رَمَضَانَ فَصَلَّى فِيهَا لَيَالِيَ، فَصَلَّى بِصَلاَتِهِ نَاسٌ مِنْ أَصْحَابِهِ، فَلَمَّا عَلِمَ بِهِمْ جَعَلَ يَقْعُدُ، فَخَرَجَ إِلَيْهِمْ فَقَالَ ‏ "‏ قَدْ عَرَفْتُ الَّذِي رَأَيْتُ مِنْ صَنِيعِكُمْ، فَصَلُّوا أَيُّهَا النَّاسُ فِي بُيُوتِكُمْ، فَإِنَّ أَفْضَلَ الصَّلاَةِ صَلاَةُ الْمَرْءِ فِي بَيْتِهِ إِلاَّ الْمَكْتُوبَةَ ‏"‏‏.‏ قَالَ عَفَّانُ حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مُوسَى، سَمِعْتُ أَبَا النَّضْرِ، عَنْ بُسْرٍ، عَنْ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{731}\hadithtrans{Narrated Zaid bin Thabit:Allah's Messenger (ﷺ) made a small room in the month of Ramadan (Sa`id said, "I think that Zaid bin Thabit said that it was made of a mat") and he prayed there for a few nights, and so some of his companions prayed behind him. When he came to know about it, he kept on sitting. In the morning, he went out to them and said, "I have seen and understood what you did. You should pray in your houses, for the best prayer of a person is that which he prays in his house except the compulsory prayers}}
\hadithdefcmd{bukhari}{732}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ الأَنْصَارِيُّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ فَرَسًا، فَجُحِشَ شِقُّهُ الأَيْمَنُ، قَالَ أَنَسٌ ـ رضى الله عنه ـ فَصَلَّى لَنَا يَوْمَئِذٍ صَلاَةً مِنَ الصَّلَوَاتِ وَهْوَ قَاعِدٌ، فَصَلَّيْنَا وَرَاءَهُ قُعُودًا، ثُمَّ قَالَ لَمَّا سَلَّمَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ، فَإِذَا صَلَّى قَائِمًا فَصَلُّوا قِيَامًا، وَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا رَفَعَ فَارْفَعُوا، وَإِذَا سَجَدَ فَاسْجُدُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏‏.‏\hadithno{732}\hadithtrans{Narrated Anas bin Malik Al-Ansari:Allah's Messenger (ﷺ) rode a horse and fell down and the right side of his body was injured. On that day he prayed one of the prayers sitting and we also prayed behind him sitting. When the Prophet (ﷺ) finished the prayer with Taslim, he said, "The Imam is to be followed and if he prays standing then pray standing, and bow when he bows, and raise your heads when he raises his head; prostrate when he prostrates; and if he says "Sami`a l-lahu liman hamidah", you should say, "Rabbana wa laka l-hamd.:}}
\hadithdefcmd{bukhari}{733}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ خَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ فَرَسٍ فَجُحِشَ فَصَلَّى لَنَا قَاعِدًا فَصَلَّيْنَا مَعَهُ قُعُودًا، ثُمَّ انْصَرَفَ فَقَالَ ‏ "‏ إِنَّمَا الإِمَامُ ـ أَوْ إِنَّمَا جُعِلَ الإِمَامُ ـ لِيُؤْتَمَّ بِهِ، فَإِذَا كَبَّرَ فَكَبِّرُوا، وَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا رَفَعَ فَارْفَعُوا، وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا رَبَّنَا لَكَ الْحَمْدُ‏.‏ وَإِذَا سَجَدَ فَاسْجُدُوا ‏"‏‏.‏\hadithno{733}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) fell from a horse and got injured so he led the prayer sitting and we also prayed sitting. When he completed the prayer he said, "The Imam is to be followed; if he says Takbir then say Takbir, bow if he bows; raise your heads when he raises his head, when he says, 'Sami`a l-lahu liman hamidah say, 'Rabbana laka l-hamd', and prostrate when he prostrates}}
\hadithdefcmd{bukhari}{734}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ، فَإِذَا كَبَّرَ فَكَبِّرُوا، وَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ‏.‏ وَإِذَا سَجَدَ فَاسْجُدُوا، وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا أَجْمَعُونَ ‏"‏‏.‏\hadithno{734}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Imam is to be followed. Say the Takbir when he says it; bow if he bows; if he says 'Sami`a l-lahu liman hamidah', say, ' Rabbana wa laka l-hamd', prostrate if he prostrates and pray sitting altogether if he prays sitting}}
\hadithdefcmd{bukhari}{735}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَرْفَعُ يَدَيْهِ حَذْوَ مَنْكِبَيْهِ إِذَا افْتَتَحَ الصَّلاَةَ، وَإِذَا كَبَّرَ لِلرُّكُوعِ، وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَهُمَا كَذَلِكَ أَيْضًا وَقَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ، رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏‏.‏ وَكَانَ لاَ يَفْعَلُ ذَلِكَ فِي السُّجُودِ‏.‏\hadithno{735}\hadithtrans{Narrated Salim bin `Abdullah:My father said, "Allah's Messenger (ﷺ) used to raise both his hands up to the level of his shoulders when opening the prayer; and on saying the Takbir for bowing. And on raising his head from bowing he used to do the same and then say "Sami`a l-lahu liman hamidah, Rabbana wa laka l-hamd." And he did not do that (i.e. raising his hands) in prostrations}}
\hadithdefcmd{bukhari}{736}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، رضى الله عنهما قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ فِي الصَّلاَةِ رَفَعَ يَدَيْهِ حَتَّى يَكُونَا حَذْوَ مَنْكِبَيْهِ، وَكَانَ يَفْعَلُ ذَلِكَ حِينَ يُكَبِّرُ لِلرُّكُوعِ، وَيَفْعَلُ ذَلِكَ إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَيَقُولُ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏‏.‏ وَلاَ يَفْعَلُ ذَلِكَ فِي السُّجُودِ‏.‏\hadithno{736}\hadithtrans{Narrated `Abdullah bin `Umar:I saw that whenever Allah's Messenger (ﷺ) stood for the prayer, he used to raise both his hands up to the shoulders, and used to do the same on saying the Takbir for bowing and on raising his head from it and used to say, "Sami`a l-lahu liman hamidah". But he did not do that (i.e. raising his hands) in prostrations}}
\hadithdefcmd{bukhari}{737}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، أَنَّهُ رَأَى مَالِكَ بْنَ الْحُوَيْرِثِ إِذَا صَلَّى كَبَّرَ وَرَفَعَ يَدَيْهِ، وَإِذَا أَرَادَ أَنْ يَرْكَعَ رَفَعَ يَدَيْهِ، وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَ يَدَيْهِ، وَحَدَّثَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَنَعَ هَكَذَا‏.‏\hadithno{737}\hadithtrans{Narrated Abu Qilaba:I saw Malik bin Huwairith saying Takbir and raising both his hands (on starting the prayers and raising his hands on bowing and also on raising his head after bowing. Malik bin Huwairith said, "Allah's Messenger (ﷺ) did the same}}
\hadithdefcmd{bukhari}{738}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنَا سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم افْتَتَحَ التَّكْبِيرَ فِي الصَّلاَةِ، فَرَفَعَ يَدَيْهِ حِينَ يُكَبِّرُ حَتَّى يَجْعَلَهُمَا حَذْوَ مَنْكِبَيْهِ، وَإِذَا كَبَّرَ لِلرُّكُوعِ فَعَلَ مِثْلَهُ، وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَعَلَ مِثْلَهُ وَقَالَ ‏ "‏ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏‏.‏ وَلاَ يَفْعَلُ ذَلِكَ حِينَ يَسْجُدُ وَلاَ حِينَ يَرْفَعُ رَأْسَهُ مِنَ السُّجُودِ‏.‏\hadithno{738}\hadithtrans{Narrated `Abdullah bin `Umar:I saw Allah's Messenger (ﷺ) opening the prayer with the Takbir and raising his hands to the level of his shoulders at the time of saying the Takbir, and on saying the Takbir for bowing he did the same; and when he said, "Sami`a l-lahu liman hamidah ", he did the same and then said, "Rabbana wa laka lhamd." But he did not do the same on prostrating and on lifting the head from it}}
\hadithdefcmd{bukhari}{739}{حَدَّثَنَا عَيَّاشٌ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ إِذَا دَخَلَ فِي الصَّلاَةِ كَبَّرَ وَرَفَعَ يَدَيْهِ، وَإِذَا رَكَعَ رَفَعَ يَدَيْهِ، وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ رَفَعَ يَدَيْهِ، وَإِذَا قَامَ مِنَ الرَّكْعَتَيْنِ رَفَعَ يَدَيْهِ‏.‏ وَرَفَعَ ذَلِكَ ابْنُ عُمَرَ إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم‏.‏ رَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ أَيُّوبَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَرَوَاهُ ابْنُ طَهْمَانَ عَنْ أَيُّوبَ وَمُوسَى بْنِ عُقْبَةَ مُخْتَصَرًا‏.‏\hadithno{739}\hadithtrans{Narrated Nafi`:Whenever Ibn `Umar started the prayer with Takbir, he used to raise his hands: whenever he bowed, he used to raise his hands (before bowing) and also used to raise his hands on saying, "Sami`a l-lahu liman hamidah", and he used to do the same on rising from the second rak`a (for the 3rd rak`a). Ibn `Umar said: "The Prophet (ﷺ) used to do the same}}
\hadithdefcmd{bukhari}{740}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ كَانَ النَّاسُ يُؤْمَرُونَ أَنْ يَضَعَ الرَّجُلُ الْيَدَ الْيُمْنَى عَلَى ذِرَاعِهِ الْيُسْرَى فِي الصَّلاَةِ‏.‏ قَالَ أَبُو حَازِمٍ لاَ أَعْلَمُهُ إِلاَّ يَنْمِي ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏ قَالَ إِسْمَاعِيلُ يُنْمَى ذَلِكَ‏.‏ وَلَمْ يَقُلْ يَنْمِي‏.‏\hadithno{740}\hadithtrans{Narrated Sahl bin Sa`d:The people were ordered to place the right hand on the left forearm in the prayer. Abu Hazim said, "I knew that the order was from the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{741}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ هَلْ تَرَوْنَ قِبْلَتِي هَا هُنَا وَاللَّهِ مَا يَخْفَى عَلَىَّ رُكُوعُكُمْ وَلاَ خُشُوعُكُمْ، وَإِنِّي لأَرَاكُمْ وَرَاءَ ظَهْرِي ‏"‏‏.‏\hadithno{741}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "You see me facing the Qibla; but, by Allah, nothing is hidden from me regarding your bowing and submissiveness and I see you from behind my back}}
\hadithdefcmd{bukhari}{742}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَقِيمُوا الرُّكُوعَ وَالسُّجُودَ، فَوَاللَّهِ إِنِّي لأَرَاكُمْ مِنْ بَعْدِي ـ وَرُبَّمَا قَالَ مِنْ بَعْدِ ظَهْرِي ـ إِذَا رَكَعْتُمْ وَسَجَدْتُمْ ‏"‏‏.‏\hadithno{742}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Perform the bowing and the prostrations properly. By Allah, I see you from behind me (or from behind my back) when you bow or prostrate}}
\hadithdefcmd{bukhari}{743}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ ـ رضى الله عنهما ـ كَانُوا يَفْتَتِحُونَ الصَّلاَةَ بِ ـ ‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏\hadithno{743}\hadithtrans{Narrated Anas bin Malik:The Prophet, Abu Bakr and `Umar used to start the prayer with "Al hamdu li l-lahi Rabbi l-`alamin (All praise is but to Allah, Lord of the Worlds)}}
\hadithdefcmd{bukhari}{744}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، قَالَ حَدَّثَنَا عُمَارَةُ بْنُ الْقَعْقَاعِ، قَالَ حَدَّثَنَا أَبُو زُرْعَةَ، قَالَ حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْكُتُ بَيْنَ التَّكْبِيرِ وَبَيْنَ الْقِرَاءَةِ إِسْكَاتَةً ـ قَالَ أَحْسِبُهُ قَالَ هُنَيَّةً ـ فَقُلْتُ بِأَبِي وَأُمِّي يَا رَسُولَ اللَّهِ، إِسْكَاتُكَ بَيْنَ التَّكْبِيرِ وَالْقِرَاءَةِ مَا تَقُولُ قَالَ ‏ "‏ أَقُولُ اللَّهُمَّ بَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ، اللَّهُمَّ نَقِّنِي مِنَ الْخَطَايَا كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ، اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِالْمَاءِ وَالثَّلْجِ وَالْبَرَدِ ‏"‏‏.‏\hadithno{744}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) used to keep silent between the Takbir and the recitation of Qur'an and that interval of silence used to be a short one. I said to the Prophet (ﷺ) "May my parents be sacrificed for you! What do you say in the pause between Takbir and recitation?" The Prophet (ﷺ) said, "I say, 'Allahumma, baa`id baini wa baina khatayaya kama baa`adta baina l-mashriqi wa l-maghrib. Allahumma, naqqini min khatayaya kama yunaqqa th-thawbu l-abyadu mina d-danas. Allahumma, ighsil khatayaya bi l-maa'i wa th-thalji wa l-barad (O Allah! Set me apart from my sins (faults) as the East and West are set apart from each other and clean me from sins as a white garment is cleaned of dirt (after thorough washing). O Allah! Wash off my sins with water, snow and hail}}
\hadithdefcmd{bukhari}{745}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ أَخْبَرَنَا نَافِعُ بْنُ عُمَرَ، قَالَ حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى صَلاَةَ الْكُسُوفِ، فَقَامَ فَأَطَالَ الْقِيَامَ، ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ، ثُمَّ قَامَ فَأَطَالَ الْقِيَامَ، ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ، ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ، ثُمَّ رَفَعَ، ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ، ثُمَّ قَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ فَسَجَدَ فَأَطَالَ السُّجُودَ، ثُمَّ رَفَعَ، ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ انْصَرَفَ فَقَالَ ‏"‏ قَدْ دَنَتْ مِنِّي الْجَنَّةُ حَتَّى لَوِ اجْتَرَأْتُ عَلَيْهَا لَجِئْتُكُمْ بِقِطَافٍ مِنْ قِطَافِهَا، وَدَنَتْ مِنِّي النَّارُ حَتَّى قُلْتُ أَىْ رَبِّ وَأَنَا مَعَهُمْ فَإِذَا امْرَأَةٌ ـ حَسِبْتُ أَنَّهُ قَالَ ـ تَخْدِشُهَا هِرَّةٌ قُلْتُ مَا شَأْنُ هَذِهِ قَالُوا حَبَسَتْهَا حَتَّى مَاتَتْ جُوعًا، لاَ أَطْعَمَتْهَا، وَلاَ أَرْسَلَتْهَا تَأْكُلُ ‏"‏‏.‏ قَالَ نَافِعٌ حَسِبْتُ أَنَّهُ قَالَ ‏"‏ مِنْ خَشِيشِ أَوْ خُشَاشِ الأَرْضِ ‏"‏‏.‏\hadithno{745}\hadithtrans{Narrated Asma' bint Abi Bakr:The Prophet (ﷺ) once offered the eclipse prayer. He stood for a long time and then did a prolonged bowing. He stood up straight again and kept on standing for a long time, then bowed a long bowing and then stood up straight and then prostrated a prolonged prostration and then lifted his head and prostrated a prolonged prostration. And then he stood up for a long time and then did a prolonged bowing and then stood up straight again and kept on standing for a long time. Then he bowed a long bowing and then stood up straight and then prostrated a prolonged prostration and then lifted his head and went for a prolonged prostration. On completion of the prayer, he said, "Paradise became so near to me that if I had dared, I would have plucked one of its bunches for you and Hell became so near to me that I said, 'O my Lord will I be among those people?' Then suddenly I saw a woman and a cat was lacerating her with its claws. On inquiring, it was said that the woman had imprisoned the cat till it died of starvation and she neither fed it nor freed it so that it could feed itself}}
\hadithdefcmd{bukhari}{746}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، قَالَ قُلْنَا لِخَبَّابٍ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ قَالَ نَعَمْ‏.‏ قُلْنَا بِمَ كُنْتُمْ تَعْرِفُونَ ذَاكَ قَالَ بِاضْطِرَابِ لِحْيَتِهِ‏.‏\hadithno{746}\hadithtrans{Narrated Abu Ma`mar:We asked Khabbab whether Allah's Messenger (ﷺ) used to recite (the Qur'an) in the Zuhr and the `Asr prayers. He replied in the affirmative. We said, "How did you come to know about it?" He said, "By the movement of his beard}}
\hadithdefcmd{bukhari}{747}{حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا شُعْبَةُ، قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَزِيدَ، يَخْطُبُ قَالَ حَدَّثَنَا الْبَرَاءُ، وَكَانَ، غَيْرَ كَذُوبٍ أَنَّهُمْ كَانُوا إِذَا صَلَّوْا مَعَ النَّبِيِّ صلى الله عليه وسلم فَرَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَامُوا قِيَامًا حَتَّى يَرَوْنَهُ قَدْ سَجَدَ‏.‏\hadithno{747}\hadithtrans{Narrated Al-Bara:(And Al-Bara was not a liar) Whenever we offered prayer with the Prophet (ﷺ) and he raised his head from the bowing, we used to remain standing till we saw him prostrating}}
\hadithdefcmd{bukhari}{748}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، رضى الله عنهما قَالَ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى، قَالُوا يَا رَسُولَ اللَّهِ، رَأَيْنَاكَ تَنَاوَلُ شَيْئًا فِي مَقَامِكَ، ثُمَّ رَأَيْنَاكَ تَكَعْكَعْتَ‏.‏ قَالَ ‏ "‏ إِنِّي أُرِيتُ الْجَنَّةَ، فَتَنَاوَلْتُ مِنْهَا عُنْقُودًا، وَلَوْ أَخَذْتُهُ لأَكَلْتُمْ مِنْهُ مَا بَقِيَتِ الدُّنْيَا ‏"‏‏.‏\hadithno{748}\hadithtrans{Narrated `Abdullah bin `Abbas:Once solar eclipse occurred during the lifetime of Allah's Messenger (ﷺ). He offered the eclipse prayer. His companions asked, "O Allah's Messenger (ﷺ)! We saw you trying to take something while standing at your place and then we saw you retreating." The Prophet (ﷺ) said, "I was shown Paradise and wanted to have a bunch of fruit from it. Had I taken it, you would have eaten from it as long as the world remains}}
\hadithdefcmd{bukhari}{749}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، قَالَ حَدَّثَنَا فُلَيْحٌ، قَالَ حَدَّثَنَا هِلاَلُ بْنُ عَلِيٍّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَلَّى لَنَا النَّبِيُّ صلى الله عليه وسلم ثُمَّ رَقَا الْمِنْبَرَ، فَأَشَارَ بِيَدَيْهِ قِبَلَ قِبْلَةِ الْمَسْجِدِ ثُمَّ قَالَ ‏ "‏ لَقَدْ رَأَيْتُ الآنَ مُنْذُ صَلَّيْتُ لَكُمُ الصَّلاَةَ الْجَنَّةَ وَالنَّارَ مُمَثَّلَتَيْنِ فِي قِبْلَةِ هَذَا الْجِدَارِ، فَلَمْ أَرَ كَالْيَوْمِ فِي الْخَيْرِ وَالشَّرِّ ‏"‏ ثَلاَثًا‏.‏\hadithno{749}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) led us in prayer and then went up to the pulpit and beckoned with both hands towards the Qibla of the mosque and then said, "When I started leading you in prayer, I saw the display of Paradise and Hell on the wall of the mosque (facing the Qibla). I never saw good and bad as I have seen today." He repeated the last statement thrice}}
\hadithdefcmd{bukhari}{750}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَرُوبَةَ، قَالَ حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا بَالُ أَقْوَامٍ يَرْفَعُونَ أَبْصَارَهُمْ إِلَى السَّمَاءِ فِي صَلاَتِهِمْ ‏"‏‏.‏ فَاشْتَدَّ قَوْلُهُ فِي ذَلِكَ حَتَّى قَالَ ‏"‏ لَيَنْتَهُنَّ عَنْ ذَلِكَ أَوْ لَتُخْطَفَنَّ أَبْصَارُهُمْ ‏"‏‏.‏\hadithno{750}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "What is wrong with those people who look towards the sky during the prayer?" His talk grew stern while delivering this speech and he said, "They should stop (looking towards the sky during the prayer); otherwise their eyesight would be taken away}}
\hadithdefcmd{bukhari}{751}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، قَالَ حَدَّثَنَا أَشْعَثُ بْنُ سُلَيْمٍ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ الاِلْتِفَاتِ فِي الصَّلاَةِ فَقَالَ ‏ "‏ هُوَ اخْتِلاَسٌ يَخْتَلِسُهُ الشَّيْطَانُ مِنْ صَلاَةِ الْعَبْدِ ‏"‏‏.‏\hadithno{751}\hadithtrans{Narrated `Aisha:I asked Allah's Messenger (ﷺ) about looking hither and thither in prayer. He replied, "It is a way of stealing by which Satan takes away (a portion) from the prayer of a person}}
\hadithdefcmd{bukhari}{752}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى فِي خَمِيصَةٍ لَهَا أَعْلاَمٌ فَقَالَ ‏ "‏ شَغَلَتْنِي أَعْلاَمُ هَذِهِ، اذْهَبُوا بِهَا إِلَى أَبِي جَهْمٍ وَأْتُونِي بِأَنْبِجَانِيَّةٍ ‏"‏‏.‏\hadithno{752}\hadithtrans{Narrated `Aisha:Once the Prophet (ﷺ) prayed on a Khamisa with marks on it and said, "The marks on it diverted my attention, take this Khamisa to Abu Jahm and bring an Inbijaniya (from him)}}
\hadithdefcmd{bukhari}{753}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَالَ رَأَى النَّبِيُّ صلى الله عليه وسلم نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ، وَهْوَ يُصَلِّي بَيْنَ يَدَىِ النَّاسِ، فَحَتَّهَا ثُمَّ قَالَ حِينَ انْصَرَفَ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا كَانَ فِي الصَّلاَةِ فَإِنَّ اللَّهَ قِبَلَ وَجْهِهِ، فَلاَ يَتَنَخَّمَنَّ أَحَدٌ قِبَلَ وَجْهِهِ فِي الصَّلاَةِ ‏"‏‏.‏ رَوَاهُ مُوسَى بْنُ عُقْبَةَ وَابْنُ أَبِي رَوَّادٍ عَنْ نَافِعٍ‏.‏\hadithno{753}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) saw expectoration in the direction of the Qibla of the mosque while he was leading the prayer, and scratched it off. After finishing the prayer, he said, "Whenever any of you is in prayer he should know that Allah is in front of him. So none should spit in front of him in the prayer}}
\hadithdefcmd{bukhari}{754}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَنَسٌ، قَالَ بَيْنَمَا الْمُسْلِمُونَ فِي صَلاَةِ الْفَجْرِ لَمْ يَفْجَأْهُمْ إِلاَّ رَسُولُ اللَّهِ صلى الله عليه وسلم كَشَفَ سِتْرَ حُجْرَةِ عَائِشَةَ فَنَظَرَ إِلَيْهِمْ وَهُمْ صُفُوفٌ، فَتَبَسَّمَ يَضْحَكُ، وَنَكَصَ أَبُو بَكْرٍ رضى الله عنه عَلَى عَقِبَيْهِ لِيَصِلَ لَهُ الصَّفَّ فَظَنَّ أَنَّهُ يُرِيدُ الْخُرُوجَ، وَهَمَّ الْمُسْلِمُونَ أَنْ يَفْتَتِنُوا فِي صَلاَتِهِمْ، فَأَشَارَ إِلَيْهِمْ أَتِمُّوا صَلاَتَكُمْ، فَأَرْخَى السِّتْرَ، وَتُوُفِّيَ مِنْ آخِرِ ذَلِكَ الْيَوْمِ‏.‏\hadithno{754}\hadithtrans{Narrated Anas:While the Muslims were offering the Fajr prayer, Allah's Messenger (ﷺ) suddenly appeared before them by lifting the curtain of the dwelling place of `Aisha, looked towards the Muslims who were standing in rows. He smiled with pleasure. Abu Bakr started retreating to join the row on the assumption that the Prophet wanted to come out for the prayer. The Muslims intended to leave the prayer (and were on the verge of being put to trial), but the Prophet (ﷺ) beckoned them to complete their prayer and then he let the curtain fall. He died in the last hours of that day}}
\hadithdefcmd{bukhari}{755}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ شَكَا أَهْلُ الْكُوفَةِ سَعْدًا إِلَى عُمَرَ ـ رضى الله عنه ـ فَعَزَلَهُ وَاسْتَعْمَلَ عَلَيْهِمْ عَمَّارًا، فَشَكَوْا حَتَّى ذَكَرُوا أَنَّهُ لاَ يُحْسِنُ يُصَلِّي، فَأَرْسَلَ إِلَيْهِ فَقَالَ يَا أَبَا إِسْحَاقَ إِنَّ هَؤُلاَءِ يَزْعُمُونَ أَنَّكَ لاَ تُحْسِنُ تُصَلِّي قَالَ أَبُو إِسْحَاقَ أَمَّا أَنَا وَاللَّهِ فَإِنِّي كُنْتُ أُصَلِّي بِهِمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أَخْرِمُ عَنْهَا، أُصَلِّي صَلاَةَ الْعِشَاءِ فَأَرْكُدُ فِي الأُولَيَيْنِ وَأُخِفُّ فِي الأُخْرَيَيْنِ‏.‏ قَالَ ذَاكَ الظَّنُّ بِكَ يَا أَبَا إِسْحَاقَ‏.‏ فَأَرْسَلَ مَعَهُ رَجُلاً أَوْ رِجَالاً إِلَى الْكُوفَةِ، فَسَأَلَ عَنْهُ أَهْلَ الْكُوفَةِ، وَلَمْ يَدَعْ مَسْجِدًا إِلاَّ سَأَلَ عَنْهُ، وَيُثْنُونَ مَعْرُوفًا، حَتَّى دَخَلَ مَسْجِدًا لِبَنِي عَبْسٍ، فَقَامَ رَجُلٌ مِنْهُمْ يُقَالُ لَهُ أُسَامَةُ بْنُ قَتَادَةَ يُكْنَى أَبَا سَعْدَةَ قَالَ أَمَّا إِذْ نَشَدْتَنَا فَإِنَّ سَعْدًا كَانَ لاَ يَسِيرُ بِالسَّرِيَّةِ، وَلاَ يَقْسِمُ بِالسَّوِيَّةِ، وَلاَ يَعْدِلُ فِي الْقَضِيَّةِ‏.‏ قَالَ سَعْدٌ أَمَا وَاللَّهِ لأَدْعُوَنَّ بِثَلاَثٍ، اللَّهُمَّ إِنْ كَانَ عَبْدُكَ هَذَا كَاذِبًا، قَامَ رِيَاءً وَسُمْعَةً فَأَطِلْ عُمْرَهُ، وَأَطِلْ فَقْرَهُ، وَعَرِّضْهُ بِالْفِتَنِ، وَكَانَ بَعْدُ إِذَا سُئِلَ يَقُولُ شَيْخٌ كَبِيرٌ مَفْتُونٌ، أَصَابَتْنِي دَعْوَةُ سَعْدٍ‏.‏ قَالَ عَبْدُ الْمَلِكِ فَأَنَا رَأَيْتُهُ بَعْدُ قَدْ سَقَطَ حَاجِبَاهُ عَلَى عَيْنَيْهِ مِنَ الْكِبَرِ، وَإِنَّهُ لَيَتَعَرَّضُ لِلْجَوَارِي فِي الطُّرُقِ يَغْمِزُهُنَّ‏.‏\hadithno{755}\hadithtrans{Narrated Jabir bin Samura:The People of Kufa complained against Sa`d to `Umar and the latter dismissed him and appointed `Ammar as their chief . They lodged many complaints against Sa`d and even they alleged that he did not pray properly. `Umar sent for him and said, "O Aba 'Is-haq! These people claim that you do not pray properly." Abu 'Is-haq said, "By Allah, I used to pray with them a prayer similar to that of Allah's Apostle and I never reduced anything of it. I used to prolong the first two rak`at of `Isha prayer and shorten the last two rak`at." `Umar said, "O Aba 'Is-haq, this was what I thought about you." And then he sent one or more persons with him to Kufa so as to ask the people about him. So they went there and did not leave any mosque without asking about him. All the people praised him till they came to the mosque of the tribe of Bani `Abs; one of the men called Usama bin Qatada with a surname of Aba Sa`da stood up and said, "As you have put us under an oath; I am bound to tell you that Sa`d never went himself with the army and never distributed (the war booty) equally and never did justice in legal verdicts." (On hearing it) Sa`d said, "I pray to Allah for three things: O Allah! If this slave of yours is a liar and got up for showing off, give him a long life, increase his poverty and put him to trials." (And so it happened). Later on when that person was asked how he was, he used to reply that he was an old man in trial as the result of Sa`d's curse. `Abdul Malik, the sub narrator, said that he had seen him afterwards and his eyebrows were overhanging his eyes owing to old age and he used to tease and assault the small girls in the way}}
\hadithdefcmd{bukhari}{756}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِفَاتِحَةِ الْكِتَابِ ‏"‏‏.‏\hadithno{756}\hadithtrans{Narrated 'Ubada bin As-Samit:Allah's Messenger (ﷺ) said, "Whoever does not recite Al-Fatiha in his prayer, his prayer is invalid}}
\hadithdefcmd{bukhari}{757}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْمَسْجِدَ، فَدَخَلَ رَجُلٌ فَصَلَّى فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَرَدَّ وَقَالَ ‏"‏ ارْجِعْ فَصَلِّ، فَإِنَّكَ لَمْ تُصَلِّ ‏"‏‏.‏ فَرَجَعَ يُصَلِّي كَمَا صَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ثَلاَثًا‏.‏ فَقَالَ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أُحْسِنُ غَيْرَهُ فَعَلِّمْنِي‏.‏ فَقَالَ ‏"‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَكَبِّرْ، ثُمَّ اقْرَأْ مَا تَيَسَّرَ مَعَكَ مِنَ الْقُرْآنِ، ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا، ثُمَّ ارْفَعْ حَتَّى تَعْتَدِلَ قَائِمًا، ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا، ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ جَالِسًا، وَافْعَلْ ذَلِكَ فِي صَلاَتِكَ كُلِّهَا ‏"‏‏.‏\hadithno{757}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) entered the mosque and a person followed him. The man prayed and went to the Prophet and greeted him. The Prophet (ﷺ) returned the greeting and said to him, "Go back and pray, for you have not prayed." The man went back prayed in the same way as before, returned and greeted the Prophet who said, "Go back and pray, for you have not prayed." This happened thrice. The man said, "By Him Who sent you with the Truth, I cannot offer the prayer in a better way than this. Please, teach me how to pray." The Prophet (ﷺ) said, "When you stand for Prayer say Takbir and then recite from the Holy Qur'an (of what you know by heart) and then bow till you feel at ease. Then raise your head and stand up straight, then prostrate till you feel at ease during your prostration, then sit with calmness till you feel at ease (do not hurry) and do the same in all your prayers}}
\hadithdefcmd{bukhari}{758}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ قَالَ سَعْدٌ كُنْتُ أُصَلِّي بِهِمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَتَىِ الْعَشِيِّ لاَ أَخْرِمُ عَنْهَا، أَرْكُدُ فِي الأُولَيَيْنِ وَأَحْذِفُ فِي الأُخْرَيَيْنِ‏.‏ فَقَالَ عُمَرُ ـ رضى الله عنه ـ ذَلِكَ الظَّنُّ بِكَ‏.‏\hadithno{758}\hadithtrans{Narrated Jabir bin Samura:Sa`d said, "I used to pray with them a prayer similar to that of Allah's Messenger (ﷺ) (the prayer of Zuhr and `Asr) reducing nothing from them. I used to prolong the first two rak`at and shorten the last two rak`at." `Umar said to Sa`d "This was what we thought about you}}
\hadithdefcmd{bukhari}{759}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنْ صَلاَةِ الظُّهْرِ بِفَاتِحَةِ الْكِتَابِ وَسُورَتَيْنِ، يُطَوِّلُ فِي الأُولَى، وَيُقَصِّرُ فِي الثَّانِيَةِ، وَيُسْمِعُ الآيَةَ أَحْيَانًا، وَكَانَ يَقْرَأُ فِي الْعَصْرِ بِفَاتِحَةِ الْكِتَابِ وَسُورَتَيْنِ، وَكَانَ يُطَوِّلُ فِي الأُولَى، وَكَانَ يُطَوِّلُ فِي الرَّكْعَةِ الأُولَى مِنْ صَلاَةِ الصُّبْحِ، وَيُقَصِّرُ فِي الثَّانِيَةِ‏.‏\hadithno{759}\hadithtrans{Narrated `Abdullah bin Abi Qatada:My father said, "The Prophet (ﷺ) in Zuhr prayers used to recite Al-Fatiha along with two other Suras in the first two rak`at: a long one in the first rak`a and a shorter (Sura) in the second, and at times the verses were audible. In the `Asr prayer the Prophet (ﷺ) used to recite Al-Fatiha and two more Suras in the first two rak`at and used to prolong the first rak`a. And he used to prolong the first rak`a of the Fajr prayer and shorten the second}}
\hadithdefcmd{bukhari}{760}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي عُمَارَةُ، عَنْ أَبِي مَعْمَرٍ، قَالَ سَأَلْنَا خَبَّابًا أَكَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ قَالَ نَعَمْ‏.‏ قُلْنَا بِأَىِّ شَىْءٍ كُنْتُمْ تَعْرِفُونَ قَالَ بِاضْطِرَابِ لِحْيَتِهِ‏.‏\hadithno{760}\hadithtrans{Narrated Abu Ma`mar:I asked Khabbab whether the Prophet (ﷺ) used to recite the Qur'an in the Zuhr and the `Asr prayers. He replied in the affirmative. We said, "How did you come to know that?" He said, "From the movement of his beard}}
\hadithdefcmd{bukhari}{761}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، قَالَ قُلْتُ لِخَبَّابِ بْنِ الأَرَتِّ أَكَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ قَالَ نَعَمْ‏.‏ قَالَ قُلْتُ بِأَىِّ شَىْءٍ كُنْتُمْ تَعْلَمُونَ قِرَاءَتَهُ قَالَ بِاضْطِرَابِ لِحْيَتِهِ‏.‏\hadithno{761}\hadithtrans{Narrated Abu Ma`mar:I asked Khabbab bin Al-Art whether the Prophet (ﷺ) used to recite the Qur'an in the Zuhr and the `Asr prayers. He replied in the affirmative. I said, "How did you come to know that?" He replied, "From the movement of his beard}}
\hadithdefcmd{bukhari}{762}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، عَنْ هِشَامٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الرَّكْعَتَيْنِ مِنَ الظُّهْرِ وَالْعَصْرِ بِفَاتِحَةِ الْكِتَابِ، وَسُورَةٍ سُورَةٍ، وَيُسْمِعُنَا الآيَةَ أَحْيَانًا‏.‏\hadithno{762}\hadithtrans{Narrated `Abdullah bin Abi Qatada:My father said, "The Prophet (ﷺ) used to recite Al-Fatiha along with another Sura in the first two rak`at of the Zuhr and the `Asr prayers and at times a verse or so was audible to us}}
\hadithdefcmd{bukhari}{763}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ قَالَ إِنَّ أُمَّ الْفَضْلِ سَمِعَتْهُ وَهُوَ يَقْرَأُ ‏\{‏وَالْمُرْسَلاَتِ عُرْفًا‏\}‏ فَقَالَتْ يَا بُنَىَّ وَاللَّهِ لَقَدْ ذَكَّرْتَنِي بِقِرَاءَتِكَ هَذِهِ السُّورَةَ، إِنَّهَا لآخِرُ مَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهَا فِي الْمَغْرِبِ‏.‏\hadithno{763}\hadithtrans{Narrated Ibn `Abbas:(My mother) Umu-l-Fadl heard me reciting "Wal Mursalati `Urfan" (77) and said, "O my son! By Allah, your recitation made me remember that it was the last Sura I heard from Allah's Messenger (ﷺ). He recited it in the Maghrib prayer}}
\hadithdefcmd{bukhari}{764}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ مَرْوَانَ بْنِ الْحَكَمِ، قَالَ قَالَ لِي زَيْدُ بْنُ ثَابِتٍ مَا لَكَ تَقْرَأُ فِي الْمَغْرِبِ بِقِصَارٍ، وَقَدْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ بِطُولِ الطُّولَيَيْنِ\hadithno{764}\hadithtrans{Narrated Marwan bin Al-Hakam:Zaid bin Thabit said to me, "Why do you recite very short Suras in the Maghrib prayer while I heard the Prophet (ﷺ) reciting the longer of the two long Suras?}}
\hadithdefcmd{bukhari}{765}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ فِي الْمَغْرِبِ بِالطُّورِ‏.‏\hadithno{765}\hadithtrans{Narrated Jubair bin Mut`im:My father said, "I heard Allah's Messenger (ﷺ) reciting "at-Tur" (52) in the Maghrib prayer}}
\hadithdefcmd{bukhari}{766}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، عَنْ بَكْرٍ، عَنْ أَبِي رَافِعٍ، قَالَ صَلَّيْتُ مَعَ أَبِي هُرَيْرَةَ الْعَتَمَةَ فَقَرَأَ ‏\{‏إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ فَسَجَدَ فَقُلْتُ لَهُ قَالَ سَجَدْتُ خَلْفَ أَبِي الْقَاسِمِ صلى الله عليه وسلم فَلاَ أَزَالُ أَسْجُدُ بِهَا حَتَّى أَلْقَاهُ‏.‏\hadithno{766}\hadithtrans{Narrated Abu Rafi`:I offered the `Isha' prayer behind Abu Huraira and he recited, "Idha s-samaa'u n-shaqqat" (84) and prostrated. On my inquiring, he said, "I prostrated behind Abul-Qasim (the Prophet) (when he recited that Sura) and I will go on doing it till I meet him}}
\hadithdefcmd{bukhari}{767}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، قَالَ سَمِعْتُ الْبَرَاءَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي سَفَرٍ فَقَرَأَ فِي الْعِشَاءِ فِي إِحْدَى الرَّكْعَتَيْنِ بِالتِّينِ وَالزَّيْتُونِ‏.‏\hadithno{767}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) was on a journey and recited in one of the first two rak`at of the `Isha' prayer "Wa t-teeni wa z-zaitun}}
\hadithdefcmd{bukhari}{768}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنِي التَّيْمِيُّ، عَنْ بَكْرٍ، عَنْ أَبِي رَافِعٍ، قَالَ صَلَّيْتُ مَعَ أَبِي هُرَيْرَةَ الْعَتَمَةَ فَقَرَأَ ‏\{‏إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ فَسَجَدَ فَقُلْتُ مَا هَذِهِ قَالَ سَجَدْتُ بِهَا خَلْفَ أَبِي الْقَاسِمِ صلى الله عليه وسلم فَلاَ أَزَالُ أَسْجُدُ بِهَا حَتَّى أَلْقَاهُ‏.‏\hadithno{768}\hadithtrans{Narrated Abu Rafi`:Once I prayed the `Isha' prayer with Abu Huraira and he recited, "Idha s-samaa'u n-shaqqat" (84) and prostrated. I said, "What is that?" He said, "I prostrated behind Abul-Qasim, (the Prophet) (when he recited that Sura) and I will go on doing it till I meet him}}
\hadithdefcmd{bukhari}{769}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا مِسْعَرٌ، قَالَ حَدَّثَنَا عَدِيُّ بْنُ ثَابِتٍ، سَمِعَ الْبَرَاءَ، رضى الله عنه قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ ‏\{‏وَالتِّينِ وَالزَّيْتُونِ‏\}‏ فِي الْعِشَاءِ، وَمَا سَمِعْتُ أَحَدًا أَحْسَنَ صَوْتًا مِنْهُ أَوْ قِرَاءَةً‏.‏\hadithno{769}\hadithtrans{Narrated Al-Bara:I heard the Prophet (ﷺ) reciting wa t-teeni wa z-zaitun" (95) in the `Isha' prayer, and I never heard a sweeter voice or a better way of recitation than that of the Prophet}}
\hadithdefcmd{bukhari}{770}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عَوْنٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، قَالَ قَالَ عُمَرُ لِسَعْدٍ لَقَدْ شَكَوْكَ فِي كُلِّ شَىْءٍ حَتَّى الصَّلاَةِ‏.‏ قَالَ أَمَّا أَنَا فَأَمُدُّ فِي الأُولَيَيْنِ، وَأَحْذِفُ فِي الأُخْرَيَيْنِ، وَلاَ آلُو مَا اقْتَدَيْتُ بِهِ مِنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ صَدَقْتَ، ذَاكَ الظَّنُّ بِكَ، أَوْ ظَنِّي بِكَ‏.‏\hadithno{770}\hadithtrans{Narrated Jabir bin Samura:`Umar said to Sa`d, "The people complained against you in everything, even in prayer." Sa`d replied, "Really I used to prolong the first two rak`at and shorten the last two and I will never shorten the prayer in which I follow Allah's Messenger (ﷺ)." `Umar said, "You are telling the truth and that is what I think about you}}
\hadithdefcmd{bukhari}{771}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا سَيَّارُ بْنُ سَلاَمَةَ، قَالَ دَخَلْتُ أَنَا وَأَبِي، عَلَى أَبِي بَرْزَةَ الأَسْلَمِيِّ فَسَأَلْنَاهُ عَنْ وَقْتِ الصَّلَوَاتِ، فَقَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الظُّهْرَ حِينَ تَزُولُ الشَّمْسُ، وَالْعَصْرَ وَيَرْجِعُ الرَّجُلُ إِلَى أَقْصَى الْمَدِينَةِ وَالشَّمْسُ حَيَّةٌ، وَنَسِيتُ مَا قَالَ فِي الْمَغْرِبِ، وَلاَ يُبَالِي بِتَأْخِيرِ الْعِشَاءِ إِلَى ثُلُثِ اللَّيْلِ وَلاَ يُحِبُّ النَّوْمَ قَبْلَهَا، وَلاَ الْحَدِيثَ بَعْدَهَا، وَيُصَلِّي الصُّبْحَ فَيَنْصَرِفُ الرَّجُلُ فَيَعْرِفُ جَلِيسَهُ، وَكَانَ يَقْرَأُ فِي الرَّكْعَتَيْنِ أَوْ إِحْدَاهُمَا مَا بَيْنَ السِّتِّينَ إِلَى الْمِائَةِ‏.‏\hadithno{771}\hadithtrans{Narrated Saiyar bin Salama:My father and I went to Abu Barza-al-Aslami to ask him about the stated times for the prayers. He replied, "The Prophet (ﷺ) used to offer the Zuhr prayer when the sun just declined from its highest position at noon; the `Asr at a time when if a man went to the farthest place in Medina (after praying) he would find the sun still hot (bright). (The sub narrator said: I have forgotten what Abu Barza said about the Maghrib prayer). The Prophet (ﷺ) never found any harm in delaying the `Isha' prayer to the first third of the night and he never liked to sleep before it and to talk after it. He used to offer the morning prayer at a time when after finishing it one could recognize the person sitting beside him and used to recite between 60 to 100 verses in one or both the rak`at}}
\hadithdefcmd{bukhari}{772}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ فِي كُلِّ صَلاَةٍ يُقْرَأُ، فَمَا أَسْمَعَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَسْمَعْنَاكُمْ، وَمَا أَخْفَى عَنَّا أَخْفَيْنَا عَنْكُمْ، وَإِنْ لَمْ تَزِدْ عَلَى أُمِّ الْقُرْآنِ أَجْزَأَتْ، وَإِنْ زِدْتَ فَهُوَ خَيْرٌ‏.‏\hadithno{772}\hadithtrans{Narrated Abu Huraira:The Qur'an is recited in every prayer and in those prayers in which Allah's Messenger (ﷺ) recited aloud for us, we recite aloud in the same prayers for you; and the prayers in which the Prophet (ﷺ) recited quietly, we recite quietly. If you recite "Al-Fatiha" only it is sufficient but if you recite something else in addition, it is better}}
\hadithdefcmd{bukhari}{773}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ انْطَلَقَ النَّبِيُّ صلى الله عليه وسلم فِي طَائِفَةٍ مِنْ أَصْحَابِهِ عَامِدِينَ إِلَى سُوقِ عُكَاظٍ، وَقَدْ حِيلَ بَيْنَ الشَّيَاطِينِ وَبَيْنَ خَبَرِ السَّمَاءِ، وَأُرْسِلَتْ عَلَيْهِمُ الشُّهُبُ، فَرَجَعَتِ الشَّيَاطِينُ إِلَى قَوْمِهِمْ‏.‏ فَقَالُوا مَا لَكُمْ فَقَالُوا حِيلَ بَيْنَنَا وَبَيْنَ خَبَرِ السَّمَاءِ، وَأُرْسِلَتْ عَلَيْنَا الشُّهُبُ‏.‏ قَالُوا مَا حَالَ بَيْنَكُمْ وَبَيْنَ خَبَرِ السَّمَاءِ إِلاَّ شَىْءٌ حَدَثَ، فَاضْرِبُوا مَشَارِقَ الأَرْضِ وَمَغَارِبَهَا، فَانْظُرُوا مَا هَذَا الَّذِي حَالَ بَيْنَكُمْ وَبَيْنَ خَبَرِ السَّمَاءِ فَانْصَرَفَ أُولَئِكَ الَّذِينَ تَوَجَّهُوا نَحْوَ تِهَامَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ بِنَخْلَةَ، عَامِدِينَ إِلَى سُوقِ عُكَاظٍ وَهْوَ يُصَلِّي بِأَصْحَابِهِ صَلاَةَ الْفَجْرِ، فَلَمَّا سَمِعُوا الْقُرْآنَ اسْتَمَعُوا لَهُ فَقَالُوا هَذَا وَاللَّهِ الَّذِي حَالَ بَيْنَكُمْ وَبَيْنَ خَبَرِ السَّمَاءِ‏.‏ فَهُنَالِكَ حِينَ رَجَعُوا إِلَى قَوْمِهِمْ وَقَالُوا يَا قَوْمَنَا ‏\{‏إِنَّا سَمِعْنَا قُرْآنًا عَجَبًا * يَهْدِي إِلَى الرُّشْدِ فَآمَنَّا بِهِ وَلَنْ نُشْرِكَ بِرَبِّنَا أَحَدًا‏\}‏ فَأَنْزَلَ اللَّهُ عَلَى نَبِيِّهِ صلى الله عليه وسلم ‏\{‏قُلْ أُوحِيَ إِلَىَّ‏\}‏ وَإِنَّمَا أُوحِيَ إِلَيْهِ قَوْلُ الْجِنِّ‏.‏\hadithno{773}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) set out with the intention of going to Suq `Ukaz (market of `Ukaz) along with some of his companions. At the same time, a barrier was put between the devils and the news of heaven. Fire commenced to be thrown at them. The Devils went to their people, who asked them, "What is wrong with you?" They said, "A barrier has been placed between us and the news of heaven. And fire has been thrown at us." They said, "The thing which has put a barrier between you and the news of heaven must be something which has happened recently. Go eastward and westward and see what has put a barrier between you and the news of heaven." Those who went towards Tihama came across the Prophet at a place called Nakhla and it was on the way to Suq `Ukaz and the Prophet (ﷺ) was offering the Fajr prayer with his companions. When they heard the Qur'an they listened to it and said, "By Allah, this is the thing which has put a barrier between us and the news of heaven." They went to their people and said, "O our people; verily we have heard a wonderful recital (Qur'an) which shows the true path; we believed in it and would not ascribe partners to our Lord." Allah revealed the following verses to his Prophet (Sura 'Jinn') (72): "Say: It has been revealed to me." And what was revealed to him was the conversation of the Jinns}}
\hadithdefcmd{bukhari}{774}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَرَأَ النَّبِيُّ صلى الله عليه وسلم فِيمَا أُمِرَ، وَسَكَتَ فِيمَا أُمِرَ ‏\{‏وَمَا كَانَ رَبُّكَ نَسِيًّا‏\}‏ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏‏.‏\hadithno{774}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) recited aloud in the prayers in which he was ordered to do so and quietly in the prayers in which he was ordered to do so. "And your Lord is not forgetful." "Verily there was a good example for you in the ways of the Prophet}}
\hadithdefcmd{bukhari}{774p2}{وَقَالَ عُبَيْدُ اللَّهِ عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ كَانَ رَجُلٌ مِنَ الأَنْصَارِ يَؤُمُّهُمْ فِي مَسْجِدِ قُبَاءٍ، وَكَانَ كُلَّمَا افْتَتَحَ سُورَةً يَقْرَأُ بِهَا لَهُمْ فِي الصَّلاَةِ مِمَّا يَقْرَأُ بِهِ افْتَتَحَ بِ ـ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ حَتَّى يَفْرُغَ مِنْهَا، ثُمَّ يَقْرَأُ سُورَةً أُخْرَى مَعَهَا، وَكَانَ يَصْنَعُ ذَلِكَ فِي كُلِّ رَكْعَةٍ، فَكَلَّمَهُ أَصْحَابُهُ فَقَالُوا إِنَّكَ تَفْتَتِحُ بِهَذِهِ السُّورَةِ، ثُمَّ لاَ تَرَى أَنَّهَا تُجْزِئُكَ حَتَّى تَقْرَأَ بِأُخْرَى، فَإِمَّا أَنْ تَقْرَأَ بِهَا وَإِمَّا أَنْ تَدَعَهَا وَتَقْرَأَ بِأُخْرَى‏.‏ فَقَالَ مَا أَنَا بِتَارِكِهَا، إِنْ أَحْبَبْتُمْ أَنْ أَؤُمَّكُمْ بِذَلِكَ فَعَلْتُ، وَإِنْ كَرِهْتُمْ تَرَكْتُكُمْ‏.‏ وَكَانُوا يَرَوْنَ أَنَّهُ مِنْ أَفْضَلِهِمْ، وَكَرِهُوا أَنْ يَؤُمَّهُمْ غَيْرُهُ، فَلَمَّا أَتَاهُمُ النَّبِيُّ صلى الله عليه وسلم أَخْبَرُوهُ الْخَبَرَ فَقَالَ ‏"‏ يَا فُلاَنُ مَا يَمْنَعُكَ أَنْ تَفْعَلَ مَا يَأْمُرُكَ بِهِ أَصْحَابُكَ وَمَا يَحْمِلُكَ عَلَى لُزُومِ هَذِهِ السُّورَةِ فِي كُلِّ رَكْعَةٍ ‏"‏‏.‏ فَقَالَ إِنِّي أُحِبُّهَا‏.‏ فَقَالَ ‏"‏ حُبُّكَ إِيَّاهَا أَدْخَلَكَ الْجَنَّةَ ‏"‏‏.‏\hadithno{774.2}\hadithtrans{Anas said:One of the Ansar used to lead the Ansar in Salat in the Quba' mosque and it was his habit to recite Qul Huwal-lahu Ahad whenever he wanted to recite something in Salat. When he finished that Surah, he would recite another one with it. He followed the same procedure in each Rak'a. His companions discussed this with him and said, "You recite this Surah and do not consider it sufficient and then you recite another. So would you recite it alone or leave it and recite some other." He said, "I will never leave it and if you want me to be your Imam on this condition then it is all right ; otherwise I will leave you." They knew that he was the best amongst them and they did not like someone else to lead them in Salat. When the Prophet (ﷺ) went to them as usual, they informed him about it. The Prophet (ﷺ) addressed him and said, "O so-and-so, what forbids you from doing what your companions ask you to do ? Why do you read this Surah particularly in every Rak'a?" He replied, "I love this Surah." The Prophet (ﷺ) said, "Your love for this Surah will make you enter Paradise}}
\hadithdefcmd{bukhari}{775}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ جَاءَ رَجُلٌ إِلَى ابْنِ مَسْعُودٍ فَقَالَ قَرَأْتُ الْمُفَصَّلَ اللَّيْلَةَ فِي رَكْعَةٍ‏.‏ فَقَالَ هَذًّا كَهَذِّ الشِّعْرِ لَقَدْ عَرَفْتُ النَّظَائِرَ الَّتِي كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرِنُ بَيْنَهُنَّ فَذَكَرَ عِشْرِينَ سُورَةً مِنَ الْمُفَصَّلِ سُورَتَيْنِ فِي كُلِّ رَكْعَةٍ‏.‏\hadithno{775}\hadithtrans{Narrated Abu Wa'il:A man came to Ibn Mas`ud and said, "I recited the Mufassal (Suras) at night in one rak`a." Ibn Mas`ud said, "This recitation is (too quick) like the recitation of poetry. I know the identical Suras which the Prophet (ﷺ) used to recite in pairs." Ibn Mas`ud then mentioned 20 Mufassal Suras including two Suras from the family of (i.e. those verses which begin with) Ha, Meem [??] (which the Prophet (ﷺ) used to recite) in each rak`a}}
\hadithdefcmd{bukhari}{776}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الظُّهْرِ فِي الأُولَيَيْنِ بِأُمِّ الْكِتَابِ وَسُورَتَيْنِ، وَفِي الرَّكْعَتَيْنِ الأُخْرَيَيْنِ بِأُمِّ الْكِتَابِ، وَيُسْمِعُنَا الآيَةَ، وَيُطَوِّلُ فِي الرَّكْعَةِ الأُولَى مَا لاَ يُطَوِّلُ فِي الرَّكْعَةِ الثَّانِيَةِ، وَهَكَذَا فِي الْعَصْرِ وَهَكَذَا فِي الصُّبْحِ‏.‏\hadithno{776}\hadithtrans{Narrated `Abdullah bin Abi Qatada:My father said, "The Prophet (ﷺ) uses to recite Al-Fatiha followed by another Sura in the first two rak`at of the prayer and used to recite only Al-Fatiha in the last two rak`at of the Zuhr prayer. Sometimes a verse or so was audible and he used to prolong the first rak`a more than the second and used to do the same in the `Asr and Fajr prayers}}
\hadithdefcmd{bukhari}{777}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، قُلْتُ لِخَبَّابٍ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ قَالَ نَعَمْ‏.‏ قُلْنَا مِنْ أَيْنَ عَلِمْتَ قَالَ بِاضْطِرَابِ لِحْيَتِهِ‏.‏\hadithno{777}\hadithtrans{Narrated Abu Ma`mar:We said to Khabbab "Did Allah's Messenger (ﷺ) used to recite in Zuhr and `Asr prayers?" He replied in the affirmative. We said, "How did you come to know about it?" He said, "By the movement of his beard}}
\hadithdefcmd{bukhari}{778}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ بِأُمِّ الْكِتَابِ وَسُورَةٍ مَعَهَا فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنْ صَلاَةِ الظُّهْرِ وَصَلاَةِ الْعَصْرِ، وَيُسْمِعُنَا الآيَةَ أَحْيَانًا، وَكَانَ يُطِيلُ فِي الرَّكْعَةِ الأُولَى‏.‏\hadithno{778}\hadithtrans{Narrated `Abdullah bin Abi Qatada:My father said, "The Prophet (ﷺ) used to recite Al-Fatiha along with another Sura in the first two rak`at of the Zuhr and `Asr prayers. A verse or so was audible at times and he used to prolong the first rak`a}}
\hadithdefcmd{bukhari}{779}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُطَوِّلُ فِي الرَّكْعَةِ الأُولَى مِنْ صَلاَةِ الظُّهْرِ، وَيُقَصِّرُ فِي الثَّانِيَةِ، وَيَفْعَلُ ذَلِكَ فِي صَلاَةِ الصُّبْحِ‏.‏\hadithno{779}\hadithtrans{Narrated `Abdullah bin Abi Qatada:My father said, "The Prophet (ﷺ) used to prolong the first rak`a of the Zuhr prayer and shorten the second one and used to do the same in the Fajr prayer}}
\hadithdefcmd{bukhari}{780}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّهُمَا أَخْبَرَاهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَمَّنَ الإِمَامُ فَأَمِّنُوا فَإِنَّهُ مَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏ وَقَالَ ابْنُ شِهَابٍ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ آمِينَ ‏"‏‏.‏\hadithno{780}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Say Amin" when the Imam says it and if the Amin of any one of you coincides with that of the angels then all his past sins will be forgiven." Ibn Shihab said, "Allah's Messenger (ﷺ) used to Say "Amin}}
\hadithdefcmd{bukhari}{781}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ أَحَدُكُمْ آمِينَ‏.‏ وَقَالَتِ الْمَلاَئِكَةُ فِي السَّمَاءِ آمِينَ‏.‏ فَوَافَقَتْ إِحْدَاهُمَا الأُخْرَى، غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{781}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If any one of you says, "Amin" and the angels in the heavens say "Amin" and the former coincides with the latter, all his past sins will be forgiven}}
\hadithdefcmd{bukhari}{782}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا قَالَ الإِمَامُ ‏\{‏غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ‏\}‏ فَقُولُوا آمِينَ‏.‏ فَإِنَّهُ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏ تَابَعَهُ مُحَمَّدُ بْنُ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَنُعَيْمٌ الْمُجْمِرُ عَنْ أَبِي هُرَيْرَةَ رضى الله عنه‏.‏\hadithno{782}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Say Amen when the Imam says 'Ghairi l-maghdubi `alaihim wala d-daalleen' (not the path of those who earn Your Anger (such as Jews) nor of those who go astray (such as Christians)); all the past sins of the person whose saying (of Amin) coincides with that of the angels, will be forgiven}}
\hadithdefcmd{bukhari}{783}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنِ الأَعْلَمِ ـ وَهْوَ زِيَادٌ ـ عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، أَنَّهُ انْتَهَى إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ رَاكِعٌ، فَرَكَعَ قَبْلَ أَنْ يَصِلَ إِلَى الصَّفِّ، فَذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ زَادَكَ اللَّهُ حِرْصًا وَلاَ تَعُدْ ‏"‏‏.‏\hadithno{783}\hadithtrans{Narrated Abu Bakra:I reached the Prophet (ﷺ) in the mosque while he was bowing in prayer and I too bowed before joining the row. I mentioned it to the Prophet (ﷺ) and he said to me, "May Allah increase your love for the good. But do not repeat it again (bowing in that way)}}
\hadithdefcmd{bukhari}{784}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الْعَلاَءِ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ صَلَّى مَعَ عَلِيٍّ ـ رضى الله عنه ـ بِالْبَصْرَةِ فَقَالَ ذَكَّرَنَا هَذَا الرَّجُلُ صَلاَةً كُنَّا نُصَلِّيهَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَذَكَرَ أَنَّهُ كَانَ يُكَبِّرُ كُلَّمَا رَفَعَ وَكُلَّمَا وَضَعَ‏.‏\hadithno{784}\hadithtrans{Narrated `Imran bin Husain:I offered the prayer with `Ali in Basra and he made us remember the prayer which we used to pray with Allah's Messenger (ﷺ). `Ali said Takbir on each rising and bowing}}
\hadithdefcmd{bukhari}{785}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يُصَلِّي بِهِمْ، فَيُكَبِّرُ كُلَّمَا خَفَضَ وَرَفَعَ، فَإِذَا انْصَرَفَ قَالَ إِنِّي لأَشْبَهُكُمْ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{785}\hadithtrans{Narrated Abu Salama:When Abu Huraira led us in prayer he used to say Takbir on each bowing and rising. On the completion of the prayer he used to say, "My prayer is more similar to the prayer of Allah's Messenger (ﷺ) than that of anyone of you}}
\hadithdefcmd{bukhari}{786}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ، قَالَ صَلَّيْتُ خَلْفَ عَلِيِّ بْنِ أَبِي طَالِبٍ ـ رضى الله عنه ـ أَنَا وَعِمْرَانُ بْنُ حُصَيْنٍ،، فَكَانَ إِذَا سَجَدَ كَبَّرَ، وَإِذَا رَفَعَ رَأْسَهُ كَبَّرَ، وَإِذَا نَهَضَ مِنَ الرَّكْعَتَيْنِ كَبَّرَ، فَلَمَّا قَضَى الصَّلاَةَ أَخَذَ بِيَدِي عِمْرَانُ بْنُ حُصَيْنٍ فَقَالَ قَدْ ذَكَّرَنِي هَذَا صَلاَةَ مُحَمَّدٍ صلى الله عليه وسلم‏.‏ أَوْ قَالَ لَقَدْ صَلَّى بِنَا صَلاَةَ مُحَمَّدٍ صلى الله عليه وسلم‏.‏\hadithno{786}\hadithtrans{Narrated Mutarrif bin `Abdullah:`Imran bin Husain and I offered the prayer behind `Ali bin Abi Talib. When `Ali prostrated, he said the Takbir, when he raised his head, he said the Takbir and when he got up for the third rak`a he said the Takbir. On completion of the prayer `Imran took my hand and said, "This (i.e. `Ali) made me remember the prayer of Muhammad" Or he said, "He led us in a prayer like that of Muhammad}}
\hadithdefcmd{bukhari}{787}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ عِكْرِمَةَ، قَالَ رَأَيْتُ رَجُلاً عِنْدَ الْمَقَامِ يُكَبِّرُ فِي كُلِّ خَفْضٍ وَرَفْعٍ وَإِذَا قَامَ وَإِذَا وَضَعَ، فَأَخْبَرْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنه ـ قَالَ أَوَلَيْسَ تِلْكَ صَلاَةَ النَّبِيِّ صلى الله عليه وسلم لاَ أُمَّ لَكَ‏.‏\hadithno{787}\hadithtrans{Narrated `Ikrima:I saw a person praying at Muqam-Ibrahim (the place of Abraham by the Ka`ba) and he was saying Takbir on every bowing, rising, standing and sitting. I asked Ibn `Abbas (about this prayer). He admonished me saying: "Isn't that the prayer of the Prophet?}}
\hadithdefcmd{bukhari}{788}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، قَالَ صَلَّيْتُ خَلْفَ شَيْخٍ بِمَكَّةَ فَكَبَّرَ ثِنْتَيْنِ وَعِشْرِينَ تَكْبِيرَةً، فَقُلْتُ لاِبْنِ عَبَّاسٍ إِنَّهُ أَحْمَقُ‏.‏ فَقَالَ ثَكِلَتْكَ أُمُّكَ، سُنَّةُ أَبِي الْقَاسِمِ صلى الله عليه وسلم‏.‏ وَقَالَ مُوسَى حَدَّثَنَا أَبَانُ حَدَّثَنَا قَتَادَةُ حَدَّثَنَا عِكْرِمَةُ‏.‏\hadithno{788}\hadithtrans{Narrated `Ikrima:I prayed behind a Sheikh at Mecca and he said twenty two Takbirs (during the prayer). I told Ibn `Abbas that he (i.e. that Sheikh) was foolish. Ibn `Abbas admonished me and said, "This is the tradition of Abul-Qasim}}
\hadithdefcmd{bukhari}{789}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ إِلَى الصَّلاَةِ يُكَبِّرُ حِينَ يَقُومُ، ثُمَّ يُكَبِّرُ حِينَ يَرْكَعُ، ثُمَّ يَقُولُ سَمِعَ اللَّهُ لَمِنْ حَمِدَهُ‏.‏ حِينَ يَرْفَعُ صُلْبَهُ مِنَ الرَّكْعَةِ، ثُمَّ يَقُولُ وَهُوَ قَائِمٌ رَبَّنَا لَكَ الْحَمْدُ ـ قَالَ عَبْدُ اللَّهِ ‏\{‏بْنُ صَالِحٍ عَنِ اللَّيْثِ‏\}‏ وَلَكَ الْحَمْدُ ـ ثُمَّ يُكَبِّرُ حِينَ يَهْوِي، ثُمَّ يُكَبِّرُ حِينَ يَرْفَعُ رَأْسَهُ، ثُمَّ يُكَبِّرُ حِينَ يَسْجُدُ، ثُمَّ يُكَبِّرُ حِينَ يَرْفَعُ رَأْسَهُ، ثُمَّ يَفْعَلُ ذَلِكَ فِي الصَّلاَةِ كُلِّهَا حَتَّى يَقْضِيَهَا، وَيُكَبِّرُ حِينَ يَقُومُ مِنَ الثِّنْتَيْنِ بَعْدَ الْجُلُوسِ‏.‏\hadithno{789}\hadithtrans{And narrated Abu Huraira:Whenever Allah's Messenger (ﷺ) stood for the prayer, he said Takbir on starting the prayer and then on bowing. On rising from bowing he said, "Sami`a llahu liman hamidah," and then while standing straight he used to say, "Rabbana laka-l hamd" (Al- Laith said, "(The Prophet (ﷺ) said), 'Wa laka l-hamd'." He used to say Takbir on prostrating and on raising his head from prostration; again he would Say Takbir on prostrating and raising his head. He would then do the same in the whole of the prayer till it was completed. On rising from the second rak`a (after sitting for at-Tahiyyat), he used to say Takbir}}
\hadithdefcmd{bukhari}{790}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي يَعْفُورٍ، قَالَ سَمِعْتُ مُصْعَبَ بْنَ سَعْدٍ، يَقُولُ صَلَّيْتُ إِلَى جَنْبِ أَبِي فَطَبَّقْتُ بَيْنَ كَفَّىَّ ثُمَّ وَضَعْتُهُمَا بَيْنَ فَخِذَىَّ، فَنَهَانِي أَبِي وَقَالَ كُنَّا نَفْعَلُهُ فَنُهِينَا عَنْهُ، وَأُمِرْنَا أَنْ نَضَعَ أَيْدِيَنَا عَلَى الرُّكَبِ‏.‏\hadithno{790}\hadithtrans{Narrated Mus`ab bin Sa`d:I offered prayer beside my father and approximated both my hands and placed them in between the knees. My father told me not to do so and said, "We used to do the same but we were forbidden (by the Prophet) to do it and were ordered to place the hands on the knees}}
\hadithdefcmd{bukhari}{791}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ زَيْدَ بْنَ وَهْبٍ، قَالَ رَأَى حُذَيْفَةُ رَجُلاً لاَ يُتِمُّ الرُّكُوعَ وَالسُّجُودَ قَالَ مَا صَلَّيْتَ، وَلَوْ مُتَّ مُتَّ عَلَى غَيْرِ الْفِطْرَةِ الَّتِي فَطَرَ اللَّهُ مُحَمَّدًا صلى الله عليه وسلم‏.‏\hadithno{791}\hadithtrans{Narrated Zaid bin Wahb:Hudhaifa saw a person who was not performing the bowing and prostration perfectly. He said to him, "You have not prayed and if you should die you would die on a religion other than that of Muhammad}}
\hadithdefcmd{bukhari}{792}{حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي الْحَكَمُ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ، قَالَ كَانَ رُكُوعُ النَّبِيِّ صلى الله عليه وسلم وَسُجُودُهُ وَبَيْنَ السَّجْدَتَيْنِ وَإِذَا رَفَعَ مِنَ الرُّكُوعِ، مَا خَلاَ الْقِيَامَ وَالْقُعُودَ، قَرِيبًا مِنَ السَّوَاءِ‏.‏\hadithno{792}\hadithtrans{Narrated Al-Bara:The bowing, the prostration the sitting in between the two prostrations and the standing after the bowing of the Prophet (ﷺ) but not qiyam (standing in the prayer) and qu`ud (sitting in the prayer) used to be approximately equal (in duration)}}
\hadithdefcmd{bukhari}{793}{حَدَّثَنَا مُسَدَّدٌ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ الْمَسْجِدَ فَدَخَلَ رَجُلٌ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَرَدَّ النَّبِيُّ صلى الله عليه وسلم عَلَيْهِ السَّلاَمَ فَقَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ فَصَلَّى، ثُمَّ جَاءَ فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏‏.‏ ثَلاَثًا‏.‏ فَقَالَ وَالَّذِي بَعَثَكَ بِالْحَقِّ فَمَا أُحْسِنُ غَيْرَهُ فَعَلِّمْنِي‏.‏ قَالَ ‏"‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَكَبِّرْ، ثُمَّ اقْرَأْ مَا تَيَسَّرَ مَعَكَ مِنَ الْقُرْآنِ، ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا، ثُمَّ ارْفَعْ حَتَّى تَعْتَدِلَ قَائِمًا، ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا، ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ جَالِسًا، ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا، ثُمَّ افْعَلْ ذَلِكَ فِي صَلاَتِكَ كُلِّهَا ‏"‏‏.‏\hadithno{793}\hadithtrans{Narrated Abu Huraira:Once the Prophet (ﷺ) entered the mosque, a man came in, offered the prayer and greeted the Prophet. The Prophet returned his greeting and said to him, "Go back and pray again for you have not prayed." The man offered the prayer again, came back and greeted the Prophet. He said to him thrice, "Go back and pray again for you have not prayed." The man said, "By Him Who has sent you with the truth! I do not know a better way of praying. Kindly teach Me how to pray." He said, "When you stand for the prayer, say Takbir and then recite from the Qur'an what you know and then bow with calmness till you feel at ease, then rise from bowing till you stand straight. Afterwards prostrate calmly till you feel at ease and then raise (your head) and sit with Calmness till you feel at ease and then prostrate with calmness till you feel at ease in prostration and do the same in the whole of your prayer}}
\hadithdefcmd{bukhari}{794}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ رَبَّنَا وَبِحَمْدِكَ، اللَّهُمَّ اغْفِرْ لِي ‏"‏‏.‏\hadithno{794}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to say in his bowing and prostrations, "Subhanaka l-lahumma Rabbana wa bihamdika; Allahumma ghfir li.' (Exalted [from unbecoming attributes] Are you O Allah our Lord, and by Your praise [do I exalt You]. O Allah! Forgive me}}
\hadithdefcmd{bukhari}{795}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏‏.‏ قَالَ ‏"‏ اللَّهُمَّ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ يُكَبِّرُ، وَإِذَا قَامَ مِنَ السَّجْدَتَيْنِ قَالَ ‏"‏ اللَّهُ أَكْبَرُ ‏"‏‏.‏\hadithno{795}\hadithtrans{Narrated Abu Huraira:When the Prophet (ﷺ) said, "Sami`a l-lahu liman hamidah," (Allah heard those who sent praises to Him), he would say, "Rabbana wa laka l-hamd." On bowing and raising his head from it the Prophet (ﷺ) used to say Takbir. He also used to say Takbir on rising after the two prostrations. (See Hadith No)}}
\hadithdefcmd{bukhari}{796}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ‏.‏ فَإِنَّهُ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{796}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the Imam says, "Sami`a l-lahu liman hamidah," you should say, "Allahumma Rabbana laka l-hamd." And if the saying of any one of you coincides with that of the angels, all his past sins will be forgiven}}
\hadithdefcmd{bukhari}{797}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لأُقَرِّبَنَّ صَلاَةَ النَّبِيِّ صلى الله عليه وسلم‏.‏ فَكَانَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ يَقْنُتُ فِي الرَّكْعَةِ الآخِرَةِ مِنْ صَلاَةِ الظُّهْرِ وَصَلاَةِ الْعِشَاءِ، وَصَلاَةِ الصُّبْحِ، بَعْدَ مَا يَقُولُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَيَدْعُو لِلْمُؤْمِنِينَ وَيَلْعَنُ الْكُفَّارَ‏.‏\hadithno{797}\hadithtrans{Narrated Abu Salama:Abu Hurairah said, "No doubt, my Salat is similar to that of the Prophet (ﷺ)." Abu Hurairah used to recite Qunut after saying Sami' Allahu liman hamida in the last Rak'a of the Zuhr, Isha and Fajr Prayers. He would ask Allah's Forgiveness for the true believers and curse the disbelievers}}
\hadithdefcmd{bukhari}{798}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ الْقُنُوتُ فِي الْمَغْرِبِ وَالْفَجْرِ‏.‏\hadithno{798}\hadithtrans{Narrated Anas:The qunut [supplication before going down for prostration] used to be recited in the Maghrib and the Fajr prayers}}
\hadithdefcmd{bukhari}{799}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، عَنْ عَلِيِّ بْنِ يَحْيَى بْنِ خَلاَّدٍ الزُّرَقِيِّ، عَنْ أَبِيهِ، عَنْ رِفَاعَةَ بْنِ رَافِعٍ الزُّرَقِيِّ، قَالَ كُنَّا يَوْمًا نُصَلِّي وَرَاءَ النَّبِيِّ صلى الله عليه وسلم فَلَمَّا رَفَعَ رَأْسَهُ مِنَ الرَّكْعَةِ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏‏.‏ قَالَ رَجُلٌ وَرَاءَهُ رَبَّنَا وَلَكَ الْحَمْدُ، حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ، فَلَمَّا انْصَرَفَ قَالَ ‏"‏ مَنِ الْمُتَكَلِّمُ ‏"‏‏.‏ قَالَ أَنَا‏.‏ قَالَ ‏"‏ رَأَيْتُ بِضْعَةً وَثَلاَثِينَ مَلَكًا يَبْتَدِرُونَهَا، أَيُّهُمْ يَكْتُبُهَا أَوَّلُ ‏"‏‏.‏\hadithno{799}\hadithtrans{Narrated Rifa`a bin Rafi` Az-Zuraqi:One day we were praying behind the Prophet. When he raised his head from bowing, he said, "Sami`a l-lahu liman hamidah." A man behind him said, "Rabbana wa laka l-hamdu, hamdan kathiran taiyiban mubarakan fihi" (O our Lord! All the praises are for You, many good and blessed praises). When the Prophet completed the prayer, he asked, "Who has said these words?" The man replied, "I." The Prophet said, "I saw over thirty angels competing to write it first." Prophet rose (from bowing) and stood straight till all the vertebrae of his spinal column came to a natural position}}
\hadithdefcmd{bukhari}{800}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ ثَابِتٍ، قَالَ كَانَ أَنَسٌ يَنْعَتُ لَنَا صَلاَةَ النَّبِيِّ صلى الله عليه وسلم فَكَانَ يُصَلِّي وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَامَ حَتَّى نَقُولَ قَدْ نَسِيَ‏.‏\hadithno{800}\hadithtrans{Narrated Thabit:Anas used to demonstrate to us the prayer of the Prophet (ﷺ) and while demonstrating, he used to raise his head from bowing and stand so long that we would say that he had forgotten (the prostration)}}
\hadithdefcmd{bukhari}{801}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ كَانَ رُكُوعُ النَّبِيِّ صلى الله عليه وسلم وَسُجُودُهُ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَبَيْنَ السَّجْدَتَيْنِ قَرِيبًا مِنَ السَّوَاءِ‏.‏\hadithno{801}\hadithtrans{Narrated Al-Bara':The bowing, the prostrations, the period of standing after bowing and the interval between the two prostrations of the Prophet (ﷺ) used to be equal in duration}}
\hadithdefcmd{bukhari}{802}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، قَالَ كَانَ مَالِكُ بْنُ الْحُوَيْرِثِ يُرِينَا كَيْفَ كَانَ صَلاَةُ النَّبِيِّ صلى الله عليه وسلم وَذَاكَ فِي غَيْرِ وَقْتِ صَلاَةٍ، فَقَامَ فَأَمْكَنَ الْقِيَامَ، ثُمَّ رَكَعَ فَأَمْكَنَ الرُّكُوعَ، ثُمَّ رَفَعَ رَأْسَهُ فَأَنْصَتَ هُنَيَّةً، قَالَ فَصَلَّى بِنَا صَلاَةَ شَيْخِنَا هَذَا أَبِي بُرَيْدٍ‏.‏ وَكَانَ أَبُو بُرَيْدٍ إِذَا رَفَعَ رَأْسَهُ مِنَ السَّجْدَةِ الآخِرَةِ اسْتَوَى قَاعِدًا ثُمَّ نَهَضَ‏.‏\hadithno{802}\hadithtrans{Narrated Aiyub:Abu Qilaba said, "Malik bin Huwairith used to demonstrate to us the prayer of the Prophet (ﷺ) at times other than that of the compulsory prayers. So (once) he stood up for prayer and performed a perfect Qiyam (standing and reciting from the Holy Qur'an) and then bowed and performed bowing perfectly; then he raised his head and stood straight for a while." Abu Qilaba added, "Malik bin Huwairith in that demonstration prayed like this Sheikh of ours, Abu Yazid." Abu Yazid used to sit (for a while) on raising his head from the second prostration before getting up}}
\hadithdefcmd{bukhari}{803}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، كَانَ يُكَبِّرُ فِي كُلِّ صَلاَةٍ مِنَ الْمَكْتُوبَةِ وَغَيْرِهَا فِي رَمَضَانَ وَغَيْرِهِ، فَيُكَبِّرُ حِينَ يَقُومُ، ثُمَّ يُكَبِّرُ حِينَ يَرْكَعُ، ثُمَّ يَقُولُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ ثُمَّ يَقُولُ رَبَّنَا وَلَكَ الْحَمْدُ‏.‏ قَبْلَ أَنْ يَسْجُدَ، ثُمَّ يَقُولُ اللَّهُ أَكْبَرُ‏.‏ حِينَ يَهْوِي سَاجِدًا، ثُمَّ يُكَبِّرُ حِينَ يَرْفَعُ رَأْسَهُ مِنَ السُّجُودِ، ثُمَّ يُكَبِّرُ حِينَ يَسْجُدُ، ثُمَّ يُكَبِّرُ حِينَ يَرْفَعُ رَأْسَهُ مِنَ السُّجُودِ، ثُمَّ يُكَبِّرُ حِينَ يَقُومُ مِنَ الْجُلُوسِ فِي الاِثْنَتَيْنِ، وَيَفْعَلُ ذَلِكَ فِي كُلِّ رَكْعَةٍ حَتَّى يَفْرُغَ مِنَ الصَّلاَةِ، ثُمَّ يَقُولُ حِينَ يَنْصَرِفُ وَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَقْرَبُكُمْ شَبَهًا بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنْ كَانَتْ هَذِهِ لَصَلاَتَهُ حَتَّى فَارَقَ الدُّنْيَا‏.‏\hadithno{803}\hadithtrans{Narrated Abu Bakr bin `Abdur Rahman Ibn Harith bin Hisham and Abu Salama bin `Abdur Rahman:Abu Huraira used to say Takbir in all the prayers, compulsory and optional -- in the month of Ramadan or other months. He used to say Takbir on standing for prayer and on bowing; then he would say, "Sami`a l-lahu liman hamidah," and before prostrating he would say "Rabbana wa laka lhamd." Then he would say Takbir on prostrating and on raising his head from the prostration, then another Takbir on prostrating (for the second time), and on raising his head from the prostration. He also would say the Takbir on standing from the second rak`a. He used to do the same in every rak`a till he completed the prayer. On completion of the prayer, he would say, "By Him in Whose Hands my soul is! No doubt my prayer is closer to that of Allah's Messenger (ﷺ) than yours, and this was His prayer till he left this world}}
\hadithdefcmd{bukhari}{804}{قَالاَ وَقَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ يَرْفَعُ رَأْسَهُ يَقُولُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ، رَبَّنَا وَلَكَ الْحَمْدُ‏.‏ يَدْعُو لِرِجَالٍ فَيُسَمِّيهِمْ بِأَسْمَائِهِمْ فَيَقُولُ ‏ "‏ اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ وَسَلَمَةَ بْنَ هِشَامٍ وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ، وَالْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ، اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ، وَاجْعَلْهَا عَلَيْهِمْ سِنِينَ كَسِنِي يُوسُفَ ‏"‏‏.‏ وَأَهْلُ الْمَشْرِقِ يَوْمَئِذٍ مِنْ مُضَرَ مُخَالِفُونَ لَهُ‏.‏\hadithno{804}\hadithtrans{And Abu Huraira said, "When Allah's Messenger (ﷺ) raised his head from (bowing) he used to say "Sami`a l-lahu liman hamidah, Rabbana wa laka l-hamd." He Would invoke Allah for some people by naming them:"O Allah! Save Al-Walid bin Al-Walid and Salama bin Hisham and `Aiyash bin Abi Rabi`a and the weak and the helpless people among the faithful believers O Allah! Be hard on the tribe of Mudar and let them suffer from famine years like that of the time of Joseph." In those days the Eastern section of the tribe of Mudar was against the Prophet}}
\hadithdefcmd{bukhari}{805}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، غَيْرَ مَرَّةٍ عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سَقَطَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ فَرَسٍ ـ وَرُبَّمَا قَالَ سُفْيَانُ مِنْ فَرَسٍ ـ فَجُحِشَ شِقُّهُ الأَيْمَنُ، فَدَخَلْنَا عَلَيْهِ نَعُودُهُ، فَحَضَرَتِ الصَّلاَةُ، فَصَلَّى بِنَا قَاعِدًا وَقَعَدْنَا ـ وَقَالَ سُفْيَانُ مَرَّةً صَلَّيْنَا قُعُودًا ـ فَلَمَّا قَضَى الصَّلاَةَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ، فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا رَفَعَ فَارْفَعُوا، وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ‏.‏ وَإِذَا سَجَدَ فَاسْجُدُوا ‏"‏‏.‏ قَالَ سُفْيَانُ كَذَا جَاءَ بِهِ مَعْمَرٌ قُلْتُ نَعَمْ‏.‏ قَالَ لَقَدْ حَفِظَ، كَذَا قَالَ الزُّهْرِيُّ وَلَكَ الْحَمْدُ‏.‏ حَفِظْتُ مِنْ شِقِّهِ الأَيْمَنِ‏.‏ فَلَمَّا خَرَجْنَا مِنْ عِنْدِ الزُّهْرِيِّ قَالَ ابْنُ جُرَيْجٍ ـ وَأَنَا عِنْدَهُ ـ فَجُحِشَ سَاقُهُ الأَيْمَنُ‏.‏\hadithno{805}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) fell from a horse and the right side of his body was injured. We went to inquire about his health meanwhile it was time for the prayer and he led the prayer sitting and we also prayed while sitting. On completion of the prayer he said, "The Imam is to be followed; say Takbir when he says it; bow when he bows; rise when he rises and when he says "Sami`a l-lahu liman hamidah," say, "Rabbana wa laka l-hamd", and prostrate if he prostrates." Sufyan narrated the same from Ma`mar. Ibn Juraij said that his (the Prophet's) right leg had been injured}}
\hadithdefcmd{bukhari}{806}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَعَطَاءُ بْنُ يَزِيدَ اللَّيْثِيُّ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُمَا أَنَّ النَّاسَ قَالُوا يَا رَسُولَ اللَّهِ، هَلْ نَرَى رَبَّنَا يَوْمَ الْقِيَامَةِ قَالَ ‏"‏ هَلْ تُمَارُونَ فِي الْقَمَرِ لَيْلَةَ الْبَدْرِ لَيْسَ دُونَهُ سَحَابٌ ‏"‏‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَهَلْ تُمَارُونَ فِي الشَّمْسِ لَيْسَ دُونَهَا سَحَابٌ ‏"‏‏.‏ قَالُوا لاَ‏.‏ قَالَ ‏"‏ فَإِنَّكُمْ تَرَوْنَهُ كَذَلِكَ، يُحْشَرُ النَّاسُ يَوْمَ الْقِيَامَةِ، فَيَقُولُ مَنْ كَانَ يَعْبُدُ شَيْئًا فَلْيَتَّبِعْ‏.‏ فَمِنْهُمْ مَنْ يَتَّبِعُ الشَّمْسَ، وَمِنْهُمْ مَنْ يَتَّبِعُ الْقَمَرَ وَمِنْهُمْ مَنْ يَتَّبِعُ الطَّوَاغِيتَ، وَتَبْقَى هَذِهِ الأُمَّةُ فِيهَا مُنَافِقُوهَا، فَيَأْتِيهِمُ اللَّهُ فَيَقُولُ أَنَا رَبُّكُمْ فَيَقُولُونَ هَذَا مَكَانُنَا حَتَّى يَأْتِيَنَا رَبُّنَا، فَإِذَا جَاءَ رَبُّنَا عَرَفْنَاهُ‏.‏ فَيَأْتِيهِمُ اللَّهُ فَيَقُولُ أَنَا رَبُّكُمْ‏.‏ فَيَقُولُونَ أَنْتَ رَبُّنَا‏.‏ فَيَدْعُوهُمْ فَيُضْرَبُ الصِّرَاطُ بَيْنَ ظَهْرَانَىْ جَهَنَّمَ، فَأَكُونُ أَوَّلَ مَنْ يَجُوزُ مِنَ الرُّسُلِ بِأُمَّتِهِ، وَلاَ يَتَكَلَّمُ يَوْمَئِذٍ أَحَدٌ إِلاَّ الرُّسُلُ، وَكَلاَمُ الرُّسُلِ يَوْمَئِذٍ اللَّهُمَّ سَلِّمْ سَلِّمْ‏.‏ وَفِي جَهَنَّمَ كَلاَلِيبُ مِثْلُ شَوْكِ السَّعْدَانِ، هَلْ رَأَيْتُمْ شَوْكَ السَّعْدَانِ ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ‏"‏ فَإِنَّهَا مِثْلُ شَوْكِ السَّعْدَانِ، غَيْرَ أَنَّهُ لاَ يَعْلَمُ قَدْرَ عِظَمِهَا إِلاَّ اللَّهُ، تَخْطَفُ النَّاسَ بِأَعْمَالِهِمْ، فَمِنْهُمْ مَنْ يُوبَقُ بِعَمَلِهِ، وَمِنْهُمْ مَنْ يُخَرْدَلُ ثُمَّ يَنْجُو، حَتَّى إِذَا أَرَادَ اللَّهُ رَحْمَةَ مَنْ أَرَادَ مِنْ أَهْلِ النَّارِ، أَمَرَ اللَّهُ الْمَلاَئِكَةَ أَنْ يُخْرِجُوا مَنْ كَانَ يَعْبُدُ اللَّهَ، فَيُخْرِجُونَهُمْ وَيَعْرِفُونَهُمْ بِآثَارِ السُّجُودِ، وَحَرَّمَ اللَّهُ عَلَى النَّارِ أَنْ تَأْكُلَ أَثَرَ السُّجُودِ فَيَخْرُجُونَ مِنَ النَّارِ، فَكُلُّ ابْنِ آدَمَ تَأْكُلُهُ النَّارُ إِلاَّ أَثَرَ السُّجُودِ، فَيَخْرُجُونَ مِنَ النَّارِ قَدِ امْتَحَشُوا، فَيُصَبُّ عَلَيْهِمْ مَاءُ الْحَيَاةِ، فَيَنْبُتُونَ كَمَا تَنْبُتُ الْحِبَّةُ فِي حَمِيلِ السَّيْلِ، ثُمَّ يَفْرُغُ اللَّهُ مِنَ الْقَضَاءِ بَيْنَ الْعِبَادِ، وَيَبْقَى رَجُلٌ بَيْنَ الْجَنَّةِ وَالنَّارِ، وَهْوَ آخِرُ أَهْلِ النَّارِ دُخُولاً الْجَنَّةَ، مُقْبِلٌ بِوَجْهِهِ قِبَلَ النَّارِ فَيَقُولُ يَا رَبِّ اصْرِفْ وَجْهِي عَنِ النَّارِ، قَدْ قَشَبَنِي رِيحُهَا، وَأَحْرَقَنِي ذَكَاؤُهَا‏.‏ فَيَقُولُ هَلْ عَسَيْتَ إِنْ فُعِلَ ذَلِكَ بِكَ أَنْ تَسْأَلَ غَيْرَ ذَلِكَ فَيَقُولُ لاَ وَعِزَّتِكَ‏.‏ فَيُعْطِي اللَّهَ مَا يَشَاءُ مِنْ عَهْدٍ وَمِيثَاقٍ، فَيَصْرِفُ اللَّهُ وَجْهَهُ عَنِ النَّارِ، فَإِذَا أَقْبَلَ بِهِ عَلَى الْجَنَّةِ رَأَى بَهْجَتَهَا سَكَتَ مَا شَاءَ اللَّهُ أَنْ يَسْكُتَ، ثُمَّ قَالَ يَا رَبِّ قَدِّمْنِي عِنْدَ باب الْجَنَّةِ‏.‏ فَيَقُولُ اللَّهُ لَهُ أَلَيْسَ قَدْ أَعْطَيْتَ الْعُهُودَ وَالْمَوَاثِيقَ أَنْ لاَ تَسْأَلَ غَيْرَ الَّذِي كُنْتَ سَأَلْتَ فَيَقُولُ يَا رَبِّ لاَ أَكُونُ أَشْقَى خَلْقِكَ‏.‏ فَيَقُولُ فَمَا عَسَيْتَ إِنْ أُعْطِيتَ ذَلِكَ أَنْ لاَ تَسْأَلَ غَيْرَهُ فَيَقُولُ لاَ وَعِزَّتِكَ لاَ أَسْأَلُ غَيْرَ ذَلِكَ‏.‏ فَيُعْطِي رَبَّهُ مَا شَاءَ مِنْ عَهْدٍ وَمِيثَاقٍ، فَيُقَدِّمُهُ إِلَى باب الْجَنَّةِ، فَإِذَا بَلَغَ بَابَهَا، فَرَأَى زَهْرَتَهَا وَمَا فِيهَا مِنَ النَّضْرَةِ وَالسُّرُورِ، فَيَسْكُتُ مَا شَاءَ اللَّهُ أَنْ يَسْكُتَ، فَيَقُولُ يَا رَبِّ أَدْخِلْنِي الْجَنَّةَ‏.‏ فَيَقُولُ اللَّهُ وَيْحَكَ يَا ابْنَ آدَمَ مَا أَغْدَرَكَ، أَلَيْسَ قَدْ أَعْطَيْتَ الْعَهْدَ وَالْمِيثَاقَ أَنْ لاَ تَسْأَلَ غَيْرَ الَّذِي أُعْطِيتَ فَيَقُولُ يَا رَبِّ لاَ تَجْعَلْنِي أَشْقَى خَلْقِكَ‏.‏ فَيَضْحَكُ اللَّهُ ـ عَزَّ وَجَلَّ ـ مِنْهُ، ثُمَّ يَأْذَنُ لَهُ فِي دُخُولِ الْجَنَّةِ فَيَقُولُ تَمَنَّ‏.‏ فَيَتَمَنَّى حَتَّى إِذَا انْقَطَعَتْ أُمْنِيَّتُهُ قَالَ اللَّهُ عَزَّ وَجَلَّ تَمَنَّ كَذَا وَكَذَا‏.‏ أَقْبَلَ يُذَكِّرُهُ رَبُّهُ، حَتَّى إِذَا انْتَهَتْ بِهِ الأَمَانِيُّ قَالَ اللَّهُ تَعَالَى لَكَ ذَلِكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ الْخُدْرِيُّ لأَبِي هُرَيْرَةَ ـ رضى الله عنهما ـ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ قَالَ اللَّهُ لَكَ ذَلِكَ وَعَشَرَةُ أَمْثَالِهِ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ لَمْ أَحْفَظْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ قَوْلَهُ ‏"‏ لَكَ ذَلِكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ إِنِّي سَمِعْتُهُ يَقُولُ ‏"‏ ذَلِكَ لَكَ وَعَشَرَةُ أَمْثَالِهِ ‏"‏‏.‏\hadithno{806}\hadithtrans{Narrated Abu Huraira:The people said, "O Allah's Messenger (ﷺ)! Shall we see our Lord on the Day of Resurrection?" He replied, "Do you have any doubt in seeing the full moon on a clear (not cloudy) night?" They replied, "No, O Allah's Messenger (ﷺ)!" He said, "Do you have any doubt in seeing the sun when there are no clouds?" They replied in the negative. He said, "You will see Allah (your Lord) in the same way. On the Day of Resurrection, people will be gathered and He will order the people to follow what they used to worship. So some of them will follow the sun, some will follow the moon, and some will follow other deities; and only this nation (Muslims) will be left with its hypocrites. Allah will come to them and say, 'I am Your Lord.' They will say, 'We shall stay in this place till our Lord comes to us and when our Lord will come, we will recognize Him. Then Allah will come to them again and say, 'I am your Lord.' They will say, 'You are our Lord.' Allah will call them, and As-Sirat (a bridge) will be laid across Hell and I (Muhammad) shall be the first amongst the Apostles to cross it with my followers. Nobody except the Apostles will then be able to speak and they will be saying then, 'O Allah! Save us. O Allah Save us.' There will be hooks like the thorns of Sa'dan [??] in Hell. Have you seen the thorns of Sa'dan [??]?" The people said, "Yes." He said, "These hooks will be like the thorns of Sa'dan [??] but nobody except Allah knows their greatness in size and these will entangle the people according to their deeds; some of them will fall and stay in Hell forever; others will receive punishment (torn into small pieces) and will get out of Hell, till when Allah intends mercy on whomever He likes amongst the people of Hell, He will order the angels to take out of Hell those who worshipped none but Him alone. The angels will take them out by recognizing them from the traces of prostrations, for Allah has forbidden the (Hell) fire to eat away those traces. So they will come out of the Fire, it will eat away from the whole of the human body except the marks of the prostrations. At that time they will come out of the Fire as mere skeletons. The Water of Life will be poured on them and as a result they will grow like the seeds growing on the bank of flowing water. Then when Allah had finished from the Judgments amongst his creations, one man will be left between Hell and Paradise and he will be the last man from the people of Hell to enter paradise. He will be facing Hell, and will say, 'O Allah! Turn my face from the fire as its wind has dried me and its steam has burnt me.' Allah will ask him, "Will you ask for anything more in case this favor is granted to you?' He will say, "No by Your (Honor) Power!" And he will give to his Lord (Allah) what he will of the pledges and the covenants. Allah will then turn his face from the Fire. When he will face Paradise and will see its charm, he will remain quiet as long as Allah wills. He then will say, 'O my Lord! Let me go to the gate of Paradise.' Allah will ask him, 'Didn't you give pledges and make covenants (to the effect) that you would not ask for anything more than what you requested at first?' He will say, 'O my Lord! Do not make me the most wretched, amongst Your creatures.' Allah will say, 'If this request is granted, will you then ask for anything else?' He will say, 'No! By Your Power! I shall not ask for anything else.' Then he will give to his Lord what He will of the pledges and the covenants. Allah will then let him go to the gate of Paradise. On reaching then and seeing its life, charm, and pleasure, he will remain quiet as long as Allah wills and then will say, 'O my Lord ! Let me enter Paradise.' Allah will say, May Allah be merciful unto you, O son of Adam! How treacherous you are! Haven't you made covenants and given pledges that you will not ask for anything more than what you have been given?' He will say, 'O my Lord! Do not make me the most wretched amongst Your creatures.' So Allah will laugh and allow him to enter Paradise and will ask him to request as much as he likes. He will do so till all his desires have been fulfilled . Then Allah will say, 'Request more of such and such things.' Allah will remind him and when all his desires and wishes; have been fulfilled, Allah will say "All this is granted to you and a similar amount besides." Abu Sa`id Al-Khudri, said to Abu Huraira, 'Allah's Messenger (ﷺ) said, "Allah said, 'That is for you and ten times more like it.' "Abu Huraira said, "I do not remember from Allah's Messenger (ﷺ) except (his saying), 'All this is granted to you and a similar amount besides." Abu Sa`id said, "I heard him saying, 'That is for you and ten times more the like of it}}
\hadithdefcmd{bukhari}{807}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنِي بَكْرُ بْنُ مُضَرَ، عَنْ جَعْفَرٍ، عَنِ ابْنِ هُرْمُزَ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ ابْنِ بُحَيْنَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا صَلَّى فَرَّجَ بَيْنَ يَدَيْهِ حَتَّى يَبْدُوَ بَيَاضُ إِبْطَيْهِ‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ نَحْوَهُ‏.‏\hadithno{807}\hadithtrans{Narrated `Abdullah bin Malik bin Buhaina:Whenever the Prophet (ﷺ) used to offer prayer he used to keep arms away (from the body) so that the whiteness of his armpits was visible}}
\hadithdefcmd{bukhari}{808}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَهْدِيٌّ، عَنْ وَاصِلٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، رَأَى رَجُلاً لاَ يُتِمُّ رُكُوعَهُ وَلاَ سُجُودَهُ، فَلَمَّا قَضَى صَلاَتَهُ قَالَ لَهُ حُذَيْفَةُ مَا صَلَّيْتَ ـ قَالَ وَأَحْسِبُهُ قَالَ ـ وَلَوْ مُتَّ مُتَّ عَلَى غَيْرِ سُنَّةِ مُحَمَّدٍ صلى الله عليه وسلم‏.‏\hadithno{808}\hadithtrans{Narrated Abu Wail:Hudhaifa said, "I saw a person not performing his bowing and prostrations perfectly. When he completed the prayer, I told him that he had not prayed." I think that Hudhaifa added (i.e. said to the man), "Had you died, you would have died on a tradition other than that of the Prophet Muhammad (ﷺ)}}
\hadithdefcmd{bukhari}{809}{حَدَّثَنَا قَبِيصَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أُمِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْجُدَ عَلَى سَبْعَةِ أَعْضَاءٍ، وَلاَ يَكُفَّ شَعَرًا وَلاَ ثَوْبًا الْجَبْهَةِ وَالْيَدَيْنِ وَالرُّكْبَتَيْنِ وَالرِّجْلَيْنِ‏.‏\hadithno{809}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was ordered (by Allah) to prostrate on seven parts and not to tuck up the clothes or hair (while praying). Those parts are: the forehead (along with the tip of nose), both hands, both knees, and (toes of) both feet}}
\hadithdefcmd{bukhari}{810}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْنَا أَنْ نَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ وَلاَ نَكُفَّ ثَوْبًا وَلاَ شَعَرًا ‏"‏‏.‏\hadithno{810}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "We have been ordered to prostrates on seven bones and not to tuck up the clothes or hair}}
\hadithdefcmd{bukhari}{811}{حَدَّثَنَا آدَمُ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْخَطْمِيِّ، حَدَّثَنَا الْبَرَاءُ بْنُ عَازِبٍ ـ وَهْوَ غَيْرُ كَذُوبٍ ـ قَالَ كُنَّا نُصَلِّي خَلْفَ النَّبِيِّ صلى الله عليه وسلم فَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ لَمْ يَحْنِ أَحَدٌ مِنَّا ظَهْرَهُ حَتَّى يَضَعَ النَّبِيُّ صلى الله عليه وسلم جَبْهَتَهُ عَلَى الأَرْضِ‏.‏\hadithno{811}\hadithtrans{Narrated Al-Bara' bin `Azib:(He was not a liar) We used to pray behind the Prophet (ﷺ) and when he said, "Sami`a l-lahu liman hamidah", none of us would bend his back (to go for prostration) till the Prophet (ﷺ) had placed his, forehead on the ground}}
\hadithdefcmd{bukhari}{812}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ عَلَى الْجَبْهَةِ ـ وَأَشَارَ بِيَدِهِ عَلَى أَنْفِهِ ـ وَالْيَدَيْنِ، وَالرُّكْبَتَيْنِ وَأَطْرَافِ الْقَدَمَيْنِ، وَلاَ نَكْفِتَ الثِّيَابَ وَالشَّعَرَ ‏"‏‏.‏\hadithno{812}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "I have been ordered to prostrate on seven bones i.e. on the forehead along with the tip of the nose and the Prophet (ﷺ) pointed towards his nose, both hands, both knees and the toes of both feet and not to gather the clothes or the hair}}
\hadithdefcmd{bukhari}{813}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ انْطَلَقْتُ إِلَى أَبِي سَعِيدٍ الْخُدْرِيِّ فَقُلْتُ أَلاَ تَخْرُجُ بِنَا إِلَى النَّخْلِ نَتَحَدَّثْ فَخَرَجَ‏.‏ فَقَالَ قُلْتُ حَدِّثْنِي مَا، سَمِعْتَ مِنَ النَّبِيِّ، صلى الله عليه وسلم فِي لَيْلَةِ الْقَدْرِ‏.‏ قَالَ اعْتَكَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشْرَ الأُوَلِ مِنْ رَمَضَانَ، وَاعْتَكَفْنَا مَعَهُ، فَأَتَاهُ جِبْرِيلُ فَقَالَ إِنَّ الَّذِي تَطْلُبُ أَمَامَكَ‏.‏ فَاعْتَكَفَ الْعَشْرَ الأَوْسَطَ، فَاعْتَكَفْنَا مَعَهُ، فَأَتَاهُ جِبْرِيلُ فَقَالَ إِنَّ الَّذِي تَطْلُبُ أَمَامَكَ‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم خَطِيبًا صَبِيحَةَ عِشْرِينَ مِنْ رَمَضَانَ فَقَالَ ‏ "‏ مَنْ كَانَ اعْتَكَفَ مَعَ النَّبِيِّ صلى الله عليه وسلم فَلْيَرْجِعْ، فَإِنِّي أُرِيتُ لَيْلَةَ الْقَدْرِ، وَإِنِّي نُسِّيتُهَا، وَإِنَّهَا فِي الْعَشْرِ الأَوَاخِرِ فِي وِتْرٍ، وَإِنِّي رَأَيْتُ كَأَنِّي أَسْجُدُ فِي طِينٍ وَمَاءٍ ‏"‏‏.‏ وَكَانَ سَقْفُ الْمَسْجِدِ جَرِيدَ النَّخْلِ وَمَا نَرَى فِي السَّمَاءِ شَيْئًا، فَجَاءَتْ قَزْعَةٌ فَأُمْطِرْنَا، فَصَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم حَتَّى رَأَيْتُ أَثَرَ الطِّينِ وَالْمَاءِ عَلَى جَبْهَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَرْنَبَتِهِ تَصْدِيقَ رُؤْيَاهُ‏.‏\hadithno{813}\hadithtrans{Narrated Abu Salama:Once I went to Abu- Sa`id Al-Khudri and asked him, "Won't you come with us to the date-palm trees to have a talk?" So Abu Sa`id went out and I asked him, "Tell me what you heard from the Prophet (ﷺ) about the Night of Qadr." Abu Sa`id replied, "Once Allah's Messenger (ﷺ) performed I`tikaf (seclusion) on the first ten days of the month of Ramadan and we did the same with him. Gabriel came to him and said, 'The night you are looking for is ahead of you.' So the Prophet (ﷺ) performed the I`tikaf in the middle (second) ten days of the month of Ramadan and we too performed I`tikaf with him. Gabriel came to him and said, 'The night which you are looking for is ahead of you.' In the morning of the 20th of Ramadan the Prophet (ﷺ) delivered a sermon saying, 'Whoever has performed I`tikaf with me should continue it. I have been shown the Night of "Qadr", but have forgotten its date, but it is in the odd nights of the last ten nights. I saw in my dream that I was prostrating in mud and water.' In those days the roof of the mosque was made of branches of date-palm trees. At that time the sky was clear and no cloud was visible, but suddenly a cloud came and it rained. The Prophet (ﷺ) led us in the prayer and I saw the traces of mud on the forehead and on the nose of Allah's Messenger (ﷺ). So it was the confirmation of that dream}}
\hadithdefcmd{bukhari}{814}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ كَانَ النَّاسُ يُصَلُّونَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَهُمْ عَاقِدُو أُزْرِهِمْ مِنَ الصِّغَرِ عَلَى رِقَابِهِمْ فَقِيلَ لِلنِّسَاءِ لاَ تَرْفَعْنَ رُءُوسَكُنَّ حَتَّى يَسْتَوِيَ الرِّجَالُ جُلُوسًا‏.‏\hadithno{814}\hadithtrans{Narrated Sahl bin Sa`d:The people used to pray with the Prophet (ﷺ) tying their Izars around their necks because of their small sizes and the women were directed that they should not raise their heads from the prostrations till the men had sat straight}}
\hadithdefcmd{bukhari}{815}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادٌ ـ وَهْوَ ابْنُ زَيْدٍ ـ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُمِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ، وَلاَ يَكُفَّ ثَوْبَهُ وَلاَ شَعَرَهُ‏.‏\hadithno{815}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was ordered to prostrate on seven bony parts and not to tuck up his clothes or hair}}
\hadithdefcmd{bukhari}{816}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعَةٍ، لاَ أَكُفُّ شَعَرًا وَلاَ ثَوْبًا ‏"‏‏.‏\hadithno{816}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "I have been ordered to prostrate on seven (bones) and not to tuck up the hair or garment}}
\hadithdefcmd{bukhari}{817}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُكْثِرُ أَنْ يَقُولَ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ رَبَّنَا وَبِحَمْدِكَ، اللَّهُمَّ اغْفِرْ لِي ‏"‏ يَتَأَوَّلُ الْقُرْآنَ‏.‏\hadithno{817}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to say frequently in his bowing and prostrations "Subhanaka l-lahumma Rabbana wa bihamdika, Allahumma ghfir li" (Exalted [from unbecoming attributes] Are you O Allah our Lord, and by Your praise [do I exalt you]. O Allah! Forgive me). In this way [??] he was acting on what was explained to him in the Holy Qur'an}}
\hadithdefcmd{bukhari}{819}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، أَنَّ مَالِكَ بْنَ الْحُوَيْرِثِ، قَالَ لأَصْحَابِهِ أَلاَ أُنَبِّئُكُمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ وَذَاكَ فِي غَيْرِ حِينِ صَلاَةٍ، فَقَامَ، ثُمَّ رَكَعَ فَكَبَّرَ ثُمَّ رَفَعَ رَأْسَهُ، فَقَامَ هُنَيَّةً، ثُمَّ سَجَدَ ثُمَّ رَفَعَ رَأْسَهُ هُنَيَّةً، فَصَلَّى صَلاَةَ عَمْرِو بْنِ سَلِمَةَ شَيْخِنَا هَذَا‏.‏ قَالَ أَيُّوبُ كَانَ يَفْعَلُ شَيْئًا لَمْ أَرَهُمْ يَفْعَلُونَهُ، كَانَ يَقْعُدُ فِي الثَّالِثَةِ وَالرَّابِعَةِ‏.‏ قَالَ فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَأَقَمْنَا عِنْدَهُ فَقَالَ ‏ "‏ لَوْ رَجَعْتُمْ إِلَى أَهْلِيكُمْ صَلُّوا صَلاَةَ كَذَا فِي حِينِ كَذَا، صَلُّوا صَلاَةَ كَذَا فِي حِينِ كَذَا، فَإِذَا حَضَرَتِ الصَّلاَةُ فَلْيُؤَذِّنْ أَحَدُكُمْ وَلْيَؤُمَّكُمْ أَكْبَرُكُمْ ‏"‏\hadithno{819}\hadithtrans{Narrated Abu Qilaba:Once Malik bin Huwairith said to his friends, "Shall I show you how Allah's Messenger (ﷺ) used to offer his prayers?" And it was not the time for any of the compulsory congregational prayers. So he stood up (for the prayer) bowed and said the Takbir, then he raised his head and remained standing for a while and then prostrated and raised his head for a while (sat up for a while). He prayed like our Sheikh `Amr Ibn Salama. (Aiyub said, "The latter used to do a thing which I did not see the people doing i.e. he used to sit between the third and the fourth rak`a). Malik bin Huwairith said, "We came to the Prophet (after embracing Islam) and stayed with him. He said to us, 'When you go back to your families, pray such and such a prayer at such and such a time, pray such and such a prayer at such and such a time, and when there is the time for the prayer then only of you should pronounce the Adhan for the prayer and the oldest of you should lead the prayer}}
\hadithdefcmd{bukhari}{820}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ، مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الزُّبَيْرِيُّ قَالَ حَدَّثَنَا مِسْعَرٌ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ، قَالَ كَانَ سُجُودُ النَّبِيِّ صلى الله عليه وسلم وَرُكُوعُهُ، وَقُعُودُهُ بَيْنَ السَّجْدَتَيْنِ قَرِيبًا مِنَ السَّوَاءِ‏.‏\hadithno{820}\hadithtrans{Narrated Al-Bara':The time taken by the Prophet (ﷺ) in prostrations, bowing, and the sitting interval between the two prostrations was about the same}}
\hadithdefcmd{bukhari}{821}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ إِنِّي لاَ آلُو أَنْ أُصَلِّيَ بِكُمْ كَمَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُصَلِّي بِنَا‏.‏ قَالَ ثَابِتٌ كَانَ أَنَسٌ يَصْنَعُ شَيْئًا لَمْ أَرَكُمْ تَصْنَعُونَهُ، كَانَ إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَامَ حَتَّى يَقُولَ الْقَائِلُ قَدْ نَسِيَ‏.‏ وَبَيْنَ السَّجْدَتَيْنِ حَتَّى يَقُولَ الْقَائِلُ قَدْ نَسِيَ‏.‏\hadithno{821}\hadithtrans{Narrated Thabit:Anas said, "I will leave no stone unturned in making you offer the prayer as I have seen the Prophet (ﷺ) making us offer it." Anas used to do a thing which I have not seen you doing. He used to stand after the bowing for such a long time that one would think that he had forgotten (the prostrations) and he used to sit in-between the prostrations so long that one would think that he had forgotten the second prostration}}
\hadithdefcmd{bukhari}{822}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اعْتَدِلُوا فِي السُّجُودِ، وَلاَ يَبْسُطْ أَحَدُكُمْ ذِرَاعَيْهِ انْبِسَاطَ الْكَلْبِ ‏"‏‏.‏\hadithno{822}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Be straight in the prostrations and none of you should put his forearms on the ground (in the prostration) like a dog}}
\hadithdefcmd{bukhari}{823}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، قَالَ أَخْبَرَنَا هُشَيْمٌ، قَالَ أَخْبَرَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، قَالَ أَخْبَرَنَا مَالِكُ بْنُ الْحُوَيْرِثِ اللَّيْثِيُّ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يُصَلِّي، فَإِذَا كَانَ فِي وِتْرٍ مِنْ صَلاَتِهِ لَمْ يَنْهَضْ حَتَّى يَسْتَوِيَ قَاعِدًا‏.‏\hadithno{823}\hadithtrans{Narrated Malik bin Huwairith Al-Laithi:I saw the Prophet (ﷺ) praying and in the odd rak`at, he used to sit for a moment before getting up}}
\hadithdefcmd{bukhari}{824}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، قَالَ جَاءَنَا مَالِكُ بْنُ الْحُوَيْرِثِ فَصَلَّى بِنَا فِي مَسْجِدِنَا هَذَا فَقَالَ إِنِّي لأُصَلِّي بِكُمْ، وَمَا أُرِيدُ الصَّلاَةَ، وَلَكِنْ أُرِيدُ أَنْ أُرِيَكُمْ كَيْفَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُصَلِّي‏.‏ قَالَ أَيُّوبُ فَقُلْتُ لأَبِي قِلاَبَةَ وَكَيْفَ كَانَتْ صَلاَتُهُ قَالَ مِثْلَ صَلاَةِ شَيْخِنَا هَذَا ـ يَعْنِي عَمْرَو بْنَ سَلِمَةَ ـ قَالَ أَيُّوبُ وَكَانَ ذَلِكَ الشَّيْخُ يُتِمُّ التَّكْبِيرَ، وَإِذَا رَفَعَ رَأْسَهُ عَنِ السَّجْدَةِ الثَّانِيَةِ جَلَسَ وَاعْتَمَدَ عَلَى الأَرْضِ، ثُمَّ قَامَ‏.‏\hadithno{824}\hadithtrans{Narrated Aiyub:Abu Qilaba said, "Malik bin Huwairith came to us and led us in the prayer in this mosque of ours and said, 'I lead you in prayer but I do not want to offer the prayer but just to show you how Allah's Apostle performed his prayers." I asked Abu Qilaba, "How was the prayer of Malik bin Huwairith?" He replied, "Like the prayer of this Sheikh of ours-- i.e. `Amr bin Salima." That Sheikh used to pronounce the Takbir perfectly and when he raised his head from the second prostration he would sit for a while and then support himself on the ground and get up}}
\hadithdefcmd{bukhari}{825}{حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، قَالَ حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ الْحَارِثِ، قَالَ صَلَّى لَنَا أَبُو سَعِيدٍ فَجَهَرَ بِالتَّكْبِيرِ حِينَ رَفَعَ رَأْسَهُ مِنَ السُّجُودِ، وَحِينَ سَجَدَ، وَحِينَ رَفَعَ، وَحِينَ قَامَ مِنَ الرَّكْعَتَيْنِ وَقَالَ هَكَذَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{825}\hadithtrans{Narrated Sa`id bin Al-Harith:Abu Sa`id led us in the prayer and said the Takbir aloud on arising from the prostration, and on prostrating, on rising again, and on getting up from the second rak`a. Abu Sa`id said, "I saw the Prophet doing the same}}
\hadithdefcmd{bukhari}{826}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ مُطَرِّفٍ، قَالَ صَلَّيْتُ أَنَا وَعِمْرَانُ، صَلاَةً خَلْفَ عَلِيِّ بْنِ أَبِي طَالِبٍ ـ رضى الله عنه ـ فَكَانَ إِذَا سَجَدَ كَبَّرَ، وَإِذَا رَفَعَ كَبَّرَ، وَإِذَا نَهَضَ مِنَ الرَّكْعَتَيْنِ كَبَّرَ، فَلَمَّا سَلَّمَ أَخَذَ عِمْرَانُ بِيَدِي فَقَالَ لَقَدْ صَلَّى بِنَا هَذَا صَلاَةَ مُحَمَّدٍ صلى الله عليه وسلم‏.‏ أَوْ قَالَ لَقَدْ ذَكَّرَنِي هَذَا صَلاَةَ مُحَمَّدٍ صلى الله عليه وسلم‏.‏\hadithno{826}\hadithtrans{Narrated Mutarrif:`Imran and I prayed behind `Ali bin Abi Talib and he said Takbir on prostrating, on rising and on getting up after the two rak`at (i.e. after the second rak`a). When the prayer was finished, `Imran took me by the hand and said, "He (`Ali) has prayed the prayer of Muhammad" (or said, "He made us remember the prayer of Muhammad)}}
\hadithdefcmd{bukhari}{827}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، كَانَ يَرَى عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ يَتَرَبَّعُ فِي الصَّلاَةِ إِذَا جَلَسَ، فَفَعَلْتُهُ وَأَنَا يَوْمَئِذٍ حَدِيثُ السِّنِّ، فَنَهَانِي عَبْدُ اللَّهِ بْنُ عُمَرَ وَقَالَ إِنَّمَا سُنَّةُ الصَّلاَةِ أَنْ تَنْصِبَ رِجْلَكَ الْيُمْنَى وَتَثْنِيَ الْيُسْرَى‏.‏ فَقُلْتُ إِنَّكَ تَفْعَلُ ذَلِكَ‏.‏ فَقَالَ إِنَّ رِجْلَىَّ لاَ تَحْمِلاَنِي‏.‏\hadithno{827}\hadithtrans{Narrated `Abdullah bin `Abdullah:I saw `Abdullah bin `Umar crossing his legs while sitting in the prayer and I, a mere youngster in those days, did the same. Ibn `Umar forbade me to do so, and said, "The proper way is to keep the right foot propped up and bend the left in the prayer." I said questioningly, "But you are doing so (crossing the legs)." He said, "My feet cannot bear my weight}}
\hadithdefcmd{bukhari}{828}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدٍ، عَنْ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ،‏.‏ وَحَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، وَيَزِيدَ بْنِ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، أَنَّهُ كَانَ جَالِسًا مَعَ نَفَرٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَذَكَرْنَا صَلاَةَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَبُو حُمَيْدٍ السَّاعِدِيُّ أَنَا كُنْتُ أَحْفَظَكُمْ لِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم رَأَيْتُهُ إِذَا كَبَّرَ جَعَلَ يَدَيْهِ حِذَاءَ مَنْكِبَيْهِ، وَإِذَا رَكَعَ أَمْكَنَ يَدَيْهِ مِنْ رُكْبَتَيْهِ، ثُمَّ هَصَرَ ظَهْرَهُ، فَإِذَا رَفَعَ رَأْسَهُ اسْتَوَى حَتَّى يَعُودَ كُلُّ فَقَارٍ مَكَانَهُ، فَإِذَا سَجَدَ وَضَعَ يَدَيْهِ غَيْرَ مُفْتَرِشٍ وَلاَ قَابِضِهِمَا، وَاسْتَقْبَلَ بِأَطْرَافِ أَصَابِعِ رِجْلَيْهِ الْقِبْلَةَ، فَإِذَا جَلَسَ فِي الرَّكْعَتَيْنِ جَلَسَ عَلَى رِجْلِهِ الْيُسْرَى وَنَصَبَ الْيُمْنَى، وَإِذَا جَلَسَ فِي الرَّكْعَةِ الآخِرَةِ قَدَّمَ رِجْلَهُ الْيُسْرَى وَنَصَبَ الأُخْرَى وَقَعَدَ عَلَى مَقْعَدَتِهِ‏.‏ وَسَمِعَ اللَّيْثُ يَزِيدَ بْنَ أَبِي حَبِيبٍ وَيَزِيدُ مِنْ مُحَمَّدِ بْنِ حَلْحَلَةَ وَابْنُ حَلْحَلَةَ مِنَ ابْنِ عَطَاءٍ‏.‏ قَالَ أَبُو صَالِحٍ عَنِ اللَّيْثِ كُلُّ فَقَارٍ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ عَنْ يَحْيَى بْنِ أَيُّوبَ قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ أَنَّ مُحَمَّدَ بْنَ عَمْرٍو حَدَّثَهُ كُلُّ فَقَارٍ‏.‏\hadithno{828}\hadithtrans{Narrated Muhammad bin `Amr bin `Ata':I was sitting with some of the companions of Allah's Messenger (ﷺ) and we were discussing about the way of praying of the Prophet. Abu Humaid As-Sa`idi said, "I remember the prayer of Allah's Messenger (ﷺ) better than any one of you. I saw him raising both his hands up to the level of the shoulders on saying the Takbir; and on bowing he placed his hands on both knees and bent his back straight, then he stood up straight from bowing till all the vertebrate took their normal positions. In prostrations, he placed both his hands on the ground with the forearms away from the ground and away from his body, and his toes were facing the Qibla. On sitting In the second rak`a he sat on his left foot and propped up the right one; and in the last rak`a he pushed his left foot forward and kept the other foot propped up and sat over the buttocks}}
\hadithdefcmd{bukhari}{829}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ هُرْمُزَ، مَوْلَى بَنِي عَبْدِ الْمُطَّلِبِ ـ وَقَالَ مَرَّةً مَوْلَى رَبِيعَةَ بْنِ الْحَارِثِ ـ أَنَّ عَبْدَ اللَّهِ ابْنَ بُحَيْنَةَ ـ وَهْوَ مِنْ أَزْدِ شَنُوءَةَ وَهْوَ حَلِيفٌ لِبَنِي عَبْدِ مَنَافٍ، وَكَانَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم‏.‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِهِمُ الظُّهْرَ فَقَامَ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ لَمْ يَجْلِسْ، فَقَامَ النَّاسُ مَعَهُ حَتَّى إِذَا قَضَى الصَّلاَةَ، وَانْتَظَرَ النَّاسُ تَسْلِيمَهُ، كَبَّرَ وَهْوَ جَالِسٌ، فَسَجَدَ سَجْدَتَيْنِ قَبْلَ أَنْ يُسَلِّمَ ثُمَّ سَلَّمَ‏.‏\hadithno{829}\hadithtrans{Narrated `Abdullah bin Buhaina:(he was from the tribe of Uzd Shanu'a [??] and was the ally of the tribe of `Abdul-Manaf and was one of the companions of the Prophet): Once the Prophet (ﷺ) led us in the Zuhr prayer and stood up after the second rak`a and did not sit down. The people stood up with him. When the prayer was about to end and the people were waiting for him to say the Taslim, he said Takbir while sitting and prostrated twice before saying the Taslim and then he said the Taslim}}
\hadithdefcmd{bukhari}{830}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا بَكْرٌ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ ابْنِ بُحَيْنَةَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ فَقَامَ وَعَلَيْهِ جُلُوسٌ، فَلَمَّا كَانَ فِي آخِرِ صَلاَتِهِ سَجَدَ سَجْدَتَيْنِ وَهْوَ جَالِسٌ‏.‏\hadithno{830}\hadithtrans{Narrated `Abdullah bin Malik bin Buhaina:Once Allah's Messenger (ﷺ) led us in the Zuhr prayer and got up (after the prostrations of the second rak`a) although he should have sat (for the Tashahhud). So at the end of the prayer, he prostrated twice while sitting (prostrations of Sahu)}}
\hadithdefcmd{bukhari}{831}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، قَالَ قَالَ عَبْدُ اللَّهِ كُنَّا إِذَا صَلَّيْنَا خَلْفَ النَّبِيِّ صلى الله عليه وسلم قُلْنَا السَّلاَمُ عَلَى جِبْرِيلَ وَمِيكَائِيلَ، السَّلاَمُ عَلَى فُلاَنٍ وَفُلاَنٍ‏.‏ فَالْتَفَتَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ اللَّهَ هُوَ السَّلاَمُ، فَإِذَا صَلَّى أَحَدُكُمْ فَلْيَقُلِ التَّحِيَّاتُ لِلَّهِ، وَالصَّلَوَاتُ وَالطَّيِّبَاتُ، السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ‏.‏ فَإِنَّكُمْ إِذَا قُلْتُمُوهَا أَصَابَتْ كُلَّ عَبْدٍ لِلَّهِ صَالِحٍ فِي السَّمَاءِ وَالأَرْضِ، أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏‏.‏\hadithno{831}\hadithtrans{Narrated Shaqiq bin Salama:`Abdullah said, "Whenever we prayed behind the Prophet (ﷺ) we used to recite (in sitting) 'Peace be on Gabriel, Michael, peace be on so and so. Once Allah's Messenger (ﷺ) looked back at us and said, 'Allah Himself is As-Salam (Peace), and if anyone of you prays then he should say, at-Tahiyatu li l-lahi wa ssalawatu wa t-taiyibat. As-salamu `alalika aiyuha n-Nabiyu wa rahmatu l-lahi wa barakatuh. Assalamu `alaina wa `ala `ibadi l-lahi s-salihin. (All the compliments, prayers and good things are due to Allah; peace be on you, O Prophet, and Allah's mercy and blessings [be on you]. Peace be on us an on the pious subjects of Allah). (If you say that, it will reach all the subjects in the heaven and the earth). Ash-hadu al-la ilaha illa l-lah, wa ash-hadu anna Muhammadan `Abduhu wa Rasuluh. (I testify that there is no Deity [worthy of worship] but Allah, and I testify that Muhammad is His slave and His Apostle}}
\hadithdefcmd{bukhari}{833}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنَا عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو فِي الصَّلاَةِ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَفِتْنَةِ الْمَمَاتِ، اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْمَأْثَمِ وَالْمَغْرَمِ ‏"‏‏.‏ فَقَالَ لَهُ قَائِلٌ مَا أَكْثَرَ مَا تَسْتَعِيذُ مِنَ الْمَغْرَمِ فَقَالَ ‏"‏ إِنَّ الرَّجُلَ إِذَا غَرِمَ حَدَّثَ فَكَذَبَ، وَوَعَدَ فَأَخْلَفَ ‏"‏‏.‏ وَعَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَعِيذُ فِي صَلاَتِهِ مِنْ فِتْنَةِ الدَّجَّالِ\hadithno{833}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Allah's Messenger (ﷺ) used to invoke Allah in the prayer saying "Allahumma inni a`udhu bika min `adhabi l-qabr, wa a`udhu bika min fitnati l-masihi d-dajjal, wa a`udhu bika min fitnati l-mahya wa fitnati l-mamat. Allahumma inni a`udhu bika mina l-ma'thami wa l-maghram. (O Allah, I seek refuge with You from the punishment of the grave, from the afflictions of the imposter- Messiah, and from the afflictions of life and death. O Allah, I seek refuge with You from sins and from debt)." Somebody said to him, "Why do you so frequently seek refuge with Allah from being in debt?" The Prophet (ﷺ) replied, "A person in debt tells lies whenever he speaks, and breaks promises whenever he makes (them)." `Aisha also narrated: I heard Allah's Messenger (ﷺ) in his prayer seeking refuge with Allah from the afflictions of Ad-Dajjal}}
\hadithdefcmd{bukhari}{834}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ ـ رضى الله عنه ـ‏.‏ أَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم عَلِّمْنِي دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي‏.‏ قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي ظَلَمْتُ نَفْسِي ظُلْمًا كَثِيرًا ��َلاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ، فَاغْفِرْ لِي مَغْفِرَةً مِنْ عِنْدِكَ، وَارْحَمْنِي إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏‏.‏\hadithno{834}\hadithtrans{Narrated Abu Bakr As-Siddiq:I asked Allah's Messenger (ﷺ) to teach me an invocation so that I may invoke Allah with it in my prayer. He told me to say, "Allahumma inni zalumtu nafsi zulman kathiran, Wala yaghfiru dh-dhunuba illa anta, fa ghfir li maghfiratan min `indika, wa r-hamni, innaka anta l-ghafuru r-rahim (O Allah! I have done great injustice to myself and none except You forgives sins, so bestow on me a forgiveness from You, and Have Mercy on me, You are the Forgiver, the Merciful)}}
\hadithdefcmd{bukhari}{835}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ الأَعْمَشِ، حَدَّثَنِي شَقِيقٌ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا إِذَا كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الصَّلاَةِ قُلْنَا السَّلاَمُ عَلَى اللَّهِ مِنْ عِبَادِهِ، السَّلاَمُ عَلَى فُلاَنٍ وَفُلاَنٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَقُولُوا السَّلاَمُ عَلَى اللَّهِ‏.‏ فَإِنَّ اللَّهَ هُوَ السَّلاَمُ، وَلَكِنْ قُولُوا التَّحِيَّاتُ لِلَّهِ، وَالصَّلَوَاتُ وَالطَّيِّبَاتُ، السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ‏.‏ فَإِنَّكُمْ إِذَا قُلْتُمْ أَصَابَ كُلَّ عَبْدٍ فِي السَّمَاءِ أَوْ بَيْنَ السَّمَاءِ وَالأَرْضِ، أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ، ثُمَّ يَتَخَيَّرُ مِنَ الدُّعَاءِ أَعْجَبَهُ إِلَيْهِ فَيَدْعُو ‏"‏‏.‏\hadithno{835}\hadithtrans{Narrated `Abdullah:When we prayed with the Prophet (ﷺ) we used to say, "Peace be on Allah from His slaves and peace be on so and so." The Prophet (ﷺ) said, "Don't say As-Salam be on Allah, for He Himself is As-Salam, but say, at-tahiyatu li l-lahi wa s-salawatu wa t-taiyibat. As-salamu `alaika aiyuha n-Nabiyu wa rahmatu l-lahi wa barakatuh. As-salamu `alaina wa `ala `ibadi l-lahi s-salihin. (If you say this then it will reach all the slaves in heaven or between heaven and earth). Ash-hadu al la-ilaha illa l-lah, wa ash-hadu anna Muhammadan `Abduhu wa Rasuluh.' Then select the invocation you like best and recite it." (See Hadith No)}}
\hadithdefcmd{bukhari}{836}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ فَقَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْجُدُ فِي الْمَاءِ وَالطِّينِ حَتَّى رَأَيْتُ أَثَرَ الطِّينِ فِي جَبْهَتِهِ‏.‏\hadithno{836}\hadithtrans{Narrated Abu Sa`id Al-Khudri:I saw Allah's Messenger (ﷺ) prostrating in mud and water and saw the mark of mud on his forehead}}
\hadithdefcmd{bukhari}{837}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ هِنْدٍ بِنْتِ الْحَارِثِ، أَنَّ أُمَّ سَلَمَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَلَّمَ قَامَ النِّسَاءُ حِينَ يَقْضِي تَسْلِيمَهُ، وَمَكَثَ يَسِيرًا قَبْلَ أَنْ يَقُومَ‏.‏ قَالَ ابْنُ شِهَابٍ فَأُرَى ـ وَاللَّهُ أَعْلَمُ ـ أَنَّ مُكْثَهُ لِكَىْ يَنْفُذَ النِّسَاءُ قَبْلَ أَنْ يُدْرِكَهُنَّ مَنِ انْصَرَفَ مِنَ الْقَوْمِ‏.‏\hadithno{837}\hadithtrans{Narrated Um Salama:Whenever Allah's Messenger (ﷺ) finished his prayers with Taslim, the women would get up and he would stay on for a while in his place before getting up. Ibn Shihab said, "I think (and Allah knows better), that the purpose of his stay was that the women might leave before the men who had finished their prayer}}
\hadithdefcmd{bukhari}{838}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، عَنْ عِتْبَانَ، قَالَ صَلَّيْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فَسَلَّمْنَا حِينَ سَلَّمَ‏.‏\hadithno{838}\hadithtrans{Narrated `Itban bin Malik:We prayed with the Prophet (ﷺ) and used to finish our prayer with the Taslim along with him}}
\hadithdefcmd{bukhari}{840}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ،، وَزَعَمَ، أَنَّهُ عَقَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَعَقَلَ مَجَّةً مَجَّهَا مِنْ دَلْوٍ كَانَ فِي دَارِهِمْ‏.‏ قَالَ سَمِعْتُ عِتْبَانَ بْنَ مَالِكٍ الأَنْصَارِيَّ، ثُمَّ أَحَدَ بَنِي سَالِمٍ قَالَ كُنْتُ أُصَلِّي لِقَوْمِي بَنِي سَالِمٍ، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ إِنِّي أَنْكَرْتُ بَصَرِي، وَإِنَّ السُّيُولَ تَحُولُ بَيْنِي وَبَيْنَ مَسْجِدِ قَوْمِي، فَلَوَدِدْتُ أَنَّكَ جِئْتَ فَصَلَّيْتَ فِي بَيْتِي مَكَانًا، حَتَّى أَتَّخِذَهُ مَسْجِدًا فَقَالَ ‏"‏ أَفْعَلُ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ فَغَدَا عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ مَعَهُ بَعْدَ مَا اشْتَدَّ النَّهَارُ، فَاسْتَأْذَنَ النَّبِيُّ صلى الله عليه وسلم فَأَذِنْتُ لَهُ، فَلَمْ يَجْلِسْ حَتَّى قَالَ ‏"‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ مِنْ بَيْتِكَ ‏"‏‏.‏ فَأَشَارَ إِلَيْهِ مِنَ الْمَكَانِ الَّذِي أَحَبَّ أَنْ يُصَلِّيَ فِيهِ، فَقَامَ فَصَفَفْنَا خَلْفَهُ ثُمَّ سَلَّمَ، وَسَلَّمْنَا حِينَ سَلَّمَ‏.‏\hadithno{840}\hadithtrans{Narrated Mahmud bin Ar-Rabi`:I remember Allah's Messenger (ﷺ) and also the mouthful of water which he took from a bucket in our house and ejected (on me). I heard from `Itban bin Malik Al-Ansari, who was one from Bani Salim, saying, "I used to lead my tribe of Bani Salim in prayer. Once I went to the Prophet (ﷺ) and said to him, 'I have weak eyesight and at times the rainwater flood intervenes between me and the mosque of my tribe and I wish that you would come to my house and pray at some place so that I could take that place as a place for praying (mosque). He said, "Allah willing, I shall do that." Next day Allah's Messenger (ﷺ) along with Abu Bakr, came to my house after the sun had risen high and he asked permission to enter. I gave him permission, but he didn't sit till he said to me, "Where do you want me to pray in your house?" I pointed to a place in the house where I wanted him to pray. So he stood up for the prayer and we aligned behind him. He completed the prayer with Taslim and we did the same simultaneously}}
\hadithdefcmd{bukhari}{841}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ أَبَا مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ أَخْبَرَهُ أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَفْعَ الصَّوْتِ بِالذِّكْرِ حِينَ يَنْصَرِفُ النَّاسُ مِنَ الْمَكْتُوبَةِ كَانَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ ابْنُ عَبَّاسٍ كُنْتُ أَعْلَمُ إِذَا انْصَرَفُوا بِذَلِكَ إِذَا سَمِعْتُهُ‏.‏\hadithno{841}\hadithtrans{Narrated Abu Ma`bad:(the freed slave of Ibn `Abbas) Ibn `Abbas told me, "In the lifetime of the Prophet (ﷺ) it was the custom to celebrate Allah's praises aloud after the compulsory congregational prayers." Ibn `Abbas further said, "When I heard the Dhikr, I would learn that the compulsory congregational prayer had ended}}
\hadithdefcmd{bukhari}{842}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، ‏\{‏عَنْ عَمْرٍو،‏\}‏ قَالَ أَخْبَرَنِي أَبُو مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كُنْتُ أَعْرِفُ انْقِضَاءَ صَلاَةِ النَّبِيِّ صلى الله عليه وسلم بِالتَّكْبِيرِ‏.‏\hadithno{842}\hadithtrans{Narrated Ibn `Abbas:I used to recognize the completion of the prayer of the Prophet (ﷺ) by hearing Takbir}}
\hadithdefcmd{bukhari}{843}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، قَالَ حَدَّثَنَا مُعْتَمِرٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ جَاءَ الْفُقَرَاءُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا ذَهَبَ أَهْلُ الدُّثُورِ مِنَ الأَمْوَالِ بِالدَّرَجَاتِ الْعُلاَ وَالنَّعِيمِ الْمُقِيمِ، يُصَلُّونَ كَمَا نُصَلِّي، وَيَصُومُونَ كَمَا نَصُومُ، وَلَهُمْ فَضْلٌ مِنْ أَمْوَالٍ يَحُجُّونَ بِهَا، وَيَعْتَمِرُونَ، وَيُجَاهِدُونَ، وَيَتَصَدَّقُونَ قَالَ ‏"‏ أَلاَ أُحَدِّثُكُمْ بِأَمْرٍ إِنْ أَخَذْتُمْ بِهِ أَدْرَكْتُمْ مَنْ سَبَقَكُمْ وَلَمْ يُدْرِكْكُمْ أَحَدٌ بَعْدَكُمْ، وَكُنْتُمْ خَيْرَ مَنْ أَنْتُمْ بَيْنَ ظَهْرَانَيْهِ، إِلاَّ مَنْ عَمِلَ مِثْلَهُ تُسَبِّحُونَ وَتَحْمَدُونَ، وَتُكَبِّرُونَ خَلْفَ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ ‏"‏‏.‏ فَاخْتَلَفْنَا بَيْنَنَا فَقَالَ بَعْضُنَا نُسَبِّحُ ثَلاَثًا وَثَلاَثِينَ، وَنَحْمَدُ ثَلاَثًا وَثَلاَثِينَ، وَنُكَبِّرُ أَرْبَعًا وَثَلاَثِينَ‏.‏ فَرَجَعْتُ إِلَيْهِ فَقَالَ ‏"‏ تَقُولُ سُبْحَانَ اللَّهِ، وَالْحَمْدُ لِلَّهِ، وَاللَّهُ أَكْبَرُ، حَتَّى يَكُونَ مِنْهُنَّ كُلِّهِنَّ ثَلاَثًا وَثَلاَثِينَ ‏"‏‏.‏\hadithno{843}\hadithtrans{Narrated Abu Huraira:Some poor people came to the Prophet (ﷺ) and said, "The wealthy people will get higher grades and will have permanent enjoyment and they pray like us and fast as we do. They have more money by which they perform the Hajj, and `Umra; fight and struggle in Allah's Cause and give in charity." The Prophet said, "Shall I not tell you a thing upon which if you acted you would catch up with those who have surpassed you? Nobody would overtake you and you would be better than the people amongst whom you live except those who would do the same. Say "Subhana l-lah", "Al hamdu li l-lah" and "Allahu Akbar" thirty three times each after every (compulsory) prayer." We differed and some of us said that we should say, "Subhan-al-lah" thirty three times and "Al hamdu li l-lah" thirty three times and "Allahu Akbar" thirty four times. I went to the Prophet (ﷺ) who said, "Say, "Subhan-al-lah" and "Al hamdu li l-lah" and "Allahu Akbar" all together [??], thirty three times}}
\hadithdefcmd{bukhari}{844}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ وَرَّادٍ، كَاتِبِ الْمُغِيرَةِ بْنِ شُعْبَةَ قَالَ أَمْلَى عَلَىَّ الْمُغِيرَةُ بْنُ شُعْبَةَ فِي كِتَابٍ إِلَى مُعَاوِيَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ فِي دُبُرِ كُلِّ صَلاَةٍ مَكْتُوبَةٍ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ، وَلَهُ الْحَمْدُ، وَهْوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ، اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ، وَلاَ مُعْطِيَ لِمَا مَنَعْتَ، وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏‏.‏ وَقَالَ شُعْبَةُ عَنْ عَبْدِ الْمَلِكِ بِهَذَا، وَعَنِ الْحَكَمِ عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ عَنْ وَرَّادٍ بِهَذَا‏.‏ وَقَالَ الْحَسَنُ الْجَدُّ غِنًى‏.‏\hadithno{844}\hadithtrans{Narrated Warrad:(the clerk of Al-Mughira bin Shu`ba) Once Al-Mughira dictated to me in a letter addressed to Muawiya that the Prophet (ﷺ) used to say after every compulsory prayer, "La ilaha illa l-lahu wahdahu la sharika lahu, lahu l-mulku wa lahu l-hamdu, wa huwa `ala kulli shay'in qadir. Allahumma la mani`a lima a`taita, wa la mu`tiya lima mana`ta, wa la yanfa`u dhal-jaddi minka l-jadd. [There is no Deity but Allah, Alone, no Partner to Him. His is the Kingdom and all praise, and Omnipotent is He. O Allah! Nobody can hold back what you gave, nobody can give what You held back, and no struggler's effort can benefit against You]." And Al-Hasan said, "Al-jadd' means prosperity [??]}}
\hadithdefcmd{bukhari}{845}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى صَلاَةً أَقْبَلَ عَلَيْنَا بِوَجْهِهِ‏.‏\hadithno{845}\hadithtrans{Narrated Samura bin Jundub:The Prophet (ﷺ) used to face us on completion of the prayer}}
\hadithdefcmd{bukhari}{846}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الصُّبْحِ بِالْحُدَيْبِيَةِ عَلَى إِثْرِ سَمَاءٍ كَانَتْ مِنَ اللَّيْلَةِ، فَلَمَّا انْصَرَفَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ هَلْ تَدْرُونَ مَاذَا قَالَ رَبُّكُمْ ‏"‏‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ أَصْبَحَ مِنْ عِبَادِي مُؤْمِنٌ بِي وَكَافِرٌ، فَأَمَّا مَنْ قَالَ مُطِرْنَا بِفَضْلِ اللَّهِ وَرَحْمَتِهِ فَذَلِكَ مُؤْمِنٌ بِي وَكَافِرٌ بِالْكَوْكَبِ، وَأَمَّا مَنْ قَالَ بِنَوْءِ كَذَا وَكَذَا فَذَلِكَ كَافِرٌ بِي وَمُؤْمِنٌ بِالْكَوْكَبِ ‏"‏‏.‏\hadithno{846}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:The Prophet (ﷺ) led us in the Fajr prayer at Hudaibiya after a rainy night. On completion of the prayer, he faced the people and said, "Do you know what your Lord has said (revealed)?" The people replied, "Allah and His Apostle know better." He said, "Allah has said, 'In this morning some of my slaves remained as true believers and some became non-believers; whoever said that the rain was due to the Blessings and the Mercy of Allah had belief in Me and he disbelieves in the stars, and whoever said that it rained because of a particular star had no belief in Me but believes in that star}}
\hadithdefcmd{bukhari}{847}{حَدَّثَنَا عَبْدُ اللَّهِ، سَمِعَ يَزِيدَ، قَالَ أَخْبَرَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ أَخَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الصَّلاَةَ ذَاتَ لَيْلَةٍ إِلَى شَطْرِ اللَّيْلِ ثُمَّ خَرَجَ عَلَيْنَا، فَلَمَّا صَلَّى أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏ "‏ إِنَّ النَّاسَ قَدْ صَلَّوْا وَرَقَدُوا، وَإِنَّكُمْ لَنْ تَزَالُوا فِي صَلاَةٍ مَا انْتَظَرْتُمُ الصَّلاَةَ ‏"‏‏.‏\hadithno{847}\hadithtrans{Narrated Anas bin Malik:Once the Prophet (ﷺ) delayed the `Isha' prayer until midnight and then came to us. Having prayed he faced us and said, "The people had prayed and slept but you were in the prayer as long as you were waiting for it}}
\hadithdefcmd{bukhari}{848}{وَقَالَ لَنَا آدَمُ حَدَّثَنَا شُعْبَةُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ يُصَلِّي فِي مَكَانِهِ الَّذِي صَلَّى فِيهِ الْفَرِيضَةَ‏.‏ وَفَعَلَهُ الْقَاسِمُ‏.‏ وَيُذْكَرُ عَنْ أَبِي هُرَيْرَةَ رَفَعَهُ لاَ يَتَطَوَّعُ الإِمَامُ فِي مَكَانِهِ‏.‏ وَلَمْ يَصِحَّ‏.‏\hadithno{848}\hadithtrans{Narrated Nafi:Ibn Umar used to offer prayers (Nawafil) at the place where he had offered the compulsory prayer. Al-Qasim (bin Muhammad bin Abi Bakr) did the same. The narration coming from Abu Hurairah (from the Prophet (ﷺ)) forbidding the Imam from offering prayers (optional prayer) at the same place where he was offered the compulsory prayer is incorrect}}
\hadithdefcmd{bukhari}{850}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ هِنْدٍ بِنْتِ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا سَلَّمَ يَمْكُثُ فِي مَكَانِهِ يَسِيرًا‏.‏ قَالَ ابْنُ شِهَابٍ فَنُرَى ـ وَاللَّهُ أَعْلَمُ ـ لِكَىْ يَنْفُذَ مَنْ يَنْصَرِفُ مِنَ النِّسَاءِ‏.‏ وَقَالَ ابْنُ أَبِي مَرْيَمَ أَخْبَرَنَا نَافِعُ بْنُ يَزِيدَ، قَالَ أَخْبَرَنِي جَعْفَرُ بْنُ رَبِيعَةَ، أَنَّ ابْنَ شِهَابٍ، كَتَبَ إِلَيْهِ قَالَ حَدَّثَتْنِي هِنْدُ بِنْتُ الْحَارِثِ الْفِرَاسِيَّةُ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَكَانَتْ مِنْ صَوَاحِبَاتِهَا قَالَتْ كَانَ يُسَلِّمُ فَيَنْصَرِفُ النِّسَاءُ، فَيَدْخُلْنَ بُيُوتَهُنَّ مِنْ قَبْلِ أَنْ يَنْصَرِفَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ ابْنُ وَهْبٍ عَنْ يُونُسَ عَنِ ابْنِ شِهَابٍ أَخْبَرَتْنِي هِنْدُ الْفِرَاسِيَّةُ‏.‏ وَقَالَ عُثْمَانُ بْنُ عُمَرَ أَخْبَرَنَا يُونُسُ عَنِ الزُّهْرِيِّ حَدَّثَتْنِي هِنْدُ الْفِرَاسِيَّةُ‏.‏ وَقَالَ الزُّبَيْدِيُّ أَخْبَرَنِي الزُّهْرِيُّ أَنَّ هِنْدَ بِنْتَ الْحَارِثِ الْقُرَشِيَّةَ أَخْبَرَتْهُ، وَكَانَتْ تَحْتَ مَعْبَدِ بْنِ الْمِقْدَادِ ـ وَهْوَ حَلِيفُ بَنِي زُهْرَةَ ـ وَكَانَتْ تَدْخُلُ عَلَى أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ شُعَيْبٌ عَنِ الزُّهْرِيِّ حَدَّثَتْنِي هِنْدُ الْقُرَشِيَّةُ‏.‏ وَقَالَ ابْنُ أَبِي عَتِيقٍ عَنِ الزُّهْرِيِّ عَنْ هِنْدٍ الْفِرَاسِيَّةِ‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ حَدَّثَهُ عَنِ ابْنِ شِهَابٍ عَنِ امْرَأَةٍ مِنْ قُرَيْشٍ حَدَّثَتْهُ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{850}\hadithtrans{Narrated Um Salama:"The Prophet (ﷺ) after finishing the prayer with Taslim used to stay at his place for a while." Ibn Shihab said, "I think (and Allah knows better), that he used to wait for the departure of the women who had prayed." Ibn Shihab wrote that he had heard it from Hind bint Al-Harith Al-Firasiya from Um Salama, the wife of the Prophet (Hind was from the companions of Um Salama) who said, "When the Prophet (ﷺ) finished the prayer with Taslim, the women would depart and enter their houses before Allah's Apostle departed}}
\hadithdefcmd{bukhari}{851}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُمَرَ بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ، قَالَ صَلَّيْتُ وَرَاءَ النَّبِيِّ صلى الله عليه وسلم بِالْمَدِينَةِ الْعَصْرَ فَسَلَّمَ ثُمَّ قَامَ مُسْرِعًا، فَتَخَطَّى رِقَابَ النَّاسِ إِلَى بَعْضِ حُجَرِ نِسَائِهِ، فَفَزِعَ النَّاسُ مِنْ سُرْعَتِهِ فَخَرَجَ عَلَيْهِمْ، فَرَأَى أَنَّهُمْ عَجِبُوا مِنْ سُرْعَتِهِ فَقَالَ ‏ "‏ ذَكَرْتُ شَيْئًا مِنْ تِبْرٍ عِنْدَنَا فَكَرِهْتُ أَنْ يَحْبِسَنِي، فَأَمَرْتُ بِقِسْمَتِهِ ‏"‏‏.‏\hadithno{851}\hadithtrans{Narrated `Uqba:I offered the `Asr prayer behind the Prophet (ﷺ) at Medina. When he had finished the prayer with Taslim, he got up hurriedly and went out by crossing the rows of the people to one of the dwellings of his wives. The people got scared at his speed . The Prophet (ﷺ) came back and found the people surprised at his haste and said to them, "I remembered a piece of gold Lying in my house and I did not like it to divert my attention from Allah's worship, so I have ordered it to be distributed (in charity)}}
\hadithdefcmd{bukhari}{852}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنِ الأَسْوَدِ، قَالَ قَالَ عَبْدُ اللَّهِ لاَ يَجْعَلْ أَحَدُكُمْ لِلشَّيْطَانِ شَيْئًا مِنْ صَلاَتِهِ، يَرَى أَنَّ حَقًّا عَلَيْهِ أَنْ لاَ يَنْصَرِفَ إِلاَّ عَنْ يَمِينِهِ، لَقَدْ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم كَثِيرًا يَنْصَرِفُ عَنْ يَسَارِهِ‏.‏\hadithno{852}\hadithtrans{Narrated `Abdullah:You should not give away a part of your prayer to Satan by thinking that it is necessary to depart (after finishing the prayer) from one's right side only; I have seen the Prophet (ﷺ) often leave from the left side}}
\hadithdefcmd{bukhari}{853}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ فِي غَزْوَةِ خَيْبَرَ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ ـ يَعْنِي الثُّومَ ـ فَلاَ يَقْرَبَنَّ مَسْجِدَنَا ‏"‏‏.‏\hadithno{853}\hadithtrans{Narrated Ibn `Umar:During the holy battle of Khaibar the Prophet (ﷺ) said, "Whoever ate from this plant (i.e. garlic) should not enter our mosque}}
\hadithdefcmd{bukhari}{854}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ ـ يُرِيدُ الثُّومَ ـ فَلاَ يَغْشَانَا فِي مَسَاجِدِنَا ‏"‏‏.‏ قُلْتُ مَا يَعْنِي بِهِ قَالَ مَا أُرَاهُ يَعْنِي إِلاَّ نِيئَهُ‏.‏ وَقَالَ مَخْلَدُ بْنُ يَزِيدَ عَنِ ابْنِ جُرَيْجٍ إِلاَّ نَتْنَهُ‏.‏\hadithno{854}\hadithtrans{Narrated `Ata':I heard Jabir bin `Abdullah saying, "The Prophet (ﷺ) said, 'Whoever eats (from) this plant (he meant garlic) should keep away from our mosque." I said, "What does he mean by that?" He replied, "I think he means only raw garlic}}
\hadithdefcmd{bukhari}{855}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، زَعَمَ عَطَاءٌ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، زَعَمَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَكَلَ ثُومًا أَوْ بَصَلاً فَلْيَعْتَزِلْنَا ـ أَوْ قَالَ ـ فَلْيَعْتَزِلْ مَسْجِدَنَا، وَلْيَقْعُدْ فِي بَيْتِهِ ‏"‏‏.‏ وَأَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِقِدْرٍ فِيهِ خَضِرَاتٌ مِنْ بُقُولٍ، فَوَجَدَ لَهَا رِيحًا فَسَأَلَ فَأُخْبِرَ بِمَا فِيهَا مِنَ الْبُقُولِ فَقَالَ ‏"‏ قَرِّبُوهَا ‏"‏ إِلَى بَعْضِ أَصْحَابِهِ كَانَ مَعَهُ، فَلَمَّا رَآهُ كَرِهَ أَكْلَهَا قَالَ ‏"‏ كُلْ فَإِنِّي أُنَاجِي مَنْ لاَ تُنَاجِي ‏"‏‏.‏ وَقَالَ أَحْمَدُ بْنُ صَالِحٍ عَنِ ابْنِ وَهْبٍ أُتِيَ بِبَدْرٍ‏.‏ قَالَ ابْنُ وَهْبٍ يَعْنِي طَبَقًا فِيهِ خُضَرَاتٌ‏.‏ وَلَمْ يَذْكُرِ اللَّيْثُ وَأَبُو صَفْوَانَ عَنْ يُونُسَ قِصَّةَ الْقِدْرِ، فَلاَ أَدْرِي هُوَ مِنْ قَوْلِ الزُّهْرِيِّ أَوْ فِي الْحَدِيثِ‏.‏\hadithno{855}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "Whoever eats garlic or onion should keep away from our mosque or should remain in his house." (Jabir bin `Abdullah, in another narration said, "Once a big pot containing cooked vegetables was brought. On finding unpleasant smell coming from it, the Prophet (ﷺ) asked, 'What is in it?' He was told all the names of the vegetables that were in it. The Prophet (ﷺ) ordered that it should be brought near to some of his companions who were with him. When the Prophet (ﷺ) saw it he disliked to eat it and said, 'Eat. (I don't eat) for I converse with those whom you don't converse with (i.e. the angels)}}
\hadithdefcmd{bukhari}{856}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، قَالَ سَأَلَ رَجُلٌ أَنَسًا مَا سَمِعْتَ نَبِيَّ اللَّهِ صلى الله عليه وسلم فِي الثُّومِ فَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ فَلاَ يَقْرَبْنَا، أَوْ لاَ يُصَلِّيَنَّ مَعَنَا ‏"‏‏.‏\hadithno{856}\hadithtrans{Narrated `Abdul `Aziz:A man asked Anas, "What did you hear from the Prophet (ﷺ) about garlic?" He said, "The Prophet (ﷺ) said, 'Whoever has eaten this plant should neither come near us nor pray with us}}
\hadithdefcmd{bukhari}{857}{حَدَّثَنَا ابْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ سُلَيْمَانَ الشَّيْبَانِيَّ، قَالَ سَمِعْتُ الشَّعْبِيَّ، قَالَ أَخْبَرَنِي مَنْ، مَرَّ مَعَ النَّبِيِّ صلى الله عليه وسلم عَلَى قَبْرٍ مَنْبُوذٍ، فَأَمَّهُمْ وَصَفُّوا عَلَيْهِ‏.‏ فَقُلْتُ يَا أَبَا عَمْرٍو مَنْ حَدَّثَكَ فَقَالَ ابْنُ عَبَّاسٍ‏.‏\hadithno{857}\hadithtrans{Narrated Sulaiman Ash-Shaibani:I heard Ash-Shu`bi saying, "A person who was accompanying the Prophet (ﷺ) passed by a grave that was separated from the other graves told me that the Prophet (ﷺ) once led the people in the (funeral) prayer and the people had aligned behind him. I said, "O Aba `Amr! Who told you about it?" He said, "Ibn `Abbas}}
\hadithdefcmd{bukhari}{858}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي صَفْوَانُ بْنُ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْغُسْلُ يَوْمَ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏‏.‏\hadithno{858}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Ghusl (taking a bath) on Friday is compulsory for every Muslim reaching the age of puberty}}
\hadithdefcmd{bukhari}{859}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ أَخْبَرَنِي كُرَيْبٌ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ لَيْلَةً، فَنَامَ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا كَانَ فِي بَعْضِ اللَّيْلِ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَوَضَّأَ مِنْ شَنٍّ مُعَلَّقٍ وُضُوءًا خَفِيفًا ـ يُخَفِّفُهُ عَمْرٌو وَيُقَلِّلُهُ جِدًّا ـ ثُمَّ قَامَ يُصَلِّي، فَقُمْتُ فَتَوَضَّأْتُ نَحْوًا مِمَّا تَوَضَّأَ، ثُمَّ جِئْتُ فَقُمْتُ عَنْ يَسَارِهِ، فَحَوَّلَنِي فَجَعَلَنِي عَنْ يَمِينِهِ، ثُمَّ صَلَّى مَا شَاءَ اللَّهُ، ثُمَّ اضْطَجَعَ فَنَامَ حَتَّى نَفَخَ، فَأَتَاهُ الْمُنَادِي يُؤْذِنُهُ بِالصَّلاَةِ فَقَامَ مَعَهُ إِلَى الصَّلاَةِ، فَصَلَّى وَلَمْ يَتَوَضَّأْ‏.‏ قُلْنَا لِعَمْرٍو إِنَّ نَاسًا يَقُولُونَ إِنَّ النَّبِيَّ صلى الله عليه وسلم تَنَامُ عَيْنُهُ وَلاَ يَنَامُ قَلْبُهُ‏.‏ قَالَ عَمْرٌو سَمِعْتُ عُبَيْدَ بْنَ عُمَيْرٍ يَقُولُ إِنَّ رُؤْيَا الأَنْبِيَاءِ وَحْىٌ ثُمَّ قَرَأَ ‏\{‏إِنِّي أَرَى فِي الْمَنَامِ أَنِّي أَذْبَحُكَ‏\}‏‏.‏\hadithno{859}\hadithtrans{Narrated Ibn `Abbas:One night I slept at the house of my aunt Maimuna and the Prophet (ﷺ) slept (too). He got up (for prayer) in the last hours of the night and performed a light ablution from a hanging leather skin. (`Amr, the sub-narrator described that the ablution was very light). Then he stood up for prayer and I got up too and performed the ablution in the same way and joined him on his left side. He pulled me to the right and prayed as much as Allah will. Then he lay down and slept and I heard his breath sounds till the Mu'adh-dhin came to him to inform him about the (Fajr) prayer. He left with him for the prayer and prayed without repeating the ablution. (Sufyan the sub-narrator said: We said to `Amr, "Some people say, 'The eyes of the Prophet (ﷺ) sleep but his heart never sleeps.' " `Amr said, "'Ubai bin `Umar said, 'The dreams of the Prophets are Divine Inspirations. Then he recited, '(O my son), I have seen in dream that I was slaughtering you (offering you in sacrifice)}}
\hadithdefcmd{bukhari}{860}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ جَدَّتَهُ، مُلَيْكَةَ دَعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ صَنَعَتْهُ، فَأَكَلَ مِنْهُ فَقَالَ ‏ "‏ قُومُوا فَلأُصَلِّيَ بِكُمْ ‏"‏‏.‏ فَقُمْتُ إِلَى حَصِيرٍ لَنَا قَدِ اسْوَدَّ مِنْ طُولِ مَا لُبِسَ، فَنَضَحْتُهُ بِمَاءٍ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْيَتِيمُ مَعِي، وَالْعَجُوزُ مِنْ وَرَائِنَا، فَصَلَّى بِنَا رَكْعَتَيْنِ‏.‏\hadithno{860}\hadithtrans{Narrated Anas bin Malik:My grandmother Mulaika invited Allah's Messenger (ﷺ) for a meal which she had prepared specially for him. He ate some of it and said, "Get up. I shall lead you in the prayer." I brought a mat that had become black owing to excessive use and I sprinkled water on it. Allah's Messenger (ﷺ) stood on it and prayed two rak`at; and the orphan was with me (in the first row), and the old lady stood behind us}}
\hadithdefcmd{bukhari}{861}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ قَالَ أَقْبَلْتُ رَاكِبًا عَلَى حِمَارٍ أَتَانٍ وَأَنَا يَوْمَئِذٍ قَدْ نَاهَزْتُ الاِحْتِلاَمَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِالنَّاسِ بِمِنًى إِلَى غَيْرِ جِدَارٍ، فَمَرَرْتُ بَيْنَ يَدَىْ بَعْضِ الصَّفِّ، فَنَزَلْتُ وَأَرْسَلْتُ الأَتَانَ تَرْتَعُ وَدَخَلْتُ فِي الصَّفِّ، فَلَمْ يُنْكِرْ ذَلِكَ عَلَىَّ أَحَدٌ‏.‏\hadithno{861}\hadithtrans{Narrated Ibn `Abbas:Once I came riding a she-ass and I, then, had just attained the age of puberty. Allah's Messenger (ﷺ) was leading the people in prayer at Mina facing no wall. I passed in front of the row and let loose the sheass for grazing and joined the row and no one objected to my deed}}
\hadithdefcmd{bukhari}{862}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، قَالَتْ أَعْتَمَ النَّبِيُّ صلى الله عليه وسلم‏.‏ وَقَالَ عَيَّاشٌ حَدَّثَنَا عَبْدُ الأَعْلَى حَدَّثَنَا مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْعِشَاءِ حَتَّى نَادَاهُ عُمَرُ قَدْ نَامَ النِّسَاءُ وَالصِّبْيَانُ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّهُ لَيْسَ أَحَدٌ مِنْ أَهْلِ الأَرْضِ يُصَلِّي هَذِهِ الصَّلاَةَ غَيْرُكُمْ ‏"‏‏.‏ وَلَمْ يَكُنْ أَحَدٌ يَوْمَئِذٍ يُصَلِّي غَيْرَ أَهْلِ الْمَدِينَةِ‏.‏\hadithno{862}\hadithtrans{Narrated `Aisha:Once Allah's Messenger (ﷺ) delayed the `Isha' prayer till `Umar informed him that the women and children had slept. Then Allah's Messenger (ﷺ) came out and said: "None from amongst the dwellers of earth have prayed this prayer except you." In those days none but the people of Medina prayed}}
\hadithdefcmd{bukhari}{863}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَابِسٍ، سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَهُ رَجُلٌ شَهِدْتَ الْخُرُوجَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ، وَلَوْلاَ مَكَانِي مِنْهُ مَا شَهِدْتُهُ ـ يَعْنِي مِنْ صِغَرِهِ ـ أَتَى الْعَلَمَ الَّذِي عِنْدَ دَارِ كَثِيرِ بْنِ الصَّلْتِ، ثُمَّ خَطَبَ ثُمَّ أَتَى النِّسَاءَ فَوَعَظَهُنَّ وَذَكَّرَهُنَّ وَأَمَرَهُنَّ أَنْ يَتَصَدَّقْنَ فَجَعَلَتِ الْمَرْأَةُ تُهْوِي بِيَدِهَا إِلَى حَلْقِهَا تُلْقِي فِي ثَوْبِ بِلاَلٍ، ثُمَّ أَتَى هُوَ وَبِلاَلٌ الْبَيْتَ‏.‏\hadithno{863}\hadithtrans{Narrated `Abdur Rahman bin `Abis:A person asked Ibn `Abbas, "Have you ever presented yourself at the (`Id) prayer with Allah's Apostle?" He replied, "Yes." And had it not been for my kinship (position) with the Prophet (ﷺ) it would not have been possible for me to do so (for he was too young). The Prophet (ﷺ) went to the mark near the house of Kathir bin As-Salt and delivered a sermon. He then went towards the women. He advised and reminded them and asked them to give alms. So the woman would bring her hand near her neck and take off her necklace and put it in the garment of Bilal. Then the Prophet (ﷺ) and Bilal came to the house}}
\hadithdefcmd{bukhari}{864}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْعَتَمَةِ حَتَّى نَادَاهُ عُمَرُ نَامَ النِّسَاءُ وَالصِّبْيَانُ‏.‏ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَا يَنْتَظِرُهَا أَحَدٌ غَيْرُكُمْ مِنْ أَهْلِ الأَرْضِ ‏"‏‏.‏ وَلاَ يُصَلَّى يَوْمَئِذٍ إِلاَّ بِالْمَدِينَةِ، وَكَانُوا يُصَلُّونَ الْعَتَمَةَ فِيمَا بَيْنَ أَنْ يَغِيبَ الشَّفَقُ إِلَى ثُلُثِ اللَّيْلِ الأَوَّلِ‏.‏\hadithno{864}\hadithtrans{Narrated `Aisha:Once Allah's Messenger (ﷺ) delayed the `Isha' prayer till `Umar informed him that the women and children had slept. The Prophet (ﷺ) came out and said, "None except you from amongst the dwellers of earth is waiting for this prayer." In those days, there was no prayer except in Medina and they used to pray the `Isha' prayer between the disappearance of the twilight and the first third of the night}}
\hadithdefcmd{bukhari}{865}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ حَنْظَلَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَأْذَنَكُمْ نِسَاؤُكُمْ بِاللَّيْلِ إِلَى الْمَسْجِدِ فَأْذَنُوا لَهُنَّ ‏"‏‏.‏ تَابَعَهُ شُعْبَةُ عَنِ الأَعْمَشِ عَنْ مُجَاهِدٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{865}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "If your women ask permission to go to the mosque at night, allow them}}
\hadithdefcmd{bukhari}{866}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَتْنِي هِنْدُ بِنْتُ الْحَارِثِ، أَنَّ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهَا أَنَّ النِّسَاءَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم كُنَّ إِذَا سَلَّمْنَ مِنَ الْمَكْتُوبَةِ قُمْنَ، وَثَبَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَنْ صَلَّى مِنَ الرِّجَالِ مَا شَاءَ اللَّهُ، فَإِذَا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَامَ الرِّجَالُ‏.‏\hadithno{866}\hadithtrans{Narrated Um Salama:(the wife of the Prophet) In the lifetime of Allah's Messenger (ﷺ) the women used to get up when they finished their compulsory prayers with Taslim. The Prophet (ﷺ) and the men would stay on at their places as long as Allah will. When the Prophet (ﷺ) got up, the men would then get up}}
\hadithdefcmd{bukhari}{867}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُصَلِّي الصُّبْحَ، فَيَنْصَرِفُ النِّسَاءُ مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ، مَا يُعْرَفْنَ مِنَ الْغَلَسِ‏.‏\hadithno{867}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) finished the Fajr prayer, the women would leave covered in their sheets and were not recognized owing to the darkness}}
\hadithdefcmd{bukhari}{868}{حَدَّثَنَا مُحَمَّدُ بْنُ مِسْكِينٍ، قَالَ حَدَّثَنَا بِشْرٌ، أَخْبَرَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ الأَنْصَارِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَقُومُ إِلَى الصَّلاَةِ وَأَنَا أُرِيدُ أَنْ أُطَوِّلَ فِيهَا، فَأَسْمَعُ بُكَاءَ الصَّبِيِّ، فَأَتَجَوَّزُ فِي صَلاَتِي كَرَاهِيَةَ أَنْ أَشُقَّ عَلَى أُمِّهِ ‏"‏‏.‏\hadithno{868}\hadithtrans{Narrated `Abdullah bin Abi Qatada Al-Ansari:My father said, "Allah's Messenger (ﷺ) said, "Whenever I stand for prayer, I want to prolong it but on hearing the cries of a child, I would shorten it as I dislike to put its mother in trouble}}
\hadithdefcmd{bukhari}{869}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَوْ أَدْرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا أَحْدَثَ النِّسَاءُ لَمَنَعَهُنَّ كَمَا مُنِعَتْ نِسَاءُ بَنِي إِسْرَائِيلَ‏.‏ قُلْتُ لِعَمْرَةَ أَوَ مُنِعْنَ قَالَتْ نَعَمْ‏.‏\hadithno{869}\hadithtrans{Narrated `Aisha:Had Allah's Messenger (ﷺ) known what the women were doing, he would have forbidden them from going to the mosque as the women of Bani Israel had been forbidden. Yahya bin Sa`id (a sub-narrator) asked `Amra (another sub-narrator), "Were the women of Bani Israel forbidden?" She replied "Yes}}
\hadithdefcmd{bukhari}{870}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ هِنْدٍ بِنْتِ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَلَّمَ قَامَ النِّسَاءُ حِينَ يَقْضِي تَسْلِيمَهُ، وَيَمْكُثُ هُوَ فِي مَقَامِهِ يَسِيرًا قَبْلَ أَنْ يَقُومَ‏.‏ قَالَ نَرَى ـ وَاللَّهُ أَعْلَمُ ـ أَنَّ ذَلِكَ كَانَ لِكَىْ يَنْصَرِفَ النِّسَاءُ قَبْلَ أَنْ يُدْرِكَهُنَّ أَحَدٌ مِنَ الرِّجَالِ‏.‏\hadithno{870}\hadithtrans{Narrated Um Salama:Whenever Allah's Messenger (ﷺ) completed the prayer with Taslim, the women used to get up immediately and Allah's Messenger (ﷺ) would remain at his place for some time before getting up. (The sub-narrator (Az-Zuhri) said, "We think, and Allah knows better, that he did so, so that the women might leave before men could get in touch with them}}
\hadithdefcmd{bukhari}{871}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ إِسْحَاقَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم فِي بَيْتِ أُمِّ سُلَيْمٍ، فَقُمْتُ وَيَتِيمٌ خَلْفَهُ، وَأُمُّ سُلَيْمٍ خَلْفَنَا‏.‏\hadithno{871}\hadithtrans{Narrated Anas:The Prophet (ﷺ) prayed in the house of Um Sulaim; and I, along with an orphan stood behind him while Um Sulaim (stood) behind us}}
\hadithdefcmd{bukhari}{872}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا فُلَيْحٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الصُّبْحَ بِغَلَسٍ فَيَنْصَرِفْنَ نِسَاءُ الْمُؤْمِنِينَ، لاَ يُعْرَفْنَ مِنَ الْغَلَسِ، أَوْ لاَ يَعْرِفُ بَعْضُهُنَّ بَعْضًا‏.‏\hadithno{872}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to offer the Fajr prayer when it was still dark and the believing women used to return (after finishing their prayer) and nobody could recognize them owing to darkness, or they could not recognize one another}}
\hadithdefcmd{bukhari}{873}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ ‏ "‏ إِذَا اسْتَأْذَنَتِ امْرَأَةُ أَحَدِكُمْ فَلاَ يَمْنَعْهَا ‏"‏‏.‏\hadithno{873}\hadithtrans{Narrated Salim bin `Abdullah:My father said, "The Prophet (ﷺ) said, 'If the wife of any one of you asks permission (to go to the mosque) do not forbid her}}
\hadithdefcmd{bukhari}{874}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ إِسْحَاقَ، عَنْ أَنَسٍ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم فِي بَيْتِ أُمِّ سُلَيْمٍ، فَقُمْتُ وَيَتِيمٌ خَلْفَهُ، وَأُمُّ سُلَيْمٍ خَلْفَنَا‏.‏\hadithno{874}\hadithtrans{Narrated Anas:The Prophet (ﷺ) prayed in the house of Um Sulaim; and I, along with an orphan stood behind him while Um Sulaim (stood) behind us}}
\hadithdefcmd{bukhari}{875}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ هِنْدَ بِنْتِ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَلَّمَ قَامَ النِّسَاءُ حِينَ يَقْضِي تَسْلِيمَهُ، وَهُوَ يَمْكُثُ فِي مَقَامِهِ يَسِيرًا قَبْلَ أَنْ يَقُومَ‏.‏ قَالَتْ نُرَى ـ وَاللَّهُ أَعْلَمُ ـ أَنَّ ذَلِكَ كَانَ لِكَىْ يَنْصَرِفَ النِّسَاءُ قَبْلَ أَنْ يُدْرِكَهُنَّ الرِّجَالُ‏.‏\hadithno{875}\hadithtrans{Narrated Umm Salama:Whenever Allah's Messenger (ﷺ) completed the Salat with Taslim, the women used to get up immediately and Allah's Messenger (ﷺ) would remain at his place for sometime before getting up. The sub-narrator (Az-Zuhri) said, "We think, and Allah knows better, that he did so, so that the women might leave before the men could catch up with them}}
