% Auto-generated chapter 27 for nasai
% Hadiths in this chapter: 174

\hadithdefcmd{nasai}{3389}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ السَّرَخْسِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَاسْتَفْتَى عُمَرُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ عَبْدَ اللَّهِ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَقَالَ ‏ "‏ مُرْ عَبْدَ اللَّهِ فَلْيُرَاجِعْهَا ثُمَّ يَدَعْهَا حَتَّى تَطْهُرَ مِنْ حَيْضَتِهَا هَذِهِ ثُمَّ تَحِيضَ حَيْضَةً أُخْرَى فَإِذَا طَهُرَتْ فَإِنْ شَاءَ فَلْيُفَارِقْهَا قَبْلَ أَنْ يُجَامِعَهَا وَإِنْ شَاءَ فَلْيُمْسِكْهَا فَإِنَّهَا الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ عَزَّ وَجَلَّ أَنْ تُطَلَّقَ لَهَا النِّسَاءُ ‏"‏ ‏.‏\hadithno{3389}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi' narrated from 'Abdullah, that he divorced his wife while she was menstruating. 'Umar asked the Messenger of Allah about that and said:"Abdullah has divorced his wife while she was menstruating." He said: "Tell 'Abdullah to take her back, then leave her until she becomes pure from this menstrual period, then menstruates again, then when she becomes pure again, if he wishes he may separate from her before having intercourse with her, or if he wishes he may keep her. This is the time when Allah, the Mighty and Sublime, has stated that women may be divorced}}
\hadithdefcmd{nasai}{3390}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيُمْسِكْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ ثُمَّ تَطْهُرَ ثُمَّ إِنْ شَاءَ أَمْسَكَ بَعْدُ وَإِنْ شَاءَ طَلَّقَ قَبْلَ أَنْ يَمَسَّ فَتِلْكَ الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ عَزَّ وَجَلَّ أَنْ تُطَلَّقَ لَهَا النِّسَاءُ ‏"‏ ‏.‏\hadithno{3390}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that he divorced his wife while she was menstruating, during the time of the Messenger of Allah. 'Umar bin Al-Khattab, may Allah be pleased with him, asked the Messenger of Allah about that, and the Messenger of Allah said:"Tell him to take her back and keep her until she becomes pure, then menstruates again and becomes pure again. Then if he wishes he may keep her, or if he wishes, he may divorce her before he touches (has intercourse with) her. This is the time when Allah, the Mighty and Sublime, has stated that women may be divorced}}
\hadithdefcmd{nasai}{3391}{أَخْبَرَنِي كَثِيرُ بْنُ عُبَيْدٍ، عَنْ مُحَمَّدِ بْنِ حَرْبٍ، قَالَ حَدَّثَنَا الزُّبَيْدِيُّ، قَالَ سُئِلَ الزُّهْرِيُّ كَيْفَ الطَّلاَقُ لِلْعِدَّةِ فَقَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ طَلَّقْتُ امْرَأَتِي فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِيَ حَائِضٌ ‏.‏ فَذَكَرَ ذَلِكَ عُمَرُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَتَغَيَّظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ فَقَالَ ‏ "‏ لِيُرَاجِعْهَا ثُمَّ يُمْسِكْهَا حَتَّى تَحِيضَ حَيْضَةً وَتَطْهُرَ فَإِنْ بَدَا لَهُ أَنْ يُطَلِّقَهَا طَاهِرًا قَبْلَ أَنْ يَمَسَّهَا فَذَاكَ الطَّلاَقُ لِلْعِدَّةِ كَمَا أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَرَاجَعْتُهَا وَحَسِبْتُ لَهَا التَّطْلِيقَةَ الَّتِي طَلَّقْتُهَا ‏.‏\hadithno{3391}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Salim bin 'Abdullah bin 'Umar narrated that 'Abdullah bin 'Umar said:"I divorced my wife during the lifetime of the Messenger of Allah while she was menstruating. 'Umar mentioned that to the Messenger of Allah, and the Messenger of Allah got angry about that and said: 'Let him take her back, then keep her until she has menstruated again and become pure again. Then if he wants to divorce her when she is pure and before he touches her (has intercourse with her), then that is divorce at the prescribed time as Allah, the Mighty and Sublime, has revealed.'" 'Abdullah bin 'Umar said: "So I took her back, but I still counted the divorce that I had issued to her}}
\hadithdefcmd{nasai}{3392}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ تَمِيمٍ، عَنْ حَجَّاجٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ أَيْمَنَ، يَسْأَلُ ابْنَ عُمَرَ وَأَبُو الزُّبَيْرِ يَسْمَعُ كَيْفَ تَرَى فِي رَجُلٍ طَلَّقَ امْرَأَتَهُ حَائِضًا فَقَالَ لَهُ طَلَّقَ عَبْدُ اللَّهِ بْنُ عُمَرَ امْرَأَتَهُ وَهِيَ حَائِضٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عُمَرُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ طَلَّقَ امْرَأَتَهُ وَ هِيَ حَائِضٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِيُرَاجِعْهَا ‏"‏ ‏.‏ فَرَدَّهَا عَلَىَّ قَالَ ‏"‏ إِذَا طَهُرَتْ فَلْيُطَلِّقْ أَوْ لِيُمْسِكْ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏\{‏ يَا أَيُّهَا النَّبِيُّ إِذَا طَلَّقْتُمُ النِّسَاءَ فَطَلِّقُوهُنَّ ‏\}‏ فِي قُبُلِ عِدَّتِهِنَّ ‏.‏\hadithno{3392}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Ayman asked Ibn 'Umar while Abu Az-Zubair was listening:"What did you think about a man who divorces his wife when she is menstruating?" He said to him: "Abdullah bin 'Umar divorced his wife when she was menstruating during the time of the Messenger of Allah. 'Umar asked the Messenger of Allah (about that) and said: 'Abdullah bin 'Umar has divorced his wife while she was menstruating.' The Messenger of Allah said: 'Let him take her back.' So he made me take her back. He said: 'When she becomes pure, let him divorce her or keep her.' Ibn 'Umar said: 'The Prophet said: 'O Prophet! When you divorce women, divorce them before their 'Iddah (prescribed period) elapses}}
\hadithdefcmd{nasai}{3393}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ مُجَاهِدًا، يُحَدِّثُهُ عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا النَّبِيُّ إِذَا طَلَّقْتُمُ النِّسَاءَ فَطَلِّقُوهُنَّ لِعِدَّتِهِنَّ ‏\}‏ قَالَ ابْنُ عَبَّاسٍ رضى الله عنه قُبُلِ عِدَّتِهِنَّ ‏.‏\hadithno{3393}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas, concerning the saying of Allah, the Mighty and Sublime:"O Prophet! When you divorce women, divorce them at their 'Iddah (prescribed periods)." Ibn 'Abbas, may Allah be pleased with him, said: "Before their 'Iddah elapses}}
\hadithdefcmd{nasai}{3394}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ، قَالَ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ قَالَ طَلاَقُ السُّنَّةِ تَطْلِيقَةٌ وَهِيَ طَاهِرٌ فِي غَيْرِ جِمَاعٍ فَإِذَا حَاضَتْ وَطَهُرَتْ طَلَّقَهَا أُخْرَى فَإِذَا حَاضَتْ وَطَهُرَتْ طَلَّقَهَا أُخْرَى ثُمَّ تَعْتَدُّ بَعْدَ ذَلِكَ بِحَيْضَةٍ ‏.‏ قَالَ الأَعْمَشُ سَأَلْتُ إِبْرَاهِيمَ فَقَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{3394}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah that he said:"The Sunnah divorce is a divorce issued when she is pure (not menstruating) without having had intercourse with her. If she menstruates and becomes pure again, give her another divorce, and if she menstruates and becomes pure again, give her another divorce, then after that, she should wait for another menstrual cycle." (One of the narrators) Al-A'mash said: "I asked Ibrahim, and he said something similar}}
\hadithdefcmd{nasai}{3395}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ طَلاَقُ السُّنَّةِ أَنْ يُطَلِّقَهَا طَاهِرًا فِي غَيْرِ جِمَاعٍ ‏.‏\hadithno{3395}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah said:"The Sunnah divorce is to divorce her when she is pure (not menstruating) without having had intercourse with her}}
\hadithdefcmd{nasai}{3396}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ بْنَ عُمَرَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ تَطْلِيقَةً فَانْطَلَقَ عُمَرُ فَأَخْبَرَ النَّبِيَّ صلى الله عليه وسلم بِذَلِكَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مُرْ عَبْدَ اللَّهِ فَلْيُرَاجِعْهَا فَإِذَا اغْتَسَلَتْ فَلْيَتْرُكْهَا حَتَّى تَحِيضَ فَإِذَا اغْتَسَلَتْ مِنْ حَيْضَتِهَا الأُخْرَى فَلاَ يَمَسَّهَا حَتَّى يُطَلِّقَهَا فَإِنْ شَاءَ أَنْ يُمْسِكَهَا فَلْيُمْسِكْهَا فَإِنَّهَا الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ عَزَّ وَجَلَّ أَنْ تُطَلَّقَ لَهَا النِّسَاءُ ‏"‏ ‏.‏\hadithno{3396}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah that he issued a divorce to his wife when she was menstruating. So 'Umar went to inform the Prophet about that. The Prophet said to him:"Tell 'Abdullah to take her back, then, when she has performed Ghusl, let him leave her alone, until she menstruates (again). Then, when she performs Ghusl following that second period, he should not touch her until he divorces her. And if he wants to keep her, then let him keep her. That is the time when Allah has stated that women may be divorced}}
\hadithdefcmd{nasai}{3397}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى طَلْحَةَ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيُطَلِّقْهَا وَهِيَ طَاهِرٌ أَوْ حَامِلٌ ‏"‏ ‏.‏\hadithno{3397}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that he divorced his wife while she was menstruating. He mentioned that to the Prophet and he said:"Tell him to take her back, then divorce her while she is pure (not menstruating) or pregnant}}
\hadithdefcmd{nasai}{3398}{أَخْبَرَنِي زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَرَدَّهَا عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى طَلَّقَهَا وَهِيَ طَاهِرٌ ‏.‏\hadithno{3398}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that he divorced his wife when she was menstruating, but the Messenger of Allah told him to take her back, and divorce her when she was pure (not menstruating)}}
\hadithdefcmd{nasai}{3399}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنْ رَجُلٍ، طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَقَالَ هَلْ تَعْرِفُ عَبْدَ اللَّهِ بْنَ عُمَرَ فَإِنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَسَأَلَ عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يُرَاجِعَهَا ثُمَّ يَسْتَقْبِلَ عِدَّتَهَا ‏.‏ فَقُلْتُ لَهُ فَيَعْتَدُّ بِتِلْكَ التَّطْلِيقَةِ فَقَالَ مَهْ أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ ‏.‏\hadithno{3399}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Yunus bin Jubair said:"I asked Ibn 'Umar about a man who divorced his wife while she was menstruating. He said: 'Do you know 'Abdullah bin 'Umar?' He divorced his wife while she was menstruating, and 'Umar asked the Prophet about that, and he told him to take her back, then wait for the right time. I said to him: 'Was that divorce counted?' He said: 'Be quiet! What do you think if some becomes helpless and behaves foolishly?}}
\hadithdefcmd{nasai}{3400}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ يُونُسَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَجُلٌ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَقَالَ أَتَعْرِفُ عَبْدَ اللَّهِ بْنَ عُمَرَ فَإِنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَأَتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم يَسْأَلُهُ فَأَمَرَهُ أَنْ يُرَاجِعَهَا ثُمَّ يَسْتَقْبِلَ عِدَّتَهَا قُلْتُ لَهُ إِذَا طَلَّقَ الرَّجُلُ امْرَأَتَهُ وَهِيَ حَائِضٌ أَيَعْتَدُّ بِتِلْكَ التَّطْلِيقَةِ فَقَالَ مَهْ وَإِنْ عَجَزَ وَاسْتَحْمَقَ ‏.‏\hadithno{3400}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Yunus bin Jubair said:"I said to Ibn 'Umar: 'A man divorced his wife while she was menstruating.' He said: 'Do you know 'Abdullah bin 'Umar? He divorced his wife when she was menstruating, and 'Umar went to the Prophet and asked him about that, and he told him to take her back then wait for the right time.' I said to him: 'Was that divorce counted?' He said: 'Be quiet! What do you think if some becomes helpless and behaves foolishly?}}
\hadithdefcmd{nasai}{3401}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ مَحْمُودَ بْنَ لَبِيدٍ، قَالَ أُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ رَجُلٍ، طَلَّقَ امْرَأَتَهُ ثَلاَثَ تَطْلِيقَاتٍ جَمِيعًا فَقَامَ غَضْبَانًا ثُمَّ قَالَ ‏ "‏ أَيُلْعَبُ بِكِتَابِ اللَّهِ وَأَنَا بَيْنَ أَظْهُرِكُمْ ‏"‏ ‏.‏ حَتَّى قَامَ رَجُلٌ وَقَالَ يَا رَسُولَ اللَّهِ أَلاَ أَقْتُلُهُ ‏.‏\hadithno{3401}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Makhramah narrated that his father said:"I heard Mahmud bin Labid say: 'The Messenger of Allah was told about a man who had divorced his wife with three simultaneous divorces. He stood up angrily and said: Is the Book of Allah being toyed with while I am still among you? Then a man stood up and said: 'O Messenger of Allah, shall I kill him?}}
\hadithdefcmd{nasai}{3402}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، أَنَّ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، أَخْبَرَهُ أَنَّ عُوَيْمِرًا الْعَجْلاَنِيَّ جَاءَ إِلَى عَاصِمِ بْنِ عَدِيٍّ فَقَالَ أَرَأَيْتَ يَا عَاصِمُ لَوْ أَنَّ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَيَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ سَلْ لِي يَا عَاصِمُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ ‏.‏ فَسَأَلَ عَاصِمٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ وَعَابَهَا حَتَّى كَبُرَ عَلَى عَاصِمٍ مَا سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَجَعَ عَاصِمٌ إِلَى أَهْلِهِ جَاءَهُ عُوَيْمِرٌ فَقَالَ يَا عَاصِمُ مَاذَا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمٌ لِعُوَيْمِرٍ لَمْ تَأْتِنِي بِخَيْرٍ قَدْ كَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْأَلَةَ الَّتِي سَأَلْتَ عَنْهَا ‏.‏ فَقَالَ عُوَيْمِرٌ وَاللَّهِ لاَ أَنْتَهِي حَتَّى أَسْأَلَ عَنْهَا رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَقْبَلَ عُوَيْمِرٌ حَتَّى أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَطَ النَّاسِ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ نَزَلَ فِيكَ وَفِي صَاحِبَتِكَ فَاذْهَبْ فَائْتِ بِهَا ‏"‏ ‏.‏ قَالَ سَهْلٌ فَتَلاَعَنَا وَأَنَا مَعَ النَّاسِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا فَرَغَ عُوَيْمِرٌ قَالَ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ إِنْ أَمْسَكْتُهَا ‏.‏ فَطَلَّقَهَا ثَلاَثًا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3402}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sahl bin Sa'd As-Sa'idi narrated that 'Uwaimir Al-'Ajlani came to 'Asim bin 'Adiy and said:"What do you think, O 'Asim! If a man finds another man with his wife, should he kill him, and be killed in retaliation, or what should he do? O 'Asim! Ask the Messenger of Allah about that for me." So 'Asim asked the Messenger of Allah about that, and the Messenger of Allah disapproved of the question, and criticized the asking of too many questions until 'Asim felt upset. When 'Asim went back to his people, 'Uwaimir came to him and said: "O 'Asim, what did the Messenger of Allah say to you?" 'Asim said: "You have not brought me any good. The Messenger of Allah disapproved of the question you asked." 'Uwaimir said: "By Allah, I will go and ask the Messenger of Allah." So he went to the Messenger of Allah and found him in the midst of the people. He said: "O Messenger of Allah, what do you think if a man finds another man with his wife -should he kill him, and be killed in retaliation or what should he do?" The Messenger of Allah said: "Something has been revealed concerning you and your wife, so go and bring her here." Sahl said: "So they engaged in the procedure of Li'an, and I was among the people in the presence of the Messenger of Allah. When 'Uwaimir finished he said: "I would have been telling lies about her, O Messenger of Allah, if I keep her." So he divorced her thrice before the Messenger of Allah told him to do so}}
\hadithdefcmd{nasai}{3403}{أَخْبَرَنَا أَحْمَدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ يَزِيدَ الأَحْمَسِيُّ، قَالَ حَدَّثَنَا الشَّعْبِيُّ، قَالَ حَدَّثَتْنِي فَاطِمَةُ بِنْتُ قَيْسٍ، قَالَتْ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ أَنَا بِنْتُ آلِ خَالِدٍ وَإِنَّ زَوْجِي فُلاَنًا أَرْسَلَ إِلَىَّ بِطَلاَقِي وَإِنِّي سَأَلْتُ أَهْلَهُ النَّفَقَةَ وَالسُّكْنَى فَأَبَوْا عَلَىَّ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّهُ قَدْ أَرْسَلَ إِلَيْهَا بِثَلاَثِ تَطْلِيقَاتٍ ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا النَّفَقَةُ وَالسُّكْنَى لِلْمَرْأَةِ إِذَا كَانَ لِزَوْجِهَا عَلَيْهَا الرَّجْعَةُ ‏"‏ ‏.‏\hadithno{3403}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Fatimah bint Qais said:"I came to the Prophet and said: 'I am the daughter of Ali Khalid and my husband, so and so, sent word to me divorcing me. I asked his family for provision and shelter but they refused.' They said: 'O Messenger of Allah, he sent word to her divorcing her thrice.'" She said: "The Messenger of Allah said: 'The woman is still entitled to provision and shelter if the husband can still take her back}}
\hadithdefcmd{nasai}{3404}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ الْمُطَلَّقَةُ ثَلاَثًا لَيْسَ لَهَا سُكْنَى وَلاَ نَفَقَةٌ ‏"‏ ‏.‏\hadithno{3404}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Fatimah bint Qais that the Prophet said:"The thrice-divorced woman is not entitled to provision and shelter}}
\hadithdefcmd{nasai}{3405}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ أَبِي عَمْرٍو، - وَهُوَ الأَوْزَاعِيُّ - قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، قَالَ حَدَّثَتْنِي فَاطِمَةُ بِنْتُ قَيْسٍ، أَنَّ أَبَا عَمْرِو بْنَ حَفْصٍ الْمَخْزُومِيَّ، طَلَّقَهَا ثَلاَثًا فَانْطَلَقَ خَالِدُ بْنُ الْوَلِيدِ فِي نَفَرٍ مِنْ بَنِي مَخْزُومٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبَا عَمْرِو بْنَ حَفْصٍ طَلَّقَ فَاطِمَةَ ثَلاَثًا فَهَلْ لَهَا نَفَقَةٌ فَقَالَ ‏ "‏ لَيْسَ لَهَا نَفَقَةٌ وَلاَ سُكْنَى ‏"‏ ‏.‏\hadithno{3405}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Fatimah bint Qais narrated that Abu 'Amr bin Hafs Al-Makhzumi divorced her thrice. Khalid bin Al-Walid went with a group of (the tribe of) Makhzum to the Messenger of Allah and said:"O Messenger of Allah! Abu 'Amr bin Hafs has divorced Fatimah thrice, is she entitled to provision?" He said: "She is not entitled to provision nor shelter}}
\hadithdefcmd{nasai}{3406}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، أَنَّ أَبَا الصَّهْبَاءِ، جَاءَ إِلَى ابْنِ عَبَّاسٍ فَقَالَ يَا ابْنَ عَبَّاسٍ أَلَمْ تَعْلَمْ أَنَّ الثَّلاَثَ، كَانَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَصَدْرًا مِنْ خِلاَفَةِ عُمَرَ رَضِيَ اللَّهُ عَنْهُمَا تُرَدُّ إِلَى الْوَاحِدَةِ قَالَ نَعَمْ ‏.‏\hadithno{3406}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Tawus, from his father, that Abu As-Sahba' came to Ibn 'Abbas and said:"O Ibn 'Abbas! Did you not know that the threefold divorce during the time of the Messenger of Allah and Abu Bakr, and during the early part of 'Umar's Caliphate, used to be counted as one divorce?" He said: "Yes}}
\hadithdefcmd{nasai}{3407}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ رَجُلٍ طَلَّقَ امْرَأَتَهُ فَتَزَوَّجَتْ زَوْجًا غَيْرَهُ فَدَخَلَ بِهَا ثُمَّ طَلَّقَهَا قَبْلَ أَنْ يُوَاقِعَهَا أَتَحِلُّ لِلأَوَّلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حَتَّى يَذُوقَ الآخَرُ عُسَيْلَتَهَا وَتَذُوقَ عُسَيْلَتَهُ ‏"‏ ‏.‏\hadithno{3407}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah was asked about a man who divorced his wife, and she married another man who had a closed meeting with her then divorced her, before having intercourse with her. Is it permissible for her to remarry the first husband? The Messenger of Allah said: 'No, not until the second one tastes her sweetness and she tastes his sweetness}}
\hadithdefcmd{nasai}{3408}{أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، عَنْ أَبِيهِ، قَالَ حَدَّثَنِي أَيُّوبُ بْنُ مُوسَى، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتِ امْرَأَةُ رِفَاعَةَ الْقُرَظِيِّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي نَكَحْتُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ وَاللَّهِ مَا مَعَهُ إِلاَّ مِثْلَ هَذِهِ الْهُدْبَةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَلَّكِ تُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى يَذُوقَ عُسَيْلَتَكِ وَتَذُوقِي عُسَيْلَتَهُ ‏"‏ ‏.‏\hadithno{3408}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The wife of Rifa'ah Al-Qurazi came to the Messenger of Allah and said: 'O Messenger of Allah! I got married to 'Abdur-Rahman bin Az-Zabir, and what he has is like this fringe.' The Messenger of Allah said: 'Perhaps you want to go back to Rifa'ah? No, not until he ('Abdur-Rahman) tastes your sweetness and you taste his sweetness}}
\hadithdefcmd{nasai}{3409}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتِ امْرَأَةُ رِفَاعَةَ الْقُرَظِيِّ إِلَى النَّبِيِّ صلى الله عليه وسلم وَأَبُو بَكْرٍ عِنْدَهُ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ تَحْتَ رِفَاعَةَ الْقُرَظِيِّ فَطَلَّقَنِي الْبَتَّةَ فَتَزَوَّجْتُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ وَأَنَّهُ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا مَعَهُ إِلاَّ مِثْلَ هَذِهِ الْهُدْبَةِ وَأَخَذَتْ هُدْبَةً مِنْ جِلْبَابِهَا وَخَالِدُ بْنُ سَعِيدٍ بِالْبَابِ فَلَمْ يُأْذَنْ لَهُ فَقَالَ يَا أَبَا بَكْرٍ أَلاَ تَسْمَعُ هَذِهِ تَجْهَرُ بِمَا تَجْهَرُ بِهِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏ "‏ تُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى تَذُوقِي عُسَيْلَتَهُ وَيَذُوقَ عُسَيْلَتَكِ ‏"‏ ‏.‏\hadithno{3409}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The wife of Rifa'ah Al-Qurazi came to the Prophet when Abu Bakr was with him, and she said: 'O Messenger of Allah! I was married to Rifa'ah Al-Qurazi and he divorced me, and made it irrevocable. Then I married 'Abdur-Rahman bin Az-Zabir, and by Allah, O Messenger of Allah, what he has is like this fringe;' and she held up a fringe of her Jilbab. Khalid bin Sa'eed was at the door and he did not let him in. He said: 'O Abu Bakr? Do you not hear this woman speaking in such an audacious manner in the presence of the Messenger of Allah?' He said: 'Do you want to go back to Rifa'ah? No, not until you taste his sweetness and he tastes your sweetness}}
\hadithdefcmd{nasai}{3410}{أَخْبَرَنَا عَلِيُّ بْنُ نَصْرِ بْنِ عَلِيٍّ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ قُلْتُ لأَيُّوبَ هَلْ عَلِمْتَ أَحَدًا قَالَ فِي أَمْرِكِ بِيَدِكِ أَنَّهَا ثَلاَثٌ غَيْرَ الْحَسَنِ فَقَالَ لاَ ثُمَّ قَالَ اللَّهُمَّ غَفْرًا إِلاَّ مَا حَدَّثَنِي قَتَادَةُ عَنْ كَثِيرٍ مَوْلَى ابْنِ سَمُرَةَ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثٌ ‏"‏ ‏.‏ فَلَقِيتُ كَثِيرًا فَسَأَلْتُهُ فَلَمْ يَعْرِفْهُ فَرَجَعْتُ إِلَى قَتَادَةَ فَأَخْبَرْتُهُ فَقَالَ نَسِيَ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا حَدِيثٌ مُنْكَرٌ ‏.‏\hadithno{3410}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Hammad bin Zaid said:"I said to Ayyub: 'Do you know anyone who said concerning the phrase 'It is up to you' that it is equivalent to three (divorces) except Al-Hasan?' He said: 'No.' Then he said: 'O Allah! Grant forgiveness, sorry.'" Qatadah narrated to me from Kathir the freed slave of Ibn Samurah, from Abu Salamah, from Abu Hurairah, that the Prophet said: "Three." I met Kathir and asked him, and he did not know of it. I went back to Qatadah and told him, and he said: "He forgot}}
\hadithdefcmd{nasai}{3411}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتِ امْرَأَةُ رِفَاعَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنَّ زَوْجِي طَلَّقَنِي فَأَبَتَّ طَلاَقِي وَإِنِّي تَزَوَّجْتُ بَعْدَهُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ وَمَا مَعَهُ إِلاَّ مِثْلَ هُدْبَةِ الثَّوْبِ ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ لَعَلَّكِ تُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى يَذُوقَ عُسَيْلَتَكِ وَتَذُوقِي عُسَيْلَتَهُ ‏"‏ ‏.‏\hadithno{3411}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The wife of Rifa'ah came to the Messenger of Allah and said: 'My husband divorced me and made it irrevocable. After that I married 'Abdur-Rahman bin Az-Zabir and what he has is like the fringe of a garment.' The Messenger of Allah smiled and said: 'Perhaps you want to go back to Rifa'ah? No, not until he tastes your sweetness and you taste his sweetness}}
\hadithdefcmd{nasai}{3412}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي الْقَاسِمُ، عَنْ عَائِشَةَ، أَنَّ رَجُلاً، طَلَّقَ امْرَأَتَهُ ثَلاَثًا فَتَزَوَّجَتْ زَوْجًا فَطَلَّقَهَا قَبْلَ أَنْ يَمَسَّهَا فَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَتَحِلُّ لِلأَوَّلِ فَقَالَ ‏ "‏ لاَ حَتَّى يَذُوقَ عُسَيْلَتَهَا كَمَا ذَاقَ الأَوَّلُ ‏"‏ ‏.‏\hadithno{3412}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that a man divorced his wife three times and she married another husband who divorced her, before having intercourse with her. The Messenger of Allah was asked:"Is she permissible for the first (husband to remarry her)?" He said: "No, not until he tastes her sweetness as the first tasted her sweetness}}
\hadithdefcmd{nasai}{3413}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ الْغُمَيْصَاءَ، أَوِ الرُّمَيْصَاءَ أَتَتِ النَّبِيَّ صلى الله عليه وسلم تَشْتَكِي زَوْجَهَا أَنَّهُ لاَ يَصِلُ إِلَيْهَا فَلَمْ يَلْبَثْ أَنْ جَاءَ زَوْجُهَا فَقَالَ يَا رَسُولَ اللَّهِ هِيَ كَاذِبَةٌ وَهُوَ يَصِلُ إِلَيْهَا وَلَكِنَّهَا تُرِيدُ أَنْ تَرْجِعَ إِلَى زَوْجِهَا الأَوَّلِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ ذَلِكَ حَتَّى تَذُوقِي عُسَيْلَتَهُ ‏"‏ ‏.‏\hadithno{3413}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that Al-Ghumaisa or Ar-Rumaisa' came to the Prophet complaining that her husband would not have intercourse with her. It was not long before her husband came and said:"O Messenger of Allah, she is lying; he is having intercourse with her, but she wants to go back to her first husband." The Messenger of Allah said: "She cannot do that until she tastes his sweetness}}
\hadithdefcmd{nasai}{3414}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، قَالَ سَمِعْتُ سَالِمَ بْنَ رَزِينٍ، يُحَدِّثُ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرَّجُلِ تَكُونُ لَهُ الْمَرْأَةُ يُطَلِّقُهَا ثُمَّ يَتَزَوَّجُهَا رَجُلٌ آخَرُ فَيُطَلِّقُهَا قَبْلَ أَنْ يَدْخُلَ بِهَا فَتَرْجِعَ إِلَى زَوْجِهَا الأَوَّلِ قَالَ ‏ "‏ لاَ حَتَّى تَذُوقَ الْعُسَيْلَةَ ‏"‏ ‏.‏\hadithno{3414}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet said, concerning a man who had a wife and he divorced her, then she married another man who divorced her before consummating the marriage with her, and (it was asked) whether she could go back to her first husband:"No, not until she tastes his sweetness}}
\hadithdefcmd{nasai}{3415}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ رَزِينِ بْنِ سُلَيْمَانَ الأَحْمَرِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الرَّجُلِ يُطَلِّقُ امْرَأَتَهُ ثَلاَثًا فَيَتَزَوَّجُهَا الرَّجُلُ فَيُغْلِقُ الْبَابَ وَيُرْخِي السِّتْرَ ثُمَّ يُطَلِّقُهَا قَبْلَ أَنْ يَدْخُلَ بِهَا قَالَ ‏ "‏ لاَ تَحِلُّ لِلأَوَّلِ حَتَّى يُجَامِعَهَا الآخَرُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا أَوْلَى بِالصَّوَابِ ‏.‏\hadithno{3415}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Prophet was asked about a man who divorced his wife three times, then another man married her and he closed the door and drew the curtain, then divorced her before consummating the marriage with her. He said: "She is not permissible for the first one (to remarry her) until the second one has had intercourse with her}}
\hadithdefcmd{nasai}{3416}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ سُفْيَانَ، عَنْ أَبِي قَيْسٍ، عَنْ هُزَيْلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَاشِمَةَ وَالْمُوتَشِمَةَ وَالْوَاصِلَةَ وَالْمَوْصُولَةَ وَآكِلَ الرِّبَا وَمُوكِلَهُ وَالْمُحَلِّلَ وَالْمُحَلَّلَ لَهُ ‏.‏\hadithno{3416}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah cursed the woman who tattoos and the one tattooed, the woman who fixed hair extensions and the one who had her hair get extended, the consumer of Riba and the one who pays it, and Al-Muhallil and Al-Muhallal Lahu}}
\hadithdefcmd{nasai}{3417}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ سَأَلْتُ الزُّهْرِيَّ عَنِ الَّتِي، اسْتَعَاذَتْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَخْبَرَنِي عُرْوَةُ عَنْ عَائِشَةَ أَنَّ الْكِلاَبِيَّةَ لَمَّا دَخَلَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَتْ أَعُوذُ بِاللَّهِ مِنْكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقَدْ عُذْتِ بِعَظِيمٍ الْحَقِي بِأَهْلِكِ ‏"‏ ‏.‏\hadithno{3417}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah that when the Kilabi woman entered upon the Prophet she said:"I seek refuge with Allah from you." The Messenger of Allah said: "You have sought refuge with One Who is Great. Go back to your family}}
\hadithdefcmd{nasai}{3418}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي بَكْرٍ، - وَهُوَ ابْنُ أَبِي الْجَهْمِ - قَالَ سَمِعْتُ فَاطِمَةَ بِنْتَ قَيْسٍ، تَقُولُ أَرْسَلَ إِلَىَّ زَوْجِي بِطَلاَقِي فَشَدَدْتُ عَلَىَّ ثِيَابِي ثُمَّ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ كَمْ طَلَّقَكِ ‏"‏ ‏.‏ فَقُلْتُ ثَلاَثًا ‏.‏ قَالَ ‏"‏ لَيْسَ لَكِ نَفَقَةٌ وَاعْتَدِّي فِي بَيْتِ ابْنِ عَمِّكِ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ ضَرِيرُ الْبَصَرِ تُلْقِينَ ثِيَابَكِ عِنْدَهُ فَإِذَا انْقَضَتْ عِدَّتُكِ فَآذِنِينِي ‏"‏ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{3418}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Bakr -the son of Abu Al-Jahm- said:"I heard Fatimah bint Qais say: 'My husband sent word to me that I was divorced, so I put on my garments and went to the Prophet. He said: 'How many times did he divorce you?' I said: 'Three.' He said: 'You are not entitled to maintenance. Observe your 'Iddah in the house of your paternal cousin Ibn Umm Maktum, for he is blind and you can take off your garments there. And when your 'Iddah is over let me know.'" This is an abridgment}}
\hadithdefcmd{nasai}{3419}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ تَمِيمٍ، مَوْلَى فَاطِمَةَ عَنْ فَاطِمَةَ، نَحْوَهُ ‏.‏\hadithno{3419}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{A similar report was narrated from Tamim, the freed slave of Fatimah, from Fatimah}}
\hadithdefcmd{nasai}{3420}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَلِيٍّ الْمَوْصِلِيُّ، قَالَ حَدَّثَنَا مَخْلَدٌ، عَنْ سُفْيَانَ، عَنْ سَالِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَتَاهُ رَجُلٌ فَقَالَ إِنِّي جَعَلْتُ امْرَأَتِي عَلَىَّ حَرَامًا ‏.‏ قَالَ كَذَبْتَ لَيْسَتْ عَلَيْكَ بِحَرَامٍ ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ لِمَ تُحَرِّمُ مَا أَحَلَّ اللَّهُ لَكَ ‏\}‏ عَلَيْكَ أَغْلَظُ الْكَفَّارَةِ عِتْقُ رَقَبَةٍ ‏.‏\hadithno{3420}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"A man came to him and said: 'I have made my wife forbidden to myself.' He said: 'You are lying, she is not forbidden to you.' Then he recited this Verse: 'O Prophet! Why do you forbid (for yourself) that which Allah has allowed to you.' (And he said): 'You have to offer the severest form of expiation: Freeing a slave}}
\hadithdefcmd{nasai}{3421}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ حَجَّاجٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، أَنَّهُ سَمِعَ عُبَيْدَ بْنَ عُمَيْرٍ، قَالَ سَمِعْتُ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَمْكُثُ عِنْدَ زَيْنَبَ وَيَشْرَبُ عِنْدَهَا عَسَلاً فَتَوَاصَيْتُ وَحَفْصَةَ أَيَّتُنَا مَا دَخَلَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم فَلْتَقُلْ إِنِّي أَجِدُ مِنْكَ رِيحَ مَغَافِيرَ فَدَخَلَ عَلَى إِحْدَاهُمَا فَقَالَتْ ذَلِكَ لَهُ فَقَالَ ‏"‏ بَلْ شَرِبْتُ عَسَلاً عِنْدَ زَيْنَبَ - وَقَالَ - لَنْ أَعُودَ لَهُ ‏"‏ ‏.‏ فَنَزَلَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ لِمَ تُحَرِّمُ مَا أَحَلَّ اللَّهُ لَكَ ‏\}‏ ‏\{‏ إِنْ تَتُوبَا إِلَى اللَّهِ ‏\}‏ لِعَائِشَةَ وَحَفْصَةَ ‏\{‏ وَإِذْ أَسَرَّ النَّبِيُّ إِلَى بَعْضِ أَزْوَاجِهِ حَدِيثًا ‏\}‏ لِقَوْلِهِ ‏"‏ بَلْ شَرِبْتُ عَسَلاَ ‏"‏ ‏.‏ كُلُّهُ فِي حَدِيثِ عَطَاءٍ ‏.‏\hadithno{3421}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ubaid bin 'Umair narrated from 'Aishah, the wife of the Prophet:"The Prophet used to stay with Zainab bint Jahsh and drink honey at her house. Hafsah and I agreed that if the Prophet came to either of us, she would say: 'I detect the smell of Maghafir (a nasty-smelling gum) on you; have you eaten Maghafir?' He came to one of them and she said that to him. He said: 'No, rather I drank honey at the house of Zainab bint Jahsh, but I will never do it again.' Then the following was revealed: 'O Prophet! Why do you forbid (for yourself) that which Allah has allowed to you.' 'If you two turn in repentance to Allah, (it will be better for you).' addressing 'Aishah and Hafsah; 'And (remember) when the Prophet disclosed a matter in confidence to one of his wives.' refers to him saying: "No, rather I drank honey}}
\hadithdefcmd{nasai}{3422}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ نُعَيْمٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مَكِّيِّ بْنِ عِيسَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، قَالَ حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، يُحَدِّثُ حَدِيثَهُ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ وَقَالَ فِيهِ إِذَا رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَأْتِينِي فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ح وَأَخْبَرَنِي سُلَيْمَانُ بْنُ دَاوُدَ قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ عَنْ يُونُسَ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبِ بْنِ مَالِكٍ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ يُحَدِّثُ حَدِيثَهُ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ وَسَاقَ قِصَّتَهُ وَقَالَ إِذَا رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَأْتِي فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ أَنْ تَعْتَزِلَ امْرَأَتَكَ ‏.‏ فَقُلْتُ أُطَلِّقُهَا أَمْ مَاذَا قَالَ لاَ بَلِ اعْتَزِلْهَا فَلاَ تَقْرَبْهَا ‏.‏ فَقُلْتُ لاِمْرَأَتِي الْحَقِي بِأَهْلِكِ فَكُونِي عِنْدَهُمْ حَتَّى يَقْضِيَ اللَّهُ عَزَّ وَجَلَّ فِي هَذَا الأَمْرِ ‏.‏\hadithno{3422}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ka'b bin Malik narrated the Hadith about when he stayed behind, and did not join the Messenger of Allah on the expedition to Tabuk. He told the story, and said:"The envoy of the Messenger of Allah came to me and said: 'The Messenger of Allah commands you to stay away from your wife.' I said: 'Shall I divorce her or what?' He said: 'No, just keep away from her and do not approach her.' I said to my wife: 'Go to your family and stay with them until Allah, the Mighty and Sublime, decides concerning this matter}}
\hadithdefcmd{nasai}{3423}{أَخْبَرَنِي مُحَمَّدُ بْنُ جَبَلَةَ، وَمُحَمَّدُ بْنُ يَحْيَى بْنِ مُحَمَّدٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى بْنِ أَعْيَنَ، قَالَ حَدَّثَنَا أَبِي، عَنْ إِسْحَاقَ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبِي كَعْبَ بْنَ مَالِكٍ، - قَالَ وَهُوَ أَحَدُ الثَّلاَثَةِ الَّذِينَ تِيبَ عَلَيْهِمْ - يُحَدِّثُ قَالَ أَرْسَلَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِلَى صَاحِبَىَّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكُمْ أَنْ تَعْتَزِلُوا نِسَاءَكُمْ ‏.‏ فَقُلْتُ لِلرَّسُولِ أُطَلِّقُ امْرَأَتِي أَمْ مَاذَا أَفْعَلُ قَالَ لاَ بَلْ تَعْتَزِلُهَا فَلاَ تَقْرَبْهَا ‏.‏ فَقُلْتُ لاِمْرَأَتِي الْحَقِي بِأَهْلِكِ فَكُونِي فِيهِمْ فَلَحِقَتْ بِهِمْ ‏.‏\hadithno{3423}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdur-Rahman bin 'Abdullah bin Ka'b bin Malik narrated that his father said:"I heard my father Ka'b bin Malik -who was one of the three whose repentance was accepted- say: 'The Messenger of Allah sent word to me and to my two companions saying: The Messenger of Allah commands you to keep away from your wives. I said to his envoy: Shall I divorce my wife, or what should I do? He said: No, just keep away from her, and do not approach her. I said to my wife: Go to your family and stay with them. So she went to them}}
\hadithdefcmd{nasai}{3424}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، قَالَ سَمِعْتُ كَعْبًا، يُحَدِّثُ حَدِيثَهُ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ وَقَالَ فِيهِ إِذَا رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَأْتِينِي وَيَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ أَنْ تَعْتَزِلَ امْرَأَتَكَ ‏.‏ فَقُلْتُ أُطَلِّقُهَا أَمْ مَاذَا أَفْعَلُ قَالَ بَلِ اعْتَزِلْهَا وَلاَ تَقْرَبْهَا ‏.‏ وَأَرْسَلَ إِلَى صَاحِبَىَّ بِمِثْلِ ذَلِكَ فَقُلْتُ لاِمْرَأَتِي الْحَقِي بِأَهْلِكِ وَكُونِي عِنْدَهُمْ حَتَّى يَقْضِيَ اللَّهُ عَزَّ وَجَلَّ فِي هَذَا الأَمْرِ ‏.‏ خَالَفَهُمْ مَعْقِلُ بْنُ عُبَيْدِ اللَّهِ ‏.‏\hadithno{3424}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur-Rahman bin 'Abdullah bin Ka'b bin Malik narrated that 'Abdullah bin Ka'b said:"I heard Ka'b narrate the Hadith about when he stayed behind and did not join the Messenger of Allah on the expedition to Tabuk. He said: 'The envoy of the Messenger of Allah came to me and said: "The Messenger of Allah commands you to keep away from your wife." I said: "Shall I divorce her, or what should I do?" He said: "No, just keep away from her and do not approach her." And he sent similar instructions to my two companions. I said to my wife: "Go to your family and stay with them until Allah, the Mighty and Sublime, decides concerning this matter}}
\hadithdefcmd{nasai}{3425}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْدَانَ بْنِ عِيسَى، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، قَالَ حَدَّثَنَا مَعْقِلٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبٍ، عَنْ عَمِّهِ، عُبَيْدِ اللَّهِ بْنِ كَعْبٍ قَالَ سَمِعْتُ أَبِي كَعْبًا، يُحَدِّثُ قَالَ أَرْسَلَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِلَى صَاحِبَىَّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكُمْ أَنْ تَعْتَزِلُوا نِسَاءَكُمْ فَقُلْتُ لِلرَّسُولِ أُطَلِّقُ امْرَأَتِي أَمْ مَاذَا أَفْعَلُ قَالَ لاَ بَلْ تَعْتَزِلُهَا وَلاَ تَقْرَبْهَا ‏.‏ فَقُلْتُ لاِمْرَأَتِي الْحَقِي بِأَهْلِكِ فَكُونِي فِيهِمْ حَتَّى يَقْضِيَ اللَّهُ عَزَّ وَجَلَّ ‏.‏ فَلَحِقَتْ بِهِمْ ‏.‏ خَالَفَهُ مَعْمَرٌ ‏.‏\hadithno{3425}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ma'qil, from Az-Zuhri who said:"Abdur-Rahman bin 'Abdullah bin Ka'b narrated that his paternal uncle 'Ubaidullah bin Ka'b said: 'I heard my father Ka'b say: The Messenger of Allah sent word to me and my two companions saying: The Messenger of Allah commands you to keep away from your wives. I said to the envoy: Should I divorce my wife, or what should I do? He said: No, just keep away from her and do not come near her. I said to my wife: Go to your family and stay with them until Allah, the Mighty and Sublime, decides (concerning me). So she went to them}}
\hadithdefcmd{nasai}{3426}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ ثَوْرٍ - عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ فِي حَدِيثِهِ إِذَا رَسُولٌ مِنَ النَّبِيِّ صلى الله عليه وسلم قَدْ أَتَانِي فَقَالَ اعْتَزِلِ امْرَأَتَكَ ‏.‏ فَقُلْتُ أُطَلِّقُهَا قَالَ لاَ وَلَكِنْ لاَ تَقْرَبْهَا ‏.‏ وَلَمْ يَذْكُرْ فِيهِ الْحَقِي بِأَهْلِكِ ‏.‏\hadithno{3426}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin Ka'b bin Malik that his father said:"The envoy of the Messenger of Allah came to me and said: 'Keep away from your wife.' I said: 'Should I divorce her?' He said: 'No, but do not approach her.'" And he (the narrator) did not mention (the words): "Go to your family}}
\hadithdefcmd{nasai}{3427}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ سَمِعْتُ يَحْيَى، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عُمَرَ بْنِ مُعَتِّبٍ، أَنَّ أَبَا حَسَنٍ، مَوْلَى بَنِي نَوْفَلٍ أَخْبَرَهُ قَالَ كُنْتُ أَنَا وَامْرَأَتِي، مَمْلُوكَيْنِ فَطَلَّقْتُهَا تَطْلِيقَتَيْنِ ثُمَّ أُعْتِقْنَا جَمِيعًا فَسَأَلْتُ ابْنَ عَبَّاسٍ فَقَالَ إِنْ رَاجَعْتَهَا كَانَتْ عِنْدَكَ عَلَى وَاحِدَةٍ قَضَى بِذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ خَالَفَهُ مَعْمَرٌ ‏.‏\hadithno{3427}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Umar bin Mu'attib that Abu Hasan, the freed slave of Banu Nawfal, said:"My wife and I were slaves, and I divorced her twice, then we were both set free. I asked Ibn 'Abbas and he said: 'If you take her back, you have two divorces left. This is how the Messenger of Allah ruled}}
\hadithdefcmd{nasai}{3428}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُمَرَ بْنِ مُعَتِّبٍ، عَنِ الْحَسَنِ، مَوْلَى بَنِي نَوْفَلٍ قَالَ سُئِلَ ابْنُ عَبَّاسٍ عَنْ عَبْدٍ طَلَّقَ، امْرَأَتَهُ تَطْلِيقَتَيْنِ ثُمَّ عُتِقَا أَيَتَزَوَّجُهَا قَالَ نَعَمْ ‏.‏ قَالَ عَمَّنْ قَالَ أَفْتَى بِذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ عَبْدُ الرَّزَّاقِ قَالَ ابْنُ الْمُبَارَكِ لِمَعْمَرٍ الْحَسَنُ هَذَا مَنْ هُوَ لَقَدْ حَمَلَ صَخْرَةً عَظِيمَةً ‏.‏\hadithno{3428}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Al-Hasan, the freed slave of Banu Nawfal, said:"Ibn 'Abbas was asked about a slave who divorced his wife twice, then they were set free; could he marry her? He said: 'Yes.' He said: 'From whom (did you hear that)?' He said: 'The Messenger of Allah issued a Fatwa to that effect.'" (One of the narrators) 'Abdur-Razzaq said: "Ibn Al-Mubarak said to Ma'mar: 'Which Al-Hasan is this? He has taken on a heavy burden}}
\hadithdefcmd{nasai}{3429}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَسَدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي جَعْفَرٍ الْخَطْمِيِّ، عَنْ عُمَارَةَ بْنِ خُزَيْمَةَ، عَنْ كَثِيرِ بْنِ السَّائِبِ، قَالَ حَدَّثَنِي أَبْنَاءُ، قُرَيْظَةَ أَنَّهُمْ عُرِضُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ قُرَيْظَةَ فَمَنْ كَانَ مُحْتَلِمًا أَوْ نَبَتَتْ عَانَتُهُ قُتِلَ وَمَنْ لَمْ يَكُنْ مُحْتَلِمًا أَوْ لَمْ تَنْبُتْ عَانَتُهُ تُرِكَ ‏.‏\hadithno{3429}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Kathir bin As-Sa'ib said:"The sons of Quraizah told me that they were presented to the Messenger of Allah on the Day of Quraizah, and whoever (among them) had reached puberty, or had grown pubic hair, was killed, and whoever had not reached puberty and had not grown pubic hair was left (alive)}}
\hadithdefcmd{nasai}{3430}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَطِيَّةَ الْقُرَظِيِّ، قَالَ كُنْتُ يَوْمَ حُكْمِ سَعْدٍ فِي بَنِي قُرَيْظَةَ غُلاَمًا فَشَكُّوا فِيَّ فَلَمْ يَجِدُونِي أَنْبَتُّ فَاسْتُبْقِيتُ فَهَا أَنَا ذَا بَيْنَ أَظْهُرِكُمْ ‏.‏\hadithno{3430}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Atiyyah Al-Qurazi said:"On the day that Sa'd passed judgment on Banu Quraizah I was a young boy and they were not sure about me, but they did not find any pubic hair, so they let me live, and here I am among you}}
\hadithdefcmd{nasai}{3431}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَرَضَهُ يَوْمَ أُحُدٍ وَهُوَ ابْنُ أَرْبَعَ عَشْرَةَ سَنَةً فَلَمْ يُجِزْهُ وَعَرَضَهُ يَوْمَ الْخَنْدَقِ وَهُوَ ابْنُ خَمْسَ عَشْرَةَ سَنَةً فَأَجَازَهُ ‏.‏\hadithno{3431}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Umar that he presented himself to the Messenger of Allah on the Day of Uhud when he was fourteen years old, but he did not permit him (to join the army). He presented himself on the Day of Al-Khandaq when he was fifteen years old, and he permitted him (to join the army)}}
\hadithdefcmd{nasai}{3432}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حَمَّادٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رُفِعَ الْقَلَمُ عَنْ ثَلاَثٍ عَنِ النَّائِمِ حَتَّى يَسْتَيْقِظَ وَعَنِ الصَّغِيرِ حَتَّى يَكْبُرَ وَعَنِ الْمَجْنُونِ حَتَّى يَعْقِلَ أَوْ يَفِيقَ ‏"‏ ‏.‏\hadithno{3432}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"The pen has been lifted from three: From the sleeper until he wakes up, from the minor until he grows up, and from the insane until he comes back to his senses or recovers}}
\hadithdefcmd{nasai}{3433}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، وَعَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم - قَالَ عَبْدُ الرَّحْمَنِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ ‏ "‏ إِنَّ اللَّهَ تَعَالَى تَجَاوَزَ عَنْ أُمَّتِي كُلَّ شَىْءٍ حَدَّثَتْ بِهِ أَنْفُسَهَا مَا لَمْ تَكَلَّمْ بِهِ أَوْ تَعْمَلْ ‏"‏ ‏.‏\hadithno{3433}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that -(one of the narrators) 'Abdur-Rahman said:"The Messenger of Allah -said: 'Allah, the Most High, has forgiven my Ummah for everything that enters the mind, so long as it is not spoken of or put into action}}
\hadithdefcmd{nasai}{3434}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ مِسْعَرٍ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ تَجَاوَزَ لأُمَّتِي مَا وَسْوَسَتْ بِهِ وَحَدَّثَتْ بِهِ أَنْفُسَهَا مَا لَمْ تَعْمَلْ أَوْ تَتَكَلَّمْ بِهِ ‏"‏ ‏.‏\hadithno{3434}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Allah, the Mighty and Sublime, has forgiven my Ummah for what is whispered to them or what enters their minds, so long as they do not act upon it or speak of it}}
\hadithdefcmd{nasai}{3435}{أَخْبَرَنِي مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ شَيْبَانَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ تَعَالَى تَجَاوَزَ لأُمَّتِي عَمَّا حَدَّثَتْ بِهِ أَنْفُسَهَا مَا لَمْ تَكَلَّمْ أَوْ تَعْمَلْ بِهِ ‏"‏ ‏.‏\hadithno{3435}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Allah, the Most High, has forgiven my Ummah for whatever enters the mind, so long as it is not spoken of or put into action}}
\hadithdefcmd{nasai}{3436}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، قَالَ حَدَّثَنَا بَهْزٌ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم جَارٌ فَارِسِيٌّ طَيِّبُ الْمَرَقَةِ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ وَعِنْدَهُ عَائِشَةُ فَأَوْمَأَ إِلَيْهِ بِيَدِهِ أَنْ تَعَالَ وَأَوْمَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى عَائِشَةَ أَىْ وَهَذِهِ فَأَوْمَأَ إِلَيْهِ الآخَرُ هَكَذَا بِيَدِهِ أَنْ لاَ مَرَّتَيْنِ أَوْ ثَلاَثًا ‏.‏\hadithno{3436}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah had a Persian neighbor who was good at making soup. He came to the Messenger of Allah one day when 'Aishah was with him, and gestured to him with his hand to come. The Messenger of Allah gestured toward 'Aishah -meaning: 'What about her?'- and the man gestured to him like this, meaning, 'No,' two or three times}}
\hadithdefcmd{nasai}{3437}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ حَدَّثَنَا مَالِكٌ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ أَخْبَرَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، رضى الله عنه - وَفِي حَدِيثِ الْحَارِثِ أَنَّهُ سَمِعَ عُمَرَ يَقُولُ - قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الأَعْمَالُ بِالنِّيَّةِ وَإِنَّمَا لاِمْرِئٍ مَا نَوَى فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ وَمَنْ كَانَتْ هِجْرَتُهُ لِدُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{3437}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Umar bin Al-Khattab, may Allah be pleased with him, said that the Messenger of Allah said:"Actions are but by intentions, and each man will have but that which he intended. Whoever emigrated for the sake of Allah and His Messenger, his emigration was for the sake of Allah and His Messenger, and whoever emigrated for the sake of some worldly gain or to marry some woman, his emigration was for that for which he emigrated}}
\hadithdefcmd{nasai}{3438}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنِي شُعَيْبٌ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، مِمَّا حَدَّثَهُ عَبْدُ الرَّحْمَنِ الأَعْرَجُ، مِمَّا ذَكَرَ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ ‏ "‏ انْظُرُوا كَيْفَ يَصْرِفُ اللَّهُ عَنِّي شَتْمَ قُرَيْشٍ وَلَعْنَهُمْ إِنَّهُمْ يَشْتِمُونَ مُذَمَّمًا وَيَلْعَنُونَ مُذَمَّمًا وَأَنَا مُحَمَّدٌ ‏"‏ ‏.‏\hadithno{3438}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Look at how Allah diverts the insults and curses of Quraish from me. They insult 'Mudhammam' and curse 'Mudhammam' -but I am Muhammad}}
\hadithdefcmd{nasai}{3439}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا يُونُسُ بْنُ يَزِيدَ، وَمُوسَى بْنُ عُلَىٍّ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَمَّا أُمِرَ رَسُولُ اللَّهِ بِتَخْيِيرِ أَزْوَاجِهِ بَدَأَ بِي فَقَالَ ‏"‏ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ لاَ تُعَجِّلِي حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏ ‏.‏ قَالَتْ قَدْ عَلِمَ أَنَّ أَبَوَاىَ لَمْ يَكُونَا لِيَأْمُرَانِّي بِفِرَاقِهِ - قَالَتْ - ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ إِنْ كُنْتُنَّ تُرِدْنَ الْحَيَاةَ الدُّنْيَا ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ جَمِيلاً ‏\}‏ فَقُلْتُ أَفِي هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ عَزَّ وَجَلَّ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ - قَالَتْ عَائِشَةُ - ثُمَّ فَعَلَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم مِثْلَ مَا فَعَلْتُ وَلَمْ يَكُنْ ذَلِكَ حِينَ قَالَ لَهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاخْتَرْنَهُ طَلاَقًا مِنْ أَجْلِ أَنَّهُنَّ اخْتَرْنَهُ ‏.‏\hadithno{3439}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah, the wife of the Prophet, said:"When the Messenger of Allah was commanded to give his wives the choice, he started with me and said: 'I am going to say something to you and you do not have to rush (to make a decision) until you consult your parents.'" She said: "He knew that my parents would never tell me to leave him." She said: "Then he recited this Verse: 'O Prophet! Say to your wives: If you desire the life of this world, and its glitter, then come! I will make a provision for you and set you free in a handsome manner.' I said: 'Do I need to consult my parents concerning this? I desire Allah, the Mighty and Sublime, and His Messenger, and the home of the Hereafter.'" 'Aishah said: "Then the wives of the Prophet all did the same as I did, and that was not counted as a divorce, when the Messenger of Allah gave them the choice and they chose him}}
\hadithdefcmd{nasai}{3440}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَتْ ‏\{‏ إِنْ كُنْتُنَّ تُرِدْنَ اللَّهَ وَرَسُولَهُ ‏\}‏ دَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم بَدَأَ بِي فَقَالَ ‏"‏ يَا عَائِشَةُ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ لاَ تُعَجِّلِي حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏ ‏.‏ قَالَتْ قَدْ عَلِمَ وَاللَّهِ أَنَّ أَبَوَىَّ لَمْ يَكُونَا لِيَأْمُرَانِّي بِفِرَاقِهِ فَقَرَأَ عَلَىَّ ‏\{‏ يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ إِنْ كُنْتُنَّ تُرِدْنَ الْحَيَاةَ الدُّنْيَا وَزِينَتَهَا ‏\}‏ فَقُلْتُ أَفِي هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ وَرَسُولَهُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالأَوَّلُ أَوْلَى بِالصَّوَابِ وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{3440}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"When the following was revealed: 'But if you desire Allah and His Messenger,' the Prophet came and started with me. He said: 'O 'Aishah, I am going to say something to you and you do not have to rush (to make a decision) until you consult your parents.'" She said: "He knew, by Allah, that my parents would never tell me to leave him. Then he recited to me: 'O Prophet! Say to your wives: If you desire the life of this world, and its glitter.'" "I said: 'Do I need to consult my parents concerning this? I desire Allah and His Messenger}}
\hadithdefcmd{nasai}{3441}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، - هُوَ ابْنُ سَعِيدٍ - عَنْ إِسْمَاعِيلَ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَرْنَاهُ فَهَلْ كَانَ طَلاَقًا\hadithno{3441}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah gave us the choice and we chose him; was that a divorce?}}
\hadithdefcmd{nasai}{3442}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، قَالَ قَالَ الشَّعْبِيُّ عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ قَدْ خَيَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ فَلَمْ يَكُنْ طَلاَقًا ‏.‏\hadithno{3442}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah gave his wives the choice but that was not a divorce}}
\hadithdefcmd{nasai}{3443}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ صُدْرَانَ، عَنْ خَالِدِ بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا أَشْعَثُ، - وَهُوَ ابْنُ عَبْدِ الْمَلِكِ - عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ قَدْ خَيَّرَ النَّبِيُّ صلى الله عليه وسلم نِسَاءَهُ فَلَمْ يَكُنْ طَلاَقًا ‏.‏\hadithno{3443}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Masruq that 'Aishah said:"The Prophet gave his wives the choice and that was not a divorce}}
\hadithdefcmd{nasai}{3444}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ قَدْ خَيَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ أَفَكَانَ طَلاَقًا ‏.‏\hadithno{3444}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah gave his wives the choice; was that a divorce?}}
\hadithdefcmd{nasai}{3445}{أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الضَّعِيفُ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَرْنَاهُ فَلَمْ يَعُدَّهَا عَلَيْنَا شَيْئًا ‏.‏\hadithno{3445}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah gave us the choice and we chose him, and that was not counted as anything}}
\hadithdefcmd{nasai}{3446}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا ابْنُ مَوْهَبٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ كَانَ لِعَائِشَةَ غُلاَمٌ وَجَارِيَةٌ قَالَتْ فَأَرَدْتُ أَنْ أُعْتِقَهُمَا فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ ابْدَئِي بِالْغُلاَمِ قَبْلَ الْجَارِيَةِ ‏"‏ ‏.‏\hadithno{3446}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Al-Qasim bin Muhammad said:"Aishah had a male slave and a female slave. She said: 'I wanted to set them free, and I mentioned that to the Messenger of Allah. He said: Start with the male slave before the female slave}}
\hadithdefcmd{nasai}{3447}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ فِي بَرِيرَةَ ثَلاَثُ سُنَنٍ إِحْدَى السُّنَنِ أَنَّهَا أُعْتِقَتْ فَخُيِّرَتْ فِي زَوْجِهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ وَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْبُرْمَةُ تَفُورُ بِلَحْمٍ فَقُرِّبَ إِلَيْهِ خُبْزٌ وَأُدْمٌ مِنْ أُدْمِ الْبَيْتِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَمْ أَرَ بُرْمَةً فِيهَا لَحْمٌ ‏"‏ ‏.‏ فَقَالُوا بَلَى يَا رَسُولَ اللَّهِ ذَلِكَ لَحْمٌ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ وَأَنْتَ لاَ تَأْكُلُ الصَّدَقَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ عَلَيْهَا صَدَقَةٌ وَهُوَ لَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{3447}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah, the wife of the Prophet, said:Three Sunan were established because of Barirah. One of those Sunan was that she was set free and was given the choice concerning her husband; the Messenger of Allah said: 'Al Wala' is to the one who set the slave free;' and the Messenger of Allah entered when some meat was being cooked in a pot, but bread and some condiments were brought to him. He said: 'Do I not see a pot in which some meat is being cooked?' They said: 'Yes, O Messenger of Allah, that is meat that was given in charity to Barirah and you do not eat (food given in) charity.' The Messenger of Allah said: 'It is charity for her and a gift for us}}
\hadithdefcmd{nasai}{3448}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ فِي بَرِيرَةَ ثَلاَثُ قَضِيَّاتٍ أَرَادَ أَهْلُهَا أَنْ يَبِيعُوهَا وَيَشْتَرِطُوا الْوَلاَءَ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ اشْتَرِيهَا وَأَعْتِقِيهَا فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ وَأُعْتِقَتْ فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَارَتْ نَفْسَهَا وَكَانَ يُتَصَدَّقُ عَلَيْهَا فَتُهْدِي لَنَا مِنْهُ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ كُلُوهُ فَإِنَّهُ عَلَيْهَا صَدَقَةٌ وَهُوَ لَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{3448}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Three judgments were established because of Barirah. Her masters wanted to sell her but they stipulated that Al-Wala should still be to them. I mentioned that to the Prophet and he said: 'Buy her and set her free, for Al-Wala, is to the one who sets the slave free.' She was set free and the Messenger of Allah gave her the choice, and she chose herself. And she used to be given charity and she would give some of it as a gift to us. I mentioned that to the Prophet and he said: 'Eat it for it is charity for her and a gift for us}}
\hadithdefcmd{nasai}{3449}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتِ اشْتَرَيْتُ بَرِيرَةَ فَاشْتَرَطَ أَهْلُهَا وَلاَءَهَا فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَعْتِقِيهَا فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْطَى الْوَرِقَ ‏"‏ ‏.‏ قَالَتْ فَأَعْتَقْتُهَا فَدَعَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَيَّرَهَا مِنْ زَوْجِهَا قَالَتْ لَوْ أَعْطَانِي كَذَا وَكَذَا مَا أَقَمْتُ عِنْدَهُ ‏.‏ فَاخْتَارَتْ نَفْسَهَا وَكَانَ زَوْجُهَا حُرًّا ‏.‏\hadithno{3449}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"I bought Barirah and her masters stipulated that her Wala' should go to them. I mentioned that to the Prophet and he said: 'Set her free, and Al-Wala' is to the one who pays the silver.' So I set her free and the Messenger of Allah called her and gave her the choice concerning her husband. She said: 'Even if you gave me such and such, I would not stay with him,' so she chose herself and her husband was a free man}}
\hadithdefcmd{nasai}{3450}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ، بَرِيرَةَ فَاشْتَرَطُوا وَلاَءَهَا فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ اشْتَرِيهَا وَأَعْتِقِيهَا فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ وَأُتِيَ بِلَحْمٍ فَقِيلَ إِنَّ هَذَا مِمَّا تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ ‏.‏ فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏ وَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ زَوْجُهَا حُرًّا ‏.‏\hadithno{3450}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that she wanted to buy Barirah, but her masters stipulated that her Wala' should go to them. She mentioned that to the Prophet and he said:"Buy her and set her free, for Al-Wala' is to the one who sets the slave free." Some meat was brought and it was said: "This is some of that which was given in charity to Barirah." He said: "It is charity for her and a gift for us." And the Messenger of Allah gave her the choice, and her husband was a free man}}
\hadithdefcmd{nasai}{3451}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَاتَبَتْ بَرِيرَةُ عَلَى نَفْسِهَا بِتِسْعِ أَوَاقٍ فِي كُلِّ سَنَةٍ بِأُوقِيَّةٍ فَأَتَتْ عَائِشَةَ تَسْتَعِينُهَا فَقَالَتْ لاَ إِلاَّ أَنْ يَشَاءُوا أَنْ أَعُدَّهَا لَهُمْ عَدَّةً وَاحِدَةً وَيَكُونُ الْوَلاَءُ لِي ‏.‏ فَذَهَبَتْ بَرِيرَةُ فَكَلَّمَتْ فِي ذَلِكَ أَهْلَهَا فَأَبَوْا عَلَيْهَا إِلاَّ أَنْ يَكُونَ الْوَلاَءُ لَهُمْ فَجَاءَتْ إِلَى عَائِشَةَ وَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ فَقَالَتْ لَهَا مَا قَالَ أَهْلُهَا فَقَالَتْ لاَهَا اللَّهِ إِذًا إِلاَّ أَنْ يَكُونَ الْوَلاَءُ لِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ بَرِيرَةَ أَتَتْنِي تَسْتَعِينُ بِي عَلَى كِتَابَتِهَا فَقُلْتُ لاَ إِلاَّ أَنْ يَشَاءُوا أَنْ أَعُدَّهَا لَهُمْ عَدَّةً وَاحِدَةً وَيَكُونُ الْوَلاَءُ لِي فَذَكَرَتْ ذَلِكَ لأَهْلِهَا فَأَبَوْا عَلَيْهَا إِلاَّ أَنْ يَكُونَ الْوَلاَءُ لَهُمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ابْتَاعِيهَا وَاشْتَرِطِي لَهُمُ الْوَلاَءَ فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ ثُمَّ قَامَ فَخَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ مَا بَالُ أَقْوَامٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ يَقُولُونَ أَعْتِقْ فُلاَنًا وَالْوَلاَءُ لِي كِتَابُ اللَّهِ عَزَّ وَجَلَّ أَحَقُّ وَشَرْطُ اللَّهِ أَوْثَقُ وَكُلُّ شَرْطٍ لَيْسَ فِي كِتَابِ اللَّهِ فَهُوَ بَاطِلٌ وَإِنْ كَانَ مِائَةَ شَرْطٍ ‏"‏ ‏.‏ فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ زَوْجِهَا وَكَانَ عَبْدًا فَاخْتَارَتْ نَفْسَهَا ‏.‏ قَالَ عُرْوَةُ فَلَوْ كَانَ حُرًّا مَا خَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3451}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"Barirah made a contract that she would be freed in return for nine Awaq, one Uqiyyah to be paid each year." She came to 'Aishah asking for help and she said: "No, not unless they agree to accept the sum in one payment, and that the Wala' will go to me." Barirah went and spoke to her masters but they insisted that the Wala' should be for them. She came to 'Aishah and the Messenger of Allah came, and she told her what her masters had said. She said: "No, by Allah, not unless Wala' is to me." The Messenger of Allah said: "What is this?" She said: "O Messenger of Allah, Barirah came to me and asked me to help her with her contract of manumission, and I said no, not unless they agree to accept the sum in one payment, and that the Wala' will be for me. She mentioned that to her masters and they insisted that the Wala' should be for them." The Messenger of Allah said: "Buy her, and stipulate that the Wala' is for the one who sets the slave free." Then he stood up and addressed the people and said: "What is the matter with people who stipulate conditions that are not in the Book of Allah, the Mighty and Sublime? They say: 'I set so-and-so free but the Wala' will be to me.' Every condition that is not in the Book of Allah, the Mighty and Sublime, is a false condition, even if there are a hundred conditions." And the Messenger of Allah gave her the choice with regard to her husband who was still a slave, and she chose herself. 'Urwah said: "If he had been free the Messenger of Allah would not have given her the choice}}
\hadithdefcmd{nasai}{3452}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمُغِيرَةُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ زَوْجُ بَرِيرَةَ عَبْدًا ‏.‏\hadithno{3452}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah, may Allah be pleased with her, said:"The husband of Barirah was a slave}}
\hadithdefcmd{nasai}{3453}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ سِمَاكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا اشْتَرَتْ بَرِيرَةَ مِنْ أُنَاسٍ مِنَ الأَنْصَارِ فَاشْتَرَطُوا الْوَلاَءَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَلاَءُ لِمَنْ وَلِيَ النِّعْمَةَ ‏"‏ ‏.‏ وَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ زَوْجُهَا عَبْدًا وَأَهْدَتْ لِعَائِشَةَ لَحْمًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ وَضَعْتُمْ لَنَا مِنْ هَذَا اللَّحْمِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ ‏.‏ فَقَالَ ‏"‏ هُوَ عَلَيْهَا صَدَقَةٌ وَهُوَ لَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{3453}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that she bought Barirah from some of the Ansar who stipulated that her Wala' should go to them. The Messenger of Allah said:"Al-Wala' is to the one who did the favor (of setting the slave free)." The Messenger of Allah gave her the choice, as her husband was a slave. And she gave some meat to 'Aishah as a gift, and the Messenger of Allah said: "Why don't you give me some of this meat?" 'Aishah said: "It was given in charity to Barirah." He said: "It is a charity for her, and a gift for us}}
\hadithdefcmd{nasai}{3454}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ الْكَرْمَانِيُّ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - قَالَ وَكَانَ وَصِيَّ أَبِيهِ قَالَ وَفَرِقْتُ أَنْ أَقُولَ، سَمِعْتُهُ مِنْ، أَبِيكَ - قَالَتْ عَائِشَةُ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ بَرِيرَةَ وَأَرَدْتُ أَنْ أَشْتَرِيَهَا وَاشْتُرِطَ الْوَلاَءُ لأَهْلِهَا فَقَالَ ‏"‏ اشْتَرِيهَا فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ قَالَ وَخُيِّرَتْ وَكَانَ زَوْجُهَا عَبْدًا ثُمَّ قَالَ بَعْدَ ذَلِكَ مَا أَدْرِي وَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلَحْمٍ ‏.‏ فَقَالُوا هَذَا مِمَّا تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ ‏.‏ قَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{3454}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Yahya bin Abi Bukair Al-Karmani said:"Shu'bah narrated to us, from 'Abdur-Rahman bin Al-Qasim, from his father, from 'Aishah. He (Shu'bah) said: "And he ('Abdur-Rahman) was the executor for his father." He (Shu'bah) said: "I was afraid to say to him: 'Did you hear this from your father.'" -- 'Aishah said: "I asked the Messenger of Allah about Barirah, as I wanted to buy her but it was stipulated that the Wala' would go to her (former) masters. He said: 'Buy her, for the Wala' is to the one who sets the slave free.' And she was given the choice, as her husband was a slave." Then he said, after that: "I do not know." --"And some meat was brought to the Messenger of Allah and they said: 'This is some of that which was given in charity to Barirah.' He said: 'It is charity for her and a gift for us}}
\hadithdefcmd{nasai}{3455}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ الْبَصْرِيُّ، قَالَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، قَالَ حَدَّثَنَا أَبُو يَعْفُورٍ، عَنْ أَبِي الضُّحَى، قَالَ تَذَاكَرْنَا الشَّهْرَ عِنْدَهُ فَقَالَ بَعْضُنَا ثَلاَثِينَ ‏.‏ وَقَالَ بَعْضُنَا تِسْعًا وَعِشْرِينَ ‏.‏ فَقَالَ أَبُو الضُّحَى حَدَّثَنَا ابْنُ عَبَّاسٍ قَالَ أَصْبَحْنَا يَوْمًا وَنِسَاءُ النَّبِيِّ صلى الله عليه وسلم يَبْكِينَ عِنْدَ كُلِّ امْرَأَةٍ مِنْهُنَّ أَهْلُهَا فَدَخَلْتُ الْمَسْجِدَ فَإِذَا هُوَ مَلآنُ مِنَ النَّاسِ - قَالَ - فَجَاءَ عُمَرُ رضى الله عنه فَصَعِدَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ فِي عُلِّيَّةٍ لَهُ فَسَلَّمَ عَلَيْهِ فَلَمْ يُجِبْهُ أَحَدٌ ثُمَّ سَلَّمَ فَلَمْ يُجِبْهُ أَحَدٌ ثُمَّ سَلَّمَ فَلَمْ يُجِبْهُ أَحَدٌ فَرَجَعَ فَنَادَى بِلاَلاً فَدَخَلَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَطَلَّقْتَ نِسَاءَكَ فَقَالَ ‏ "‏ لاَ وَلَكِنِّي آلَيْتُ مِنْهُنَّ شَهْرًا ‏"‏ ‏.‏ فَمَكَثَ تِسْعًا وَعِشْرِينَ ثُمَّ نَزَلَ فَدَخَلَ عَلَى نِسَائِهِ ‏.‏\hadithno{3455}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn 'Abbas said:"One morning, we saw the wives of the Prophet weeping, and each one of them had her family with her. I entered the Masjid and found it filled with people. Then 'Umar, may Allah be pleased with him, came, and went to the Prophet who was in his room. He greeted him with the Salam but no one answered. He greeted him again but no one answered. He greeted him (a third time) but no one answered. So he went back and called out: 'Bilal!' He came to the Prophet and said: 'Have you divorced your wives?' He said: 'No, but I have sworn an oath of abstention from them for a month.' So he stayed away from them for twenty-nine days, then he came and went into his wives}}
\hadithdefcmd{nasai}{3456}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ آلَى النَّبِيُّ صلى الله عليه وسلم مِنْ نِسَائِهِ شَهْرًا فِي مَشْرَبَةٍ لَهُ فَمَكَثَ تِسْعًا وَعِشْرِينَ لَيْلَةً ثُمَّ نَزَلَ فَقِيلَ يَا رَسُولَ اللَّهِ أَلَيْسَ آلَيْتَ عَلَى شَهْرٍ قَالَ ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏\hadithno{3456}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The Prophet swore an oath of abstention from his wives for a month and stayed in his room for twenty-nine days. It was said: 'O Messenger of Allah, did you not swear an oath of abstention for a month?' He said: 'This month is twenty-nine days}}
\hadithdefcmd{nasai}{3457}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مَعْمَرٍ، عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم قَدْ ظَاهَرَ مِنِ امْرَأَتِهِ فَوَقَعَ عَلَيْهَا فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي ظَاهَرْتُ مِنِ امْرَأَتِي فَوَقَعْتُ قَبْلَ أَنْ أُكَفِّرَ ‏.‏ قَالَ ‏"‏ وَمَا حَمَلَكَ عَلَى ذَلِكَ يَرْحَمُكَ اللَّهُ ‏"‏ ‏.‏ قَالَ رَأَيْتُ خَلْخَالَهَا فِي ضَوْءِ الْقَمَرِ ‏.‏ فَقَالَ ‏"‏ لاَ تَقْرَبْهَا حَتَّى تَفْعَلَ مَا أَمَرَ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3457}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that a man came to the Prophet who had declared Zihar from his wife, then he had intercourse with her. He said:"O Messenger of Allah, I declared Zihar on my wife, then I had intercourse with her before I offered the expiation." He said: "What made you do that, may Allah have mercy on you?" He said: "I saw her anklets in the light of the moon." He said: "Do not approach her until you have done that which Allah, the Mighty and Sublime, has commanded}}
\hadithdefcmd{nasai}{3458}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، قَالَ تَظَاهَرَ رَجُلٌ مِنِ امْرَأَتِهِ فَأَصَابَهَا قَبْلَ أَنْ يُكَفِّرَ فَذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا حَمَلَكَ عَلَى ذَلِكَ ‏"‏ ‏.‏ قَالَ رَحِمَكَ اللَّهُ يَا رَسُولَ اللَّهِ رَأَيْتُ خَلْخَالَهَا أَوْ سَاقَيْهَا فِي ضَوْءِ الْقَمَرِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَاعْتَزِلْهَا حَتَّى تَفْعَلَ مَا أَمَرَكَ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3458}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ikrimah said:"A man declared Zihar to his wife, then had intercourse with her before he had offered the expiation. He mentioned that to the Prophet. The Prophet said to him: 'What made you do that?' He said: 'May Allah have mercy on you, O Messenger of Allah. I saw her anklets, or her calves, in the light of the moon.' The Messenger of Allah said: 'Keep away from her until you have done that which Allah, the Mighty and Sublime, has commanded}}
\hadithdefcmd{nasai}{3459}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمُعْتَمِرُ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ الْحَكَمَ بْنَ أَبَانَ، قَالَ سَمِعْتُ عِكْرِمَةَ، قَالَ أَتَى رَجُلٌ نَبِيَّ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ إِنَّهُ ظَاهَرَ مِنِ امْرَأَتِهِ ثُمَّ غَشِيَهَا قَبْلَ أَنْ يَفْعَلَ مَا عَلَيْهِ ‏.‏ قَالَ ‏"‏ مَا حَمَلَكَ عَلَى ذَلِكَ ‏"‏ ‏.‏ قَالَ يَا نَبِيَّ اللَّهِ رَأَيْتُ بَيَاضَ سَاقَيْهَا فِي الْقَمَرِ ‏.‏ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَاعْتَزِلْ حَتَّى تَقْضِيَ مَا عَلَيْكَ ‏"‏ ‏.‏ وَقَالَ إِسْحَاقُ فِي حَدِيثِهِ ‏"‏ فَاعْتَزِلْهَا حَتَّى تَقْضِيَ مَا عَلَيْكَ ‏"‏ ‏.‏ وَاللَّفْظُ لِمُحَمَّدٍ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الْمُرْسَلُ أَوْلَى بِالصَّوَابِ مِنَ الْمُسْنَدِ وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{3459}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ikrimah said:"A man came to the Prophet of Allah and said: 'O Prophet of Allah,' and that he had declared Zihar to his wife, then he had intercourse with her before he did what he had to do. He said: 'What made you do that?' He said: 'O Prophet of Allah! I saw the whiteness of her calves in the moonlight.' The Prophet said: 'Keep away until you have done what you have to do.' (One of the narrators) Ishaq said in his Hadith: "Keep away from her until you have done what you have to do." The wording is that of Muhammad}}
\hadithdefcmd{nasai}{3460}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتِ الْحَمْدُ لِلَّهِ الَّذِي وَسِعَ سَمْعُهُ الأَصْوَاتَ لَقَدْ جَاءَتْ خَوْلَةُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم تَشْكُو زَوْجَهَا فَكَانَ يَخْفَى عَلَىَّ كَلاَمُهَا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ قَدْ سَمِعَ اللَّهُ قَوْلَ الَّتِي تُجَادِلُكَ فِي زَوْجِهَا وَتَشْتَكِي إِلَى اللَّهِ وَاللَّهُ يَسْمَعُ تَحَاوُرَكُمَا ‏\}‏ الآيَةَ ‏.‏\hadithno{3460}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that she said:"Praise be to Allah Whose hearing encompasses all voices. Khawlah came to the Messenger of Allah complaining about her husband, but I could not hear what she said. Then Allah, the Mighty and Sublime, revealed: 'Indeed Allah has heard the statement of her that disputes with you concerning her husband, and complains to Allah. And Allah hears the argument between you both}}
\hadithdefcmd{nasai}{3461}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمَخْزُومِيُّ، - وَهُوَ الْمُغِيرَةُ بْنُ سَلَمَةَ - قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْمُنْتَزِعَاتُ وَالْمُخْتَلِعَاتُ هُنَّ الْمُنَافِقَاتُ ‏"‏ ‏.‏ قَالَ الْحَسَنُ لَمْ أَسْمَعْهُ مِنْ غَيْرِ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الْحَسَنُ لَمْ يَسْمَعْ مِنْ أَبِي هُرَيْرَةَ شَيْئًا ‏.‏\hadithno{3461}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ayyub, from Al-Hasan, from Abu Hurairah, that the Prophet said:"Women who seek divorce and Khul' are like the female hypocrites." Al-Hasan said: "I did not hear it from anyone other than Abu Hurairah}}
\hadithdefcmd{nasai}{3462}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا أَخْبَرَتْهُ عَنْ حَبِيبَةَ بِنْتِ سَهْلٍ، أَنَّهَا كَانَتْ تَحْتَ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ وَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الصُّبْحِ فَوَجَدَ حَبِيبَةَ بِنْتَ سَهْلٍ عِنْدَ بَابِهِ فِي الْغَلَسِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ قَالَتْ أَنَا حَبِيبَةُ بِنْتُ سَهْلٍ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ مَا شَأْنُكِ ‏"‏ ‏.‏ قَالَتْ لاَ أَنَا وَلاَ ثَابِتُ بْنُ قَيْسٍ ‏.‏ لِزَوْجِهَا فَلَمَّا جَاءَ ثَابِتُ بْنُ قَيْسٍ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذِهِ حَبِيبَةُ بِنْتُ سَهْلٍ قَدْ ذَكَرَتْ مَا شَاءَ اللَّهُ أَنْ تَذْكُرَ ‏"‏ ‏.‏ فَقَالَتْ حَبِيبَةُ يَا رَسُولَ اللَّهِ كُلُّ مَا أَعْطَانِي عِنْدِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِثَابِتٍ ‏"‏ خُذْ مِنْهَا ‏"‏ ‏.‏ فَأَخَذَ مِنْهَا وَجَلَسَتْ فِي أَهْلِهَا ‏.‏\hadithno{3462}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Yahya bin Sa'eed, from 'Amrah bint 'Abdur-Rahman, that she told him about Habibah bint Sahl:"She was married to Thabit bin Qais bin Shammas. The Messenger of Allah went out to pray As-Subh and he found Habibah bint Sahl at his door at the end of the night. The Messenger of Allah said: 'Who is this?' She said: 'I am Habibah bint Sahl, O Messenger of Allah.' He said: 'What is the matter?' She said: 'I cannot live with Thabit bin Qais' -her husband. When Thabit bin Qais came, the Messenger of Allah said to him: 'Here is Habibah bint Sahl and she has said what Allah willed she should say.' Habibah said: 'O Messenger of Allah, everything that he gave me is with me.' The Messenger of Allah said: 'Take it from her.' So he took it from her and she stayed with her family}}
\hadithdefcmd{nasai}{3463}{أَخْبَرَنَا أَزْهَرُ بْنُ جَمِيلٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةَ، ثَابِتِ بْنِ قَيْسٍ أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ ثَابِتُ بْنُ قَيْسٍ أَمَا إِنِّي مَا أَعِيبُ عَلَيْهِ فِي خُلُقٍ وَلاَ دِينٍ وَلَكِنِّي أَكْرَهُ الْكُفْرَ فِي الإِسْلاَمِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَرُدِّينَ عَلَيْهِ حَدِيقَتَهُ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْبَلِ الْحَدِيقَةَ وَطَلِّقْهَا تَطْلِيقَةً ‏"‏ ‏.‏\hadithno{3463}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that the wife of Thabit bin Qais came to the Prophet and said:"O Messenger of Allah, I do not find any fault with Thabit bin Qais regarding his attitude or religious commitment, but I hate Kufr after becoming Muslim." The Messenger of Allah said: "Will you give him back his garden?" She said: "Yes." The Messenger of Allah said: "Take back the garden and divorce her once}}
\hadithdefcmd{nasai}{3464}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، عَنْ عُمَارَةَ بْنِ أَبِي حَفْصَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ امْرَأَتِي لاَ تَمْنَعُ يَدَ لاَمِسٍ ‏.‏ فَقَالَ ‏"‏ غَرِّبْهَا إِنْ شِئْتَ ‏"‏ ‏.‏ قَالَ إِنِّي أَخَافُ أَنْ تَتَّبِعَهَا نَفْسِي ‏.‏ قَالَ ‏"‏ اسْتَمْتِعْ بِهَا ‏"‏ ‏.‏\hadithno{3464}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"A man came to the Messenger of Allah and said: 'My wife does not object if anyone touches her.' He said: 'Divorce her if you wish.' He said: 'I am afraid that I will miss her.' He said: 'Then stay with her as much as you need to}}
\hadithdefcmd{nasai}{3465}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا هَارُونُ بْنُ رِئَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنَّ تَحْتِي امْرَأَةً لاَ تَرُدُّ يَدَ لاَمِسٍ قَالَ ‏"‏ طَلِّقْهَا ‏"‏ ‏.‏ قَالَ إِنِّي لاَ أَصْبِرُ عَنْهَا ‏.‏ قَالَ ‏"‏ فَأَمْسِكْهَا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ مُرْسَلٌ ‏.‏\hadithno{3465}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that a man said:"O Messenger of Allah, I have a wife who does not object if anyone touches her." He said: "Divorce her." He said: "I cannot live without her." He said: "Then keep her}}
\hadithdefcmd{nasai}{3466}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، وَإِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنْ عَاصِمِ بْنِ عَدِيٍّ، قَالَ جَاءَنِي عُوَيْمِرٌ - رَجُلٌ مِنْ بَنِي الْعَجْلاَنِ - فَقَالَ أَىْ عَاصِمُ أَرَأَيْتُمْ رَجُلاً رَأَى مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ يَا عَاصِمُ سَلْ لِي رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَسَأَلَ عَاصِمٌ عَنْ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَعَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ وَكَرِهَهَا ‏.‏ فَجَاءَهُ عُوَيْمِرٌ فَقَالَ مَا صَنَعْتَ يَا عَاصِمُ فَقَالَ صَنَعْتُ أَنَّكَ لَمْ تَأْتِنِي بِخَيْرٍ كَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ وَعَابَهَا ‏.‏ قَالَ عُوَيْمِرٌ وَاللَّهِ لأَسْأَلَنَّ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَانْطَلَقَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِيكَ وَفِي صَاحِبَتِكَ فَائْتِ بِهَا ‏"‏ ‏.‏ قَالَ سَهْلٌ وَأَنَا مَعَ النَّاسِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَ بِهَا فَتَلاَعَنَا فَقَالَ يَا رَسُولَ اللَّهِ وَاللَّهِ لَئِنْ أَمْسَكْتُهَا لَقَدْ كَذَبْتُ عَلَيْهَا ‏.‏ فَفَارَقَهَا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِفِرَاقِهَا فَصَارَتْ سُنَّةَ الْمُتَلاَعِنَيْنِ ‏.‏\hadithno{3466}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sahl bin Sa'd, from 'Asim bin 'Adiyy who said:"Uwaimir, a man from Banu 'Ajlan, came and said: 'O 'Asim, what do you think if a man sees another man with his wife, should he kill him and be killed in retaliation, or what should he do? O 'Asim, ask the Messenger of Allah about that for me.'" So 'Asim asked the Messenger of Allah about that, and the Messenger of Allah disapproved of the question and criticized the asking of too many questions. Then 'Uwaimir came to him and said: "What happened, O 'Asim?" 'Asim said to 'Uwaimir: "What happened?! You have not brought me any good. The Messenger of Allah disapproved of the question I asked." 'Uwaimir said: "By Allah, I will go and ask the Messenger of Allah." So he went to the Messenger of Allah and asked him. The Messenger of Allah said: "Allah the Mighty and Sublime has revealed (something) concerning you and your wife, so bring her here." Sahl said: "I was among the people in the presence of the Messenger of Allah and he brought her and they engaged in the procedure of Li'an. He said: 'O Messenger of Allah, by Allah! If I keep her I would have been telling lies about her.' So he parted from her before the Messenger of Allah told him to separate from her, and that became the way of Li'an}}
\hadithdefcmd{nasai}{3467}{حَدَّثَنَا أَحْمَدُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، قَالَ حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُقْبَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لاَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الْعَجْلاَنِيِّ وَامْرَأَتِهِ وَكَانَتْ حُبْلَى ‏.‏\hadithno{3467}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah conducted the procedure of Li'an between the 'Ajlani and his wife, who was pregnant}}
\hadithdefcmd{nasai}{3468}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الأَعْلَى، قَالَ سُئِلَ هِشَامٌ عَنِ الرَّجُلِ، يَقْذِفُ امْرَأَتَهُ فَحَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنْ ذَلِكَ، وَأَنَا أَرَى، أَنَّ عِنْدَهُ، مِنْ ذَلِكَ عِلْمًا فَقَالَ إِنَّ هِلاَلَ بْنَ أُمَيَّةَ قَذَفَ امْرَأَتَهُ بِشَرِيكِ ابْنِ السَّحْمَاءِ - وَكَانَ أَخُو الْبَرَاءِ بْنِ مَالِكٍ لأُمِّهِ وَكَانَ أَوَّلَ مَنْ لاَعَنَ - فَلاَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا ثُمَّ قَالَ ‏ "‏ ابْصُرُوهُ فَإِنْ جَاءَتْ بِهِ أَبْيَضَ سَبِطًا قَضِيءَ الْعَيْنَيْنِ فَهُوَ لِهِلاَلِ بْنِ أُمَيَّةَ وَإِنْ جَاءَتْ بِهِ أَكْحَلَ جَعْدًا أَحْمَشَ السَّاقَيْنِ فَهُوَ لِشَرِيكِ ابْنِ السَّحْمَاءِ ‏"‏ ‏.‏ قَالَ فَأُنْبِئْتُ أَنَّهَا جَاءَتْ بِهِ أَكْحَلَ جَعْدًا أَحْمَشَ السَّاقَيْنِ ‏.‏\hadithno{3468}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Muhammad said:"I asked Anas bin Malik about that, as I thought that he had knowledge of that. He said: 'Hilal bin Umayyah accused his wife (of committing adultery) with Sharik bin As-Sahma', who was the brother of Al-Bara' bin Malik through his mother. He was the first one who engaged in the procedure of Li'an. The Messenger of Allah conducted the procedure of Li'an between them, then he said: "Look and see, if she produces a child who is white, with straight hair and Qadiy'a eyes, then he belongs to Hilal bin Umayyah, and if she produces a child who has dark lines around his eyes, curly hair and narrow calves, then he belongs to Sharik bin As-Sahma'." I was told that she produced a child who has dark lines around his eyes, curly hair and narrow calves}}
\hadithdefcmd{nasai}{3469}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا مَخْلَدُ بْنُ حُسَيْنٍ الأَزْدِيُّ، قَالَ حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ إِنَّ أَوَّلَ لِعَانٍ كَانَ فِي الإِسْلاَمِ أَنَّ هِلاَلَ بْنَ أُمَيَّةَ قَذَفَ شَرِيكَ ابْنَ السَّحْمَاءِ بِامْرَأَتِهِ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ بِذَلِكَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرْبَعَةَ شُهَدَاءَ وَإِلاَّ فَحَدٌّ فِي ظَهْرِكَ ‏"‏ ‏.‏ يُرَدِّدُ ذَلِكَ عَلَيْهِ مِرَارًا فَقَالَ لَهُ هِلاَلٌ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَيَعْلَمُ أَنِّي صَادِقٌ وَلَيُنْزِلَنَّ اللَّهُ عَزَّ وَجَلَّ عَلَيْكَ مَا يُبَرِّئُ ظَهْرِي مِنَ الْجَلْدِ ‏.‏ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ نَزَلَتْ عَلَيْهِ آيَةُ اللِّعَانِ ‏\{‏ وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ ‏\}‏ إِلَى آخِرِ الآيَةِ فَدَعَا هِلاَلاً فَشَهِدَ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الصَّادِقِينَ وَالْخَامِسَةُ أَنَّ لَعْنَةَ اللَّهِ عَلَيْهِ إِنْ كَانَ مِنَ الْكَاذِبِينَ ثُمَّ دُعِيَتِ الْمَرْأَةُ فَشَهِدَتْ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الْكَاذِبِينَ فَلَمَّا أَنْ كَانَ فِي الرَّابِعَةِ أَوِ الْخَامِسَةِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَقِّفُوهَا فَإِنَّهَا مُوجِبَةٌ ‏"‏ ‏.‏ فَتَلَكَّأَتْ حَتَّى مَا شَكَكْنَا أَنَّهَا سَتَعْتَرِفُ ثُمَّ قَالَتْ لاَ أَفْضَحُ قَوْمِي سَائِرَ الْيَوْمِ ‏.‏ فَمَضَتْ عَلَى الْيَمِينِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْظُرُوهَا فَإِنْ جَاءَتْ بِهِ أَبْيَضَ سَبِطًا قَضِيءَ الْعَيْنَيْنِ فَهُوَ لِهِلاَلِ بْنِ أُمَيَّةَ وَإِنْ جَاءَتْ بِهِ آدَمَ جَعْدًا رَبْعًا حَمْشَ السَّاقَيْنِ فَهُوَ لِشَرِيكِ ابْنِ السَّحْمَاءِ ‏"‏ ‏.‏ فَجَاءَتْ بِهِ آدَمَ جَعْدًا رَبْعًا حَمْشَ السَّاقَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْلاَ مَا سَبَقَ فِيهَا مِنْ كِتَابِ اللَّهِ لَكَانَ لِي وَلَهَا شَأْنٌ ‏"‏ ‏.‏ قَالَ الشَّيْخُ وَالْقَضِيءُ طَوِيلُ شَعْرِ الْعَيْنَيْنِ لَيْسَ بِمَفْتُوحِ الْعَيْنِ وَلاَ جَاحِظِهِمَا وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{3469}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The first Li'an in Islam was when Hilal bin Umayyah accused Sharik bin As-Sahma' (of committing adultery) with his wife. He came to the Prophet and told him about that. The Prophet said: '(Bring) four witnesses, otherwise (you will feel) the Hadd punishment on your back.' And he repeated that several times. Hilal said to him: 'By Allah, O Messenger of Allah! Allah, the Mighty and Sublime, knows that I am telling the truth, and Allah, the Mighty and Sublime, will certainly reveal to you that which will spare my back from the whip.' While they were like that, the Verse of Li'an was revealed to him: 'As to those who accuse their wives.' He called Hilal and he bore witness four times by Allah that he was telling the truth, and the fifth time he invoked the curse of Allah upon him if he were lying. Then he called the woman and she bore witness four times by Allah that he was lying. When it came to the fourth or fifth time, the Messenger of Allah said: 'Stop her, for it will inevitably bring the punishment of Allah upon the liar.' She hesitated until we thought that she was going to confess, then she said: 'I will not dishonor my people today.' Then she went ahead with the oath. The Messenger of Allah said: 'Wait and see. If she produces a child who is white, with straight hair and Qadiy'a eyes, then he belongs to Hilal bin Umayyah, but if she produces a child who is dark with curly hair, of average size and with narrow calves, then he belongs to Sharik bin As-Sahma'.' She produced a child who was dark with curly hair, of average size and with narrow calves. The Messenger of Allah said: 'Had not the matter been settled by the Book of Allah, I would have punished her severely}}
\hadithdefcmd{nasai}{3470}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ ذُكِرَ التَّلاَعُنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمُ بْنُ عَدِيٍّ فِي ذَلِكَ قَوْلاً ثُمَّ انْصَرَفَ فَأَتَاهُ رَجُلٌ مِنْ قَوْمِهِ يَشْكُو إِلَيْهِ أَنَّهُ وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً قَالَ عَاصِمٌ مَا ابْتُلِيتُ بِهَذَا إِلاَّ بِقَوْلِي فَذَهَبَ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِالَّذِي وَجَدَ عَلَيْهِ امْرَأَتَهُ وَكَانَ ذَلِكَ الرَّجُلُ مُصْفَرًّا قَلِيلَ اللَّحْمِ سَبِطَ الشَّعَرِ وَكَانَ الَّذِي ادَّعَى عَلَيْهِ أَنَّهُ وَجَدَهُ عِنْدَ أَهْلِهِ آدَمَ خَدْلاً كَثِيرَ اللَّحْمِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَيِّنْ ‏"‏ ‏.‏ فَوَضَعَتْ شَبِيهًا بِالرَّجُلِ الَّذِي ذَكَرَ زَوْجُهَا أَنَّهُ وَجَدَهُ عِنْدَهَا فَلاَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا ‏.‏ فَقَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ فِي الْمَجْلِسِ أَهِيَ الَّتِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ رَجَمْتُ أَحَدًا بِغَيْرِ بَيِّنَةٍ رَجَمْتُ هَذِهِ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ لاَ تِلْكَ امْرَأَةٌ كَانَتْ تُظْهِرُ فِي الإِسْلاَمِ الشَّرَّ ‏.‏\hadithno{3470}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"Mention of Li'an was made in the presence of the Messenger of Allah and 'Asim bin 'Adiyy said something about that, then he went away. A man from among his people came to him, complaining that he had found a man with his wife. 'Asim said: 'I was only put to this test because of what I said.' He took him to the Messenger of Allah and told him of the situation in which he found his wife. That man was pale and slim with straight hair, and the one whom he claimed to have found with his wife was dark and well-built. The Messenger of Allah said: 'O Allah, make it clear to me.' Then she gave birth to a child who resembled the one whom her husband said he had found with her. So the Messenger of Allah conducted the procedure of Li'an between them." A man in the gathering said to Ibn 'Abbas: "Was she the one of whom the Messenger of Allah said: 'If I were to have stoned anyone without evidence I would have stoned this one?'" Ibn 'Abbas said: "No, that was a woman who used to do mischief even after becoming Muslim}}
\hadithdefcmd{nasai}{3471}{أَخْبَرَنَا يَحْيَى بْنُ مُحَمَّدِ بْنِ السَّكَنِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَهْضَمٍ، عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، عَنْ يَحْيَى، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ ذُكِرَ التَّلاَعُنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمُ بْنُ عَدِيٍّ فِي ذَلِكَ قَوْلاً ثُمَّ انْصَرَفَ فَلَقِيَهُ رَجُلٌ مِنْ قَوْمِهِ فَذَكَرَ أَنَّهُ وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَذَهَبَ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِالَّذِي وَجَدَ عَلَيْهِ امْرَأَتَهُ وَكَانَ ذَلِكَ الرَّجُلُ مُصْفَرًّا قَلِيلَ اللَّحْمِ سَبِطَ الشَّعْرِ وَكَانَ الَّذِي ادَّعَى عَلَيْهِ أَنَّهُ وَجَدَ عِنْدَ أَهْلِهِ آدَمَ خَدْلاً كَثِيرَ اللَّحْمِ جَعْدًا قَطَطًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَيِّنْ ‏"‏ ‏.‏ فَوَضَعَتْ شَبِيهًا بِالَّذِي ذَكَرَ زَوْجُهَا أَنَّهُ وَجَدَهُ عِنْدَهَا فَلاَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا فَقَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ فِي الْمَجْلِسِ أَهِيَ الَّتِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ رَجَمْتُ أَحَدًا بِغَيْرِ بَيِّنَةٍ رَجَمْتُ هَذِهِ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ لاَ تِلْكَ امْرَأَةٌ كَانَتْ تُظْهِرُ الشَّرَّ فِي الإِسْلاَمِ ‏.‏\hadithno{3471}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Abbas said:"Mention of Li'an was made in the presence of the Messenger of Allah and 'Asim bin 'Adiyy said something about that, then he went away. He was met by a man from among his people who told him that he had found a man with his wife. He took him to the Messenger of Allah and told him of the situation in which he found his wife. That man was pale and slim with straight hair, and the one whom he claimed to have found with his wife was dark and well built, with very curly hair. The Messenger of Allah said: 'O Allah, make it clear to me.' Then she gave birth to a child who resembled the one whom her husband said he had found with her. So the Messenger of Allah conducted the procedure of Li'an between them." A man in the gathering said to Ibn 'Abbas: "Was she the one of whom the Messenger of Allah said: 'If I were to have stoned anyone without evidence I would have stoned this one?'" Ibn 'Abbas said: "No, that was a woman who used to do mischief even after becoming Muslim}}
\hadithdefcmd{nasai}{3472}{أَخْبَرَنَا عَلِيُّ بْنُ مَيْمُونٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ رَجُلاً حِينَ أَمَرَ الْمُتَلاَعِنَيْنِ أَنْ يَتَلاَعَنَا أَنْ يَضَعَ يَدَهُ عِنْدَ الْخَامِسَةِ عَلَى فِيهِ وَقَالَ ‏ "‏ إِنَّهَا مُوجِبَةٌ ‏"‏ ‏.‏\hadithno{3472}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas:"When the Prophet commanded the two who were engaging in Li'an to utter the fifth oath, he commanded a man to place his hand over his mouth, and he said: "It will inevitably bring the punishment upon the liar}}
\hadithdefcmd{nasai}{3473}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، يَقُولُ سُئِلْتُ عَنِ الْمُتَلاَعِنَيْنِ، فِي إِمَارَةِ ابْنِ الزُّبَيْرِ أَيُفَرَّقُ بَيْنَهُمَا فَمَا دَرَيْتُ مَا أَقُولُ فَقُمْتُ مِنْ مَقَامِي إِلَى مَنْزِلِ ابْنِ عُمَرَ فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ الْمُتَلاَعِنَيْنِ أَيُفَرَّقُ بَيْنَهُمَا قَالَ نَعَمْ ‏.‏ سُبْحَانَ اللَّهِ إِنَّ أَوَّلَ مَنْ سَأَلَ عَنْ ذَلِكَ فُلاَنُ بْنُ فُلاَنٍ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ - وَلَمْ يَقُلْ عَمْرٌو أَرَأَيْتَ - الرَّجُلَ مِنَّا يَرَى عَلَى امْرَأَتِهِ فَاحِشَةً إِنْ تَكَلَّمَ فَأَمْرٌ عَظِيمٌ - وَقَالَ عَمْرٌو أَتَى أَمْرًا عَظِيمًا - وَإِنْ سَكَتَ سَكَتَ عَلَى مِثْلِ ذَلِكَ ‏.‏ فَلَمْ يُجِبْهُ فَلَمَّا كَانَ بَعْدَ ذَلِكَ أَتَاهُ فَقَالَ إِنَّ الأَمْرَ الَّذِي سَأَلْتُكَ ابْتُلِيتُ بِهِ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ هَؤُلاَءِ الآيَاتِ فِي سُورَةِ النُّورِ ‏\{‏ وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ ‏\}‏ حَتَّى بَلَغَ ‏\{‏ وَالْخَامِسَةَ أَنَّ غَضَبَ اللَّهِ عَلَيْهَا إِنْ كَانَ مِنَ الصَّادِقِينَ ‏\}‏ فَبَدَأَ بِالرَّجُلِ فَوَعَظَهُ وَذَكَّرَهُ وَأَخْبَرَهُ أَنَّ عَذَابَ الدُّنْيَا أَهْوَنُ مِنْ عَذَابِ الآخِرَةِ فَقَالَ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا كَذَبْتُ ‏.‏ ثُمَّ ثَنَّى بِالْمَرْأَةِ فَوَعَظَهَا وَذَكَّرَهَا فَقَالَتْ وَالَّذِي بَعَثَكَ بِالْحَقِّ إِنَّهُ لَكَاذِبٌ فَبَدَأَ بِالرَّجُلِ فَشَهِدَ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الصَّادِقِينَ وَالْخَامِسَةُ أَنَّ لَعْنَةَ اللَّهِ عَلَيْهِ إِنْ كَانَ مِنَ الْكَاذِبِينَ ثُمَّ ثَنَّى بِالْمَرْأَةِ فَشَهِدَتْ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الْكَاذِبِينَ وَالْخَامِسَةَ أَنَّ غَضَبَ اللَّهِ عَلَيْهَا إِنْ كَانَ مِنَ الصَّادِقِينَ فَفَرَّقَ بَيْنَهُمَا ‏.‏\hadithno{3473}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdul-Malik bin Abi Sulaiman said:"I heard Sa'eed bin Jubair say: 'I was asked about the two who engage in Li'an during the governorship of Ibn Az-Zubair - should they be separated? I did not know what to say, so I got up and went to the house of Ibn 'Umar and said: "O Abu 'Abdur-Rahman, should the two who engage in Li'an be separated?" He said: "Yes, Subhan Allah! The first one who asked about that was so-and-so the son of so-and-so who said: 'O Messenger of Allah, what do you think if a man among us sees his wife committing immoral actions, and if he speaks of it, he will be speaking of a grave matter, but if he keeps quiet, he will be keeping quiet about a grave matter?' He did not answer him, then after that, he came to him and said: 'I was tried with the matter that I asked you about, so Allah, the Mighty and Sublime, revealed these Verses in Surat An-Nur.: 'And for those who accuse their wives' until he reached: 'And the fifth (testimony) should be that the Wrath of Allah be upon her if he (her husband) speaks the truth.' So he started with the man, exhorting him, reminding him, and telling him that the punishment in this world was less severe than the punishment in the Hereafter. He said: 'By the One Who sent you with the truth, I am not lying.' Then he turned to the woman and exhorted her and reminded her. She said: 'By the One Who sent you with the truth, he is lying.' So he started with the man, and he bore witness four times by Allah that he was telling the truth, and the fifth time (he invoked) the curse of Allah upon himself if he was lying. Then he turned to the woman and she bore witness four times by Allah that he was lying, and the fifth time (she invoked) the wrath of Allah upon herself if he was telling the truth. Then he separated them}}
\hadithdefcmd{nasai}{3474}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ لَمْ يُفَرِّقِ الْمُصْعَبُ بَيْنَ الْمُتَلاَعِنَيْنِ ‏.‏ قَالَ سَعِيدٌ فَذَكَرْتُ ذَلِكَ لاِبْنِ عُمَرَ فَقَالَ فَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَخَوَىْ بَنِي الْعَجْلاَنِ ‏.‏\hadithno{3474}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"Al-Mus'ab did not separate the two who engaged in Li'an." Sa'eed said: "I mentioned that to Ibn 'Umar and he said: 'The Messenger of Allah separated the couple from Banu 'Ajlan}}
\hadithdefcmd{nasai}{3475}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَجُلٌ قَذَفَ امْرَأَتَهُ ‏.‏ قَالَ فَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَخَوَىْ بَنِي الْعَجْلاَنِ وَقَالَ ‏"‏ اللَّهُ يَعْلَمُ إِنَّ أَحَدَكُمَا كَاذِبٌ فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏ ‏.‏ قَالَ لَهُمَا ثَلاَثًا فَأَبَيَا فَفَرَّقَ بَيْنَهُمَا ‏.‏ قَالَ أَيُّوبُ وَقَالَ عَمْرُو بْنُ دِينَارٍ إِنَّ فِي هَذَا الْحَدِيثِ شَيْئًا لاَ أَرَاكَ تُحَدِّثُ بِهِ قَالَ قَالَ الرَّجُلُ مَالِي قَالَ ‏"‏ لاَ مَالَ لَكَ إِنْ كُنْتَ صَادِقًا فَقَدْ دَخَلْتَ بِهَا وَإِنْ كُنْتَ كَاذِبًا فَهِيَ أَبْعَدُ مِنْكَ ‏"‏ ‏.‏\hadithno{3475}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ayyub, that Sa'eed bin Jubair said:"I said to Ibn 'Umar: 'A man accused his wife.' He said: 'The Messenger of Allah separated the couple from Banu 'Ajlan and said: Allah knows that one of you is lying, so will either of you repent? He said that to them three times and they did not respond, then he separated them.'" (One of the narrators) Ayyub said: "Amr bin Dinar said: 'In this Hadith there is something that I think you are not narrating.' He said: 'The man said: My wealth. He said: You are not entitled to any wealth. If you are telling the truth, you have consummated the marriage with her, and if you are lying then you are even less entitled to it}}
\hadithdefcmd{nasai}{3476}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، يَقُولُ سَأَلْتُ ابْنَ عُمَرَ عَنِ الْمُتَلاَعِنَيْنِ، فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْمُتَلاَعِنَيْنِ ‏"‏ حِسَابُكُمَا عَلَى اللَّهِ أَحَدُكُمَا كَاذِبٌ وَلاَ سَبِيلَ لَكَ عَلَيْهَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَالِي قَالَ ‏"‏ لاَ مَالَ لَكَ إِنْ كُنْتَ صَدَقْتَ عَلَيْهَا فَهُوَ بِمَا اسْتَحْلَلْتَ مِنْ فَرْجِهَا وَإِنْ كُنْتَ كَذَبْتَ عَلَيْهَا فَذَاكَ أَبْعَدُ لَكَ ‏"‏ ‏.‏\hadithno{3476}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Amr said:"I heard Sa'eed bin Jubair say: 'I asked Ibn 'Umar about the two who engage in Li'an. He said: 'The Messenger of Allah said to the two who engaged in Li'an: Your reckoning will be with Allah. One of you is lying, and you cannot stay with her. He said: O Messenger of Allah, my wealth! He said: You are not entitled to any wealth. If you are telling the truth about her, then it is in return for having been allowed intimacy with her, and if you are lying then you are even less entitled to it}}
\hadithdefcmd{nasai}{3477}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لاَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ رَجُلٍ وَامْرَأَتِهِ وَفَرَّقَ بَيْنَهُمَا وَأَلْحَقَ الْوَلَدَ بِالأُمِّ ‏.‏\hadithno{3477}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah conducted the procedure of Li'an between a man and his wife, and he separated them and attributed the child to his mother}}
\hadithdefcmd{nasai}{3478}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، مِنْ بَنِي فَزَارَةَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَمَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ ‏.‏ قَالَ ‏"‏ فَهَلْ فِيهَا مِنْ أَوْرَقَ ‏"‏ ‏.‏ قَالَ إِنَّ فِيهَا لَوُرْقًا ‏.‏ قَالَ ‏"‏ فَأَنَّى تَرَى أَتَى ذَلِكَ ‏"‏ ‏.‏ قَالَ عَسَى أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَهَذَا عَسَى أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏"‏ ‏.‏\hadithno{3478}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that a man from Banu Fazarah came to the Messenger of Allah and said:"My wife has given birth to a black boy." The Messenger of Allah said: "Do you have camels?" He said: "Yes." He said: "What color are they?" He said: "Red." He said: "Are there any gray ones among them?" He said: "There are some gray ones among them." He said: "Where do you think they come from?" He said: "Perhaps it is hereditary." He said: "Likewise, perhaps this is hereditary}}
\hadithdefcmd{nasai}{3479}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ مِنْ بَنِي فَزَارَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ ‏.‏ وَهُوَ يُرِيدُ الاِنْتِفَاءَ مِنْهُ ‏.‏ فَقَالَ ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ مَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ ‏.‏ قَالَ ‏"‏ هَلْ فِيهَا مِنْ أَوْرَقَ ‏"‏ ‏.‏ قَالَ فِيهَا ذَوْدٌ وُرْقٌ ‏.‏ قَالَ ‏"‏ فَمَا ذَاكَ تُرَى ‏"‏ ‏.‏ قَالَ لَعَلَّهُ أَنْ يَكُونَ نَزَعَهَا عِرْقٌ ‏.‏ قَالَ ‏"‏ فَلَعَلَّ هَذَا أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏"‏ ‏.‏ قَالَ فَلَمْ يُرَخِّصْ لَهُ فِي الاِنْتِفَاءِ مِنْهُ ‏.‏\hadithno{3479}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"A man from Banu Fazarah came to the Prophet and said: 'My wife has given birth to a black boy' -and he wanted to disown him. He said: 'Do you have camels?' He said: 'Yes.' He said: 'What color are they?' He said: 'Red.' He said: 'Are there any gray ones among them?' He said: 'There are some gray camels among them.' He said: 'Why is that do you think?' He said: 'Perhaps it is hereditary.' He said: 'Perhaps this is hereditary.' And he did not permit him to disown him}}
\hadithdefcmd{nasai}{3480}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا أَبُو حَيْوَةَ، - حِمْصِيٌّ - قَالَ حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَمَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي وُلِدَ لِي غُلاَمٌ أَسْوَدُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَنَّى كَانَ ذَلِكَ ‏"‏ ‏.‏ قَالَ مَا أَدْرِي قَالَ ‏"‏ فَهَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَمَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ ‏.‏ قَالَ ‏"‏ فَهَلْ فِيهَا جَمَلٌ أَوْرَقُ ‏"‏ ‏.‏ قَالَ فِيهَا إِبِلٌ وُرْقٌ ‏.‏ قَالَ ‏"‏ فَأَنَّى كَانَ ذَلِكَ ‏"‏ ‏.‏ قَالَ مَا أَدْرِي يَا رَسُولَ اللَّهِ إِلاَّ أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏.‏ قَالَ ‏"‏ وَهَذَا لَعَلَّهُ نَزَعَهُ عِرْقٌ ‏"‏ ‏.‏ فَمِنْ أَجْلِهِ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم هَذَا لاَ يَجُوزُ لِرَجُلٍ أَنْ يَنْتَفِيَ مِنْ وَلَدٍ وُلِدَ عَلَى فِرَاشِهِ إِلاَّ أَنْ يَزْعُمَ أَنَّهُ رَأَى فَاحِشَةً ‏.‏\hadithno{3480}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"While we were with the Prophet, a man stood up and said: 'O Messenger of Allah, a black boy has been born to me.' The Messenger of Allah said: 'How did that happen?' He said: 'I do not know.' He said: 'Do you have camels?' He said: 'Yes.' He said: 'What color are they?' He said: 'Red.' He said: 'Are there any gray camels among them?' He said: 'There are some gray camels among them.' He said: 'Where do they come from?' He said: 'I do not know, O Allah's Messenger! Perhaps it is hereditary.' He said: 'Perhaps this is also hereditary.' Because of this, the Messenger of Allah decreed the following: 'It is not allowed for a man, to disown a child who was born on his bed, unless he claimed that he had seen an immoral act (Fahishah)}}
\hadithdefcmd{nasai}{3481}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، قَالَ شُعَيْبٌ قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ يُونُسَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ حِينَ نَزَلَتْ آيَةُ الْمُلاَعَنَةِ ‏ "‏ أَيُّمَا امْرَأَةٍ أَدْخَلَتْ عَلَى قَوْمٍ رَجُلاً لَيْسَ مِنْهُمْ فَلَيْسَتْ مِنَ اللَّهِ فِي شَىْءٍ وَلاَ يُدْخِلُهَا اللَّهُ جَنَّتَهُ وَأَيُّمَا رَجُلٍ جَحَدَ وَلَدَهُ وَهُوَ يَنْظُرُ إِلَيْهِ احْتَجَبَ اللَّهُ عَزَّ وَجَلَّ مِنْهُ وَفَضَحَهُ عَلَى رُءُوسِ الأَوَّلِينَ وَالآخِرِينَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3481}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that he heard the Messenger of Allah say when the Verse of Mula'anah (Li'an) was revealed:"Any woman who falsely attributes a man to people to whom he does not belong, has no share from Allah, and Allah will not admit her to His Paradise. Any man who denies his son while looking at him (knowing that he is indeed his son), Allah, the Mighty and Sublime, will cast him away, and disgrace him before the first and the last on the Day of Resurrection}}
\hadithdefcmd{nasai}{3482}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏\hadithno{3482}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"The child is the bed's and for the fornicator is the stone}}
\hadithdefcmd{nasai}{3483}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏\hadithno{3483}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"The child is the bed's and for the fornicator is the stone}}
\hadithdefcmd{nasai}{3484}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اخْتَصَمَ سَعْدُ بْنُ أَبِي وَقَّاصٍ وَعَبْدُ بْنُ زَمْعَةَ فِي غُلاَمٍ فَقَالَ سَعْدٌ هَذَا يَا رَسُولَ اللَّهِ ابْنُ أَخِي عُتْبَةَ بْنِ أَبِي وَقَّاصٍ عَهِدَ إِلَىَّ أَنَّهُ ابْنُهُ انْظُرْ إِلَى شَبَهِهِ ‏.‏ وَقَالَ عَبْدُ بْنُ زَمْعَةَ أَخِي وُلِدَ عَلَى فِرَاشِ أَبِي مِنْ وَلِيدَتِهِ ‏.‏ فَنَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى شَبَهِهِ فَرَأَى شَبَهًا بَيِّنًا بِعُتْبَةَ فَقَالَ ‏ "‏ هُوَ لَكَ يَا عَبْدُ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ وَاحْتَجِبِي مِنْهُ يَا سَوْدَةُ بِنْتَ زَمْعَةَ ‏"‏ ‏.‏ فَلَمْ يَرَ سَوْدَةَ قَطُّ ‏.‏\hadithno{3484}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Sa'd bin Abi Waqqas and 'Abd bin Zam'ah disputed over a boy. Sa'd said: 'O Messenger of Allah! This is the son of my brother 'Utbah bin Abi Waqqas, who made me promise to look after him because he is his son. Look at whom he resembles.' 'Abd bin Zam'ah said: 'He is my brother who was born on my father's bed to his slave woman.' The Messenger of Allah looked to determine at whom he resembled, and saw that he resembled 'Utbah. He said: 'He is for you, O 'Abd! The child is the bed's and for the fornicator is the stone. Veil yourself from him, O Sawdah bint Zam'ah.' And he never saw Sawdah again}}
\hadithdefcmd{nasai}{3485}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ يُوسُفَ بْنِ الزُّبَيْرِ، - مَوْلًى لَهُمْ - عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ كَانَتْ لِزَمْعَةَ جَارِيَةٌ يَطَؤُهَا هُوَ وَكَانَ يَظُنُّ بِآخَرَ يَقَعُ عَلَيْهَا فَجَاءَتْ بِوَلَدٍ شِبْهِ الَّذِي كَانَ يَظُنُّ بِهِ فَمَاتَ زَمْعَةُ وَهِيَ حُبْلَى فَذَكَرَتْ ذَلِكَ سَوْدَةُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوَلَدُ لِلْفِرَاشِ وَاحْتَجِبِي مِنْهُ يَا سَوْدَةُ فَلَيْسَ لَكِ بِأَخٍ ‏"‏\hadithno{3485}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin Az-Zubair said:"Zam'ah had a slave woman with whom he used to have intercourse, but he suspected that someone else was also having intercourse with her. She gave birth to a child who resembled the one whom he suspected. Zam'ah died when she was pregnant, and Sawdah mentioned that to the Messenger of Allah. The Messenger of Allah said: 'The child is the bed's, but veil yourself from him, O Sawdah, for he is not a brother of yours}}
\hadithdefcmd{nasai}{3486}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَلاَ أَحْسُبُ هَذَا عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{3486}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah that the Messenger of Allah said:"The child is the bed's, and for the fornicator is the stone}}
\hadithdefcmd{nasai}{3487}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اخْتَصَمَ سَعْدُ بْنُ أَبِي وَقَّاصٍ وَعَبْدُ بْنُ زَمْعَةَ فِي ابْنِ زَمْعَةَ قَالَ سَعْدٌ أَوْصَانِي أَخِي عُتْبَةُ إِذَا قَدِمْتَ مَكَّةَ فَانْظُرِ ابْنَ وَلِيدَةِ زَمْعَةَ فَهُوَ ابْنِي ‏.‏ فَقَالَ عَبْدُ بْنُ زَمْعَةَ هُوَ ابْنُ أَمَةِ أَبِي وُلِدَ عَلَى فِرَاشِ أَبِي ‏.‏ فَرَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم شَبَهًا بَيِّنًا بِعُتْبَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوَلَدُ لِلْفِرَاشِ وَاحْتَجِبِي مِنْهُ يَا سَوْدَةُ ‏"‏ ‏.‏\hadithno{3487}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Sa'd bin Abi Waqqas and 'Abd bin Zam'ah disputed concerning a son of Zam'ah. Sa'd said: 'My brother 'Utbah urged me, if I came to Makkah: Look for the son of the slave woman of Zam'ah, for he is my son.' 'Abd bin Zam'ah said: 'He is the son of my father's slave woman who was born on my father's bed.' The Messenger of Allah saw that he resembled 'Utbah, but he said: 'The child is the bed's. Veil yourself from him, O Sawdah}}
\hadithdefcmd{nasai}{3488}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا الثَّوْرِيُّ، عَنْ صَالِحٍ الْهَمْدَانِيِّ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ خَيْرٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ أُتِيَ عَلِيٌّ رضى الله عنه بِثَلاَثَةٍ وَهُوَ بِالْيَمَنِ وَقَعُوا عَلَى امْرَأَةٍ فِي طُهْرٍ وَاحِدٍ فَسَأَلَ اثْنَيْنِ أَتُقِرَّانِ لِهَذَا بِالْوَلَدِ قَالاَ لاَ ‏.‏ ثُمَّ سَأَلَ اثْنَيْنِ أَتُقِرَّانِ لِهَذَا بِالْوَلَدِ قَالاَ لاَ ‏.‏ فَأَقْرَعَ بَيْنَهُمْ فَأَلْحَقَ الْوَلَدَ بِالَّذِي صَارَتْ عَلَيْهِ الْقُرْعَةُ وَجَعَلَ عَلَيْهِ ثُلُثَىِ الدِّيَةِ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ ‏.‏\hadithno{3488}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Arqam said:"Three men were brought to 'Ali while he was in Yemen; they all had intercourse with a woman during a single menstrual cycle. He asked two of them: 'Do you affirm that this child belongs to (the third man)?' And they said: 'No.' He asked another two of them: 'Do you affirm that this child belongs to (the third man)?' And they said: 'No.' So he cast lots between them, and attributed the child to the one whom the lot fell, and obliged him to pay two-thirds of the Diyah. The Prophet was told of this, and he laughed so much that his back teeth became visible}}
\hadithdefcmd{nasai}{3489}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَجْلَحِ، عَنِ الشَّعْبِيِّ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي الْخَلِيلِ الْحَضْرَمِيُّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ بَيْنَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَهُ رَجُلٌ مِنَ الْيَمَنِ فَجَعَلَ يُخْبِرُهُ وَيُحَدِّثُهُ وَعَلِيٌّ بِهَا فَقَالَ يَا رَسُولَ اللَّهِ أَتَى عَلِيًّا ثَلاَثَةُ نَفَرٍ يَخْتَصِمُونَ فِي وَلَدٍ وَقَعُوا عَلَى امْرَأَةٍ فِي طُهْرٍ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{3489}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Arqam said:"While we were with the Messenger of Allah, a man came to him from Yemen and started telling him (about an incident) while 'Ali was still in Yemen. He said: 'O Messenger of Allah, three men were brought to 'Ali who were disputing about a child, and they all had intercourse with a woman during a single menstrual cycle.'" And he quoted the same Hadith}}
\hadithdefcmd{nasai}{3490}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ الأَجْلَحِ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْخَلِيلِ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم وَعَلِيٌّ رضى الله عنه يَوْمَئِذٍ بِالْيَمَنِ فَأَتَاهُ رَجُلٌ فَقَالَ شَهِدْتُ عَلِيًّا أُتِيَ فِي ثَلاَثَةِ نَفَرٍ ادَّعَوْا وَلَدَ امْرَأَةٍ فَقَالَ عَلِيٌّ لأَحَدِهِمْ تَدَعُهُ لِهَذَا ‏.‏ فَأَبَى وَقَالَ لِهَذَا تَدَعُهُ لِهَذَا ‏.‏ فَأَبَى وَقَالَ لِهَذَا تَدَعُهُ لِهَذَا ‏.‏ فَأَبَى قَالَ عَلِيٌّ رضى الله عنه أَنْتُمْ شُرَكَاءُ مُتَشَاكِسُونَ وَسَأُقْرِعُ بَيْنَكُمْ فَأَيُّكُمْ أَصَابَتْهُ الْقُرْعَةُ فَهُوَ لَهُ وَعَلَيْهِ ثُلُثَا الدِّيَةِ ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَدَتْ نَوَاجِذُهُ ‏.‏\hadithno{3490}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Arqam said:"I was with the Messenger of Allah, and 'Ali, may Allah be pleased with him, was in Yemen at that time. A man came to him and said: 'I saw 'Ali when three men were brought to him who all claimed (to be the father) of a child. 'Ali said to one of them: Will you give the child up to him? And he refused. He said to (the next one): Will you give the child up to him? And he refused. He said to (the next one): Will you give the child up to him? And he refused. 'Ali said: You are disputing partners. I will cast lots among you, and whoever wins the draw, the child is for him, and he has to pay two-thirds of the Diyah.' The Messenger of Allah laughed so much that his back teeth became visible}}
\hadithdefcmd{nasai}{3491}{أَخْبَرَنَا إِسْحَاقُ بْنُ شَاهِينَ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، عَنْ رَجُلٍ، مِنْ حَضْرَمَوْتَ عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيًّا عَلَى الْيَمَنِ فَأُتِيَ بِغُلاَمٍ تَنَازَعَ فِيهِ ثَلاَثَةٌ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ خَالَفَهُمْ سَلَمَةُ بْنُ كُهَيْلٍ ‏.‏\hadithno{3491}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from a man from Hadramawt, that Zaid bin Arqam said:"The Messenger of Allah sent 'Ali to (be the governor of) Yemen, and a child was brought to him concerning whom three men were disputing." Then he quoted the same Hadith. Salamah bin Kuhail contradicted them}}
\hadithdefcmd{nasai}{3492}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ سَمِعْتُ الشَّعْبِيَّ، يُحَدِّثُ عَنْ أَبِي الْخَلِيلِ، أَوِ ابْنِ أَبِي الْخَلِيلِ أَنَّ ثَلاَثَةَ، نَفَرٍ اشْتَرَكُوا فِي طُهْرٍ فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرْ زَيْدَ بْنَ أَرْقَمَ وَلَمْ يَرْفَعْهُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا صَوَابٌ وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{3492}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Salamah bin Kuhail said:"I heard Ash-Sha'bi narrating from Abu Al-Khalil or Ibn Abi Al-Khalil that three men had intercourse (with the same woman) during a single menstrual cycle;" and he mentioned something similar, but he did not mention Zaid bin Arqam or attribute anything to the Prophet}}
\hadithdefcmd{nasai}{3493}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَىَّ مَسْرُورًا تَبْرُقُ أَسَارِيرُ وَجْهِهِ فَقَالَ ‏ "‏ أَلَمْ تَرَىْ أَنَّ مُجَزِّزًا نَظَرَ إِلَى زَيْدِ بْنِ حَارِثَةَ وَأُسَامَةَ فَقَالَ إِنَّ بَعْضَ هَذِهِ الأَقْدَامِ لَمِنْ بَعْضٍ ‏"‏ ‏.‏\hadithno{3493}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah came to me looking happy and cheerful, and he said: 'Did you not see that Mujazziz looked at Zaid bin Harithah and Usamah and said: These feet belong to one another}}
\hadithdefcmd{nasai}{3494}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ مَسْرُورًا فَقَالَ ‏ "‏ يَا عَائِشَةُ أَلَمْ تَرَىْ أَنَّ مُجَزِّزًا الْمُدْلِجِيَّ دَخَلَ عَلَىَّ وَعِنْدِي أُسَامَةُ بْنُ زَيْدٍ فَرَأَى أُسَامَةَ بْنَ زَيْدٍ وَزَيْدًا وَعَلَيْهِمَا قَطِيفَةٌ وَقَدْ غَطَّيَا رُءُوسَهُمَا وَبَدَتْ أَقْدَامُهُمَا فَقَالَ هَذِهِ أَقْدَامٌ بَعْضُهَا مِنْ بَعْضٍ ‏"‏ ‏.‏\hadithno{3494}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah, may Allah be pleased with her, said:"The Messenger of Allah came to me one day looking happy and said: 'O 'Aishah! Did you not see that Mujazziz Al-Mudliji came to me when Usamah bin Zaid was with me. He saw Usamah bin Zaid and Zaid with a blanket over them; their heads were covered but their feet were exposed, and he said: These feet belong to one another}}
\hadithdefcmd{nasai}{3495}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُثْمَانَ الْبَتِّيِّ، عَنْ عَبْدِ الْحَمِيدِ بْنِ سَلَمَةَ الأَنْصَارِيِّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ أَسْلَمَ وَأَبَتِ امْرَأَتُهُ أَنْ تُسْلِمَ فَجَاءَ ابْنٌ لَهُمَا صَغِيرٌ لَمْ يَبْلُغِ الْحُلُمَ فَأَجْلَسَ النَّبِيُّ صلى الله عليه وسلم الأَبَ هَا هُنَا وَالأُمَّ هَا هُنَا ثُمَّ خَيَّرَهُ فَقَالَ ‏ "‏ اللَّهُمَّ اهْدِهِ ‏"‏ ‏.‏ فَذَهَبَ إِلَى أَبِيهِ ‏.‏\hadithno{3495}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdul-Hamid bin Salamah Al-Ansari, from his father, from his grandfather, that he became Muslim but his wife refused to become Muslim. A young son of theirs, who had not yet reached puberty, came, and the Prophet seated the father on one side and the mother on the other side, and he gave him the choice. He said:"O Allah, guide him," and (the child) went to his father}}
\hadithdefcmd{nasai}{3496}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي زِيَادٌ، عَنْ هِلاَلِ بْنِ أُسَامَةَ، عَنْ أَبِي مَيْمُونَةَ، قَالَ بَيْنَا أَنَا عِنْدَ أَبِي هُرَيْرَةَ، فَقَالَ إِنَّ امْرَأَةً جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ فَدَاكَ أَبِي وَأُمِّي إِنَّ زَوْجِي يُرِيدُ أَنْ يَذْهَبَ بِابْنِي وَقَدْ نَفَعَنِي وَسَقَانِي مِنْ بِئْرِ أَبِي عِنَبَةَ ‏.‏ فَجَاءَ زَوْجُهَا وَقَالَ مَنْ يُخَاصِمُنِي فِي ابْنِي فَقَالَ ‏ "‏ يَا غُلاَمُ هَذَا أَبُوكَ وَهَذِهِ أُمُّكَ فَخُذْ بِيَدِ أَيِّهِمَا شِئْتَ ‏"‏ ‏.‏ فَأَخَذَ بِيَدِ أُمِّهِ فَانْطَلَقَتْ بِهِ ‏.‏\hadithno{3496}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Maimunah said:"While I was with Abu Hurairah he said: 'A woman came to the Messenger of Allah and said: May my father and mother be ransomed for you! My husband wants to take my son away, but he helps me, and brings me water from the well of Abu 'Inabah. Her husband came and said: Who is going to take my son from me? The Messenger of Allah said: "O boy, this is your father and this is your mother; take the hand of whichever of them you want." He took his mother's hand and she left with him}}
\hadithdefcmd{nasai}{3497}{أَخْبَرَنَا أَبُو عَلِيٍّ، مُحَمَّدُ بْنُ يَحْيَى الْمَرْوَزِيُّ قَالَ أَخْبَرَنِي شَاذَانُ بْنُ عُثْمَانَ، أَخُو عَبْدَانَ قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ الرُّبَيِّعَ بِنْتَ مُعَوِّذِ ابْنِ عَفْرَاءَ، أَخْبَرَتْهُ أَنَّ ثَابِتَ بْنَ قَيْسِ بْنِ شَمَّاسٍ ضَرَبَ امْرَأَتَهُ فَكَسَرَ يَدَهَا وَهِيَ جَمِيلَةُ بِنْتُ عَبْدِ اللَّهِ بْنِ أُبَىٍّ فَأَتَى أَخُوهَا يَشْتَكِيهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى ثَابِتٍ فَقَالَ لَهُ ‏ "‏ خُذِ الَّذِي لَهَا عَلَيْكَ وَخَلِّ سَبِيلَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَأَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَتَرَبَّصَ حَيْضَةً وَاحِدَةً فَتَلْحَقَ بِأَهْلِهَا ‏.‏\hadithno{3497}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ar-Rubayy' bint Mu'awwidh bin 'Afra' narrated that Thabit bin Qais bin Shammas hit his wife and broke her arm --her name was Jamilah bint 'Abdullah bin Ubayy. Her brother came to the Messenger of Allah to complain about him, and the Messenger of Allah sent for Thabit and said:"Take what she owes you and let her go." He said: "Yes." And the Messenger of Allah ordered her to wait for one menstrual cycle and then go to her family}}
\hadithdefcmd{nasai}{3498}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي عُبَادَةُ بْنُ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ رُبَيِّعٍ بِنْتِ مُعَوِّذٍ، قَالَ قُلْتُ لَهَا حَدِّثِينِي حَدِيثَكِ، ‏.‏ قَالَتِ اخْتَلَعْتُ مِنْ زَوْجِي ثُمَّ جِئْتُ عُثْمَانَ فَسَأَلْتُهُ مَاذَا عَلَىَّ مِنَ الْعِدَّةِ فَقَالَ لاَ عِدَّةَ عَلَيْكِ إِلاَّ أَنْ تَكُونِي حَدِيثَةَ عَهْدٍ بِهِ فَتَمْكُثِي حَتَّى تَحِيضِي حَيْضَةً - قَالَ - وَأَنَا مُتَّبِعٌ فِي ذَلِكَ قَضَاءَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي مَرْيَمَ الْمَغَالِيَّةِ كَانَتْ تَحْتَ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ فَاخْتَلَعَتْ مِنْهُ ‏.‏\hadithno{3498}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ubadah bin Al-Walid bin 'Ubadah bin As-Samit narrated from Rubayy' bint Mu'awwidh. He said:"I said to her: 'Tell me your Hadith.' She said: 'I was separated from husband by Khul', then I came to 'Uthman and asked him: What 'Iddah do I have to observe? He said: You do not have to observe any 'Iddah, unless you had intercourse with him recently, in which case you should stay with him until you have menstruated. He said: In that I am following the ruling of the Messenger of Allah concerning Mariam Al-Maghaliyyah, who was married to Thabit bin Qais and was separated by Khul' from him}}
\hadithdefcmd{nasai}{3499}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، أَنْبَأَنَا يَزِيدُ النَّحْوِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ ‏\{‏ مَا نَنْسَخْ مِنْ آيَةٍ أَوْ نُنْسِهَا نَأْتِ بِخَيْرٍ مِنْهَا أَوْ مِثْلِهَا ‏\}‏ وَقَالَ ‏\{‏ وَإِذَا بَدَّلْنَا آيَةً مَكَانَ آيَةٍ وَاللَّهُ أَعْلَمُ بِمَا يُنَزِّلُ ‏\}‏ الآيَةَ وَقَالَ ‏\{‏ يَمْحُو اللَّهُ مَا يَشَاءُ وَيُثْبِتُ وَعِنْدَهُ أُمُّ الْكِتَابِ ‏\}‏ فَأَوَّلُ مَا نُسِخَ مِنَ الْقُرْآنِ الْقِبْلَةُ وَقَالَ ‏\{‏ وَالْمُطَلَّقَاتُ يَتَرَبَّصْنَ بِأَنْفُسِهِنَّ ثَلاَثَةَ قُرُوءٍ ‏\}‏ وَقَالَ ‏\{‏ وَاللاَّئِي يَئِسْنَ مِنَ الْمَحِيضِ مِنْ نِسَائِكُمْ إِنِ ارْتَبْتُمْ فَعِدَّتُهُنَّ ثَلاَثَةُ أَشْهُرٍ ‏\}‏ فَنُسِخَ مِنْ ذَلِكَ قَالَ تَعَالَى ‏\{‏ وَإِنْ طَلَّقْتُمُوهُنَّ مِنْ قَبْلِ أَنْ تَمَسُّوهُنَّ ‏\}‏ ‏\{‏ فَمَا لَكُمْ عَلَيْهِنَّ مِنْ عِدَّةٍ تَعْتَدُّونَهَا ‏\}‏ ‏.‏\hadithno{3499}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas with regard to Allah's saying:"Whatever a Verse (revelation) do We abrogate or cause to be forgotten, We bring a better one or similar to it." and He said: "And when We change a Verse in place of another --and Allah knows best what He sends down." and He said: "Allah blots out what He wills and confirms (what He wills). And with Him is the Mother of the Book." "The first thing that was abrogated in the Qur'an was the Qiblah." And He said: "And divorced women shall wait (as regards their marriage) for three menstrual periods." and He said: "And those of your women as have passed the age of monthly courses, for them the 'Iddah, if you have doubt (about their periods), is three months." So (some) of that was abrogated, (according to) His, Most High, saying: "And then divorce them before you have sexual intercourse with them, no 'Iddah have you to count in respect of them}}
\hadithdefcmd{nasai}{3500}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي حُمَيْدُ بْنُ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، قَالَتْ أُمُّ حَبِيبَةَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تَحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثَةِ أَيَّامٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3500}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Zainab bint Umm Salamah said:"Umm Habibah said: 'I heard the Messenger of Allah say: It is not permissible for a woman who believes in Allah and the Last Day to mourn for anyone who dies for more than three days, except for a husband; (she mourns for him for) four months and ten (days)}}
\hadithdefcmd{nasai}{3501}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، قُلْتُ عَنْ أُمِّهَا، قَالَ نَعَمْ إِنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنِ امْرَأَةٍ تُوُفِّيَ عَنْهَا زَوْجُهَا فَخَافُوا عَلَى عَيْنِهَا أَتَكْتَحِلُ فَقَالَ ‏ "‏ قَدْ كَانَتْ إِحْدَاكُنَّ تَمْكُثُ فِي بَيْتِهَا فِي شَرِّ أَحْلاَسِهَا حَوْلاً ثُمَّ خَرَجَتْ فَلاَ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3501}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Zainab bint Umm Salamah -I (the narrator) said:"From her mother?" He said: "Yes" - "that the Prophet was asked about a woman whose husband had died but they were worried about her eyes - could she use kohl?" He said: "One of you used to stay in her house wearing her shabbiest clothes for a year, then she would come out. No, (the mourning period is) four months and ten (days)}}
\hadithdefcmd{nasai}{3502}{أَخْبَرَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ يَحْيَى بْنِ سَعِيدِ بْنِ قَيْسِ بْنِ قَهْدٍ الأَنْصَارِيِّ، - وَجَدُّهُ قَدْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم - عَنْ حُمَيْدِ بْنِ نَافِعٍ عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ وَأُمِّ حَبِيبَةَ قَالَتَا جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَإِنِّي أَخَافُ عَلَى عَيْنِهَا أَفَأَكْحُلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ كَانَتْ إِحْدَاكُنَّ تَجْلِسُ حَوْلاً وَإِنَّمَا هِيَ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا فَإِذَا كَانَ الْحَوْلُ خَرَجَتْ وَرَمَتْ وَرَاءَهَا بِبَعْرَةٍ ‏"‏ ‏.‏\hadithno{3502}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab bint Umm Salamah, that Umm Salamah and Umm Habibah said:"A woman came to the Prophet and said: 'My daughter's husband has died, and I am worried about her eyes. Can I apply kohl to her?' The Messenger of Allah said: 'One of you used to stay (in mourning) for a year. Rather (the mourning period is) four months and ten (days). And when that year had passed she would go out and fling a piece of dung behind her}}
\hadithdefcmd{nasai}{3503}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ نَافِعًا، يَقُولُ عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، أَنَّهَا سَمِعَتْ حَفْصَةَ بِنْتَ عُمَرَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تَحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ فَإِنَّهَا تَحِدُّ عَلَيْهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3503}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Safiyyah bint Abi 'Ubaid that she heard Hafsah bint 'Umar, the wife of the Prophet, (narrate) that the Prophet said:"It is not permissible for a woman who believes in Allah and the Last Day to mourn for anyone who dies for more than three days except for a husband; she should mourn for him for four months and ten (days)}}
\hadithdefcmd{nasai}{3504}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، قَالَ أَنْبَأَنَا سَعِيدٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، عَنْ بَعْضِ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم وَعَنْ أُمِّ سَلَمَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تَحِدُّ عَلَى مَيِّتٍ أَكْثَرَ مِنْ ثَلاَثَةِ أَيَّامٍ إِلاَّ عَلَى زَوْجٍ فَإِنَّهَا تَحِدُّ عَلَيْهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3504}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Safiyyah bint Abi 'Ubaid from one of the wives of the Prophet, and from Umm Salamah, that the Prophet said:"It is not permissible for a woman who believes in Allah and the Last Day to mourn for anyone who dies for more than three days except for a husband; she should mourn for him for four months and ten (days)}}
\hadithdefcmd{nasai}{3505}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا السَّهْمِيُّ، - يَعْنِي عَبْدَ اللَّهِ بْنَ بَكْرٍ - قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، عَنْ بَعْضِ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم وَهِيَ أُمُّ سَلَمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3505}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{A similar report was narrated from Safiyyah bint Abi 'Ubaid from one of the wives of the Prophet -and she is Umm Salamah- from the Prophet}}
\hadithdefcmd{nasai}{3506}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لِمُحَمَّدٍ - قَالاَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّ سُبَيْعَةَ الأَسْلَمِيَّةَ، نُفِسَتْ بَعْدَ وَفَاةِ زَوْجِهَا بِلَيَالٍ فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَأْذَنَتْ أَنْ تَنْكِحَ فَأَذِنَ لَهَا فَنَكَحَتْ ‏.‏\hadithno{3506}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Al-Miswar bin Makhramah that Subai'ah Al-Aslamiyyah gave birth one day after her husband died. She came to the Messenger of Allah and asked his permission to marry, and he gave her permission to marry and she married}}
\hadithdefcmd{nasai}{3507}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيِّ بْنِ نَصْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دَاوُدَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ سُبَيْعَةَ أَنْ تَنْكِحَ إِذَا تَعَلَّتْ مِنْ نِفَاسِهَا ‏.‏\hadithno{3507}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Miswar bin Makhramah that the Prophet commanded Sabai'ah to get married when her Nifas ended}}
\hadithdefcmd{nasai}{3508}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ أَخْبَرَنِي جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ أَبِي السَّنَابِلِ، قَالَ وَضَعَتْ سُبَيْعَةُ حَمْلَهَا بَعْدَ وَفَاةِ زَوْجِهَا بِثَلاَثَةٍ وَعِشْرِينَ أَوْ خَمْسَةٍ وَعِشْرِينَ لَيْلَةً فَلَمَّا تَعَلَّتْ تَشَوَّفَتْ لِلأَزْوَاجِ فَعِيبَ ذَلِكَ عَلَيْهَا فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَا يَمْنَعُهَا قَدِ انْقَضَى أَجَلُهَا ‏"‏ ‏.‏\hadithno{3508}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu As-Sanabil said:"Subai'ah gave birth twenty-three or twenty-five days after her husband died, and when her Nifas ended she expressed her wish to remarry and was criticized for that. Mention of that was made to the Messenger of Allah and he said: 'There is nothing to stop her; her term has ended}}
\hadithdefcmd{nasai}{3509}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَبْدُ رَبِّهِ بْنُ سَعِيدٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، يَقُولُ اخْتَلَفَ أَبُو هُرَيْرَةَ وَابْنُ عَبَّاسٍ فِي الْمُتَوَفَّى عَنْهَا زَوْجُهَا إِذَا وَضَعَتْ حَمْلَهَا قَالَ أَبُو هُرَيْرَةَ تُزَوَّجُ ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ أَبْعَدَ الأَجَلَيْنِ ‏.‏ فَبَعَثُوا إِلَى أُمِّ سَلَمَةَ فَقَالَتْ تُوُفِّيَ زَوْجُ سُبَيْعَةَ فَوَلَدَتْ بَعْدَ وَفَاةِ زَوْجِهَا بِخَمْسَةَ عَشَرَ نِصْفِ شَهْرٍ - قَالَتْ - فَخَطَبَهَا رَجُلاَنِ فَحَطَّتْ بِنَفْسِهَا إِلَى أَحَدِهِمَا فَلَمَّا خَشُوا أَنْ تَفْتَاتَ بِنَفْسِهَا قَالُوا إِنَّكِ لاَ تَحِلِّينَ ‏.‏ قَالَتْ فَانْطَلَقْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قَدْ حَلَلْتِ فَانْكِحِي مَنْ شِئْتِ ‏"‏ ‏.‏\hadithno{3509}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Salamah said:"Abu Hurairah and Ibn 'Abbas differed concerning the widow who gives birth after her husband's death. Abu Hurairah said: 'She may be married.' Ibn 'Abbas said: '(She has to wait) for the longer of the two periods.' They sent word to Umm Salamah and she said: 'The husband of Subai'ah died and she gave birth fifteen days -half a month- after her husband died.' She said: 'Two men proposed marriage to her, and she was inclined toward one of them. When they feared that she was becoming single-minded (on this issue, and not consulting her family), they said: It is not permissible for you to marry. She went to the Messenger of Allah and he said: 'It is permissible for you to marry, so marry whomever you want}}
\hadithdefcmd{nasai}{3510}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لِمُحَمَّدٍ - قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، قَالَ سُئِلَ ابْنُ عَبَّاسٍ وَأَبُو هُرَيْرَةَ عَنِ الْمُتَوَفَّى، عَنْهَا زَوْجُهَا وَهِيَ حَامِلٌ قَالَ ابْنُ عَبَّاسٍ آخِرُ الأَجَلَيْنِ ‏.‏ وَقَالَ أَبُو هُرَيْرَةَ إِذَا وَلَدَتْ فَقَدْ حَلَّتْ ‏.‏ فَدَخَلَ أَبُو سَلَمَةَ إِلَى أُمِّ سَلَمَةَ فَسَأَلَهَا عَنْ ذَلِكَ، فَقَالَتْ وَلَدَتْ سُبَيْعَةُ الأَسْلَمِيَّةُ بَعْدَ وَفَاةِ زَوْجِهَا بِنِصْفِ شَهْرٍ فَخَطَبَهَا رَجُلاَنِ أَحَدُهُمَا شَابٌّ وَالآخَرُ كَهْلٌ فَحَطَّتْ إِلَى الشَّابِّ فَقَالَ الْكَهْلُ لَمْ تَحْلِلْ ‏.‏ وَكَانَ أَهْلُهَا غُيَّبًا فَرَجَا إِذَا جَاءَ أَهْلُهَا أَنْ يُؤْثِرُوهُ بِهَا فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قَدْ حَلَلْتِ فَانْكِحِي مَنْ شِئْتِ ‏"‏ ‏.‏\hadithno{3510}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Salamah said:"Ibn 'Abbas and Abu Hurairah were asked about the woman whose husband dies when she is pregnant. Ibn 'Abbas said: '(She should wait) for the longer of the two periods.' Abu Hurairah said: 'When she gives birth it becomes permissible for her to marry.' Abu Salamah went to Umm Salamah and asked her about that, and she said: 'Subai'ah Al-Aslamiyyah gave birth half a month after her husband died, and two men proposed to her. One was young and one was old, and she was inclined toward the young one. So the old one said: It is not permissible for you to marry. Her family was not there, and he hoped that if he went to her family they would marry her to him. She went to the Messenger of Allah and he said: It is permissible for you to marry, so marry whomever you want}}
\hadithdefcmd{nasai}{3511}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ قِيلَ لاِبْنِ عَبَّاسٍ فِي امْرَأَةٍ وَضَعَتْ بَعْدَ وَفَاةِ زَوْجِهَا بِعِشْرِينَ لَيْلَةً أَيَصْلُحُ لَهَا أَنْ تَزَوَّجَ قَالَ لاَ إِلاَّ آخِرَ الأَجَلَيْنِ ‏.‏ قَالَ قُلْتُ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏ وَأُولاَتُ الأَحْمَالِ أَجَلُهُنَّ أَنْ يَضَعْنَ حَمْلَهُنَّ ‏\}‏ فَقَالَ إِنَّمَا ذَلِكَ فِي الطَّلاَقِ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ أَنَا مَعَ ابْنِ أَخِي ‏.‏ يَعْنِي أَبَا سَلَمَةَ ‏.‏ فَأَرْسَلَ غُلاَمَهُ كُرَيْبًا فَقَالَ ائْتِ أُمَّ سَلَمَةَ فَسَلْهَا هَلْ كَانَ هَذَا سُنَّةً مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَ فَقَالَ قَالَتْ نَعَمْ سُبَيْعَةُ الأَسْلَمِيَّةُ وَضَعَتْ بَعْدَ وَفَاةِ زَوْجِهَا بِعِشْرِينَ لَيْلَةً فَأَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَزَوَّجَ فَكَانَ أَبُو السَّنَابِلِ فِيمَنْ يَخْطُبُهَا ‏.‏\hadithno{3511}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Salamah bin 'Abdur-Rahman said:"It was said to Ibn 'Abbas concerning a woman who gives birth one day after her husband died: 'Can she get married?' He said: 'No, not until the longer of the two periods has ended.' He said: 'Allah says: And for those who are pregnant (whether they are divorced or their husbands are dead), their 'Iddah (prescribed period) is until they lay down their burden.' He said: 'That only applies in the case of divorce.' Abu Hurairah said: 'I agree with my brother's son' --meaning, Abu Salamah. He sent his slave Kuraib and told him: 'Go to Umm Salamah and ask her: Was this the Sunnah of the Messenger of Allah?' He came back and said: 'Yes, Subai'ah Al-Aslamiyyah gave birth twenty days after her husband died, and the Messenger of Allah told her to get married, and Abu As-Sanabil was one of those who proposed marriage to her}}
\hadithdefcmd{nasai}{3512}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ أَبَا هُرَيْرَةَ، وَابْنَ، عَبَّاسٍ وَأَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ تَذَاكَرُوا عِدَّةَ الْمُتَوَفَّى عَنْهَا زَوْجُهَا تَضَعُ عِنْدَ وَفَاةِ زَوْجِهَا فَقَالَ ابْنُ عَبَّاسٍ تَعْتَدُّ آخِرَ الأَجَلَيْنِ ‏.‏ وَقَالَ أَبُو سَلَمَةَ بَلْ تَحِلُّ حِينَ تَضَعُ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ أَنَا مَعَ ابْنِ أَخِي ‏.‏ فَأَرْسَلُوا إِلَى أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ وَضَعَتْ سُبَيْعَةُ الأَسْلَمِيَّةُ بَعْدَ وَفَاةِ زَوْجِهَا بِيَسِيرٍ فَاسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرَهَا أَنْ تَتَزَوَّجَ ‏.‏\hadithno{3512}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sulaiman bin Yasir that Abu Hurairah, Ibn 'Abbas, and Abu Salamah bin 'Abdur-Rahman were talking about the 'Iddah of a woman whose husband dies, and she gives birth after her husband dies. Ibn 'Abbas said:"She should observe 'Iddah for the longer of the two periods." Abu Salamah said: "No, it becomes permissible for her to marry when she has given birth." Abu Hurairah said: "I agree with my brother's son." So they sent word to Umm Salamah, the wife of the Prophet, and she said: "Subai'ah Al-Aslamiyyah gave birth shortly after her husband died; she consulted the Messenger of Allah and he told her to get married}}
\hadithdefcmd{nasai}{3513}{أَخْبَرَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ كُرَيْبٍ، عَنْ أُمِّ سَلَمَةَ، وَمُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ كُرَيْبٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ وَضَعَتْ سُبَيْعَةُ بَعْدَ وَفَاةِ زَوْجِهَا بِأَيَّامٍ فَأَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَزَوَّجَ ‏.‏\hadithno{3513}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Salamah said:"Subai'ah gave birth a few days after her husband died, and the Messenger of Allah told her to get married}}
\hadithdefcmd{nasai}{3514}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَأَبَا، سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ اخْتَلَفَا فِي الْمَرْأَةِ تُنْفَسُ بَعْدَ وَفَاةِ زَوْجِهَا بِلَيَالٍ فَقَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ آخِرُ الأَجَلَيْنِ ‏.‏ وَقَالَ أَبُو سَلَمَةَ إِذَا نُفِسَتْ فَقَدْ حَلَّتْ ‏.‏ فَجَاءَ أَبُو هُرَيْرَةَ فَقَالَ أَنَا مَعَ ابْنِ أَخِي ‏.‏ يَعْنِي أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ ‏.‏ فَبَعَثُوا كُرَيْبًا مَوْلَى ابْنِ عَبَّاسٍ إِلَى أُمِّ سَلَمَةَ يَسْأَلُهَا عَنْ ذَلِكَ فَجَاءَهُمْ فَأَخْبَرَهُمْ أَنَّهَا قَالَتْ وَلَدَتْ سُبَيْعَةُ بَعْدَ وَفَاةِ زَوْجِهَا بِلَيَالٍ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قَدْ حَلَلْتِ ‏"‏ ‏.‏\hadithno{3514}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sulaiman bin Yasar that 'Abdullah bin 'Abbas and Abu Salamah bin 'Abdur-Rahman disagreed concerning a woman who gave birth one day after her husband died. 'Abdullah bin 'Abbas said:"(She should wait) for the longer of the two periods." Abu Salamah said: "When she has given birth, it becomes permissible for her to remarry." Abu Hurairah came and said: "I agree with my brother's son" -meaning Abu Salamah bin 'Abdur-Rahman. They sent Kuraib, the freed slave of Ibn 'Abbas, to Umm Salamah to ask her about that. He came back to them and told them that she said: "Subai'ah gave birth one day after her husband died;" she mentioned that to the Messenger of Allah and he said: "It has become permissible for you to marry}}
\hadithdefcmd{nasai}{3515}{أَخْبَرَنَا حُسَيْنُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ يَسَارٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ كُنْتُ أَنَا وَابْنُ، عَبَّاسٍ وَأَبُو هُرَيْرَةَ فَقَالَ ابْنُ عَبَّاسٍ إِذَا وَضَعَتِ الْمَرْأَةُ بَعْدَ وَفَاةِ زَوْجِهَا فَإِنَّ عِدَّتَهَا آخِرُ الأَجَلَيْنِ ‏.‏ فَقَالَ أَبُو سَلَمَةَ فَبَعَثْنَا كُرَيْبًا إِلَى أُمِّ سَلَمَةَ يَسْأَلُهَا عَنْ ذَلِكَ فَجَاءَنَا مِنْ عِنْدِهَا أَنَّ سُبَيْعَةَ تُوُفِّيَ عَنْهَا زَوْجُهَا فَوَضَعَتْ بَعْدَ وَفَاةِ زَوْجِهَا بِأَيَّامٍ فَأَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَتَزَوَّجَ ‏.‏\hadithno{3515}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Salamah bin 'Abdur-Rahman said:"Ibn 'Abbas, Abu Hurairah and I were together, and Ibn 'Abbas said: 'If a woman gives birth after her husband dies, her 'Iddah is the longer of the two periods.'" Abu Salamah said: "We sent Kuraib to Umm Salamah to ask her about that. He came to us and told us from her that the husband of Subai'ah died and she gave birth a few days after her husband died, and the Messenger of Allah told her to get married}}
\hadithdefcmd{nasai}{3516}{أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ عَنْ أُمِّهَا أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ امْرَأَةً مِنْ أَسْلَمَ يُقَالُ لَهَا سُبَيْعَةُ كَانَتْ تَحْتَ زَوْجِهَا فَتُوُفِّيَ عَنْهَا وَهِيَ حُبْلَى فَخَطَبَهَا أَبُو السَّنَابِلِ بْنُ بَعْكَكٍ فَأَبَتْ أَنْ تَنْكِحَهُ فَقَالَ مَا يَصْلُحُ لَكِ أَنْ تَنْكِحِي حَتَّى تَعْتَدِّي آخِرَ الأَجَلَيْنِ ‏.‏ فَمَكَثَتْ قَرِيبًا مِنْ عِشْرِينَ لَيْلَةً ثُمَّ نُفِسَتْ فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ انْكِحِي ‏"‏ ‏.‏\hadithno{3516}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Salamah bin 'Abdur-Rahman that Zainab bint Abi Salamah told him, from her mother, Umm Salamah, the wife of the Prophet:"That a woman from Aslam who was called Subai'ah was married to her husband, and he died while she was pregnant. Abu As-Sanabil bin Ba'kak proposed to her but she refused to marry him. He said: 'You cannot get married until you have observed 'Iddah for the longer of the two periods.' Approximately twenty days later she gave birth. She went to the Messenger of Allah and he said: 'Get married}}
\hadithdefcmd{nasai}{3517}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي دَاوُدُ بْنُ أَبِي عَاصِمٍ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ قَالَ بَيْنَمَا أَنَا وَأَبُو هُرَيْرَةَ عِنْدَ ابْنِ عَبَّاسٍ إِذْ جَاءَتْهُ امْرَأَةٌ فَقَالَتْ تُوُفِّيَ عَنْهَا زَوْجُهَا وَهِي حَامِلٌ فَوَلَدَتْ لأَدْنَى مِنْ أَرْبَعَةِ أَشْهُرٍ مِنْ يَوْمِ مَاتَ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ آخِرُ الأَجَلَيْنِ ‏.‏ فَقَالَ أَبُو سَلَمَةَ أَخْبَرَنِي رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ سُبَيْعَةَ الأَسْلَمِيَّةَ جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ تُوُفِّيَ عَنْهَا زَوْجُهَا وَهِيَ حَامِلٌ فَوَلَدَتْ لأَدْنَى مِنْ أَرْبَعَةِ أَشْهُرٍ فَأَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَتَزَوَّجَ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَأَنَا أَشْهَدُ عَلَى ذَلِكَ ‏.‏\hadithno{3517}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Salamah bin 'Abdur-Rahman said:"While Abu Hurairah and I were with Ibn 'Abbas, a woman came and said that her husband had died while she was pregnant, then she had given birth less than four months after the day he died. Ibn 'Abbas said: '(You have to wait) for the longer of the two periods.'" Abu Salamah said: "A man from among the Companions of the Prophet told me that Subai'ah Al-Aslamiyyah came to the Messenger of Allah and said that her husband died while she was pregnant, and she gave birth less than four months after he died. The Messenger of Allah told her to get married. Abu Hurairah said: 'And I bear witness to that}}
\hadithdefcmd{nasai}{3518}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُ أَنَّ أَبَاهُ كَتَبَ إِلَى عُمَرَ بْنِ عَبْدِ اللَّهِ بْنِ أَرْقَمَ الزُّهْرِيِّ يَأْمُرُهُ أَنْ يَدْخُلَ عَلَى سُبَيْعَةَ بِنْتِ الْحَارِثِ الأَسْلَمِيَّةِ فَيَسْأَلَهَا حَدِيثَهَا وَعَمَّا قَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ اسْتَفْتَتْهُ فَكَتَبَ عُمَرُ بْنُ عَبْدِ اللَّهِ إِلَى عَبْدِ اللَّهِ بْنِ عُتْبَةَ يُخْبِرُهُ أَنَّ سُبَيْعَةَ أَخْبَرَتْهُ أَنَّهَا كَانَتْ تَحْتَ سَعْدِ ابْنِ خَوْلَةَ - وَهُوَ مِنْ بَنِي عَامِرِ بْنِ لُؤَىٍّ وَكَانَ مِمَّنْ شَهِدَ بَدْرًا فَتُوُفِّيَ عَنْهَا زَوْجُهَا فِي حَجَّةِ الْوَدَاعِ وَهِيَ حَامِلٌ - فَلَمْ تَنْشَبْ أَنْ وَضَعَتْ حَمْلَهَا بَعْدَ وَفَاتِهِ فَلَمَّا تَعَلَّتْ مِنْ نِفَاسِهَا تَجَمَّلَتْ لِلْخُطَّابِ فَدَخَلَ عَلَيْهَا أَبُو السَّنَابِلِ بْنُ بَعْكَكٍ - رَجُلٌ مِنْ بَنِي عَبْدِ الدَّارِ - فَقَالَ لَهَا مَا لِي أَرَاكِ مُتَجَمِّلَةً لَعَلَّكِ تُرِيدِينَ النِّكَاحَ إِنَّكِ وَاللَّهِ مَا أَنْتِ بِنَاكِحٍ حَتَّى تَمُرَّ عَلَيْكِ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا ‏.‏ قَالَتْ سُبَيْعَةُ فَلَمَّا قَالَ لِي ذَلِكَ جَمَعْتُ عَلَىَّ ثِيَابِي حِينَ أَمْسَيْتُ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلْتُهُ عَنْ ذَلِكَ فَأَفْتَانِي بِأَنِّي قَدْ حَلَلْتُ حِينَ وَضَعْتُ حَمْلِي وَأَمَرَنِي بِالتَّزْوِيجِ إِنْ بَدَا لِي ‏.‏\hadithno{3518}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ubaidullah bin 'Abdullah narrated that his father wrote to 'Umar bin 'Abdullah bin Arqam Az-Zuhri, telling him to go to Subai'ah bint Al-Harith Al-Aslamiyyah and ask her about her Hadith and what the Messenger of Allah had said to her when she consulted him. 'Umar bin 'Abdullah wrote back to 'Abdullah bin 'Utbah telling him that Subai'ah told him, that she was married to Sahl bin Khawlah -who was from Banu 'Amir bin Lu-ayy and was one of those who had been present at Badr- and her husband died during the Farewell Pilgrimage while she was pregnant. She gave birth soon after he died, and when her Nifas ended she adorned herself to receive proposals of marriage. Abu As-Sanabil bin Ba'kak -a man from Banu 'Abd Ad-Dar- went to her and said to her:'Why do I see you adorned? Perhaps you want to get married, but by Allah you will not get married until four months and ten days have passed.' Subai'ah said: 'When he said that to me, I put on my clothes in the evening and went to the Messenger of Allah and asked him about that. He ruled that it had become permissible for me to marry when I gave birth, and he told me to get married if I wanted to}}
\hadithdefcmd{nasai}{3519}{أَخْبَرَنَا مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ الزُّهْرِيِّ، قَالَ كَتَبَ إِلَيْهِ يَذْكُرُ أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ حَدَّثَهُ أَنَّ زُفَرَ بْنَ أَوْسِ بْنِ الْحَدَثَانِ النَّصْرِيَّ حَدَّثَهُ أَنَّ أَبَا السَّنَابِلِ بْنَ بَعْكَكِ بْنِ السَّبَّاقِ قَالَ لِسُبَيْعَةَ الأَسْلَمِيَّةِ لاَ تَحِلِّينَ حَتَّى يَمُرَّ عَلَيْكِ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا أَقْصَى الأَجَلَيْنِ ‏.‏ فَأَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلَتْهُ عَنْ ذَلِكَ فَزَعَمَتْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفْتَاهَا أَنْ تَنْكِحَ إِذَا وَضَعَتْ حَمْلَهَا وَكَانَتْ حُبْلَى فِي تِسْعَةِ أَشْهُرٍ حِينَ تُوُفِّيَ زَوْجُهَا وَكَانَتْ تَحْتَ سَعْدِ ابْنِ خَوْلَةَ فَتُوُفِّيَ فِي حَجَّةِ الْوَدَاعِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَكَحَتْ فَتًى مِنْ قَوْمِهَا حِينَ وَضَعَتْ مَا فِي بَطْنِهَا ‏.‏\hadithno{3519}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Yazid bin Abi Habib that Muhammad bin Muslim Az-Zuhri wrote to him mentioning that 'Ubaidullah bin 'Abdullah told him, that Zufar bin Aws bin Al-Hadathan An-Nasri told him that Abu As-Sanabil bin Ba'kak bin As-Sabbaq said to Subai'ah Al-Aslamiyyah:"It is not permissible for you to get married until four months and ten days, the longer of the two periods, have passed." She went to the Messenger of Allah and asked him about that. She said that the Messenger of Allah ruled that she could get married when she had given birth. She was nine months pregnant when her husband died, and she was married to Sa'd bin Khawlah, who died during the Farewell Pilgrimage with the Messenger of Allah. She married a young man from her people when she had given birth to (the child)}}
\hadithdefcmd{nasai}{3520}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُتْبَةَ، كَتَبَ إِلَى عُمَرَ بْنِ عَبْدِ اللَّهِ بْنِ الأَرْقَمِ الزُّهْرِيِّ أَنِ ادْخُلْ، عَلَى سُبَيْعَةَ بِنْتِ الْحَارِثِ الأَسْلَمِيَّةِ فَاسْأَلْهَا عَمَّا أَفْتَاهَا بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَمْلِهَا ‏.‏ قَالَ فَدَخَلَ عَلَيْهَا عُمَرُ بْنُ عَبْدِ اللَّهِ فَسَأَلَهَا فَأَخْبَرَتْهُ أَنَّهَا كَانَتْ تَحْتَ سَعْدِ ابْنِ خَوْلَةَ - وَكَانَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِمَّنْ شَهِدَ بَدْرًا - فَتُوُفِّيَ عَنْهَا فِي حَجَّةِ الْوَدَاعِ فَوَلَدَتْ قَبْلَ أَنْ تَمْضِيَ لَهَا أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا مِنْ وَفَاةِ زَوْجِهَا فَلَمَّا تَعَلَّتْ مِنْ نِفَاسِهَا دَخَلَ عَلَيْهَا أَبُو السَّنَابِلِ - رَجُلٌ مِنْ بَنِي عَبْدِ الدَّارِ - فَرَآهَا مُتَجَمِّلَةً فَقَالَ لَعَلَّكِ تُرِيدِينَ النِّكَاحَ قَبْلَ أَنْ تَمُرَّ عَلَيْكِ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا ‏.‏ قَالَتْ فَلَمَّا سَمِعْتُ ذَلِكَ مِنْ أَبِي السَّنَابِلِ جِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَحَدَّثْتُهُ حَدِيثِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ حَلَلْتِ حِينَ وَضَعْتِ حَمْلَكِ ‏"‏ ‏.‏\hadithno{3520}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah that 'Abdullah bin 'Utbah wrote to 'Umar bin 'Abdullah bin Al-Arqam Az-Zuhri, telling him:"Go to Subai'ah bint Al-Harith Al-Aslamiyyah, and ask her about the ruling of the Messenger of Allah concerning her pregnancy." He said: "So 'Umar bin 'Abdullah went to her and asked her. She told him that she was married to Sa'd bin Khawlah, who was one of the Companions of the Messenger of Allah who had been present at Badr. He died during the Farewell Pilgrimage, and she gave birth before four months and ten days had passed since her husband's death. When her Nifas ended, Abu As-Sanabil -a man from Banu 'Abd Ad-Dar- went to her and saw that she had adorned herself. He said: 'Perhaps you want to get married before four months and ten days has passed?' She said: 'When I heard that from Abu As-Sanabil, I went to the Messenger of Allah and told him my story. The Messenger of Allah said: 'It is permissible for you to marry when you gave birth}}
\hadithdefcmd{nasai}{3521}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، قَالَ كُنْتُ جَالِسًا فِي نَاسٍ بِالْكُوفَةِ فِي مَجْلِسٍ - لِلأَنْصَارِ - عَظِيمٍ فِيهِمْ عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى فَذَكَرُوا شَأْنَ سُبَيْعَةَ فَذَكَرْتُ عَنْ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ فِي مَعْنَى قَوْلِ ابْنِ عَوْنٍ حَتَّى تَضَعَ ‏.‏ قَالَ ابْنُ أَبِي لَيْلَى لَكِنَّ عَمَّهُ لاَ يَقُولُ ذَلِكَ فَرَفَعْتُ صَوْتِي وَقُلْتُ إِنِّي لَجَرِيءٌ أَنْ أَكْذِبَ عَلَى عَبْدِ اللَّهِ بْنِ عُتْبَةَ وَهُوَ فِي نَاحِيَةِ الْكُوفَةِ ‏.‏ قَالَ فَلَقِيتُ مَالِكًا قُلْتُ كَيْفَ كَانَ ابْنُ مَسْعُودٍ يَقُولُ فِي شَأْنِ سُبَيْعَةَ قَالَ قَالَ أَتَجْعَلُونَ عَلَيْهَا التَّغْلِيظَ وَلاَ تَجْعَلُونَ لَهَا الرُّخْصَةَ لأُنْزِلَتْ سُورَةُ النِّسَاءِ الْقُصْرَى بَعْدَ الطُّولَى ‏.‏\hadithno{3521}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Muhammad said:"I was sitting with some people in Al-Kufah in a large gathering of the Ansar, among whom was 'Abdur-Rahman bin Abi Laila. They spoke about the story of Subai'ah and I mentioned what 'Abdullah bin 'Utbah bin Mas'ud had said in meaning." (One of the narrators) Ibn 'Awn's saying was: "when she gives birth." Ibn Abi Layla said: 'But his (paternal) uncle did not say that.' I raised my voice and said: 'Would I dare to tell lies about 'Abdullah bin 'Utbah when he is in the vicinity of Al-Kufah?'" He said: "Then I met Malik and said: 'What did Ibn Mas'ud say about the story of Subai'ah?' He said: 'He said: "Are you going to be too strict with her and not allow her the concession (with regard to the 'Iddah)? The shorter Surah about women (At-Talaq) was revealed after the longer one (Al-Baqarah)}}
\hadithdefcmd{nasai}{3522}{أَخْبَرَنِي مُحَمَّدُ بْنُ مِسْكِينِ بْنِ نُمَيْلَةَ، - يَمَامِيٌّ - قَالَ أَنْبَأَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَأَخْبَرَنِي مَيْمُونُ بْنُ الْعَبَّاسِ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ الْحَكَمِ بْنِ أَبِي مَرْيَمَ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي ابْنُ شُبْرُمَةَ الْكُوفِيُّ، عَنْ إِبْرَاهِيمَ النَّخَعِيِّ، عَنْ عَلْقَمَةَ بْنِ قَيْسٍ، أَنَّ ابْنَ مَسْعُودٍ، قَالَ مَنْ شَاءَ لاَعَنْتُهُ مَا أُنْزِلَتْ ‏\{‏ وَأُولاَتُ الأَحْمَالِ أَجَلُهُنَّ أَنْ يَضَعْنَ حَمْلَهُنَّ ‏\}‏ إِلاَّ بَعْدَ آيَةِ الْمُتَوَفَّى عَنْهَا زَوْجُهَا إِذَا وَضَعَتِ الْمُتَوَفَّى عَنْهَا زَوْجُهَا فَقَدْ حَلَّتْ وَاللَّفْظُ لِمَيْمُونٍ ‏.‏\hadithno{3522}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Alqamah bin Qais that Ibn Mas'ud said:"Whoever wants, I will meet and debate with him and invoke the curse of Allah upon those who lie. The Verse: 'And for those who are pregnant (whether they are divorced or their husbands are dead), their 'Iddah (prescribed period) is until they lay down their burden.' was only revealed after the Verse about women whose husbands die. 'When a woman whose husband has died gives birth, it becomes permissible for her to marry.'" This is the wording of Maimun (one of the narrators)}}
\hadithdefcmd{nasai}{3523}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ قَالَ حَدَّثَنَا الْحَسَنُ، وَهُوَ ابْنُ أَعْيَنَ قَالَ حَدَّثَنَا زُهَيْرٌ، ح وَأَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ الأَسْوَدِ، وَمَسْرُوقٍ، وَعَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ سُورَةَ النِّسَاءِ الْقُصْرَى، نَزَلَتْ بَعْدَ الْبَقَرَةِ ‏.‏\hadithno{3523}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah that the shorter Surah, that speaks of women (At-Talaq), was revealed after Al-Baqarah}}
\hadithdefcmd{nasai}{3524}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنِ ابْنِ مَسْعُودٍ، أَنَّهُ سُئِلَ عَنْ رَجُلٍ، تَزَوَّجَ امْرَأَةً وَلَمْ يَفْرِضْ لَهَا صَدَاقًا وَلَمْ يَدْخُلْ بِهَا حَتَّى مَاتَ قَالَ ابْنُ مَسْعُودٍ لَهَا مِثْلُ صَدَاقِ نِسَائِهَا لاَ وَكْسَ وَلاَ شَطَطَ وَعَلَيْهَا الْعِدَّةُ وَلَهَا الْمِيرَاثُ ‏.‏ فَقَامَ مَعْقِلُ بْنُ سِنَانٍ الأَشْجَعِيُّ فَقَالَ قَضَى فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بِرْوَعَ بِنْتِ وَاشِقٍ - امْرَأَةٍ مِنَّا - مِثْلَ مَا قَضَيْتَ ‏.‏ فَفَرِحَ ابْنُ مَسْعُودٍ رضى الله عنه ‏.‏\hadithno{3524}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Mas'ud, that he was asked about a man who married a woman, but did not name a Mahr or consummate the marriage before he died. Ibn Mas'ud said:"She should have a Mahr like that of women like her, no less and no more; she has to observe the 'Iddah, and she is entitled to inherit." Ma'qil bin Sinan Al-Ashja'i stood up and said: "The Messenger of Allah passed a similar judgment among us concerning Birwa' bint Washiq." And Ibn Masud rejoiced at that}}
\hadithdefcmd{nasai}{3525}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تَحِدُّ عَلَى مَيِّتٍ أَكْثَرَ مِنْ ثَلاَثٍ إِلاَّ عَلَى زَوْجِهَا ‏"‏ ‏.‏\hadithno{3525}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"It is not permissible for a woman to mourn for anyone who dies for more than three days, except for her husband}}
\hadithdefcmd{nasai}{3526}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تَحِدَّ فَوْقَ ثَلاَثَةِ أَيَّامٍ إِلاَّ عَلَى زَوْجٍ ‏"‏ ‏.‏\hadithno{3526}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"It is not permissible for a woman who believes in Allah and the Last Day to mourn for more than three days, except for her husband}}
\hadithdefcmd{nasai}{3527}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي أَيُّوبُ بْنُ مُوسَى، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّ أُمَّ حَبِيبَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى هَذَا الْمِنْبَرِ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَرَسُولِهِ أَنْ تَحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3527}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab bint Abi Salamah that Umm Habibah said:"I heard the Messenger of Allah say this on this Minbar: 'It is not permissible for a woman who believes in Allah and His Messenger to mourn for anyone who dies for more than three days, except for a husband, (for whom the mourning period is) four months and ten days}}
\hadithdefcmd{nasai}{3528}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ شُعْبَةَ، وَابْنِ، جُرَيْجٍ وَيَحْيَى بْنِ سَعِيدٍ وَمُحَمَّدِ بْنِ إِسْحَاقَ عَنْ سَعْدِ بْنِ إِسْحَاقَ، عَنْ زَيْنَبَ بِنْتِ كَعْبٍ، عَنِ الْفَارِعَةِ بِنْتِ مَالِكٍ، أَنَّ زَوْجَهَا، خَرَجَ فِي طَلَبِ أَعْلاَجٍ فَقَتَلُوهُ - قَالَ شُعْبَةُ وَابْنُ جُرَيْجٍ وَكَانَتْ فِي دَارٍ قَاصِيَةٍ فَجَاءَتْ وَمَعَهَا أَخُوهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا لَهُ فَرَخَّصَ لَهَا حَتَّى إِذَا رَجَعَتْ دَعَاهَا فَقَالَ ‏ "‏ اجْلِسِي فِي بَيْتِكِ حَتَّى يَبْلُغَ الْكِتَابُ أَجَلَهُ ‏"‏ ‏.‏\hadithno{3528}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Al-Fari'ah bint Malik that her husband went out to pursue some slaves and they killed him. Shu'bah and Ibn Juraij said:"She was in a remote house. She came with her brothers to the Messenger of Allah and told him (about the situation) and he granted her a concession. When she was leaving he called her back and said: 'Stay in your house until the term prescribed is fulfilled}}
\hadithdefcmd{nasai}{3529}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ يَزِيدَ بْنِ مُحَمَّدٍ، عَنْ سَعْدِ بْنِ إِسْحَاقَ، عَنْ عَمَّتِهِ، زَيْنَبَ بِنْتِ كَعْبٍ عَنِ الْفُرَيْعَةِ بِنْتِ مَالِكٍ، أَنَّ زَوْجَهَا، تَكَارَى عُلُوجًا لِيَعْمَلُوا لَهُ فَقَتَلُوهُ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَقَالَتْ إِنِّي لَسْتُ فِي مَسْكَنٍ لَهُ وَلاَ يَجْرِي عَلَىَّ مِنْهُ رِزْقٌ أَفَأَنْتَقِلُ إِلَى أَهْلِي وَيَتَامَاىَ وَأَقُومُ عَلَيْهِمْ قَالَ ‏"‏ افْعَلِي ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ كَيْفَ قُلْتِ ‏"‏ ‏.‏ فَأَعَادَتْ عَلَيْهِ قَوْلَهَا قَالَ ‏"‏ اعْتَدِّي حَيْثُ بَلَغَكِ الْخَبَرُ ‏"‏ ‏.‏\hadithno{3529}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Furai'ah bint Malik that her husband hired some slaves to work for him and they killed him. She mentioned that to the Messenger of Allah and said:"I am not living in a house that belongs to him, and I do not receive maintenance from him; should I move to my family with my two orphans and stay with them?" He said: "Do that." Then he said: "What did you say?" So she told him again and he said: "Observe your 'Iddah where the news came to you}}
\hadithdefcmd{nasai}{3530}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ سَعْدِ بْنِ إِسْحَاقَ، عَنْ زَيْنَبَ، عَنْ فُرَيْعَةَ، أَنَّ زَوْجَهَا، خَرَجَ فِي طَلَبِ أَعْلاَجٍ لَهُ فَقُتِلَ بِطَرَفِ الْقَدُّومِ - قَالَتْ - فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ لَهُ النُّقْلَةَ إِلَى أَهْلِي وَذَكَرَتْ لَهُ حَالاً مِنْ حَالِهَا - قَالَتْ - فَرَخَّصَ لِي فَلَمَّا أَقْبَلْتُ نَادَانِي فَقَالَ ‏ "‏ امْكُثِي فِي أَهْلِكِ حَتَّى يَبْلُغَ الْكِتَابُ أَجَلَهُ ‏"‏ ‏.‏\hadithno{3530}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Furai'ah that her husband went out to pursue some slaves of his and he was killed on the edge of Al-Qadum. She said:"I came to the Prophet and mentioned moving to (join) my family." She told him about her situation. She said: "He allowed me, then, when I turned to leave, he called me back and said: 'Stay with your family until the term prescribed is fulfilled}}
\hadithdefcmd{nasai}{3531}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا وَرْقَاءُ، عَنِ ابْنِ أَبِي نَجِيحٍ، قَالَ عَطَاءٌ عَنِ ابْنِ عَبَّاسٍ، نَسَخَتْ هَذِهِ الآيَةُ عِدَّتَهَا فِي أَهْلِهَا فَتَعْتَدُّ حَيْثُ شَاءَتْ وَهُوَ قَوْلُ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ غَيْرَ إِخْرَاجٍ ‏\}‏ ‏.‏\hadithno{3531}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that this Verse abrogated the woman's 'Iddah among her family, and she may observe her 'Iddah wherever she wants. That is the saying of Allah, the Mighty and Sublime:without turning them out}}
\hadithdefcmd{nasai}{3532}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ سَعْدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَتْنِي زَيْنَبُ بِنْتُ كَعْبٍ، قَالَتْ حَدَّثَتْنِي فُرَيْعَةُ بِنْتُ مَالِكٍ، أُخْتُ أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَتْ تُوُفِّيَ زَوْجِي بِالْقَدُّومِ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ لَهُ أَنَّ دَارَنَا شَاسِعَةٌ فَأَذِنَ لَهَا ثُمَّ دَعَاهَا فَقَالَ ‏ "‏ امْكُثِي فِي بَيْتِكِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا حَتَّى يَبْلُغَ الْكِتَابُ أَجَلَهُ ‏"‏ ‏.‏\hadithno{3532}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Furai'ah bint Malik, the sister of Abu Sa'eed Al-Khudri, said:"My husband died in Al-Qadum, so I went to the Prophet and told him that our house was remote." He gave her permission then he called her back and said: "Stay in your house for four months and ten days, until the term prescribed is fulfilled}}
\hadithdefcmd{nasai}{3533}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ بِهَذِهِ الأَحَادِيثِ الثَّلاَثَةِ، قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ بْنُ حَرْبٍ فَدَعَتْ أُمُّ حَبِيبَةَ بِطِيبٍ فَدَهَنَتْ مِنْهُ جَارِيَةً ثُمَّ مَسَّتْ بِعَارِضَيْهَا ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تَحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3533}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Humaid bin Nafi' that Zainab bint Abi Salamah told him these three Hadiths. Zainab said:"I entered upon Umm Habibah, the wife of the Prophet, when her father Abu Sufyan bin Harb died. Umm Habibah called for some perfume and put some on a young girl, then she put some on her cheeks. Then she said: 'By Allah, I do not have any need for perfume but I heard the Messenger of Allah say: It is not permissible for any woman who believes in Allah and the Last Day to mourn for anyone who dies for more than three days, except for a husband, (for whom the mourning period is) four months and ten days}}
\hadithdefcmd{nasai}{3533p2}{قَالَتْ زَيْنَبُ ثُمَّ دَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا وَقَدْ دَعَتْ بِطِيبٍ وَمَسَّتْ مِنْهُ ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تَحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3533.2}\hadithtrans{Zainab said:"Then I went into Zainab bint Jahsh when her brother died, and she called for some perfume and put some on. Then she said: 'By Allah, I do not have any need for perfume but I heard the Messenger of Allah say on the Minbar: It is not permissible for any woman who believes in Allah and the Last Day to mourn for anyone who dies for more than three days, except for a husband, (for whom the mourning period is) four months and ten days}}
\hadithdefcmd{nasai}{3533p3}{وَقَالَتْ زَيْنَبُ سَمِعْتُ أُمَّ سَلَمَةَ، تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنَهَا أَفَأَكْحُلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعْرَةِ عِنْدَ رَأْسِ الْحَوْلِ ‏"‏ ‏.‏ قَالَ حُمَيْدٌ فَقُلْتُ لِزَيْنَبَ وَمَا تَرْمِي بِالْبَعْرَةِ عِنْدَ رَأْسِ الْحَوْلِ قَالَتْ زَيْنَبُ كَانَتِ الْمَرْأَةُ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا دَخَلَتْ حِفْشًا وَلَبِسَتْ شَرَّ ثِيَابِهَا وَلَمْ تَمَسَّ طِيبًا وَلاَ شَيْئًا حَتَّى تَمُرَّ بِهَا سَنَةٌ ثُمَّ تُؤْتَى بِدَابَّةٍ حِمَارٍ أَوْ شَاةٍ أَوْ طَيْرٍ فَتَفْتَضُّ بِهِ فَقَلَّمَا تَفْتَضُّ بِشَىْءٍ إِلاَّ مَاتَ ثُمَّ تَخْرُجُ فَتُعْطَى بَعْرَةً فَتَرْمِي بِهَا وَتُرَاجِعُ بَعْدُ مَا شَاءَتْ مِنْ طِيبٍ أَوْ غَيْرِهِ ‏.‏ قَالَ مَالِكٌ تَفْتَضُّ تَمْسَحُ بِهِ فِي حَدِيثِ مُحَمَّدٍ ‏.‏ قَالَ مَالِكٌ الْحِفْشُ الْخُصُّ ‏.‏\hadithno{3533.3}\hadithtrans{Zainab said:"I heard Umm Salamah say: 'A woman came to the Messenger of Allah and said: O Messenger of Allah, my daughter's husband has died and she has a problem in her eye; can I put kohl on her? The Messenger of Allah said: No. Then he said: It is four months and ten days. During the Jahiliyyah one of you would throw a piece of dung at the end of the year.'" Humaid said: "I said to Zainab: 'What is this throwing a piece of dung at the end of the year?' She said: 'If a woman's husband died, she would enter a small room (Hifsh) and wear her worst clothes, and she would not put on perfume or anything until a year. Then an animal would be brought, a donkey or sheep or bird, and she would end her 'Iddah with it (clean herself with it), and usually any animal used for that purpose would die. Then she would come out and would be given a piece of dung which she would throw, then she would go back to whatever she wanted of perfume, etc.'" In the narration of Muhammad (bin Salamah) Malik said: Hifsh means hut}}
\hadithdefcmd{nasai}{3534}{أَخْبَرَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحِدُّ امْرَأَةٌ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ فَإِنَّهَا تَحِدُّ عَلَيْهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا وَلاَ تَلْبَسُ ثَوْبًا مَصْبُوغًا وَلاَ ثَوْبَ عَصْبٍ وَلاَ تَكْتَحِلُ وَلاَ تَمْتَشِطُ وَلاَ تَمَسُّ طِيبًا إِلاَّ عِنْدَ طُهْرِهَا حِينَ تَطْهُرُ نُبَذًا مِنْ قُسْطٍ وَأَظْفَارٍ ‏"‏ ‏.‏\hadithno{3534}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Umm 'Atiyyah said:"The Messenger of Allah said: 'No woman should mourn for anyone who dies for more than three days, except for a husband, for whom she should mourn for four months and ten days. She should not wear garments that are dyed or patterned, or put on kohl or comb her hair, and she should not put on any perfume except when purifying herself after her period, when she may use a little of Qust or Azfar}}
\hadithdefcmd{nasai}{3535}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، قَالَ حَدَّثَنِي بُدَيْلٌ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُتَوَفَّى عَنْهَا زَوْجُهَا لاَ تَلْبَسُ الْمُعَصْفَرَ مِنَ الثِّيَابِ وَلاَ الْمُمَشَّقَةَ وَلاَ تَخْتَضِبُ وَلاَ تَكْتَحِلُ ‏"‏ ‏.‏\hadithno{3535}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Safiyyah bint Shaibah, from Umm Salamah, the wife of the Prophet, that the Prophet said:"The woman whose husband has died should not wear clothes that are dyed with safflower or red clay, and she should not use dye nor kohl}}
\hadithdefcmd{nasai}{3536}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَاصِمٌ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تَحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ وَلاَ تَكْتَحِلُ وَلاَ تَخْتَضِبُ وَلاَ تَلْبَسُ ثَوْبًا مَصْبُوغًا ‏"‏ ‏.‏\hadithno{3536}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Umm 'Atiyyah that the Prophet said:"It is not permissible for a woman who believes in Allah and the Last Day, to mourn for anyone who dies for more than three days, except for a husband; she should not use kohl, dye nor wear dyed clothes}}
\hadithdefcmd{nasai}{3537}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ الْمُغِيرَةَ بْنَ الضَّحَّاكِ، يَقُولُ حَدَّثَتْنِي أُمُّ حَكِيمٍ بِنْتُ أَسِيدٍ، عَنْ أُمِّهَا، أَنَّ زَوْجَهَا، تُوُفِّيَ وَكَانَتْ تَشْتَكِي عَيْنَهَا فَتَكْتَحِلُ الْجِلاَءَ فَأَرْسَلَتْ مَوْلاَةً لَهَا إِلَى أُمِّ سَلَمَةَ فَسَأَلَتْهَا عَنْ كُحْلِ الْجِلاَءِ فَقَالَتْ لاَ تَكْتَحِلُ إِلاَّ مِنْ أَمْرٍ لاَ بُدَّ مِنْهُ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُو سَلَمَةَ وَقَدْ جَعَلْتُ عَلَى عَيْنِي صَبِرًا فَقَالَ ‏"‏ مَا هَذَا يَا أُمَّ سَلَمَةَ ‏"‏ ‏.‏ قُلْتُ إِنَّمَا هُوَ صَبِرٌ يَا رَسُولَ اللَّهِ لَيْسَ فِيهِ طِيبٌ ‏.‏ قَالَ ‏"‏ إِنَّهُ يَشُبُّ الْوَجْهَ فَلاَ تَجْعَلِيهِ إِلاَّ بِاللَّيْلِ وَلاَ تَمْتَشِطِي بِالطِّيبِ وَلاَ بِالْحِنَّاءِ فَإِنَّهُ خِضَابٌ ‏"‏ ‏.‏ قُلْتُ بِأَىِّ شَىْءٍ أَمْتَشِطُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِالسِّدْرِ تُغَلِّفِينَ بِهِ رَأْسَكِ ‏"‏ ‏.‏\hadithno{3537}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umm Hakim bint Asid narrated from her mother that her husband died and she had a problem in her eye, so she applied kohl to clear her eyes. She sent a freed slave woman of hers to Umm Salamah to ask her about using kohl to clear her eyes. She said:"Do not use kohl unless it cannot be avoided. The Messenger of Allah entered upon me when Abu Salamah died and I had put some aloe juice on my eyes. He said: 'What is this, O Umm Salamah?' I said: 'It is aloe juice, O Messenger of Allah, there is no perfume in it.' He said: 'It makes the face look bright, so only use it at night, and do not comb your hair with perfume or henna, for it is a dye.' I said: 'With what can I comb it, O Messenger of Allah?' He said: 'With lote leaves -cover your head with them}}
\hadithdefcmd{nasai}{3538}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، عَنْ أَبِيهِ، قَالَ حَدَّثَنَا أَيُّوبُ، - وَهُوَ ابْنُ مُوسَى - قَالَ حُمَيْدٌ وَحَدَّثَتْنِي زَيْنَبُ بِنْتُ أَبِي سَلَمَةَ، عَنْ أُمِّهَا أُمِّ سَلَمَةَ، قَالَتْ جَاءَتِ امْرَأَةٌ مِنْ قُرَيْشٍ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي رَمِدَتْ أَفَأَكْحُلُهَا ‏.‏ وَكَانَتْ مُتَوَفًّى عَنْهَا ‏.‏ فَقَالَ ‏"‏ أَلاَ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ ثُمَّ قَالَتْ إِنِّي أَخَافُ عَلَى بَصَرِهَا فَقَالَ ‏"‏ لاَ إِلاَّ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا قَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَحِدُّ عَلَى زَوْجِهَا سَنَةً ثُمَّ تَرْمِي عَلَى رَأْسِ السَّنَةِ بِالْبَعْرَةِ ‏"‏ ‏.‏\hadithno{3538}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Zainab bint Abi Salamah narrated that her mother Umm Salamah said:"A woman from the Quraish came and said: 'O Messenger of Allah, my daughter's eyes are inflamed; shall I apply kohl to her?' (The daughter's) husband had died so (the Prophet) said: 'Not until four months and ten days (have passed).' Then she said: 'I fear for her sight.' He said: 'No, not until four months and ten days (have passed). During the Jahiliyyah one of you would mourn for her husband for a year, then when one year had passed she would throw a piece of dung}}
\hadithdefcmd{nasai}{3539}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّهَا، أَنَّ امْرَأَةً، أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَسَأَلَتْهُ عَنِ ابْنَتِهَا مَاتَ زَوْجُهَا وَهِيَ تَشْتَكِي قَالَ ‏ "‏ قَدْ كَانَتْ إِحْدَاكُنَّ تَحِدُّ السَّنَةَ ثُمَّ تَرْمِي الْبَعْرَةَ عَلَى رَأْسِ الْحَوْلِ وَإِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3539}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab bint Abi Salamah, from her mother, that a woman came to the Prophet and asked him about her daughter whose husband had died and she was ill. He said:"One of you used to mourn for a year, then throw a piece of dung when a year had passed. Rather it (the mourning period) is four months and ten days}}
\hadithdefcmd{nasai}{3540}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْدَانَ بْنِ عِيسَى بْنِ مَعْدَانَ، قَالَ حَدَّثَنَا ابْنُ أَعْيَنَ، قَالَ حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، مَوْلَى الأَنْصَارِ عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ امْرَأَةً، مِنْ قُرَيْشٍ جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدْ خِفْتُ عَلَى عَيْنِهَا وَهِيَ تُرِيدُ الْكُحْلَ فَقَالَ ‏ "‏ قَدْ كَانَتْ إِحْدَاكُنَّ تَرْمِي بِالْبَعْرَةِ عَلَى رَأْسِ الْحَوْلِ وَإِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ فَقُلْتُ لِزَيْنَبَ مَا رَأْسُ الْحَوْلِ قَالَتْ كَانَتِ الْمَرْأَةُ فِي الْجَاهِلِيَّةِ إِذَا هَلَكَ زَوْجُهَا عَمَدَتْ إِلَى شَرِّ بَيْتٍ لَهَا فَجَلَسَتْ فِيهِ حَتَّى إِذَا مَرَّتْ بِهَا سَنَةٌ خَرَجَتْ فَرَمَتْ وَرَاءَهَا بِبَعْرَةٍ ‏.‏\hadithno{3540}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab bint Abi Salamah, from Umm Salamah that a woman from the Quraish came to the Messenger of Allah and said:"My daughter's husband has died, and I am worried about her eyes; she needs kohl." He said: "One of you used to throw a piece of dung after a year had passed. Rather it (the mourning period) is four months and ten days." I (the narrator) said to Zainab: "What does 'after a year had passed' mean?" She said: "During the Jahiliyyah, if a woman's husband died she would go to the worst room she had and stay there, then, when a year had passed, she would come out and throw a piece of dung behind her}}
\hadithdefcmd{nasai}{3541}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ، أَنَّ امْرَأَةً، سَأَلَتْ أُمَّ سَلَمَةَ وَأُمَّ حَبِيبَةَ أَتَكْتَحِلُ فِي عِدَّتِهَا مِنْ وَفَاةِ زَوْجِهَا فَقَالَتْ أَتَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَأَلَتْهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ قَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا أَقَامَتْ سَنَةً ثُمَّ قَذَفَتْ خَلْفَهَا بِبَعْرَةٍ ثُمَّ خَرَجَتْ وَإِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا حَتَّى يَنْقَضِيَ الأَجَلُ ‏"‏ ‏.‏\hadithno{3541}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab that a woman asked Umm Salamah and Umm Habibah whether she could put on kohl during her 'Iddah following her husband's death. She said:"A woman came to the Prophet and asked him about that, and he said: 'During the Jahiliyyah, if her husband died, one of you would stay (in mourning) for a year, then she would throw a piece of dung then come out. Rather it (the mourning period) is four months and ten days, until the term prescribed is fulfilled}}
\hadithdefcmd{nasai}{3542}{أَخْبَرَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ، - هُوَ الدُّورِيُّ - قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، عَنْ زَائِدَةَ، عَنْ هِشَامٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ رَخَّصَ لِلْمُتَوَفَّى عَنْهَا عِنْدَ طُهْرِهَا فِي الْقُسْطِ وَالأَظْفَارِ ‏.‏\hadithno{3542}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hafsah, from Umm 'Atiyyah, from the Prophet, that he granted a concession to the woman whose husband has died, allowing her to use Qust and Azfar when purifying herself following her menses}}
\hadithdefcmd{nasai}{3543}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى السِّجْزِيُّ، خَيَّاطُ السُّنَّةِ قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، قَالَ أَخْبَرَنِي أَبِي قَالَ، حَدَّثَنَا يَزِيدُ النَّحْوِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ ‏\{‏ وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا وَصِيَّةً لأَزْوَاجِهِمْ مَتَاعًا إِلَى الْحَوْلِ غَيْرَ إِخْرَاجٍ ‏\}‏ نُسِخَ ذَلِكَ بِآيَةِ الْمِيرَاثِ مِمَّا فُرِضَ لَهَا مِنَ الرُّبُعِ وَالثُّمُنِ وَنَسَخَ أَجَلَ الْحَوْلِ أَنْ جُعِلَ أَجَلُهَا أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏.‏\hadithno{3543}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas, with regard to Allah's saying:"And those of you who die and leave behind wives should bequeath for their wives a year's maintenance and residence without turning them out." This was abrogated by the Verse on inheritance, which allocated to her one-quarter or one-eighth. And the appointed time ('Iddah) of one year was abrogated and replaced with the ('Iddah) term of four months and ten days}}
\hadithdefcmd{nasai}{3544}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا وَصِيَّةً لأَزْوَاجِهِمْ مَتَاعًا إِلَى الْحَوْلِ غَيْرَ إِخْرَاجٍ ‏\}‏ قَالَ نَسَخَتْهَا ‏\{‏ وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا يَتَرَبَّصْنَ بِأَنْفُسِهِنَّ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏\}‏ ‏.‏\hadithno{3544}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ikrimah with regard to the saying of Allah, the Mighty and Sublime:"And those of you who die and leave behind wives should bequeath for their wives a year's maintenance and residence without turning them out," that he said: "This was abrogated by: 'And those of you who die and leave wives behind them, they (the wives) shall wait (as regards their marriage) for four months and ten days}}
\hadithdefcmd{nasai}{3545}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَاصِمٍ، أَنَّ فَاطِمَةَ بِنْتَ قَيْسٍ، أَخْبَرَتْهُ وَكَانَتْ، عِنْدَ رَجُلٍ مِنْ بَنِي مَخْزُومٍ أَنَّهُ طَلَّقَهَا ثَلاَثًا وَخَرَجَ إِلَى بَعْضِ الْمَغَازِي وَأَمَرَ وَكِيلَهُ أَنْ يُعْطِيَهَا بَعْضَ النَّفَقَةِ فَتَقَالَّتْهَا فَانْطَلَقَتْ إِلَى بَعْضِ نِسَاءِ النَّبِيِّ صلى الله عليه وسلم فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهِيَ عِنْدَهَا فَقَالَتْ يَا رَسُولَ اللَّهِ هَذِهِ فَاطِمَةُ بِنْتُ قَيْسٍ طَلَّقَهَا فُلاَنٌ فَأَرْسَلَ إِلَيْهَا بِبَعْضِ النَّفَقَةِ فَرَدَّتْهَا وَزَعَمَ أَنَّهُ شَىْءٌ تَطَوَّلَ بِهِ ‏.‏ قَالَ ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَانْتَقِلِي إِلَى أُمِّ كُلْثُومٍ فَاعْتَدِّي عِنْدَهَا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ أُمَّ كُلْثُومٍ امْرَأَةٌ يَكْثُرُ عُوَّادُهَا فَانْتَقِلِي إِلَى عَبْدِ اللَّهِ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ أَعْمَى ‏"‏ ‏.‏ فَانْتَقَلَتْ إِلَى عَبْدِ اللَّهِ فَاعْتَدَّتْ عِنْدَهُ حَتَّى انْقَضَتْ عِدَّتُهَا ثُمَّ خَطَبَهَا أَبُو الْجَهْمِ وَمُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم تَسْتَأْمِرُهُ فِيهِمَا فَقَالَ ‏"‏ أَمَّا أَبُو الْجَهْمِ فَرَجُلٌ أَخَافُ عَلَيْكِ قَسْقَاسَتَهُ لِلْعَصَا وَأَمَّا مُعَاوِيَةُ فَرَجُلٌ أَمْلَقُ مِنَ الْمَالِ ‏"‏ ‏.‏ فَتَزَوَّجَتْ أُسَامَةَ بْنَ زَيْدٍ بَعْدَ ذَلِكَ ‏.‏\hadithno{3545}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdur-Rahman bin 'Asim narrated that Fatimah bint Qais -who was married to a man of Banu Makhzum- told him that he divorced her three times. He went out on a military campaign and told his representative to give her some provision. She thought it was too little, so she went to one of the wives of the Prophet, and the Messenger of Allah came in while she was with her. She said:"O Messenger of Allah, this is Fatimah bint Qais who has been divorced by so-and-so. He sent her some provision but she rejected it. He said that it was something he did not have to do (a favor)." He said: "He is telling the truth." The Prophet said: "Go to Umm Kulthum and observe your 'Iddah in her house." Then he said: "Umm Kulthum is a woman who has a lot of visitors. Go to 'Abdullah bin Umm Maktum for he is blind." So she went to 'Abdullah and observed her 'Iddah in his house, until her 'Iddah was over. Then Abu Al-Jahm and Mu'awiyah bin Abi Sufyan proposed to her. So she came to the Messenger of Allah to consult him about them. He said: "As for Abu Al-Jahm, he is a man the waving of whose stick I fear for you. And as for Mu'awiyah he is a man who does not have any money." So she married Usamah bin Zaid after that}}
\hadithdefcmd{nasai}{3546}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، كَانَتْ تَحْتَ أَبِي عَمْرِو بْنِ حَفْصِ بْنِ الْمُغِيرَةِ فَطَلَّقَهَا آخِرَ ثَلاَثِ تَطْلِيقَاتٍ ‏.‏ فَزَعَمَتْ فَاطِمَةُ أَنَّهَا جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَفْتَتْهُ فِي خُرُوجِهَا مِنْ بَيْتِهَا فَأَمَرَهَا أَنْ تَنْتَقِلَ إِلَى ابْنِ أُمِّ مَكْتُومٍ الأَعْمَى فَأَبَى مَرْوَانُ أَنْ يُصَدِّقَ فَاطِمَةَ فِي خُرُوجِ الْمُطَلَّقَةِ مِنْ بَيْتِهَا ‏.‏ قَالَ عُرْوَةُ أَنْكَرَتْ عَائِشَةُ ذَلِكَ عَلَى فَاطِمَةَ ‏.‏\hadithno{3546}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Salamah bin 'Abdur-Rahman that Fatimah bint Qais told him that she was married to Abu 'Amr bin Hafs bin Al-Mughirah, who divorced her by giving her the last of three divorces. Fatimah said that she came to the Messenger of Allah and consulted him about leaving her house. He told her to move to the house of Ibn Umm Maktum, the blind man. Marwan refused to believe Fatimah about the divorced woman leaving her house. 'Urwah said:"Aishah denounced Fatimah for that}}
\hadithdefcmd{nasai}{3547}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا حَفْصٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ فَاطِمَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ زَوْجِي طَلَّقَنِي ثَلاَثًا وَأَخَافُ أَنْ يُقْتَحَمَ عَلَىَّ ‏.‏ فَأَمَرَهَا فَتَحَوَّلَتْ ‏.‏\hadithno{3547}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hisham narrated from his father that Fatimah said:"I said: 'O Messenger of Allah! My husband has divorced me three times and I am afraid that my house be broken into.' So he told her to move}}
\hadithdefcmd{nasai}{3548}{أَخْبَرَنَا يَعْقُوبُ بْنُ مَاهَانَ، - بَصْرِيٌّ - عَنْ هُشَيْمٍ، قَالَ حَدَّثَنَا سَيَّارٌ، وَحُصَيْنٌ، وَمُغِيرَةُ، وَدَاوُدُ بْنُ أَبِي هِنْدٍ، وَإِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، وَذَكَرَ، آخَرِينَ عَنِ الشَّعْبِيِّ، قَالَ دَخَلْتُ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ فَسَأَلْتُهَا عَنْ قَضَاءِ، رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَيْهَا فَقَالَتْ طَلَّقَهَا زَوْجُهَا الْبَتَّةَ فَخَاصَمَتْهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي السُّكْنَى وَالنَّفَقَةِ قَالَتْ فَلَمْ يَجْعَلْ لِي سُكْنَى وَلاَ نَفَقَةً وَأَمَرَنِي أَنْ أَعْتَدَّ فِي بَيْتِ ابْنِ أُمِّ مَكْتُومٍ ‏.‏\hadithno{3548}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ash-Sha'bi said:"I came to Fatimah bint Qais and asked her about the ruling of the Messenger of Allah concerning her. She said that her husband divorced her irrevocably, and she referred her dispute with him, concerning accommodation and maintenance, to the Messenger of Allah. She said: 'He did not give me (the right to) accommodation and maintenance, and he told me to observe my 'Iddah in the house of Ibn Umm Maktum}}
\hadithdefcmd{nasai}{3549}{أَخْبَرَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ الصَّاغَانِيُّ، قَالَ حَدَّثَنَا أَبُو الْجَوَّابِ، قَالَ حَدَّثَنَا عَمَّارٌ، - هُوَ ابْنُ رُزَيْقٍ - عَنْ أَبِي إِسْحَاقَ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، قَالَتْ طَلَّقَنِي زَوْجِي فَأَرَدْتُ النُّقْلَةَ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْتَقِلِي إِلَى بَيْتِ ابْنِ عَمِّكِ عَمْرِو ابْنِ أُمِّ مَكْتُومٍ فَاعْتَدِّي فِيهِ ‏"‏ ‏.‏ فَحَصَبَهُ الأَسْوَدُ وَقَالَ وَيْلَكَ لِمَ تُفْتِي بِمِثْلِ هَذَا ‏.‏ قَالَ عُمَرُ إِنْ جِئْتِ بِشَاهِدَيْنِ يَشْهَدَانِ أَنَّهُمَا سَمِعَاهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِلاَّ لَمْ نَتْرُكْ كِتَابَ اللَّهِ لِقَوْلِ امْرَأَةٍ ‏\{‏ لاَ تُخْرِجُوهُنَّ مِنْ بُيُوتِهِنَّ وَلاَ يَخْرُجْنَ إِلاَّ أَنْ يَأْتِينَ بِفَاحِشَةٍ مُبَيِّنَةٍ ‏\}‏ ‏.‏\hadithno{3549}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Fatimah bint Qais said:"My husband divorced me and I wanted to move, so I went to the Messenger of Allah and he said: 'Move to the house of your paternal cousin 'Amr bin Umm Maktum, and observe your 'Iddah there.'" Al-Aswad hit him (Ash-Sha'bi) with a pebble and said: "Woe be to you! Why do you issue such a Fatwa? 'Umar said: 'If you bring two witnesses who will testify that they heard that from the Messenger of Allah (we will believe you), otherwise, we will not leave the Book of Allah for the word of a woman.' 'And turn them not out of their (husband's) homes nor shall they (themselves) leave, except in case they are guilty of some open Fahishah}}
\hadithdefcmd{nasai}{3550}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ طُلِّقَتْ خَالَتُهُ فَأَرَادَتْ أَنْ تَخْرُجَ إِلَى نَخْلٍ لَهَا فَلَقِيَتْ رَجُلاً فَنَهَاهَا فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ اخْرُجِي فَجُدِّي نَخْلَكِ لَعَلَّكِ أَنْ تَصَدَّقِي وَتَفْعَلِي مَعْرُوفًا ‏"‏ ‏.‏\hadithno{3550}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that his maternal aunt was divorced, and she wanted to go out to some date palms of hers, but she met a man who told her not to do that. She went to the Messenger of Allah and he said:"Go out and take the harvest of your date palms, for perhaps you will give Zakah or do some good (give voluntary charity)}}
\hadithdefcmd{nasai}{3551}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ أَبِي الْجَهْمِ، قَالَ دَخَلْتُ أَنَا وَأَبُو سَلَمَةَ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ قَالَتْ طَلَّقَنِي زَوْجِي فَلَمْ يَجْعَلْ لِي سُكْنَى وَلاَ نَفَقَةً - قَالَتْ - فَوَضَعَ لِي عَشْرَةَ أَقْفِزَةٍ عِنْدَ ابْنِ عَمٍّ لَهُ خَمْسَةُ شَعِيرٍ وَخَمْسَةُ تَمْرٍ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ ذَلِكَ فَقَالَ ‏ "‏ صَدَقَ ‏"‏ ‏.‏ وَأَمَرَنِي أَنْ أَعْتَدَّ فِي بَيْتِ فُلاَنٍ وَكَانَ زَوْجُهَا طَلَّقَهَا طَلاَقًا بَائِنًا ‏.‏\hadithno{3551}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Bakr bin Hafs said:Abu Salamah and I entered upon Fatimah bint Qais, who said: "My husband divorced me and he did not give me any accommodation or maintenance." She said: "He left with me ten measures (Aqfizah) (of food) with a cousin of his: Five of barley and five of dates. I went to the Messenger of Allah and told him about that. He said: 'He has spoken the truth.' And he told me to observe my 'Iddah in the house of so-and-so." And her husband had divorced her irrevocably}}
\hadithdefcmd{nasai}{3552}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ شُعَيْبٍ، قَالَ قَالَ الزُّهْرِيُّ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ عُثْمَانَ، طَلَّقَ ابْنَةَ سَعِيدِ بْنِ زَيْدٍ - وَأُمُّهَا حَمْنَةُ بِنْتُ قَيْسٍ - الْبَتَّةَ فَأَمَرَتْهَا خَالَتُهَا فَاطِمَةُ بِنْتُ قَيْسٍ بِالاِنْتِقَالِ مِنْ بَيْتِ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَسَمِعَ بِذَلِكَ، مَرْوَانُ فَأَرْسَلَ إِلَيْهَا فَأَمَرَهَا أَنْ تَرْجِعَ إِلَى مَسْكَنِهَا حَتَّى تَنْقَضِيَ عِدَّتُهَا فَأَرْسَلَتْ إِلَيْهِ تُخْبِرُهُ أَنَّ خَالَتَهَا فَاطِمَةَ أَفْتَتْهَا بِذَلِكَ وَأَخْبَرَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفْتَاهَا بِالاِنْتِقَالِ حِينَ طَلَّقَهَا أَبُو عَمْرِو بْنُ حَفْصٍ الْمَخْزُومِيُّ فَأَرْسَلَ مَرْوَانُ قَبِيصَةَ بْنَ ذُؤَيْبٍ إِلَى فَاطِمَةَ فَسَأَلَهَا عَنْ ذَلِكَ فَزَعَمَتْ أَنَّهَا كَانَتْ تَحْتَ أَبِي عَمْرٍو لَمَّا أَمَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيَّ بْنَ أَبِي طَالِبٍ عَلَى الْيَمَنِ خَرَجَ مَعَهُ فَأَرْسَلَ إِلَيْهَا بِتَطْلِيقَةٍ وَهِيَ بَقِيَّةُ طَلاَقِهَا فَأَمَرَ لَهَا الْحَارِثَ بْنَ هِشَامٍ وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ بِنَفَقَتِهَا فَأَرْسَلَتْ إِلَى الْحَارِثِ وَعَيَّاشٍ تَسْأَلُهُمَا النَّفَقَةَ الَّتِي أَمَرَ لَهَا بِهَا زَوْجُهَا فَقَالاَ وَاللَّهِ مَا لَهَا عَلَيْنَا نَفَقَةٌ إِلاَّ أَنْ تَكُونَ حَامِلاً وَمَا لَهَا أَنْ تَسْكُنَ فِي مَسْكَنِنَا إِلاَّ بِإِذْنِنَا ‏.‏ فَزَعَمَتْ فَاطِمَةُ أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ فَصَدَّقَهُمَا قَالَتْ فَقُلْتُ أَيْنَ أَنْتَقِلُ يَا رَسُولَ اللَّهِ فَقَالَ ‏ "‏ انْتَقِلِي عِنْدَ ابْنِ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏ وَهُوَ الأَعْمَى الَّذِي عَاتَبَهُ اللَّهُ عَزَّ وَجَلَّ فِي كِتَابِهِ فَانْتَقَلْتُ عِنْدَهُ فَكُنْتُ أَضَعُ ثِيَابِي عِنْدَهُ حَتَّى أَنْكَحَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم زَعَمَتْ أُسَامَةَ بْنَ زَيْدٍ ‏.‏\hadithno{3552}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ubaidullah bin 'Abdullah bin 'Utbah narrated that 'Abdullah bin 'Amr bin 'Uthman divorced the daughter of Sa'eed bin Zaid -whose mother was Hamnah bint Qais- irrevocably. Her maternal aunt Fatimah bint Qais told her to move from the house of 'Abdullah bin 'Amr. Marwan heard of that, so he sent word to her, telling her to go back to her home until her 'Iddah was over. She sent a word to him telling him that her maternal aunt Fatimah had issued a Fatwa to that effect, and she told her that the Messenger of Allah had issued a Fatwa to her, telling her to move when Abu 'Amr bin Hafs Al-Makhzumi divorced her. Marwan sent Qabisah bin Dhu'aib to Fatimah to ask her about that. She said that she had been married to Abu 'Amr when the Messenger of Allah appointed 'Ali bin Abi Talib as governor of Yemen, and he went out with him, then he sent word to her divorcing her, and that was the final divorce for her. He told her to ask Al-Harith bin Hisham and 'Ayyash for her provisions that her husband had allocated for her. They said:"By Allah, she is not entitled to any provision. So, she sent to Al-Harith bin Hisham and 'Ayyash asking them for the provisions from us unless she is pregnant, and she has no right to live in our house unless we permit her." Fatimah said that she went to the Messenger of Allah and told him about that and he said that they had told the truth. She said: "I said: 'Where shall I move to, O Messenger of Allah?' He said: 'Move to the house of Ibn Umm Maktum' -who was the blind man, concerning whom Allah rebuked him in His Book. I moved to his house, and I used to take off my outer garments." Then the Messenger of Allah married her to Usamah bin Zaid}}
\hadithdefcmd{nasai}{3553}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنِ الْمُنْذِرِ بْنِ الْمُغِيرَةِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ فَاطِمَةَ ابْنَةَ أَبِي حُبَيْشٍ، حَدَّثَتْهُ أَنَّهَا، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَشَكَتْ إِلَيْهِ الدَّمَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ فَانْظُرِي إِذَا أَتَاكِ قُرْؤُكِ فَلاَ تُصَلِّي فَإِذَا مَرَّ قُرْؤُكِ فَلْتَطْهُرِي - قَالَ - ثُمَّ صَلِّي مَا بَيْنَ الْقُرْءِ إِلَى الْقُرْءِ ‏"‏ ‏.‏\hadithno{3553}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Az-Zubair that Fatimah bint Abi Hubaish told him that she came to the Messenger of Allah and complained to him about (continual) bleeding. The Messenger of Allah said to her:"That is a vein. Look and when your period comes, do not pray, and when your period ends, then purify yourself and pray during the time between one period and the next}}
\hadithdefcmd{nasai}{3554}{حَدَّثَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا يَزِيدُ النَّحْوِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ ‏\{‏ مَا نَنْسَخْ مِنْ آيَةٍ أَوْ نُنْسِهَا نَأْتِ بِخَيْرٍ مِنْهَا أَوْ مِثْلِهَا ‏\}‏ وَقَالَ ‏\{‏ وَإِذَا بَدَّلْنَا آيَةً مَكَانَ آيَةٍ وَاللَّهُ أَعْلَمُ بِمَا يُنَزِّلُ ‏\}‏ الآيَةَ وَقَالَ ‏\{‏ يَمْحُو اللَّهُ مَا يَشَاءُ وَيُثْبِتُ وَعِنْدَهُ أُمُّ الْكِتَابِ ‏\}‏ فَأَوَّلُ مَا نُسِخَ مِنَ الْقُرْآنِ الْقِبْلَةُ وَقَالَ ‏\{‏ وَالْمُطَلَّقَاتُ يَتَرَبَّصْنَ بِأَنْفُسِهِنَّ ثَلاَثَةَ قُرُوءٍ وَلاَ يَحِلُّ لَهُنَّ أَنْ يَكْتُمْنَ مَا خَلَقَ اللَّهُ فِي أَرْحَامِهِنَّ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ إِنْ أَرَادُوا إِصْلاَحًا ‏\}‏ وَذَلِكَ بِأَنَّ الرَّجُلَ كَانَ إِذَا طَلَّقَ امْرَأَتَهُ فَهُوَ أَحَقُّ بِرَجْعَتِهَا وَإِنْ طَلَّقَهَا ثَلاَثًا فَنَسَخَ ذَلِكَ وَقَالَ ‏\{‏ الطَّلاَقُ مَرَّتَانِ فَإِمْسَاكٌ بِمَعْرُوفٍ أَوْ تَسْرِيحٌ بِإِحْسَانٍ ‏\}‏ ‏.‏\hadithno{3554}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas, regarding Allah's saying:"Whatever a Verse do We abrogate or cause to be forgotten, We bring a better one or similar to it." and "And when We change a Verse in place of another -and Allah knows best what He sends down" (Al-Nahl 16:101) and "Allah blots out what He wills and confirms (what He wills). And with Him is the Mother of the Book." The first thing that was abrogated in the Qur'an was the Qiblah. And He said: "And divorced women shall wait (as regards their marriage) for three menstrual periods, and it is not lawful for them to conceal what Allah has created in their wombs, if they believe in Allah and the Last Day." "And their husbands have better right to take them back in that period, if they wish for reconciliation." -that is because when a man divorced his wife, he had more right to take her back, even if he had divorced her three times. Then (Allah) abrogated that and said: "The divorce is twice, after that, either you retain her on reasonable terms or release her with kindness}}
\hadithdefcmd{nasai}{3555}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ يُونُسَ بْنَ جُبَيْرٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، قَالَ طَلَّقْتُ امْرَأَتِي وَهِيَ حَائِضٌ فَأَتَى النَّبِيَّ صلى الله عليه وسلم عُمَرُ فَذَكَرَ لَهُ ذَلِكَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مُرْهُ أَنْ يُرَاجِعَهَا فَإِذَا طَهُرَتْ - يَعْنِي - فَإِنْ شَاءَ فَلْيُطَلِّقْهَا ‏"‏ ‏.‏ قُلْتُ لاِبْنِ عُمَرَ فَاحْتَسَبْتَ مِنْهَا فَقَالَ مَا يَمْنَعُهَا أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ ‏.‏\hadithno{3555}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn 'Umar said:"I divorced my wife when she was menstruating. 'Umar went to the Prophet and told him about that. The Prophet said: 'Tell him to take her back, then when she becomes pure, if he wants to, let him divorce her.'" I said to Ibn 'Umar: "Did that count as one divorce?" He said: "Why not? What do you think if some becomes helpless and behaves foolishly}}
\hadithdefcmd{nasai}{3556}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنِ ابْنِ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، وَيَحْيَى بْنِ سَعِيدٍ، وَعُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ح وَأَخْبَرَنَا زُهَيْرٌ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالُوا إِنَّ ابْنَ عُمَرَ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَذَكَرَ عُمَرُ رضى الله عنه لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ مُرْهُ فَلْيُرَاجِعْهَا حَتَّى تَحِيضَ حَيْضَةً أُخْرَى فَإِذَا طَهُرَتْ فَإِنْ شَاءَ طَلَّقَهَا وَإِنْ شَاءَ أَمْسَكَهَا فَإِنَّهُ الطَّلاَقُ الَّذِي أَمَرَ اللَّهُ عَزَّ وَجَلَّ بِهِ ‏"‏ ‏.‏ قَالَ تَعَالَى ‏\{‏ فَطَلِّقُوهُنَّ لِعِدَّتِهِنَّ ‏\}‏ ‏.‏\hadithno{3556}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that he divorced his wife when she was menstruating. 'Umar, may Allah be pleased with him, mentioned that to the Prophet and he said:"Tell him to take her back until she menstruates again, then when she becomes pure, if he wants he may divorce her and if he wants he may keep her. This is the divorce that Allah has enjoined. Allah, the Mighty and Sublime, says: 'The divorce is twice, after that, either you retain her on reasonable terms or release her with kindness}}
\hadithdefcmd{nasai}{3557}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ إِذَا سُئِلَ عَنِ الرَّجُلِ، طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَيَقُولُ أَمَّا إِنْ طَلَّقَهَا وَاحِدَةً أَوِ اثْنَتَيْنِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَهُ أَنْ يُرَاجِعَهَا ثُمَّ يُمْسِكَهَا حَتَّى تَحِيضَ حَيْضَةً أُخْرَى ثُمَّ تَطْهُرَ ثُمَّ يُطَلِّقَهَا قَبْلَ أَنْ يَمَسَّهَا وَأَمَّا إِنْ طَلَّقَهَا ثَلاَثًا فَقَدْ عَصَيْتَ اللَّهَ فِيمَا أَمَرَكَ بِهِ مِنْ طَلاَقِ امْرَأَتِكَ وَبَانَتْ مِنْكَ امْرَأَتُكَ ‏.‏\hadithno{3557}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{When Ibn 'Umar was asked about a man who divorced his wife when she was menstruating, he would say:"If it is the first or second divorce, the Messenger of Allah would tell him to take her back and keep her until she has menstruated again and purified herself, then divorce her before having intercourse with her. But if it was three simultaneous divorces, then you have disobeyed Allah with regard to the way in which divorce should be conducted and your wife has become irrevocably divorced}}
\hadithdefcmd{nasai}{3558}{أَخْبَرَنَا يُوسُفُ بْنُ عِيسَى، - مَرْوَزِيٌّ - قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا حَنْظَلَةُ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَاجَعَهَا ‏.‏\hadithno{3558}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that he divorced his wife when she was menstruating, and the Messenger of Allah told him to take her back}}
\hadithdefcmd{nasai}{3559}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِيهِ ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، يُسْأَلُ عَنْ رَجُلٍ، طَلَّقَ امْرَأَتَهُ حَائِضًا فَقَالَ أَتَعْرِفُ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ نَعَمْ ‏.‏ قَالَ فَإِنَّهُ طَلَّقَ امْرَأَتَهُ حَائِضًا فَأَتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ الْخَبَرَ فَأَمَرَهُ أَنْ يُرَاجِعَهَا حَتَّى تَطْهُرَ ‏.‏ وَلَمْ أَسْمَعْهُ يَزِيدُ عَلَى هَذَا ‏.‏\hadithno{3559}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Tawus narrated from his father that he heard 'Abdullah bin 'Umar being asked about a man who divorced his wife when she was menstruating. He said:"Do you know 'Abdullah bin 'Umar?" He said: "Yes." He said: "He divorced his wife when she was menstruating, and 'Umar went to the Prophet and told him about that. He ordered him to take her back until she became pure," and I did not hear him adding anything to that}}
\hadithdefcmd{nasai}{3560}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ آدَمَ، ح وَأَنْبَأَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سَهْلُ بْنُ مُحَمَّدٍ أَبُو سَعِيدٍ، قَالَ نُبِّئْتُ عَنْ يَحْيَى بْنِ زَكَرِيَّا، عَنْ صَالِحِ بْنِ صَالِحٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم - وَقَالَ عَمْرٌو إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم - كَانَ طَلَّقَ حَفْصَةَ ثُمَّ رَاجَعَهَا ‏.‏ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{3560}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Umar that the Prophet -'Amr (one of the narrators) said:"The Messenger of Allah- had divorced Hafsah, then he took her back." And Allah knows best}}
