% Auto-generated chapter 13 for nasai
% Hadiths in this chapter: 188

\hadithdefcmd{nasai}{1179}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصَمِّ، قَالَ سُئِلَ أَنَسُ بْنُ مَالِكٍ عَنِ التَّكْبِيرِ، فِي الصَّلاَةِ فَقَالَ يُكَبِّرُ إِذَا رَكَعَ وَإِذَا سَجَدَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ السُّجُودِ وَإِذَا قَامَ مِنَ الرَّكْعَتَيْنِ ‏.‏ فَقَالَ حُطَيْمٌ عَمَّنْ تَحْفَظُ هَذَا فَقَالَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ - رضى الله عنهما - ثُمَّ سَكَتَ ‏.‏ فَقَالَ لَهُ حُطَيْمٌ وَعُثْمَانُ قَالَ وَعُثْمَانُ ‏.‏\hadithno{1179}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdur-Rahman bin Al-Asamm said:"Anas bin Malik was asked about the takbir in the prayer. He said: "The takbir should be said when bowing, when prostrating, when raising one's head from prostration and when standing up following the first two rak'ahs.' Hutaim said: 'From whom did you learn this?' He said: 'From the Prophet (ﷺ), Abu Bakr and 'Umar, may Allah (SWT) be pleased with them.' Then he fell silent and Hutaim said to him: 'And 'Uthman?' He said: 'And 'Uthman}}
\hadithdefcmd{nasai}{1180}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ، قَالَ صَلَّى عَلِيُّ بْنُ أَبِي طَالِبٍ فَكَانَ يُكَبِّرُ فِي كُلِّ خَفْضٍ وَرَفْعٍ يُتِمُّ التَّكْبِيرَ ‏.‏ فَقَالَ عِمْرَانُ بْنُ حُصَيْنٍ لَقَدْ ذَكَّرَنِي هَذَا صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1180}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mutarrif bin 'Abdullah said:"Ali bin Abi Talib prayed, and he said the takbir every time he went down and came up, in all movements of the prayer. 'Imran bin Husain said: 'This reminds me of the prayer of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{1181}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ سَمِعْتُهُ يُحَدِّثُ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَامَ مِنَ السَّجْدَتَيْنِ كَبَّرَ وَرَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ كَمَا صَنَعَ حِينَ افْتَتَحَ الصَّلاَةَ ‏.‏\hadithno{1181}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Humaid As-Sa'idi that:When the Prophet (ﷺ) stood up following two prostrations, he would say the takbir and raise his hands until they were level with his shoulders, as he had done at the beginning of the prayer}}
\hadithdefcmd{nasai}{1182}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ، - وَهُوَ ابْنُ عُمَرَ - عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَرْفَعُ يَدَيْهِ إِذَا دَخَلَ فِي الصَّلاَةِ وَإِذَا أَرَادَ أَنْ يَرْكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَإِذَا قَامَ مِنَ الرَّكْعَتَيْنِ يَرْفَعُ يَدَيْهِ كَذَلِكَ حَذْوَ الْمَنْكِبَيْنِ ‏.‏\hadithno{1182}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that :The Prophet (ﷺ) used to raise his hands when he began to pray, when he wanted to bow, when he raised his head from bowing, and when he stood up after the first two rak'ahs, he would raise his hands likewise, level with his shoulders}}
\hadithdefcmd{nasai}{1183}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، - وَهُوَ ابْنُ عُمَرَ - عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ انْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصْلِحُ بَيْنَ بَنِي عَمْرِو بْنِ عَوْفٍ فَحَضَرَتِ الصَّلاَةُ فَجَاءَ الْمُؤَذِّنُ إِلَى أَبِي بَكْرٍ فَأَمَرَهُ أَنْ يَجْمَعَ النَّاسَ وَيَؤُمَّهُمْ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَرَقَ الصُّفُوفَ حَتَّى قَامَ فِي الصَّفِّ الْمُقَدَّمِ وَصَفَّحَ النَّاسُ بِأَبِي بَكْرٍ لِيُؤْذِنُوهُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ أَبُو بَكْرٍ لاَ يَلْتَفِتُ فِي الصَّلاَةِ فَلَمَّا أَكْثَرُوا عَلِمَ أَنَّهُ قَدْ نَابَهُمْ شَىْءٌ فِي صَلاَتِهِمْ فَالْتَفَتَ فَإِذَا هُوَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَوْمَأَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىْ كَمَا أَنْتَ فَرَفَعَ أَبُو بَكْرٍ يَدَيْهِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ رَجَعَ الْقَهْقَرَى وَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى فَلَمَّا انْصَرَفَ قَالَ لأَبِي بَكْرٍ ‏"‏ مَا مَنَعَكَ إِذْ أَوْمَأْتُ إِلَيْكَ أَنْ تُصَلِّيَ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ رضى الله عنه مَا كَانَ يَنْبَغِي لاِبْنِ أَبِي قُحَافَةَ أَنْ يَؤُمَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ ثُمَّ قَالَ لِلنَّاسِ ‏"‏ مَا بَالُكُمْ صَفَّحْتُمْ إِنَّمَا التَّصْفِيحُ لِلنِّسَاءِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِذَا نَابَكُمْ شَىْءٌ فِي صَلاَتِكُمْ فَسَبِّحُوا ‏"‏ ‏.‏\hadithno{1183}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sahl bin Sa'd said:"The Messenger of Allah (ﷺ) set out to bring about reconciliation among Banu 'Amr bin 'Awf. The time for prayer came, and the Mu'adhdhin went to Abu Bakr to tell him to gather the people and lead them in prayer. Then the Messenger of Allah (ﷺ) came and passed though the rows until he stood in the first row. The people started clapping to let Abu Bakr know that the Messenger of Allah (ﷺ) had come. Abu Bakr never used to turn around when he prayed, but when they clapped consistently he realized something must have happened while they were praying. So he turned around and saw the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) gestured to him to stay where he was. Abu Bakr raised his hands and praised and thanked Allah (SWT) for what the Messenger of Allah (ﷺ) had said. Then, he moved backwards, and the Messenger of Allah (ﷺ) went forward and prayed. When he finished, he said to Abu Bakr: 'What stopped you from continuing to pray when I gestured to you?' Abu Bakr, may Allah (SWT) be pleased with him, said: 'It was not appropriate for the son of Abu Quhafah to lead the Messenger of Allah (ﷺ) in prayer.' Then he said to the people: 'Why did you clap?' Clapping is for women.' Then he said: 'If you notice something when you are praying, say "SubhanAllah}}
\hadithdefcmd{nasai}{1184}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْثَرٌ، عَنِ الأَعْمَشِ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ رَافِعُو أَيْدِينَا فِي الصَّلاَةِ فَقَالَ ‏ "‏ مَا بَالُهُمْ رَافِعِينَ أَيْدِيَهُمْ فِي الصَّلاَةِ كَأَنَّهَا أَذْنَابُ الْخَيْلِ الشُّمُسِ اسْكُنُوا فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1184}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"The Messenger of Allah (ﷺ) came out to us and we were raising our hands during the Salah. He said: 'Why are you raising your hands while praying, like the tails of wild horses? Stay still when you are praying}}
\hadithdefcmd{nasai}{1185}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ مِسْعَرٍ، عَنْ عُبَيْدِ اللَّهِ ابْنِ الْقِبْطِيَّةِ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كُنَّا نُصَلِّي خَلْفَ النَّبِيِّ صلى الله عليه وسلم فَنُسَلِّمُ بِأَيْدِينَا فَقَالَ ‏ "‏ مَا بَالُ هَؤُلاَءِ يُسَلِّمُونَ بِأَيْدِيهِمْ كَأَنَّهَا أَذْنَابُ خَيْلٍ شُمْسٍ أَمَا يَكْفِي أَحَدَهُمْ أَنْ يَضَعَ يَدَهُ عَلَى فَخِذِهِ ثُمَّ يَقُولَ السَّلاَمُ عَلَيْكُمُ السَّلاَمُ عَلَيْكُمْ ‏"‏ ‏.‏\hadithno{1185}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"We used to pray behind the Messenger of Allah (ﷺ) and we would greet (others) with our hands. He said: 'What is the matter with those who greet (others) with their hands as if they were tails of wild horses? It is sufficient for any one of you to put his hand on his thigh and say: "As-salamu 'alaikum, as-salamu 'alaikum}}
\hadithdefcmd{nasai}{1186}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ نَابِلٍ، صَاحِبِ الْعَبَاءِ عَنِ ابْنِ عُمَرَ، عَنْ صُهَيْبٍ، صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ مَرَرْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُصَلِّي فَسَلَّمْتُ عَلَيْهِ فَرَدَّ عَلَىَّ إِشَارَةً وَلاَ أَعْلَمُ إِلاَّ أَنَّهُ قَالَ بِإِصْبَعِهِ ‏.‏\hadithno{1186}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Suhaib, the Companion of the Messenger of Allah (ﷺ) said:"I passed by the Messenger of Allah (ﷺ) when he was praying, and greeted him with Salam. He returned my greeting with a gesture, or maybe it was just with his finger}}
\hadithdefcmd{nasai}{1187}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الْمَكِّيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، قَالَ قَالَ ابْنُ عُمَرَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم مَسْجِدَ قُبَاءَ لِيُصَلِّيَ فِيهِ فَدَخَلَ عَلَيْهِ رِجَالٌ يُسَلِّمُونَ عَلَيْهِ فَسَأَلْتُ صُهَيْبًا وَكَانَ مَعَهُ كَيْفَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصْنَعُ إِذَا سُلِّمَ عَلَيْهِ قَالَ كَانَ يُشِيرُ بِيَدِهِ ‏.‏\hadithno{1187}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Zaid bin Aslam said:"Ibn 'Umar said: The Prophet (ﷺ) entered the Masjid of Quba' to pray there, then some men came in and greeted him with Salam. I asked Suhaib, who was with him: 'What did the Messenger of Allah (ﷺ) do when he was greeted?' He said: 'He used to gesture with his hand}}
\hadithdefcmd{nasai}{1188}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا وَهْبٌ، - يَعْنِي ابْنَ جَرِيرٍ - قَالَ حَدَّثَنَا أَبِي، عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ عَطَاءٍ، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّهُ سَلَّمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُصَلِّي فَرَدَّ عَلَيْهِ ‏.‏\hadithno{1188}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ammar bin Yasir that:He greeted the Messenger of Allah (ﷺ) with the Salam when he was praying, and he returned the greeting}}
\hadithdefcmd{nasai}{1189}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم لِحَاجَةٍ ثُمَّ أَدْرَكْتُهُ وَهُوَ يُصَلِّي فَسَلَّمْتُ عَلَيْهِ فَأَشَارَ إِلَىَّ فَلَمَّا فَرَغَ دَعَانِي فَقَالَ ‏ "‏ إِنَّكَ سَلَّمْتَ عَلَىَّ آنِفًا وَأَنَا أُصَلِّي ‏"‏ ‏.‏ وَإِنَّمَا هُوَ مُوَجَّهٌ يَوْمَئِذٍ إِلَى الْمَشْرِقِ\hadithno{1189}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) sent me on an errand then I came back to him while he was praying. I greeted him with the salam and he gestured to me. When he finished he called me and said: 'You greeted me with Salam just now and I was praying.' And he was facing toward the east that day}}
\hadithdefcmd{nasai}{1190}{أَخْبَرَنَا مُحَمَّدُ بْنُ هَاشِمٍ الْبَعْلَبَكِّيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبِ بْنِ شَابُورٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم فَأَتَيْتُهُ وَهُوَ يَسِيرُ مُشَرِّقًا أَوْ مُغَرِّبًا فَسَلَّمْتُ عَلَيْهِ فَأَشَارَ بِيَدِهِ ثُمَّ سَلَّمْتُ عَلَيْهِ فَأَشَارَ بِيَدِهِ فَانْصَرَفْتُ فَنَادَانِي ‏"‏ يَا جَابِرُ ‏"‏ ‏.‏ فَنَادَانِي النَّاسُ يَا جَابِرُ ‏.‏ فَأَتَيْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَلَّمْتُ عَلَيْكَ فَلَمْ تَرُدَّ عَلَىَّ ‏.‏ فَقَالَ ‏"‏ إِنِّي كُنْتُ أُصَلِّي ‏"‏ ‏.‏\hadithno{1190}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) sent me on an errand, then I came back to him while he was facing the east or the west. I greeted him with salam and he gestured to me. Then when he finished he called me and said: "O Jabir!" So I came and said: "O Messenger of Allah, I greeted you with Salam but you did not answer." He said: 'I was praying}}
\hadithdefcmd{nasai}{1191}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَالْحُسَيْنُ بْنُ حُرَيْثٍ، - وَاللَّفْظُ لَهُ - عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَامَ أَحَدُكُمْ فِي الصَّلاَةِ فَلاَ يَمْسَحِ الْحَصَى فَإِنَّ الرَّحْمَةَ تُوَاجِهُهُ ‏"‏ ‏.‏\hadithno{1191}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah (ﷺ) said: 'When any one of you stands in prayer, let him not smooth the pebbles, for he is facing Mercy}}
\hadithdefcmd{nasai}{1192}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي مُعَيْقِيبٌ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كُنْتَ لاَ بُدَّ فَاعِلاً فَمَرَّةً ‏"‏ ‏.‏\hadithno{1192}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Salamah bin 'Abdur-Rahman said:"Mu'aiqib told me that the Messenger of Allah (ﷺ) said: 'If you have to do that, then do it only once}}
\hadithdefcmd{nasai}{1193}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَشُعَيْبُ بْنُ يُوسُفَ، عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ الْقَطَّانُ - عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا بَالُ أَقْوَامٍ يَرْفَعُونَ أَبْصَارَهُمْ إِلَى السَّمَاءِ فِي صَلاَتِهِمْ ‏"‏ ‏.‏ فَاشْتَدَّ قَوْلُهُ فِي ذَلِكَ حَتَّى قَالَ ‏"‏ لَيَنْتَهُنَّ عَنْ ذَلِكَ أَوْ لَتُخْطَفَنَّ أَبْصَارُهُمْ ‏"‏ ‏.‏\hadithno{1193}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that:The Messenger of Allah (ﷺ) said: "What is the matter with people who lift their gaze to the sky when praying?" And he spoke sternly concerning that until he said: "They must stop that or they will certainly lose their eyesight}}
\hadithdefcmd{nasai}{1194}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم حَدَّثَهُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ فِي الصَّلاَةِ فَلاَ يَرْفَعْ بَصَرَهُ إِلَى السَّمَاءِ أَنْ يُلْتَمَعَ بَصَرُهُ ‏"‏ ‏.‏\hadithno{1194}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ubaidullah bin Abdullah that:A man from among the companions of the Prophet (ﷺ) told him that he heard the Messenger of Allah (ﷺ) say: 'If any one of you in praying, let him not lift his gaze to the sky, or his eyesight will be taken away}}
\hadithdefcmd{nasai}{1195}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُ أَبَا الأَحْوَصِ، يُحَدِّثُنَا فِي مَجْلِسِ سَعِيدِ بْنِ الْمُسَيَّبِ وَابْنُ الْمُسَيَّبِ جَالِسٌ أَنَّهُ سَمِعَ أَبَا ذَرٍّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ اللَّهُ عَزَّ وَجَلَّ مُقْبِلاً عَلَى الْعَبْدِ فِي صَلاَتِهِ مَا لَمْ يَلْتَفِتْ فَإِذَا صَرَفَ وَجْهَهُ انْصَرَفَ عَنْهُ ‏"‏ ‏.‏\hadithno{1195}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Az-Zuhri said:"I heard Abu Al-Ahwas saying to us in a gathering with Ibn Al-Musayyab when Ibn Al-Musayyab was sitting there, that he had heard Abu Dharr say: The Messenger of Allah (ﷺ) said: "Allah (SWT) continues to look upon His slave while he is praying, so long as he does not turn away. If he turns his face away, He turns away from him}}
\hadithdefcmd{nasai}{1196}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ الاِلْتِفَاتِ فِي الصَّلاَةِ فَقَالَ ‏ "‏ اخْتِلاَسٌ يَخْتَلِسُهُ الشَّيْطَانُ مِنَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1196}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah, may Allah (SWT) be pleased with her, said:"I asked the Messenger of Allah (ﷺ) about looking here and there during prayer. He said: 'That is something that the Shaitan snatches from one's prayer}}
\hadithdefcmd{nasai}{1197}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1197}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated from 'Aishah:A similar report was also narrated from 'Aishah, from the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{1198}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِي عَطِيَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1198}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated from 'Aishah:A similar report was also narrated from 'Aishah, from the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{1199}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ بْنِ هِلاَلٍ، قَالَ حَدَّثَنَا الْمُعَافَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا الْقَاسِمُ، - وَهُوَ ابْنُ مَعْنٍ - عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ أَبِي عَطِيَّةَ، قَالَ قَالَتْ عَائِشَةُ إِنَّ الاِلْتِفَاتَ فِي الصَّلاَةِ اخْتِلاَسٌ يَخْتَلِسُهُ الشَّيْطَانُ مِنَ الصَّلاَةِ ‏.‏\hadithno{1199}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu 'Atiyyah said:"Aishah said: 'Turning around during prayer is something that the Shaitan snatches from one's prayer}}
\hadithdefcmd{nasai}{1200}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ اشْتَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّيْنَا وَرَاءَهُ وَهُوَ قَاعِدٌ وَأَبُو بَكْرٍ يُكَبِّرُ يُسْمِعُ النَّاسَ تَكْبِيرَهُ فَالْتَفَتَ إِلَيْنَا فَرَآنَا قِيَامًا فَأَشَارَ إِلَيْنَا فَقَعَدْنَا فَصَلَّيْنَا بِصَلاَتِهِ قُعُودًا فَلَمَّا سَلَّمَ قَالَ ‏ "‏ إِنْ كُنْتُمْ آنِفًا تَفْعَلُونَ فِعْلَ فَارِسَ وَالرُّومِ يَقُومُونَ عَلَى مُلُوكِهِمْ وَهُمْ قُعُودٌ فَلاَ تَفْعَلُوا ائْتَمُّوا بِأَئِمَّتِكُمْ إِنْ صَلَّى قَائِمًا فَصَلُّوا قِيَامًا وَإِنْ صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا ‏"‏ ‏.‏\hadithno{1200}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) was ill, and we prayed behind him while he was sitting, and Abu Bakr repeated his takbirs so that the people could hear them. He turned to us and saw us standing, so he gestured to us to sit down. So we prayed behind him sitting. When he said the salam he said: 'Just now you were doing what the Persians and Romans do for their kings when they are sitting. Do not do that. Follow your Imams: If they pray standing then pray standing, and if they pray sitting then pray sitting}}
\hadithdefcmd{nasai}{1201}{أَخْبَرَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَلْتَفِتُ فِي صَلاَتِهِ يَمِينًا وَشِمَالاً وَلاَ يَلْوِي عُنُقَهُ خَلْفَ ظَهْرِهِ ‏.‏\hadithno{1201}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) used to turn to his right and left when praying, but he did not twist his neck to look behind him}}
\hadithdefcmd{nasai}{1202}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، وَيَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - عَنْ مَعْمَرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ ضَمْضَمِ بْنِ جَوْسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الأَسْوَدَيْنِ فِي الصَّلاَةِ ‏.‏\hadithno{1202}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) commanded us to kill the two black ones (snakes and scorpions) while praying}}
\hadithdefcmd{nasai}{1203}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ أَبُو دَاوُدَ، قَالَ حَدَّثَنَا هِشَامٌ، - وَهُوَ ابْنُ أَبِي عَبْدِ اللَّهِ - عَنْ مَعْمَرٍ، عَنْ يَحْيَى، عَنْ ضَمْضَمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الأَسْوَدَيْنِ فِي الصَّلاَةِ ‏.‏\hadithno{1203}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) enjoined killing the two black ones (snakes and scorpions) while praying}}
\hadithdefcmd{nasai}{1204}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي وَهُوَ حَامِلٌ أُمَامَةَ فَإِذَا سَجَدَ وَضَعَهَا وَإِذَا قَامَ رَفَعَهَا ‏.‏\hadithno{1204}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Qatadah that:The Messenger of Allah (ﷺ) used to pray carrying Umamah. When he prostrated he put her down and when he stood up he picked her up again}}
\hadithdefcmd{nasai}{1205}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُثْمَانَ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ، عَنْ أَبِي قَتَادَةَ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَؤُمُّ النَّاسَ وَهُوَ حَامِلٌ أُمَامَةَ بِنْتَ أَبِي الْعَاصِ عَلَى عَاتِقِهِ فَإِذَا رَكَعَ وَضَعَهَا فَإِذَا فَرَغَ مِنْ سُجُودِهِ أَعَادَهَا ‏.‏\hadithno{1205}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Qatadah said:"I saw the Messenger of Allah (ﷺ) leading the people in prayer, carrying Umamah bint Abi Al-'As on his shoulder. When he bowed he put her down and when he finished prostrating he picked her up again}}
\hadithdefcmd{nasai}{1206}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ وَرْدَانَ، قَالَ حَدَّثَنَا بُرْدُ بْنُ سِنَانَ أَبُو الْعَلاَءِ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتِ اسْتَفْتَحْتُ الْبَابَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي تَطَوُّعًا وَالْبَابُ عَلَى الْقِبْلَةِ فَمَشَى عَنْ يَمِينِهِ أَوْ عَنْ يَسَارِهِ فَفَتَحَ الْبَابَ ثُمَّ رَجَعَ إِلَى مُصَلاَّهُ ‏.‏\hadithno{1206}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah, may Allah (SWT) be pleased with her, said:"I knocked at the door when the Messenger of Allah (ﷺ) was offering a voluntary prayer. The door was in the direction of the Qiblah so he took a few steps to his right or left and opened the door, then he went back to where he was praying}}
\hadithdefcmd{nasai}{1207}{أَخْبَرَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏ ‏.‏ زَادَ ابْنُ الْمُثَنَّى ‏"‏ فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1207}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet (ﷺ) said: "The Tasbih is for men, and clapping is for women." Ibn Al-Muthanna added: "During the prayer}}
\hadithdefcmd{nasai}{1208}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{1208}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sa'eed bin Al-Musayyab and Abu Salamah bin 'Abdur-Rahman said that:They heard Abu Hurairah say: "The Messenger of Allah (ﷺ) said: 'The Tasbih is for men and clapping is for women}}
\hadithdefcmd{nasai}{1209}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْفُضَيْلُ بْنُ عِيَاضٍ، عَنِ الأَعْمَشِ، ح وَأَنْبَأَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{1209}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The tasbih is for men and clapping is for women}}
\hadithdefcmd{nasai}{1210}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَوْفٍ، قَالَ حَدَّثَنِي مُحَمَّدٌ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{1210}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet (ﷺ) said: "The tasbih is for men and clapping is for women}}
\hadithdefcmd{nasai}{1211}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الْمُغِيرَةِ، عَنِ الْحَارِثِ الْعُكْلِيِّ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُجَىٍّ، عَنْ عَلِيٍّ، قَالَ كَانَ لِي مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَاعَةٌ آتِيهِ فِيهَا فَإِذَا أَتَيْتُهُ اسْتَأْذَنْتُ إِنْ وَجَدْتُهُ يُصَلِّي فَتَنَحْنَحَ دَخَلْتُ وَإِنْ وَجَدْتُهُ فَارِغًا أَذِنَ لِي ‏.‏\hadithno{1211}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"I had certain times when I used to come to the Messenger of Allah (ﷺ). When I came to him I would ask for permission to enter. If I found him praying he would clear his throat and I would enter, and if I found him free he would give me permission (to enter)}}
\hadithdefcmd{nasai}{1212}{أَخْبَرَنِي مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا ابْنُ عَيَّاشٍ، عَنْ مُغِيرَةَ، عَنِ الْحَارِثِ الْعُكْلِيِّ، عَنِ ابْنِ نُجَىٍّ، قَالَ قَالَ عَلِيٌّ كَانَ لِي مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَدْخَلاَنِ مَدْخَلٌ بِاللَّيْلِ وَمَدْخَلٌ بِالنَّهَارِ فَكُنْتُ إِذَا دَخَلْتُ بِاللَّيْلِ تَنَحْنَحَ لِي ‏.‏\hadithno{1212}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"I had two times when I would enter upon the Messenger of Allah (ﷺ), one at night and one during the day. When I entered at night he would clear his throat (to tell me to come in)}}
\hadithdefcmd{nasai}{1213}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنِي شُرَحْبِيلُ، - يَعْنِي ابْنَ مُدْرِكٍ - قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ نُجَىٍّ، عَنْ أَبِيهِ، قَالَ قَالَ لِي عَلِيٌّ كَانَتْ لِي مَنْزِلَةٌ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَمْ تَكُنْ لأَحَدٍ مِنَ الْخَلاَئِقِ فَكُنْتُ آتِيهِ كُلَّ سَحَرٍ فَأَقُولُ السَّلاَمُ عَلَيْكَ يَا نَبِيَّ اللَّهِ فَإِنْ تَنَحْنَحَ انْصَرَفْتُ إِلَى أَهْلِي وَإِلاَّ دَخَلْتُ عَلَيْهِ ‏.‏\hadithno{1213}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Nujayy narrated that his father said:"Ali said to me: 'I was so close to the Messenger of Allah (ﷺ), closer than anyone else. I used to come to him at the end of every night, before dawn, and say: "As-salamu 'alayka ya Nabiyy Allah (Peace be upon you, O Prophet of Allah)." If he cleared his throat I would go back to my family, otherwise I would enter upon him}}
\hadithdefcmd{nasai}{1214}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ مُطَرِّفٍ، عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يُصَلِّي وَلِجَوْفِهِ أَزِيزٌ كَأَزِيزِ الْمِرْجَلِ يَعْنِي يَبْكِي ‏.‏\hadithno{1214}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Mutarrif that his father said:"I came to the Prophet (ﷺ) when he was praying, and there was a sound coming from his chest like the sound of water boiling," meaning, he was weeping}}
\hadithdefcmd{nasai}{1215}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ وَهْبٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، قَالَ حَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فَسَمِعْنَاهُ يَقُولُ ‏"‏ أَعُوذُ بِاللَّهِ مِنْكَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلْعَنُكَ بِلَعْنَةِ اللَّهِ ‏"‏ ‏.‏ ثَلاَثًا وَبَسَطَ يَدَهُ كَأَنَّهُ يَتَنَاوَلُ شَيْئًا فَلَمَّا فَرَغَ مِنَ الصَّلاَةِ قُلْنَا يَا رَسُولَ اللَّهِ قَدْ سَمِعْنَاكَ تَقُولُ فِي الصَّلاَةِ شَيْئًا لَمْ نَسْمَعْكَ تَقُولُهُ قَبْلَ ذَلِكَ وَرَأَيْنَاكَ بَسَطْتَ يَدَكَ ‏.‏ قَالَ ‏"‏ إِنَّ عَدُوَّ اللَّهِ إِبْلِيسَ جَاءَ بِشِهَابٍ مِنْ نَارٍ لِيَجْعَلَهُ فِي وَجْهِي فَقُلْتُ أَعُوذُ بِاللَّهِ مِنْكَ ثَلاَثَ مَرَّاتٍ ثُمَّ قُلْتُ أَلْعَنُكَ بِلَعْنَةِ اللَّهِ فَلَمْ يَسْتَأْخِرْ ثَلاَثَ مَرَّاتٍ ثُمَّ أَرَدْتُ أَنْ آخُذَهُ وَاللَّهِ لَوْلاَ دَعْوَةُ أَخِينَا سُلَيْمَانَ لأَصْبَحَ مُوثَقًا بِهَا يَلْعَبُ بِهِ وِلْدَانُ أَهْلِ الْمَدِينَةِ ‏"‏ ‏.‏\hadithno{1215}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Ad-Darda' said:"The Messenger of Allah (ﷺ) stood praying, and we heard him say: 'I seek refuge with Allah from you.' Then he said: 'I curse you with the curse of Allah (SWT),' three times and stretched out his hand as if to take something. When he finished praying we said: 'O Messenger of Allah, we heard you say something in your prayer that we have never heard you say before, and we saw you stretch out your hand.' He said: 'The enemy of Allah (SWT), Iblis, came with a brand of fire to throw it in my face, so I said: I seek refuge with Allah from you three times, then I wanted to take hold of him. By Allah (SWT), were it not for the prayer of our brother Sulaiman, he would have been tied up this morning for the children of Al-Madinah to play with him}}
\hadithdefcmd{nasai}{1216}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الصَّلاَةِ وَقُمْنَا مَعَهُ فَقَالَ أَعْرَابِيٌّ وَهُوَ فِي الصَّلاَةِ اللَّهُمَّ ارْحَمْنِي وَمُحَمَّدًا وَلاَ تَرْحَمْ مَعَنَا أَحَدًا ‏.‏ فَلَمَّا سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لِلأَعْرَابِيِّ ‏ "‏ لَقَدْ تَحَجَّرْتَ وَاسِعًا ‏"‏ ‏.‏ يُرِيدُ رَحْمَةَ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{1216}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Salamah that :Abu Hurairah said: "The Messenger of Allah (ﷺ) stood up to pray and we stood up with him. A Bedouin said- while he was praying- 'O Allah, have mercy on me and Muhammad and do not have mercy on anyone else.' When the Messenger of Allah (ﷺ) said the Salam, he said to the Bedouin: 'You have limited something vast," meaning the mercy of Allah (SWT)}}
\hadithdefcmd{nasai}{1217}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الزُّهْرِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ أَحْفَظُهُ مِنَ الزُّهْرِيِّ قَالَ أَخْبَرَنِي سَعِيدٌ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ أَعْرَابِيًّا، دَخَلَ الْمَسْجِدَ فَصَلَّى رَكْعَتَيْنِ ثُمَّ قَالَ اللَّهُمَّ ارْحَمْنِي وَمُحَمَّدًا وَلاَ تَرْحَمْ مَعَنَا أَحَدًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقَدْ تَحَجَّرْتَ وَاسِعًا ‏"‏ ‏.‏\hadithno{1217}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:A Bedouin entered the masjid and prayed two rak'ahs, then he said: "O Allah, have mercy on me and on Muhammad and do not have mercy on anyone else." The Messenger of Allah (ﷺ) said: "You have limited something vast}}
\hadithdefcmd{nasai}{1218}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ يَسَارٍ، عَنْ مُعَاوِيَةَ بْنِ الْحَكَمِ السُّلَمِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا حَدِيثُ عَهْدٍ بِجَاهِلِيَّةٍ فَجَاءَ اللَّهُ بِالإِسْلاَمِ وَإِنَّ رِجَالاً مِنَّا يَتَطَيَّرُونَ ‏.‏ قَالَ ‏"‏ ذَاكَ شَىْءٌ يَجِدُونَهُ فِي صُدُورِهِمْ فَلاَ يَصُدَّنَّهُمْ ‏"‏ ‏.‏ وَرِجَالٌ مِنَّا يَأْتُونَ الْكُهَّانَ ‏.‏ قَالَ ‏"‏ فَلاَ تَأْتُوهُمْ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ وَرِجَالٌ مِنَّا يَخُطُّونَ ‏.‏ قَالَ ‏"‏ كَانَ نَبِيٌّ مِنَ الأَنْبِيَاءِ يَخُطُّ فَمَنْ وَافَقَ خَطُّهُ فَذَاكَ ‏"‏ ‏.‏ قَالَ وَبَيْنَا أَنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الصَّلاَةِ إِذْ عَطَسَ رَجُلٌ مِنَ الْقَوْمِ فَقُلْتُ يَرْحَمُكَ اللَّهُ فَحَدَّقَنِي الْقَوْمُ بِأَبْصَارِهِمْ فَقُلْتُ وَاثُكْلَ أُمِّيَاهُ مَا لَكُمْ تَنْظُرُونَ إِلَىَّ قَالَ فَضَرَبَ الْقَوْمُ بِأَيْدِيهِمْ عَلَى أَفْخَاذِهِمْ فَلَمَّا رَأَيْتُهُمْ يُسَكِّتُونِي لَكِنِّي سَكَتُّ فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم دَعَانِي بِأَبِي وَأُمِّي هُوَ مَا ضَرَبَنِي وَلاَ كَهَرَنِي وَلاَ سَبَّنِي مَا رَأَيْتُ مُعَلِّمًا قَبْلَهُ وَلاَ بَعْدَهُ أَحْسَنَ تَعْلِيمًا مِنْهُ قَالَ ‏"‏ إِنَّ صَلاَتَنَا هَذِهِ لاَ يَصْلُحُ فِيهَا شَىْءٌ مِنْ كَلاَمِ النَّاسِ إِنَّمَا هُوَ التَّسْبِيحُ وَالتَّكْبِيرُ وَتِلاَوَةُ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ ثُمَّ اطَّلَعْتُ إِلَى غُنَيْمَةٍ لِي تَرْعَاهَا جَارِيَةٌ لِي فِي قِبَلِ أُحُدٍ وَالْجَوَّانِيَّةِ وَإِنِّي اطَّلَعْتُ فَوَجَدْتُ الذِّئْبَ قَدْ ذَهَبَ مِنْهَا بِشَاةٍ وَأَنَا رَجُلٌ مِنْ بَنِي آدَمَ آسَفُ كَمَا يَأْسَفُونَ فَصَكَكْتُهَا صَكَّةً ثُمَّ انْصَرَفْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَعَظَّمَ ذَلِكَ عَلَىَّ فَقُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ أَعْتِقُهَا قَالَ ‏"‏ ادْعُهَا ‏"‏ ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيْنَ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَتْ فِي السَّمَاءِ ‏.‏ قَالَ ‏"‏ فَمَنْ أَنَا ‏"‏ ‏.‏ قَالَتْ أَنْتَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ إِنَّهَا مُؤْمِنَةٌ فَاعْتِقْهَا ‏"‏ ‏.‏\hadithno{1218}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Mu'awiyah bin Al-Hakam As-Sulami said:"I said: 'O Messenger of Allah (ﷺ), we were recently in a state of ignorance, then Allah (SWT) brought Islam. Some men among us follow omens.' He said: 'That is something that they find in their own hearts; it should not deter them from going ahead.' I said: 'And some men among us go to fortune tellers.' He said: 'Do not go to them.' He said: 'Some men among us draw lines.' He said: 'One of the Prophets used to draw lines. So whoever is in accord with his drawing of lines, then so it is.'" He said: "While I was praying with the Messenger of Allah (ﷺ), a man sneezed and I said: 'Yarhamuk-Allah (May Allah have mercy on you).' The people glared at me and I said: 'May my mother be bereft of me, why are you looking at me?' The people struck their hands against their thighs, and when I saw that they were telling me to be quiet, I fell silent. When the Messenger of Allah (ﷺ) finished, he called me. May my father and mother be ransomed for him, he neither did hit me nor rebuke me nor revile me. I have never seen a better teacher than him, before or after. He said: 'This prayer of ours is not the place for ordinary human speech, rather it is glorification and magnification of Allah (SWT), and reciting Qur'an.' Then I went out to a flock of sheep of mine that was tended by a slave woman of mine beside Uhud and Al-Jawwaniyyah, and I found that the wolf had taken one of the sheep. I am a man from the sons of Adam and I get upset as they get upset. So I slapped her. Then I came to the Messenger of Allah (ﷺ) and told him what happened. He regarded that as a serious action on my part. I said: 'O Messenger of Allah (ﷺ), should I set her free?' He said: 'Call her.' The Messenger of Allah (ﷺ) said to her: 'Where is Allah (SWT), the Mighty and Sublime?' She said: 'Above the heavens.' He said: 'And who am I?' She said: 'The Messenger of Allah (ﷺ).' He said: 'She is a believer, set her free}}
\hadithdefcmd{nasai}{1219}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، قَالَ حَدَّثَنِي الْحَارِثُ بْنُ شُبَيْلٍ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ كَانَ الرَّجُلُ يُكَلِّمُ صَاحِبَهُ فِي الصَّلاَةِ بِالْحَاجَةِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ حَافِظُوا عَلَى الصَّلَوَاتِ وَالصَّلاَةِ الْوُسْطَى وَقُومُوا لِلَّهِ قَانِتِينَ ‏\}‏ فَأُمِرْنَا بِالسُّكُوتِ ‏.‏\hadithno{1219}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Zaid bin Arqam said:"We used to speak to each other during the prayer, saying whatever was necessary, at the time of the Messenger of Allah (ﷺ), until this verse was revealed: Guard strictly (five obligatory) As-Salawat (the prayers) especially the middle Salah (i.e. the best prayer- 'Asr). And stand before Allah with obedience (and do not speak to others during the Salah (prayers)), so we were commanded to be silent}}
\hadithdefcmd{nasai}{1220}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي غَنِيَّةَ، - وَاسْمُهُ يَحْيَى بْنُ عَبْدِ الْمَلِكِ - وَالْقَاسِمُ بْنُ يَزِيدَ الْجَرْمِيُّ عَنْ سُفْيَانَ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنْ كُلْثُومٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، - وَهَذَا حَدِيثُ الْقَاسِمِ - قَالَ كُنْتُ آتِي النَّبِيَّ صلى الله عليه وسلم وَهُوَ يُصَلِّي فَأُسَلِّمُ عَلَيْهِ فَيَرُدُّ عَلَىَّ فَأَتَيْتُهُ فَسَلَّمْتُ عَلَيْهِ وَهُوَ يُصَلِّي فَلَمْ يَرُدَّ عَلَىَّ فَلَمَّا سَلَّمَ أَشَارَ إِلَى الْقَوْمِ فَقَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ - يَعْنِي - أَحْدَثَ فِي الصَّلاَةِ أَنْ لاَ تَكَلَّمُوا إِلاَّ بِذِكْرِ اللَّهِ وَمَا يَنْبَغِي لَكُمْ وَأَنْ تَقُومُوا لِلَّهِ قَانِتِينَ ‏"‏ ‏.‏\hadithno{1220}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abdullah bin Mas'ud said:"I used to come to the Prophet (ﷺ) when he was praying, and I would greet him with Salam, he would return my greeting. Then I came to him when he was praying, and he did not return my greeting. When he said the Taslim, he pointed to the people and said: "Allah (SWT) has decreed that in the prayer you should not speak except to remember Allah (SWT), and it is not appropriate for you, and that you should stand before Allah (SWT) with obedience}}
\hadithdefcmd{nasai}{1221}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ كُنَّا نُسَلِّمُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَيَرُدُّ عَلَيْنَا السَّلاَمَ حَتَّى قَدِمْنَا مِنْ أَرْضِ الْحَبَشَةِ فَسَلَّمْتُ عَلَيْهِ فَلَمْ يَرُدَّ عَلَىَّ فَأَخَذَنِي مَا قَرُبَ وَمَا بَعُدَ فَجَلَسْتُ حَتَّى إِذَا قَضَى الصَّلاَةَ قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يُحْدِثُ مِنْ أَمْرِهِ مَا يَشَاءُ وَإِنَّهُ قَدْ أَحْدَثَ مِنْ أَمْرِهِ أَنْ لاَ يُتَكَلَّمَ فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1221}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn Mas'ud said:"We used to greet the Prophet (ﷺ) with salam and he would return our salam, until we came back from the land of Ethiopia. I greeted him with salam and he did not return my greeting,a nd I started to wonder why. So I sat down; and when he finished praying, he said: 'Allah (SWT) decrees what He wills, and He has decreed what we should not speak during the prayer}}
\hadithdefcmd{nasai}{1222}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ، قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ ثُمَّ قَامَ فَلَمْ يَجْلِسْ فَقَامَ النَّاسُ مَعَهُ فَلَمَّا قَضَى صَلاَتَهُ وَنَظَرْنَا تَسْلِيمَهُ كَبَّرَ فَسَجَدَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ قَبْلَ التَّسْلِيمِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1222}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abdullah bin Buhainah said:"The Messenger of Allah (ﷺ) led us in praying two rak'ahs, then he stood up and did not sit, and the people stood up with him. When he finished the prayer, and we were waiting for him to say the taslim, he said the takbir and prostrated twice while sitting, before the taslim. Then he said the taslim}}
\hadithdefcmd{nasai}{1223}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَامَ فِي الصَّلاَةِ وَعَلَيْهِ جُلُوسٌ فَسَجَدَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ قَبْلَ التَّسْلِيمِ ‏.‏\hadithno{1223}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin Buhainah that:The Messenger of Allah (ﷺ) stood up during the prayer when he should have sat, so he prostrated twice while sitting, before the taslim}}
\hadithdefcmd{nasai}{1224}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ قَالَ أَبُو هُرَيْرَةَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم إِحْدَى صَلاَتَىِ الْعَشِيِّ ‏.‏ قَالَ قَالَ أَبُو هُرَيْرَةَ وَلَكِنِّي نَسِيتُ - قَالَ - فَصَلَّى بِنَا رَكْعَتَيْنِ ثُمَّ سَلَّمَ فَانْطَلَقَ إِلَى خَشَبَةٍ مَعْرُوضَةٍ فِي الْمَسْجِدِ فَقَالَ بِيَدِهِ عَلَيْهَا كَأَنَّهُ غَضْبَانُ وَخَرَجَتِ السَّرَعَانُ مِنْ أَبْوَابِ الْمَسْجِدِ فَقَالُوا قُصِرَتِ الصَّلاَةُ وَفِي الْقَوْمِ أَبُو بَكْرٍ وَعُمَرُ - رضى الله عنهما - فَهَابَاهُ أَنْ يُكَلِّمَاهُ وَفِي الْقَوْمِ رَجُلٌ فِي يَدَيْهِ طُولٌ قَالَ كَانَ يُسَمَّى ذَا الْيَدَيْنِ فَقَالَ يَا رَسُولَ اللَّهِ أَنَسِيتَ أَمْ قُصِرَتِ الصَّلاَةُ قَالَ ‏"‏ لَمْ أَنْسَ وَلَمْ تُقْصَرِ الصَّلاَةُ ‏"‏ ‏.‏ قَالَ وَقَالَ ‏"‏ أَكَمَا قَالَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَجَاءَ فَصَلَّى الَّذِي كَانَ تَرَكَهُ ثُمَّ سَلَّمَ ثُمَّ كَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ثُمَّ رَفَعَ رَأْسَهُ وَكَبَّرَ ثُمَّ سَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ثُمَّ رَفَعَ رَأْسَهُ ثُمَّ كَبَّرَ ‏.‏\hadithno{1224}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Muhammad bin Sirin said:"Abu Hurairah said: 'The Prophet (ﷺ) led us in one of the nighttime prayers.'" He said: "Abu Hurairah said: 'But I forgot (which one).' He said: 'He led us in praying two rak'ahs, then he said the taslim and went to a piece of wood that was lying in the masjid and leaned his hand on it as if he was angry. Those who were in a hurry left the masjid, and said: "The prayer has been shortened." Among the people were Abu Bakr and 'Umar but they hesitated to ask him for they revere him. Also among the people was a man with long hands who was known as Dhul-Yadain. He said: O Messenger of Allah (ﷺ), did you forget or has the prayer been shortened? He said: I did not forget and the prayer has not been shortened. He said: Is it as Dhul-Yadain says? They said: yes. So he came and prayed what he had missed, then he said the salam, then he said the takbir and prostrated as usual or longer than that. Then he raised his head and said the takbir, and prostrated as usual or longer than that. Then he raised his head and said the takbir}}
\hadithdefcmd{nasai}{1225}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي أَيُّوبُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْصَرَفَ مِنَ اثْنَتَيْنِ فَقَالَ لَهُ ذُو الْيَدَيْنِ أَقُصِرَتِ الصَّلاَةُ أَمْ نَسِيتَ يَا رَسُولَ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالَ النَّاسُ نَعَمْ ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى اثْنَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ كَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ثُمَّ رَفَعَ رَأْسَهُ ثُمَّ سَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ثُمَّ رَفَعَ ‏.‏\hadithno{1225}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that :The Messenger of Allah (ﷺ) finished praying two rak'ahs,and Dhul-Yadain said to him: "Has the prayer been shortened or did you forget, O Messenger of Allah?" The Messenger of Allah (ﷺ) said: "Is Dhul-Yadain speaking the truth?" The people said: "Yes." So the Messenger of Allah (ﷺ) stood up and prayed two, then he said the takbir and prostrated as usual or longer than that. Then he raised his head, then he prostrated as usual or longer than that, then he sat up}}
\hadithdefcmd{nasai}{1226}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي سُفْيَانَ، مَوْلَى ابْنِ أَبِي أَحْمَدَ أَنَّهُ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْعَصْرِ فَسَلَّمَ فِي رَكْعَتَيْنِ فَقَامَ ذُو الْيَدَيْنِ فَقَالَ أَقُصِرَتِ الصَّلاَةُ يَا رَسُولَ اللَّهِ أَمْ نَسِيتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ ذَلِكَ لَمْ يَكُنْ ‏"‏ ‏.‏ فَقَالَ قَدْ كَانَ بَعْضُ ذَلِكَ يَا رَسُولَ اللَّهِ ‏.‏ فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النَّاسِ فَقَالَ ‏"‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالُوا نَعَمْ ‏.‏ فَأَتَمَّ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا بَقِيَ مِنَ الصَّلاَةِ ثُمَّ سَجَدَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ بَعْدَ التَّسْلِيمِ ‏.‏\hadithno{1226}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) led us in praying 'Asr, and he said the salam after two rak'ahs. Dhul-Yadain stood up and said: 'Has the prayer been shortened, O Messenger of Allah (ﷺ) or did you forget?' The Messenger of Allah (ﷺ) said: 'Neither.' He said: 'One of them happened, O Messenger of Allah (ﷺ).' The Messenger of Allah (ﷺ) turned to the people and said: 'Is Dhul-Yadain speaking the truth?' They said: 'Yes.' So the Messenger of Allah (ﷺ) completed what was left of the prayer, then he prostrated twice when he was sitting after the taslim}}
\hadithdefcmd{nasai}{1227}{أَخْبَرَنَا سُلَيْمَانُ بْنُ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، أَنَّهُ سَمِعَ أَبَا سَلَمَةَ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى صَلاَةَ الظُّهْرِ رَكْعَتَيْنِ ثُمَّ سَلَّمَ فَقَالُوا أَقُصِرَتِ الصَّلاَةُ فَقَامَ وَصَلَّى رَكْعَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ‏.‏\hadithno{1227}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) prayed Zuhr with two rak'ahs, then said the salam. They said: "Has the prayer been shortened?" So he stood up and prayed two rak'ahs, then he said the salam, then he prostrated twice}}
\hadithdefcmd{nasai}{1228}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى يَوْمًا فَسَلَّمَ فِي رَكْعَتَيْنِ ثُمَّ انْصَرَفَ فَأَدْرَكَهُ ذُو الشِّمَالَيْنِ فَقَالَ يَا رَسُولَ اللَّهِ أَنُقِصَتِ الصَّلاَةُ أَمْ نَسِيتَ فَقَالَ ‏"‏ لَمْ تُنْقَصِ الصَّلاَةُ وَلَمْ أَنْسَ ‏"‏ ‏.‏ قَالَ بَلَى وَالَّذِي بَعَثَكَ بِالْحَقِّ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَصَلَّى بِالنَّاسِ رَكْعَتَيْنِ ‏.‏\hadithno{1228}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) prayed one day and said the salam after two rak'ahs, then he left. Dhul-Shimalain caught up with him and said: "O Messenger of Alah, has the prayer been shortened or did you forget?" He said: "The prayer has not been shortened, and I did not forget." He said: "Yes, by the One Who sent you with the truth." The Messenger of Allah (ﷺ) said: 'Is Dhul-Yadain speaking the truth?" They said: 'Yes.' So he led the people in praying two rak'ahs}}
\hadithdefcmd{nasai}{1229}{أَخْبَرَنَا هَارُونُ بْنُ مُوسَى الْفَرْوِيُّ، قَالَ حَدَّثَنِي أَبُو ضَمْرَةَ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَسِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَلَّمَ فِي سَجْدَتَيْنِ ‏.‏ فَقَالَ لَهُ ذُو الشِّمَالَيْنِ أَقُصِرَتِ الصَّلاَةُ أَمْ نَسِيتَ يَا رَسُولَ اللَّهِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَتَمَّ الصَّلاَةَ ‏.‏\hadithno{1229}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) forgot and said the taslim after two rak'ahs. Dhul-Shimalain said to him: 'Has the prayer been shortened or did you forget, O Messenger of Allah (ﷺ)?' The Messenger of Allah (ﷺ) said: 'Is Dhul-Yadain speaking the truth?' They said: "Yes." So the Messenger of Allah (ﷺ) stood up and completed the prayer}}
\hadithdefcmd{nasai}{1230}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَأَبِي، بَكْرِ بْنِ سُلَيْمَانَ بْنِ أَبِي حَثْمَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ أَوِ الْعَصْرَ فَسَلَّمَ فِي رَكْعَتَيْنِ وَانْصَرَفَ ‏.‏ فَقَالَ لَهُ ذُو الشِّمَالَيْنِ بْنُ عَمْرٍو أَنُقِصَتِ الصَّلاَةُ أَمْ نَسِيتَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا يَقُولُ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالُوا صَدَقَ يَا نَبِيَّ اللَّهِ ‏.‏ فَأَتَمَّ بِهِمُ الرَّكْعَتَيْنِ اللَّتَيْنِ نَقَصَ ‏.‏\hadithno{1230}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) prayed Zuhr or 'Asr and said the taslim following two rak'ahs and left. Dhul-Shimalain bin 'Amr said to him: 'Has the prayer been shortened or did you forget?" The Prophet (ﷺ) said: 'What is Dhul-Yadain saying?' They said: 'He is speaking the truth, O Messenger of Allah (ﷺ).' So he led them in praying the two rak'ahs that he missed}}
\hadithdefcmd{nasai}{1231}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا بَكْرِ بْنَ سُلَيْمَانَ بْنِ أَبِي حَثْمَةَ، أَخْبَرَهُ أَنَّهُ، بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى رَكْعَتَيْنِ فَقَالَ لَهُ ذُو الشِّمَالَيْنِ نَحْوَهُ ‏.‏ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي هَذَا الْخَبَرَ سَعِيدُ بْنُ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ وَأَخْبَرَنِيهِ أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ وَأَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ وَعُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ ‏.‏\hadithno{1231}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Abu Bakr bin Sulaiman bin Abi Hathmah narrated that:It was conveyed to him that the Messenger of Allah (ﷺ) prayed two rak'ahs, and Dhul-Shimalain said something similar to him. (One of the narrators Ibn Shihab said: "Sa'eed bin Al-Musayyab informed me of this hadith from Abu Hurairah." He said: "And Abu Salamah bin 'Abdur Rahman, Abu Bakr bin 'Abdur Rahman, abu Bakr bin 'Abdur Rahman bin Al-Harith and 'Ubaidullah bin 'Abdullah informed me)}}
\hadithdefcmd{nasai}{1232}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ وَأَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ وَابْنِ أَبِي حَثْمَةَ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ لَمْ يَسْجُدْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ قَبْلَ السَّلاَمِ وَلاَ بَعْدَهُ ‏.‏\hadithno{1232}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:'The Messenger of Allah (ﷺ) did not prostrate that day either before the salam or after}}
\hadithdefcmd{nasai}{1233}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَجَدَ يَوْمَ ذِي الْيَدَيْنِ سَجْدَتَيْنِ بَعْدَ السَّلاَمِ ‏.‏\hadithno{1233}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) prostrated twice after the salam on the day of Dhul-Yadain}}
\hadithdefcmd{nasai}{1234}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ، قَالَ أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا عَمْرُو بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1234}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated from Abu Hurairah:A similar report was narrated from Abu Hurairah from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{1235}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ وَحَدَّثَنِي ابْنُ عَوْنٍ، وَخَالِدٌ الْحَذَّاءُ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَجَدَ فِي وَهْمِهِ بَعْدَ التَّسْلِيمِ ‏.‏\hadithno{1235}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that :The Prophet (ﷺ) prostrated after the salam when he was not sure}}
\hadithdefcmd{nasai}{1236}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ أَخْبَرَنِي أَشْعَثُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِهِمْ فَسَهَا فَسَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1236}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Imran bin Husain that:The Prophet (ﷺ) led them in prayer and forgot (how many rak'ahs he had prayed), then he prostrated twice, then he said the salam}}
\hadithdefcmd{nasai}{1237}{أَخْبَرَنَا أَبُو الأَشْعَثِ، عَنْ يَزِيدَ بْنِ زُرَيْعٍ، قَالَ حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَلاَثِ رَكَعَاتٍ مِنَ الْعَصْرِ فَدَخَلَ مَنْزِلَهُ فَقَامَ إِلَيْهِ رَجُلٌ يُقَالُ لَهُ الْخِرْبَاقُ فَقَالَ يَعْنِي نَقَصَتِ الصَّلاَةُ يَا رَسُولَ اللَّهِ فَخَرَجَ مُغْضَبًا يَجُرُّ رِدَاءَهُ فَقَالَ ‏ "‏ أَصَدَقَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَقَامَ فَصَلَّى تِلْكَ الرَّكْعَةَ ثُمَّ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَيْهَا ثُمَّ سَلَّمَ ‏.‏\hadithno{1237}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Imran bin Husain said:"The Messenger of Allah (ﷺ) said the salam after three rak'ahs of 'Asr, then he entered his house. A man called Al-Khibaq stood up and said: 'Has the prayer been shortened, O Messenger of Allah?' He came out angry, dragging his upper garment and said: 'Is he speaking the truth?' They said: 'Yes.' So he stood and prayed that rak'ah, then he said the salam, then prostrated twice, then he said the salam (again)}}
\hadithdefcmd{nasai}{1238}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَكَّ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيُلْغِ الشَّكَّ وَلْيَبْنِ عَلَى الْيَقِينِ فَإِذَا اسْتَيْقَنَ بِالتَّمَامِ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ قَاعِدٌ فَإِنْ كَانَ صَلَّى خَمْسًا شَفَعَتَا لَهُ صَلاَتَهُ وَإِنْ صَلَّى أَرْبَعًا كَانَتَا تَرْغِيمًا لِلشَّيْطَانِ ‏"‏ ‏.‏\hadithno{1238}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa'eed that:The Prophet (ﷺ) said: "If one of you is not sure about his prayer, let him forget about what he is unsure of and complete his prayer on the basis of what he is sure of. When he is sure that he has completed it, let him prostrate twice while he is sitting. Then if he has prayed five (rak'ahs), they (the two prostrations) will make his prayer even-numbered, and if he had prayed four, they will annoy and humiliate the shaitan}}
\hadithdefcmd{nasai}{1239}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، - وَهُوَ ابْنُ أَبِي سَلَمَةَ - عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا لَمْ يَدْرِ أَحَدُكُمْ صَلَّى ثَلاَثًا أَمْ أَرْبَعًا فَلْيُصَلِّ رَكْعَةً ثُمَّ يَسْجُدْ بَعْدَ ذَلِكَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ فَإِنْ كَانَ صَلَّى خَمْسًا شَفَعَتَا لَهُ صَلاَتَهُ وَإِنْ صَلَّى أَرْبَعًا كَانَتَا تَرْغِيمًا لِلشَّيْطَانِ ‏"‏ ‏.‏\hadithno{1239}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:The Prophet (ﷺ) said: "If one of you does not know whether he prayed three or four (rak'ahs), let him pray a rak'ah then prostrate twice after that when he is sitting. Then if he prayed five (rak'ahs), they (the two prostrations) will make his prayer even-numbered, and if he had prayed four, they will annoy and humiliate the shaitan}}
\hadithdefcmd{nasai}{1240}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا مُفَضَّلٌ، - وَهُوَ ابْنُ مُهَلْهَلٍ - عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، يَرْفَعُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَكَّ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيَتَحَرَّ الَّذِي يَرَى أَنَّهُ الصَّوَابُ فَيُتِمَّهُ ثُمَّ - يَعْنِي - يَسْجُدُ سَجْدَتَيْنِ ‏"‏ ‏.‏ وَلَمْ أَفْهَمْ بَعْضَ حُرُوفِهِ كَمَا أَرَدْتُ ‏.‏\hadithno{1240}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah and attributed to the Prophet (ﷺ):"If one of you is not sure about his prayer, let him estimate what he thinks is most likely to be correct and complete the prayer on that basis, then let him prostrate twice}}
\hadithdefcmd{nasai}{1241}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرَّمِيُّ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَكَّ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيَتَحَرَّ وَيَسْجُدْ سَجْدَتَيْنِ بَعْدَ مَا يَفْرُغُ ‏"‏ ‏.‏\hadithno{1241}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah (ﷺ) said: 'If one of you is not sure about his prayer, let him estimate and prostrate twice after he has finished}}
\hadithdefcmd{nasai}{1242}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مِسْعَرٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَزَادَ أَوْ نَقَصَ فَلَمَّا سَلَّمَ قُلْنَا يَا رَسُولَ اللَّهِ هَلْ حَدَثَ فِي الصَّلاَةِ شَىْءٌ قَالَ ‏ "‏ لَوْ حَدَثَ فِي الصَّلاَةِ شَىْءٌ أَنْبَأْتُكُمُوهُ وَلَكِنِّي إِنَّمَا أَنَا بَشَرٌ أَنْسَى كَمَا تَنْسَوْنَ فَأَيُّكُمْ مَا شَكَّ فِي صَلاَتِهِ فَلْيَنْظُرْ أَحْرَى ذَلِكَ إِلَى الصَّوَابِ فَلْيُتِمَّ عَلَيْهِ ثُمَّ لْيُسَلِّمْ وَلْيَسْجُدْ سَجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{1242}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah (ﷺ) prayed and did more or less (rak'ahs). When he had said the taslim, it was said: 'O Messenger of Allah, has there been some change concerning the prayer?' He said: 'If there had been some change concerning the prayer, I would have told you. Rather I am a human being and I forget as you forget. If any one of you is not sure about his prayer, let him consider an estimate of what is correct, and complete his prayer on that basis, then say the taslim and prostrate twice}}
\hadithdefcmd{nasai}{1243}{أَخْبَرَنَا الْحَسَنُ بْنُ إِسْمَاعِيلَ بْنِ سُلَيْمَانَ الْمُجَالِدِيُّ، قَالَ حَدَّثَنَا الْفُضَيْلُ، - يَعْنِي ابْنَ عِيَاضٍ - عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةً فَزَادَ فِيهَا أَوْ نَقَصَ فَلَمَّا سَلَّمَ قُلْنَا يَا نَبِيَّ اللَّهِ هَلْ حَدَثَ فِي الصَّلاَةِ شَىْءٌ قَالَ ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ فَذَكَرْنَا لَهُ الَّذِي فَعَلَ فَثَنَى رِجْلَهُ فَاسْتَقْبَلَ الْقِبْلَةَ فَسَجَدَ سَجْدَتَىِ السَّهْوِ ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏"‏ لَوْ حَدَثَ فِي الصَّلاَةِ شَىْءٌ لأَنْبَأْتُكُمْ بِهِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّمَا أَنَا بَشَرٌ أَنْسَى كَمَا تَنْسَوْنَ فَأَيُّكُمْ شَكَّ فِي صَلاَتِهِ شَيْئًا فَلْيَتَحَرَّ الَّذِي يَرَى أَنَّهُ صَوَابٌ ثُمَّ يُسَلِّمْ ثُمَّ يَسْجُدْ سَجْدَتَىِ السَّهْوِ ‏"‏ ‏.‏\hadithno{1243}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah (ﷺ) prayed and did more or less (rak'ahs). When he had said the salam we said: 'O Messenger of Allah (ﷺ), has there been some change concerning the prayer?' He said: 'Why are you asking?' So we told him what he had done. He turned back toward the Qiblah and prostrated two prostrations of forgetfulness, then he turned to face us and said: 'If there had been some change concerning the prayer I would have told you.' Then he said: 'Rather I am a human being and I forget as you forget. If any one of you is not sure about his prayer, let him estimate what he thinks is correct, and complete his prayer on that basis, then say the taslim and prostrate two prostrations of forgetfulness}}
\hadithdefcmd{nasai}{1244}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ شُعْبَةَ، قَالَ كَتَبَ إِلَىَّ مَنْصُورٌ وَقَرَأْتُهُ عَلَيْهِ وَسَمِعْتُهُ يُحَدِّثُ رَجُلاً عَنْ إِبْرَاهِيمَ عَنْ عَلْقَمَةَ عَنْ عَبْدِ اللَّهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى صَلاَةَ الظُّهْرِ ثُمَّ أَقْبَلَ عَلَيْهِمْ بِوَجْهِهِ فَقَالُوا أَحَدَثَ فِي الصَّلاَةِ حَدَثٌ قَالَ ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ فَأَخْبَرُوهُ بِصَنِيعِهِ فَثَنَى رِجْلَهُ وَاسْتَقْبَلَ الْقِبْلَةَ فَسَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ أَقْبَلَ عَلَيْهِمْ بِوَجْهِهِ فَقَالَ ‏"‏ إِنَّمَا أَنَا بَشَرٌ أَنْسَى كَمَا تَنْسَوْنَ فَإِذَا نَسِيتُ فَذَكِّرُونِي ‏"‏ ‏.‏ وَقَالَ ‏"‏ لَوْ كَانَ حَدَثَ فِي الصَّلاَةِ حَدَثٌ أَنْبَأْتُكُمْ بِهِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِذَا أَوْهَمَ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيَتَحَرَّ أَقْرَبَ ذَلِكَ مِنَ الصَّوَابِ ثُمَّ لْيُتِمَّ عَلَيْهِ ثُمَّ يَسْجُدْ سَجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{1244}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah that:The Messenger of Allah (ﷺ) prayed Zuhr then he turned to face them and they said: 'Has there been some change concerning the prayer?' He said: 'Why are you asking?' They told him what he had done, so he turned back toward the Qiblah and prostrated twice. Then he said the salam and turned to face them and said: 'I am only human, I forget as you forget, so if I forget, then remind me.' And he said: 'If there had been some change concerning the prayer I would have told you.' And he said: 'If one of you is not sure about his prayer, let him estimate what is closest to what is correct, then let him complete it on that basis, then prostrate twice}}
\hadithdefcmd{nasai}{1245}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يَقُولُ قَالَ عَبْدُ اللَّهِ مَنْ أَوْهَمَ فِي صَلاَتِهِ فَلْيَتَحَرَّ الصَّوَابَ ثُمَّ يَسْجُدْ سَجْدَتَيْنِ بَعْدَ مَا يَفْرُغُ وَهُوَ جَالِسٌ ‏.‏\hadithno{1245}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah said:"Whoever us not sure about his prayer, then let him estimate what is correct, then let him prostrate twice after he finished his prayer, while he is sitting}}
\hadithdefcmd{nasai}{1246}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مِسْعَرٍ، عَنِ الْحَكَمِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ مَنْ شَكَّ أَوْ أَوْهَمَ فَلْيَتَحَرَّ الصَّوَابَ ثُمَّ لْيَسْجُدْ سَجْدَتَيْنِ ‏.‏\hadithno{1246}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah said:"Whoever has doubt, or is not sure, let him estimate what is correct, then let him prostrate twice}}
\hadithdefcmd{nasai}{1247}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، قَالَ كَانُوا يَقُولُونَ إِذَا أَوْهَمَ يَتَحَرَّى الصَّوَابَ ثُمَّ يَسْجُدُ سَجْدَتَيْنِ ‏.‏\hadithno{1247}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibrahim said:"They used to say: 'If one is not sure of what he estimates is correct, then prostrate twice}}
\hadithdefcmd{nasai}{1248}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ جُرَيْجٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مُسَافِعٍ عَنْ عُتْبَةَ بْنِ مُحَمَّدِ بْنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَكَّ فِي صَلاَتِهِ فَلْيَسْجُدْ سَجْدَتَيْنِ بَعْدَ مَا يُسَلِّمُ ‏"‏ ‏.‏\hadithno{1248}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abdullah bin Ja'far said:"The Messenger of Allah (ﷺ) said: 'Whoever has doubt during his prayer, let him prostrate twice after he has said the taslim}}
\hadithdefcmd{nasai}{1249}{أَخْبَرَنَا مُحَمَّدُ بْنُ هَاشِمٍ، أَنْبَأَنَا الْوَلِيدُ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُسَافِعٍ، عَنْ عُتْبَةَ بْنِ مُحَمَّدِ بْنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَكَّ فِي صَلاَتِهِ فَلْيَسْجُدْ سَجْدَتَيْنِ بَعْدَ التَّسْلِيمِ ‏"‏ ‏.‏\hadithno{1249}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated 'Abdullah bin Ja'far that :The Messenger of Allah (ﷺ) said: "Whoever has doubt during his prayer, let him prostrate twice after he said the taslim}}
\hadithdefcmd{nasai}{1250}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُسَافِعٍ، أَنَّ مُصْعَبَ بْنَ شَيْبَةَ، أَخْبَرَهُ عَنْ عُتْبَةَ بْنِ مُحَمَّدِ بْنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَكَّ فِي صَلاَتِهِ فَلْيَسْجُدْ سَجْدَتَيْنِ بَعْدَ مَا يُسَلِّمُ ‏"‏ ‏.‏\hadithno{1250}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Ja'far that :The Messenger of Allah (ﷺ) said: "Whoever has doubt during his prayer, let him prostrate twice after he said the taslim}}
\hadithdefcmd{nasai}{1251}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا حَجَّاجٌ، وَرَوْحٌ، - هُوَ ابْنُ عُبَادَةَ - عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُسَافِعٍ، أَنَّ مُصْعَبَ بْنَ شَيْبَةَ، أَخْبَرَهُ عَنْ عُتْبَةَ بْنِ مُحَمَّدِ بْنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ شَكَّ فِي صَلاَتِهِ فَلْيَسْجُدْ سَجْدَتَيْنِ ‏"‏ ‏.‏ قَالَ حَجَّاجٌ ‏"‏ بَعْدَ مَا يُسَلِّمُ ‏"‏ ‏.‏ وَقَالَ رَوْحٌ ‏"‏ وَهُوَ جَالِسٌ ‏"‏ ‏.‏\hadithno{1251}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Ja'far that:The Messenger of Allah (ﷺ) said: "Whoever has doubt during his prayer, let him prostrate twice." (One of the narrators) Hajjaj said: "After he has said the taslim." (Another of them) Rawh said: "While he is sitting}}
\hadithdefcmd{nasai}{1252}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا قَامَ يُصَلِّي جَاءَهُ الشَّيْطَانُ فَلَبَسَ عَلَيْهِ صَلاَتَهُ حَتَّى لاَ يَدْرِي كَمْ صَلَّى فَإِذَا وَجَدَ أَحَدُكُمْ ذَلِكَ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏\hadithno{1252}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "When any one of you gets up and prays, the Shaitan comes to him an confuses him until he does not know how many (Rak'ahs) he prayed. If any one of you notices that, let him prostrate twice when he is sitting}}
\hadithdefcmd{nasai}{1253}{أَخْبَرَنَا بِشْرُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا نُودِيَ لِلصَّلاَةِ أَدْبَرَ الشَّيْطَانُ لَهُ ضُرَاطٌ فَإِذَا قُضِيَ التَّثْوِيبُ أَقْبَلَ حَتَّى يَخْطُرَ بَيْنَ الْمَرْءِ وَقَلْبِهِ حَتَّى لاَ يَدْرِي كَمْ صَلَّى فَإِذَا رَأَى أَحَدُكُمْ ذَلِكَ فَلْيَسْجُدْ سَجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{1253}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'When the call to prayer is given, the Shaitan runs away breaking wind loudly. When the Tathwb (Iqamah) is completed, he comes back and whispers to a man in his hear, until he does not know how many (rak'ahs) he has prayed. If any one of you notices that, let him prostrate twice}}
\hadithdefcmd{nasai}{1254}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ خَمْسًا فَقِيلَ لَهُ أَزِيدَ فِي الصَّلاَةِ قَالَ ‏ "‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالُوا صَلَّيْتَ خَمْسًا ‏.‏ فَثَنَى رِجْلَهُ وَسَجَدَ سَجْدَتَيْنِ ‏.‏\hadithno{1254}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"The Prophet(ﷺ) prayed Zuhr with five rak'ahs, and it was said to him: 'Has something been added to the prayer?' He said: 'Why are you asking?' They said: 'You prayed five.' So he turned around and prostrated twice}}
\hadithdefcmd{nasai}{1255}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ أَنْبَأَنَا ابْنُ شُمَيْلٍ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الْحَكَمِ، وَمُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى بِهِمُ الظُّهْرَ خَمْسًا فَقَالُوا إِنَّكَ صَلَّيْتَ خَمْسًا ‏.‏ فَسَجَدَ سَجْدَتَيْنِ بَعْدَ مَا سَلَّمَ وَهُوَ جَالِسٌ ‏.‏\hadithno{1255}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah that:The Prophet (ﷺ) led them in praying Zuhr with five (rak'ahs). They said: 'You prayed five.' So he prostrated twice after he had said the taslim, while he was sitting}}
\hadithdefcmd{nasai}{1256}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنِي يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا مُفَضَّلُ بْنُ مُهَلْهَلٍ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ سُوَيْدٍ، قَالَ صَلَّى عَلْقَمَةُ خَمْسًا فَقِيلَ لَهُ فَقَالَ مَا فَعَلْتُ ‏.‏ قُلْتُ بِرَأْسِي بَلَى ‏.‏ قَالَ وَأَنْتَ يَا أَعْوَرُ فَقُلْتُ نَعَمْ ‏.‏ فَسَجَدَ سَجْدَتَيْنِ ثُمَّ حَدَّثَنَا عَنْ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى خَمْسًا فَوَشْوَشَ الْقَوْمُ بَعْضُهُمْ إِلَى بَعْضٍ فَقَالُوا لَهُ أَزِيدَ فِي الصَّلاَةِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ فَأَخْبَرُوهُ فَثَنَى رِجْلَهُ فَسَجَدَ سَجْدَتَيْنِ ثُمَّ قَالَ ‏"‏ إِنَّمَا أَنَا بَشَرٌ أَنْسَى كَمَا تَنْسَوْنَ ‏"‏ ‏.‏\hadithno{1256}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibrahim bin Suwaid said:"Alqamah prayed five (rak'ahs) and was told about that. He said: 'Did I really do that?' I nodded yes. He said: 'What about you, O odd-eyed one?' I said: 'Yes'. So he prostrated twice, then he narrated to us from 'Abdullah that the Prophet (ﷺ) prayed five (rak'ahs), and the people whispered to one another, then they said to him: 'Has something been added the prayer?' He said: 'No.' So they told him, and he turned around and prostrated twice, then he said: 'I am only human; I forget as you forget}}
\hadithdefcmd{nasai}{1257}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، قَالَ سَمِعْتُ الشَّعْبِيَّ، يَقُولُ سَهَا عَلْقَمَةُ بْنُ قَيْسٍ فِي صَلاَتِهِ فَذَكَرُوا لَهُ بَعْدَ مَا تَكَلَّمَ فَقَالَ أَكَذَلِكَ يَا أَعْوَرُ قَالَ نَعَمْ ‏.‏ فَحَلَّ حُبْوَتَهُ ثُمَّ سَجَدَ سَجْدَتَىِ السَّهْوِ وَقَالَ هَكَذَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ وَسَمِعْتُ الْحَكَمَ يَقُولُ كَانَ عَلْقَمَةُ صَلَّى خَمْسًا ‏.‏\hadithno{1257}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Malik bin Mighwal said:"I heard Ash-Sha'bi say: 'Alqamah bin Qais forgot (and made a mistake) in his prayer, and they told him about that after he had spoken, He said: 'Is that true, O odd-eyed one?' He said: 'Yes.' So he undid his cloak, then he performed two prostrations of forgtfulness,and said: 'This is what the Messenger of Allah (ﷺ) did.' He said: And I heard Al-Hakam say: 'Alqamah had prayed five}}
\hadithdefcmd{nasai}{1258}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ، أَنَّ عَلْقَمَةَ، صَلَّى خَمْسًا فَلَمَّا سَلَّمَ قَالَ إِبْرَاهِيمُ بْنُ سُوَيْدٍ يَا أَبَا شِبْلٍ صَلَّيْتَ خَمْسًا ‏.‏ فَقَالَ أَكَذَلِكَ يَا أَعْوَرُ فَسَجَدَ سَجْدَتَىِ السَّهْوِ ثُمَّ قَالَ هَكَذَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1258}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibrahim said:"Alqamah prayed five (rak'ahs) and when he said the taslim, Ibrahim bin Suwaid said : 'O Abu Shibl, you prayed five!' He said: 'Is that true, O odd-eyed one?' Then he prostrated two prostrations of forgetfulness, then he said: 'This is what the Messenger of Allah (ﷺ) did}}
\hadithdefcmd{nasai}{1259}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ أَبِي بَكْرٍ النَّهْشَلِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى إِحْدَى صَلاَتَىِ الْعَشِيِّ خَمْسًا فَقِيلَ لَهُ أَزِيدَ فِي الصَّلاَةِ فَقَالَ ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالُوا صَلَّيْتَ خَمْسًا ‏.‏ قَالَ ‏"‏ إِنَّمَا أَنَا بَشَرٌ أَنْسَى كَمَا تَنْسَوْنَ وَأَذْكُرُ كَمَا تَذْكُرُونَ ‏"‏ ‏.‏ فَسَجَدَ سَجْدَتَيْنِ ثُمَّ انْفَتَلَ ‏.‏\hadithno{1259}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah that :The Messenger of Allah (ﷺ) offered one of the afternoon prayers with five (rak'ahs), and it was said to him: "Has something been added to the prayer?" He said: 'Why are you asking?' They said: 'You prayed five.' He said: 'I am only human, I forget as you forget, and I remember as you remember.' Then he prostrated twice then ended his prayer}}
\hadithdefcmd{nasai}{1260}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ مُحَمَّدِ بْنِ يُوسُفَ، مَوْلَى عُثْمَانَ عَنْ أَبِيهِ، يُوسُفَ أَنَّ مُعَاوِيَةَ، صَلَّى إِمَامَهُمْ فَقَامَ فِي الصَّلاَةِ وَعَلَيْهِ جُلُوسٌ فَسَبَّحَ النَّاسُ فَتَمَّ عَلَى قِيَامِهِ ثُمَّ سَجَدَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ بَعْدَ أَنْ أَتَمَّ الصَّلاَةَ ثُمَّ قَعَدَ عَلَى الْمِنْبَرِ فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ نَسِيَ شَيْئًا مِنْ صَلاَتِهِ فَلْيَسْجُدْ مِثْلَ هَاتَيْنِ السَّجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{1260}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Muhammad bin Yusuf, the freed slave of Uthman, from his father Yusuf, that:Mu'awiyah prayed in front of them, and he stood up during the prayer when he should have sat. The people said tasbih, but he remained standing, then he prostrated twice while he was sitting, after he completed the prayer. Then he sat on the Minbar and said: 'I heard the Messenger of Allah (ﷺ) say: 'Whoever forgets something in his prayer, let him prostrate twice like this}}
\hadithdefcmd{nasai}{1261}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، وَيُونُسُ، وَاللَّيْثُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُمْ عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، أَنَّ عَبْدَ اللَّهِ ابْنَ بُحَيْنَةَ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فِي الثِّنْتَيْنِ مِنَ الظُّهْرِ فَلَمْ يَجْلِسْ فَلَمَّا قَضَى صَلاَتَهُ سَجَدَ سَجْدَتَيْنِ كَبَّرَ فِي كُلِّ سَجْدَةٍ وَهُوَ جَالِسٌ قَبْلَ أَنْ يُسَلِّمَ وَسَجَدَهُمَا النَّاسُ مَعَهُ مَكَانَ مَا نَسِيَ مِنَ الْجُلُوسِ ‏.‏\hadithno{1261}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdur-Rahman Al A'raj that:Abdullah bin Buhainah told him that the Messenger of Allah (ﷺ) stood up following two rak'ahs of Zuhr and did not sit down (for tashahhud). When he finished the prayer he prostrated twice, saying Takbir for each prostration, while he was sitting, before he said the taslim, and the people prostrated with him. (He did that) in place of the sitting that he had forgotten}}
\hadithdefcmd{nasai}{1262}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَمُحَمَّدُ بْنُ بَشَّارِ، بُنْدَارٌ - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا كَانَ فِي الرَّكْعَتَيْنِ اللَّتَيْنِ تَنْقَضِي فِيهِمَا الصَّلاَةُ أَخَّرَ رِجْلَهُ الْيُسْرَى وَقَعَدَ عَلَى شِقِّهِ مُتَوَرِّكًا ثُمَّ سَلَّمَ ‏.‏\hadithno{1262}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Humaid As-Sa'idi said:"At the end of the last two rak'ahs of the prayer, the Prophet (ﷺ) would move his left foot forward and sit on his left buttock, Mutawarrikan, then he would say the taslim}}
\hadithdefcmd{nasai}{1263}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْفَعُ يَدَيْهِ إِذَا افْتَتَحَ الصَّلاَةَ وَإِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَإِذَا جَلَسَ أَضْجَعَ الْيُسْرَى وَنَصَبَ الْيُمْنَى وَوَضَعَ يَدَهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى وَيَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَعَقَدَ ثِنْتَيْنِ الْوُسْطَى وَالإِبْهَامَ وَأَشَارَ ‏.‏\hadithno{1263}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Wa'il bin Hujr said:"I saw the Messenger of Allah (ﷺ) raise his hands when he started to pray, and when he bowed, and when he raised his head from bowing. And when he sat, he would ay his left foot on the ground and keep his right foot upright, and he placed his left hand on his left thigh, and his right hand on his right thigh, making a circle with his middle finger and thumb, and pointing}}
\hadithdefcmd{nasai}{1264}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ الرَّقِّيُّ، قَالَ حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ يُوسُفَ الْفِرْيَابِيُّ - قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم جَلَسَ فِي الصَّلاَةِ فَافْتَرَشَ رِجْلَهُ الْيُسْرَى وَوَضَعَ ذِرَاعَيْهِ عَلَى فَخِذَيْهِ وَأَشَارَ بِالسَّبَّابَةِ يَدْعُو بِهَا ‏.‏\hadithno{1264}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Wa'il bin Hujr that :He saw the Prophet (ﷺ) sitting during the prayer. He lay his left foot on the ground and placed his forearms on his thighs, and pointed with his forefinger, supplicating with it}}
\hadithdefcmd{nasai}{1265}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ أَنْبَأَنَا بِشْرُ بْنُ الْمُفَضَّلِ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ قُلْتُ لأَنْظُرَنَّ إِلَى صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ يُصَلِّي فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاسْتَقْبَلَ الْقِبْلَةَ فَرَفَعَ يَدَيْهِ حَتَّى حَاذَتَا أُذُنَيْهِ ثُمَّ أَخَذَ شِمَالَهُ بِيَمِينِهِ فَلَمَّا أَرَادَ أَنْ يَرْكَعَ رَفَعَهُمَا مِثْلَ ذَلِكَ وَوَضَعَ يَدَيْهِ عَلَى رُكْبَتَيْهِ فَلَمَّا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَهُمَا مِثْلَ ذَلِكَ فَلَمَّا سَجَدَ وَضَعَ رَأْسَهُ بِذَلِكَ الْمَنْزِلِ مِنْ يَدَيْهِ ثُمَّ جَلَسَ فَافْتَرَشَ رِجْلَهُ الْيُسْرَى وَوَضَعَ يَدَهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى وَحَدَّ مِرْفَقَهُ الأَيْمَنَ عَلَى فَخِذِهِ الْيُمْنَى وَقَبَضَ ثِنْتَيْنِ وَحَلَّقَ وَرَأَيْتُهُ يَقُولُ هَكَذَا وَأَشَارَ بِشْرٌ بِالسَّبَّابَةِ مِنَ الْيُمْنَى وَحَلَّقَ الإِبْهَامَ وَالْوُسْطَى ‏.‏\hadithno{1265}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Wa'il bin Hujr said:"I said: 'I am going to watch the Messenger of Allah (ﷺ) and see how he prays.' The Messenger of Allah (ﷺ) stood up and faced the Qiblah, then he raised his hands until they were in level with his ears, then he held his left hand with his right. When he wanted to bow, he raised them (his hands) likewise, then placed his hands on his knees. When he raised his head from bowing, he raised them (his hands) likewise. When he prostrated he put his hands in the same position in relation to his head, then he sat up and lay his left foot on the ground. He placed his left hand on his left thigh and his right elbow on his right thigh, and made a circle with two of his fingers. And I saw him doing like this"- Bishr (one of the narrators) pointed with the forefinger of his right hand and made a circle with the thumb and middle finger}}
\hadithdefcmd{nasai}{1266}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، - شَيْخٌ مِنْ أَهْلِ الْمَدِينَةِ - ثُمَّ لَقِيتُ الشَّيْخَ فَقَالَ سَمِعْتُ عَلِيَّ بْنَ عَبْدِ الرَّحْمَنِ يَقُولُ صَلَّيْتُ إِلَى جَنْبِ ابْنِ عُمَرَ فَقَلَّبْتُ الْحَصَى فَقَالَ لِي ابْنُ عُمَرَ لاَ تُقَلِّبِ الْحَصَى فَإِنَّ تَقْلِيبَ الْحَصَى مِنَ الشَّيْطَانِ وَافْعَلْ كَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ ‏.‏ قُلْتُ وَكَيْفَ رَأَيْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ قَالَ هَكَذَا وَنَصَبَ الْيُمْنَى وَأَضْجَعَ الْيُسْرَى وَوَضَعَ يَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَيَدَهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى وَأَشَارَ بِالسَّبَّابَةِ ‏.‏\hadithno{1266}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali bin Abdur-Rahman said:"I prayed beside Ibn Umar and I turned over the pebbles. Ibn Umar said to me: 'Do not turn over the pebbles, for turning over the pebbles comes from Shaitan. Do what I saw the Messenger of Allah (ﷺ) do.' I said: 'What did you see the Messenger of Allah (ﷺ) do?' He said; 'This'- and he held his right foot upright and lay his left foot on the ground, and placed his right hand on his right thigh and his left hand on his left thigh, and pointed with his forefinger}}
\hadithdefcmd{nasai}{1267}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ عَلِيِّ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ رَآنِي ابْنُ عُمَرَ وَأَنَا أَعْبَثُ، بِالْحَصَى فِي الصَّلاَةِ فَلَمَّا انْصَرَفَ نَهَانِي وَقَالَ اصْنَعْ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏ قُلْتُ وَكَيْفَ كَانَ يَصْنَعُ قَالَ كَانَ إِذَا جَلَسَ فِي الصَّلاَةِ وَضَعَ كَفَّهُ الْيُمْنَى عَلَى فَخِذِهِ وَقَبَضَ - يَعْنِي أَصَابِعَهُ كُلَّهَا - وَأَشَارَ بِأُصْبُعِهِ الَّتِي تَلِي الإِبْهَامَ وَوَضَعَ كَفَّهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى ‏.‏\hadithno{1267}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali bin Abdur-Rahman said:"Ibn Umar saw me playing with the pebbles while praying. When he finished (praying), he told me not to do that and said: 'Do what the Messenger of Allah (ﷺ) used to do.' I said: 'What did he used to do?' He said: 'When he sat during the prayer, he placed his right hand on his thigh and clenched all his fingers, and pointed with the finger that is next to the thumb, and he put his left hand on his left thigh}}
\hadithdefcmd{nasai}{1268}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ زَائِدَةَ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، قَالَ حَدَّثَنِي أَبِي أَنَّ وَائِلَ بْنَ حُجْرٍ، قَالَ قُلْتُ لأَنْظُرَنَّ إِلَى صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ يُصَلِّي فَنَظَرْتُ إِلَيْهِ فَوَصَفَ قَالَ ثُمَّ قَعَدَ وَافْتَرَشَ رِجْلَهُ الْيُسْرَى وَوَضَعَ كَفَّهُ الْيُسْرَى عَلَى فَخِذِهِ وَرُكْبَتِهِ الْيُسْرَى وَجَعَلَ حَدَّ مِرْفَقِهِ الأَيْمَنِ عَلَى فَخِذِهِ الْيُمْنَى ثُمَّ قَبَضَ اثْنَتَيْنِ مِنْ أَصَابِعِهِ وَحَلَّقَ حَلْقَةً ثُمَّ رَفَعَ أُصْبُعَهُ فَرَأَيْتُهُ يُحَرِّكُهَا يَدْعُو بِهَا ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{1268}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Wa'il bin Hujr said:"I am going to watch the Messenger of Allah (ﷺ) and see how he prays. So, I watched him." And he described (his prayer): "Then he sat and lay his left foot on the ground, and placed his left hand on his left thigh and knee. He put his right elbow on his right thigh, then he made a circle with two fingers of his (right) hand, then he raised his finger and I saw him moving it, supplicating with it}}
\hadithdefcmd{nasai}{1269}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا جَلَسَ فِي الصَّلاَةِ وَضَعَ يَدَيْهِ عَلَى رُكْبَتَيْهِ وَرَفَعَ أُصْبُعَهُ الَّتِي تَلِي الإِبْهَامَ فَدَعَا بِهَا وَيَدَهُ الْيُسْرَى عَلَى رُكْبَتِهِ بَاسِطُهَا عَلَيْهَا ‏.‏\hadithno{1269}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:When the Messenger of Allah (ﷺ) sat during the prayer, he put his hands on his knees and raised the finger that is next to the thumb, and supplicates with it, and his left hand was on his knee laid on it}}
\hadithdefcmd{nasai}{1270}{أَخْبَرَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الْوَزَّانُ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي زِيَادٌ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُشِيرُ بِأُصْبُعِهِ إِذَا دَعَا وَلاَ يُحَرِّكُهَا ‏.‏ قَالَ ابْنُ جُرَيْجٍ وَزَادَ عَمْرٌو قَالَ أَخْبَرَنِي عَامِرُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنْ أَبِيهِ أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يَدْعُو كَذَلِكَ وَيَتَحَامَلُ بِيَدِهِ الْيُسْرَى عَلَى رِجْلِهِ الْيُسْرَى ‏.‏\hadithno{1270}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdullah bin Az-Zubair:That the Prophet (ﷺ) used to point with his finger when he supplicated, but he did not move it. Ibn Jurayj said: "And 'Amr added: 'Amir bin 'Abdullah bin Az-Zubair told me that his father saw the Prophet (ﷺ) supplicating like that, putting his weight on his left arm, leaning on his left leg}}
\hadithdefcmd{nasai}{1271}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ الْمَوْصِلِيُّ، عَنِ الْمُعَافَى، عَنْ عِصَامِ بْنِ قُدَامَةَ، عَنْ مَالِكٍ، - وَهُوَ ابْنُ نُمَيْرٍ الْخُزَاعِيِّ - عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَاضِعًا يَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى فِي الصَّلاَةِ وَيُشِيرُ بِأُصْبُعِهِ ‏.‏\hadithno{1271}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Malik bin Numair Al-Khuza'I that his father said:"I saw the Messenger of Allah (ﷺ) putting his right hand on his right thigh when praying and pointing with his finger}}
\hadithdefcmd{nasai}{1272}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، قَالَ حَدَّثَنَا ابْنُ عَجْلاَنَ، عَنِ الْقَعْقَاعِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، كَانَ يَدْعُو بِأُصْبُعَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحِّدْ أَحِّدْ ‏"‏ ‏.‏\hadithno{1272}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:A man used to supplicate with two fingers and the Messenger of Allah (ﷺ) said: "Make it one, make it one}}
\hadithdefcmd{nasai}{1273}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ سَعْدٍ، قَالَ مَرَّ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَدْعُو بِأَصَابِعِي فَقَالَ ‏ "‏ أَحِّدْ أَحِّدْ ‏"‏ ‏.‏ وَأَشَارَ بِالسَّبَّابَةِ ‏.‏\hadithno{1273}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa`d who said:"The Messenger of Allah (ﷺ) passed by me when I was supplicating with my fingers and he said: 'Make it one, make it one' and pointed with his forefinger}}
\hadithdefcmd{nasai}{1274}{أَخْبَرَنِي أَحْمَدُ بْنُ يَحْيَى الصُّوفِيُّ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا عِصَامُ بْنُ قُدَامَةَ الْجَدَلِيُّ، قَالَ حَدَّثَنِي مَالِكُ بْنُ نُمَيْرٍ الْخُزَاعِيُّ، مِنْ أَهْلِ الْبَصْرَةِ أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم قَاعِدًا فِي الصَّلاَةِ وَاضِعًا ذِرَاعَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى رَافِعًا أُصْبُعَهُ السَّبَّابَةَ قَدْ أَحْنَاهَا شَيْئًا وَهُوَ يَدْعُو ‏.‏\hadithno{1274}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Malik bin Numair Al-Khuza'I, one of the inhabitants of Al-Basrah, narrated that:His father told him that he saw the Messenger of Allah (ﷺ) sitting when praying, putting his right forearm on his right thigh and raising his forefinger, which he had bent slightly, and he was supplicating}}
\hadithdefcmd{nasai}{1275}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَعَدَ فِي التَّشَهُّدِ وَضَعَ كَفَّهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى وَأَشَارَ بِالسَّبَّابَةِ لاَ يُجَاوِزُ بَصَرُهُ إِشَارَتَهُ ‏.‏\hadithno{1275}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Amir bin Abdullah bin Az-Zubair, from his father, that:When the Messenger of Allah (ﷺ) sat to say the tashahhud, he placed his left hand on his left thigh and pointed with his forefinger, and his gaze did not go beyond he finger with which he was pointing}}
\hadithdefcmd{nasai}{1276}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَنْتَهِيَنَّ أَقْوَامٌ عَنْ رَفْعِ أَبْصَارِهِمْ عِنْدَ الدُّعَاءِ فِي الصَّلاَةِ إِلَى السَّمَاءِ أَوْ لَتُخْطَفَنَّ أَبْصَارُهُمْ ‏"‏ ‏.‏\hadithno{1276}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "People should certainly stop lifting their gaze to the sky when they supplicate during the prayer, or they will lose their eyesight}}
\hadithdefcmd{nasai}{1277}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو عُبَيْدِ اللَّهِ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، وَمَنْصُورٌ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ كُنَّا نَقُولُ فِي الصَّلاَةِ قَبْلَ أَنْ يُفْرَضَ التَّشَهُّدُ السَّلاَمُ عَلَى اللَّهِ السَّلاَمُ عَلَى جِبْرِيلَ وَمِيكَائِيلَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُولُوا هَكَذَا فَإِنَّ اللَّهَ عَزَّ وَجَلَّ هُوَ السَّلاَمُ وَلَكِنْ قُولُوا التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1277}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Mas'ud said:"Before the tashahhud was enjoined, when we prayed we used to say: 'Peace (As-Salam) be upon Allah (SWT), pace be upon Jibril, peace be upon Mika'il.' The Messenger of Allah (ﷺ) said: 'Do not say this, for indeed Allah (SWT), the Mighty and Sublime, is As-Salam. Rather say: "At-tahiyyatu lillahi wasalawatu wat-tayibaat, as-salamu 'alaika ayah-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina a 'ala ibad illahis-salihin, ashadu an la ilaha ill Allah, wa ashhadu anna Muhammadan 'abduhu wa rasuluhu. (All compliments, prayers and pure words are due to Allah. Peace be upon you O Prophet, and the mercy of Allah and His blessings. Peace be upon us and upon the righteous slaves of Allah. I bear witness that that none has the right to be worshipped except Allah, and I bear witness that Muhammad is His slave and messenger)}}
\hadithdefcmd{nasai}{1278}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ ‏.‏\hadithno{1278}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) used to teach us the tashahhud just as he used to teach us a surah from the Quran}}
\hadithdefcmd{nasai}{1279}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْفُضَيْلُ، - وَهُوَ ابْنُ عِيَاضٍ - عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ هُوَ السَّلاَمُ فَإِذَا قَعَدَ أَحَدُكُمْ فَلْيَقُلِ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ثُمَّ لْيَتَخَيَّرْ بَعْدَ ذَلِكَ مِنَ الْكَلاَمِ مَا شَاءَ ‏"‏ ‏.‏\hadithno{1279}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abdullah said:"The Messenger of Allah (ﷺ) said: 'Allah, the Mighty and Sublime, is As-Salam the source of peace; the One free from all faults), so when any one of you sits (during the prayer), let him say: At-tahiyyatu lillahi wasalawatu wat-tayibaat, as-salamu 'alaika ayah-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina a 'ala ibad illahis-salihin, ashadu an la ilaha ill Allah, wa ashhadu anna Muhammadan 'abduhu wa rasuluhu. (All compliments, prayers and pure words are due to Allah. Peace be upon you O Prophet, and the mercy of Allah and His blessings. Peace be upon us and upon the righteous slaves of Allah. I bear witness that that none has the right to be worshipped except Allah, and I bear witness that Muhammad is His slave and messenger.)" Then after that, let him choose whatever words he wants}}
\hadithdefcmd{nasai}{1280}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، أَنَّ الأَشْعَرِيَّ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَنَا فَعَلَّمَنَا سُنَّتَنَا وَبَيَّنَ لَنَا صَلاَتَنَا فَقَالَ ‏"‏ إِذَا قُمْتُمْ إِلَى الصَّلاَةِ فَأَقِيمُوا صُفُوفَكُمْ ثُمَّ لْيَؤُمَّكُمْ أَحَدُكُمْ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا قَالَ ‏\{‏ وَلاَ الضَّالِّينَ ‏\}‏ فَقُولُوا آمِينَ يُجِبْكُمُ اللَّهُ ثُمَّ إِذَا كَبَّرَ وَرَكَعَ فَكَبِّرُوا وَارْكَعُوا فَإِنَّ الإِمَامَ يَرْكَعُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَالَ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ثُمَّ إِذَا كَبَّرَ وَسَجَدَ فَكَبِّرُوا وَاسْجُدُوا فَإِنَّ الإِمَامَ يَسْجُدُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ وَإِذَا كَانَ عِنْدَ الْقَعْدَةِ فَلْيَكُنْ مِنْ قَوْلِ أَحَدِكُمْ أَنْ يَقُولَ التَّحِيَّاتُ الطَّيِّبَاتُ الصَّلَوَاتُ لِلَّهِ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1280}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hittan bin 'Abdullah that Al-Ash'ari said:"The Messenger of Allah (ﷺ) addressed us and taught us our Sunnahs and our prayer. He said: 'When you stand for the prayer, make your rows straight, then let one of you lead the others. When he says the takbir, then say the takbir; when he says : "Wa lad-dallin" then say "Amin" and Allah (SWT) will answer you. Then when he says the takbir and bows, then say the takbir and bow, for the Imam bows before you and stands up before you.' The Prophet of Allah (ﷺ) said: "This makes up for that. When he says: 'Sami' Allahu liman hamidah (Allah hears the one who praises Him),' say: 'Allahumma, Rabbana wa lakal-hamd (O Allah, our Lord, to You be praise),' Allah will hear you, for indeed Allah (SWT), the Mighty and Sublime, has said on the tongue of His Prophet: "Allah hears the one who praises Him." Then when he says the takbir and prostrates, say the takbir and prostrate, for the Imam prostrates before you and rises before you.' The Prophet of Allah (ﷺ) said: 'This makes up for that. Then when you are sitting, let the following be among what one of you says: At-tahiyyatu lillahi wasalawatu wat-tayibaat, as-salamu 'alaika ayah-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina a 'ala ibad illahis-salihin, ashadu an la ilaha ill Allah, wa ashhadu anna Muhammadan 'abduhu wa rasuluhu. (All compliments, prayers and pure words are due to Allah. Peace be upon you O Prophet, and the mercy of Allah and His blessings. Peace be upon us and upon the righteous slaves of Allah. I bear witness that that none has the right to be worshipped except Allah, and I bear witness that Muhammad is His slave and messenger)}}
\hadithdefcmd{nasai}{1281}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ حَدَّثَنَا أَيْمَنُ بْنُ نَابِلٍ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ ‏ "‏ بِسْمِ اللَّهِ وَبِاللَّهِ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ وَأَسْأَلُ اللَّهَ الْجَنَّةَ وَأَعُوذُ بِهِ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ نَعْلَمُ أَحَدًا تَابَعَ أَيْمَنَ بْنَ نَابِلٍ عَلَى هَذِهِ الرِّوَايَةِ وَأَيْمَنُ عِنْدَنَا لاَ بَأْسَ بِهِ وَالْحَدِيثُ خَطَأٌ وَبِاللَّهِ التَّوْفِيقُ ‏.‏\hadithno{1281}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) used to teach us the tashahhud just as he would teach us a surah of the Quran: 'Bismillah, wa billahi. At-tahiyyatu lillahi wasalawatu wat-tayibaat, as-salamu 'alaika ayah-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina a 'ala ibad illahis-salihin, ashadu an la ilaha ill Allah, wa ashhadu anna Muhammadan 'abduhu wa rasuluhu. As'al Allahal-jannah wa author billahi min an-nar (All compliments, prayers and pure words are due to Allah. Peace be upon you O Prophet, and the mercy of Allah and His blessings. Peace be upon us and upon the righteous slaves of Allah. I bear witness that that none has the right to be worshipped except Allah, and I bear witness that Muhammad is His slave and messenger. I ask Allah for Paradise and I seek refuge with Allah from the Fire)}}
\hadithdefcmd{nasai}{1282}{أَخْبَرَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْحَكَمِ الْوَرَّاقُ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنْ سُفْيَانَ بْنِ سَعِيدٍ، ح وَأَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، وَعَبْدُ الرَّزَّاقِ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، عَنْ زَاذَانَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِلَّهِ مَلاَئِكَةً سَيَّاحِينَ فِي الأَرْضِ يُبَلِّغُونِي مِنْ أُمَّتِي السَّلاَمَ ‏"‏ ‏.‏\hadithno{1282}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abdullah said:"The Messenger of Allah (ﷺ) said: 'Allah (SWT) has angels who travel around on Earth conveying to me the Salams of my Ummah}}
\hadithdefcmd{nasai}{1283}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ الْكَوْسَجُ، قَالَ أَنْبَأَنَا عَفَّانُ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا ثَابِتٌ، قَالَ قَدِمَ عَلَيْنَا سُلَيْمَانُ مَوْلَى الْحَسَنِ بْنِ عَلِيٍّ زَمَنَ الْحَجَّاجِ فَحَدَّثَنَا عَنْ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ عَنْ أَبِيهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَ ذَاتَ يَوْمٍ وَالْبُشْرَى فِي وَجْهِهِ فَقُلْنَا إِنَّا لَنَرَى الْبُشْرَى فِي وَجْهِكَ ‏.‏ فَقَالَ ‏ "‏ إِنَّهُ أَتَانِي الْمَلَكُ فَقَالَ يَا مُحَمَّدُ إِنَّ رَبَّكَ يَقُولُ أَمَا يُرْضِيكَ أَنَّهُ لاَ يُصَلِّي عَلَيْكَ أَحَدٌ إِلاَّ صَلَّيْتُ عَلَيْهِ عَشْرًا وَلاَ يُسَلِّمُ عَلَيْكَ أَحَدٌ إِلاَّ سَلَّمْتُ عَلَيْهِ عَشْرًا ‏"‏ ‏.‏\hadithno{1283}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abdullah bin Abi Talha, from his father, that:The Messenger of Allah (ﷺ) came one day with a cheerful expression on his face, and we said: "We see you looking cheerful". He said: "The Angel came to me and said: 'O Muhammad, your Lord says: 'Will it not please you (to know) that no one will send salah upon you that I will send salah upon him tenfold, and no one will send salams upon you but I will send salams upon him tenfold?}}
\hadithdefcmd{nasai}{1284}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، عَنْ أَبِي هَانِئٍ، أَنَّ أَبَا عَلِيٍّ الْجَنْبِيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ فَضَالَةَ بْنَ عُبَيْدٍ، يَقُولُ سَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً يَدْعُو فِي صَلاَتِهِ لَمْ يُمَجِّدِ اللَّهَ وَلَمْ يُصَلِّ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَجِلْتَ أَيُّهَا الْمُصَلِّي ‏"‏ ‏.‏ ثُمَّ عَلَّمَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً يُصَلِّي فَمَجَّدَ اللَّهَ وَحَمِدَهُ وَصَلَّى عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ادْعُ تُجَبْ وَسَلْ تُعْطَ ‏"‏ ‏.‏\hadithno{1284}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Fadalah bin Ubaid said:"The Messenger of Allah (ﷺ) heard a man supplicating during the prayer without glorifying Allah (SWT) nor sending salah upon the Prophet (ﷺ). The Messenger of Allah (ﷺ) said: 'You are in a hurry, O worshipper.' Then the Messenger of Allah (ﷺ) taught them. And the Messenger of Allah (ﷺ) heard a man praying; he glorified and praised Allah (SWT) and sent salah upon the Prophet (ﷺ). The Messenger of Allah (ﷺ) said: 'Supplicate, you will be answered; ask, you will be given}}
\hadithdefcmd{nasai}{1285}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، أَنَّ مُحَمَّدَ بْنَ عَبْدِ اللَّهِ بْنِ زَيْدٍ الأَنْصَارِيَّ، - وَعَبْدُ اللَّهِ بْنُ زَيْدٍ الَّذِي أُرِيَ النِّدَاءَ بِالصَّلاَةِ - أَخْبَرَهُ عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، أَنَّهُ قَالَ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَجْلِسِ سَعْدِ بْنِ عُبَادَةَ فَقَالَ لَهُ بَشِيرُ بْنُ سَعْدٍ أَمَرَنَا اللَّهُ عَزَّ وَجَلَّ أَنْ نُصَلِّيَ عَلَيْكَ يَا رَسُولَ اللَّهِ فَكَيْفَ نُصَلِّي عَلَيْكَ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى تَمَنَّيْنَا أَنَّهُ لَمْ يَسْأَلْهُ ثُمَّ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ فِي الْعَالَمِينَ إِنَّكَ حَمِيدٌ مَجِيدٌ وَالسَّلاَمُ كَمَا عَلِمْتُمْ ‏"‏ ‏.‏\hadithno{1285}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Mas'ud Al-Ansari siad:"The Messenger of Allah (ﷺ) came to us in the Majlis of Sa'd bin 'Ubadah and Bashir bin Sa'd said to him: 'Allah has commanded us to send Salah upon you, O Messenger of Allah; so how should we send salah upon you?' The Messenger of Allah (ﷺ) remained silent until we wished that he had not asked him. Then he said: 'Say: 'Alahumma salli 'ala Muhammad wa 'ala ali Muhammad, kama sallaita 'ala Ibrahima wa barik 'ala Muhammad kama barakta 'ala ali Ibrahim fil-'alamin, innaka hamidun majid (O Allah, send salah upon Muhammad and upon the family of Muhammad, as You sent salah upon the family of Ibrahim, and send blessings upon Muhammad and upon the family of Muhammad as You sent blessings upon the family of Ibrahim among the nations. You are indeed Worthy of praise, Full of glory.)" And the salam is as you know}}
\hadithdefcmd{nasai}{1286}{أَخْبَرَنَا زِيَادُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، قَالَ حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بِشْرٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم أُمِرْنَا أَنْ نُصَلِّيَ عَلَيْكَ وَنُسَلِّمَ أَمَّا السَّلاَمُ فَقَدْ عَرَفْنَاهُ فَكَيْفَ نُصَلِّي عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ ‏"‏ ‏.‏\hadithno{1286}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Mas'ud Al-Ansari said:"It was said to the Prophet (ﷺ): We have been commanded to send salah and salams upon you. We know how to send salams, but how should we send salah?' He said: Say: 'Alahumma salli 'ala Muhammad wa 'ala ali Muhammad, kama sallaita 'ala Ibrahima wa barik 'ala Muhammad kama barakta 'ala ali Ibrahim fil-'alamin, innaka hamidun majid (O Allah, send salah upon Muhammad and upon the family of Muhammad, as You sent salah upon the family of Ibrahim)}}
\hadithdefcmd{nasai}{1287}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، مِنْ كِتَابِهِ قَالَ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سُلَيْمَانَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ السَّلاَمُ عَلَيْكَ قَدْ عَرَفْنَاهُ فَكَيْفَ الصَّلاَةُ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي لَيْلَى وَنَحْنُ نَقُولُ وَعَلَيْنَا مَعَهُمْ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ حَدَّثَنَا بِهِ مِنْ كِتَابِهِ وَهَذَا خَطَأٌ ‏.‏\hadithno{1287}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ka'b bin 'Ujrah said:"We said: 'O Messenger of Allah (ﷺ), we know about sending salams upon you, but how should we send salah upon you?' He said: "Say: 'Alahumma salli 'ala Muhammad wa 'ala ali Muhammad, kama sallaita 'ala Ibrahima wa barik 'ala Muhammad kama barakta 'ala ali Ibrahim fil-'alamin, innaka hamidun majid (O Allah, send salah upon Muhammad and upon the family of Muhammad, as You sent salah upon the family of Ibrahim, and send blessings upon Muhammad and upon the family of Muhammad as You sent blessings upon the family of Ibrahim among the nations. You are indeed Worthy of praise, Full of glory.)'" (One of the narrators) Ibn Abi Laila said: "We used to say: 'And also upon us.'" Abu Abdur-Rahman (An-Nasa'I) said: It was narrated from his book, and this is a mistake}}
\hadithdefcmd{nasai}{1288}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ سُلَيْمَانَ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ السَّلاَمُ عَلَيْكَ قَدْ عَرَفْنَاهُ فَكَيْفَ الصَّلاَةُ عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ وَآلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ وَآلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنُ وَنَحْنُ نَقُولُ وَعَلَيْنَا مَعَهُمْ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا أَوْلَى بِالصَّوَابِ مِنَ الَّذِي قَبْلَهُ وَلاَ نَعْلَمُ أَحَدًا قَالَ فِيهِ عَمْرُو بْنُ مُرَّةَ غَيْرَ هَذَا وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{1288}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ka'b bin 'Ujrah said:'We said: "O Messenger of Allah (ﷺ), we know about sending salams upon you, but how should we send salah upon you?" He said: 'Say: Alahumma salli 'ala Muhammad wa 'ala ali Muhammad, kama sallaita 'ala Ibrahima wa barik 'ala Muhammad kama barakta 'ala ali Ibrahim fil-'alamin, innaka hamidun majid (O Allah, send salah upon Muhammad and upon the family of Muhammad, as You sent salah upon the family of Ibrahim, and send blessings upon Muhammad and upon the family of Muhammad as You sent blessings upon the family of Ibrahim among the nations. You are indeed Worthy of praise, Full of glory.)'" (One of the narrators) 'abdur Rahman said: "We used to say: 'And also upon us.'" Abu Abdur-rahman (An Nasa'i) said: This is more worthy of being correct than the one that is before it. And we do not know of anyone who said "Amr bin Murrah" in it other than in this case. And Allah (SWT) knows best}}
\hadithdefcmd{nasai}{1289}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ قَالَ لِي كَعْبُ بْنُ عُجْرَةَ أَلاَ أُهْدِي لَكَ هَدِيَّةً قُلْنَا يَا رَسُولَ اللَّهِ قَدْ عَرَفْنَا كَيْفَ السَّلاَمُ عَلَيْكَ فَكَيْفَ نُصَلِّي عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَآلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ وَآلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏\hadithno{1289}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Abi Laila said:"Ka'b bin Ujrah said to me: 'Shall I not give you a gift?' We said: "O Messenger of Allah (ﷺ), we know about sending salams upon you, but how should we send salah upon you?" He said: 'Say: Alahumma salli 'ala Muhammad wa 'ala ali Muhammad, kama sallaita 'ala Ibrahima wa barik 'ala Muhammad kama barakta 'ala ali Ibrahim fil-'alamin, innaka hamidun majid (O Allah, send salah upon Muhammad and upon the family of Muhammad, as You sent salah upon the family of Ibrahim, and send blessings upon Muhammad and upon the family of Muhammad as You sent blessings upon the family of Ibrahim among the nations. You are indeed Worthy of praise, Full of glory)}}
\hadithdefcmd{nasai}{1290}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا مُجَمِّعُ بْنُ يَحْيَى، عَنْ عُثْمَانَ بْنِ مَوْهَبٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِيهِ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ كَيْفَ الصَّلاَةُ عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ وَآلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ وَآلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏\hadithno{1290}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Musa bin Talha that:His father said: "We said: 'O Messenger of Allah, how should we send salah upon you?' He said: 'Say: Alahumma salli 'ala Muhammad wa 'ala ali Muhammad, kama sallaita 'ala Ibrahima wa barik 'ala Muhammad kama barakta 'ala ali Ibrahim fil-'alamin, innaka hamidun majid (O Allah, send salah upon Muhammad and upon the family of Muhammad, as You sent salah upon the family of Ibrahim, and send blessings upon Muhammad and upon the family of Muhammad as You sent blessings upon the family of Ibrahim among the nations. You are indeed Worthy of praise, Full of glory)}}
\hadithdefcmd{nasai}{1291}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ عُثْمَانَ بْنِ مَوْهَبٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى نَبِيَّ اللَّهِ صلى الله عليه وسلم فَقَالَ كَيْفَ نُصَلِّي عَلَيْكَ يَا نَبِيَّ اللَّهِ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏\hadithno{1291}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Musa bin Talha, from his father, that:A man came to the Prophet of Allah (ﷺ) and said: "How should we send blessings upon you, O Prophet of Allah?' He said: 'Say: Alahumma salli 'ala Muhammad wa 'ala ali Muhammad, kama sallaita 'ala Ibrahima wa barik 'ala Muhammad kama barakta 'ala ali Ibrahim fil-'alamin, innaka hamidun majid (O Allah, send salah upon Muhammad and upon the family of Muhammad, as You sent salah upon the family of Ibrahim, and send blessings upon Muhammad and upon the family of Muhammad as You sent blessings upon the family of Ibrahim among the nations. You are indeed Worthy of praise, Full of glory)}}
\hadithdefcmd{nasai}{1292}{أَخْبَرَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، فِي حَدِيثِهِ عَنْ أَبِيهِ، عَنْ عُثْمَانَ بْنِ حَكِيمٍ، عَنْ خَالِدِ بْنِ سَلَمَةَ، عَنْ مُوسَى بْنِ طَلْحَةَ، قَالَ سَأَلْتُ زَيْدَ بْنَ خَارِجَةَ قَالَ أَنَا سَأَلْتُ، رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ صَلُّوا عَلَىَّ وَاجْتَهِدُوا فِي الدُّعَاءِ وَقُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ ‏"‏ ‏.‏\hadithno{1292}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Musa bin Talha said:"I asked Zaid bin Kharijah who said: 'I asked the Messenger of Allah (ﷺ) and he said: Send salah upon me and strive hard in supplication, and say: Alahumma salli 'ala Muhammad wa 'ala ali Muhammad (O Allah, send salah upon Muhammad and upon the family of Muhammad)}}
\hadithdefcmd{nasai}{1293}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرٌ، - وَهُوَ ابْنُ مُضَرَ - عَنِ ابْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ السَّلاَمُ عَلَيْكَ قَدْ عَرَفْنَاهُ فَكَيْفَ الصَّلاَةُ عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ عَبْدِكَ وَرَسُولِكَ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ وَبَارِكْ عَلَى مُحَمَّدٍ وَآلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ ‏"‏ ‏.‏\hadithno{1293}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that abu Sa'eed Al-Khudri said:"We said: 'O Messenger of Allah (ﷺ), we know how to send salams upon you, but how should we send salah upon you?' He said: 'Say: "Allahumma salli 'ala Muhammadin 'abdika wa rasulika kama salaita 'ala Ibrahim wa barik 'ala Muhammadin wa 'ala ali Muhammadin kama barakta 'ala Ibrahim (O Allah, send salah upon Muhammad, Your slave and Messenger , as You sent Salah upon Ibrahim, and send blessings upon Muhammad and upon the family of Muhammad as You sent blessings upon Ibrahim)}}
\hadithdefcmd{nasai}{1294}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، قَالَ أَخْبَرَنِي أَبُو حُمَيْدٍ السَّاعِدِيُّ، أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ نُصَلِّي عَلَيْكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ ‏"‏ ‏.‏ فِي حَدِيثِ الْحَارِثِ ‏"‏ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ وَبَارِكْ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ ‏"‏ ‏.‏ قَالاَ جَمِيعًا ‏"‏ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَنْبَأَنَا قُتَيْبَةُ بِهَذَا الْحَدِيثِ مَرَّتَيْنِ وَلَعَلَّهُ أَنْ يَكُونَ قَدْ سَقَطَ عَلَيْهِ مِنْهُ شَطْرٌ ‏.‏\hadithno{1294}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Amr bin Sulam Az-Zuraqi said:"Abu Humaid As-Sa'idi told me that they said: 'O Messenger of Allah (ﷺ), how should we send salah upon you?' The Messenger of Allah (ﷺ) said: 'Say: Allahumma sali 'ala Muhammadin wa azwajihi wa dhuriyatihi ( O Allah, send salah upon Muhamad and his wives and progeny)- in the narration of Al-Harith (one of the two who narrated it)-kama salaita 'ala Ibraim wa barik 'alaMuhammad wa azwajihi wa dhuriyatti (as You sent salah upon Irahim and send blessings upon Muhammad and his wives and progeny)- both of them said that- kama barakta 'ala ali Ibrahima innaka hamidun majid (as You sent blessings upon Ibrahim, You are indeed worthy of praise, Full of glory.)" Abu Abdur-Rahman (An-Nasa'i) said: Qutaibah informed us of this hadith two times, and perhaps he had missed a part of it}}
\hadithdefcmd{nasai}{1295}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ الْمُبَارَكِ - قَالَ أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ سُلَيْمَانَ، مَوْلَى الْحَسَنِ بْنِ عَلِيٍّ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَ ذَاتَ يَوْمٍ وَالْبِشْرُ يُرَى فِي وَجْهِهِ فَقَالَ ‏ "‏ إِنَّهُ جَاءَنِي جِبْرِيلُ صلى الله عليه وسلم فَقَالَ أَمَا يُرْضِيكَ يَا مُحَمَّدُ أَنْ لاَ يُصَلِّيَ عَلَيْكَ أَحَدٌ مِنْ أُمَّتِكَ إِلاَّ صَلَّيْتُ عَلَيْهِ عَشْرًا وَلاَ يُسَلِّمَ عَلَيْكَ أَحَدٌ مِنْ أُمَّتِكَ إِلاَّ سَلَّمْتُ عَلَيْهِ عَشْرًا ‏"‏ ‏.‏\hadithno{1295}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abdullah bin Abi Talhah, from his father, that:The Messenger of Allah (ﷺ) came one day with a joyful expression on his face. He said: "Jibril came to me and said: 'Will it not please you, O Muhammad, (to know) that no one of your Ummah will send salah upon you but I will send salah upon him tenfold, and no one will send salams upon you but I will send salams upon him tenfold?}}
\hadithdefcmd{nasai}{1296}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَلَّى عَلَىَّ وَاحِدَةً صَلَّى اللَّهُ عَلَيْهِ عَشْرًا ‏"‏ ‏.‏\hadithno{1296}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet (ﷺ) said: "Whoever sends salah upon me once, Allah (SWT) will send salah upon him tenfold}}
\hadithdefcmd{nasai}{1297}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى عَلَىَّ صَلاَةً وَاحِدَةً صَلَّى اللَّهُ عَلَيْهِ عَشْرَ صَلَوَاتٍ وَحُطَّتْ عَنْهُ عَشْرُ خَطِيئَاتٍ وَرُفِعَتْ لَهُ عَشْرُ دَرَجَاتٍ ‏"‏ ‏.‏\hadithno{1297}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik said:"The Messenger of Allah (ﷺ) said: "Whoever sends salah upon me once, Allah (SWT) will send salah upon him tenfold, and will erase ten sins from him, and will raise him ten degrees in status}}
\hadithdefcmd{nasai}{1298}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَعَمْرُو بْنُ عَلِيٍّ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُلَيْمَانُ الأَعْمَشُ، قَالَ حَدَّثَنِي شَقِيقٌ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا إِذَا جَلَسْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الصَّلاَةِ قُلْنَا السَّلاَمُ عَلَى اللَّهِ مِنْ عِبَادِهِ السَّلاَمُ عَلَى فُلاَنٍ وَفُلاَنٍ ‏.‏ فَقَال�� رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُولُوا السَّلاَمُ عَلَى اللَّهِ فَإِنَّ اللَّهَ هُوَ السَّلاَمُ وَلَكِنْ إِذَا جَلَسَ أَحَدُكُمْ فَلْيَقُلِ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ فَإِنَّكُمْ إِذَا قُلْتُمْ ذَلِكَ أَصَابَتْ كُلَّ عَبْدٍ صَالِحٍ فِي السَّمَاءِ وَالأَرْضِ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ثُمَّ لْيَتَخَيَّرْ مِنَ الدُّعَاءِ بَعْدُ أَعْجَبَهُ إِلَيْهِ يَدْعُو بِهِ ‏"‏ ‏.‏\hadithno{1298}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"When we sat during the prayer with the Messenger of Allah (ﷺ), we used to say: 'Peace (salam) be upon Allah(SWT), peace be upon so-and-so and so-and-so.' The Messenger of Allah (ﷺ) said: 'Do not say peace (salam) be upon Allah (SWT), for Allah (SWT) is As-Salam (the Source of peace; the One free from all faults). Rather say: At-tahiyyatu lillahi wasalawatu wat-tayibaat, as-salamu 'alaika ayah-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina a 'ala ibad illahis-salihin (All compliments, prayers and pure words are due to Allah. Peace be upon you O Prophet, and the mercy of Allah and His blessings. Peace be upon us and upon the righteous slaves of Allah.) If you say that, it will be for every righteous slave in the heavens and on earth, "ashadu an la ilaha ill Allah, wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (I bear witness that that none has the right to be worshipped except Allah, and I bear witness that Muhammad is His slave and messenger.) Then let him choose any supplication that he likes to say after that}}
\hadithdefcmd{nasai}{1299}{أَخْبَرَنَا عُبَيْدُ بْنُ وَكِيعِ بْنِ الْجَرَّاحِ، أَخُو سُفْيَانَ بْنِ وَكِيعٍ قَالَ حَدَّثَنَا أَبِي، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَاءَتْ أُمُّ سُلَيْمٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ عَلِّمْنِي كَلِمَاتٍ أَدْعُو بِهِنَّ فِي صَلاَتِي ‏.‏ قَالَ ‏ "‏ سَبِّحِي اللَّهَ عَشْرًا وَاحْمَدِيهِ عَشْرًا وَكَبِّرِيهِ عَشْرًا ثُمَّ سَلِيهِ حَاجَتَكِ يَقُلْ نَعَمْ نَعَمْ ‏"‏ ‏.‏\hadithno{1299}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"Umm Sulaim came to the Prophet (ﷺ) and said: 'O Messenger of Allah (ﷺ), teach me some words that I may supplicate with during my prayer.' He said: 'Glorify Allah (by saying SubhanAllah) ten times, and praise Him (by saying Alhamdulilah) ten times, and magnify Him (by saying Allahu Akbar) ten times, then ask Him for what you need; He will say: 'Yes, yes}}
\hadithdefcmd{nasai}{1300}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا خَلَفُ بْنُ خَلِيفَةَ، عَنْ حَفْصِ بْنِ أَخِي، أَنَسٍ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم جَالِسًا - يَعْنِي - وَرَجُلٌ قَائِمٌ يُصَلِّي فَلَمَّا رَكَعَ وَسَجَدَ وَتَشَهَّدَ دَعَا فَقَالَ فِي دُعَائِهِ اللَّهُمَّ إِنِّي أَسْأَلُكَ بِأَنَّ لَكَ الْحَمْدَ لاَ إِلَهَ إِلاَّ أَنْتَ الْمَنَّانُ بَدِيعُ السَّمَوَاتِ وَالأَرْضِ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ يَا حَىُّ يَا قَيُّومُ إِنِّي أَسْأَلُكَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ تَدْرُونَ بِمَا دَعَا ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ دَعَا اللَّهَ بِاسْمِهِ الْعَظِيمِ الَّذِي إِذَا دُعِيَ بِهِ أَجَابَ وَإِذَا سُئِلَ بِهِ أَعْطَى ‏"‏ ‏.‏\hadithno{1300}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"I was sitting with the Messenger of Allah (ﷺ) and a man was standing and praying. When he bowed, prostrated and recited the tashahhud, he supplicated, and in his supplication he said: "Allahumma inni as'aluka bi-anna lakal-hamd, lailaha illa ant, al-mannanu badi'us-samawati wal-ard, ya dhal-jalali wal-ikram! Ya hayyu ya qayyum! Inni as'aluka. (O Allah, indeed I ask You since all praise is due to You, there is none worthy of worship but You, the Bestower, the Creator of the heavens and earth, O Possessor of majesty and honor, O Ever-living, O-Eternal, I ask of You.)' The Prophet (ﷺ) said: 'Do you know what he has supplicated with?' They said: "Allah (SWT) and His Messenger know best." He said: 'By the One in Whose Hand is my soul, he called upon Allah by His greatest Name, which, if He is called by it, He responds, and if He is asked by it, He gives}}
\hadithdefcmd{nasai}{1301}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ أَبُو بُرَيْدٍ الْبَصْرِيُّ، عَنْ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنِ ابْنِ بُرَيْدَةَ، قَالَ حَدَّثَنِي حَنْظَلَةُ بْنُ عَلِيٍّ، أَنَّ مِحْجَنَ بْنَ الأَدْرَعِ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْمَسْجِدَ إِذَا رَجُلٌ قَدْ قَضَى صَلاَتَهُ وَهُوَ يَتَشَهَّدُ فَقَالَ اللَّهُمَّ إِنِّي أَسْأَلُكَ يَا اللَّهُ بِأَنَّكَ الْوَاحِدُ الأَحَدُ الصَّمَدُ الَّذِي لَمْ يَلِدْ وَلَمْ يُولَدْ وَلَمْ يَكُنْ لَهُ كُفُوًا أَحَدٌ أَنْ تَغْفِرَ لِي ذُنُوبِي إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ غُفِرَ لَهُ ‏"‏ ‏.‏ ثَلاَثًا ‏.‏\hadithno{1301}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hanzalah bin 'Ali narrated that:Mihjan bin Al-Adra' narrated to him that the Messenger of Allah (ﷺ) entered the masjid and there was a man who had finished his prayer and he was reciting the tashahhud. He said: "Allahumma inni as'aluka ya Allah! Bi-annakal-Wahidul-Ahad us-Samad, alladhi lam yalid wa lam yowled, wa lam yakun lahu kufuwan ahad, an taghfirali dhunubi, innaka antal-Ghafurur-Rahim (O Allah, I ask of You, O Allah, as You are the One, the Only, the Self-Sufficient Master, Who begets not nor was He begotten, and there is None equal or comparable to Him, forgive me my sins, for You are the Oft-Forgiving, Most Merciful.)" The Messenger of Allah (ﷺ) said: "He has been forgiven," three times}}
\hadithdefcmd{nasai}{1302}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، - رضى الله عنهما أَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم عَلِّمْنِي دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي ‏.‏ قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي ظَلَمْتُ نَفْسِي ظُلْمًا كَثِيرًا وَلاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ فَاغْفِرْ لِي مَغْفِرَةً مِنْ عِنْدِكَ وَارْحَمْنِي إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏ ‏.‏\hadithno{1302}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Amr, from Abu Bakr As-Siddiq, may Allah (SWT) be pleased with them both, that he said to the Messenger of Allah (ﷺ):"Teach me a supplication that I may recite in my prayer." He said: "Say: 'Alahumma inni zalamtu afsi zulman kathiran wa la yaghfirudhunub illa anta faghfirli maghfiratan min 'indika warhamni innaka antalGhafurur-Rahim (O Allah, verily I have wronged myself much and there is None who forgives sins except You. Grant me forgiveness from You and have mercy on me for You are the Oft-Forgiving, Most Merciful)}}
\hadithdefcmd{nasai}{1303}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ سَمِعْتُ حَيْوَةَ، يُحَدِّثُ عَنْ عُقْبَةَ بْنِ مُسْلِمٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنِ الصُّنَابِحِيِّ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ أَخَذَ بِيَدِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنِّي لأُحِبُّكَ يَا مُعَاذُ ‏"‏ ‏.‏ فَقُلْتُ وَأَنَا أُحِبُّكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلاَ تَدَعْ أَنْ تَقُولَ فِي كُلِّ صَلاَةٍ رَبِّ أَعِنِّي عَلَى ذِكْرِكَ وَشُكْرِكَ وَحُسْنِ عِبَادَتِكَ ‏"‏ ‏.‏\hadithno{1303}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mu'adhbin Jabal said:"The Messenger of Allah (ﷺ) took my hand and said: 'I love you, O Mu'adh!' I said: 'And I love you, O Messenger of Allah (ﷺ).' Then the Messenger of Allah (ﷺ) said: 'Never forget to say in every prayer: Rabbi a'inni 'ala dhikrika wa shukrika wa husni 'ibadatik (My Lord, help me to remember You, give thanks to You and worship You well)}}
\hadithdefcmd{nasai}{1304}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي الْعَلاَءِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ فِي صَلاَتِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ الثَّبَاتَ فِي الأَمْرِ وَالْعَزِيمَةِ عَلَى الرُّشْدِ وَأَسْأَلُكَ شُكْرَ نِعْمَتِكَ وَحُسْنَ عِبَادَتِكَ وَأَسْأَلُكَ قَلْبًا سَلِيمًا وَلِسَانًا صَادِقًا وَأَسْأَلُكَ مِنْ خَيْرِ مَا تَعْلَمُ وَأَعُوذُ بِكَ مِنْ شَرِّ مَا تَعْلَمُ وَأَسْتَغْفِرُكَ لِمَا تَعْلَمُ ‏"‏ ‏.‏\hadithno{1304}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Shadad bin Aws that:The Messenger of Allah (ﷺ) used to say in his prayer: "Allahumma inni as'aluka at-thabbuta fi al-amr wal-'azimata 'alar-rushdi wa as'aluka shukr ni'matik wa husna 'ibadatik wa as'aluka qalban saliman wa lisanan sadiqan wa as'aluka min khairi ma at'lamu wa author bika min sharri ma at'lamu wastaghfiruka lima ta'lam (O Allah, I ask You for steadfastness in all my affairs and determination in following the right path, I ask You to make me thankful for Your blessings and to make me worship You properly. I ask You for a sound heart and a truthful tongue. I ask You for the best of what You know and I seek refuge in You from the worst of what You know and I seek Your forgiveness for what You know)}}
\hadithdefcmd{nasai}{1305}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِيهِ، قَالَ صَلَّى بِنَا عَمَّارُ بْنُ يَاسِرٍ صَلاَةً فَأَوْجَزَ فِيهَا فَقَالَ لَهُ بَعْضُ الْقَوْمِ لَقَدْ خَفَّفْتَ أَوْ أَوْجَزْتَ الصَّلاَةَ ‏.‏ فَقَالَ أَمَّا عَلَى ذَلِكَ فَقَدْ دَعَوْتُ فِيهَا بِدَعَوَاتٍ سَمِعْتُهُنَّ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا قَامَ تَبِعَهُ رَجُلٌ مِنَ الْقَوْمِ هُوَ أَبِي غَيْرَ أَنَّهُ كَنَى عَنْ نَفْسِهِ فَسَأَلَهُ عَنِ الدُّعَاءِ ثُمَّ جَاءَ فَأَخْبَرَ بِهِ الْقَوْمَ ‏ "‏ اللَّهُمَّ بِعِلْمِكَ الْغَيْبَ وَقُدْرَتِكَ عَلَى الْخَلْقِ أَحْيِنِي مَا عَلِمْتَ الْحَيَاةَ خَيْرًا لِي وَتَوَفَّنِي إِذَا عَلِمْتَ الْوَفَاةَ خَيْرًا لِي اللَّهُمَّ وَأَسْأَلُكَ خَشْيَتَكَ فِي الْغَيْبِ وَالشَّهَادَةِ وَأَسْأَلُكَ كَلِمَةَ الْحَقِّ فِي الرِّضَا وَالْغَضَبِ وَأَسْأَلُكَ الْقَصْدَ فِي الْفَقْرِ وَالْغِنَى وَأَسْأَلُكَ نَعِيمًا لاَ يَنْفَدُ وَأَسْأَلُكَ قُرَّةَ عَيْنٍ لاَ تَنْقَطِعُ وَأَسْأَلُكَ الرِّضَاءَ بَعْدَ الْقَضَاءِ وَأَسْأَلُكَ بَرْدَ الْعَيْشِ بَعْدَ الْمَوْتِ وَأَسْأَلُكَ لَذَّةَ النَّظَرِ إِلَى وَجْهِكَ وَالشَّوْقَ إِلَى لِقَائِكَ فِي غَيْرِ ضَرَّاءَ مُضِرَّةٍ وَلاَ فِتْنَةٍ مُضِلَّةٍ اللَّهُمَّ زَيِّنَّا بِزِينَةِ الإِيمَانِ وَاجْعَلْنَا هُدَاةً مُهْتَدِينَ ‏"‏ ‏.‏\hadithno{1305}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ata bn As-Sa'ib narrated that his father said:"Ammar bin Yasir led us in prayer and he made it brief. Some of the people said to him: 'You made the prayer sort (or brief).' He said: 'Nevertheless I still recited supplications that I heard from the Messenger of Allah (ﷺ).' When he got up and left, a man -- he was my father but he did not name himself -- followed him and asked him about that supplication, then he came and told the people: "Allāhumma bi `ilmikal-ghaiba wa qudratika 'alal-khalqi aḥyinī mā `alimtal-ḥayāta khairan lī, wa tawaffanī idhā `alimtal-wafāta khairan lī. Allāhumma wa 'as'aluka khashyataka fil-ghaibi wash-shahādati wa 'as'aluka kalimatal-ḥaqqi fir-riḍā'i wal ghaḍab, wa as'alukal-qaṣda fil faqri wal-ghina, wa 'as'aluka na`īman lā yanfadu wa 'as'aluka qurrata `ainin lā tanqaṭi`u wa as'alukar-riḍā'i ba`dal-qaḍā'i wa 'as'aluka bardal `aishi ba`dal-mawti, wa 'as'aluka ladhdhatan-naẓari ilā wajhika wash-shawqa ilā liqā'ika fī ghairi ḍarrā'a muḍirratin wa lā fitnatin muḍillatin, Allāhumma zayyinnā bizīnatil-īmāni waj`alna hudātan muhtadīn (O Allah, by Your knowledge of the unseen and Your power over creation, keep me alive so long as You know that living is good for me and cause me to die when You know that death is better for me. O Allah, cause me to fear You in secret and in public. I ask You to make me true in speech in times of pleasure and of anger. I ask You to make me moderate in times of wealth and poverty. And I ask You for everlasting delight and joy that will never cease. I ask You to make me pleased with that which You have decreed and for an easy life after death. I askYou for the sweetness of looking upon Your face and a longing to meet You in a manner that does not entail a calamity that will bring about harm or a trial that will cause deviation. O Allah, beautify us with the adornment of faith and make us among those who guide and are rightly guided)}}
\hadithdefcmd{nasai}{1306}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي هَاشِمٍ الْوَاسِطِيِّ، عَنْ أَبِي مِجْلَزٍ، عَنْ قَيْسِ بْنِ عُبَادٍ، قَالَ صَلَّى عَمَّارُ بْنُ يَاسِرٍ بِالْقَوْمِ صَلاَةً أَخَفَّهَا فَكَأَنَّهُمْ أَنْكَرُوهَا فَقَالَ أَلَمْ أُتِمَّ الرُّكُوعَ وَالسُّجُودَ قَالُوا بَلَى ‏.‏ قَالَ أَمَّا إِنِّي دَعَوْتُ فِيهَا بِدُعَاءٍ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْعُو بِهِ ‏ "‏ اللَّهُمَّ بِعِلْمِكَ الْغَيْبَ وَقُدْرَتِكَ عَلَى الْخَلْقِ أَحْيِنِي مَا عَلِمْتَ الْحَيَاةَ خَيْرًا لِي وَتَوَفَّنِي إِذَا عَلِمْتَ الْوَفَاةَ خَيْرًا لِي وَأَسْأَلُكَ خَشْيَتَكَ فِي الْغَيْبِ وَالشَّهَادَةِ وَكَلِمَةَ الإِخْلاَصِ فِي الرِّضَا وَالْغَضَبِ وَأَسْأَلُكَ نَعِيمًا لاَ يَنْفَدُ وَقُرَّةَ عَيْنٍ لاَ تَنْقَطِعُ وَأَسْأَلُكَ الرِّضَاءَ بِالْقَضَاءِ وَبَرْدَ الْعَيْشِ بَعْدَ الْمَوْتِ وَلَذَّةَ النَّظَرِ إِلَى وَجْهِكَ وَالشَّوْقَ إِلَى لِقَائِكَ وَأَعُوذُ بِكَ مِنْ ضَرَّاءَ مُضِرَّةٍ وَفِتْنَةٍ مُضِلَّةٍ اللَّهُمَّ زَيِّنَّا بِزِينَةِ الإِيمَانِ وَاجْعَلْنَا هُدَاةً مُهْتَدِينَ ‏"‏ ‏.‏\hadithno{1306}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qais bin 'Ubad said:"Ammar bin Yasir led the people in prayer and he made the prayer short. It was as if they disliked that, so he said: 'Did I not do bowing and prostration properly?' They said: 'Yes.' He said: 'And I said a supplication that the Prophet (ﷺ) used to say:Allahumma bi 'ilmikal-ghaiba wa qudratika 'alal-khalqi ahini ma 'alimtal-hayata khairan li, wa tawaffani idha 'alimtal-wafata khairan li. Allahumma as'aluka khashyataka fil-ghaibi wash-shahadati wa as'aluka kalimatul-aqua fir-rida'i wal ghadab, wa as'alukal-qasda fil faqr wal-ghina, wa as'aluka na'iman la yanfadu wa as'aluka qurrata ainan la tanqati'u wa as'alukar-rida'i ba'dal-qada'i wa as'aluka bardal 'aishi ba'dal-mawti, wa as'aluka ladhatan-nazari ila wajhika wash-shawqa ila liqa'ika fi fitnatin mudillatin, Allahumma zayyina dizinatil-imani waj'alna hudatan muhtadin (O Allah, by Your knowledge of the unseen and Your power over creation, keep me alive so long as You know that living is good for me and cause me to die when You know that death is better for me. O Allah, cause me to fear You in secret and in public. I ask You to make me true in speech in times of pleasure and of anger. I ask You to make me moderate in times of wealth and poverty. And I ask You for everlasting delight and joy that will never cease. I ask You to make me pleased with that which You have decreed and for an easy life after death. I ask You for the sweetness of looking upon Your face and a longing to meet You in a manner that does not entail a calamity that will bring about harm or a trial that will cause deviation. O Allah, beautify us with the adornment of faith and make us among those who guide and are rightly guided)}}
\hadithdefcmd{nasai}{1307}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، قَالَ قُلْتُ لِعَائِشَةَ حَدِّثِينِي بِشَىْءٍ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهِ فِي صَلاَتِهِ ‏.‏ فَقَالَتْ نَعَمْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{1307}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Farwah bin Nawfal said:"I said to 'Aishah: 'Tell me of a supplication that the Messenger of Allah (ﷺ) used to say in his prayer.' She said: 'Yes. The Messenger of Allah (ﷺ) used to say: Allahumma inni author bika min sharri ma 'amiltu wa min sharri ma lam a'mal (O Allah, I seek refuge with You from the evil of that which I have done, and the evil of that which I have not done)}}
\hadithdefcmd{nasai}{1308}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ عَذَابِ الْقَبْرِ فَقَالَ ‏ "‏ نَعَمْ عَذَابُ الْقَبْرِ حَقٌّ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي صَلاَةً بَعْدُ إِلاَّ تَعَوَّذَ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{1308}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"I asked the Messenger of Allah (ﷺ) about the torment of the grave, and he siad: 'Yes, the torment of the grave is real.'" 'Aishah said: "After that I never saw the Messenger of Allah (ﷺ) offer any prayer but he would seek refuge with Allah (SWT) from the torment of the grave}}
\hadithdefcmd{nasai}{1309}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا أَبِي، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو فِي الصَّلاَةِ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْمَأْثَمِ وَالْمَغْرَمِ ‏"‏ ‏.‏ فَقَالَ لَهُ قَائِلٌ مَا أَكْثَرَ مَا تَسْتَعِيذُ مِنَ الْمَغْرَمِ فَقَالَ ‏"‏ إِنَّ الرَّجُلَ إِذَا غَرِمَ حَدَّثَ فَكَذَبَ وَوَعَدَ فَأَخْلَفَ ‏"‏ ‏.‏\hadithno{1309}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Urwah bin Az-Zbair narrated that:Aishah told him that the Messenger of Allah (ﷺ) used to say the following supplication in his prayer: Allahumma inni audhu bika min 'adhab ilqabri wa 'audhu bika min fitnatil-masihid-dajjal, wa 'audhu bika min fitnatil-mahya walmamati, Allahumma inni 'audhu bika min al-ma'thami wal-maghram ( O Allah, I seek refuge with You from the torment of the grave, and I seek refuge in You from the tribulation of the Al-Masihid-Dajjal, and I seek refuge with You from the trials of life and death. O Allah, I seek refuge in You from sin and debt.) Someone said to him: "How often you seek refuge from debt!" He said: "If a man gets into debt, when he speaks lies, and when he makes a promise, he betrays it}}
\hadithdefcmd{nasai}{1310}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ الْمَوْصِلِيُّ، عَنِ الْمُعَافَى، عَنِ الأَوْزَاعِيِّ، ح وَأَنْبَأَنَا عَلِيُّ بْنُ خَشْرَمٍ، عَنْ عِيسَى بْنِ يُونُسَ، - وَاللَّفْظُ لَهُ - عَنِ الأَوْزَاعِيِّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ مُحَمَّدِ بْنِ أَبِي عَائِشَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَشَهَّدَ أَحَدُكُمْ فَلْيَتَعَوَّذْ بِاللَّهِ مِنْ أَرْبَعٍ مِنْ عَذَابِ جَهَنَّمَ وَعَذَابِ الْقَبْرِ وَفِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَمِنْ شَرِّ الْمَسِيحِ الدَّجَّالِ ثُمَّ يَدْعُو لِنَفْسِهِ بِمَا بَدَا لَهُ ‏"‏ ‏.‏\hadithno{1310}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Muhammad bin Abi 'Aishah said:"I heard Abu Hurairah say: 'The Messenger of Allah (ﷺ) said: When one of you recites the tashahhud, let him seek refuge with Allah (SWT) from our things: From the torment of hell, from the torment of the grave, from the trials of life and death and from the evils of the Dajjal. Then let him pray for himself asking whatever he wants}}
\hadithdefcmd{nasai}{1311}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ فِي صَلاَتِهِ بَعْدَ التَّشَهُّدِ ‏ "‏ أَحْسَنُ الْكَلاَمِ كَلاَمُ اللَّهِ وَأَحْسَنُ الْهَدْىِ هَدْىُ مُحَمَّدٍ صلى الله عليه وسلم ‏"‏ ‏.‏\hadithno{1311}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir that:The Messenger of Allah (ﷺ) used to say in his prayer, after the tashahhud: "The best of word is the word of Allah (SWT) and the best of guidance is the guidance of Muhammad (ﷺ)}}
\hadithdefcmd{nasai}{1312}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا مَالِكٌ، - وَهُوَ ابْنُ مِغْوَلٍ - عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ حُذَيْفَةَ، أَنَّهُ رَأَى رَجُلاً يُصَلِّي فَطَفَّفَ فَقَالَ لَهُ حُذَيْفَةُ مُنْذُ كَمْ تُصَلِّي هَذِهِ الصَّلاَةَ قَالَ مُنْذُ أَرْبَعِينَ عَامًا ‏.‏ قَالَ مَا صَلَّيْتُ مُنْذُ أَرْبَعِينَ سَنَةً وَلَوْ مِتَّ وَأَنْتَ تُصَلِّي هَذِهِ الصَّلاَةَ لَمِتَّ عَلَى غَيْرِ فِطْرَةِ مُحَمَّدٍ صلى الله عليه وسلم ثُمَّ قَالَ إِنَّ الرَّجُلَ لَيُخَفِّفُ وَيُتِمُّ وَيُحْسِنُ ‏.‏\hadithno{1312}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Hudhaifah that:He saw a man praying (And his bowing and prostration) were lacking. Hudhaifah said to him: 'For how long have you been praying like this?' He said: "For forty years.' He said: 'You have not been praying for forty years and if you die praying like this, you will have died following a path other than the path of Muhammad (ﷺ). Then he said: 'It is possible for a man to pray briefly, but still do it properly}}
\hadithdefcmd{nasai}{1313}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَلِيٍّ، - وَهُوَ ابْنُ يَحْيَى - عَنْ أَبِيهِ، عَنْ عَمٍّ، لَهُ بَدْرِيٍّ أَنَّهُ حَدَّثَهُ أَنَّ رَجُلاً دَخَلَ الْمَسْجِدَ فَصَلَّى وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَرْمُقُهُ وَنَحْنُ لاَ نَشْعُرُ فَلَمَّا فَرَغَ أَقْبَلَ فَسَلَّمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَرَجَعَ فَصَلَّى ثُمَّ أَقْبَلَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا ‏.‏ فَقَالَ لَهُ الرَّجُلُ وَالَّذِي أَكْرَمَكَ يَا رَسُولَ اللَّهِ لَقَدْ جَهِدْتُ فَعَلِّمْنِي فَقَالَ ‏"‏ إِذَا قُمْتَ تُرِيدُ الصَّلاَةَ فَتَوَضَّأْ فَأَحْسِنْ وُضُوءَكَ ثُمَّ اسْتَقْبِلِ الْقِبْلَةَ فَكَبِّرْ ثُمَّ اقْرَأْ ثُمَّ ارْكَعْ فَاطْمَئِنَّ رَاكِعًا ثُمَّ ارْفَعْ حَتَّى تَعْتَدِلَ قَائِمًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ قَاعِدًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا ثُمَّ ارْفَعْ ثُمَّ افْعَلْ كَذَلِكَ حَتَّى تَفْرُغَ مِنْ صَلاَتِكَ ‏"‏ ‏.‏\hadithno{1313}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ali- who is bin Yahya- from his father that:A paternal uncle of his who was present at Badr told him, that a man entered the masjid and prayed, and the Messenger of Allah (ﷺ) was watching, but we did not realize. When he had finished, he came and greeted the Messenger of Allah (ﷺ) with salam. He said: "Go back and pray, for you have not prayed." So he went back and prayed, then he came to the Messenger of Allah (ﷺ) and he said: "Go back and pray, for you have not prayed." (This happened) two or three times. Then the man said to him: "By the One who has honored you , O Messenger of Allah (ﷺ), I have tried my best; teach me." He said: "When you get up to pray, perform wudu and do it well, then turn to face the Qiblah and say the takbir. Then recite the Quran, then bow until you are at ease in bowing. Then stand up until you are standing straight, then prostrate until you are at ease prostrating, then sit up until you are at ease sitting, then prostrate until you are at ease prostrating, then get up, and continue doing that until you have finished your prayer}}
\hadithdefcmd{nasai}{1314}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ دَاوُدَ بْنِ قَيْسٍ، قَالَ حَدَّثَنِي عَلِيُّ بْنُ يَحْيَى بْنِ خَلاَّدِ بْنِ رَافِعِ بْنِ مَالِكٍ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَمٍّ، لَهُ بَدْرِيٍّ قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم جَالِسًا فِي الْمَسْجِدِ فَدَخَلَ رَجُلٌ فَصَلَّى رَكْعَتَيْنِ ثُمَّ جَاءَ فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَقَدْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَرْمُقُهُ فِي صَلاَتِهِ فَرَدَّ عَلَيْهِ السَّلاَمَ ثُمَّ قَالَ لَهُ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَرَجَعَ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَرَدَّ عَلَيْهِ السَّلاَمَ ثُمَّ قَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ حَتَّى كَانَ عِنْدَ الثَّالِثَةِ أَوِ الرَّابِعَةِ فَقَالَ وَالَّذِي أَنْزَلَ عَلَيْكَ الْكِتَابَ لَقَدْ جَهِدْتُ وَحَرَصْتُ فَأَرِنِي وَعَلِّمْنِي ‏.‏ قَالَ ‏"‏ إِذَا أَرَدْتَ أَنْ تُصَلِّيَ فَتَوَضَّأْ فَأَحْسِنْ وُضُوءَكَ ثُمَّ اسْتَقْبِلِ الْقِبْلَةَ فَكَبِّرْ ثُمَّ اقْرَأْ ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا ثُمَّ ارْفَعْ حَتَّى تَعْتَدِلَ قَائِمًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ قَاعِدًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا ثُمَّ ارْفَعْ فَإِذَا أَتْمَمْتَ صَلاَتَكَ عَلَى هَذَا فَقَدْ تَمَّتْ وَمَا انْتَقَصْتَ مِنْ هَذَا فَإِنَّمَا تَنْتَقِصُهُ مِنْ صَلاَتِكَ ‏"‏ ‏.‏\hadithno{1314}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali bin Yahya bin Khallad bin Raf' bin Malik Al-Ansari said:"My father narrated to me that a paternal uncle of his, who had been at Badr, said: 'I was sitting with the Messenger of Allah (ﷺ) in the masjid when a man came in and prayed two rak'ahs, then he came and greeted the Prophet (ﷺ) with salam. The Prophet (ﷺ) had been watching him as he prayed, so he returned his salam, then he said: "Go back and pray, for you have not prayed." So he went back and prayed, then he came back and greeted the Prophet (ﷺ) with salam. He returned the salam, then he said: "Go back and pray, for you have not prayed." The third or fourth time this happened, then the man said: "By the One Who revealed the Book to you, I have done my best and have tried hard; show me and teach me." He said: 'When you want to pray, perform wudu and do it well, then turn to face the Qiblah and say the takbir. Then recite the Quran, then bow until you are at ease in bowing. Then stand up until you are standing straight, then prostrate until you are at ease prostrating, then sit up until you are at ease sitting, then prostrate until you are at ease prostrating, then get up. If you complete the prayer in this manner you wil hve done it properly, and whatever you do less than this is lacking from you prayer}}
\hadithdefcmd{nasai}{1315}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، قَالَ قُلْتُ يَا أُمَّ الْمُؤْمِنِينَ أَنْبِئِينِي عَنْ وَتْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ كُنَّا نُعِدُّ لَهُ سِوَاكَهُ وَطُهُورَهُ فَيَبْعَثُهُ اللَّهُ لِمَا شَاءَ أَنْ يَبْعَثَهُ مِنَ اللَّيْلِ فَيَتَسَوَّكُ وَيَتَوَضَّأُ وَيُصَلِّي ثَمَانِ رَكَعَاتٍ لاَ يَجْلِسُ فِيهِنَّ إِلاَّ عِنْدَ الثَّامِنَةِ فَيَجْلِسُ فَيَذْكُرُ اللَّهَ عَزَّ وَجَلَّ وَيَدْعُو ثُمَّ يُسَلِّمُ تَسْلِيمًا يُسْمِعُنَا ‏.‏\hadithno{1315}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'd bin Hisham said:"I said: 'O Mother of the believers! Tell me about the Witr of the Messenger of Allah (ﷺ).' She said: 'We used to prepare his siwak and water for purification, then Allah (SWT) would wake him when He willed to wake him at night. He would use the siwak and perform wudu, then pray eith rak'ahs; not sitting until the eighth rak'ah, when he would sit and remember Allah (SWT) and call upon Him. Then he would say the taslim loud enough for us to hear}}
\hadithdefcmd{nasai}{1316}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ دَاوُدَ الْهَاشِمِيُّ - قَالَ حَدَّثَنَا إِبْرَاهِيمُ، - وَهُوَ ابْنُ سَعْدٍ - قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، - وَهُوَ ابْنُ الْمِسْوَرِ الْمَخْرَمِيُّ - عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنِي عَامِرُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ ‏.‏\hadithno{1316}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Amr bin Sa'd narrated from his father:That the Messenger of Allah (ﷺ) used to say the taslim to his right and to his left}}
\hadithdefcmd{nasai}{1317}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمَخْرَمِيُّ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، قَالَ كُنْتُ أَرَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ حَتَّى يُرَى بَيَاضُ خَدِّهِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ هَذَا لَيْسَ بِهِ بَأْسٌ وَعَبْدُ اللَّهِ بْنُ جَعْفَرِ بْنِ نَجِيحٍ وَالِدُ عَلِيِّ بْنِ الْمَدِينِيِّ مَتْرُوكُ الْحَدِيثِ ‏.‏\hadithno{1317}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Sa'd said:"I used to see the Messenger of Allah (ﷺ) saying the taslim to his right and to his left until the whiteness of his cheek could be seen}}
\hadithdefcmd{nasai}{1318}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ مِسْعَرٍ، عَنْ عُبَيْدِ اللَّهِ ابْنِ الْقِبْطِيَّةِ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ كُنَّا إِذَا صَلَّيْنَا خَلْفَ النَّبِيِّ صلى الله عليه وسلم قُلْنَا السَّلاَمُ عَلَيْكُمُ السَّلاَمُ عَلَيْكُمْ ‏.‏ وَأَشَارَ مِسْعَرٌ بِيَدِهِ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ فَقَالَ ‏ "‏ مَا بَالُ هَؤُلاَءِ الَّذِينَ يَرْمُونَ بِأَيْدِيهِمْ كَأَنَّهَا أَذْنَابُ الْخَيْلِ الشُّمُسِ أَمَا يَكْفِي أَنْ يَضَعَ يَدَهُ عَلَى فَخِذِهِ ثُمَّ يُسَلِّمُ عَلَى أَخِيهِ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ ‏"‏ ‏.‏\hadithno{1318}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ubaidullah bin Al-Qibtiyyah said:"I heard Jabir bin Samurah say: 'When we prayed behind the Prophet (ﷺ) we used to say: As-salamu 'alaykum, as-salamu 'alaykum (peace be upon you, peace be upon you)" - and Mis'ar (one of the narrators) pointed with his hand to the right and the left. He (ﷺ) said: 'What is the matter with these people who wave their hands as if they are the tails of wild horses? It is sufficient for one to place his hands on his thighs and to say the salam to his brother to his right and left}}
\hadithdefcmd{nasai}{1319}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنِ الأَسْوَدِ، وَعَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُكَبِّرُ فِي كُلِّ خَفْضٍ وَرَفْعٍ وَقِيَامٍ وَقُعُودٍ وَيُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ ‏ "‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ حَتَّى يُرَى بَيَاضُ خَدِّهِ وَرَأَيْتُ أَبَا بَكْرٍ وَعُمَرَ - رضى الله عنهما - يَفْعَلاَنِ ذَلِكَ ‏.‏\hadithno{1319}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"I saw the Messenger of Allah (ﷺ) saying the takir every time he went down or came up, or stood or sat, and he said the salam to his right and to his left: As-salamu 'alaykum wa rahmatullah, as-salamu alaykum wa rahmatullah (peace be upon you and the mercy of Allah, peace be upon you and the mercy of Allah) until the whiteness of his cheek could be seen . And I saw Abu Bakr and 'Umar, may Allah (WT) be pleased with them, doing likewise}}
\hadithdefcmd{nasai}{1320}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، عَنْ حَجَّاجٍ، قَالَ ابْنُ جُرَيْجٍ أَنْبَأَنَا عَمْرُو بْنُ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، ‏.‏ أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ عُمَرَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ اللَّهُ أَكْبَرُ كُلَّمَا وَضَعَ اللَّهُ أَكْبَرُ كُلَّمَا رَفَعَ ثُمَّ يَقُولُ ‏ "‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ عَنْ يَمِينِهِ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ عَنْ يَسَارِهِ ‏"‏ ‏.‏\hadithno{1320}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Wasi' bin Habban that:He asked 'Abdullah bin 'Umar about the prayer of the Messenger of Allah (ﷺ). He said: "Allahu Akbar" every time he went down and "Allahu Akbar" every time he came up, then he said: "As-salamu 'alaykum wa rahmatullah (peace be upon you and the mercy of Allah) to his right and: As-salamu 'alaykum wa rahmatullah (peace be upon you and the mercy of Allah) to his left}}
\hadithdefcmd{nasai}{1321}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، قَالَ قُلْتُ لاِبْنِ عُمَرَ أَخْبِرْنِي عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ كَانَتْ قَالَ فَذَكَرَ التَّكْبِيرَ قَالَ يَعْنِي وَذَكَرَ ‏"‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ" عَنْ يَمِينِهِ, "السَّلاَمُ عَلَيْكُمْ" عَنْ يَسَارِهِ."‏\hadithno{1321}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Wasi' bin Habban said:"I said to Ibn 'Umar: "Tell me about the prayer of the Messenger of Allah (ﷺ); how was it?" He mentioned the takbir and he mentioned: As-salamu 'alaykum wa rahmatullah (peace be upon you and the mercy of Allah) to his right and: As-salamu 'alaykum (peace be upon you) to his left}}
\hadithdefcmd{nasai}{1322}{أَخْبَرَنَا زَيْدُ بْنُ أَخْزَمَ، عَنِ ابْنِ دَاوُدَ، - يَعْنِي عَبْدَ اللَّهِ بْنَ دَاوُدَ الْخُرَيْبِيَّ - عَنْ عَلِيِّ بْنِ صَالِحٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ كَأَنِّي أَنْظُرُ إِلَى بَيَاضِ خَدِّهِ عَنْ يَمِينِهِ ‏"‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ وَعَنْ يَسَارِهِ ‏"‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏\hadithno{1322}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah that:The Prophet (ﷺ) said: "It is as if I can see the whiteness of his cheek, saying to his right: As-salamu 'alaykum wa rahmatullah (peace be upon you and the mercy of Allah) and to his left: As-salamu 'alaykum wa rahmatullah (peace be upon you and the mercy of Allah)." (Sahih)}}
\hadithdefcmd{nasai}{1323}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ عُمَرَ بْنِ عُبَيْدٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسَلِّمُ عَنْ يَمِينِهِ حَتَّى يَبْدُوَ بَيَاضُ خَدِّهِ وَعَنْ يَسَارِهِ حَتَّى يَبْدُوَ بَيَاضُ خَدِّهِ ‏.‏\hadithno{1323}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah (ﷺ) used to say the salam to his right so that the whiteness of his cheek could be seen, and to his left so that the whiteness of his cheek could be seen}}
\hadithdefcmd{nasai}{1324}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ أَنَّهُ كَانَ يُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ ‏ "‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ حَتَّى يُرَى بَيَاضُ خَدِّهِ مِنْ هَا هُنَا وَبَيَاضُ خَدِّهِ مِنْ هَا هُنَا ‏.‏\hadithno{1324}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah that:The Prophet (ﷺ) used to say salam to his right and to his left: As-salamu 'alaykum wa rahmatullah, as-salamu alaykum wa rahmatullah (peace be upon you and the mercy of Allah, peace be upon you and the mercy of Allah) until the whiteness of his cheek could be seen from here, and the whiteness of his cheek from here}}
\hadithdefcmd{nasai}{1325}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ أَنْبَأَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، وَأَبِي الأَحْوَصِ، قَالُوا حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُسَلِّمُ عَنْ يَمِينِهِ ‏"‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ حَتَّى يُرَى بَيَاضُ خَدِّهِ الأَيْمَنِ وَعَنْ يَسَارِهِ ‏"‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ حَتَّى يُرَى بَيَاضُ خَدِّهِ الأَيْسَرِ ‏.‏\hadithno{1325}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Mas'ud narrated that:The Messenger of Allah (ﷺ) used to say salam to his right:As-salamu 'alaykum wa rahmatullah (peace be upon you and the mercy of Allah) , until the whiteness of his right cheek could be seen, and to his left: As-salamu 'alaykum wa rahmatullah (peace be upon you and the mercy of Allah) until the whiteness of his left cheek could be seen}}
\hadithdefcmd{nasai}{1326}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ فُرَاتٍ الْقَزَّازِ، عَنْ عُبَيْدِ اللَّهِ، - وَهُوَ ابْنُ الْقِبْطِيَّةِ - عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكُنَّا إِذَا سَلَّمْنَا قُلْنَا بِأَيْدِينَا السَّلاَمُ عَلَيْكُمُ السَّلاَمُ عَلَيْكُمْ - قَالَ - فَنَظَرَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَا شَأْنُكُمْ تُشِيرُونَ بِأَيْدِيكُمْ كَأَنَّهَا أَذْنَابُ خَيْلٍ شُمْسٍ إِذَا سَلَّمَ أَحَدُكُمْ فَلْيَلْتَفِتْ إِلَى صَاحِبِهِ وَلاَ يُومِئْ بِيَدِهِ ‏"‏ ‏.‏\hadithno{1326}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin Samurah said:"I prayed with the Messenger of Allah (ﷺ) and when we said the salam we used to gesture with our hands: 'Asalamu alaykum wa rahmatullah (peace be upon, peace be upon you).' The Messenger of Allah (ﷺ) looked at us and said: 'What is the matter with you, pointing with your hands as if they are the tails of wild horses? When any one of you says the salam, let him turn to his companions and not gesture with his hand}}
\hadithdefcmd{nasai}{1327}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، أَخْبَرَهُ قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ، قَالَ سَمِعْتُ عِتْبَانَ بْنَ مَالِكٍ، يَقُولُ كُنْتُ أُصَلِّي بِقَوْمِي بَنِي سَالِمٍ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنِّي قَدْ أَنْكَرْتُ بَصَرِي وَإِنَّ السُّيُولَ تَحُولُ بَيْنِي وَبَيْنَ مَسْجِدِ قَوْمِي فَلَوَدِدْتُ أَنَّكَ جِئْتَ فَصَلَّيْتَ فِي بَيْتِي مَكَانًا أَتَّخِذُهُ مَسْجِدًا ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ سَأَفْعَلُ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ فَغَدَا عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ - رضى الله عنه - مَعَهُ بَعْدَ مَا اشْتَدَّ النَّهَارُ فَاسْتَأْذَنَ النَّبِيُّ صلى الله عليه وسلم فَأَذِنْتُ لَهُ فَلَمْ يَجْلِسْ حَتَّى قَالَ ‏"‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ مِنْ بَيْتِكَ ‏"‏ ‏.‏ فَأَشَرْتُ لَهُ إِلَى الْمَكَانِ الَّذِي أُحِبُّ أَنْ يُصَلِّيَ فِيهِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَفَفْنَا خَلْفَهُ ثُمَّ سَلَّمَ وَسَلَّمْنَا حِينَ سَلَّمَ ‏.‏\hadithno{1327}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Itban bin Malik said:"I used to lead my people Bani Salim in prayer. I came to the Messenger of Allah (ﷺ) and said: 'I have lost my eyesight and the rainwater prevents me from reaching the masjid of my people. I would like you to come and pray in my house in a place that I can take as a masjid.' The Prophet (ﷺ) said: 'I will do that, if Allah (SWT) wills.' The next day, the Messenger of Allah (ﷺ) came, and Abu Bakr was with him, after the day had grown hot. The Prophet (ﷺ) asked for permission to enter, and I gave him permission. He did not sit own until he asked: 'Where would you like me to pray in your house?' I showed him the place where I wanted him to pray, so the Messenger of Allah (ﷺ) stood there and formed a row behind him, then he said the salam and we said the salam when he did}}
\hadithdefcmd{nasai}{1328}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ بْنِ حَمَّادِ بْنِ سَعْدٍ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، وَعَمْرُو بْنُ الْحَارِثِ، وَيُونُسُ بْنُ يَزِيدَ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُمْ عَنْ عُرْوَةَ، قَالَ قَالَتْ عَائِشَةُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِيمَا بَيْنَ أَنْ يَفْرُغَ مِنْ صَلاَةِ الْعِشَاءِ إِلَى الْفَجْرِ إِحْدَى عَشْرَةَ رَكْعَةً وَيُوتِرُ بِوَاحِدَةٍ وَيَسْجُدُ سَجْدَةً قَدْرَ مَا يَقْرَأُ أَحَدُكُمْ خَمْسِينَ آيَةً قَبْلَ أَنْ يَرْفَعَ رَأْسَهُ ‏.‏ وَبَعْضُهُمْ يَزِيدُ عَلَى بَعْضٍ فِي الْحَدِيثِ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{1328}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Urwah (that) Aishah said:"The Messenger of Allah (ﷺ) used to pray eleven rak'ahs, making it odd (witr) by one between the time when he finished 'Isha and dawn, and he would prostrate for as long as it takes one of you to recite fifty verses before raising his head}}
\hadithdefcmd{nasai}{1329}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ حَفْصٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَلَّمَ ثُمَّ تَكَلَّمَ ثُمَّ سَجَدَ سَجْدَتَىِ السَّهْوِ ‏.‏\hadithno{1329}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah that:The Prophet (ﷺ) said the salam, then he spoke, then he performed two prostrations of forgetfulness}}
\hadithdefcmd{nasai}{1330}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، قَالَ حَدَّثَنَا ضَمْضَمُ بْنُ جَوْسٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَىِ السَّهْوِ وَهُوَ جَالِسٌ ثُمَّ سَلَّمَ ‏.‏ قَالَ ذَكَرَهُ فِي حَدِيثِ ذِي الْيَدَيْنِ ‏.‏\hadithno{1330}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that:"The Messenger of Allah (ﷺ) said the salam then he performed two prostrations of forgetfulness while he was still sitting, then he said the salam." He said: He mentioned it in the hadith of Dhul-Yadain}}
\hadithdefcmd{nasai}{1331}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى ثَلاَثًا ثُمَّ سَلَّمَ فَقَالَ الْخِرْبَاقُ إِنَّكَ صَلَّيْتَ ثَلاَثًا ‏.‏ فَصَلَّى بِهِمُ الرَّكْعَةَ الْبَاقِيَةَ ثُمَّ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَىِ السَّهْوِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1331}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Imran bin Husain that:The Prophet (ﷺ) prayed three (rak'ahs) then said the taslim. Al-Khirbaq said: "You prayed three." So he led them in praying the remaining rak'ah, then he said the taslim, then he did the two prostrations of forgetfulness, then he said the taslim (again)}}
\hadithdefcmd{nasai}{1332}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ هِلاَلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ رَمَقْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي صَلاَتِهِ فَوَجَدْتُ قِيَامَهُ وَرَكْعَتَهُ وَاعْتِدَالَهُ بَعْدَ الرَّكْعَةِ فَسَجْدَتَهُ فَجَلْسَتَهُ بَيْنَ السَّجْدَتَيْنِ فَسَجْدَتَهُ فَجَلْسَتَهُ بَيْنَ التَّسْلِيمِ وَالاِنْصِرَافِ قَرِيبًا مِنَ السَّوَاءِ ‏.‏\hadithno{1332}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Al-Bara' bin 'Azib said:"I watched the Messenger of Allah (ﷺ) when he prayed, and I noticed that his standing, his bowing, his standing up after bowing, his prostration, his sitting between the two prostrations and his sitting between the taslim and departing were almost the same in length}}
\hadithdefcmd{nasai}{1333}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، قَالَ ابْنُ شِهَابٍ أَخْبَرَتْنِي هِنْدُ بِنْتُ الْحَارِثِ الْفِرَاسِيَّةُ، أَنَّ أُمَّ سَلَمَةَ، أَخْبَرَتْهَا أَنَّ النِّسَاءَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم كُنَّ إِذَا سَلَّمْنَ مِنَ الصَّلاَةِ قُمْنَ وَثَبَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَنْ صَلَّى مِنَ الرِّجَالِ مَا شَاءَ اللَّهُ فَإِذَا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَامَ الرِّجَالُ ‏.‏\hadithno{1333}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Hind bint Al-Harith Al-Farrasiyyah narrated that:Umm Salamah told her that during the time of the Messenger of Allah (ﷺ), when the women said the taslim at the end of the prayer, the Messenger of Allah (ﷺ) and the men who had prayed with him would stay put for as long as Allah (ﷺ) willed. Then, when the Messenger of Allah (ﷺ) got up, the men did too}}
\hadithdefcmd{nasai}{1334}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي يَعْلَى بْنُ عَطَاءٍ، عَنْ جَابِرِ بْنِ يَزِيدَ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، أَنَّهُ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الصُّبْحِ فَلَمَّا صَلَّى انْحَرَفَ ‏.‏\hadithno{1334}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin Yazid bin Al-Aswad, from his father that:He prayed subh with the Messenger of Allah (ﷺ), and when he finished praying he turned away (from the Qiblah and toward the people)}}
\hadithdefcmd{nasai}{1335}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ الْعَسْكَرِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّمَا كُنْتُ أَعْلَمُ انْقِضَاءَ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالتَّكْبِيرِ ‏.‏\hadithno{1335}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"I used to know that the prayer of the Messenger of Allah (ﷺ) ended by the takbir}}
\hadithdefcmd{nasai}{1336}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ اللَّيْثِ، عَنْ حُنَيْنِ بْنِ أَبِي حَكِيمٍ، عَنْ عُلَىِّ بْنِ رَبَاحٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَقْرَأَ الْمُعَوِّذَاتِ دُبُرَ كُلِّ صَلاَةٍ ‏.‏\hadithno{1336}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amr said:"The Messenger of Allah (ﷺ) commanded me to recite Al-Mu'awwidhat following every prayer}}
\hadithdefcmd{nasai}{1337}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنْ أَبِي عَمْرٍو الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي شَدَّادٌ أَبُو عَمَّارٍ، أَنَّ أَبَا أَسْمَاءَ الرَّحَبِيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا انْصَرَفَ مِنْ صَلاَتِهِ اسْتَغْفَرَ ثَلاَثًا وَقَالَ ‏ "‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ تَبَارَكْتَ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{1337}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thawban, the freed slave of the Messenger of Allah (ﷺ), narrated that:When he finished the prayer, the Messenger of Allah (ﷺ) would pray for forgiveness three times and say: 'Allahumma anta asalam, wa minka as-salam tabarakta ya dhal-jalali wal-ikram (O Allah, You are the source of eace (or the One free from all faults) and from You comes peace, blessed are You, O Possessor of Majesty and Honor}}
\hadithdefcmd{nasai}{1338}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، وَمُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ صُدْرَانَ، عَنْ خَالِدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَائِشَةَ، - رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَلَّمَ قَالَ ‏ "‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ تَبَارَكْتَ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{1338}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that :After saying the taslim the Messenger of Allah (ﷺ) would say: "Allahumma anta as-salam wa minka as-salam tabarakta ya dhal-jalali wal-ikram (O Allah, You are the source of eace (or the One free from all faults) and from You comes peace, blessed are You, O Possessor of Majesty and Honor}}
\hadithdefcmd{nasai}{1339}{أَخْبَرَنَا مُحَمَّدُ بْنُ شُجَاعٍ الْمَرُّوذِيُّ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ الْحَجَّاجِ بْنِ أَبِي عُثْمَانَ، قَالَ حَدَّثَنِي أَبُو الزُّبَيْرِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، يُحَدِّثُ عَلَى هَذَا الْمِنْبَرِ وَهُوَ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَلَّمَ يَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ لاَ إِلَهَ إِلاَّ اللَّهُ لاَ نَعْبُدُ إِلاَّ إِيَّاهُ أَهْلَ النِّعْمَةِ وَالْفَضْلِ وَالثَّنَاءِ الْحَسَنِ لاَ إِلَهَ إِلاَّ اللَّهُ مُخْلِصِينَ لَهُ الدِّينَ وَلَوْ كَرِهَ الْكَافِرُونَ ‏"‏ ‏.‏\hadithno{1339}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Az-Zubair said:"I heard Abdullah bin Az-Zubair speaking from the Minbar, saying: 'When the Messenger of Allah (ﷺ) said the taslim, he would say: "La Ilaha Illallah wahdahu la sharika lah, lahul-mulk wa lahul-hamd wa huwa 'ala kulli shay'in qadir, la hawla wala quwwata illa billahil-'azim; la ilaha ill-Allahu wa la nabbed illa iyyah, ahlan-ni'mati wal-fadli wath-thana'il-has an; la ilaha ill-Allah, mukhlisina lahud-dina wa law karihal-kafirun (There is none worthy of worship except Allah (SWT) alone, with no partner or associate. His is the Dominion, to Him be all praise, and He is able to do all things; there is no power and no strength except with Allah (SWT) the Almighty. There is none worthy of worship except Allah (SWT), and we worship none but Him, the source of blessing and kindness and the One Who is deserving of all good praise. There is none worthy of worship except Allah (SWT), and we are sincere in faith and devotion to Him even though the disbelievers detest it}}
\hadithdefcmd{nasai}{1340}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدَةُ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِي الزُّبَيْرِ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ يُهَلِّلُ فِي دُبُرِ الصَّلاَةِ يَقُولُ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ لاَ إِلَهَ إِلاَّ اللَّهُ وَلاَ نَعْبُدُ إِلاَّ إِيَّاهُ لَهُ النِّعْمَةُ وَلَهُ الْفَضْلُ وَلَهُ الثَّنَاءُ الْحَسَنُ لاَ إِلَهَ إِلاَّ اللَّهُ مُخْلِصِينَ لَهُ الدِّينَ وَلَوْ كَرِهَ الْكَافِرُونَ ‏.‏ ثُمَّ يَقُولُ ابْنُ الزُّبَيْرِ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُهَلِّلُ بِهِنَّ فِي دُبُرِ الصَّلاَةِ ‏.‏\hadithno{1340}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Az-Zubair said:"Abdullah bin Az-Zubair used to recite the tahlil following every prayer, saying: 'La Ilaha Illallah wahdahu la sharika lah, lahul-mulk wa lahul-hamd wa huwa 'ala kulli shay'in qadir, la hawla wala quwwata illa billahil-'azim; la ilaha ill-Allahu wa la nabbed illa iyyah, ahlan-ni'mati wal-fadli wath-thana'il-has an; la ilaha ill-Allah, mukhlisina lahud-dina wa law karihal-kafirun (There is none worthy of worship except Allah (SWT) alone, with no partner or associate. His is the Dominion, to Him be all praise, and He is able to do all things; there is no power and no strength except with Allah (SWT) the Almighty. There is none worthy of worship except Allah (SWT), and we worship none but Him, the source of blessing and kindness and the One Who is deserving of all good praise. There is none worthy of worship except Allah (SWT), and we are sincere in faith and devotion to Him even though the disbelievers detest it. ) Then Ibn Az-Zubair said: 'The Messenger of Allah (ﷺ) used to recite the tahlil in this manner following every prayer}}
\hadithdefcmd{nasai}{1341}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ سَمِعْتُهُ مِنْ، عَبْدَةَ بْنِ أَبِي لُبَابَةَ وَسَمِعْتُهُ مِنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، كِلاَهُمَا سَمِعَهُ مِنْ، وَرَّادٍ، كَاتِبِ الْمُغِيرَةِ بْنِ شُعْبَةَ قَالَ كَتَبَ مُعَاوِيَةُ إِلَى الْمُغِيرَةِ بْنِ شُعْبَةَ أَخْبِرْنِي بِشَىْءٍ، سَمِعْتَهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَضَى الصَّلاَةَ قَالَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏\hadithno{1341}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Warrad, the scribe of Al-Mughirah bin Shu'bah, said:Muawiyah wrote to Al-Mughirah bin Shu'bah saying: "Tell me of something that you heard from the Messenger of Allah (ﷺ)." He said: "When the Messenger of Allah (ﷺ) finished praying, he would say: La Ilaha Illallah wahdahu la sharika lah, lahul-mulk wa lahul-hamd wa huwa 'ala kulli shay'in qadir. Allahumma la mani' lima a'taita wa la mu'tia lima mana'ta wa la yanfa'u dhal-jaddi minka al-jadd. (There is none worthy of worship except Allah (ﷺ) alone with no partner or associate. He is the Dominion and to Him be all praise, and He is able to do all things. O Allah, one can withhold what You have given and none can give what You have withheld, and no wealth or fortune can benefit anyone for from You comes all wealth and fortune}}
\hadithdefcmd{nasai}{1342}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْمُسَيَّبِ أَبِي الْعَلاَءِ، عَنْ وَرَّادٍ، قَالَ كَتَبَ الْمُغِيرَةُ بْنُ شُعْبَةَ إِلَى مُعَاوِيَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ دُبُرَ الصَّلاَةِ إِذَا سَلَّمَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏\hadithno{1342}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Warrad said:"Al-Mughirah bin Shu'bah wrote to Mu'awiyah (Saying) that the Messenger of Allah (ﷺ) used to say following every prayer, after the taslim: 'La Ilaha Illallah wahdahu la sharika lah, lahul-mulk wa lahul-hamd wa huwa 'ala kulli shay'in qadir. Allahumma la mani' lima a'taita wa la mu'tia lima mana'ta wa la yanfa'u dhal-jaddi minka al-jadd. (There is none worthy of worship except Allah (ﷺ) alone with no partner or associate. He is the Dominion and to Him be all praise, and He is able to do all things. O Allah, one can withhold what You have given and none can give what You have withheld, and no wealth or fortune can benefit anyone for from You comes all wealth and fortune}}
\hadithdefcmd{nasai}{1343}{أَخْبَرَنَا الْحَسَنُ بْنُ إِسْمَاعِيلُ الْمُجَالِدِيُّ، قَالَ أَنْبَأَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا الْمُغِيرَةُ، وَذَكَرَ، آخَرَ ح وَأَنْبَأَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا غَيْرُ، وَاحِدٍ، مِنْهُمُ الْمُغِيرَةُ عَنِ الشَّعْبِيِّ، عَنْ وَرَّادٍ، كَاتِبِ الْمُغِيرَةِ أَنَّ مُعَاوِيَةَ، كَتَبَ إِلَى الْمُغِيرَةِ أَنِ اكْتُبْ إِلَىَّ بِحَدِيثٍ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَكَتَبَ إِلَيْهِ الْمُغِيرَةُ إِنِّي سَمِعْتُهُ يَقُولُ عِنْدَ انْصِرَافِهِ مِنَ الصَّلاَةِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{1343}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Warrad that:Mu'awiyah wrote to Al-Mughirah asking him to write him a hadith that he had heard from the Messenger of Allah (ﷺ). Al-Mughirah wrote to him (Saying): "I heard him say, when he finished the prayer: 'La Ilaha Illallah wahdahu la sharika lah, lahul-mulk wa lahul-hamd wa huwa 'ala kulli shay'in qadir (There is none worthy of worship except Allah (ﷺ) alone with no partner or associate. He is the Dominion and to Him be all praise, and He is able to do all things) three times}}
\hadithdefcmd{nasai}{1344}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الصَّاغَانِيُّ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ الْخُزَاعِيُّ، مَنْصُورُ بْنُ سَلَمَةَ قَالَ حَدَّثَنَا خَلاَّدُ بْنُ سُلَيْمَانَ، - قَالَ أَبُو سَلَمَةَ وَكَانَ مِنَ الْخَائِفِينَ - عَنْ خَالِدِ بْنِ أَبِي عِمْرَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا جَلَسَ مَجْلِسًا أَوْ صَلَّى تَكَلَّمَ بِكَلِمَاتٍ فَسَأَلَتْهُ عَائِشَةُ عَنِ الْكَلِمَاتِ فَقَالَ ‏ "‏ إِنْ تَكَلَّمَ بِخَيْرٍ كَانَ طَابِعًا عَلَيْهِنَّ إِلَى يَوْمِ الْقِيَامَةِ وَإِنْ تَكَلَّمَ بِغَيْرِ ذَلِكَ كَانَ كَفَّارَةً لَهُ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏"‏ ‏.‏\hadithno{1344}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Aishah that:When the Messenger of Allah (ﷺ) sat in a gathering or prayed, he said some words, and 'Aishah asked him about those words. He said: "If he has spoken some good words (and he says this statement of remembrance), it will be a seal for them to preserve them until the Day of Resurrection, and if he has said something other than that, it (these words) will be an expiation for him: 'Subhanak Allahumma wa bihamdika, astaghfiruka wa atubu ilayk (Glory and praise be to You, O Allah, I seek Your forgiveness and I repent to You)}}
\hadithdefcmd{nasai}{1345}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا قُدَامَةُ، عَنْ جَسْرَةَ، قَالَتْ حَدَّثَتْنِي عَائِشَةُ، - رضى الله عنها - قَالَتْ دَخَلَتْ عَلَىَّ امْرَأَةٌ مِنَ الْيَهُودِ فَقَالَتْ إِنَّ عَذَابَ الْقَبْرِ مِنَ الْبَوْلِ ‏.‏ فَقُلْتُ كَذَبْتِ ‏.‏ فَقَالَتْ بَلَى إِنَّا لَنَقْرِضُ مِنْهُ الْجِلْدَ وَالثَّوْبَ ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الصَّلاَةِ وَقَدِ ارْتَفَعَتْ أَصْوَاتُنَا فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَأَخْبَرْتُهُ بِمَا قَالَتْ فَقَالَ ‏"‏ صَدَقَتْ ‏"‏ ‏.‏ فَمَا صَلَّى بَعْدَ يَوْمَئِذٍ صَلاَةً إِلاَّ قَالَ فِي دُبُرِ الصَّلاَةِ ‏"‏ رَبَّ جِبْرِيلَ وَمِيكَائِيلَ وَإِسْرَافِيلَ أَعِذْنِي مِنْ حَرِّ النَّارِ وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{1345}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah said:"A Jewish woman entered unto me and said: 'The torment of the grave is because of urine.' I said: 'You are lying.' She said: 'No, it is true; we cut our skin and clothes because of it.' The Messenger of Allah (ﷺ) went out to pray and our voices became loud. He said: 'What is this?' So I told him what she had said. He said: 'She spoke the truth.' After that day he never offered any prayer but he said, following the prayer: 'Rabba Jibril wa Mika'il wa Israfil, aiding min harrin-nar wa 'adhabil-qabr (Lord of Jibril, Mika'il and Israfil, grant me refuge from the heat of the Fire and the torment of the grave)}}
\hadithdefcmd{nasai}{1346}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَطَاءِ بْنِ أَبِي مَرْوَانَ، عَنْ أَبِيهِ، أَنَّ كَعْبًا، حَلَفَ لَهُ بِاللَّهِ الَّذِي فَلَقَ الْبَحْرَ لِمُوسَى إِنَّا لَنَجِدُ فِي التَّوْرَاةِ أَنَّ دَاوُدَ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا انْصَرَفَ مِنْ صَلاَتِهِ قَالَ ‏"‏ اللَّهُمَّ أَصْلِحْ لِي دِينِي الَّذِي جَعَلْتَهُ لِي عِصْمَةً وَأَصْلِحْ لِي دُنْيَاىَ الَّتِي جَعَلْتَ فِيهَا مَعَاشِي اللَّهُمَّ إِنِّي أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَأَعُوذُ بِعَفْوِكَ مِنْ نِقْمَتِكَ وَأَعُوذُ بِكَ مِنْكَ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏.‏ قَالَ وَحَدَّثَنِي كَعْبٌ أَنَّ صُهَيْبًا حَدَّثَهُ أَنَّ مُحَمَّدًا صلى الله عليه وسلم كَانَ يَقُولُهُنَّ عِنْدَ انْصِرَافِهِ مِنْ صَلاَتِهِ ‏.‏\hadithno{1346}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Ata bin Abi Marwan, from his father, that:Ka'b swore to him: "By Allah (SWT) Who parted the sea for Musa, we find in the Tawrah that when Dawud, the Prophet of Allah, finished his prayer, he would say: 'Allahumma Aslih li dinya-lladhi ja'altahu li ismatan wa aslih li dunyaya-llati ja'alta fiha ma'ashi, Allahumma inni a-udhu biridaka min sakhatik wa a-udhu bi'afwika min naqmatika wa a-udhu bika mink, la mani' lima a'taita wa la mu'tia lima mana'ta wa la yanfa'u dhal-jaddi minka al-jadd (O Allah, set straight my religious commitment that You have made a protection for me, and set straight my worldly affairs which You have made a means of my livelihood. O Allah, I seek refuge in Your pleasure from Your wrath, and I seek refuge in Your forgiveness from Your punishment, and I seek refuge in You from You. None can withhold what you have given and none can give what you have withheld, and no wealth or fortune can avail the man of wealth and fortune before You.)'" He said: "And Ka'b told me that Suhaib told him that Muhammad (ﷺ) used to say (these words) when he had finished praying}}
\hadithdefcmd{nasai}{1347}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُثْمَانَ الشَّحَّامِ، عَنْ مُسْلِمِ بْنِ أَبِي بَكْرَةَ، قَالَ كَانَ أَبِي يَقُولُ فِي دُبُرِ الصَّلاَةِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكُفْرِ وَالْفَقْرِ وَعَذَابِ الْقَبْرِ فَكُنْتُ أَقُولُهُنَّ فَقَالَ أَبِي أَىْ بُنَىَّ عَمَّنْ أَخَذْتَ هَذَا قُلْتُ عَنْكَ ‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُهُنَّ فِي دُبُرِ الصَّلاَةِ ‏.‏\hadithno{1347}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Muslim bin Abi Bakrah said:"My father used to say following every prayer: 'Allahumma inni a-udhu bika min al-kufri wal-faqri wa 'adhab al-qabr. ( O Allah, I seek refuge with You from Kufr, poverty, and the torment of the grave)' and I used to say them (these words). My father said: 'O my son, from whom did you learn this?' I said: 'From you. He said: "The Messenger of Allah (ﷺ) used to say them following the prayer}}
\hadithdefcmd{nasai}{1348}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَلَّتَانِ لاَ يُحْصِيهِمَا رَجُلٌ مُسْلِمٌ إِلاَّ دَخَلَ الْجَنَّةَ وَهُمَا يَسِيرٌ وَمَنْ يَعْمَلُ بِهِمَا قَلِيلٌ ‏"‏ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الصَّلَوَاتُ الْخَمْسُ يُسَبِّحُ أَحَدُكُمْ فِي دُبُرِ كُلِّ صَلاَةٍ عَشْرًا وَيَحْمَدُ عَشْرًا وَيُكَبِّرُ عَشْرًا فَهِيَ خَمْسُونَ وَمِائَةٌ فِي اللِّسَانِ وَأَلْفٌ وَخَمْسُمِائَةٍ فِي الْمِيزَانِ ‏"‏ ‏.‏ وَأَنَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَعْقِدُهُنَّ بِيَدِهِ ‏"‏ وَإِذَا أَوَى أَحَدُكُمْ إِلَى فِرَاشِهِ أَوْ مَضْجَعِهِ سَبَّحَ ثَلاَثًا وَثَلاَثِينَ وَحَمِدَ ثَلاَثًا وَثَلاَثِينَ وَكَبَّرَ أَرْبَعًا وَثَلاَثِينَ فَهِيَ مِائَةٌ عَلَى اللِّسَانِ وَأَلْفٌ فِي الْمِيزَانِ ‏"‏ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَيُّكُمْ يَعْمَلُ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ أَلْفَيْنِ وَخَمْسَمِائَةِ سَيِّئَةٍ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَكَيْفَ لاَ نُحْصِيهِمَا فَقَالَ ‏"‏ إِنَّ الشَّيْطَانَ يَأْتِي أَحَدَكُمْ وَهُوَ فِي صَلاَتِهِ فَيَقُولُ اذْكُرْ كَذَا اذْكُرْ كَذَا وَيَأْتِيهِ عِنْدَ مَنَامِهِ فَيُنِيمُهُ ‏"‏ ‏.‏\hadithno{1348}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abdullah in 'Umar said:"The Messenger of Allah (ﷺ) said: 'There are two qualities which no Muslim person attains but he will enter Paradise, and they are easy, but those who do them are few.' The Messenger of Allah (ﷺ) said: 'The five daily prayers: After each prayer one of you glorifies Allah (SWT) ten times and praises Him ten times and magnifies him ten times, which makes one hundred and fifty on the tongue and one thousand five hundred in the balance.' And I saw the Messenger of Allah (ﷺ) counting them on his hands. 'And when one of you retires to his bed he says the tasbih thirty-three times and the tahmid thirty-three times and the takbir thirty-four times, that is one hundred on the tongue and one thousand in the balance.' The Messenger of Allah (ﷺ) said: "So which of you does two thousand five hundred bad deeds in a day and a night?" It was said: "O Messenger of Allah (ﷺ), how can a person not persist in doing that?" He said: "The Shaitan comes to one of you when he is praying and says: 'Remember such and such, remember such and such," or he comes to him when he is in bed and makes him fall asleep}}
\hadithdefcmd{nasai}{1349}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، عَنْ أَسْبَاطٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ قَيْسٍ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُعَقِّبَاتٌ لاَ يَخِيبُ قَائِلُهُنَّ يُسَبِّحُ اللَّهَ فِي دُبُرِ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَيَحْمَدُهُ ثَلاَثًا وَثَلاَثِينَ وَيُكَبِّرُهُ أَرْبَعًا وَثَلاَثِينَ ‏"‏ ‏.‏\hadithno{1349}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ka'b bin 'Ujrah said:"The Messenger of Allah (ﷺ) said: 'There are statements of remembrance following the prayer of which the one who says them will never be deprive of the reward: Glorifying Allah (SWT) thirty-three times following each prayer, and praising Him thirty-three times, and magnifying Him thirty-four times}}
\hadithdefcmd{nasai}{1350}{أَخْبَرَنَا مُوسَى بْنُ حِزَامٍ التِّرْمِذِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنِ ابْنِ إِدْرِيسَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ كَثِيرِ بْنِ أَفْلَحَ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ أُمِرُوا أَنْ يُسَبِّحُوا، دُبُرَ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَيَحْمَدُوا ثَلاَثًا وَثَلاَثِينَ وَيُكَبِّرُوا أَرْبَعًا وَثَلاَثِينَ فَأُتِيَ رَجُلٌ مِنَ الأَنْصَارِ فِي مَنَامِهِ فَقِيلَ لَهُ أَمَرَكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُسَبِّحُوا دُبُرَ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَتَحْمَدُوا ثَلاَثًا وَثَلاَثِينَ وَتُكَبِّرُوا أَرْبَعًا وَثَلاَثِينَ قَالَ نَعَمْ ‏.‏ قَالَ فَاجْعَلُوهَا خَمْسًا وَعِشْرِينَ وَاجْعَلُوا فِيهَا التَّهْلِيلَ فَلَمَّا أَصْبَحَ أَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏ "‏ اجْعَلُوهَا كَذَلِكَ ‏"‏ ‏.‏\hadithno{1350}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Thabit said:"They were commanded to say the tasbih thirty-three times following the prayer, and to say the tahmid thirty-three times, and to say the takbir thirty-four times, then a man from among the Ansar was told in a dream: 'Did the Messenger of Allah (ﷺ) command you to say the tasbih thirty-three times following the prayer, and to say the tahmid thirty-three times, and to say the takbir thirty-four times?' He said: 'Yes.' 'Instead of that, say each one twenty-five times, and include the tahlil among them.' The next morning he came to the Messenger of Allah (ﷺ) and told him about that, and he said: 'Do that}}
\hadithdefcmd{nasai}{1351}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْكَرِيمِ أَبُو زُرْعَةَ الرَّازِيُّ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، قَالَ حَدَّثَنِي عَلِيُّ بْنُ الْفُضَيْلِ بْنِ عِيَاضٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، رَأَى فِيمَا يَرَى النَّائِمُ قِيلَ لَهُ بِأَىِّ شَىْءٍ أَمَرَكُمْ نَبِيُّكُمْ صلى الله عليه وسلم قَالَ أَمَرَنَا أَنْ نُسَبِّحَ ثَلاَثًا وَثَلاَثِينَ وَنَحْمَدَ ثَلاَثًا وَثَلاَثِينَ وَنُكَبِّرَ أَرْبَعًا وَثَلاَثِينَ فَتِلْكَ مِائَةٌ ‏.‏ قَالَ سَبِّحُوا خَمْسًا وَعِشْرِينَ وَاحْمَدُوا خَمْسًا وَعِشْرِينَ وَكَبِّرُوا خَمْسًا وَعِشْرِينَ وَهَلِّلُوا خَمْسًا وَعِشْرِينَ فَتِلْكَ مِائَةٌ فَلَمَّا أَصْبَحَ ذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ افْعَلُوا كَمَا قَالَ الأَنْصَارِيُّ ‏"‏ ‏.‏\hadithno{1351}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that :A man saw in a dream that it was said to him: "What does your Prophet (ﷺ) command you to do?" He said: "He commanded us to say Tasbih thirty-three times following the prayer, and to say the tahmid thirty-three times, and to say the takbir thirty-four times, and that makes one-hundred." He said: Say the tasbih twenty-five times and say the tahmid twenty-five times and say the takbir twenty-five times and say the tahlil twenty-five times, and that will make one hundred." The following morning he told the Prophet (ﷺ) about that and the Messenger of Allah (ﷺ) said: "Do what the Ansari said}}
\hadithdefcmd{nasai}{1352}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ قَالَ سَمِعْتُ كُرَيْبًا، عَنِ ابْنِ عَبَّاسٍ، عَنْ جُوَيْرِيَةَ بِنْتِ الْحَارِثِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ عَلَيْهَا وَهِيَ فِي الْمَسْجِدِ تَدْعُو ثُمَّ مَرَّ بِهَا قَرِيبًا مِنْ نِصْفِ النَّهَارِ فَقَالَ لَهَا ‏"‏ مَا زِلْتِ عَلَى حَالِكِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ أَلاَ أُعَلِّمُكِ - يَعْنِي - كَلِمَاتٍ تَقُولِينَهُنَّ سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ سُبْحَانَ اللَّهِ رِضَا نَفْسِهِ سُبْحَانَ اللَّهِ رِضَا نَفْسِهِ سُبْحَانَ اللَّهِ رِضَا نَفْسِهِ سُبْحَانَ اللَّهِ زِنَةَ عَرْشِهِ سُبْحَانَ اللَّهِ زِنَةَ عَرْشِهِ سُبْحَانَ اللَّهِ زِنَةَ عَرْشِهِ سُبْحَانَ اللَّهِ مِدَادَ كَلِمَاتِهِ سُبْحَانَ اللَّهِ مِدَادَ كَلِمَاتِهِ سُبْحَانَ اللَّهِ مِدَادَ كَلِمَاتِهِ ‏"‏ ‏.‏\hadithno{1352}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Juwayriyah bint Al-Harith said that:The Prophet (ﷺ) passed by her while she was in the masjid, supplicating, then he passed by her again when it was almost midday. He said to her: "Are you still here?" She said: "Yes." He said: "Shall I not teach you some words which you can say? Subhan Allah adada khalqihi, subhan Allah adada khalqihi, subhan Allah adada khalqihi; subhan Allah rida nafsihi, subhan Allah rida nafsihi, subhan Allah rida nafsihi; Subhan Allah zinata 'arshihi, Subhan Allah zinata 'arshihi, Subhan Allah zinata 'arshihi; Subhan Allah midada Kalamatihi, Subhan Allah midada Kalamatihi, Subhan Allah midada Kalamatihi (Glory be to Allah the number of His creation, glory be to Allah the number of His creation, glory be to Allah the number of His creation; glory be to Allah as much as pleases Him, glory be to Allah as much as pleases Him, glory be to Allah as much as pleases Him; glory be to Allah the weight of His throne, glory be to Allah the weight of His throne, glory be to Allah the weight of His throne; glory be to Allah the number of His words, glory be to Allah the number of His words, glory be to Allah the number of His words)}}
\hadithdefcmd{nasai}{1353}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَتَّابٌ، - هُوَ ابْنُ بَشِيرٍ - عَنْ خُصَيْفٍ، عَنْ عِكْرِمَةَ، وَمُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ الْفُقَرَاءُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّ الأَغْنِيَاءَ يُصَلُّونَ كَمَا نُصَلِّي وَيَصُومُونَ كَمَا نَصُومُ وَلَهُمْ أَمْوَالٌ يَتَصَدَّقُونَ وَيُنْفِقُونَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا صَلَّيْتُمْ فَقُولُوا سُبْحَانَ اللَّهِ ثَلاَثًا وَثَلاَثِينَ وَالْحَمْدُ لِلَّهِ ثَلاَثًا وَثَلاَثِينَ وَاللَّهُ أَكْبَرُ ثَلاَثًا وَثَلاَثِينَ وَلاَ إِلَهَ إِلاَّ اللَّهُ عَشْرًا فَإِنَّكُمْ تُدْرِكُونَ بِذَلِكَ مَنْ سَبَقَكُمْ وَتَسْبِقُونَ مَنْ بَعْدَكُمْ ‏"‏ ‏.‏\hadithno{1353}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"Some poor people came to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah (ﷺ), the rich pray as we pray, and they fast as we fast, but they have wealth that they give in charity and with which they free slaves.' The Prophet (ﷺ) said: 'If you pray and say SubhanAllah thirty-three times, Al-hamdu-lillah thirty-three times and Alahu Akbar thirty-four times, and La illaha illaAllah ten times, then you will catch up with those who went ahead of you and will go ahead of those who come after you}}
\hadithdefcmd{nasai}{1354}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، - يَعْنِي ابْنَ طَهْمَانَ - عَنِ الْحَجَّاجِ بْنِ الْحَجَّاجِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ أَبِي عَلْقَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَبَّحَ فِي دُبُرِ صَلاَةِ الْغَدَاةِ مِائَةَ تَسْبِيحَةٍ وَهَلَّلَ مِائَةَ تَهْلِيلَةٍ غُفِرَتْ لَهُ ذُنُوبُهُ وَلَوْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{1354}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'Whoever says the tasbih one hundred times following the morning prayer, and the tahlil one hundred times, he will be forgiven his sins even if they are like the foam of the sea}}
\hadithdefcmd{nasai}{1355}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، وَالْحُسَيْنُ بْنُ مُحَمَّدٍ الذَّارِعُ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا عَثَّامُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَعْقِدُ التَّسْبِيحَ ‏.‏\hadithno{1355}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"I saw the Messenger of Allah (ﷺ) counting tasbih on his fingers}}
\hadithdefcmd{nasai}{1356}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا بَكْرٌ، - وَهُوَ ابْنُ مُضَرَ - عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُجَاوِرُ فِي الْعَشْرِ الَّذِي فِي وَسَطِ الشَّهْرِ فَإِذَا كَانَ مِنْ حِينِ يَمْضِي عِشْرُونَ لَيْلَةً وَيَسْتَقْبِلُ إِحْدَى وَعِشْرِينَ يَرْجِعُ إِلَى مَسْكَنِهِ وَيَرْجِعُ مَنْ كَانَ يُجَاوِرُ مَعَهُ ثُمَّ إِنَّهُ أَقَامَ فِي شَهْرٍ جَاوَرَ فِيهِ تِلْكَ اللَّيْلَةَ الَّتِي كَانَ يَرْجِعُ فِيهَا فَخَطَبَ النَّاسَ فَأَمَرَهُمْ بِمَا شَاءَ اللَّهُ ثُمَّ قَالَ ‏ "‏ إِنِّي كُنْتُ أُجَاوِرُ هَذِهِ الْعَشْرَ ثُمَّ بَدَا لِي أَنْ أُجَاوِرَ هَذِهِ الْعَشْرَ الأَوَاخِرَ فَمَنْ كَانَ اعْتَكَفَ مَعِي فَلْيَثْبُتْ فِي مُعْتَكَفِهِ وَقَدْ رَأَيْتُ هَذِهِ اللَّيْلَةَ فَأُنْسِيتُهَا فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ فِي كُلِّ وَتْرٍ وَقَدْ رَأَيْتُنِي أَسْجُدُ فِي مَاءٍ وَطِينٍ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ مُطِرْنَا لَيْلَةَ إِحْدَى وَعِشْرِينَ فَوَكَفَ الْمَسْجِدُ فِي مُصَلَّى رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَظَرْتُ إِلَيْهِ وَقَدِ انْصَرَفَ مِنْ صَلاَةِ الصُّبْحِ وَوَجْهُهُ مُبْتَلٌّ طِينًا وَمَاءً ‏.‏\hadithno{1356}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah (ﷺ) used to observe I'tikaf during the middle ten days of the month, and after the twentieth (day of the month), he would come out on the twenty-first and go back to his home, and those who were observing I'tikaf with him would go back like him. Then he stayed one month on the night when he used to go back home, and he addressed the people and enjoined upon them whatever Allah (SWT) willed. Then he said: 'I used to observe I'tikaf during these ten days, then I decided to spend the last ten days in I'tikaf. So whoever was observing I'tikaf with me, let him stay in his place of I'tikaf, for I was shown this night (Lailatul Qadr), then I was caused to forget it, so seek it during the last ten nights on the odd-numbered nights. And I saw myself prostrating in water and mud.'" Abu Sa'eed said: "It rained on the night of the twenty-first, and the roof of the Masjid leaked over the place where the Messenger of Allah (ﷺ) used to pray. I looked at him when he had finished praying subh and his face was wet with water and mud}}
\hadithdefcmd{nasai}{1357}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا صَلَّى الْفَجْرَ قَعَدَ فِي مُصَلاَّهُ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏\hadithno{1357}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin Samurah said:"When the Messenger of Allah (ﷺ) prayed fajr, he would sit in the place where he had prayed until the sun rose}}
\hadithdefcmd{nasai}{1358}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا زُهَيْرٌ، وَذَكَرَ، آخَرَ عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ قُلْتُ لِجَابِرِ بْنِ سَمُرَةَ كُنْتَ تُجَالِسُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا صَلَّى الْفَجْرَ جَلَسَ فِي مُصَلاَّهُ حَتَّى تَطْلُعَ الشَّمْسُ فَيَتَحَدَّثُ أَصْحَابُهُ يَذْكُرُونَ حَدِيثَ الْجَاهِلِيَّةِ وَيُنْشِدُونَ الشِّعْرَ وَيَضْحَكُونَ وَيَتَبَسَّمُ صلى الله عليه وسلم ‏.‏\hadithno{1358}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Simak bin Harb said:"I said to Jabir bin Samurah: 'Did you used to sit with the Messenger of Allah (ﷺ)?" He said: 'Yes.' When the Messenger of Allah (ﷺ) had prayed fajr, he would sit in the place where he had prayed until the sun rose, and his companions would talk and remember things from the time of Jahilliyah and recite poetry, and they would laugh and he would smile}}
\hadithdefcmd{nasai}{1359}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ السُّدِّيِّ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ كَيْفَ أَنْصَرِفُ إِذَا صَلَّيْتُ عَنْ يَمِينِي، أَوْ عَنْ يَسَارِي، قَالَ أَمَّا أَنَا فَأَكْثَرُ، مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْصَرِفُ عَنْ يَمِينِهِ ‏.‏\hadithno{1359}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that As-Suddi said:"I asked Anas bin Malik: 'How should I leave after I have prayed- to the right or to the left?' He said: 'I usually saw the Messenger of Allah (ﷺ) leave to the right}}
\hadithdefcmd{nasai}{1360}{أَخْبَرَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ، عَنِ الأَسْوَدِ، قَالَ قَالَ عَبْدُ اللَّهِ لاَ يَجْعَلَنَّ أَحَدُكُمْ لِلشَّيْطَانِ مِنْ نَفْسِهِ جُزْءًا يَرَى أَنَّ حَتْمًا عَلَيْهِ أَنْ لاَ يَنْصَرِفَ إِلاَّ عَنْ يَمِينِهِ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَكْثَرَ انْصِرَافِهِ عَنْ يَسَارِهِ ‏.‏\hadithno{1360}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Al-Aswad said:"Abdullah said: 'No one among you should allow the Shaitan to give him wrong ideas by making him believe that he can only leave after praying by moving to his right, because I saw the Messenger of Allah (ﷺ) usually departing to the left}}
\hadithdefcmd{nasai}{1361}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا بَقِيَّةُ، قَالَ حَدَّثَنَا الزُّبَيْرِيُّ، أَنَّ مَكْحُولاً، حَدَّثَهُ أَنَّ مَسْرُوقَ بْنَ الأَجْدَعِ حَدَّثَهُ عَنْ عَائِشَةَ، قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَشْرَبُ قَائِمًا وَقَاعِدًا وَيُصَلِّي حَافِيًا وَمُنْتَعِلاً وَيَنْصَرِفُ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ ‏.‏\hadithno{1361}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I saw the Messenger of Allah (ﷺ) drink standing and sitting, and he prayed barefoot and with sandals, and he left (after prayer) to the right and to the left}}
\hadithdefcmd{nasai}{1362}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النِّسَاءُ يُصَلِّينَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْفَجْرَ فَكَانَ إِذَا سَلَّمَ انْصَرَفْنَ مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ فَلاَ يُعْرَفْنَ مِنَ الْغَلَسِ ‏.‏\hadithno{1362}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Women used to pray fajr with the Messenger of Allah (ﷺ), and when he said the taslim they would leave, wrapped in their Mirts, unrecognizable because of the darkness}}
\hadithdefcmd{nasai}{1363}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الْمُخْتَارِ بْنِ فُلْفُلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏"‏ إِنِّي إِمَامُكُمْ فَلاَ تُبَادِرُونِي بِالرُّكُوعِ وَلاَ بِالسُّجُودِ وَلاَ بِالْقِيَامِ وَلاَ بِالاِنْصِرَافِ فَإِنِّي أَرَاكُمْ مِنْ أَمَامِي وَمِنْ خَلْفِي ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ رَأَيْتُمْ مَا رَأَيْتُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏ ‏.‏ قُلْنَا مَا رَأَيْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ رَأَيْتُ الْجَنَّةَ وَالنَّارَ ‏"‏ ‏.‏\hadithno{1363}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) led us in prayer one day, then he turned to face us and said: 'I am now your imam, so do not hasten to bow or prostrate or stand or leave before I do. I can see you in front of me and behind me.' Then he said: 'By the One in Whose Hand is my soul, if you had seen what I have seen, you would laugh little and weep much.' We said: 'What have you seen, O Messenger of Allah (ﷺ)?' He said: 'Paradise and Hell}}
\hadithdefcmd{nasai}{1364}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، - وَهُوَ ابْنُ الْمُفَضَّلِ - قَالَ حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي ذَرٍّ، قَالَ صُمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم رَمَضَانَ فَلَمْ يَقُمْ بِنَا النَّبِيُّ صلى الله عليه وسلم حَتَّى بَقِيَ سَبْعٌ مِنَ الشَّهْرِ فَقَامَ بِنَا حَتَّى ذَهَبَ نَحْوٌ مِنْ ثُلُثِ اللَّيْلِ ثُمَّ كَانَتْ سَادِسَةٌ فَلَمْ يَقُمْ بِنَا فَلَمَّا كَانَتِ الْخَامِسَةُ قَامَ بِنَا حَتَّى ذَهَبَ نَحْوٌ مِنْ شَطْرِ اللَّيْلِ قُلْنَا يَا رَسُولَ اللَّهِ لَوْ نَفَلْتَنَا قِيَامَ هَذِهِ اللَّيْلَةَ ‏.‏ قَالَ ‏ "‏ إِنَّ الرَّجُلَ إِذَا صَلَّى مَعَ الإِمَامِ حَتَّى يَنْصَرِفَ حُسِبَ لَهُ قِيَامُ لَيْلَةٍ ‏"‏ ‏.‏ قَالَ ثُمَّ كَانَتِ الرَّابِعَةُ فَلَمْ يَقُمْ بِنَا فَلَمَّا بَقِيَ ثُلُثٌ مِنَ الشَّهْرِ أَرْسَلَ إِلَى بَنَاتِهِ وَنِسَائِهِ وَحَشَدَ النَّاسَ فَقَامَ بِنَا حَتَّى خَشِينَا أَنْ يَفُوتَنَا الْفَلاَحُ ثُمَّ لَمْ يَقُمْ بِنَا شَيْئًا مِنَ الشَّهْرِ ‏.‏ قَالَ دَاوُدُ قُلْتُ مَا الْفَلاَحُ قَالَ السُّحُورُ ‏.‏\hadithno{1364}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Dharr said:"We fasted Ramadan with the Messenger of Allah (ﷺ), and the Prophet (ﷺ) did not lead us in Qiyam until there were seven days left of the month, then he led us in Qiyam until one-third of the night had passed. Then, when there were six days left, he did not lead us in Qiyam. When there were five days left, he led us in praying Qiyam until half the night had passed. We said: 'O Messenger of Allah (SA), why don't you lead us in praying Qiyam for the rest of the night?' He said: 'If a man prays with the Imam until he leaves, that will be continued for him as if he spent the whole night in prayer.' Then, when there were four days left, he did not lead us in praying Qiyam. When there were three days left he sent for his daughters and women, and gathered the people, and he led us in praying Qiyam until we feared that we would miss Al-Falah. Then he did not lead us in praying Qiyam for the rest of the month." Dawud (one of the narrators) said: "I said: ' What is falah?' He said: 'Sahur}}
\hadithdefcmd{nasai}{1365}{أَخْبَرَنَا أَحْمَدُ بْنُ بَكَّارٍ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ أَبِي حُسَيْنٍ النَّوْفَلِيِّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم الْعَصْرَ بِالْمَدِينَةِ ثُمَّ انْصَرَفَ يَتَخَطَّى رِقَابَ النَّاسِ سَرِيعًا حَتَّى تَعَجَّبَ النَّاسُ لِسُرْعَتِهِ فَتَبِعَهُ بَعْضُ أَصْحَابِهِ فَدَخَلَ عَلَى بَعْضِ أَزْوَاجِهِ ثُمَّ خَرَجَ فَقَالَ ‏ "‏ إِنِّي ذَكَرْتُ وَأَنَا فِي الْعَصْرِ شَيْئًا مِنْ تِبْرٍ كَانَ عِنْدَنَا فَكَرِهْتُ أَنْ يَبِيتَ عِنْدَنَا فَأَمَرْتُ بِقِسْمَتِهِ ‏"‏ ‏.‏\hadithno{1365}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Uqbah bin Al-Harith said:"I prayed 'Asr with the Prophet (ﷺ) in Al-Madinah, then he left, stepping over the necks of the people, so quickly that the people were surprised at his haste. He entered unto one of his wives, then he came out and said: 'While I was praying 'Asr, I remembered some gold that we had, and I did not want it to stay with us overnight, so I ordered that it be distributed}}
\hadithdefcmd{nasai}{1366}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ هِشَامٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، يَوْمَ الْخَنْدَقِ بَعْدَ مَا غَرَبَتِ الشَّمْسُ جَعَلَ يَسُبُّ كُفَّارَ قُرَيْشٍ وَقَالَ يَا رَسُولَ اللَّهِ مَا كِدْتُ أَنْ أُصَلِّيَ حَتَّى كَادَتِ الشَّمْسُ تَغْرُبُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَوَاللَّهِ مَا صَلَّيْتُهَا ‏"‏ ‏.‏ فَنَزَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى بُطْحَانَ فَتَوَضَّأَ لِلصَّلاَةِ وَتَوَضَّأْنَا لَهَا فَصَلَّى الْعَصْرَ بَعْدَ مَا غَرَبَتِ الشَّمْسُ ثُمَّ صَلَّى بَعْدَهَا الْمَغْرِبَ ‏.‏\hadithno{1366}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jabir bin Abdullah that:On the Day of Al-Khandaq, after the sun had set, Umar bin Al-Khattab started cursing the disbelievers of the Quraish and said: "O Messenger of Allah, I was hardly able to pray until the sun set." The Messenger of Allah (ﷺ) said: "By Allah, I did not pray." So we went down with the Messenger of Allah (ﷺ) to Buthan. He performed wudu' for prayer and so did we, and he prayed 'Asr after the sun had set, then he prayed Maghrib after that}}
