% Auto-generated chapter 1 for nasai
% Hadiths in this chapter: 324

\hadithdefcmd{nasai}{1}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ نَوْمِهِ فَلاَ يَغْمِسْ يَدَهُ فِي وَضُوئِهِ حَتَّى يَغْسِلَهَا ثَلاَثًا فَإِنَّ أَحَدَكُمْ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏\hadithno{1}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"When any one of you wakes from sleep, let him not dip his hand in (the water he uses for) his Wudu' until he has washed it three times, for none of you knows where his hand spent the night}}
\hadithdefcmd{nasai}{2}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ مِنَ اللَّيْلِ يَشُوصُ فَاهُ بِالسِّوَاكِ ‏.‏\hadithno{2}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Huthaifah said:"When the Messenger of Allah (ﷺ) got up at night, he would brush his mouth with the Siwak}}
\hadithdefcmd{nasai}{3}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدَةَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ أَخْبَرَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَسْتَنُّ وَطَرَفُ السِّوَاكِ عَلَى لِسَانِهِ وَهُوَ يَقُولُ ‏ "‏ عَأْعَأْ ‏"‏ ‏.‏\hadithno{3}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"I came to the Messenger of Allah (ﷺ) when he was using the Siwak, and the end of the Siwak was on his toungue, and he was saying, "'A','a}}
\hadithdefcmd{nasai}{4}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - قَالَ حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنِي أَبُو بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ أَقْبَلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَمَعِي رَجُلاَنِ مِنَ الأَشْعَرِيِّينَ أَحَدُهُمَا عَنْ يَمِينِي وَالآخَرُ عَنْ يَسَارِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَاكُ فَكِلاَهُمَا سَأَلَ الْعَمَلَ قُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ نَبِيًّا مَا أَطْلَعَانِي عَلَى مَا فِي أَنْفُسِهِمَا وَمَا شَعَرْتُ أَنَّهُمَا يَطْلُبَانِ الْعَمَلَ فَكَأَنِّي أَنْظُرُ إِلَى سِوَاكِهِ تَحْتَ شَفَتِهِ قَلَصَتْ فَقَالَ ‏ "‏ إِنَّا لاَ - أَوْ لَنْ - نَسْتَعِينَ عَلَى الْعَمَلِ مَنْ أَرَادَهُ وَلَكِنِ اذْهَبْ أَنْتَ ‏"‏ ‏.‏ فَبَعَثَهُ عَلَى الْيَمَنِ ثُمَّ أَرْدَفَهُ مُعَاذُ بْنُ جَبَلٍ رضى الله عنهما ‏.‏\hadithno{4}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Burdah that Abu Musa said:"I came to the Prophet (ﷺ) when he was using the Siwak and with me were two men of the Ash'aris - one on my right and the other on my left - who were seeking to be appointed as officials. I said: 'By the One Who sent you as a Prophet with the truth, they did not tell me why they wanted to come with me and I did not realize that they were seeking to be appointed as officials.' And I could see his Siwak beneath his lip, then it slipped and he said: 'We do not' - or; 'We will never appoint as an official anyone who seeks that. Rather you should go.'" So he sent his (Abu Musa) to Yemen, then he sent Mu'adh bin Jabal to go after him - may Allah be pleased with them}}
\hadithdefcmd{nasai}{5}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، عَنْ يَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَتِيقٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، سَمِعْتُ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السِّوَاكُ مَطْهَرَةٌ لِلْفَمِ مَرْضَاةٌ لِلرَّبِّ ‏"‏ ‏.‏\hadithno{5}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdur-Rahman bin Abu 'Atiq said:"My father told me: 'I heard 'Aishah say, (narrating) from the Prophet (ﷺ): "Siwak is a means of purification for the mouth and is pleasing to the Lord}}
\hadithdefcmd{nasai}{6}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، وَعِمْرَانُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ الْحَبْحَابِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ أَكْثَرْتُ عَلَيْكُمْ فِي السِّوَاكِ ‏"‏ ‏.‏\hadithno{6}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) said: 'I have indeed urged you with regard to the Siwak}}
\hadithdefcmd{nasai}{7}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِالسِّوَاكِ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏\hadithno{7}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Were it not that it would be too difficult for my Ummah, I would have commanded them to use the Siwak at (the time of) every Salah}}
\hadithdefcmd{nasai}{8}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ، قَالَ حَدَّثَنَا عِيسَى، - وَهُوَ ابْنُ يُونُسَ - عَنْ مِسْعَرٍ، عَنِ الْمِقْدَامِ، - وَهُوَ ابْنُ شُرَيْحٍ - عَنْ أَبِيهِ، قَالَ قُلْتُ لِعَائِشَةَ بِأَىِّ شَىْءٍ كَانَ يَبْدَأُ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ بَيْتَهُ قَالَتْ بِالسِّوَاكِ ‏.‏\hadithno{8}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Al-Miqdam - Abu Shuraih - that his father said:"I said to 'Aishah: 'What did the Prophet (ﷺ) start with when he entered his house?' She said: 'The Siwak}}
\hadithdefcmd{nasai}{9}{أَخْبَرَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْفِطْرَةُ خَمْسٌ الاِخْتِتَانُ وَالاِسْتِحْدَادُ وَقَصُّ الشَّارِبِ وَتَقْلِيمُ الأَظْفَارِ وَنَتْفُ الإِبْطِ ‏"‏ ‏.‏\hadithno{9}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"The Fitrah are five: Circumcision, removing the pubes, trimming the mustache, clipping the nails, and plucking the armpit hairs}}
\hadithdefcmd{nasai}{10}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ مَعْمَرًا، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الْفِطْرَةِ قَصُّ الشَّارِبِ وَنَتْفُ الإِبْطِ وَتَقْلِيمُ الأَظْفَارِ وَالاِسْتِحْدَادُ وَالْخِتَانُ ‏"‏ ‏.‏\hadithno{10}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The Fitrah are five: Trimming the mustache, plucking the armpit hairs, clipping the nails, removing the pubes, and circumcision}}
\hadithdefcmd{nasai}{11}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مِنَ الْفِطْرَةِ الْخِتَانُ وَحَلْقُ الْعَانَةِ وَنَتْفُ الإِبْطِ وَتَقْلِيمُ الأَظْفَارِ وَأَخْذُ الشَّارِبِ ‏"‏ ‏.‏\hadithno{11}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"The Fitrah are five: Circumcision, shaving the pubes, plucking the armpit hairs, clipping the nails and taking from the mustache}}
\hadithdefcmd{nasai}{12}{أَخْبَرَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنْ حَنْظَلَةَ بْنِ أَبِي سُفْيَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْفِطْرَةُ قَصُّ الأَظْفَارِ وَأَخْذُ الشَّارِبِ وَحَلْقُ الْعَانَةِ ‏"‏ ‏.‏\hadithno{12}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"The deeds connected to the Fitrah are: Clipping the nails, removing the mustache and shaving the pubes}}
\hadithdefcmd{nasai}{13}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ يُوسُفَ بْنِ صُهَيْبٍ، عَنْ حَبِيبِ بْنِ يَسَارٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَمْ يَأْخُذْ شَارِبَهُ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{13}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Zaid bin Arqam said:"The Messenger of Allah (ﷺ) said: 'Whoever does not trim his mustache, he is not from one of us}}
\hadithdefcmd{nasai}{14}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا جَعْفَرٌ، - هُوَ ابْنُ سُلَيْمَانَ - عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ وَقَّتَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي قَصِّ الشَّارِبِ وَتَقْلِيمِ الأَظْفَارِ وَحَلْقِ الْعَانَةِ وَنَتْفِ الإِبْطِ أَنْ لاَ نَتْرُكَ أَكْثَرَ مِنْ أَرْبَعِينَ يَوْمًا ‏.‏ وَقَالَ مَرَّةً أُخْرَى أَرْبَعِينَ لَيْلَةً ‏.‏\hadithno{14}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:"A time limit was set for us, by the Messenger of Allah (ﷺ), regarding trimming the mustache, clipping the nails and plucking the pubes; we were not to leave that for more than forty days," on one occasion he said: "Forty nights}}
\hadithdefcmd{nasai}{15}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، - هُوَ ابْنُ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَحْفُوا الشَّوَارِبَ وَأَعْفُوا اللِّحَى ‏"‏ ‏.‏\hadithno{15}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet (ﷺ) said:"Trim the mustache and let the beard grow}}
\hadithdefcmd{nasai}{16}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو جَعْفَرٍ الْخَطْمِيُّ، عُمَيْرُ بْنُ يَزِيدَ قَالَ حَدَّثَنِي الْحَارِثُ بْنُ فُضَيْلٍ، وَعُمَارَةُ بْنُ خُزَيْمَةَ بْنِ ثَابِتٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي قُرَادٍ، قَالَ خَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى الْخَلاَءِ وَكَانَ إِذَا أَرَادَ الْحَاجَةَ أَبْعَدَ ‏.‏\hadithno{16}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdur-Rahman bin Abi Qurad said:"I went out with the Messenger of Allah (ﷺ) to an isolated area, and when he wanted to relieve himself he moved far away}}
\hadithdefcmd{nasai}{17}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا ذَهَبَ الْمَذْهَبَ أَبْعَدَ قَالَ فَذَهَبَ لِحَاجَتِهِ - وَهُوَ فِي بَعْضِ أَسْفَارِهِ - فَقَالَ ‏ "‏ ائْتِنِي بِوَضُوءٍ ‏"‏ ‏.‏ فَأَتَيْتُهُ بِوَضُوءٍ فَتَوَضَّأَ وَمَسَحَ عَلَى الْخُفَّيْنِ ‏.‏ قَالَ الشَّيْخُ إِسْمَاعِيلُ هُوَ ابْنُ جَعْفَرِ بْنِ أَبِي كَثِيرٍ الْقَارِئُ ‏.‏\hadithno{17}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Mughirah bin Shu'bah that when the Prophet (ﷺ) would go away (to relieve himself) he would go far away. He went to relieve himself when he was on one of his journeys, and said:"Bring me (water for) Wudu'." So I brought him (water for) Wudu', and he performed Wudu' and wiped over his Khuffs. The Shaikh [1] said: "Isma'il (one of the narrators) is Ibn Ja'far bin Abi Kathir Al-Qari. [1] Meaning the author, and it appears that Ibn As-Sunni who heard the text, said this}}
\hadithdefcmd{nasai}{18}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، قَالَ أَنْبَأَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ حُذَيْفَةَ، قَالَ كُنْتُ أَمْشِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَانْتَهَى إِلَى سُبَاطَةِ قَوْمٍ فَبَالَ قَائِمًا فَتَنَحَّيْتُ عَنْهُ فَدَعَانِي وَكُنْتُ عِنْدَ عَقِبَيْهِ حَتَّى فَرَغَ ثُمَّ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ ‏.‏\hadithno{18}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hudhaifah said:"I was walking with the Messenger of Allah (ﷺ) and he came to some people's garbage dump and urinated while standing up. I turned to go away, but he called me back (to conceal him), and I was just behind him. Then when he had finished, he performed Wudu' and wiped over his Khuffs}}
\hadithdefcmd{nasai}{19}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْخُبُثِ وَالْخَبَائِثِ ‏"‏ ‏.‏\hadithno{19}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) entered Al-Khala' (the toilet) and said: 'Allahumma inni a'uthu bika min al-khubuthi wal-khaba'ith (O Allah, I seek refuge with You from male and female devils)."[1] [1] See Ma'alam As-Sunan by Al-Khattabi. And Al-Khala' is the area one relieves oneself in. It refers to outside or other than that, it should not be understood to mean toilet only}}
\hadithdefcmd{nasai}{20}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، وَاللَّفْظُ، لَهُ عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ رَافِعِ بْنِ إِسْحَاقَ، أَنَّهُ سَمِعَ أَبَا أَيُّوبَ الأَنْصَارِيَّ، وَهُوَ بِمِصْرَ يَقُولُ وَاللَّهِ مَا أَدْرِي كَيْفَ أَصْنَعُ بِهَذِهِ الْكَرَايِيسِ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا ذَهَبَ أَحَدُكُمْ إِلَى الْغَائِطِ أَوِ الْبَوْلِ فَلاَ يَسْتَقْبِلِ الْقِبْلَةَ وَلاَ يَسْتَدْبِرْهَا ‏"‏ ‏.‏\hadithno{20}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Rafi' bin Ishaq that he heard Abu Ayyub Al-Ansari say - when he was in Egypt:"By Allah, I do not know what I should do with these Karais (toilets). The Messenger of Allah (ﷺ) said: 'When any one of you goes to defecate or urinate, let him not face toward the Qiblah, nor turn his back towards it}}
\hadithdefcmd{nasai}{21}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي أَيُّوبَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَسْتَقْبِلُوا الْقِبْلَةَ وَلاَ تَسْتَدْبِرُوهَا لِغَائِطٍ أَوْ بَوْلٍ وَلَكِنْ شَرِّقُوا أَوْ غَرِّبُوا ‏"‏ ‏.‏\hadithno{21}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Ayyub that the Prophet (ﷺ) said:"Do not face towards the Qiblah nor turn your backs toward it when defecating or urinating, rather face toward the east or the west}}
\hadithdefcmd{nasai}{22}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا غُنْدَرٌ، قَالَ أَنْبَأَنَا مَعْمَرٌ، قَالَ أَنْبَأَنَا ابْنُ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَى أَحَدُكُمُ الْغَائِطَ فَلاَ يَسْتَقْبِلِ الْقِبْلَةَ وَلَكِنْ لِيُشَرِّقْ أَوْ لِيُغَرِّبْ ‏"‏ ‏.‏\hadithno{22}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Ayyub Al-Ansari said:"The Messenger of Allah (ﷺ) said: 'When any one of you goes to defecate, let him not face toward the Qiblah, rather let him face towards the east or the west}}
\hadithdefcmd{nasai}{23}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ لَقَدِ ارْتَقَيْتُ عَلَى ظَهْرِ بَيْتِنَا فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى لَبِنَتَيْنِ مُسْتَقْبِلَ بَيْتِ الْمَقْدِسِ لِحَاجَتِهِ ‏.‏\hadithno{23}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"I climbed on the roof of our house and saw the Messenger of Allah (ﷺ) on two bricks, facing toward Bait Al-Maqdis (jerusalem), relieving himself}}
\hadithdefcmd{nasai}{24}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ أَنْبَأَنَا أَبُو إِسْمَاعِيلَ، - وَهُوَ الْقَنَّادُ - قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ عَبْدَ اللَّهِ بْنَ أَبِي قَتَادَةَ، حَدَّثَهُ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا بَالَ أَحَدُكُمْ فَلاَ يَأْخُذْ ذَكَرَهُ بِيَمِينِهِ ‏"‏ ‏.‏\hadithno{24}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin Abi Qatadah, from his father, that the Messenger of Allah (ﷺ said:"When any one of you urinates, let him not hold his penis in his right hand)}}
\hadithdefcmd{nasai}{25}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنْ هِشَامٍ، عَنْ يَحْيَى، - هُوَ ابْنُ أَبِي كَثِيرٍ - عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْخَلاَءَ فَلاَ يَمَسَّ ذَكَرَهُ بِيَمِينِهِ ‏"‏ ‏.‏\hadithno{25}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin Abi Qatadah that his father said:"The Messenger of Allah (ﷺ) said: 'When any one of you enters Al-Khala' (the toilet), let him not touch his penis with his right hand}}
\hadithdefcmd{nasai}{26}{أَخْبَرَنَا مُؤَمَّلُ بْنُ هِشَامٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى سُبَاطَةَ قَوْمٍ فَبَالَ قَائِمًا ‏.‏\hadithno{26}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hudhifah that the Messenger of Allah (ﷺ)came to some people's garbage dump and urinated while standing}}
\hadithdefcmd{nasai}{27}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ أَنْبَأَنَا مُحَمَّدٌ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، أَنَّ حُذَيْفَةَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى سُبَاطَةَ قَوْمٍ فَبَالَ قَائِمًا ‏.‏\hadithno{27}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Mansur said:"I heard Abu Wa'il (say) that Hudhaifah said: 'The Messenger of Allah (ﷺ) came to some people's garbage dump and urinated while standing}}
\hadithdefcmd{nasai}{28}{أَخْبَرَنَا سُلَيْمَانُ بْنُ عُبَيْدِ اللَّهِ، قَالَ أَنْبَأَنَا بَهْزٌ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، وَمَنْصُورٌ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَشَى إِلَى سُبَاطَةِ قَوْمٍ فَبَالَ قَائِمًا ‏.‏ قَالَ سُلَيْمَانُ فِي حَدِيثِهِ وَمَسَحَ عَلَى خُفَّيْهِ وَلَمْ يَذْكُرْ مَنْصُورٌ الْمَسْحَ ‏.‏\hadithno{28}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hudhaifah that the Prophet (ﷺ) went to some people's garbage dump and urinated while standing. In his narration, Sulaiman bin 'Ubaidullah said:"And he wiped over his Khuffs," but Mansur did not mention the wiping. [1] [1]Meaning, in this route, since Shu'bah narrated it from both Sulaiman and Mansur}}
\hadithdefcmd{nasai}{29}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا شَرِيكٌ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَنْ حَدَّثَكُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَالَ قَائِمًا فَلاَ تُصَدِّقُوهُ مَا كَانَ يَبُولُ إِلاَّ جَالِسًا ‏.‏\hadithno{29}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"Whoever tells you that the Messenger of Allah (ﷺ) urinated standing up, do not believe him, for he would not urinate except while squatting}}
\hadithdefcmd{nasai}{30}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ ابْنِ حَسَنَةَ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَفِي يَدِهِ كَهَيْئَةِ الدَّرَقَةِ فَوَضَعَهَا ثُمَّ جَلَسَ خَلْفَهَا فَبَالَ إِلَيْهَا فَقَالَ بَعْضُ الْقَوْمِ انْظُرُوا يَبُولُ كَمَا تَبُولُ الْمَرْأَةُ فَسَمِعَهُ فَقَالَ ‏ "‏ أَوَمَا عَلِمْتَ مَا أَصَابَ صَاحِبُ بَنِي إِسْرَائِيلَ كَانُوا إِذَا أَصَابَهُمْ شَىْءٌ مِنَ الْبَوْلِ قَرَضُوهُ بِالْمَقَارِيضِ فَنَهَاهُمْ صَاحِبُهُمْ فَعُذِّبَ فِي قَبْرِهِ ‏"‏ ‏.‏\hadithno{30}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdur-Rahman bin Hasanah said:"The Messenger of Allah (ﷺ) came out to us with a small leather shield in his hand. He put it down, then he sat behind it and urinated toward it. Some of the people said: 'Look, he is urinating like a woman.' He heard that and said: 'Do you not know what happened to the companion of the Children of Israel? If they got any urine on themselves they would clip that part of their garments off. Their companion told them not to do that and he was punished in his grave}}
\hadithdefcmd{nasai}{31}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ مُجَاهِدًا، يُحَدِّثُ عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى قَبْرَيْنِ فَقَالَ ‏"‏ إِنَّهُمَا يُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا هَذَا فَكَانَ لاَ يَسْتَنْزِهُ مِنْ بَوْلِهِ وَأَمَّا هَذَا فَإِنَّهُ كَانَ يَمْشِي بِالنَّمِيمَةِ ‏"‏ ‏.‏ ثُمَّ دَعَا بِعَسِيبٍ رَطْبٍ فَشَقَّهُ بِاثْنَيْنِ فَغَرَسَ عَلَى هَذَا وَاحِدًا وَعَلَى هَذَا وَاحِدًا ثُمَّ قَالَ ‏"‏ لَعَلَّهُ يُخَفَّفُ عَنْهُمَا مَا لَمْ يَيْبَسَا ‏"‏ ‏.‏ خَالَفَهُ مَنْصُورٌ رَوَاهُ عَنْ مُجَاهِدٍ عَنِ ابْنِ عَبَّاسٍ وَلَمْ يَذْكُرْ طَاوُسًا ‏.‏\hadithno{31}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) passed by two graves and said: 'These two are being punished, but they are not being punished for something that was difficult to avoid. As for this, he used not to take precautions to avoid (his body to clothes being soiled by) urine, and this one used to walk around spreading malicious gossip.' Then he called for a fresh palm-leaf stalk and split it in two, and placed one piece on each of the two graves. They said: 'O Messenger of Allah, why did you do that?' He said: 'Perhaps the torment will be reduced for them so long as this does not dry out.'" Mansur Contradicted him, he reported it from Mujahid from ibn 'Abbas but he did not mention Tawus in it}}
\hadithdefcmd{nasai}{32}{أَخْبَرَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الْوَزَّانُ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَتْنِي حُكَيْمَةُ بِنْتُ أُمَيْمَةَ، عَنْ أُمِّهَا، أُمَيْمَةَ بِنْتِ رُقَيْقَةَ قَالَتْ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم قَدَحٌ مِنْ عَيْدَانٍ يَبُولُ فِيهِ وَيَضَعُهُ تَحْتَ السَّرِيرِ ‏.‏\hadithno{32}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Umaimah bint Ruqaiqah said:"The Prophet (ﷺ) had a vessel made from a date tree in which he would urinate and place it under the bed}}
\hadithdefcmd{nasai}{33}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا أَزْهَرُ، أَنْبَأَنَا ابْنُ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ يَقُولُونَ إِنَّ النَّبِيَّ صلى الله عليه وسلم أَوْصَى إِلَى عَلِيٍّ لَقَدْ دَعَا بِالطَّسْتِ لِيَبُولَ فِيهَا فَانْخَنَثَتْ نَفْسُهُ وَمَا أَشْعُرُ فَإِلَى مَنْ أَوْصَى قَالَ الشَّيْخُ أَزْهَرُ هُوَ ابْنُ سَعْدٍ السَّمَّانُ ‏.‏\hadithno{33}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"They say that the Prophet (ﷺ) made a will for 'Ali,[1] but he called for a basin in which to urinate, then he went flaccid suddenly (and died), so how could he leave a will?!" The Shaikh said: Azhar (one of the narrators) is Ibn Sa'd As-Samman. [1] Meaning, appointing him as the Khalifah}}
\hadithdefcmd{nasai}{34}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ أَنْبَأَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي جُحْرٍ ‏"‏ ‏.‏ قَالُوا لِقَتَادَةَ وَمَا يُكْرَهُ مِنَ الْبَوْلِ فِي الْجُحْرِ قَالَ يُقَالُ إِنَّهَا مَسَاكِنُ الْجِنِّ ‏.‏\hadithno{34}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Qatadah, from 'Abdullah bin Sarjis, that the Prophet of Allah (ﷺ) said:"None of you should urinate into a burrow in the ground." They said to Qatadah: "Why is it disliked to urinate into a burrow in the ground?" He said: "It is said that these are dwelling-places of the jinn}}
\hadithdefcmd{nasai}{35}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ الْبَوْلِ فِي الْمَاءِ الرَّاكِدِ ‏.‏\hadithno{35}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) forbade urinating into standing water}}
\hadithdefcmd{nasai}{36}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الأَشْعَثِ بْنِ عَبْدِ اللَّهِ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي مُسْتَحَمِّهِ فَإِنَّ عَامَّةَ الْوَسْوَاسِ مِنْهُ ‏"‏ ‏.‏\hadithno{36}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Mughaffal that the Prophet (ﷺ) said:"None of you should urinate in the place where he bathes, for most Waswas (devilish whispers) [1] come from that." [1] I.e., with regard to whether the urine has soiled his body or not}}
\hadithdefcmd{nasai}{37}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، وَقَبِيصَةُ، قَالاَ أَنْبَأَنَا سُفْيَانُ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَرَّ رَجُلٌ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَبُولُ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْهِ السَّلاَمَ ‏.‏\hadithno{37}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"A man passed by the Prophet (ﷺ) when he was urinating and greeted him with Salam, but he did not return his greeting}}
\hadithdefcmd{nasai}{38}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، قَالَ أَنْبَأَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ حُضَيْنٍ أَبِي سَاسَانَ، عَنِ الْمُهَاجِرِ بْنِ قُنْفُذٍ، أَنَّهُ سَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَبُولُ فَلَمْ يَرُدَّ عَلَيْهِ السَّلاَمَ حَتَّى تَوَضَّأَ فَلَمَّا تَوَضَّأَ رَدَّ عَلَيْهِ ‏.‏\hadithno{38}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Muhajir bin Qunfudh that he greeted the Prophet (ﷺ) with Salam while he was urinating, and he did not return the greeting until he had performed Wudu'. When he had performed Wudu' he returned the greeting}}
\hadithdefcmd{nasai}{39}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُثْمَانَ بْنِ سَنَّةَ الْخُزَاعِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَسْتَطِيبَ أَحَدُكُمْ بِعَظْمٍ أَوْ رَوْثٍ ‏.‏\hadithno{39}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin Mas'ud, that the Messenger of Allah (ﷺ) forbade cleaning oneself with bones or dung}}
\hadithdefcmd{nasai}{40}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، قَالَ أَخْبَرَنِي الْقَعْقَاعُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا أَنَا لَكُمْ مِثْلُ الْوَالِدِ أُعَلِّمُكُمْ إِذَا ذَهَبَ أَحَدُكُمْ إِلَى الْخَلاَءِ فَلاَ يَسْتَقْبِلِ الْقِبْلَةَ وَلاَ يَسْتَدْبِرْهَا وَلاَ يَسْتَنْجِ بِيَمِينِهِ ‏"‏ وَكَانَ يَأْمُرُ بِثَلاَثَةِ أَحْجَارٍ وَنَهَى عَنِ الرَّوْثِ وَالرِّمَّةِ ‏.‏\hadithno{40}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"I am like a father teaching you. When any one of you goes to Al-Khala' (the toilet), let him not face toward the Qiblah nor turn his back toward it, and let him not clean himself with his right hand." And he used to tell them to use three stones, and he forbade using dung or old bones}}
\hadithdefcmd{nasai}{41}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ سَلْمَانَ، قَالَ قَالَ لَهُ رَجُلٌ إِنَّ صَاحِبَكُمْ لَيُعَلِّمُكُمْ حَتَّى الْخِرَاءَةَ ‏.‏ قَالَ أَجَلْ نَهَانَا أَنْ نَسْتَقْبِلَ الْقِبْلَةَ بِغَائِطٍ أَوْ بَوْلٍ أَوْ نَسْتَنْجِيَ بِأَيْمَانِنَا أَوْ نَكْتَفِيَ بِأَقَلَّ مِنْ ثَلاَثَةِ أَحْجَارٍ ‏.‏\hadithno{41}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Salman said, that a man said to him:"Your companion (meaning, the Prophet(ﷺ)) even teaches you how to go to the toilet!" He said: "Yes, he forbade us from facing the Qiblah when defecating or urinating, or cleaning ourselves with out right hands, or to use less than three stones}}
\hadithdefcmd{nasai}{42}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ زُهَيْرٍ، عَنْ أَبِي إِسْحَاقَ، قَالَ لَيْسَ أَبُو عُبَيْدَةَ ذَكَرَهُ وَلَكِنْ عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ عَنْ أَبِيهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ، يَقُولُ أَتَى النَّبِيُّ صلى الله عليه وسلم الْغَائِطَ وَأَمَرَنِي أَنْ آتِيَهُ بِثَلاَثَةِ أَحْجَارٍ فَوَجَدْتُ حَجَرَيْنِ وَالْتَمَسْتُ الثَّالِثَ فَلَمْ أَجِدْهُ فَأَخَذْتُ رَوْثَةً فَأَتَيْتُ بِهِنَّ النَّبِيَّ صلى الله عليه وسلم فَأَخَذَ الْحَجَرَيْنِ وَأَلْقَى الرَّوْثَةَ وَقَالَ ‏ "‏ هَذِهِ رِكْسٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الرِّكْسُ طَعَامُ الْجِنِّ ‏.‏\hadithno{42}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdur-Rahman bin Al-Aswad (narrated) from his father that he heard 'Abdullah say:"The Prophet (ﷺ) wanted to defecate, and he told me to bring him three stones. I found two stones and looked for a third, but I could not find any, so I picked up a piece of dung and brought them to the Prophet (ﷺ). He took the two stones and three away the dung and said: "This is Riks." Abu 'Abdur-Rahman (An-Nasai') said: Riks is the food of the jinn}}
\hadithdefcmd{nasai}{43}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاَهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ سَلَمَةَ بْنِ قَيْسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَجْمَرْتَ فَأَوْتِرْ ‏"‏ ‏.‏\hadithno{43}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Salamah bin Qais that the Messenger of Allah (ﷺ) said:"When you clean yourselves (with stones, after defecating), use an odd number}}
\hadithdefcmd{nasai}{44}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ مُسْلِمِ بْنِ قُرْطٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا ذَهَبَ أَحَدُكُمْ إِلَى الْغَائِطِ فَلْيَذْهَبْ مَعَهُ بِثَلاَثَةِ أَحْجَارٍ فَلْيَسْتَطِبْ بِهَا فَإِنَّهَا تَجْزِي عَنْهُ ‏"‏ ‏.‏\hadithno{44}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) said:"When any one of you goes to the Gha'it (toilet to defecate), let him take with him three stones and clean himself with them, for that will suffice him}}
\hadithdefcmd{nasai}{45}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ أَحْمِلُ أَنَا وَغُلاَمٌ مَعِي نَحْوِي إِدَاوَةً مِنْ مَاءٍ فَيَسْتَنْجِي بِالْمَاءِ ‏.‏\hadithno{45}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik said:"When the Messenger of Allah (ﷺ) would go to the toilet, I and another boy like me would bring a small leather vessel of water and he would clean himself with water}}
\hadithdefcmd{nasai}{46}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ مُعَاذَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ مُرْنَ أَزْوَاجَكُنَّ أَنْ يَسْتَطِيبُوا بِالْمَاءِ فَإِنِّي أَسْتَحْيِيهِمْ مِنْهُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُهُ ‏.‏\hadithno{46}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"Tell your husbands to clean themselves with water, for I am too shy to tell them myself. The Messenger of Allah (ﷺ) used to do that}}
\hadithdefcmd{nasai}{47}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ أَنْبَأَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَرِبَ أَحَدُكُمْ فَلاَ يَتَنَفَّسْ فِي إِنَائِهِ وَإِذَا أَتَى الْخَلاَءَ فَلاَ يَمَسَّ ذَكَرَهُ بِيَمِينِهِ وَلاَ يَتَمَسَّحْ بِيَمِينِهِ ‏"‏ ‏.‏\hadithno{47}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Qatadah that the Messenger of Allah (ﷺ) said:"When any one of you drinks, let him not breathe into the vessel, and when he goes to the toilet let him not touch his penis with his right hand, nor wipe himself with this right hand}}
\hadithdefcmd{nasai}{48}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنِ ابْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَتَنَفَّسَ فِي الإِنَاءِ وَأَنْ يَمَسَّ ذَكَرَهُ بِيَمِينِهِ وَأَنْ يَسْتَطِيبَ بِيَمِينِهِ ‏.‏\hadithno{48}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abi Qatadah, from his father, that the Prophet (ﷺ) forbade breathing into the vessel (when drinking), touching one's penis with one's right hand, and cleaning oneself with one's right hand}}
\hadithdefcmd{nasai}{49}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَشُعَيْبُ بْنُ يُوسُفَ، وَاللَّفْظُ، لَهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ سَلْمَانَ، قَالَ قَالَ الْمُشْرِكُونَ إِنَّا لَنَرَى صَاحِبَكُمْ يُعَلِّمُكُمُ الْخِرَاءَةَ ‏.‏ قَالَ أَجَلْ نَهَانَا أَنْ يَسْتَنْجِيَ أَحَدُنَا بِيَمِينِهِ وَيَسْتَقْبِلَ الْقِبْلَةَ وَقَالَ ‏ "‏ لاَ يَسْتَنْجِي أَحَدُكُمْ بِدُونِ ثَلاَثَةِ أَحْجَارٍ ‏"‏ ‏.‏\hadithno{49}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Salman said:"The idolators said: 'We see that your companion teaches you how to go to the toilet.' He said: 'Yes, he forbade us from cleaning ourselves with our right hand, and from facing toward the Qiblah, and he said: 'None of you should clean with less than three stones}}
\hadithdefcmd{nasai}{50}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ إِبْرَاهِيمَ بْنِ جَرِيرٍ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ فَلَمَّا اسْتَنْجَى دَلَكَ يَدَهُ بِالأَرْضِ ‏.‏\hadithno{50}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) performed Wudu', and when he had performed Istinja' he rubbed his hand on the ground}}
\hadithdefcmd{nasai}{51}{أَخْبَرَنَا أَحْمَدُ بْنُ الصَّبَّاحِ، قَالَ حَدَّثَنَا شُعَيْبٌ، - يَعْنِي ابْنَ حَرْبٍ - قَالَ حَدَّثَنَا أَبَانُ بْنُ عَبْدِ اللَّهِ الْبَجَلِيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ جَرِيرٍ، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَأَتَى الْخَلاَءَ فَقَضَى الْحَاجَةَ ثُمَّ قَالَ ‏ "‏ يَا جَرِيرُ هَاتِ طَهُورًا ‏"‏ ‏.‏ فَأَتَيْتُهُ بِالْمَاءِ فَاسْتَنْجَى بِالْمَاءِ وَقَالَ بِيَدِهِ فَدَلَكَ بِهَا الأَرْضَ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا أَشْبَهُ بِالصَّوَابِ مِنْ حَدِيثِ شَرِيكٍ وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{51}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Ibrahim bin Jarir narrated that his father said:"I was with the Prophet (ﷺ) and he went to Al Khala' (toilet) and relieved himself, then he said: "O Jarir, bring Tahur (a means of purification)." So I brought him some water and he performed Intinja' with water, and did like this with hand, rubbing it on the ground. Abu 'Abdur-Rahman (An-Nasa'i) said: "This resembles more with what is correct than the (previous) narration of Sharik, and Allah knows best}}
\hadithdefcmd{nasai}{52}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، وَالْحُسَيْنُ بْنُ حُرَيْثٍ، عَنْ أَبِي أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمَاءِ وَمَا يَنُوبُهُ مِنَ الدَّوَابِّ وَالسِّبَاعِ ‏.‏ فَقَالَ ‏ "‏ إِذَا كَانَ الْمَاءُ قُلَّتَيْنِ لَمْ يَحْمِلِ الْخَبَثَ ‏"‏ ‏.‏\hadithno{52}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Abdullah bin 'Umar that his father said:"The Messenger of Allah (ﷺ) was asked about water and how some animals and carnivorous beasts might drink from it. He said: 'If the water is more than two Qullahs, it will not carry filth.'"[1] [1]It comes with some explanation in Sunan At Timidhi 'Abdah (one of the narrators) said: "Muhammad bin Ishaq said: 'A Qullah refers to Jirar (These are two nouns describing large casks that are used to hold water), and a Qullah is the thing that drinking water is held in."' At-Tirmidhi said: "This is the saying of Ash Shafa'i, Ahmad and Ishaq. They say that when the water is two Qullahs then nothing makes it impure, as long as it does not change its smell, and its taste. And they say, it is approximately fifty Qirbahs (waterskins)}}
\hadithdefcmd{nasai}{53}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ أَعْرَابِيًّا، بَالَ فِي الْمَسْجِدِ فَقَامَ إِلَيْهِ بَعْضُ الْقَوْمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعُوهُ لاَ تُزْرِمُوهُ ‏"‏ ‏.‏ فَلَمَّا فَرَغَ دَعَا بِدَلْوٍ فَصَبَّهُ عَلَيْهِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ يَعْنِي لاَ تَقْطَعُوا عَلَيْهِ ‏.‏\hadithno{53}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that a Bedouin urinated in the Masjid, and some of the people went after him, but the Messenger of Allah (ﷺ) said:"Leave him and do not restrain him." When he had finished he called for a bucket (of water) and poured it over it. [1] Abu 'Abdur-Rahman (An-Nasa'i) said: "Meaning: 'Do not interrupt him.'" [1]The author will cite this narration again in No. 330 as a possible proof for setting the minimum, since it mentions "a bucket" as if this is the minium amount required}}
\hadithdefcmd{nasai}{54}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبِيدَةُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَنَسٍ، قَالَ بَالَ أَعْرَابِيٌّ فِي الْمَسْجِدِ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِدَلْوٍ مِنْ مَاءٍ فَصُبَّ عَلَيْهِ ‏.‏\hadithno{54}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"A Bedouin urinated in the Masjid, and the Prophet (ﷺ) ordered that a bucket (be brought) and poured over it}}
\hadithdefcmd{nasai}{55}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ جَاءَ أَعْرَابِيٌّ إِلَى الْمَسْجِدِ فَبَالَ فَصَاحَ بِهِ النَّاسُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اتْرُكُوهُ ‏"‏ ‏.‏ فَتَرَكُوهُ حَتَّى بَالَ ثُمَّ أَمَرَ بِدَلْوٍ فَصُبَّ عَلَيْهِ ‏.‏\hadithno{55}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas said:"A Bedouin came to the Masjid and urinated, and the people yelled at him, but the Messenger of Allah (ﷺ) said: 'Leave him alone.' So they left him alone. When he had finished urinating, he ordered that a bucket (be brought) and poured over it}}
\hadithdefcmd{nasai}{56}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، عَنْ عُمَرَ بْنِ عَبْدِ الْوَاحِدِ، عَنِ الأَوْزَاعِيِّ، عَنْ مُحَمَّدِ بْنِ الْوَلِيدِ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَامَ أَعْرَابِيٌّ فَبَالَ فِي الْمَسْجِدِ فَتَنَاوَلَهُ النَّاسُ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعُوهُ وَأَهْرِيقُوا عَلَى بَوْلِهِ دَلْوًا مِنْ مَاءٍ فَإِنَّمَا بُعِثْتُمْ مُيَسِّرِينَ وَلَمْ تُبْعَثُوا مُعَسِّرِينَ ‏"‏ ‏.‏\hadithno{56}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"A Bedouin stood up and urinated in the Masjid, ans the people started shouting. The Messenger of Allah (ﷺ) said to them: 'Leave him alone, and spill a bucket of water over his urine. For you have been sent to make things easy for people, you have not been sent to make things difficult}}
\hadithdefcmd{nasai}{57}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا عَوْفٌ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ ثُمَّ يَتَوَضَّأُ مِنْهُ ‏"‏ ‏.‏ قَالَ عَوْفٌ وَقَالَ خِلاَسٌ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{57}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"None of you should urinate into still water and then perform Wudu' with it}}
\hadithdefcmd{nasai}{58}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ يَحْيَى بْنِ عَتِيقٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ ثُمَّ يَغْتَسِلُ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ كَانَ يَعْقُوبُ لاَ يُحَدِّثُ بِهَذَا الْحَدِيثِ إِلاَّ بِدِينَارٍ ‏.‏\hadithno{58}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'None of you should urinate in still water and perform Ghusl with it.'" Abu 'Abdur-Rahman (An-Nasa'i) said: "ya'qub would not narrate this Hadith except for a Dinar."[1] [1] Ya'qub bin Ibrahim Ad-Dawrqi, and the meaning is that he held the view that it is permissible to accept a payment for narrating, contrary to many others}}
\hadithdefcmd{nasai}{59}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ سَلَمَةَ، أَنَّ الْمُغِيرَةَ بْنَ أَبِي بُرْدَةَ، مِنْ بَنِي عَبْدِ الدَّارِ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نَرْكَبُ الْبَحْرَ وَنَحْمِلُ مَعَنَا الْقَلِيلَ مِنَ الْمَاءِ فَإِنْ تَوَضَّأْنَا بِهِ عَطِشْنَا أَفَنَتَوَضَّأُ مِنْ مَاءِ الْبَحْرِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏\hadithno{59}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said:"A man asked the Prophet (ﷺ): 'O Messenger of Allah, we travel by sea and we take a little water with us, but if we use it for Wudu', we will go thirsty. Can we perform Wudu', with sea-water?' The Messenger of Allah (ﷺ) said: 'Its water is a means of purification and its dead meat is permissible}}
\hadithdefcmd{nasai}{60}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اسْتَفْتَحَ الصَّلاَةَ سَكَتَ هُنَيْهَةً فَقُلْتُ بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ مَا تَقُولُ فِي سُكُوتِكَ بَيْنَ التَّكْبِيرِ وَالْقِرَاءَةِ قَالَ ‏ "‏ أَقُولُ اللَّهُمَّ بَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ اللَّهُمَّ نَقِّنِي مِنْ خَطَايَاىَ كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ اللَّهُمَّ اغْسِلْنِي مِنْ خَطَايَاىَ بِالثَّلْجِ وَالْمَاءِ وَالْبَرَدِ ‏"‏ ‏.‏\hadithno{60}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"When the Messenger of Allah (ﷺ) started Salah, he would remain silent for a short while. I said: 'May my father and mother be ransomed for you, O Messenger of Allah! What do you say when you remain silent between the Takbir and the recitation (in the Salah)?' He said: 'I say: Allahumma ba'id baini was baina khatayaya kama ba'adta baina al-mashriq wal-maghrib; Allahumma naqqini min khatayaya kama yunaqqath-thawb al-abyad min ad-danas; Allahummaghsilni min khatayaya bith-thalji wal-ma'i wal-barad (O Allah, out a great distance between me and my sins, as great as the distance You have made between the East and the West; O Allah, cleanse me of of sin as a white garment is cleansed from filth; Wash away my sins with snow, water, and hail)}}
\hadithdefcmd{nasai}{61}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ وَنَقِّ قَلْبِي مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ ‏"‏ ‏.‏\hadithno{61}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Prophet (ﷺ) used to say: 'Allahumaghsil khatayaya bi-ma'ith-thalj wal-barad was naqqi qalbi min al-khataya kama naqayta ath-thawb al-abyad min ad-danas (O Allah, was away my sins with the water of snow and hail, and cleanse my heart of sin as a white garment is cleansed of filth)}}
\hadithdefcmd{nasai}{62}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ حَبِيبِ بْنِ عُبَيْدٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، قَالَ شَهِدْتُ عَوْفَ بْنَ مَالِكٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى مَيِّتٍ فَسَمِعْتُ مِنْ دُعَائِهِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لَهُ وَارْحَمْهُ وَعَافِهِ وَاعْفُ عَنْهُ وَأَكْرِمْ نُزُلَهُ وَأَوْسِعْ مُدْخَلَهُ وَاغْسِلْهُ بِالْمَاءِ وَالثَّلْجِ وَالْبَرَدِ وَنَقِّهِ مِنَ الْخَطَايَا كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ ‏"‏ ‏.‏\hadithno{62}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Awf bin Malik said:"I heard the Messenger of Allah (ﷺ) offering the (funeral) prayer for one who had died, and I heard him say in his supplication: 'Allahummaghfir lahu warhamhu wa 'afihi was a'fu 'anhu, wa akrim nuzulahu wa wassi' ,adkhalahu waghsilhu bil-ma'i wath-thalji wal-baradi wa naqqihi min al-khataya kama ynaqqath-thawb al-abyad min ad-danas. (O Allah, forgive him and have mercy on him, keep him safe and sound and forgive him, honor the place where he settles and make his entrance wide; wash him with water and snow and hail, and cleanse him of sin as a white garment is cleansed of dirt)}}
\hadithdefcmd{nasai}{63}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَرِبَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{63}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"If a dog drinks from the vessel of one of you, let him wash it seven times}}
\hadithdefcmd{nasai}{64}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي زِيَادُ بْنُ سَعْدٍ، أَنَّ ثَابِتًا، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{64}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Thabit, the freed slave of 'Abdur-Rahman bin Zaid narrated that he heard Abu Hurairah say:"The Messenger of Allah (ﷺ) said: 'If a dog licks the vessel of any one of you, let him wash it seven times}}
\hadithdefcmd{nasai}{65}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي زِيَادُ بْنُ سَعْدٍ، أَنَّهُ أَخْبَرَهُ هِلاَلُ بْنُ أُسَامَةَ، أَنَّهُ سَمِعَ أَبَا سَلَمَةَ، يُخْبِرُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{65}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A similar Hadith was narrated from Abu Hurairah from Prophet (ﷺ)}}
\hadithdefcmd{nasai}{66}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي رَزِينٍ، وَأَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيُرِقْهُ ثُمَّ لْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ أَعْلَمُ أَحَدًا تَابَعَ عَلِيَّ بْنَ مُسْهِرٍ عَلَى قَوْلِهِ فَلْيُرِقْهُ ‏.‏\hadithno{66}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'If a dog licks the vessel of any one of you, let him throw (the contents) away and wash it seven times.'" Abu 'Abdur-Rahman (An-Nasa'i) said: I do not know any one who followed 'Ali bin Mushir in narrating it with: "Let him throw it away}}
\hadithdefcmd{nasai}{67}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، قَالَ حَدَّثَنَا خَالِدٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ مُطَرِّفًا، عَنْ عَبْدِ اللَّهِ بْنِ الْمُغَفَّلِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ وَرَخَّصَ فِي كَلْبِ الصَّيْدِ وَالْغَنَمِ وَقَالَ ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي الإِنَاءِ فَاغْسِلُوهُ سَبْعَ مَرَّاتٍ وَعَفِّرُوهُ الثَّامِنَةَ بِالتُّرَابِ ‏"‏ ‏.‏\hadithno{67}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin Al-Mughaffal that the Messenger of Allah (ﷺ) commanded that dogs be killed, but he made an exception for hunting dogs and sheepdogs and said:"If a dog licks a vessel then wash it seven times, and rub it the eighth time with dust}}
\hadithdefcmd{nasai}{68}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ حُمَيْدَةَ بِنْتِ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ كَبْشَةَ بِنْتِ كَعْبِ بْنِ مَالِكٍ، أَنَّ أَبَا قَتَادَةَ، دَخَلَ عَلَيْهَا ثُمَّ ذَكَرَتْ كَلِمَةً مَعْنَاهَا فَسَكَبْتُ لَهُ وَضُوءًا فَجَاءَتْ هِرَّةٌ فَشَرِبَتْ مِنْهُ فَأَصْغَى لَهَا الإِنَاءَ حَتَّى شَرِبَتْ - قَالَتْ كَبْشَةُ - فَرَآنِي أَنْظُرُ إِلَيْهِ فَقَالَ أَتَعْجَبِينَ يَا ابْنَةَ أَخِي فَقُلْتُ نَعَمْ ‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهَا لَيْسَتْ بِنَجَسٍ إِنَّمَا هِيَ مِنَ الطَّوَّافِينَ عَلَيْكُمْ وَالطَّوَّافَاتِ ‏"‏ ‏.‏\hadithno{68}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Kabshah bint Ka'b bin Malik that Abu Qatadah entered upon her, then she narrated the following:"I poured some water from him for Wudu', and a cat came and drank from it, so he tilted the vessel for it to drink." Kabshah said: "He saw me looking at him and said: 'Are you surprised, O daughter of my brother?' I said: 'Yes.' He said: 'The Messenger of Allah (ﷺ) said: They are not impure, rather they are among the males and females (animals) who go around among you}}
\hadithdefcmd{nasai}{69}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، قَالَ أَتَانَا مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ اللَّهَ وَرَسُولَهُ يَنْهَاكُمْ عَنْ لُحُومِ الْحُمُرِ فَإِنَّهَا رِجْسٌ ‏.‏\hadithno{69}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"An announcer came to us from the Messenger of Allah (ﷺ) and said: 'Allah and His Messenger forbid you from (eating) the flesh of domestic donkeys, for it is filth}}
\hadithdefcmd{nasai}{70}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ أَتَعَرَّقُ الْعَرْقَ فَيَضَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاهُ حَيْثُ وَضَعْتُ وَأَنَا حَائِضٌ وَكُنْتُ أَشْرَبُ مِنَ الإِنَاءِ فَيَضَعُ فَاهُ حَيْثُ وَضَعْتُ وَأَنَا حَائِضٌ ‏.‏\hadithno{70}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah, may Allah be pleased with her, said:"While I was menstruating, I would nibble meat from a bone, and the Messenger of Allah (ﷺ) would put his mouth where mine had been. And while I was menstruating, I would drink from a vessel and he would put his mouth where mine had been}}
\hadithdefcmd{nasai}{71}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، ح وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ الرِّجَالُ وَالنِّسَاءُ يَتَوَضَّئُونَ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم جَمِيعًا ‏.‏\hadithno{71}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Umar said:"Men and women used to perform Wudu' together during the time of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{72}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، كَانَتْ تَغْتَسِلُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الإِنَاءِ الْوَاحِدِ ‏.‏\hadithno{72}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that she used to perform Ghusl with the Messenger of Allah (ﷺ) from a single vessel}}
\hadithdefcmd{nasai}{73}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ جَبْرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ بِمَكُّوكٍ وَيَغْتَسِلُ بِخَمْسَةِ مَكَاكِيَّ ‏.‏\hadithno{73}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin Jabr said:"I heard Anas bin Malik say: 'The Messenger of Allah (ﷺ) used to perform Wudu' with a Makkuk (cup) and Ghusl with five Makkuks (cups)}}
\hadithdefcmd{nasai}{74}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبٍ، قَالَ سَمِعْتُ عَبَّادَ بْنَ تَمِيمٍ، يُحَدِّثُ عَنْ جَدَّتِي، وَهِيَ أُمُّ عُمَارَةَ بِنْتُ كَعْبٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ فَأُتِيَ بِمَاءٍ فِي إِنَاءٍ قَدْرَ ثُلُثَىِ الْمُدِّ ‏.‏ قَالَ شُعْبَةُ فَأَحْفَظُ أَنَّهُ غَسَلَ ذِرَاعَيْهِ وَجَعَلَ يَدْلُكُهُمَا وَيَمْسَحُ أُذُنَيْهِ بَاطِنَهُمَا وَلاَ أَحْفَظُ أَنَّهُ مَسَحَ ظَاهِرَهُمَا ‏.‏\hadithno{74}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Shu'bah that Habib said:"I heard 'Abbad bin Tamim narrate from my grandmother - who was Umm 'Umarah bint Ka'b - that the Prophet (ﷺ) performed Wudu', and he was brought a vessel in which there were two-thirds of a Mudd." Shu'bah said: "I remember that he washed his forearms and started rubbing them, and he wiped the inside of his ear, but I do not remember whether he wiped the outside of them}}
\hadithdefcmd{nasai}{75}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، عَنْ حَمَّادٍ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، حَدَّثَنِي مَالِكٌ، ح وَأَخْبَرَنَا سُلَيْمَانُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، - وَاللَّفْظُ لَهُ - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الأَعْمَالُ بِالنِّيَّةِ وَإِنَّمَا لاِمْرِئٍ مَا نَوَى فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ وَمَنْ كَانَتْ هِجْرَتُهُ إِلَى دُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَنْكِحُهَا فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{75}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Umar bin Al-Khattab (may Allah be pleased with him) said:"The Messenger of Allah said: 'Actions are only done with intentions, and every man shall have what he intended. Thus he whose emigration was for Allah and His Messenger, his emigration was for Allah and His Messenger, and he whose emigration was to achieve some worldly benefit or to take some woman in marriage, his emigration was for that which he intended}}
\hadithdefcmd{nasai}{76}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَحَانَتْ صَلاَةُ الْعَصْرِ فَالْتَمَسَ النَّاسُ الْوَضُوءَ فَلَمْ يَجِدُوهُ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَضُوءٍ فَوَضَعَ يَدَهُ فِي ذَلِكَ الإِنَاءِ وَأَمَرَ النَّاسَ أَنْ يَتَوَضَّئُوا فَرَأَيْتُ الْمَاءَ يَنْبُعُ مِنْ تَحْتِ أَصَابِعِهِ حَتَّى تَوَضَّئُوا مِنْ عِنْدِ آخِرِهِمْ ‏.‏\hadithno{76}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"I saw the Messenger of Allah (ﷺ) when the time for 'Asr prayer had come. The people looked for (water for) Wudu' but they could not find any. Then some (water for) Wudu' was brought to the Messenger of Allah (ﷺ). He put his hand in that vessel and told the poeple to perform Wudu', and I saw water springing from beneath his fingers, until they had all performed Wudu}}
\hadithdefcmd{nasai}{77}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَجِدُوا مَاءً فَأُتِيَ بِتَوْرٍ فَأَدْخَلَ يَدَهُ فَلَقَدْ رَأَيْتُ الْمَاءَ يَتَفَجَّرُ مِنْ بَيْنِ أَصَابِعِهِ وَيَقُولُ ‏ "‏ حَىَّ عَلَى الطَّهُورِ وَالْبَرَكَةِ مِنَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَ الأَعْمَشُ فَحَدَّثَنِي سَالِمُ بْنُ أَبِي الْجَعْدِ قَالَ قُلْتُ لِجَابِرٍ كَمْ كُنْتُمْ يَوْمَئِذٍ قَالَ أَلْفٌ وَخَمْسُمِائَةٍ ‏.‏\hadithno{77}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"We were with the Prophet (ﷺ) and they could not find any water. A vessel was brought to him and he put his hand in it, and I saw water springing from between his fingers. He said: 'Come to a means of purification and a blessing from Allah, may He be glorified.'" (One of the narrators) Al-A'mash said: "Salim bin Abi Al-Ja'd told me: I said to Jabir: "How many were you that day?' He said: "One thousand five hundred}}
\hadithdefcmd{nasai}{78}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، وَقَتَادَةُ، عَنْ أَنَسٍ، قَالَ طَلَبَ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَضُوءًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ مَعَ أَحَدٍ مِنْكُمْ مَاءٌ ‏"‏ ‏.‏ فَوَضَعَ يَدَهُ فِي الْمَاءِ وَيَقُولُ ‏"‏ تَوَضَّئُوا بِسْمِ اللَّهِ ‏"‏ ‏.‏ فَرَأَيْتُ الْمَاءَ يَخْرُجُ مِنْ بَيْنِ أَصَابِعِهِ حَتَّى تَوَضَّئُوا مِنْ عِنْدِ آخِرِهِمْ ‏.‏ قَالَ ثَابِتٌ قُلْتُ لأَنَسٍ كَمْ تُرَاهُمْ قَالَ نَحْوًا مِنْ سَبْعِينَ ‏.‏\hadithno{78}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"Some of the Companions of the Prophet (ﷺ) were looking for (water for) Wudu'. The Messenger of Allah (ﷺ) said: 'Do any of you have water?' He put his hand in the water and said: 'Perform Wudu' in the Name of Allah.' I saw the water coming out from between his fingers until they had all performed Wudu'." Thabit said: "I said to Anas: 'How many did you see?' He said: 'About seventy}}
\hadithdefcmd{nasai}{79}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ وَهْبٍ، عَنْ مَالِكٍ، وَيُونُسَ، وَعَمْرِو بْنِ الْحَارِثِ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُمْ عَنْ عَبَّادِ بْنِ زِيَادٍ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ، أَنَّهُ سَمِعَ أَبَاهُ، يَقُولُ سَكَبْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ تَوَضَّأَ فِي غَزْوَةِ تَبُوكَ فَمَسَحَ عَلَى الْخُفَّيْنِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لَمْ يَذْكُرْ مَالِكٌ عُرْوَةَ بْنَ الْمُغِيرَةِ ‏.‏\hadithno{79}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Urwah bin Al-Mughirah that he heard his father say:"I poured water for the Messenger of Allah (ﷺ) when he performed Wudu' during the battle of Tabuk, and he wiped over his Khuff}}
\hadithdefcmd{nasai}{80}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَلاَ أُخْبِرُكُمْ بِوُضُوءِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَوَضَّأَ مَرَّةً مَرَّةً ‏.‏\hadithno{80}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Abbas said:"Shall I not tell you of the Wudu' of the Messenger of Allah (ﷺ)? He performed Wudu' by washing each part of the body once}}
\hadithdefcmd{nasai}{81}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، قَالَ أَنْبَأَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي الْمُطَّلِبُ بْنُ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، تَوَضَّأَ ثَلاَثًا ثَلاَثًا يُسْنِدُ ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{81}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Muttalib bin 'Abdullah bin Hantab (narrated) that 'Abdullah bin 'Umar performed Wudu', washing each part of the body three times, and he attributed that to the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{82}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ الْبَصْرِيُّ، عَنْ بِشْرِ بْنِ الْمُفَضَّلِ، عَنِ ابْنِ عَوْنٍ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ، عَنِ الْمُغِيرَةِ، وَعَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ رَجُلٍ، حَتَّى رَدَّهُ إِلَى الْمُغِيرَةِ - قَالَ ابْنُ عَوْنٍ وَلاَ أَحْفَظُ حَدِيثَ ذَا مِنْ حَدِيثِ ذَا - أَنَّ الْمُغِيرَةَ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَقَرَعَ ظَهْرِي بِعَصًا كَانَتْ مَعَهُ فَعَدَلَ وَعَدَلْتُ مَعَهُ حَتَّى أَتَى كَذَا وَكَذَا مِنَ الأَرْضِ فَأَنَاخَ ثُمَّ انْطَلَقَ ‏.‏ قَالَ فَذَهَبَ حَتَّى تَوَارَى عَنِّي ثُمَّ جَاءَ فَقَالَ ‏"‏ أَمَعَكَ مَاءٌ ‏"‏ ‏.‏ وَمَعِي سَطِيحَةٌ لِي فَأَتَيْتُهُ بِهَا فَأَفْرَغْتُ عَلَيْهِ فَغَسَلَ يَدَيْهِ وَوَجْهَهُ وَذَهَبَ لِيَغْسِلَ ذِرَاعَيْهِ وَعَلَيْهِ جُبَّةٌ شَامِيَّةٌ ضَيِّقَةُ الْكُمَّيْنِ فَأَخْرَجَ يَدَهُ مِنْ تَحْتِ الْجُبَّةِ فَغَسَلَ وَجْهَهُ وَذِرَاعَيْهِ وَذَكَرَ مِنْ نَاصِيَتِهِ شَيْئًا وَعِمَامَتِهِ شَيْئًا - قَالَ ابْنُ عَوْنٍ لاَ أَحْفَظُ كَمَا أُرِيدُ ثُمَّ مَسَحَ عَلَى خُفَّيْهِ - ثُمَّ قَالَ ‏"‏ حَاجَتَكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ لَيْسَتْ لِي حَاجَةٌ فَجِئْنَا وَقَدْ أَمَّ النَّاسَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ وَقَدْ صَلَّى بِهِمْ رَكْعَةً مِنْ صَلاَةِ الصُّبْحِ فَذَهَبْتُ لأُوذِنَهُ فَنَهَانِي فَصَلَّيْنَا مَا أَدْرَكْنَا وَقَضَيْنَا مَا سُبِقْنَا ‏.‏\hadithno{82}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Mughirah said:"We were with the Prophet (ﷺ) on a journey, and he tapped me on the back with a stick he had with him, then he turned off (route) and I turned off with him until he came to such and such an area. Then he made his camel stop and went away until he disappeared from me, then he came back and said: 'Do you have water with you?' I had a water skin with me, so I brought it out and poured it for him. He washed his hands and face and began to wash his arms, but he was wearing a Syrian Jubbah[1] that had narrow sleeves, so he brought his arms out from beneath the Jubbah and washed his hands and arms, and wiped his forelock a little and his turban a little." - Ibn 'Awn said: "I cannot remember it well - then he wiped over his Khuffs." Then he said: 'What do you need?' I said: 'O Messenger of Allah, I do not need anything.' Then we came and 'Abdur-Rahman bin 'Awf was leading the people in Salah, and he had led them in one Rak'ah of the Subh (Fajr) prayer. I wanted to tell him that the Prophet (ﷺ) had arrived but he did not let me, so we prayed what we had caught up with and made up what we had missed.'" [1] It is a type of cloak}}
\hadithdefcmd{nasai}{83}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ، - وَهُوَ ابْنُ حَبِيبٍ - عَنْ شُعْبَةَ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنِ ابْنِ أَبِي أَوْسٍ، عَنْ جَدِّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَوْكَفَ ثَلاَثًا ‏.‏\hadithno{83}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from (Aws bin) Abi Aws that his grandfather said:"I saw the Messenger of Allah (ﷺ) trickle water into his hand until it started to drip from his hand, three times}}
\hadithdefcmd{nasai}{84}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ حُمْرَانَ بْنِ أَبَانَ، قَالَ رَأَيْتُ عُثْمَانَ بْنَ عَفَّانَ - رضى الله عنه - تَوَضَّأَ فَأَفْرَغَ عَلَى يَدَيْهِ ثَلاَثًا فَغَسَلَهُمَا ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى إِلَى الْمِرْفَقِ ثَلاَثًا ثُمَّ الْيُسْرَى مِثْلَ ذَلِكَ ثُمَّ مَسَحَ بِرَأْسِهِ ثُمَّ غَسَلَ قَدَمَهُ الْيُمْنَى ثَلاَثًا ثُمَّ الْيُسْرَى مِثْلَ ذَلِكَ ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ نَحْوَ وُضُوئِي ثُمَّ قَالَ ‏ "‏ مَنْ تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا ثُمَّ صَلَّى رَكْعَتَيْنِ لاَ يُحَدِّثُ نَفْسَهُ فِيهِمَا بِشَىْءٍ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{84}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Humran bin Aban said:"I saw 'Uthman bin 'Affan, may Allah be pleased with him, performing Wudu'. He poured water on his hands three times and washed them, then he rinsed his mouth and his nose, then he washed his face three times, then he washed his right arm to the elbow three times, then the left likewise. Then he wiped his head, then he washed his right foot three times, then the left likewise. Then he said: 'I saw the Messenger of Allah (ﷺ) performing Wudu' like I have just done. Then he said: 'Whoever performs Wudu' as I have done, then prays two rak'ahs without letting his thoughts wander, his previous sins will be forgiven}}
\hadithdefcmd{nasai}{85}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ، - هُوَ ابْنُ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ عَنْ - شُعَيْبٍ، - هُوَ ابْنُ أَبِي حَمْزَةَ - عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَطَاءُ بْنُ يَزِيدَ، عَنْ حُمْرَانَ، أَنَّهُ رَأَى عُثَّمَانَ دَعَا بِوَضُوءٍ فَأَفْرَغَ عَلَى يَدَيْهِ مِنْ إِنَائِهِ فَغَسَلَهَا ثَلاَثَ مَرَّاتٍ ثُمَّ أَدْخَلَ يَمِينَهُ فِي الْوَضُوءِ فَتَمَضْمَضَ وَاسْتَنْشَقَ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ ثَلاَثَ مَرَّاتٍ ثُمَّ مَسَحَ بِرَأْسِهِ ثُمَّ غَسَلَ كُلَّ رِجْلٍ مِنْ رِجْلَيْهِ ثَلاَثَ مَرَّاتٍ ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ وُضُوئِي هَذَا ثُمَّ قَالَ ‏ "‏ مَنْ تَوَضَّأَ مِثْلَ وُضُوئِي هَذَا ثُمَّ قَامَ فَصَلَّى رَكْعَتَيْنِ لاَ يُحَدِّثُ فِيهِمَا نَفْسَهُ بِشَىْءٍ غَفَرَ اللَّهُ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{85}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Humran that he saw 'Uthman call for (water for) Wudu', then he poured water on his hands from the vessel and washed them three times. Then he put his right hand in the water and rinsed his mouth and his nose. Then he washed his face three times, and his arms up to the elbow three times. Then he wiped his head, and washed each of his feet three times. Then he said:"I saw the Messenger of Allah (ﷺ) performing Wudu' like I have just done." Then he said: "Whoever performs Wudu' as I have done, then stands and prays two Rak'ahs without letting his thoughts wander, his previous sins will be forgiven}}
\hadithdefcmd{nasai}{86}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو الزِّنَادِ، ح وَحَدَّثَنَا الْحُسَيْنُ بْنُ عِيسَى، عَنْ مَعْنٍ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ أَحَدُكُمْ فَلْيَجْعَلْ فِي أَنْفِهِ مَاءً ثُمَّ لْيَسْتَنْثِرْ ‏"‏ ‏.‏\hadithno{86}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"When any one of you performs Wudu', let him put water in his nose then blow it out}}
\hadithdefcmd{nasai}{87}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ كَثِيرٍ، ح وَأَنْبَأَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي هَاشِمٍ، عَنْ عَاصِمِ بْنِ لَقِيطِ بْنِ صَبْرَةَ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَخْبِرْنِي عَنِ الْوُضُوءِ، قَالَ ‏ "‏ أَسْبِغِ الْوُضُوءَ وَبَالِغْ فِي الاِسْتِنْشَاقِ إِلاَّ أَنْ تَكُونَ صَائِمًا ‏"‏ ‏.‏\hadithno{87}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Asim bin Laqit bin Sabirah that his father said:"I said: 'O Messenger of Allah, tell me about Wudu." He said: 'Perform Wudu' well,[1] and exxagerate in sniffing water up into your nose, except when you are fasting.'" [1]See No}}
\hadithdefcmd{nasai}{88}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَوَضَّأَ فَلْيَسْتَنْثِرْ وَمَنِ اسْتَجْمَرَ فَلْيُوتِرْ ‏"‏ ‏.‏\hadithno{88}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Whoever performs Wudu' then let him sniff water in the nose and blow it out, and whoever uses small stones (to remove filth) then make it odd (numbered)}}
\hadithdefcmd{nasai}{89}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ سَلَمَةَ بْنِ قَيْسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأْتَ فَاسْتَنْثِرْ وَإِذَا اسْتَجْمَرْتَ فَأَوْتِرْ ‏"‏ ‏.‏\hadithno{89}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Salamah bin Qais that the Messenger of Allah (ﷺ) said:"When you perform Wudu', sniff water in your nose and blow it out, and when you use small stones (to remove filth), then make it off (numbered)}}
\hadithdefcmd{nasai}{90}{أَخْبَرَنَا مُحَمَّدُ بْنُ زُنْبُورٍ الْمَكِّيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، أَنَّ مُحَمَّدَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُ عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ مَنَامِهِ فَتَوَضَّأَ فَلْيَسْتَنْثِرْ ثَلاَثَ مَرَّاتٍ فَإِنَّ الشَّيْطَانَ يَبِيتُ عَلَى خَيْشُومِهِ ‏"‏ ‏.‏\hadithno{90}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"When any one of you wakes from sleep to perform Wudu', then let him sniff water in his nose and blow it out three times, for the Shaitan spends the night on his nose}}
\hadithdefcmd{nasai}{91}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، قَالَ حَدَّثَنَا خَالِدُ بْنُ عَلْقَمَةَ، عَنْ عَبْدِ خَيْرٍ، عَنْ عَلِيٍّ، أَنَّهُ دَعَا بِوَضُوءٍ فَتَمَضْمَضَ وَاسْتَنْشَقَ وَنَثَرَ بِيَدِهِ الْيُسْرَى فَفَعَلَ هَذَا ثَلاَثًا ثُمَّ قَالَ هَذَا طُهُورُ نَبِيِّ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{91}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Ali called for (water for) Wudu', then he rinsed his mouth and nose, and he sniffed up water and blew it out using his left hand. He did that three times, then he said:"This is how the Prophet of Allah (ﷺ) purified himself}}
\hadithdefcmd{nasai}{92}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ خَالِدِ بْنِ عَلْقَمَةَ، عَنْ عَبْدِ خَيْرٍ، قَالَ أَتَيْنَا عَلِيَّ بْنَ أَبِي طَالِبٍ - رضى الله عنه - وَقَدْ صَلَّى فَدَعَا بِطَهُورٍ فَقُلْنَا مَا يَصْنَعُ بِهِ وَقَدْ صَلَّى مَا يُرِيدُ إِلاَّ لِيُعَلِّمَنَا فَأُتِيَ بِإِنَاءٍ فِيهِ مَاءٌ وَطَسْتٍ فَأَفْرَغَ مِنَ الإِنَاءِ عَلَى يَدَيْهِ فَغَسَلَهَا ثَلاَثًا ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ ثَلاَثًا مِنَ الْكَفِّ الَّذِي يَأْخُذُ بِهِ الْمَاءَ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا وَغَسَلَ يَدَهُ الْيُمْنَى ثَلاَثًا وَيَدَهُ الشِّمَالَ ثَلاَثًا وَمَسَحَ بِرَأْسِهِ مَرَّةً وَاحِدَةً ثُمَّ غَسَلَ رِجْلَهُ الْيُمْنَى ثَلاَثًا وَرِجْلَهُ الشِّمَالَ ثَلاَثًا ثُمَّ قَالَ مَنْ سَرَّهُ أَنْ يَعْلَمَ وُضُوءَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهُوَ هَذَا ‏.‏\hadithno{92}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abd Khair said:"We came to 'Ali bin Abi Talib, may Allah be pleased with him, and he had prayed. He called for water and we said: 'What is he going to do with it when he has (already) prayed? He only wants to teach us.' A vessel of water and a basin were brought to him. He poured some water onto his hand and washed it three times, then he rinsed his mouth and nose three times from the hand with which he took the water. Then he washed his face three times, and he washed his right hand three times, and his left hand three times, and wiped his head once, then he washed his right foot three times and his left foot three times. Then he said: 'Whoever would like to learn how the Messenger of Allah (ﷺ) did Wudu', this is it}}
\hadithdefcmd{nasai}{93}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، - وَهُوَ ابْنُ الْمُبَارَكِ - عَنْ شُعْبَةَ، عَنْ مَالِكِ بْنِ عُرْفُطَةَ، عَنْ عَبْدِ خَيْرٍ، عَنْ عَلِيٍّ، رضى الله عنه أَنَّهُ أُتِيَ بِكُرْسِيٍّ فَقَعَدَ عَلَيْهِ ثُمَّ دَعَا بِتَوْرٍ فِيهِ مَاءٌ فَكَفَأَ عَلَى يَدَيْهٍ ثَلاَثًا ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ بِكَفٍّ وَاحِدٍ ثَلاَثَ مَرَّاتٍ وَغَسَلَ وَجْهَهُ ثَلاَثًا وَغَسَلَ ذِرَاعَيْهِ ثَلاَثًا ثَلاَثًا وَأَخَذَ مِنَ الْمَاءِ فَمَسَحَ بِرَأْسِهِ - وَأَشَارَ شُعْبَةُ مَرَّةً مِنْ نَاصِيَتِهِ إِلَى مُؤَخَّرِ رَأْسِهِ - ثُمَّ قَالَ - لاَ أَدْرِي أَرَدَّهُمَا أَمْ لاَ - وَغَسَلَ رِجْلَيْهِ ثَلاَثًا ثَلاَثًا ثُمَّ قَالَ مَنْ سَرَّهُ أَنْ يَنْظُرَ إِلَى طُهُورِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهَذَا طُهُورُهُ ‏.‏ وَقَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ خَالِدُ بْنُ عَلْقَمَةَ لَيْسَ مَالِكَ بْنَ عُرْفُطَةَ ‏.‏\hadithno{93}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abd Khair, that 'Ali (may Allah be pleased with him) was brought a chair, and he sat down on it, then he called for a vessel of water which he tilted onto his hand three times, then he rinsed his mouth and nose with one hand, three times, he washed his face three times, washed each forearm three times, and took some of the water and wiped his head. One one occasion (One of the narrators) Shu'bah, indicated (that he wiped) from his forelock to the back of his head, then said:"I do not know whether he brought his hands back or not. And he washed each foot three times, then he said: 'Whoever would like to see how the Messenger of Allah (ﷺ) purified himself, this is how he purified himself.'" Abu 'Abdur-Rahman said: "This is a mistake. What is correct is Khalid bin 'Alqamah, not Malik bin 'Urfutah}}
\hadithdefcmd{nasai}{94}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنِي شُعْبَةُ، عَنْ مَالِكِ بْنِ عُرْفُطَةَ، عَنْ عَبْدِ خَيْرٍ، قَالَ شَهِدْتُ عَلِيًّا دَعَا بِكُرْسِيٍّ فَقَعَدَ عَلَيْهِ ثُمَّ دَعَا بِمَاءٍ فِي تَوْرٍ فَغَسَلَ يَدَيْهِ ثَلاَثًا ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ بِكَفٍّ وَاحِدٍ ثَلاَثًا ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا وَيَدَيْهِ ثَلاَثًا ثَلاَثًا ثُمَّ غَمَسَ يَدَهُ فِي الإِنَاءِ فَمَسَحَ بِرَأْسِهِ ثُمَّ غَسَلَ رِجْلَيْهِ ثَلاَثًا ثَلاَثًا ثُمَّ قَالَ مَنْ سَرَّهُ أَنْ يَنْظُرَ إِلَى وُضُوءِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهَذَا وَضُوؤُهُ ‏.‏\hadithno{94}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abd Khair said:"I saw 'Ali call for a chair and he sat down, then he called for water in a vessel and washed his hands three times, then he rinsed his mouth and nose with one hand, three times. Then he washed his face three times, and his hands three times. Then he dipped his hand in the vessel and wiped his head, then he washed each foot three times. Then he said: 'Whoever would like to see how the Messenger of Allah (ﷺ) performed Wudu', this is his Wudu}}
\hadithdefcmd{nasai}{95}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ الْمِقْسَمِيُّ، قَالَ أَنْبَأَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ حَدَّثَنِي شَيْبَةُ، أَنَّ مُحَمَّدَ بْنَ عَلِيٍّ، أَخْبَرَهُ قَالَ أَخْبَرَنِي أَبِي عَلِيٌّ، أَنَّ الْحُسَيْنَ بْنَ عَلِيٍّ، قَالَ دَعَانِي أَبِي عَلِيٌّ بِوَضُوءٍ فَقَرَّبْتُهُ لَهُ فَبَدَأَ فَغَسَلَ كَفَّيْهِ ثَلاَثَ مَرَّاتٍ قَبْلَ أَنْ يُدْخِلَهُمَا فِي وَضُوئِهِ ثُمَّ مَضْمَضَ ثَلاَثًا وَاسْتَنْثَرَ ثَلاَثًا ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى إِلَى الْمِرْفَقِ ثَلاَثًا ثُمَّ الْيُسْرَى كَذَلِكَ ثُمَّ مَسَحَ بِرَأْسِهِ مَسْحَةً وَاحِدَةً ثُمَّ غَسَلَ رِجْلَهُ الْيُمْنَى إِلَى الْكَعْبَيْنِ ثَلاَثًا ثُمَّ الْيُسْرَى كَذَلِكَ ثُمَّ قَامَ قَائِمًا فَقَالَ نَاوِلْنِي فَنَاوَلْتُهُ الإِنَاءَ الَّذِي فِيهِ فَضْلُ وَضُوئِهِ فَشَرِبَ مِنْ فَضْلِ وَضُوئِهِ قَائِمًا فَعَجِبْتُ فَلَمَّا رَآنِي قَالَ لاَ تَعْجَبْ فَإِنِّي رَأَيْتُ أَبَاكَ النَّبِيَّ صلى الله عليه وسلم يَصْنَعُ مِثْلَ مَا رَأَيْتَنِي صَنَعْتُ يَقُولُ لِوُضُوئِهِ هَذَا وَشُرْبِ فَضْلِ وَضُوئِهِ قَائِمًا ‏.‏\hadithno{95}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Husain bin 'Ali said:"My father 'Ali called me to bring (water for) Wudu', so I brought it to him, and he started by washing his hands three times, before putting them into the water. Then he rinsed his mouth three times and sniffed water into his nose and blew it out three times. Then he washed his face three times, then his right hand up to the elbow three times, then his left likewise. Then he wiped his head once then he washed his right foot up to the ankle three times, then the left likewise. Then he stood up and said: 'Pass me the vessel.' So I passed the vessel containing the remaining water for his Wudu' to him, and he drank from it standing up. I was surprised and when he noticed that he said: 'Do not be surprised, for I saw your father the Prophet (ﷺ) doing,' referring to his Wudu' and drinking the leftover water while standing}}
\hadithdefcmd{nasai}{96}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ، - وَهُوَ ابْنُ قَيْسٍ - قَالَ رَأَيْتُ عَلِيًّا - رضى الله عنه - تَوَضَّأَ فَغَسَلَ كَفَّيْهِ حَتَّى أَنْقَاهُمَا ثُمَّ تَمَضْمَضَ ثَلاَثًا وَاسْتَنْشَقَ ثَلاَثًا وَغَسَلَ وَجْهَهُ ثَلاَثًا وَغَسَلَ ذِرَاعَيْهِ ثَلاَثًا ثَلاَثًا ثُمَّ مَسَحَ بِرَأْسِهِ ثُمَّ غَسَلَ قَدَمَيْهِ إِلَى الْكَعْبَيْنِ ثُمَّ قَامَ فَأَخَذَ فَضْلَ طَهُورِهِ فَشَرِبَ وَهُوَ قَائِمٌ ثُمَّ قَالَ أَحْبَبْتُ أَنْ أُرِيَكُمْ كَيْفَ طَهُورُ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{96}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hayyah - Ibn Qais - said:"I saw 'Ali perform Wudu'. He washed his hands until they looked clean, then he rinsed his mouth three times and his nose three times, and he washed each forearm three times. Then he wiped his head, then he washed his feet up to the ankles. Then he stood up, took the left over water for his Wudu' and drank from it while standing. Then he said: 'I wanted to show you how the Prophet (ﷺ) performed Wudu}}
\hadithdefcmd{nasai}{97}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ زَيْدِ بْنِ عَاصِمٍ - وَكَانَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ جَدُّ عَمْرِو بْنِ يَحْيَى - هَلْ تَسْتَطِيعُ أَنْ تُرِيَنِي كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ قَالَ عَبْدُ اللَّهِ بْنُ زَيْدٍ نَعَمْ ‏.‏ فَدَعَا بِوَضُوءٍ فَأَفْرَغَ عَلَى يَدَيْهِ فَغَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ ثَلاَثًا ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ إِلَى الْمِرْفَقَيْنِ ثُمَّ مَسَحَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ بَدَأَ بِمُقَدَّمِ رَأْسِهِ ثُمَّ ذَهَبَ بِهِمَا إِلَى قَفَاهُ ثُمَّ رَدَّهُمَا حَتَّى رَجَعَ إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ ثُمَّ غَسَلَ رِجْلَيْهِ ‏.‏\hadithno{97}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Amr bin Yahya Al-Mazini that his father said to 'Abdullah bin Zaid bin 'Asim - who was one of the Companions of the Prophet (ﷺ) and the grandfather of 'Amr bin Yahya:"Can you show me how the Messenger of Allah (ﷺ) used to perform Wudu'? 'Abdullah bin Zaid said: "Yes. He called for (water for) Wudu' and poured some onto his hand, washing each hand twice. Then he rinsed his mouth and nose three times, then he washed his face three times, then he washed each hand twice, up to the elbow. Then he wiped his head with his hands, back and forth, starting at the front of his head and moving his hands to the nape of his neck, then bringing them back to the place he started. Then he washed his feet}}
\hadithdefcmd{nasai}{98}{أَخْبَرَنَا عُتْبَةُ بْنُ عَبْدِ اللَّهِ، عَنْ مَالِكٍ، - هُوَ ابْنُ أَنَسٍ - عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ زَيْدِ بْنِ عَاصِمٍ - وَهُوَ جَدُّ عَمْرِو بْنِ يَحْيَى - هَلْ تَسْتَطِيعُ أَنْ تُرِيَنِي، كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ قَالَ عَبْدُ اللَّهِ بْنُ زَيْدٍ نَعَمْ ‏.‏ فَدَعَا بِوَضُوءٍ فَأَفْرَغَ عَلَى يَدِهِ الْيُمْنَى فَغَسَلَ يَدَيْهِ مَرَّتَيْنِ ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ ثَلاَثًا ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ إِلَى الْمِرْفَقَيْنِ ثُمَّ مَسَحَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ بَدَأَ بِمُقَدَّمِ رَأْسِهِ ثُمَّ ذَهَبَ بِهِمَا إِلَى قَفَاهُ ثُمَّ رَدَّهُمَا حَتَّى رَجَعَ إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ ثُمَّ غَسَلَ رِجْلَيْهِ ‏.‏\hadithno{98}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin Yahya that his father said to 'Abdullah bin Zaid bin 'Asim - who was one of the Companions of the Prophet (ﷺ) and the grandfather of 'Amr bin Yahya:"Can you show me how the Messenger of Allah (ﷺ) used to perform Wudu'?" 'Abdullah bin Zaid said: "Yes. He called for (water for) Wudu' and poured some onto his right hand, washing his hands twice. Then he rinsed his mouth and nose three times, then washed his face three times, then he washed his hands twice, up to the elbows. Then he wiped his head with his hands, back and forth, starting at the front of his head and moving his hands to the nape of his neck, then bringing them back to the place he started. Then he washed his feet}}
\hadithdefcmd{nasai}{99}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، - الَّذِي أُرِيَ النِّدَاءَ - قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ فَغَسَلَ وَجْهَهُ ثَلاَثًا وَيَدَيْهِ مَرَّتَيْنِ وَغَسَلَ رِجْلَيْهِ مَرَّتَيْنِ وَمَسَحَ بِرَأْسِهِ مَرَّتَيْنِ ‏.‏\hadithno{99}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Zaid, who was shown the call to prayer (in a dream), said:"I saw the Messenger of Allah (ﷺ) perform Wudu'; he washed his face three times and his hands twice, he washed his feet twice and wiped his head twice}}
\hadithdefcmd{nasai}{100}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ جُعَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنِي عَبْدُ الْمَلِكِ بْنُ مَرْوَانَ بْنِ الْحَارِثِ بْنِ أَبِي ذُبَابٍ، قَالَ أَخْبَرَنِي أَبُو عَبْدِ اللَّهِ، سَالِمٌ سَبَلاَنُ قَالَ وَكَانَتْ عَائِشَةُ تَسْتَعْجِبُ بِأَمَانَتِهِ وَتَسْتَأْجِرُهُ فَأَرَتْنِي كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ فَتَمَضْمَضَتْ وَاسْتَنْثَرَتْ ثَلاَثًا وَغَسَلَتْ وَجْهَهَا ثَلاَثًا ثُمَّ غَسَلَتْ يَدَهَا الْيُمْنَى ثَلاَثًا وَالْيُسْرَى ثَلاَثًا وَوَضَعَتْ يَدَهَا فِي مُقَدَّمِ رَأْسِهَا ثُمَّ مَسَحَتْ رَأْسَهَا مَسْحَةً وَاحِدَةً إِلَى مُؤَخَّرِهِ ثُمَّ أَمَرَّتْ يَدَيْهَا بِأُذُنَيْهَا ثُمَّ مَرَّتْ عَلَى الْخَدَّيْنِ قَالَ سَالِمٌ كُنْتُ آتِيهَا مُكَاتَبًا مَا تَخْتَفِي مِنِّي فَتَجْلِسُ بَيْنَ يَدَىَّ وَتَتَحَدَّثُ مَعِي حَتَّى جِئْتُهَا ذَاتَ يَوْمٍ فَقُلْتُ ادْعِي لِي بِالْبَرَكَةِ يَا أُمَّ الْمُؤْمِنِينَ ‏.‏ قَالَتْ وَمَا ذَاكَ قُلْتُ أَعْتَقَنِي اللَّهُ ‏.‏ قَالَتْ بَارَكَ اللَّهُ لَكَ ‏.‏ وَأَرْخَتِ الْحِجَابَ دُونِي فَلَمْ أَرَهَا بَعْدَ ذَلِكَ الْيَوْمِ ‏.‏\hadithno{100}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Abu 'Abdullah Salim Sabalan said:"'Aishah liked my honesty and hired me, and she showed me how the Messenger of Allah (ﷺ) used to perform Wudu'. She rinsed her mouth, sniffed water into her nose and blew it out three times, and washed her face three times. Then she washed her right hand three times and her left hand three times. Then she put her hand on the front of her head and wiped her head once, front to back. Then she rubbed her ears with her hands, then she passed her hands over her cheeks." Salim said: "I came to her as a slave with a contract of manumission, and she did not hide herself from me. She would sit before me and talk to me, until I came to her one day and said: 'Pray for blessing for me, O Mother of Believers.' She said: 'Why is that?' I said: 'Allah has set me free.' She said: 'May Allah bless you.' Then she lowered the Hijab before me, and I never saw her again after that day}}
\hadithdefcmd{nasai}{101}{أَخْبَرَنَا الْهَيْثَمُ بْنُ أَيُّوبَ الطَّالَقَانِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ فَغَسَلَ يَدَيْهِ ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ مِنْ غَرْفَةٍ وَاحِدَةٍ وَغَسَلَ وَجْهَهُ وَغَسَلَ يَدَيْهِ مَرَّةً مَرَّةً وَمَسَحَ بِرَأْسِهِ وَأُذُنَيْهِ مَرَّةً ‏.‏ قَالَ عَبْدُ الْعَزِيزِ وَأَخْبَرَنِي مَنْ سَمِعَ ابْنَ عَجْلاَنَ يَقُولُ فِي ذَلِكَ وَغَسَلَ رِجْلَيْهِ ‏.‏\hadithno{101}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"I saw the Messenger of Allah (ﷺ) performing Wudu'. He washed his hands, then he rinsed his mouth and nose with one handful of water, washed his face, washed each hand once, and wiped his head and ears once." (One of the narrators) 'Abdul-'Aziz said: "Someone who heard from Ibn 'Ajlan told me that he said concerning that: 'And he washed his feet}}
\hadithdefcmd{nasai}{102}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، قَالَ حَدَّثَنَا ابْنُ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَغَرَفَ غَرْفَةً فَمَضْمَضَ وَاسْتَنْشَقَ ثُمَّ غَرَفَ غَرْفَةً فَغَسَلَ وَجْهَهُ ثُمَّ غَرَفَ غَرْفَةً فَغَسَلَ يَدَهُ الْيُمْنَى ثُمَّ غَرَفَ غَرْفَةً فَغَسَلَ يَدَهُ الْيُسْرَى ثُمَّ مَسَحَ بِرَأْسِهِ وَأُذُنَيْهِ بَاطِنِهِمَا بِالسَّبَّاحَتَيْنِ وَظَاهِرِهِمَا بِإِبْهَامَيْهِ ثُمَّ غَرَفَ غَرْفَةً فَغَسَلَ رِجْلَهُ الْيُمْنَى ثُمَّ غَرَفَ غَرْفَةً فَغَسَلَ رِجْلَهُ الْيُسْرَى ‏.‏\hadithno{102}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) performed Wudu', and he scooped up one handful (of water) and rinsed his mouth and nose. Then he scooped up another handful and washed his face. Then he scooped up another handful and washed his right hand, then another handful and washed his left hand. Then he wiped his head and his ears, the inside with his forefinger and the outside with his thumb. Then he scooped up a handful of water and washed his right foot, and scooped up another handful and washed his left foot}}
\hadithdefcmd{nasai}{103}{أَخْبَرَنَا قُتَيْبَةُ، وَعُتْبَةُ بْنُ عَبْدِ اللَّهِ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ الصُّنَابِحِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ الْعَبْدُ الْمُؤْمِنُ فَتَمَضْمَضَ خَرَجَتِ الْخَطَايَا مِنْ فِيهِ فَإِذَا اسْتَنْثَرَ خَرَجَتِ الْخَطَايَا مِنْ أَنْفِهِ فَإِذَا غَسَلَ وَجْهَهُ خَرَجَتِ الْخَطَايَا مِنْ وَجْهِهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَشْفَارِ عَيْنَيْهِ فَإِذَا غَسَلَ يَدَيْهِ خَرَجَتِ الْخَطَايَا مِنْ يَدَيْهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَظْفَارِ يَدَيْهِ فَإِذَا مَسَحَ بِرَأْسِهِ خَرَجَتِ الْخَطَايَا مِنْ رَأْسِهِ حَتَّى تَخْرُجَ مِنْ أُذُنَيْهِ فَإِذَا غَسَلَ رِجْلَيْهِ خَرَجَتِ الْخَطَايَا مِنْ رِجْلَيْهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَظْفَارِ رِجْلَيْهِ ثُمَّ كَانَ مَشْيُهُ إِلَى الْمَسْجِدِ وَصَلاَتُهُ نَافِلَةً لَهُ ‏"‏ ‏.‏ قَالَ قُتَيْبَةُ عَنِ الصُّنَابِحِيِّ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏.‏\hadithno{103}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah As-Sunabihi that the Messenger of Allah (ﷺ) said:"When the believing slave performs Wudu' and rinses his mouth, his sins come out from his mouth. When he sniffs water into his nose and blows it out, his sins come from his nose. When he washes his face, his sins come out from his face, even from beneath his eyelashes. When he washes his hands, his sins come out from his hands, even from beneath his fingernails. When he wipes his head, his sins come out from his head, even from his ears. When washes his feet, his sins come from his feet, even from beneath his toenails. Then his walking to the Masjid and his Salah will earn extra merit for him}}
\hadithdefcmd{nasai}{104}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، ح وَأَنْبَأَنَا الْحُسَيْنُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنْ بِلاَلٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَمْسَحُ عَلَى الْخُفَّيْنِ وَالْخِمَارِ ‏.‏\hadithno{104}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Bilal said:"I saw the Prophet (ﷺ) wiping over the Khuff and the Khimar." [1] A head covering not limited to the common usage of "turban" as is clear from the first narration}}
\hadithdefcmd{nasai}{105}{وَأَخْبَرَنَا الْحُسَيْنُ بْنُ عَبْدِ الرَّحْمَنِ الْجَرْجَرَائِيُّ، عَنْ طَلْقِ بْنِ غَنَّامٍ، قَالَ حَدَّثَنَا زَائِدَةُ، وَحَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنْ بِلاَلٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ عَلَى الْخُفَّيْنِ ‏.‏\hadithno{105}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Bilal said:"I saw the Messenger of Allah (ﷺ) wiping over the Khuff}}
\hadithdefcmd{nasai}{106}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ بِلاَلٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ عَلَى الْخِمَارِ وَالْخُفَّيْنِ ‏.‏\hadithno{106}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Bilal said:"I saw the Messenger of Allah (ﷺ) wiping over the Khimar and Khuff}}
\hadithdefcmd{nasai}{107}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، قَالَ حَدَّثَنَا بَكْرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، عَنِ الْحَسَنِ، عَنِ ابْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنِ الْمُغِيرَةِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ فَمَسَحَ نَاصِيَتَهُ وَعِمَامَتَهُ وَعَلَى الْخُفَّيْنِ ‏.‏ قَالَ بَكْرٌ وَقَدْ سَمِعْتُهُ مِنِ ابْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ عَنْ أَبِيهِ ‏.‏\hadithno{107}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Al-Mughirah that the Prophet (ﷺ) performed Wudu', and he wiped the forehead, the 'Imamah, and over the Khuff. (Another chain)}}
\hadithdefcmd{nasai}{108}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا حُمَيْدٌ، قَالَ حَدَّثَنَا بَكْرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، عَنْ حَمْزَةَ بْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أَبِيهِ، قَالَ تَخَلَّفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَخَلَّفْتُ مَعَهُ فَلَمَّا قَضَى حَاجَتَهُ قَالَ ‏ "‏ أَمَعَكَ مَاءٌ ‏"‏ ‏.‏ فَأَتَيْتُهُ بِمِطْهَرَةٍ فَغَسَلَ يَدَيْهِ وَغَسَلَ وَجْهَهُ ثُمَّ ذَهَبَ يَحْسُرُ عَنْ ذِرَاعَيْهِ فَضَاقَ كُمُّ الْجُبَّةِ فَأَلْقَاهُ عَلَى مَنْكِبَيْهِ فَغَسَلَ ذِرَاعَيْهِ وَمَسَحَ بِنَاصِيَتِهِ وَعَلَى الْعِمَامَةِ وَعَلَى خُفَّيْهِ ‏.‏\hadithno{108}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hamzah bin Al-Mughirah bin Shu'bah that his father said:"The Messenger of Allah (ﷺ) stayed behind, and I stayed with him. When he had relieved himself he said: 'Do you have any water with you?' I brought some water to him, and he washed his hands and face, then he started trying to uncover his arms, but the sleeves of his Jubbah were too tight, so he threw it over his shoulders and washed his arms and wiped over his forehead and 'Imamah, and over his Khuff}}
\hadithdefcmd{nasai}{109}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَخْبَرَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنِ ابْنِ سِيرِينَ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ وَهْبٍ الثَّقَفِيُّ، قَالَ سَمِعْتُ الْمُغِيرَةَ بْنَ شُعْبَةَ، قَالَ خَصْلَتَانِ لاَ أَسْأَلُ عَنْهُمَا أَحَدًا بَعْدَ مَا شَهِدْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - كُنَّا مَعَهُ فِي سَفَرٍ فَبَرَزَ لِحَاجَتِهِ ثُمَّ جَاءَ فَتَوَضَّأَ وَمَسَحَ بِنَاصِيَتِهِ وَجَانِبَىْ عِمَامَتِهِ وَمَسَحَ عَلَى خُفَّيْهِ قَالَ وَصَلاَةُ الإِمَامِ خَلْفَ الرَّجُلِ مِنْ رَعِيَّتِهِ فَشَهِدْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ فِي سَفَرٍ فَحَضَرَتِ الصَّلاَةُ فَاحْتَبَسَ عَلَيْهِمُ النَّبِيُّ صلى الله عليه وسلم فَأَقَامُوا الصَّلاَةَ وَقَدَّمُوا ابْنَ عَوْفٍ فَصَلَّى بِهِمْ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى خَلْفَ ابْنِ عَوْفٍ مَا بَقِيَ مِنَ الصَّلاَةِ فَلَمَّا سَلَّمَ ابْنُ عَوْفٍ قَامَ النَّبِيُّ صلى الله عليه وسلم فَقَضَى مَا سُبِقَ بِهِ ‏.‏\hadithno{109}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Al-Mughirah bin Shu'bah said:"There are two things which I never asked anyone about after I saw the Messenger of Allah (ﷺ). He was with us on a journey and he went away to relieve himself, then he came and performed Wudu', and he wiped over his forehead and two sides of his 'Imamah, and he wiped over his Khuffs." He said: "And (the other issue) the Imam's Salah behind one of his followers. I saw the Messenger of Allah (ﷺ) when he was on a journey and time for prayer came. The Prophet (ﷺ) could not join them, so they called the Iqamah and they asked Ibn 'Awf to lead them in prayer. Then the Messenger of Allah (ﷺ) came and offered the remainder of the prayer behinf Ibn 'Awf, then when Ibn 'Awf said the Salah, the Prophet (ﷺ) stood up and completed what he had missed (of the prayer)}}
\hadithdefcmd{nasai}{110}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ شُعْبَةَ، ح وَأَنْبَأَنَا مُؤَمَّلُ بْنُ هِشَامٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ وَيْلٌ لِلْعَقِبِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{110}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"Abu Al-Qasim the Messenger of Allah (ﷺ) said: 'Woe to the heels from the Fire}}
\hadithdefcmd{nasai}{111}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، ح وَأَنْبَأَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، - وَاللَّفْظُ لَهُ - عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ أَبِي يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم قَوْمًا يَتَوَضَّئُونَ فَرَأَى أَعْقَابَهُمْ تَلُوحُ فَقَالَ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ أَسْبِغُوا الْوُضُوءَ ‏"‏ ‏.‏\hadithno{111}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah (ﷺ) saw some people whose heels were still dry, so he said: 'Woe to the heels from the Fire. Perform Wudu' properly}}
\hadithdefcmd{nasai}{112}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي الأَشْعَثُ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، - رضى الله عنها - وَذَكَرَتْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُحِبُّ التَّيَامُنَ مَا اسْتَطَاعَ فِي طُهُورِهِ وَنَعْلِهِ وَتَرَجُّلِهِ ‏.‏ قَالَ شُعْبَةُ ثُمَّ سَمِعْتُ الأَشْعَثَ بِوَاسِطٍ يَقُولُ يُحِبُّ التَّيَامُنَ فَذَكَرَ شَأْنَهُ كُلَّهُ ثُمَّ سَمِعْتُهُ بِالْكُوفَةِ يَقُولُ يُحِبُّ التَّيَامُنَ مَا اسْتَطَاعَ ‏.‏\hadithno{112}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah (may Allah be pleased with her) mentioned:"The Messenger of Allah (ﷺ) used to like to start with the right whenever he could, when purifying himself and when putting on shoes or combing his hair." (One of the narrators) Shu'bah said: Then I heard Al-Ash'ath in Wasit, saying that he liked to start with the right, and he preferred that in all his affaris. Then I heard him in Al-Kufah saying that he liked to start with the right whenever he could}}
\hadithdefcmd{nasai}{113}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي أَبُو جَعْفَرٍ الْمَدَنِيُّ، قَالَ سَمِعْتُ ابْنَ عُثْمَانَ بْنِ حُنَيْفٍ، - يَعْنِي عُمَارَةَ - قَالَ حَدَّثَنِي الْقَيْسِيُّ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَأُتِيَ بِمَاءٍ فَقَالَ عَلَى يَدَيْهِ مِنَ الإِنَاءِ فَغَسَلَهُمَا مَرَّةً وَغَسَلَ وَجْهَهُ وَذِرَاعَيْهِ مَرَّةً مَرَّةً وَغَسَلَ رِجْلَيْهِ بِيَمِينِهِ كِلْتَيْهِمَا ‏.‏\hadithno{113}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Qaisi narrated that he was with the Messenger of Allah (ﷺ) on a journey, and some water was brought to him. He poured some onto his hands from the vessel and washed them once, then he washed his face and each arm once, and he washed his feet with both hands}}
\hadithdefcmd{nasai}{114}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ كَثِيرٍ، وَكَانَ، يُكْنَى أَبَا هَاشِمٍ ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي هَاشِمٍ، عَنْ عَاصِمِ بْنِ لَقِيطٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَوَضَّأْتَ فَأَسْبِغِ الْوُضُوءَ وَخَلِّلْ بَيْنَ الأَصَابِعِ ‏"‏ ‏.‏\hadithno{114}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Asim bin Laqit that his father said:The Messenger of Allah (ﷺ) said: "When you perform Wudu', do so properly, and wash in between the fingers (Al-Asabi')."[2] [1] Al-Asabi' is plural meaning fingers as well as toes, and the author mentioned only one narration on the topic whereas some of them clarify "of the hands and feet." So he mentioned the general wording amids chapters how to wash the feet. [2] Part of this narration preceded under No}}
\hadithdefcmd{nasai}{115}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنِ ابْنِ أَبِي زَائِدَةَ، قَالَ حَدَّثَنِي أَبِي وَغَيْرُهُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ الْوَادِعِيِّ، قَالَ رَأَيْتُ عَلِيًّا تَوَضَّأَ فَغَسَلَ كَفَّيْهِ ثَلاَثًا وَتَمَضْمَضَ وَاسْتَنْشَقَ ثَلاَثًا وَغَسَلَ وَجْهَهُ ثَلاَثًا وَذِرَاعَيْهِ ثَلاَثًا ثَلاَثًا وَمَسَحَ بِرَأْسِهِ وَغَسَلَ رِجْلَيْهِ ثَلاَثًا ثَلاَثًا قَالَ هَذَا وُضُوءُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{115}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hayyah Al-Wadi'i said:I saw 'Ali performing Wudu'. He washed his hands three times, and rinsed his mouth three times and his nose three times, and he washed his face three times and each forearm three times. Then he wiped his head and washed each foot three times. Then he said: 'This is the Wudu' of the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{116}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَطَاءَ بْنَ يَزِيدَ اللَّيْثِيَّ، أَخْبَرَهُ أَنَّ حُمْرَانَ مَوْلَى عُثْمَانَ أَخْبَرَهُ أَنَّ عُثْمَانَ دَعَا بِوَضُوءٍ فَتَوَضَّأَ فَغَسَلَ كَفَّيْهِ ثَلاَثَ مَرَّاتٍ ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى إِلَى الْمِرْفَقِ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ يَدَهُ الْيُسْرَى مِثْلَ ذَلِكَ ثُمَّ مَسَحَ بِرَأْسِهِ ثُمَّ غَسَلَ رِجْلَهُ الْيُمْنَى إِلَى الْكَعْبَيْنِ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ رِجْلَهُ الْيُسْرَى مِثْلَ ذَلِكَ ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا ثُمَّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا ثُمَّ قَامَ فَرَكَعَ رَكْعَتَيْنِ لاَ يُحَدِّثُ فِيهِمَا نَفْسَهُ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{116}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Humran the freed slave of 'Uthman said:"Uthman called for water for Wudu'. He washed his hands three times, then he rinsed his mouth and nose, then he washed his face three times, then washed his right hand up to the elbow three times. Then he washed his left hand likewise. Then he washed his left hand likewise. Then he wiped his head, then he washed his right foot up to the ankle three times, and he washed his left foot likewise, and he washed his left foot likewise. Then he said: 'I saw the Messenger of Allah (ﷺ) performing Wudu' as I have just done.' Then he said: "The Messenger of Allah (ﷺ) said: 'Whoever performs Wudu' as I have just done, then prayes two Rak'ahs without letting his thoughts wander, his previous sins will be forgiven}}
\hadithdefcmd{nasai}{117}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ، وَمَالِكٍ، وَابْنِ، جُرَيْجٍ عَنِ الْمَقْبُرِيِّ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَأَيْتُكَ تَلْبَسُ هَذِهِ النِّعَالَ السِّبْتِيَّةَ وَتَتَوَضَّأُ فِيهَا ‏.‏ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْبَسُهَا وَيَتَوَضَّأُ فِيهَا ‏.‏\hadithno{117}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ubaid bin Juraih said:"I said to Ibn 'Umar: 'I see you are wearing Sibtiyyah sandals, [1] and you performed Wudu' in them.' He said: 'I saw the Messenger of Allah (ﷺ) wearing then and performing Wudu' in them.'" [1] Made of hairless, tanned leather}}
\hadithdefcmd{nasai}{118}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَفْصٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ فَقِيلَ لَهُ أَتَمْسَحُ فَقَالَ قَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ ‏.‏ وَكَانَ أَصْحَابُ عَبْدِ اللَّهِ يُعْجِبُهُمْ قَوْلُ جَرِيرٍ وَكَانَ إِسْلاَمُ جَرِيرٍ قَبْلَ مَوْتِ النَّبِيِّ صلى الله عليه وسلم بِيَسِيرٍ ‏.‏\hadithno{118}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jarir bin 'Abdullah that he performed Wudu' and wiped over his Khuffs. it was said to him:"Are you wiping (over you Khuffs)?" He said: "I saw the Messenger of Allah (ﷺ) wiping (over his Khuffs)." The companions of 'Abdullah liked what Jarir said, because Jarir became Muslim shortly before the Prophet (ﷺ) died.[1] [1]In the narration recorded by At-Tirmidhi Nos. 93,94) this comment is attributed to Ibrahim, one of the narrators}}
\hadithdefcmd{nasai}{119}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ، عَنْ أَبِيهِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ وَمَسَحَ عَلَى الْخُفَّيْنِ ‏.‏\hadithno{119}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ja'far bin 'Amr bin Umayyah Ad-Damri that his father saw the Messenger of Allah (ﷺ) performing Wudu' and wiping over his Khuffs}}
\hadithdefcmd{nasai}{120}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، دُحَيْمٌ وَسُلَيْمَانُ بْنُ دَاوُدَ - وَاللَّفْظُ لَهُ - عَنِ ابْنِ نَافِعٍ، عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَبِلاَلٌ الأَسْوَاقَ فَذَهَبَ لِحَاجَتِهِ ثُمَّ خَرَجَ قَالَ أُسَامَةُ فَسَأَلْتُ بِلاَلاً مَا صَنَعَ فَقَالَ بِلاَلٌ ذَهَبَ النَّبِيُّ صلى الله عليه وسلم لِحَاجَتِهِ ثُمَّ تَوَضَّأَ فَغَسَلَ وَجْهَهُ وَيَدَيْهِ وَمَسَحَ بِرَأْسِهِ وَمَسَحَ عَلَى الْخُفَّيْنِ ثُمَّ صَلَّى ‏.‏\hadithno{120}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Usamah bin Zaid said:"The Messenger of Allah (ﷺ) and Bilal entered Al-Aswaf [1] and he went to relieve himself and then came out." Usamah said: "I asked Bilal: 'What did he do?' Bilal said: 'The Prophet (ﷺ) went to relieve himself, then he performed Wudu', so he washed his hands and face, and wiped his head and he wiped over his Khuffs, then prayed}}
\hadithdefcmd{nasai}{121}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ مَسَحَ عَلَى الْخُفَّيْنِ ‏.‏\hadithno{121}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sa'd bin Abi Waqqas that the Messenger of Allah (ﷺ) wiped over the Khuffs}}
\hadithdefcmd{nasai}{122}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَسْحِ عَلَى الْخُفَّيْنِ أَنَّهُ لاَ بَأْسَ بِهِ ‏.‏\hadithno{122}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sa'd bin Abi Waqqas, from the Messenger of Allah (ﷺ), with regard to wiping over the Khuffs; "There is nothing wrong with it}}
\hadithdefcmd{nasai}{123}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ، قَالَ حَدَّثَنَا عِيسَى، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم لِحَاجَتِهِ فَلَمَّا رَجَعَ تَلَقَّيْتُهُ بِإِدَاوَةٍ فَصَبَبْتُ عَلَيْهِ فَغَسَلَ يَدَيْهِ ثُمَّ غَسَلَ وَجْهَهُ ثُمَّ ذَهَبَ لِيَغْسِلَ ذِرَاعَيْهِ فَضَاقَتْ بِهِ الْجُبَّةُ فَأَخْرَجَهُمَا مِنْ أَسْفَلِ الْجُبَّةِ فَغَسَلَهُمَا وَمَسَحَ عَلَى خُفَّيْهِ ثُمَّ صَلَّى بِنَا ‏.‏\hadithno{123}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Al-Mughirah bin Shu'bah said:"The Prophet (ﷺ) went out to relieve himself, and when he came back, I met him with a vessel (of water). I poured some for him and he washed his hands, then he washed his face. Then he wanted to wash his forearms but his Jubbah was too tight, so he brought them out from beneath the Jubbah to wash them, and he wiped over his Khuffs, then he led us in prayer}}
\hadithdefcmd{nasai}{124}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ الْمُغِيرَةِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ خَرَجَ لِحَاجَتِهِ فَاتَّبَعَهُ الْمُغِيرَةُ بِإِدَاوَةٍ فِيهَا مَاءٌ فَصَبَّ عَلَيْهِ حَتَّى فَرَغَ مِنْ حَاجَتِهِ فَتَوَضَّأَ وَمَسَحَ عَلَى الْخُفَّيْنِ ‏.‏\hadithno{124}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Al-Mughirah bin Shu'bah that the Messenger of Allah (ﷺ) went out to relieve himself, and Al-Mughirah followed him, (carrying) a vessel of water. He poured water for him when he had finished relieving himself, and he performed Wudu' and wiped over his Khuffs}}
\hadithdefcmd{nasai}{125}{\hadithno{125}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{126}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ رَخَّصَ لَنَا النَّبِيُّ صلى الله عليه وسلم إِذَا كُنَّا مُسَافِرِينَ أَنْ لاَ نَنْزِعَ خِفَافَنَا ثَلاَثَةَ أَيَّامٍ وَلَيَالِيَهُنَّ ‏.‏\hadithno{126}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Safwan bin 'Assal said:"The Prophet (ﷺ) granted us a dispensation when traveling, allowing us not to take off our Khuffs for three days and three nights}}
\hadithdefcmd{nasai}{127}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ الرُّهَاوِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، وَمَالِكُ بْنُ مِغْوَلٍ، وَزُهَيْرٌ، وَأَبُو بَكْرِ بْنُ عَيَّاشٍ وَسُفْيَانُ بْنُ عُيَيْنَةَ عَنْ عَاصِمٍ، عَنْ زِرٍّ، قَالَ سَأَلْتُ صَفْوَانَ بْنَ عَسَّالٍ عَنِ الْمَسْحِ، عَلَى الْخُفَّيْنِ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا إِذَا كُنَّا مُسَافِرِينَ أَنْ نَمْسَحَ عَلَى خِفَافِنَا وَلاَ نَنْزِعَهَا ثَلاَثَةَ أَيَّامٍ مِنْ غَائِطٍ وَبَوْلٍ وَنَوْمٍ إِلاَّ مِنْ جَنَابَةٍ ‏.‏\hadithno{127}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zirr said:"I asked Safwan bin 'Assal about wiping over the Khuffs, and he said: 'The Messenger of Allah (ﷺ) used to tell us, when we were travelling, to wipe over our Khuffs and not take them off for three nights in the event of defecating, urinating or sleeping; only in the case of Janabah}}
\hadithdefcmd{nasai}{128}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا الثَّوْرِيُّ، عَنْ عَمْرِو بْنِ قَيْسٍ الْمُلاَئِيِّ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ شُرَيْحِ بْنِ هَانِئٍ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْمُسَافِرِ ثَلاَثَةَ أَيَّامٍ وَلَيَالِيَهُنَّ وَيَوْمًا وَلَيْلَةً لِلْمُقِيمِ يَعْنِي فِي الْمَسْحِ ‏.‏\hadithno{128}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ali (may Allah be pleased with him) said:"The Messenger of Allah (ﷺ) set a time limit of three days and three nights for the traveler, and one day and one night for the resident - meaning, with regards to wiping (over the Khuffs)}}
\hadithdefcmd{nasai}{129}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ شُرَيْحِ بْنِ هَانِئٍ، قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - عَنِ الْمَسْحِ عَلَى الْخُفَّيْنِ فَقَالَتِ ائْتِ عَلِيًّا فَإِنَّهُ أَعْلَمُ بِذَلِكَ مِنِّي ‏.‏ فَأَتَيْتُ عَلِيًّا فَسَأَلْتُهُ عَنِ الْمَسْحِ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا أَنْ يَمْسَحَ الْمُقِيمُ يَوْمًا وَلَيْلَةً وَالْمُسَافِرُ ثَلاَثًا ‏.‏\hadithno{129}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Shuraih bin Hani' said:"I asked 'Aishah about wiping over the Khuffs and she said: 'Go to 'Ali, for he knows more about that than I do.' So I went to 'Ali and asked him about wiping (over the Khuffs) and he said: 'The Messenger of Allah (ﷺ) used to tell us to wipe (over the Khuffs) for one day and one night for the resident, and three for the traveler}}
\hadithdefcmd{nasai}{130}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، قَالَ سَمِعْتُ النَّزَّالَ بْنَ سَبْرَةَ، قَالَ رَأَيْتُ عَلِيًّا - رضى الله عنه - صَلَّى الظُّهْرَ ثُمَّ قَعَدَ لِحَوَائِجِ النَّاسِ فَلَمَّا حَضَرَتِ الْعَصْرُ أُتِيَ بِتَوْرٍ مِنْ مَاءٍ فَأَخَذَ مِنْهُ كَفًّا فَمَسَحَ بِهِ وَجْهَهُ وَذِرَاعَيْهِ وَرَأْسَهُ وَرِجْلَيْهِ ثُمَّ أَخَذَ فَضْلَهُ فَشَرِبَ قَائِمًا وَقَالَ إِنَّ نَاسًا يَكْرَهُونَ هَذَا وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ وَهَذَا وُضُوءُ مَنْ لَمْ يُحْدِثْ ‏.‏\hadithno{130}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{An-Nazzal bin Sabrah said:"I saw 'Ali (may Allah be please with him) praying Zuhr, then he sat to tend to the people's needs, and when the time for 'Asr came, a vessel of water was brought to him. He took a handful of it and wiped his face, forearms, head and feet with it, then he took what was left and drank standing up. He said: 'People dislike this, but I saw the Messenger of Allah (ﷺ) doing it. This is the Wudu' of one who has not committed Hadath}}
\hadithdefcmd{nasai}{131}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ عَامِرٍ، عَنْ أَنَسٍ، أَنَّهُ ذَكَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِإِنَاءٍ صَغِيرٍ فَتَوَضَّأَ ‏.‏ قُلْتُ أَكَانَ النَّبِيُّ صلى الله عليه وسلم يَتَوَضَّأُ لِكُلِّ صَلاَةٍ قَالَ نَعَمْ ‏.‏ قَالَ فَأَنْتُمْ قَالَ كُنَّا نُصَلِّي الصَّلَوَاتِ مَا لَمْ نُحْدِثْ قَالَ وَقَدْ كُنَّا نُصَلِّي الصَّلَوَاتِ بِوُضُوءٍ ‏.‏\hadithno{131}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Amr bin 'Amir that Anas mentioned:"The Messenger of Allah (ﷺ) was brought a small vessel (of water) and he performed Wudu'." I said: "Did the Messenger of Allah (ﷺ) perform Wudu' for every prayer?" He said: "Yes." He said: "What about you?" He said: "We used to pray all the prayers so long as we did not commit Hadath." He said: "And we used to pray all the prayers with (one) Wudu}}
\hadithdefcmd{nasai}{132}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مِنَ الْخَلاَءِ فَقُرِّبَ إِلَيْهِ طَعَامٌ فَقَالُوا أَلاَ نَأْتِيكَ بِوَضُوءٍ فَقَالَ ‏ "‏ إِنَّمَا أُمِرْتُ بِالْوُضُوءِ إِذَا قُمْتُ إِلَى الصَّلاَةِ ‏"‏ ‏.‏\hadithno{132}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) came out from the toilet and food was brought to him. They said:"Shall we not bring water for Wudu'?" He said: "I have only been commanded to perform Wudu' when I want to pray}}
\hadithdefcmd{nasai}{133}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا عَلْقَمَةُ بْنُ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ لِكُلِّ صَلاَةٍ فَلَمَّا كَانَ يَوْمُ الْفَتْحِ صَلَّى الصَّلَوَاتِ بِوُضُوءٍ وَاحِدٍ فَقَالَ لَهُ عُمَرُ فَعَلْتَ شَيْئًا لَمْ تَكُنْ تَفْعَلُهُ ‏.‏ قَالَ ‏ "‏ عَمْدًا فَعَلْتُهُ يَا عُمَرُ ‏"‏ ‏.‏\hadithno{133}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Buraidah that his father said:"The Messenger of Allah (ﷺ) used to perform Wudu' for every prayer. One the day of the Conquest (of Makkah), he offered all the prayers with one Wudu'. 'Umar said to him: 'You have done something that you never did before.' He said: 'I did that deliberately, O 'Umar}}
\hadithdefcmd{nasai}{134}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ الْحَكَمِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا تَوَضَّأَ أَخَذَ حَفْنَةً مِنْ مَاءٍ فَقَالَ بِهَا هَكَذَا - وَوَصَفَ شُعْبَةُ - نَضَحَ بِهِ فَرْجَهُ فَذَكَرْتُهُ لإِبْرَاهِيمَ فَأَعْجَبَهُ قَالَ الشَّيْخُ ابْنُ السُّنِّيِّ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الْحَكَمُ هُوَ ابْنُ سُفْيَانَ الثَّقَفِيُّ رضى الله عنه ‏.‏\hadithno{134}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Hakam, from his father, that when the Messenger of Allah (ﷺ) performed Wudu', he would take a handful of water and do this with it. Shu'bah described it:"He would sprinkle his private parts with it." [1] Shaikh Ibn As-Sunni said: "Al-Hakam (one of the narrators) is Ibn Sufyan Ath-Thaqafi. [1] The purpose is to ward off devilish whispers lest the person think any emission has taken place, and thus think that his Wudu' has been invalidated}}
\hadithdefcmd{nasai}{135}{أَخْبَرَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، قَالَ حَدَّثَنَا الأَحْوَصُ بْنُ جَوَّابٍ، حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، ��َنْ مَنْصُورٍ، ح وَأَنْبَأَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا قَاسِمٌ، - وَهُوَ ابْنُ يَزِيدَ الْجَرْمِيُّ - قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنِ الْحَكَمِ بْنِ سُفْيَانَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ وَنَضَحَ فَرْجَهُ ‏.‏ قَالَ أَحْمَدُ فَنَضَحَ فَرْجَهُ ‏.‏\hadithno{135}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Hakam bin Sufyan said:"I saw the Messenger of Allah (ﷺ) performing Wudu' and sprinkling his private area (with water)}}
\hadithdefcmd{nasai}{136}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ قَالَ حَدَّثَنَا أَبُو عَتَّابٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ، قَالَ رَأَيْتُ عَلِيًّا - رضى الله عنه - تَوَضَّأَ ثَلاَثًا ثَلاَثًا ثُمَّ قَامَ فَشَرِبَ فَضْلَ وَضُوئِهِ وَقَالَ صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَمَا صَنَعْتُ ‏.‏\hadithno{136}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hayyah said:"I saw 'Ali performing Wudu', washing each part thrice. Then he stood up and drank the water that was left over from his Wudu' and said: 'The Messenger of Allah (ﷺ) did as I have done}}
\hadithdefcmd{nasai}{137}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ شَهِدْتُ النَّبِيَّ صلى الله عليه وسلم بِالْبَطْحَاءِ وَأَخْرَجَ بِلاَلٌ فَضْلَ وَضُوئِهِ فَابْتَدَرَهُ النَّاسُ فَنِلْتُ مِنْهُ شَيْئًا وَرَكَزْتُ لَهُ الْعَنَزَةَ فَصَلَّى بِالنَّاسِ وَالْحُمُرُ وَالْكِلاَبُ وَالْمَرْأَةُ يَمُرُّونَ بَيْنَ يَدَيْهِ ‏.‏\hadithno{137}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Awn bin Abi Juhaifah that his father said:"I saw the Prophet (ﷺ) in Al-Batha'. Bilal brought out the water left over from his Wudu' and the people rushed toward it and I got some of it. Then a short spear was planted in the ground and he led the people in prayer, while donkeys, dogs and women were passing in front of him}}
\hadithdefcmd{nasai}{138}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ سَمِعْتُ ابْنَ الْمُنْكَدِرِ، يَقُولُ سَمِعْتُ جَابِرًا، يَقُولُ مَرِضْتُ فَأَتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ يَعُودَانِّي فَوَجَدَانِي قَدْ أُغْمِيَ عَلَىَّ فَتَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَبَّ عَلَىَّ وَضُوءَهُ ‏.‏\hadithno{138}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Al-Munkadir said:"I heard Jabir say: 'I fell sick, and the Messenger of Allah (ﷺ) and Abu Bakr came to visit me. They found me unconscious, so the Messenger of Allah (ﷺ) performed Wudu' and poured his Wudu' water over me}}
\hadithdefcmd{nasai}{139}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقْبَلُ اللَّهُ صَلاَةً بِغَيْرِ طُهُورٍ وَلاَ صَدَقَةً مِنْ غُلُولٍ ‏"‏ ‏.‏\hadithno{139}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Al-Malih, that his father said:"The Messenger of Allah (ﷺ) said: 'Allah does not accept Salah without purification, nor charity from Ghulul.'" [1] [1] That which is taken from the spoils of war prior to their distribution}}
\hadithdefcmd{nasai}{140}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم يَسْأَلُهُ عَنِ الْوُضُوءِ فَأَرَاهُ الْوُضُوءَ ثَلاَثًا ثَلاَثًا ثُمَّ قَالَ ‏ "‏ هَكَذَا الْوُضُوءُ فَمَنْ زَادَ عَلَى هَذَا فَقَدْ أَسَاءَ وَتَعَدَّى وَظَلَمَ ‏"‏ ‏.‏\hadithno{140}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"A Bedouin came to the Prophet (ﷺ) to ask him about Wudu', so he showed him how to perform Wudu', washing each part three times, then he said: 'This is Wudu'. Whoever does more than that has done badly, done to extremes and done wrong}}
\hadithdefcmd{nasai}{141}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا أَبُو جَهْضَمٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كُنَّا جُلُوسًا إِلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَقَالَ وَاللَّهِ مَا خَصَّنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَىْءٍ دُونَ النَّاسِ إِلاَّ بِثَلاَثَةِ أَشْيَاءَ فَإِنَّهُ أَمَرَنَا أَنْ نُسْبِغَ الْوُضُوءَ وَلاَ نَأْكُلَ الصَّدَقَةَ وَلاَ نُنْزِيَ الْحُمُرَ عَلَى الْخَيْلِ ‏.‏\hadithno{141}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin 'Ubaidullah bin 'Abbas said:"We were sitting with 'Abdullah bin 'Abbas and he said: 'By Allah, the Messenger of Allah (ﷺ) did not say specifically anything for us above the people, except for three things: He commanded us to do Wudu' properly, [2] not to consume charity, and not to mate donkeys with horses.'" [1] Isbagh Al-Wudu' [2] An Nusbig Al-Wudu}}
\hadithdefcmd{nasai}{142}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ أَبِي يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَسْبِغُوا الْوُضُوءَ ‏"‏ ‏.‏\hadithno{142}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah (ﷺ) said: 'Do Wudu' properly.'" [1] [1] Isbighu Al-Wudu'. And this narration supports the claim that some of them used this expression to mean "three times" for each limb, rather than "properly}}
\hadithdefcmd{nasai}{143}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِمَا يَمْحُو اللَّهُ بِهِ الْخَطَايَا وَيَرْفَعُ بِهِ الدَّرَجَاتِ إِسْبَاغُ الْوُضُوءِ عَلَى الْمَكَارِهِ وَكَثْرَةُ الْخُطَا إِلَى الْمَسَاجِدِ وَانْتِظَارُ الصَّلاَةِ بَعْدَ الصَّلاَةِ فَذَلِكُمُ الرِّبَاطُ فَذَلِكُمُ الرِّبَاطُ فَذَلِكُمُ الرِّبَاطُ ‏"‏ ‏.‏\hadithno{143}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Shall I not tell you of that by means of which Allah erases sins and raises (people) in status? Doing Wudu' properly [1] even when it is inconvenient, taking a lot of steps to the Masjid, and waiting for one Salah after another. That is the Ribat for you, that is the Ribat for you, that is the Ribat for you." [1] Isbagh Al-Wudu}}
\hadithdefcmd{nasai}{144}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ سُفْيَانَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَاصِمِ بْنِ سُفْيَانَ الثَّقَفِيِّ، أَنَّهُمْ غَزَوْا غَزْوَةَ السَّلاَسِلِ فَفَاتَهُمُ الْغَزْوُ فَرَابَطُوا ثُمَّ رَجَعُوا إِلَى مُعَاوِيَةَ وَعِنْدَهُ أَبُو أَيُّوبَ وَعُقْبَةُ بْنُ عَامِرٍ فَقَالَ عَاصِمٌ يَا أَبَا أَيُّوبَ فَاتَنَا الْغَزْوُ الْعَامَ وَقَدْ أُخْبِرْنَا أَنَّهُ مَنْ صَلَّى فِي الْمَسَاجِدِ الأَرْبَعَةِ غُفِرَ لَهُ ذَنْبُهُ ‏.‏ فَقَالَ يَا ابْنَ أَخِي أَدُلُّكَ عَلَى أَيْسَرَ مِنْ ذَلِكَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ تَوَضَّأَ كَمَا أُمِرَ وَصَلَّى كَمَا أُمِرَ غُفِرَ لَهُ مَا قَدَّمَ مِنْ عَمَلٍ ‏"‏ ‏.‏ أَكَذَلِكَ يَا عُقْبَةُ قَالَ نَعَمْ ‏.‏\hadithno{144}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Asim bin Sufyan Ath-Thaqafi that they went out for the battle of As-Salasil, but they missed the fighting, so they kept watch, then they went back to Mu'awiyah, and Abu Ayyub and 'Uqbah bin 'Amir were with him. 'Asim said:"O Abu Ayyub, we missed the general mobilization, but we have been told that whoever prays in the four Masjids will be forgiven his sins." He said: "O son of my brother! I will tell you of something easier than that. I heard the Messenger of Allah (ﷺ) says: 'Whoever performs Wudu' as commanded and prays as commanded, will be forgiven for his previous actions.' Is it not so, O 'Uqbah?" He said: "Yes}}
\hadithdefcmd{nasai}{145}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ جَامِعِ بْنِ شَدَّادٍ، قَالَ سَمِعْتُ حُمْرَانَ بْنَ أَبَانَ، أَخْبَرَ أَبَا بُرْدَةَ، فِي الْمَسْجِدِ أَنَّهُ سَمِعَ عُثْمَانَ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَتَمَّ الْوُضُوءَ كَمَا أَمَرَهُ اللَّهُ عَزَّ وَجَلَّ فَالصَّلَوَاتُ الْخَمْسُ كَفَّارَاتٌ لِمَا بَيْنَهُنَّ ‏"‏ ‏.‏\hadithno{145}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jami' bin Shaddad said:"I heard Humran bin Aban tell Abu Burdah in the Masjid that he heard 'Uthman narrating that the Messenger of Allah (ﷺ) said: 'Whoever performs Wudu' completely as commanded by Allah, the five daily prayers will be an expiation for whatever comes in between them}}
\hadithdefcmd{nasai}{146}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ أَنَّ عُثْمَانَ، - رضى الله عنه - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنِ امْرِئٍ يَتَوَضَّأُ فَيُحْسِنُ وُضُوءَهُ ثُمَّ يُصَلِّي الصَّلاَةَ إِلاَّ غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الصَّلاَةِ الأُخْرَى حَتَّى يُصَلِّيَهَا ‏"‏ ‏.‏\hadithno{146}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Uthman said:"I heard the Messenger of Allah (ﷺ) say: 'There is no man who performs Wudu' and does it well, then prays, but when he prays it, he will be forgiven whatever (sins he commits) between that and the next prayer}}
\hadithdefcmd{nasai}{147}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا اللَّيْثُ، - هُوَ ابْنُ سَعْدٍ - قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، قَالَ أَخْبَرَنِي أَبُو يَحْيَى، سُلَيْمُ بْنُ عَامِرٍ وَضَمْرَةُ بْنُ حَبِيبٍ وَأَبُو طَلْحَةَ نُعَيْمُ بْنُ زِيَادٍ قَالُوا سَمِعْنَا أَبَا أُمَامَةَ الْبَاهِلِيَّ، يَقُولُ سَمِعْتُ عَمْرَو بْنَ عَبَسَةَ، يَقُولُ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ الْوُضُوءُ قَالَ ‏ "‏ أَمَّا الْوُضُوءُ فَإِنَّكَ إِذَا تَوَضَّأْتَ فَغَسَلْتَ كَفَّيْكَ فَأَنْقَيْتَهُمَا خَرَجَتْ خَطَايَاكَ مِنْ بَيْنِ أَظْفَارِكَ وَأَنَامِلِكَ فَإِذَا مَضْمَضْتَ وَاسْتَنْشَقْتَ مَنْخِرَيْكَ وَغَسَلْتَ وَجْهَكَ وَيَدَيْكَ إِلَى الْمِرْفَقَيْنِ وَمَسَحْتَ رَأْسَكَ وَغَسَلْتَ رِجْلَيْكَ إِلَى الْكَعْبَيْنِ اغْتَسَلْتَ مِنْ عَامَّةِ خَطَايَاكَ فَإِنْ أَنْتَ وَضَعْتَ وَجْهَكَ لِلَّهِ عَزَّ وَجَلَّ خَرَجْتَ مِنْ خَطَايَاكَ كَيَوْمَ وَلَدَتْكَ أُمُّكَ ‏"‏ ‏.‏ قَالَ أَبُو أُمَامَةَ فَقُلْتُ يَا عَمْرُو بْنَ عَبَسَةَ انْظُرْ مَا تَقُولُ أَكُلُّ هَذَا يُعْطَى فِي مَجْلِسٍ وَاحِدٍ فَقَالَ أَمَا وَاللَّهِ لَقَدْ كَبِرَتْ سِنِّي وَدَنَا أَجَلِي وَمَا بِي مِنْ فَقْرٍ فَأَكْذِبَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَقَدْ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{147}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Amr bin 'Abasah said:"I said: 'O Messenger of Allah! How is Wudu' done?' He said: 'As for Wudu', when you perform Wudu', and you wash your hands to clean them, your sins come out from between your fingers and fingertips. When you rinse your mouth and nostrils, and wash your face and hands up to the elbows, and wipe your head, and wash your feet up to the ankles, you are cleansed of all your sins. When you prostrate your face to Allah, may He be exalted, you emerge from your sins like the day your mother bore you.'" Abu Umamah said: "I said: 'O 'Amr bin 'Abasah! Look at what you are saying! Was all of that given in one sitting? He said: 'By Allah, I have grown old, my appointed time is near and I am not so poor that I should tell lies about the Messenger of Allah (ﷺ). I heard it with my own ears and understood it in my heart from the Messenger of Allah}}
\hadithdefcmd{nasai}{148}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ حَرْبٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، وَأَبِي، عُثْمَانَ عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ فُتِّحَتْ لَهُ ثَمَانِيَةُ أَبْوَابِ الْجَنَّةِ يَدْخُلُ مِنْ أَيِّهَا شَاءَ ‏"‏ ‏.‏\hadithno{148}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Umar bin Al-Khattab said:"The Messenger of Allah (ﷺ) said: 'Whoever performs Wudu' and does it well, then says: "Ashhadu an la ilaha ill-Allah was ashhadu anna Muhammadan 'abduhu wa rasuluh (I bear witness that there is none worthy of worship except Allah, and I bear witness that Muhammad is his slave and Messenger)," eight gates of Paradise will be opened for him, and he may enter through whichever one he wishes}}
\hadithdefcmd{nasai}{149}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ خَلَفٍ، - وَهُوَ ابْنُ خَلِيفَةَ - عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ أَبِي حَازِمٍ، قَالَ كُنْتُ خَلْفَ أَبِي هُرَيْرَةَ وَهُوَ يَتَوَضَّأُ لِلصَّلاَةِ وَكَانَ يَغْسِلُ يَدَيْهِ حَتَّى يَبْلُغَ إِبْطَيْهِ فَقُلْتُ يَا أَبَا هُرَيْرَةَ مَا هَذَا الْوُضُوءُ فَقَالَ لِي يَا بَنِي فَرُّوخَ أَنْتُمْ هَا هُنَا لَوْ عَلِمْتُ أَنَّكُمْ هَا هُنَا مَا تَوَضَّأْتُ هَذَا الْوُضُوءَ سَمِعْتُ خَلِيلِي صلى الله عليه وسلم يَقُولُ ‏ "‏ تَبْلُغُ حِلْيَةُ الْمُؤْمِنِ حَيْثُ يَبْلُغُ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{149}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hazim said:"I was behind Abu Hurairah when he performed Wudu' for Salah. He washed his hand up to the armpit, and I said: 'O Abu Hurairah! What is this Wudu'?' He said to me: 'O Banu Farrukh! You are here! If I had known that you were here I would not have performed Wudu' like this. I heard my close friend (i.e., the Prophet (ﷺ)) says: "The jewelry of the believer will reach as far as his Wudu reached}}
\hadithdefcmd{nasai}{150}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الْمَقْبُرَةِ فَقَالَ ‏"‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ وَدِدْتُ أَنِّي قَدْ رَأَيْتُ إِخْوَانَنَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَلَسْنَا إِخْوَانَكَ قَالَ ‏"‏ بَلْ أَنْتُمْ أَصْحَابِي وَإِخْوَانِي الَّذِينَ لَمْ يَأْتُوا بَعْدُ وَأَنَا فَرَطُهُمْ عَلَى الْحَوْضِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ تَعْرِفُ مَنْ يَأْتِي بَعْدَكَ مِنْ أُمَّتِكَ قَالَ ‏"‏ أَرَأَيْتَ لَوْ كَانَ لِرَجُلٍ خَيْلٌ غُرٌّ مُحَجَّلَةٌ فِي خَيْلٍ بُهْمٍ دُهْمٍ أَلاَ يَعْرِفُ خَيْلَهُ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ فَإِنَّهُمْ يَأْتُونَ يَوْمَ الْقِيَامَةِ غُرًّا مُحَجَّلِينَ مِنَ الْوُضُوءِ وَأَنَا فَرَطُهُمْ عَلَى الْحَوْضِ ‏"‏ ‏.‏\hadithno{150}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) went out to the graveyeard and said:"Peace be upon you, abode of believing people. If Allah wills, we shall join you soon. Would that I had seen our brothers." They said: "O Messenger of Allah, are we not your brother?" He said: "You are my Companions. My brothers are those who have not come yet. And I will reach the Hawd before you." They said: "O Messenger of Allah, how will you know those of your Ummah who come after you?" He said: "Don't you think that if a man has a horse with a white blaze and white feet among horses that are solid black, he will recognize his horse?" They said: "Of course." He said: "They will come on the Day of Resurrection with glittering white faces and glittering white hands and feet because of Wudu', and I will reach the Hawd before them}}
\hadithdefcmd{nasai}{151}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْمَسْرُوقِيُّ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، قَالَ حَدَّثَنَا رَبِيعَةُ بْنُ يَزِيدَ الدِّمَشْقِيُّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، وَأَبِي، عُثْمَانَ عَنْ جُبَيْرِ بْنِ نُفَيْرٍ الْحَضْرَمِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ صَلَّى رَكْعَتَيْنِ يُقْبِلُ عَلَيْهِمَا بِقَلْبِهِ وَوَجْهِهِ وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{151}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Uqbah bin 'Amir Al-Juhani said:"The Messenger of Allah (ﷺ) said: 'Whoever performs Wudu' and does it well, then prays two Rak'ahs in which his heart and face are focused, Paradise will be his}}
\hadithdefcmd{nasai}{152}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، قَالَ قَالَ عَلِيٌّ كُنْتُ رَجُلاً مَذَّاءً وَكَانَتِ ابْنَةُ النَّبِيِّ صلى الله عليه وسلم تَحْتِي فَاسْتَحْيَيْتُ أَنْ أَسْأَلَهُ فَقُلْتُ لِرَجُلٍ جَالِسٍ إِلَى جَنْبِي سَلْهُ ‏.‏ فَسَأَلَهُ فَقَالَ ‏ "‏ فِيهِ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{152}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ali said:"I was a man who had a lot of prostatic discharge, and the daughter of the Prophet (ﷺ) was married to me, so I felt shy to ask him (about that). I said to a man who was sitting beside me: 'Ask him,' so he asked him and he said: 'Perform Wudu' for that}}
\hadithdefcmd{nasai}{153}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ قُلْتُ لِلْمِقْدَادِ إِذَا بَنَى الرَّجُلُ بِأَهْلِهِ فَأَمْذَى وَلَمْ يُجَامِعْ فَسَلِ النَّبِيَّ صلى الله عليه وسلم عَنْ ذَلِكَ فَإِنِّي أَسْتَحِي أَنْ أَسْأَلَهُ عَنْ ذَلِكَ وَابْنَتُهُ تَحْتِي ‏.‏ فَسَأَلَهُ فَقَالَ ‏ "‏ يَغْسِلُ مَذَاكِيرَهُ وَيَتَوَضَّأُ وُضُوءَهُ لِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{153}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"I said to Al-Miqdad: 'If a man is intimate with his wife and excretes prostatic fluid but does not have intercourse - ask the Prophet (ﷺ) about that, for I am too shy to ask him about it since his daughter is married to me.' So he asked him, and he said: 'Let him wash his male member and perform Wudu' as for Salah}}
\hadithdefcmd{nasai}{154}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ عَائِشِ بْنِ أَنَسٍ، أَنَّ عَلِيًّا، قَالَ كُنْتُ رَجُلاً مَذَّاءً فَأَمَرْتُ عَمَّارَ بْنَ يَاسِرٍ يَسْأَلُ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ أَجْلِ ابْنَتِهِ عِنْدِي فَقَالَ ‏ "‏ يَكْفِي مِنْ ذَلِكَ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{154}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'A'ish bin Anas that 'Ali said:"I was a man who had a lot of prostatic discharge, so I told 'Ammar bin Yasir to ask the Messenger of Allah (ﷺ) (about it) because his daughter was married to me. He said: 'Wudu' is sufficient for that}}
\hadithdefcmd{nasai}{155}{أَخْبَرَنَا عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ أَنْبَأَنَا أُمَيَّةُ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَنَّ رَوْحَ بْنَ الْقَاسِمِ، حَدَّثَهُ عَنِ ابْنِ أَبِي نُجَيْحٍ، عَنْ عَطَاءٍ، عَنْ إِيَاسِ بْنِ خَلِيفَةَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ عَلِيًّا، أَمَرَ عَمَّارًا أَنْ يَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمَذْىِ فَقَالَ ‏ "‏ يَغْسِلُ مَذَاكِيرَهُ وَيَتَوَضَّأُ ‏"‏ ‏.‏\hadithno{155}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Rafi' bin Khadij that 'Ali told 'Ammar to ask the Messenger of Allah (ﷺ) about prostatic fluid, and he said:'Let him wash his male member and perform Wudu}}
\hadithdefcmd{nasai}{156}{أَخْبَرَنَا عُتْبَةُ بْنُ عَبْدِ اللَّهِ الْمَرْوَزِيُّ، عَنْ مَالِكٍ، - وَهُوَ ابْنُ أَنَسٍ - عَنْ أَبِي النَّضْرِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ، أَنَّ عَلِيًّا، أَمَرَهُ أَنْ يَسْأَلَ، رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ إِذَا دَنَا مِنْ أَهْلِهِ فَخَرَجَ مِنْهُ الْمَذْىُ مَاذَا عَلَيْهِ فَإِنَّ عِنْدِي ابْنَتَهُ وَأَنَا أَسْتَحِي أَنْ أَسَأَلَهُ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِذَا وَجَدَ أَحَدُكُمْ ذَلِكَ فَلْيَنْضَحْ فَرْجَهُ وَيَتَوَضَّأْ وُضُوءَهُ لِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{156}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Miqdad bin Al-Aswad that 'Ali told him to ask the Messenger of Allah (ﷺ) about a man who comes close to his wife and prostatic fluid comes out of him - what should he do? ('Ali said:) For his daughter is married to me and I feel too shy to ask him. So I asked the Messenger of Allah (ﷺ) about that and he said: "If any one of you experiences that, let him sprinkle water on his private part and perform Wudu' as for Salah}}
\hadithdefcmd{nasai}{157}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، قَالَ أَخْبَرَنِي سُلَيْمَانُ، قَالَ سَمِعْتُ مُنْذِرًا، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ عَلِيٍّ، قَالَ اسْتَحْيَيْتُ أَنْ أَسْأَلَ النَّبِيَّ، صلى الله عليه وسلم عَنِ الْمَذْىِ مِنْ أَجْلِ فَاطِمَةَ فَأَمَرْتُ الْمِقْدَادَ بْنَ الأَسْوَدِ فَسَأَلَهُ فَقَالَ ‏ "‏ فِيهِ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{157}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ali said:"I felt too shy to ask the Messenger of Allah (ﷺ) about prostatic fluid because of Fatimah, so I told Al-Miqdad bin Al-Aswad to ask about it, and he (the Prophet (ﷺ)) said: 'Perform Wudu' for that}}
\hadithdefcmd{nasai}{158}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، أَنَّهُ سَمِعَ زِرَّ بْنَ حُبَيْشٍ، يُحَدِّثُ قَالَ أَتَيْتُ رَجُلاً يُدْعَى صَفْوَانَ بْنَ عَسَّالٍ فَقَعَدْتُ عَلَى بَابِهِ فَخَرَجَ فَقَالَ مَا شَأْنُكَ قُلْتُ أَطْلُبُ الْعِلْمَ ‏.‏ قَالَ إِنَّ الْمَلاَئِكَةَ تَضَعُ أَجْنِحَتَهَا لِطَالِبِ الْعِلْمِ رِضًا بِمَا يَطْلُبُ ‏.‏ فَقَالَ عَنْ أَىِّ شَىْءٍ تَسْأَلُ قُلْتُ عَنِ الْخُفَّيْنِ ‏.‏ قَالَ كُنَّا إِذَا كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ أَمَرَنَا أَنْ لاَ نَنْزِعَهُ ثَلاَثًا إِلاَّ مِنْ جَنَابَةٍ وَلَكِنْ مِنْ غَائِطٍ وَبَوْلٍ وَنَوْمٍ ‏.‏\hadithno{158}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Zirr bin Hubaish narrated:"I came to a man called Safwan bin 'Assal and sat at his door. He came out and said: 'What do you want?' I said: 'I am seeking knowledge.' He said: 'The angels lower their wings for the seeker of knowledge out of pleasure at what he is seeking.' He said: 'What do you want to know about?' I said: 'About the Khuffs.' He said: 'When we were with the Messenger of Allah (ﷺ) on a journey, he told us not to take them off for three days except in the case of Janabah, but not in the case of defecation, urinating or sleep}}
\hadithdefcmd{nasai}{159}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَإِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، قَالَ قَالَ صَفْوَانُ بْنُ عَسَّالٍ كُنَّا إِذَا كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ أَمَرَنَا أَنْ لاَ نَنْزِعَهُ ثَلاَثًا إِلاَّ مِنْ جَنَابَةٍ وَلَكِنْ مِنْ غَائِطٍ وَبَوْلٍ وَنَوْمٍ ‏.‏\hadithno{159}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Safwan bin 'Assal said:"When we were with the Messenger of Allah (ﷺ) on a journey, he told us not to take them off for three days except in the case of Janabah, but not in the case of defecation, urinating or sleep}}
\hadithdefcmd{nasai}{160}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، ح وَأَخْبَرَنِي مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، قَالَ أَخْبَرَنِي سَعِيدٌ، - يَعْنِي ابْنَ الْمُسَيَّبِ - وَعَبَّادُ بْنُ تَمِيمٍ عَنْ عَمِّهِ، - وَهُوَ عَبْدُ اللَّهِ بْنُ زَيْدٍ - قَالَ شُكِيَ إِلَى النَّبِيِّ صلى الله عليه وسلم الرَّجُلُ يَجِدُ الشَّىْءَ فِي الصَّلاَةِ قَالَ ‏ "‏ لاَ يَنْصَرِفْ حَتَّى يَجِدَ رِيحًا أَوْ يَسْمَعَ صَوْتًا ‏"‏ ‏.‏\hadithno{160}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Sa'eed - meaning Ibn Al-Musayyab - and 'Abbad bin Tamim narrated that his uncle - 'Abdullah bin Zaid - said:"A man who felt something during Salah complained to the Prophet (ﷺ). He said: 'Do not stop praying unless you notice a smell or hear a sound}}
\hadithdefcmd{nasai}{161}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ مَنَامِهِ فَلاَ يُدْخِلْ يَدَهُ فِي الإِنَاءِ حَتَّى يُفْرِغَ عَلَيْهَا ثَلاَثَ مَرَّاتٍ فَإِنَّهُ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏\hadithno{161}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"When any one of you wakes from sleep, let him not put his hand into the vessel until he has washed it three times, because he does not know where his hand spent the night}}
\hadithdefcmd{nasai}{162}{أَخْبَرَنَا بِشْرُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا نَعَسَ الرَّجُلُ وَهُوَ فِي الصَّلاَةِ فَلْيَنْصَرِفْ لَعَلَّهُ يَدْعُو عَلَى نَفْسِهِ وَهُوَ لاَ يَدْرِي ‏"‏ ‏.‏\hadithno{162}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Messenger of Allah (ﷺ) said: 'If a man feels drowsy when he is praying, let him stop, lest he supplicate against himself without realizing}}
\hadithdefcmd{nasai}{163}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَعْنٌ، أَنْبَأَنَا مَالِكٌ، ح وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ أَنْبَأَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّهُ سَمِعَ عُرْوَةَ بْنَ الزُّبَيْرِ، يَقُولُ دَخَلْتُ عَلَى مَرْوَانَ بْنِ الْحَكَمِ فَذَكَرْنَا مَا يَكُونُ مِنْهُ الْوُضُوءُ فَقَالَ مَرْوَانُ مِنْ مَسِّ الذَّكَرِ الْوُضُوءُ ‏.‏ فَقَالَ عُرْوَةُ مَا عَلِمْتُ ذَلِكَ ‏.‏ فَقَالَ مَرْوَانُ أَخْبَرَتْنِي بُسْرَةُ بِنْتُ صَفْوَانَ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا مَسَّ أَحَدُكُمْ ذَكَرَهُ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{163}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Urwah bin Az-Zubair said:"I entered upon Mawan bin Al-Hakam and we mentioned the things for which Wudu' is done. Marwan said: 'Wudu' should be done after touching the penis.' 'Urwah said: 'I did not know that.' Marwan said: 'Busrah bint Safwan told me that she heard the Messenger of Allah (ﷺ) say: "And if any one of you touches his penis, let him do Wudu}}
\hadithdefcmd{nasai}{164}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ سَعِيدٍ، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّهُ سَمِعَ عُرْوَةَ بْنَ الزُّبَيْرِ، يَقُولُ ذَكَرَ مَرْوَانُ فِي إِمَارَتِهِ عَلَى الْمَدِينَةِ أَنَّهُ يُتَوَضَّأُ مِنْ مَسِّ الذَّكَرِ إِذَا أَفْضَى إِلَيْهِ الرَّجُلُ بِيَدِهِ فَأَنْكَرْتُ ذَلِكَ وَقُلْتُ لاَ وُضُوءَ عَلَى مَنْ مَسَّهُ ‏.‏ فَقَالَ مَرْوَانُ أَخْبَرَتْنِي بُسْرَةُ بِنْتُ صَفْوَانَ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ مَا يُتَوَضَّأُ مِنْهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَيُتَوَضَّأُ مِنْ مَسِّ الذَّكَرِ ‏"‏ ‏.‏ قَالَ عُرْوَةُ فَلَمْ أَزَلْ أُمَارِي مَرْوَانَ حَتَّى دَعَا رَجُلاً مِنْ حَرَسِهِ فَأَرْسَلَهُ إِلَى بُسْرَةَ فَسَأَلَهَا عَمَّا حَدَّثَتْ مَرْوَانَ فَأَرْسَلَتْ إِلَيْهِ بُسْرَةُ بِمِثْلِ الَّذِي حَدَّثَنِي عَنْهَا مَرْوَانُ ‏.‏\hadithno{164}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Urwah bin Az-Zubair said:"When he was the governor of Al-Madinah, Marwan mentioned that a man should perform Wudu' after touching his penis, if he touches it iwth his hand. I did not like that and I said: 'The one who touches it does not have to perform Wudu'.' Marwan said: 'Busrah bint Safwan told me that she heard the Messenger of Allah (ﷺ) mention the things for which Wudu' should be performed, and the Messenger of Allah (ﷺ) said: 'Wudu' should be performed after touching the penis.' 'Urwah said: 'I continued to argue with Marwan until he called one of his guards and sent him to Busrah to ask her about what Marwan had narrated, and Busrah sent word saying something like that which Marwan had narrated to me from her}}
\hadithdefcmd{nasai}{165}{أَخْبَرَنَا هَنَّادٌ، عَنْ مُلاَزِمٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَدْرٍ، عَنْ قَيْسِ بْنِ طَلْقِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، قَالَ خَرَجْنَا وَفْدًا حَتَّى قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَايَعْنَاهُ وَصَلَّيْنَا مَعَهُ فَلَمَّا قَضَى الصَّلاَةَ جَاءَ رَجُلٌ كَأَنَّهُ بَدَوِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ مَا تَرَى فِي رَجُلٍ مَسَّ ذَكَرَهُ فِي الصَّلاَةِ قَالَ ‏ "‏ وَهَلْ هُوَ إِلاَّ مُضْغَةٌ مِنْكَ أَوْ بَضْعَةٌ مِنْكَ ‏"‏ ‏.‏\hadithno{165}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Talq bin 'Ali said:"We went out as a delegation and when we arrived with the Messenger of Allah (ﷺ) he accepted our oath of allegiance and we prayed with him. When he had finished the prayer, a man who looked like a Bedouin came to him and said: 'O Messenger of Allah, what do you think about a man who touched his penis during the Salah?' He said: 'It is just a part of you,' or 'a piece of you}}
\hadithdefcmd{nasai}{166}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، قَالَ أَنْبَأَنَا ابْنُ الْهَادِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُصَلِّي وَإِنِّي لَمُعْتَرِضَةٌ بَيْنَ يَدَيْهِ اعْتِرَاضَ الْجَنَازَةِ حَتَّى إِذَا أَرَادَ أَنْ يُوتِرَ مَسَّنِي بِرِجْلِهِ ‏.‏\hadithno{166}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) used to pray when I was lying in front of him as the bier is placed (in front of the Imam), and when he wanted to pray Witr he would nudge me with his foot}}
\hadithdefcmd{nasai}{167}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ، يُحَدِّثُ عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُمُونِي مُعْتَرِضَةً بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فَإِذَا أَرَادَ أَنْ يَسْجُدَ غَمَزَ رِجْلِي فَضَمَمْتُهَا إِلَىَّ ثُمَّ يَسْجُدُ ‏.‏\hadithno{167}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"I remember lying in front of the Messenger of Allah (ﷺ), and the Messenger of Allah (ﷺ) was praying. When he wanted to prostrate he would nudge my foot and I would draw it up (out of the way) until he had finished prostrating}}
\hadithdefcmd{nasai}{168}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَنَامُ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرِجْلاَىَ فِي قِبْلَتِهِ فَإِذَا سَجَدَ غَمَزَنِي فَقَبَضْتُ رِجْلَىَّ فَإِذَا قَامَ بَسَطْتُهُمَا وَالْبُيُوتُ يَوْمَئِذٍ لَيْسَ فِيهَا مَصَابِيحُ ‏.‏\hadithno{168}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"I used to sleep in front of the Messenger of Allah (ﷺ) and my feet were in the direction of his Qiblah. When he prostrated he nudged me and I drew up my feet, then when he stood up I stretched them out again. And there were no lamps in the houses at the time}}
\hadithdefcmd{nasai}{169}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، وَنُصَيْرُ بْنُ الْفَرَجِ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ فَقَدْتُ النَّبِيَّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَجَعَلْتُ أَطْلُبُهُ بِيَدِي فَوَقَعَتْ يَدِي عَلَى قَدَمَيْهِ وَهُمَا مَنْصُوبَتَانِ وَهُوَ سَاجِدٌ يَقُولُ ‏ "‏ أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَبِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَأَعُوذُ بِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏\hadithno{169}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that 'Aishah said:"I noticed the Prophet (ﷺ) was not there one night, so I started looking for him with my hand. My hand touched his feet and they were held upright, and he was prostrating and saying: 'I seek refuge in Your pleasure from Your anger, in Your forgiveness from Your punishment, and I seek refuge in You from You. I cannot praise You enough, You are as You have praised yourself}}
\hadithdefcmd{nasai}{170}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ أَخْبَرَنِي أَبُو رَوْقٍ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُقَبِّلُ بَعْضَ أَزْوَاجِهِ ثُمَّ يُصَلِّي وَلاَ يَتَوَضَّأُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لَيْسَ فِي هَذَا الْبَابِ حَدِيثٌ أَحْسَنُ مِنْ هَذَا الْحَدِيثِ وَإِنَ كَانَ مُرْسَلاً وَقَدْ رَوَى هَذَا الْحَدِيثَ الأَعْمَشُ عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ عَنْ عُرْوَةَ عَنْ عَائِشَةَ ‏.‏ قَالَ يَحْيَى الْقَطَّانُ حَدِيثُ حَبِيبٍ عَنْ عُرْوَةَ عَنْ عَائِشَةَ هَذَا وَحَدِيثُ حَبِيبٍ عَنْ عُرْوَةَ عَنْ عَائِشَةَ تُصَلِّي وَإِنْ قَطَرَ الدَّمُ عَلَى الْحَصِيرِ لاَ شَىْءَ ‏.‏\hadithno{170}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that the Prophet (ﷺ) used to kiss one of his wives then pray without performing Wudu'. Abu 'Abdur-Rahman said:"There is nothing for this chapter which is better than this hadith, even though it is Mursal. And Al-A'mash reported this Hadith from Habib bin Abi Thabit, from 'Urwah, from 'Aishah. Yahya Al-Qattan said: "This is the Hadith of Habib from 'Urwah, from 'Aishah. And the Hadith of Habib from 'Urwah, from 'Aishah: "She prays even if blood drips on the mat" is nothing}}
\hadithdefcmd{nasai}{171}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا إِسْمَاعِيِلُ، وَعَبْدُ الرَّزَّاقِ، قَالاَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ قَارِظٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{171}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"I heard the Messenger of Allah (ﷺ) say: 'Perform Wudu' from that which has been touched by fire}}
\hadithdefcmd{nasai}{172}{أَخْبَرَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ حَرْبٍ - قَالَ حَدَّثَنِي الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ قَارِظٍ أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{172}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah (ﷺ) say: 'Perform Wudu' from that which has been touched by fire}}
\hadithdefcmd{nasai}{173}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرٍ، - وَهُوَ ابْنُ مُضَرَ - قَالَ حَدَّثَنِي أَبِي، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عَبْدِ اللَّهِ بْنِ إِبْرَاهِيمَ بْنِ قَارِظٍ، قَالَ رَأَيْتُ أَبَا هُرَيْرَةَ يَتَوَضَّأُ عَلَى ظَهْرِ الْمَسْجِدِ فَقَالَ أَكَلْتُ أَثْوَارَ أَقِطٍ فَتَوَضَّأْتُ مِنْهَا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِالْوُضُوءِ مِمَّا مَسَّتِ النَّارُ ‏.‏\hadithno{173}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Ibrahim bin Qariz said:"I saw Abu Hurairah performing Wudu' on the roof of the Masjid ans he said: 'I ate some tough cheese, so I performed Wudu' because of that. I heard the Messenger of Allah (ﷺ) commanding us to do Wudu' from that which has been touched by fire}}
\hadithdefcmd{nasai}{174}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا أَبِي، عَنْ حُسَيْنٍ الْمُعَلِّمِ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرٍو الأَوْزَاعِيِّ، أَنَّهُ سَمِعَ الْمُطَّلِبَ بْنَ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ، يَقُولُ قَالَ ابْنُ عَبَّاسٍ أَتَوَضَّأُ مِنْ طَعَامٍ أَجِدُهُ فِي كِتَابِ اللَّهِ حَلاَلاً لأَنَّ النَّارَ مَسَّتْهُ فَجَمَعَ أَبُو هُرَيْرَةَ حَصًى فَقَالَ أَشْهَدُ عَدَدَ هَذَا الْحَصَى أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{174}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas said:"Should I perform Wudu' after eating food that I see in the Book of Allah is permissible because fire has touched it?" Abu Hurairah gathered some pebbles and said: "I bear witness (as many times as) the number of these pebbles, that the Messenger of Allah (ﷺ) said: 'Perform Wudu' from that which has been touched by fire}}
\hadithdefcmd{nasai}{175}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ يَحْيَى بْنِ جَعْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{175}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:'Perform Wudu' from that which has been touched by fire}}
\hadithdefcmd{nasai}{176}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ أَنْبَأَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ يَحْيَى بْنِ جَعْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، - قَالَ مُحَمَّدٌ الْقَارِيُّ - عَنْ أَبِي أَيُّوبَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تَوَضَّئُوا مِمَّا غَيَّرَتِ النَّارُ ‏"‏ ‏.‏\hadithno{176}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Ayyub said:"The Messenger of Allah (ﷺ) said: 'Perform Wudu' from that which has been altered by fire}}
\hadithdefcmd{nasai}{177}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا حَرَمِيٌّ، - وَهُوَ ابْنُ عُمَارَةَ بْنِ أَبِي حَفْصَةَ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ يَحْيَى بْنَ جَعْدَةَ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو الْقَارِيِّ، عَنْ أَبِي طَلْحَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَوَضَّئُوا مِمَّا غَيَّرَتِ النَّارُ ‏"‏ ‏.‏\hadithno{177}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Talhah that the Messenger of Allah (ﷺ) said:"Perform Wudu' from that which has been altered by fire}}
\hadithdefcmd{nasai}{178}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ أَبِي طَلْحَةَ، عَنْ أَبِي طَلْحَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ تَوَضَّئُوا مِمَّا أَنْضَجَتِ النَّارُ ‏"‏ ‏.‏\hadithno{178}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Talhah that the Prophet (ﷺ) said:"Perform Wudu' from that which has been heated with fire}}
\hadithdefcmd{nasai}{179}{أَخْبَرَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا الزُّبَيْدِيُّ، قَالَ أَخْبَرَنِي الزُّهْرِيُّ، أَنَّ عَبْدَ الْمَلِكِ بْنَ أَبِي بَكْرٍ، أَخْبَرَهُ أَنَّ خَارِجَةَ بْنَ زَيْدِ بْنِ ثَابِتٍ أَخْبَرَهُ أَنَّ زَيْدَ بْنَ ثَابِتٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{179}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Zaid bin Thabit said:"I heard the Messenger of Allah (ﷺ) say: 'Perform Wudu' from that which has been touched by fire}}
\hadithdefcmd{nasai}{180}{أَخْبَرَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ حَدَّثَنَا ابْنُ حَرْبٍ، قَالَ حَدَّثَنَا الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ عَنْ أَبِي سُفْيَانَ بْنِ سَعِيدِ بْنِ الأَخْنَسِ بْنِ شَرِيقٍ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، دَخَلَ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَهِيَ خَالَتُهُ فَسَقَتْهُ سَوِيقًا ثُمَّ قَالَتْ لَهُ تَوَضَّأْ يَا ابْنَ أُخْتِي فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{180}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Sufyan bin Sa'eed bin Al-Akhnas bin Shariq that he entered upon Umm Habibah, the wife of the Prophet (ﷺ), who was his maternal aunt, and she made Sawiq for him, then she said to him:"Perform Wudu' O son of my sister! For the Messenger of Allah (ﷺ) said: 'Perform Wudu' from that which has been touched by fire}}
\hadithdefcmd{nasai}{181}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرِ بْنِ مُضَرَ، قَالَ حَدَّثَنِي بَكْرُ بْنُ مُضَرَ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ مُحَمَّدِ بْنِ مُسْلِمِ بْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سُفْيَانَ بْنِ سَعِيدِ بْنِ الأَخْنَسِ، أَنَّ أُمَّ حَبِيبَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَهُ وَشَرِبَ سَوِيقًا يَا ابْنَ أُخْتِي تَوَضَّأْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{181}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sufyan bin Sa'eed bin Al-Akhnas that Umm Habibah, the wife of the Prophet (ﷺ), said to him, when he had drunk some Sawiq:"O son of my sister, perform Wudu', for I heard the Messenger of Allah (ﷺ) say: 'Perform Wudu' from that which has been touched by fire}}
\hadithdefcmd{nasai}{182}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَكَلَ كَتِفًا فَجَاءَهُ بِلاَلٌ فَخَرَجَ إِلَى الصَّلاَةِ وَلَمْ يَمَسَّ مَاءً ‏.‏\hadithno{182}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Umm Salamah that the Messenger of Allah (ﷺ) at (meat from) a shoulder, then Bilal came to him and he went out to pray, and he did not touch water}}
\hadithdefcmd{nasai}{183}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ مُحَمَّدِ بْنِ يُوسُفَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ دَخَلْتُ عَلَى أُمِّ سَلَمَةَ فَحَدَّثَتْنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصْبِحُ جُنُبًا مِنْ غَيْرِ احْتِلاَمٍ ثُمَّ يَصُومُ ‏.‏ وَحَدَّثَنَا مَعَ هَذَا الْحَدِيثِ أَنَّهَا حَدَّثَتْهُ أَنَّهَا قَرَّبَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم جَنْبًا مَشْوِيًّا فَأَكَلَ مِنْهُ ثُمَّ قَامَ إِلَى الصَّلاَةِ وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{183}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Sulaiman bin Yasar said:"I entered upon Umm Salamah and she told me that the Messenger of Allah (ﷺ) used to wake up in a state of Janabah without having had a wet dream, then he would fast." And she told him that she brought the Prophet (ﷺ) some grilled ribs and he ate from that, then he got up and prayed, and did not perform Wudu}}
\hadithdefcmd{nasai}{184}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ يُوسُفَ، عَنِ ابْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَكَلَ خُبْزًا وَلَحْمًا ثُمَّ قَامَ إِلَى الصَّلاَةِ وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{184}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was reported that Ibn 'Abbas said "I witnessed (that) the Messenger of Allah (ﷺ) ate bread and meat, then stood for prayer and did not perform ablution}}
\hadithdefcmd{nasai}{185}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ كَانَ آخِرَ الأَمْرَيْنِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم تَرْكُ الْوُضُوءِ مِمَّا مَسَّتِ النَّارُ ‏.‏\hadithno{185}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was reported that Jabir (ra) said "That last of the two matters from the Messenger ofAllah (ﷺ) was leaving off ablution from that which had been touched by fire}}
\hadithdefcmd{nasai}{186}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، مَوْلَى بَنِي حَارِثَةَ أَنَّ سُوَيْدَ بْنَ النُّعْمَانِ، أَخْبَرَهُ أَنَّهُ، خَرَجَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ خَيْبَرَ حَتَّى إِذَا كَانُوا بِالصَّهْبَاءِ وَهِيَ مِنْ أَدْنَى خَيْبَرَ صَلَّى الْعَصْرَ ثُمَّ دَعَا بِالأَزْوَادِ فَلَمْ يُؤْتَ إِلاَّ بِالسَّوِيقِ فَأَمَرَ بِهِ فَثُرِّيَ فَأَكَلَ وَأَكَلْنَا ثُمَّ قَامَ إِلَى الْمَغْرِبِ فَتَمَضْمَضَ وَتَمَضْمَضْنَا ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{186}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{I went out in the company of the Prophet (ﷺ) in the year of Khaibar, and when we reached As Sahba' which is the lower part of Khaibar, the Prophet (ﷺ) offered the `Asr prayer and then asked the people to collect the journey food. Nothing was brought but Sawiq which the Prophet (ﷺ) ordered to be moistened with water, and then he ate it and we also ate it. Then he got up to offer the Maghrib prayer. He washed his mouth, and we too washed our mouths, and then he offered the prayer without repeating his abulution}}
\hadithdefcmd{nasai}{187}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم شَرِبَ لَبَنًا ثُمَّ دَعَا بِمَاءٍ فَتَمَضْمَضَ ثُمَّ قَالَ ‏ "‏ إِنَّ لَهُ دَسَمًا ‏"‏ ‏.‏\hadithno{187}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{The Apostle (ﷺ) took milk and then called for water and rinsed (his mouth) and said:It contains greasiness}}
\hadithdefcmd{nasai}{188}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَغَرِّ، - وَهُوَ ابْنُ الصَّبَّاحِ - عَنْ خَلِيفَةَ بْنِ حُصَيْنٍ، عَنْ قَيْسِ بْنِ عَاصِمٍ، أَنَّهُ أَسْلَمَ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَغْتَسِلَ بِمَاءٍ وَسِدْرٍ ‏.‏\hadithno{188}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Qais bin 'Asim that he accepted Islam, and the Prophet commanded him to perform Ghusl with water and lotus leaves}}
\hadithdefcmd{nasai}{189}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّ ثُمَامَةَ بْنَ أُثَالٍ الْحَنَفِيَّ انْطَلَقَ إِلَى نَجْلٍ قَرِيبٍ مِنَ الْمَسْجِدِ فَاغْتَسَلَ ثُمَّ دَخَلَ الْمَسْجِدَ فَقَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ يَا مُحَمَّدُ وَاللَّهِ مَا كَانَ عَلَى الأَرْضِ وَجْهٌ أَبْغَضَ إِلَىَّ مِنْ وَجْهِكَ فَقَدْ أَصْبَحَ وَجْهُكَ أَحَبَّ الْوُجُوهِ كُلِّهَا إِلَىَّ وَإِنَّ خَيْلَكَ أَخَذَتْنِي وَأَنَا أُرِيدُ الْعُمْرَةَ فَمَاذَا تَرَى فَبَشَّرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَرَهُ أَنْ يَعْتَمِرَ ‏.‏ مُخْتَصِرٌ ‏.‏\hadithno{189}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said:"Thumamah bin Uthal Al-Hanafi went to fetch some water that was near the Masjid and performed Ghusl, then he entered the Masjid and said: 'Ashhadu an la ila ha ill-Allah was ashhadu anna Muhammadan 'abduhu wa rasuluh (I bear witness that there is none worthy of worship except Allah and I bear witness that Muhammad is His slave and Messenger), O Muhammad, by Allah! There was no face on the face of the Earth that was more hateful to me than your face, not now your face has become the most beloved of all faces to me. You cavalry captured me and I want to perform 'Umrah. What do you think? The Prophet (ﷺ) gave him glad tidings and told him to perform 'Umarah}}
\hadithdefcmd{nasai}{190}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنِي شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ نَاجِيَةَ بْنَ كَعْبٍ، عَنْ عَلِيٍّ، رضى الله عنه أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ أَبَا طَالِبٍ مَاتَ ‏.‏ فَقَالَ ‏"‏ اذْهَبْ فَوَارِهِ ‏"‏ ‏.‏ قَالَ إِنَّهُ مَاتَ مُشْرِكًا ‏.‏ قَالَ ‏"‏ اذْهَبْ فَوَارِهِ ‏"‏ ‏.‏ فَلَمَّا وَارَيْتُهُ رَجَعْتُ إِلَيْهِ فَقَالَ لِي ‏"‏ اغْتَسِلْ ‏"‏ ‏.‏\hadithno{190}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abbu Ishaq said:"I heard Najiyah bin Ka'b narrating from 'Ali that he came to the Prophet (ﷺ) and said: 'Abu Talib has died.' He said: 'Go and bury him.' He said: 'He died as an idolator.' He said: 'Go and bury him.' ('Ali said:) 'When I had buried him I went back to him and he said to me: 'Perform Ghusl}}
\hadithdefcmd{nasai}{191}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ الْحَسَنَ، يُحَدِّثُ عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَلَسَ بَيْنَ شُعَبِهَا الأَرْبَعِ ثُمَّ اجْتَهَدَ فَقَدْ وَجَبَ الْغُسْلُ ‏"‏ ‏.‏\hadithno{191}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"When (a man) sits between the four parts of his wife's body and exerts himself, then Ghusl becomes obligatory}}
\hadithdefcmd{nasai}{192}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ بْنِ إِسْحَاقَ الْجُوزَجَانِيُّ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا أَشْعَثُ بْنُ عَبْدِ الْمَلِكِ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَعَدَ بَيْنَ شُعَبِهَا الأَرْبَعِ ثُمَّ اجْتَهَدَ فَقَدْ وَجَبَ الْغُسْلُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ أَشْعَثُ عَنِ الْحَسَنِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَقَدْ رَوَى الْحَدِيثَ عَنْ شُعْبَةَ النَّضْرُ بْنُ شُمَيْلٍ وَغَيْرُهُ كَمَا رَوَاهُ خَالِدٌ ‏.‏\hadithno{192}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"When (a man) sits between the four parts of his wife's body and exerts himself, then Ghusl becomes obligatory." Abu 'Abdur-Rahman said: "This is a mistake what is correct is; 'Ash'ath from Al-Hasan, from Abu Hurairah.' An-Nadr bin Shumail, and others, reported the Hadith from Shu'bah just as Khalid reported it}}
\hadithdefcmd{nasai}{193}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، - وَاللَّفْظُ لِقُتَيْبَةَ - قَالَ حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنِ الرُّكَيْنِ بْنِ الرَّبِيعِ، عَنْ حُصَيْنِ بْنِ قَبِيصَةَ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ كُنْتُ رَجُلاً مَذَّاءً فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتَ الْمَذْىَ فَاغْسِلْ ذَكَرَكَ وَتَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ وَإِذَا فَضَخْتَ الْمَاءَ فَاغْتَسِلْ ‏"‏ ‏.‏\hadithno{193}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Ali said:"I was one who had a lot of prostatic discharge, and the Messenger of Allah (ﷺ) said to me: 'If you see Madhi (prostatic fluid) then wash your penis and perform Wudu' like that for Salah, but if you ejaculate semen, then perform Ghusl}}
\hadithdefcmd{nasai}{194}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، عَنْ زَائِدَةَ، ح وَأَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - أَنْبَأَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا زَائِدَةُ، عَنِ الرُّكَيْنِ بْنِ الرَّبِيعِ بْنِ عَمِيلَةَ الْفَزَارِيِّ، عَنْ حُصَيْنِ بْنِ قَبِيصَةَ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ كُنْتُ رَجُلاً مَذَّاءً فَسَأَلْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِذَا رَأَيْتَ الْمَذْىَ فَتَوَضَّأْ وَاغْسِلْ ذَكَرَكَ وَإِذَا رَأَيْتَ فَضْخَ الْمَاءِ فَاغْتَسِلْ ‏"‏ ‏.‏\hadithno{194}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali said:"I was one who had a lot of prostatic discharge, so I asked the Prophet (ﷺ) and he said: 'If you see Madhi (prostatic fluid) then perform Wudu' and wash your penis, but if you see semen ejaculated, then perform Ghusl}}
\hadithdefcmd{nasai}{195}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدَةُ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ أُمَّ سُلَيْمٍ، سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمَرْأَةِ تَرَى فِي مَنَامِهَا مَا يَرَى الرَّجُلُ قَالَ ‏ "‏ إِذَا أَنْزَلَتِ الْمَاءَ فَلْتَغْتَسِلْ ‏"‏ ‏.‏\hadithno{195}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that Umm Sulaim asked the Messenger of Allah (ﷺ) about a woman who sees in her dream something like a man sees. He said:"If water is released then let her perform Ghusl}}
\hadithdefcmd{nasai}{196}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، عَنْ مُحَمَّدِ بْنِ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ أُمَّ سُلَيْمٍ كَلَّمَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَعَائِشَةُ جَالِسَةٌ فَقَالَتْ لَهُ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ أَرَأَيْتَ الْمَرْأَةَ تَرَى فِي النَّوْمِ مَا يَرَى الرَّجُلُ أَفَتَغْتَسِلُ مِنْ ذَلِكَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ لَهَا أُفٍّ لَكِ أَوَتَرَى الْمَرْأَةُ ذَلِكِ فَالْتَفَتَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ تَرِبَتْ يَمِينُكِ فَمِنْ أَيْنَ يَكُونُ الشَّبَهُ ‏"‏ ‏.‏\hadithno{196}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Urwah that 'Aishah told him that Umm Sulaim spoke to the Messenger of Allah (ﷺ) when 'Aishah was sitting there. She said to him:"O Messenger of Allah! Allah is not shy to tell the truth. Inform me: if a women sees in a dream what men see should she perform Ghusl from that?" The Messenger of Allah (ﷺ) said to her: "Yes." 'Aishah said: "I expressed my displeasure and said: 'Does a woman see that?' The Messenger of Allah (ﷺ) turned to me and said: 'May your right hand be covered with dust! How else would (her child) resemble her?}}
\hadithdefcmd{nasai}{197}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ امْرَأَةً، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ هَلْ عَلَى الْمَرْأَةِ غُسْلٌ إِذَا هِيَ احْتَلَمَتْ قَالَ ‏"‏ نَعَمْ إِذَا رَأَتِ الْمَاءَ ‏"‏ ‏.‏ فَضَحِكَتْ أُمُّ سَلَمَةَ فَقَالَتْ أَتَحْتَلِمُ الْمَرْأَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَفِيمَ يُشْبِهُهَا الْوَلَدُ ‏"‏ ‏.‏\hadithno{197}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Salamah that a woman said:"O Messenger of Allah, Allah is not shy to tell the truth. Does a women have to perform Ghusl if she has a wet dream?" He said: "Yes, if she sees water."[1] Umm Salamah laughed and said: "Do women really have wet dreams?" The Messenger of Allah (ﷺ) said: "How else would her child resemble her?" [1] That is, if she has an emission of the fluid of an orgasm}}
\hadithdefcmd{nasai}{198}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنْ شُعْبَةَ، قَالَ سَمِعْتُ عَطَاءً الْخُرَاسَانِيَّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ خَوْلَةَ بِنْتِ حَكِيمٍ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمَرْأَةِ تَحْتَلِمُ فِي مَنَامِهَا فَقَالَ ‏ "‏ إِذَا رَأَتِ الْمَاءَ فَلْتَغْتَسِلْ ‏"‏ ‏.‏\hadithno{198}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Khawlah bin Hakim said:"I asked the Messenger of Allah (ﷺ) about a woman who has a wet dream and he said: 'If she sees water, let her perform Ghusl}}
\hadithdefcmd{nasai}{199}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ عَبْدِ الرَّحْمَنِ بْنِ السَّائِبِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سُعَادٍ، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَاءُ مِنَ الْمَاءِ ‏"‏ ‏.‏\hadithno{199}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Ayyub that the Prophet (ﷺ) said:"Water is for Water." [1] [1] That is, water for peforming Ghusl is obligatory when the ejaculation of water (semen) occurs}}
\hadithdefcmd{nasai}{200}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَاءُ الرَّجُلِ غَلِيظٌ أَبْيَضُ وَمَاءُ الْمَرْأَةِ رَقِيقٌ أَصْفَرُ فَأَيُّهُمَا سَبَقَ كَانَ الشَّبَهُ ‏"‏ ‏.‏\hadithno{200}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) said: 'The man's water is thick and white, and the woman's water is thin and yellow. Whichever of them comes first, the child will resemble (that parent)}}
\hadithdefcmd{nasai}{201}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ الْعَدَوِيُّ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنِي هِشَامُ بْنُ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، مِنْ بَنِي أَسَدِ قُرَيْشٍ أَنَّهَا أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَتْ أَنَّهَا تُسْتَحَاضُ فَزَعَمَتْ أَنَّهُ قَالَ لَهَا ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ ثُمَّ صَلِّي ‏"‏ ‏.‏\hadithno{201}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Fatimah bint Qais from Banu Asad Quraish that she came to the Prophet (ﷺ) and mentioned that she suffered from Istihadah (non-menstrual vaginal bleeding). She said that he said to her:"That is (bleeding from) a vein, so when the time of menstruation comes, stop praying, and when it goes, then wash the blood from yourself then pray}}
\hadithdefcmd{nasai}{202}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا سَهْلُ بْنُ هَاشِمٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَقْبَلَتِ الْحَيْضَةُ فَاتْرُكِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْتَسِلِي ‏"‏ ‏.‏\hadithno{202}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Prophet (ﷺ) said:"When the time of menstruation comes, stop praying, and when it goes, perform Ghusl}}
\hadithdefcmd{nasai}{203}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُرْوَةَ، وَعَمْرَةَ، عَنْ عَائِشَةَ، قَالَتِ اسْتُحِيضَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ سَبْعَ سِنِينَ فَاشْتَكَتْ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذِهِ لَيْسَتْ بِالْحَيْضَةِ وَلَكِنْ هَذَا عِرْقٌ فَاغْتَسِلِي ثُمَّ صَلِّي ‏"‏ ‏.‏\hadithno{203}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Umm Habibah bint Jahsh suffered Istihadah (non-menstrual vaginal bleeding) for seven years. She complained about that to the Messenger of Allah (ﷺ) and the Messenger of Allah (ﷺ) said: 'That is not menstruation; rather that is (bleeding from) a vein, so perform Ghusl then pray}}
\hadithdefcmd{nasai}{204}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، قَالَ أَخْبَرَنِي النُّعْمَانُ، وَالأَوْزَاعِيُّ، وَأَبُو مُعَيْدٍ - وَهُوَ حَفْصُ بْنُ غَيْلاَنَ - عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، وَعَمْرَةُ بِنْتُ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتِ اسْتُحِيضَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ امْرَأَةُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَهِيَ أُخْتُ زَيْنَبَ بِنْتِ جَحْشٍ فَاسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذِهِ لَيْسَتْ بِالْحَيْضَةِ وَلَكِنْ هَذَا عِرْقٌ فَإِذَا أَدْبَرَتِ الْحَيْضَةُ فَاغْتَسِلِي وَصَلِّي وَإِذَا أَقْبَلَتْ فَاتْرُكِي لَهَا الصَّلاَةَ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ وَتُصَلِّي وَكَانَتْ تَغْتَسِلُ أَحْيَانًا فِي مِرْكَنٍ فِي حُجْرَةِ أُخْتِهَا زَيْنَبَ وَهِيَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى أَنَّ حُمْرَةَ الدَّمِ لَتَعْلُو الْمَاءَ وَتَخْرُجُ فَتُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَا يَمْنَعُهَا ذَلِكَ مِنَ الصَّلاَةِ ‏.‏\hadithno{204}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"Umm Habibah bint Jahsh- the wife of 'Abdur-Rahman bin 'Awf and the sister of Zainab bint Jahsh - suffered Istihadah (non-mentrual vaginal bleeding)." She said: "She consulted the Messenger of Allah (ﷺ) and the Messenger of Allah (ﷺ) said to her: 'That is not menstruation, rather that is a vein. When you period goes, perform Ghusl and pray, and when it comes, stop praying (for that period).'" 'Aishah said: "She used to perform Ghusl for every prayer and pray. Sometimes she would perform Ghusl in a washtub in the room of her sister Zainab when she was with the Messenger of Allah (ﷺ) and the water would turn red with blood, then she would go out and pray with the Messenger of Allah (ﷺ). That did not stop her from praying}}
\hadithdefcmd{nasai}{205}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ، - خَتَنَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَتَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ - اسْتُحِيضَتْ سَبْعَ سِنِينَ اسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذِهِ لَيْسَتْ بِالْحَيْضَةِ وَلَكِنْ هَذَا عِرْقٌ فَاغْتَسِلِي وَصَلِّي ‏"‏ ‏.‏\hadithno{205}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah (may Allah be pleased with her) that Umm Habibah, an in-law of the Messenger of Allah (ﷺ), who was married to 'Abdur-Rahman bin 'Awf, suffered Istihadah (non-menstrual vaginal bleeding) for seven years. She consulted the Prophet (ﷺ) about that and the Messenger of Allah (ﷺ) said:'That is not menstruation, rather that is a vein, so perform Ghusl and pray}}
\hadithdefcmd{nasai}{206}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اسْتَفْتَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُسْتَحَاضُ ‏.‏ فَقَالَ ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ فَاغْتَسِلِي وَصَلِّي ‏"‏ ‏.‏ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ ‏.‏\hadithno{206}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"Umm Habibah bint Jahsh consulted the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, I suffer from Istihadah (non-menstrual vaginal bleeding).' He said: 'That is a vein, so perform Ghusl and pray.' And she used to perform Ghusl for every prayer}}
\hadithdefcmd{nasai}{207}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ، سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الدَّمِ - قَالَتْ عَائِشَةُ رضى الله عنها رَأَيْتُ مِرْكَنَهَا مَلآنَ دَمًا - فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ امْكُثِي قَدْرَ مَا كَانَتْ تَحْبِسُكِ حَيْضَتُكِ ثُمَّ اغْتَسِلِي ‏"‏ ‏.‏ أَخْبَرَنَا قُتَيْبَةُ، مَرَّةً أُخْرَى وَلَمْ يَذْكُرْ جَعْفَرًا ‏.‏\hadithno{207}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that Umm Habibah asked the Messenger of Allah (ﷺ) about bleeding. 'Aishah said:"I saw her wash tub filled with blood. The Messenger of Allah (ﷺ) said to her: 'Stop (praying) for as long as your period prevents you, then perform Ghusl.'" (Another chain)}}
\hadithdefcmd{nasai}{208}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، تَعْنِي أَنَّ امْرَأَةً، كَانَتْ تُهَرَاقُ الدَّمَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَفْتَتْ لَهَا أُمُّ سَلَمَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لِتَنْظُرْ عَدَدَ اللَّيَالِي وَالأَيَّامِ الَّتِي كَانَتْ تَحِيضُ مِنَ الشَّهْرِ قَبْلَ أَنْ يُصِيبَهَا الَّذِي أَصَابَهَا فَلْتَتْرُكِ الصَّلاَةَ قَدْرَ ذَلِكَ مِنَ الشَّهْرِ فَإِذَا خَلَّفَتْ ذَلِكَ فَلْتَغْتَسِلْ ثُمَّ لْتَسْتَثْفِرْ ثُمَّ لْتُصَلِّي ‏"‏ ‏.‏\hadithno{208}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that a woman suffered constant bleeding at the time of the Messenger of Allah (ﷺ), so Umm Salamah consulted the Prophet (ﷺ) for her. He said:"Let her count the number of nights and says that she used to menstruate each month before this happened to her, and let her stop praying for that amount of time each month. Then when that is over let her perform Ghusl, then let her use a pad, and pray}}
\hadithdefcmd{nasai}{209}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ الَّتِي، كَانَتْ تَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَأَنَّهَا اسْتُحِيضَتْ لاَ تَطْهُرْ فَذُكِرَ شَأْنُهَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّهَا لَيْسَتْ بِالْحَيْضَةِ وَلَكِنَّهَا رَكْضَةٌ مِنَ الرَّحِمِ فَلْتَنْظُرْ قَدْرَ قُرْئِهَا الَّتِي كَانَتْ تَحِيضُ لَهَا فَلْتَتْرُكِ الصَّلاَةَ ثُمَّ تَنْظُرْ مَا بَعْدَ ذَلِكَ فَلْتَغْتَسِلْ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏\hadithno{209}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that Umm Habibah bint Jahsh who was married to 'Abdur-Rahman bin 'Awf suffered from Istihadah (non-mentrual vaginal bleeding) and did not become pure. Her situation was mentioned to the Messenger of Allah (ﷺ) and he said:'That is not menstruation, rather it is a kick [1] in the womb, so let her work out the length of the menses that she used to have, and stop praying (for that period of tie), then after that period of time), then after that let her perform Ghusl for every prayer.'" [1] A kick in the womb: in other narrations means "A kick from Shaitan,", meaning that the Shaitan uses it to confuse her about her religious commitment}}
\hadithdefcmd{nasai}{210}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ، كَانَتْ تُسْتَحَاضُ سَبْعَ سِنِينَ فَسَأَلَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَيْسَتْ بِالْحَيْضَةِ إِنَّمَا هُوَ عِرْقٌ ‏"‏ ‏.‏ فَأَمَرَهَا أَنْ تَتْرُكَ الصَّلاَةَ قَدْرَ أَقْرَائِهَا وَحَيْضَتِهَا وَتَغْتَسِلَ وَتُصَلِّيَ فَكَانَتْ تَغْتَسِلُ عِنْدَ كُلِّ صَلاَةٍ ‏.‏\hadithno{210}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that Umm Habibah bint Jahsh used to suffer from Istihadah (non-menstrual vaginal bleeding) for seven years. She asked the Prophet (ﷺ) and he said:"That is not menstruation, rather it is a vein. Tell her not to pray for the amount of time that her period used to last, then let her perform Ghusl and pray.' She used to perform Ghusl for every prayer}}
\hadithdefcmd{nasai}{211}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنِ الْمُنْذِرِ بْنِ الْمُغِيرَةِ، عَنْ عُرْوَةَ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، حَدَّثَتْ أَنَّهَا، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَشَكَتْ إِلَيْهِ الدَّمَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ فَانْظُرِي إِذَا أَتَاكِ قُرْؤُكِ فَلاَ تُصَلِّي فَإِذَا مَرَّ قُرْؤُكِ فَتَطَهَّرِي ثُمَّ صَلِّي مَا بَيْنَ الْقُرْءِ إِلَى الْقُرْءِ ‏"‏ هَذَا الدَّلِيلُ عَلَى أَنَّ الأَقْرَاءَ حِيَضٌ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَقَدْ رَوَى هَذَا الْحَدِيثَ هِشَامُ بْنُ عُرْوَةَ عَنْ عُرْوَةَ وَلَمْ يَذْكُرْ فِيهِ مَا ذَكَرَ الْمُنْذِرُ ‏.‏\hadithno{211}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Urwah that Fatimah bint Abi Hubaish narrated that she came to the Messenger of Allah (ﷺ) and complained to him about bleeding. The Messenger of Allah (ﷺ) said to her:"That is a vein, so when your period comes, do not pray, and when your period is over, purify yourself and pray in between one period and the next." This is evidence that Al-Aqra' is menstruation. Abu 'Abdur-Rahman said: Hisham bin 'Urwah reported this Hadith from 'Urwah, and he did not mention what Al-Mundhir mentioned in it}}
\hadithdefcmd{nasai}{212}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنَا عَبْدَةُ، وَوَكِيعٌ، وَأَبُو مُعَاوِيَةَ قَالُوا حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي امْرَأَةٌ أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ ‏ "‏ لاَ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏\hadithno{212}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:Fatimah bint Abi Hubaish came to the Messenger of Allah (ﷺ) and said: "I am a woman who suffers from Istihadah (non-menstrual vaginal bleeding) and I never become pure. Should I stop praying?" He said: "No, that is a vein, it is not menstruation. When you period comes, stop praying, and when it goes, wash the blood from yourself and pray}}
\hadithdefcmd{nasai}{213}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ امْرَأَةً، مُسْتَحَاضَةً عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قِيلَ لَهَا إِنَّهُ عِرْقٌ عَانِدٌ فَأُمِرَتْ أَنْ تُؤَخِّرَ الظُّهْرَ وَتُعَجِّلَ الْعَصْرَ وَتَغْتَسِلَ لَهُمَا غُسْلاً وَاحِدًا وَتُؤَخِّرَ الْمَغْرِبَ وَتُعَجِّلَ الْعِشَاءَ وَتَغْتَسِلَ لَهُمَا غُسْلاً وَاحِدًا وَتَغْتَسِلَ لِصَلاَةِ الصُّبْحِ غُسْلاً وَاحِدًا ‏.‏\hadithno{213}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that a woman who suffered from Istihadah during the time of the Messenger of Allah (ﷺ) was told that it was a stubborn vein (i.e., one that would not stop bleeding). She was told to delay Zuhr and bring 'Asr forward, and to perform one Ghusl for both, and to delay Maghrib and bring 'Isha' forward, and to perform one Ghusl for both, and to perform one Ghusl for Subh}}
\hadithdefcmd{nasai}{214}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، فِي حَدِيثِ أَسْمَاءَ بِنْتِ عُمَيْسٍ حِينَ نُفِسَتْ بِذِي الْحُلَيْفَةِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأَبِي بَكْرٍ ‏ "‏ مُرْهَا أَنْ تَغْتَسِلَ وَتُهِلَّ ‏"‏ ‏.‏\hadithno{214}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah, in the Hadith of Asma' bint 'Umair, when she gave birth in Dhul-Hulaifah, that the Messenger of Allah (ﷺ) said to Abu Bakr:"Tell her to perform Ghusl and enter Ihram}}
\hadithdefcmd{nasai}{215}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ عَمْرِو بْنِ عَلْقَمَةَ بْنِ وَقَّاصٍ - عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ فَاطِمَةَ بِنْتِ أَبِي حُبَيْشٍ، أَنَّهَا كَانَتْ تُسْتَحَاضُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ دَمُ الْحَيْضِ - فَإِنَّهُ دَمٌ أَسْوَدُ يُعْرَفُ - فَأَمْسِكِي عَنِ الصَّلاَةِ فَإِذَا كَانَ الآخَرُ فَتَوَضَّئِي فَإِنَّمَا هُوَ عِرْقٌ ‏"‏ ‏.‏\hadithno{215}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Fatimah bint Abi Hubaish that she suffered from Istihadah and the Messenger of Allah (ﷺ) said to her:"If it is menstrual blood then it is blood that is black and recognizable, so stop praying, and if it is other than that then perform Wudu', for it is just a vein}}
\hadithdefcmd{nasai}{216}{قَالَ أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، هَذَا مِنْ كِتَابِهِ أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، مِنْ حِفْظِهِ قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، كَانَتْ تُسْتَحَاضُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ دَمَ الْحَيْضِ دَمٌ أَسْوَدُ يُعْرَفُ فَإِذَا كَانَ ذَلِكِ فَأَمْسِكِي عَنِ الصَّلاَةِ وَإِذَا كَانَ الآخَرُ فَتَوَضَّئِي وَصَلِّي ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ قَدْ رَوَى هَذَا الْحَدِيثَ غَيْرُ وَاحِدٍ لَمْ يَذْكُرْ أَحَدٌ مِنْهُمْ مَا ذَكَرَهُ ابْنُ أَبِي عَدِيٍّ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{216}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that Fatimah bint Abi Hubaish suffered from Istihadah (non-menstrual vaginal bleeding). The Messenger of Allah (ﷺ) said to her:"Menstrual blood is blood that is black and recognizable, so if it is like that, then stop praying, and if it is otherwise, then perform Wudu' and pray." Abu 'Abdur-Rahman said: Others reported this Hadith, and none of them mentioned what Ibn Abi 'Adi mentioned. And Allah Most High, knows best}}
\hadithdefcmd{nasai}{217}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتِ اسْتُحِيضَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ فَسَأَلَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ أَثَرَ الدَّمِ وَتَوَضَّئِي فَإِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحَيْضَةِ ‏"‏ ‏.‏ قِيلَ لَهُ فَالْغُسْلُ قَالَ ‏"‏ ذَلِكَ لاَ يَشُكُّ فِيهِ أَحَدٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ أَعْلَمُ أَحَدًا ذَكَرَ فِي هَذَا الْحَدِيثِ ‏"‏ وَتَوَضَّئِي ‏"‏ ‏.‏ غَيْرَ حَمَّادِ بْنِ زَيْدٍ وَقَدْ رَوَى غَيْرُ وَاحِدٍ عَنْ هِشَامٍ وَلَمْ يَذْكُرْ فِيهِ ‏"‏ وَتَوَضَّئِي ‏"‏ ‏.‏\hadithno{217}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Fatimah bint Abi Hubaish suffered from Istihadah and she asked the Prophet (ﷺ): 'O Messenger of Allah, I suffer from Istihadah and I do not become pure; should I stop praying?' The Messenger of Allah (ﷺ) said: 'That is a vein and is not menstruation. When your period comes, stop praying, and when it goes wash the traces of blood from yourself and perform Wudu'. That is a vein and is not menstruation.'" It was said to him: "What about Ghusl?' He (ﷺ) said: "no one doubts that." Abu 'Abdur-Rahman said: "I do not know anyone who mentioned 'and perform Wudu' in this Hadith except Hammad bin Zaid, for some others have reported it from Hisham, and they did not mention 'and perform Wudu' in it}}
\hadithdefcmd{nasai}{218}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ يَا رَسُولَ اللَّهِ لاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ فَإِذَا ذَهَبَ قَدْرُهَا فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏\hadithno{218}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"Fatimah bint Abi Hubaish said to the Messenger of Allah (ﷺ): 'O Messenger of Allah (ﷺ), I do not become pure. Should I stop praying? The Messenger of Allah (ﷺ) said: 'That is a vein and is not menstruation. When your period comes, stop praying, and when the same amount of time as your regular period has passed, then wash the blood from yourself and pray}}
\hadithdefcmd{nasai}{219}{أَخْبَرَنَا أَبُو الأَشْعَثِ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ سَمِعْتُ هِشَامَ بْنَ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ بِنْتَ أَبِي حُبَيْشٍ، قَالَتْ يَا رَسُولَ اللَّهِ إِنِّي لاَ أَطْهُرُ أَفَأَتْرُكُ الصَّلاَةَ قَالَ ‏"‏ لاَ إِنَّمَا هُوَ عِرْقٌ ‏"‏ ‏.‏ قَالَ خَالِدٌ فِيمَا قَرَأْتُ عَلَيْهِ ‏"‏ وَلَيْسَتْ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏\hadithno{219}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the daughter of Abu Hubaish said:"O Messenger of Allah, I do not become pure, so should I stop praying?" He said: "No, that is a vein." Khalid said, in what I read from him, [1] "And it is not menstruation, so when your period comes, stop praying, and when it goes, wash the blood from yourself and pray." [1] Meaning, before Hisham, from whom he narrates it}}
\hadithdefcmd{nasai}{220}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرٍ، أَنَّ أَبَا السَّائِبِ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَغْتَسِلْ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ وَهُوَ جُنُبٌ ‏"‏ ‏.‏\hadithno{220}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'None of you should perform Ghusl in standing water when he is Junub}}
\hadithdefcmd{nasai}{221}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنْ مُوسَى بْنِ أَبِي عُثْمَانَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الرَّاكِدِ ثُمَّ يَغْتَسِلُ مِنْهُ ‏"‏ ‏.‏\hadithno{221}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"None of you should urinate into still water and then perform Ghusl from it}}
\hadithdefcmd{nasai}{222}{أَخْبَرَنَا عَمْرُو بْنُ هِشَامٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الْعَلاَءِ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ غُضَيْفِ بْنِ الْحَارِثِ، أَنَّهُ سَأَلَ عَائِشَةَ - رضى الله عنها - أَىُّ اللَّيْلِ كَانَ يَغْتَسِلُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ رُبَّمَا اغْتَسَلَ أَوَّلَ اللَّيْلِ وَرُبَّمَا اغْتَسَلَ آخِرَهُ ‏.‏ قُلْتُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏.‏\hadithno{222}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ghudaif bin Al-Harith that he asked 'Aishah in which part of the night would the Messenger of Allah (ﷺ) perform Ghusl? She said:"Sometimes he performed Ghusl at the beginning of the night and sometimes he performed Ghusl at the end." I said: "Praise be to Allah Who has made the matter flexible}}
\hadithdefcmd{nasai}{223}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ بُرْدٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ غُضَيْفِ بْنِ الْحَارِثِ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ رضى الله عنها فَسَأَلْتُهَا قُلْتُ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ مِنْ أَوَّلِ اللَّيْلِ أَوْ مِنْ آخِرِهِ قَالَتْ كُلَّ ذَلِكَ رُبَّمَا اغْتَسَلَ مِنْ أَوَّلِهِ وَرُبَّمَا اغْتَسَلَ مِنْ آخِرِهِ ‏.‏ قُلْتُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏.‏\hadithno{223}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ghudaif bin Al-Harith said:"I entered upon 'Aishah and asked her: 'Did the Messenger of Allah (ﷺ) perform Ghusl at the beginning of the night or at the end?' She said: 'Both. Sometimes he performed Ghusl at the beginning and sometimes at the end.' I said: 'Praise be to Allah who has made the matter flexible}}
\hadithdefcmd{nasai}{224}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ الْوَلِيدِ، قَالَ حَدَّثَنِي مُحِلُّ بْنُ خَلِيفَةَ، قَالَ حَدَّثَنِي أَبُو السَّمْحِ، قَالَ كُنْتُ أَخْدُمُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَانَ إِذَا أَرَادَ أَنْ يَغْتَسِلَ قَالَ ‏ "‏ وَلِّنِي قَفَاكَ ‏"‏ ‏.‏ فَأُوَلِّيهِ قَفَاىَ فَأَسْتُرُهُ بِهِ ‏.‏\hadithno{224}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu As-Samh said:"I used to serve the Messenger of Allah (ﷺ) and when he wanted to perform Ghusl he said: 'Turn your back.' So I turned my back to him and concealed him}}
\hadithdefcmd{nasai}{225}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنْ سَالِمٍ، عَنْ أَبِي مُرَّةَ، مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ عَنْ أُمِّ هَانِئٍ، رضى الله عنها أَنَّهَا ذَهَبَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم يَوْمَ الْفَتْحِ فَوَجَدَتْهُ يَغْتَسِلُ وَفَاطِمَةُ تَسْتُرُهُ بِثَوْبٍ فَسَلَّمَتْ فَقَالَ ‏ "‏ مَنْ هَذَا ‏"‏ ‏.‏ قُلْتُ أُمُّ هَانِئٍ ‏.‏ فَلَمَّا فَرَغَ مِنْ غُسْلِهِ قَامَ فَصَلَّى ثَمَانِيَ رَكَعَاتٍ فِي ثَوْبٍ مُلْتَحِفًا بِهِ ‏.‏\hadithno{225}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Hani' that she went to the Prophet (ﷺ) on the day of the Conquest (of Makkah) and found him performing Ghusl while Fatimah was concealing him with a garment. She gave him Salams and he said:"Who is this?" She said: "Umm Hani'." When he had finished his Ghusl he stood up and prayed eight Rak'ahs wrapped in a garment}}
\hadithdefcmd{nasai}{226}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ مُوسَى الْجُهَنِيِّ، قَالَ أُتِيَ مُجَاهِدٌ بِقَدَحٍ حَزَرْتُهُ ثَمَانِيَةَ أَرْطَالٍ فَقَالَ حَدَّثَتْنِي عَائِشَةُ رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْتَسِلُ بِمِثْلِ هَذَا ‏.‏\hadithno{226}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Musa Al-Juhani said:"A vessel was brought to Mujahid, which I estimated to be eight Ratls, and he said: 'Aishah told me that the Messenger of Allah (ﷺ) used to perform Ghusl using such a vessel}}
\hadithdefcmd{nasai}{227}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، سَمِعْتُ أَبَا سَلَمَةَ، يَقُولُ دَخَلْتُ عَلَى عَائِشَةَ - رضى الله عنها - وَأَخُوهَا مِنَ الرَّضَاعَةِ فَسَأَلَهَا عَنْ غُسْلِ النَّبِيِّ صلى الله عليه وسلم فَدَعَتْ بِإِنَاءٍ فِيهِ مَاءٌ قَدْرَ صَاعٍ وَسَتَرَتْ سِتْرًا فَاغْتَسَلَتْ فَأَفْرَغَتْ عَلَى رَأْسِهَا ثَلاَثًا ‏.‏\hadithno{227}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Bakr bin Hafs:"I heard Abu Salamah say: 'I entered upon 'Aishah and her foster-brother was with her. He asked her about the Ghusl of the Prophet (ﷺ). She called for a vessel in which was a Sa' of water, then she concealed herself and performed Ghusl and poured water over her head three times}}
\hadithdefcmd{nasai}{228}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ فِي الْقَدَحِ وَهُوَ الْفَرَقُ وَكُنْتُ أَغْتَسِلُ أَنَا وَهُوَ فِي إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{228}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) used to perform Ghusl from a vessel which was the size of a Faraq [1] and he and I used to perform Ghusl using a single vessel." [1] Sixteen Ratls}}
\hadithdefcmd{nasai}{229}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ جَبْرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ بِمَكُّوكٍ وَيَغْتَسِلُ بِخَمْسَةِ مَكَاكِيَّ ‏.‏\hadithno{229}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin Jabr said:"I heard Anas bin Malik say: 'The Messenger of Allah (ﷺ) used to perform Wudu' with a Makkuk and Ghusl with five Makkuks}}
\hadithdefcmd{nasai}{230}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي جَعْفَرٍ، قَالَ تَمَارَيْنَا فِي الْغُسْلِ عِنْدَ جَابِرِ بْنِ عَبْدِ اللَّهِ فَقَالَ جَابِرٌ يَكْفِي مِنَ الْغُسْلِ مِنَ الْجَنَابَةِ صَاعٌ مِنْ مَاءٍ ‏.‏ قُلْنَا مَا يَكْفِي صَاعٌ وَلاَ صَاعَانِ ‏.‏ قَالَ جَابِرٌ قَدْ كَانَ يَكْفِي مَنْ كَانَ خَيْرًا مِنْكُمْ وَأَكْثَرَ شَعْرًا ‏.‏\hadithno{230}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Ja'far said:"We argued about Ghusl in the presence of jabir in 'Abdullah, and Jabir said: 'One Sa' of water is sufficient for ghusl from Janabah.' We said: 'One Sa' is not enough and neither is two.' Jabir said: 'It was sufficient for one who was better than you and had more hair}}
\hadithdefcmd{nasai}{231}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، ح وَأَنْبَأَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، وَابْنُ، جُرَيْجٍ عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ وَهُوَ قَدْرُ الْفَرَقِ ‏.‏\hadithno{231}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"I used to perform Ghusl with the Messenger of Allah (ﷺ) from one vessel, which was the size of a Faraq}}
\hadithdefcmd{nasai}{232}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، ح وَأَنْبَأَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْتَسِلُ وَأَنَا مِنْ إِنَاءٍ وَاحِدٍ نَغْتَرِفُ مِنْهُ جَمِيعًا ‏.‏\hadithno{232}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) used to perform Ghusl; he and I from a single vessel, both of us scooping water from it}}
\hadithdefcmd{nasai}{233}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، قَالَ سَمِعْتُ الْقَاسِمَ، يُحَدِّثُ عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ مِنَ الْجَنَابَةِ ‏.‏\hadithno{233}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdur-Rahman bin Al-Qasim said:"I heard Al-Qasim narrating that 'Aishah said: 'I used to perform Ghusl, the Messenger of Allah (ﷺ) and I from a single vessel, from Janabah}}
\hadithdefcmd{nasai}{234}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ لَقَدْ رَأَيْتُنِي أُنَازِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم الإِنَاءَ أَغْتَسِلُ أَنَا وَهُوَ مِنْهُ ‏.‏\hadithno{234}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"I remember competing over the vessel with the Messenger of Allah (ﷺ), when he and I were using it to perform Ghusl}}
\hadithdefcmd{nasai}{235}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{235}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) and I used to perform Ghusl together using one vessel}}
\hadithdefcmd{nasai}{236}{أَخْبَرَنَا يَحْيَى بْنُ مُوسَى، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَخْبَرَتْنِي خَالَتِي، مَيْمُونَةُ أَنَّهَا كَانَتْ تَغْتَسِلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{236}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"My maternal aunt Maimunah told me that she and the Messenger of Allah (ﷺ) used to perform Ghusl from one vessel}}
\hadithdefcmd{nasai}{237}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ سَعِيدِ بْنِ يَزِيدَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ هُرْمُزَ الأَعْرَجَ، يَقُولُ حَدَّثَنِي نَاعِمٌ، مَوْلَى أُمِّ سَلَمَةَ رضى الله عنها أَنَّ أُمَّ سَلَمَةَ سُئِلَتْ أَتَغْتَسِلُ الْمَرْأَةُ مَعَ الرَّجُلِ قَالَتْ نَعَمْ إِذَا كَانَتْ كَيِّسَةً رَأَيْتُنِي وَرَسُولَ اللَّهِ صلى الله عليه وسلم نَغْتَسِلُ مِنْ مِرْكَنٍ وَاحِدٍ نُفِيضُ عَلَى أَيْدِينَا حَتَّى نُنْقِيَهُمَا ثُمَّ نُفِيضَ عَلَيْهَا الْمَاءَ ‏.‏ قَالَ الأَعْرَجُ لاَ تَذْكُرُ فَرْجًا وَلاَ تَبَالَهُ ‏.‏\hadithno{237}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdur-Rahman bin Hurmuz Al-A'raj said:"Na'im the freed slave of Umm Salamah narrated to me that Umm Salamah was asked: 'Can a woman perform Ghusl with a man?' She said: 'Yes, if she is well-mannered.[1] I remember the Messenger of Allah (ﷺ) and I performing Ghusl from a single wash tub. We would pour water on our hands until they were clean then pour water over them.'" Al-A'raj said: "Not mentioning the private area not paying attention to it." [1] Kaiysah:" Well-mannered when using the water with the man" (An-Nihayah) And the comments by Al-A'raj after the narration refer to its meaning}}
\hadithdefcmd{nasai}{238}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ دَاوُدَ الأَوْدِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ لَقِيتُ رَجُلاً صَحِبَ النَّبِيَّ صلى الله عليه وسلم كَمَا صَحِبَهُ أَبُو هُرَيْرَةَ - رضى الله عنه - أَرْبَعَ سِنِينَ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَمْتَشِطَ أَحَدُنَا كُلَّ يَوْمٍ أَوْ يَبُولَ فِي مُغْتَسَلِهِ أَوْ يَغْتَسِلَ الرَّجُلُ بِفَضْلِ الْمَرْأَةِ وَالْمَرْأَةُ بِفَضْلِ الرَّجُلِ وَلْيَغْتَرِفَا جَمِيعًا ‏.‏\hadithno{238}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Humaid bin 'Abdur-Rahman said:"I met a man who accompanied the Prophet (ﷺ) as Abu Hurairah (may Allah be pleased with him), accompanied him for four years. He said: 'The Messenger of Allah (ﷺ) forbade any one of us to comb his hair each day,[1] or to urinate in the place where he performs Ghusl, or for a man to perform Ghusl using the leftover water of a women, or a woman to perform Ghusl using the leftover water of a man - they should scoop it out together.'" [1] It is said this is to prevent him from making his physical appearance his main aim}}
\hadithdefcmd{nasai}{239}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، ح وَأَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَاصِمٍ، عَنْ مُعَاذَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ يُبَادِرُنِي وَأُبَادِرُهُ حَتَّى يَقُولَ ‏ "‏ دَعِي لِي ‏"‏ ‏.‏ وَأَقُولُ أَنَا دَعْ لِي ‏.‏ قَالَ سُوَيْدٌ يُبَادِرُنِي وَأُبَادِرُهُ فَأَقُولُ دَعْ لِي دَعْ لِي ‏.‏\hadithno{239}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I used to perform Ghusl - the Messenger of Allah (ﷺ) and I - from one vessel. He would compete with me and I would with him until he would say: 'Leave me some' and I would say: 'Leave me some}}
\hadithdefcmd{nasai}{240}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ أُمِّ هَانِئٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اغْتَسَلَ هُوَ وَمَيْمُونَةُ مِنْ إِنَاءٍ وَاحِدٍ فِي قَصْعَةٍ فِيهَا أَثَرُ الْعَجِينِ ‏.‏\hadithno{240}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Hani' that the Messenger of Allah (ﷺ) performed Ghusl, he and Maimunah from a single vessel, a bowl in which there were traces of dough}}
\hadithdefcmd{nasai}{241}{أَخْبَرَنَا سُلَيْمَانُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، عَنْ أُمِّ سَلَمَةَ، - رضى الله عنها - زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أَشُدُّ ضَفْرَ رَأْسِي أَفَأَنْقُضُهَا عِنْدَ غَسْلِهَا مِنَ الْجَنَابَةِ قَالَ ‏ "‏ إِنَّمَا يَكْفِيكِ أَنْ تَحْثِي عَلَى رَأْسِكِ ثَلاَثَ حَثَيَاتٍ مِنْ مَاءٍ ثُمَّ تُفِيضِينَ عَلَى جَسَدِكِ ‏"‏ ‏.‏\hadithno{241}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Umm Salamah, the wife of the Prophet (ﷺ), said:"I said: 'O Messenger of Allah, I am a woman with tightly braided hair; should I undo it when performing Ghusl from Janabah?' He said: 'No it is sufficient for you to pour three handfuls of water over your body}}
\hadithdefcmd{nasai}{242}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا أَشْهَبُ، عَنْ مَالِكٍ، أَنَّ ابْنَ شِهَابٍ، وَهِشَامَ بْنَ عُرْوَةَ، حَدَّثَاهُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ فَأَهْلَلْتُ بِالْعُمْرَةِ فَقَدِمْتُ مَكَّةَ وَأَنَا حَائِضٌ فَلَمْ أَطُفْ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَشَكَوْتُ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْقُضِي رَأْسَكِ وَامْتَشِطِي وَأَهِلِّي بِالْحَجِّ وَدَعِي الْعُمْرَةَ ‏"‏ ‏.‏ فَفَعَلْتُ فَلَمَّا قَضَيْنَا الْحَجَّ أَرْسَلَنِي مَعَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ إِلَى التَّنْعِيمِ فَاعْتَمَرْتُ فَقَالَ ‏"‏ هَذِهِ مَكَانَ عُمْرَتِكِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ مَالِكٍ عَنْ هِشَامِ بْنِ عُرْوَةَ لَمْ يَرْوِهِ أَحَدٌ إِلاَّ أَشْهَبُ ‏.‏\hadithno{242}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"We went out with the Messenger of Allah (ﷺ) in the year of the Farewell Pilgrimage. I (said the Talbiyah) for 'Umrah and I arrived in Makkah while I was menstruating, so I did not perform Tawaf around the House nor between As-Safa and Al-Marwah. I complained about that to the Messenger of Allah (ﷺ), and he said: 'Undo your braids and comb your hair, and enter (begin the Talbiyah) for Hajj, and leave the 'Umrah.' So I did that, and then when we had completed Hajj, he sent me with 'Abdur-Rahman bin Abi Bakr to At-Tan'im, and I performed 'Umrah. He said: 'This is in place of your 'Umrah.'" Abu 'Abdur-Rahman said: This Hadith is Gharib as a narration of Malik from Hisham, from 'Urwah. No one except Asshab reported it}}
\hadithdefcmd{nasai}{243}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، قَالَ حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَتْنِي عَائِشَةُ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ وُضِعَ لَهُ الإِنَاءُ فَيَصُبُّ عَلَى يَدَيْهِ قَبْلَ أَنْ يُدْخِلَهُمَا الإِنَاءَ حَتَّى إِذَا غَسَلَ يَدَيْهِ أَدْخَلَ يَدَهُ الْيُمْنَى فِي الإِنَاءِ ثُمَّ صَبَّ بِالْيُمْنَى وَغَسَلَ فَرْجَهُ بِالْيُسْرَى حَتَّى إِذَا فَرَغَ صَبَّ بِالْيُمْنَى عَلَى الْيُسْرَى فَغَسَلَهُمَا ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ ثَلاَثًا ثُمَّ يَصُبُّ عَلَى رَأْسِهِ مِلْءَ كَفَّيْهِ ثَلاَثَ مَرَّاتٍ ثُمَّ يُفِيضُ عَلَى جَسَدِهِ ‏.‏\hadithno{243}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Aishah narrated that when the Messenger of Allah (ﷺ) performed Ghusl from Janabah, the vessel (of water) would be placed before him, and he would pour water over his hands before putting then into the vessel. When he had washed his hands, he would put his right hand in the vessel then pour water with his right hand and wash his private parts with his left hand. When he had finished, he would pour water with his right hand over his left hand and wash them both. Then he would rinse his mouth and nose three times, then he would pour water filling both of his hands over his head three times, then he would pour water over his body}}
\hadithdefcmd{nasai}{244}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - عَنْ غُسْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْجَنَابَةِ فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُفْرِغُ عَلَى يَدَيْهِ ثَلاَثًا ثُمَّ يَغْسِلُ فَرْجَهُ ثُمَّ يَغْسِلُ يَدَيْهِ ثُمَّ يُمَضْمِضُ وَيَسْتَنْشِقُ ثُمَّ يُفْرِغُ عَلَى رَأْسِهِ ثَلاَثًا ثُمَّ يُفِيضُ عَلَى سَائِرِ جَسَدِهِ ‏.‏\hadithno{244}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Salamah said:"I asked 'Aishah about how the Messenger of Allah (ﷺ) performed Ghusl from Janabah. She said: 'The Messenger of Allah (ﷺ) used to pour water onto his hands three times, then he would wash his private part, then he would wash his hands, then rinse his mouth and nose, then pour water onto his head three times, then pour water over the rest of his body}}
\hadithdefcmd{nasai}{245}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، أَنْبَأَنَا النَّضْرُ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ أَنْبَأَنَا عَطَاءُ بْنُ السَّائِبِ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، أَنَّهُ دَخَلَ عَلَى عَائِشَةَ - رضى الله عنها - فَسَأَلَهَا عَنْ غُسْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْجَنَابَةِ فَقَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُؤْتَى بِالإِنَاءِ فَيَصُبُّ عَلَى يَدَيْهِ ثَلاَثًا فَيَغْسِلُهُمَا ثُمَّ يَصُبُّ بِيَمِينِهِ عَلَى شِمَالِهِ فَيَغْسِلُ مَا عَلَى فَخِذَيْهِ ثُمَّ يَغْسِلُ يَدَيْهِ وَيَتَمَضْمَضُ وَيَسْتَنْشِقُ وَيَصُبُّ عَلَى رَأْسِهِ ثَلاَثًا ثُمَّ يُفِيضُ عَلَى سَائِرِ جَسَدِهِ ‏.‏\hadithno{245}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Abu Salamah (narrated) that he entered upon 'Aishah and asked her about the Ghusl of the Messenger of Allah (ﷺ) from Janabah. She said:"A vessel would be brought to the prophet (ﷺ) then he would pour water on his hand three times and wash them, then he would pour water with his right hand onto his left and wash off whatever was on his thighs. Then he would wash his hands, rinse his mouth and nose, pour water on his head three times, then pour water over the rest of his body}}
\hadithdefcmd{nasai}{246}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ وَصَفَتْ عَائِشَةُ غُسْلَ النَّبِيِّ صلى الله عليه وسلم مِنَ الْجَنَابَةِ قَالَتْ كَانَ يَغْسِلُ يَدَيْهِ ثَلاَثًا ثُمَّ يُفِيضُ بِيَدِهِ الْيُمْنَى عَلَى الْيُسْرَى فَيَغْسِلُ فَرْجَهُ وَمَا أَصَابَهُ - قَالَ عُمَرُ وَلاَ أَعْلَمُهُ إِلاَّ قَالَ يُفِيضُ بِيَدِهِ الْيُمْنَى عَلَى الْيُسْرَى ثَلاَثَ مَرَّاتٍ - ثُمَّ يَتَمَضْمَضُ ثَلاَثًا وَيَسْتَنْشِقُ ثَلاَثًا وَيَغْسِلُ وَجْهَهُ ثَلاَثًا ثُمَّ يُفِيضُ عَلَى رَأْسِهِ ثَلاَثًا ثُمَّ يَصُبُّ عَلَيْهِ الْمَاءَ ‏.‏\hadithno{246}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Salamah bin 'Abdur-Rahman said:"Aishah described how the Prophet (ﷺ) performed Ghusl for Janabah. She said: 'He used to wash his hands three times, then pour water with his right hand onto his left and wash his private part and whatever was on it.' - (One of the narrators) 'Umar said: "I think he said: 'He would pour water with his right hand onto his left hand three times.'" - "Then he would rinse his mouth three times and his nose three times, and wash his face and hands three times, then he would pour water over his head three times, then pour water over himself}}
\hadithdefcmd{nasai}{247}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ بَدَأَ فَغَسَلَ يَدَيْهِ ثُمَّ تَوَضَّأَ كَمَا يَتَوَضَّأُ لِلصَّلاَةِ ثُمَّ يُدْخِلُ أَصَابِعَهُ الْمَاءَ فَيُخَلِّلُ بِهَا أُصُولَ شَعْرِهِ ثُمَّ يَصُبُّ عَلَى رَأْسِهِ ثَلاَثَ غُرَفٍ ثُمَّ يُفِيضُ الْمَاءَ عَلَى جَسَدِهِ كُلِّهِ ‏.‏\hadithno{247}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that when the Prophet (ﷺ) performed Ghusl from Janabah he would start by washing his hands, then he would perform Wudu' as for prayer, then he would dip his fingers in the water, then run them through his hair, then he would pour water over his head three times, then he would pour water over his entire body}}
\hadithdefcmd{nasai}{248}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا يَحْيَى، قَالَ أَنْبَأَنَا هِشَامُ بْنُ عُرْوَةَ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَتْنِي عَائِشَةُ، - رضى الله عنها - عَنْ غُسْلِ النَّبِيِّ، صلى الله عليه وسلم مِنَ الْجَنَابَةِ أَنَّهُ كَانَ يَغْسِلُ يَدَيْهِ وَيَتَوَضَّأُ وَيُخَلِّلُ رَأْسَهُ حَتَّى يَصِلَ إِلَى شَعْرِهِ ثُمَّ يُفْرِغُ عَلَى سَائِرِ جَسَدِهِ ‏.‏\hadithno{248}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated concerning the Ghusl of the Prophet (ﷺ) from Janabah, that he used to wash his hands and perform Wudu', then he would run (his fingers) through his (hair on his) head so that it reaches all of his hair, then he would pour water over his entire body}}
\hadithdefcmd{nasai}{249}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُشَرِّبُ رَأْسَهُ ثُمَّ يَحْثِي عَلَيْهِ ثَلاَثًا ‏.‏\hadithno{249}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) used to soak his head, then he would pour water over it three times}}
\hadithdefcmd{nasai}{250}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ صُرَدٍ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ تَمَارَوْا فِي الْغُسْلِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ بَعْضُ الْقَوْمِ إِنِّي لأَغْسِلُ كَذَا وَكَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمَّا أَنَا فَأُفِيضُ عَلَى رَأْسِي ثَلاَثَ أَكُفٍّ ‏"‏ ‏.‏\hadithno{250}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jubair bin Mut'im said:"They argued about Ghusl in the presence of the messenger of Allah (ﷺ). One of the people said: 'I perform Ghusl in such-and-such a manner.' The Messenger of Allah (ﷺ) said: 'As for me, I pour three handfuls of water over my head}}
\hadithdefcmd{nasai}{251}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، - وَهُوَ ابْنُ صَفِيَّةَ - عَنْ أُمِّهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ امْرَأَةً، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم عَنْ غُسْلِهَا مِنَ الْمَحِيضِ فَأَخْبَرَهَا كَيْفَ تَغْتَسِلُ ثُمَّ قَالَ ‏"‏ خُذِي فِرْصَةً مِنْ مِسْكٍ فَتَطَهَّرِي بِهَا ‏"‏ ‏.‏ قَالَتْ وَكَيْفَ أَتَطَهَّرُ بِهَا فَاسْتَتَرَ كَذَا ثُمَّ قَالَ ‏"‏ سُبْحَانَ اللَّهِ تَطَهَّرِي بِهَا ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ رضى الله عنها فَجَذَبْتُ الْمَرْأَةَ وَقُلْتُ تَتَّبِعِينَ بِهَا أَثَرَ الدَّمِ ‏.‏\hadithno{251}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that a woman asked the Prophet (ﷺ) about performing Ghusl following menstruation and he told her how to perform Ghusl. Then he said:"Take a piece of cloth perfumed with musk and purify yourself with it." She said: "How should I purify myself with it?" He covered his face then said: "Subhan Allah! Purify yourself with it." 'Aishah said: "I took the woman aside and said: 'Wipe away the traces of blood with it}}
\hadithdefcmd{nasai}{252}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا أَبِي، أَنْبَأَنَا الْحَسَنُ، - وَهُوَ ابْنُ صَالِحٍ - عَنْ أَبِي إِسْحَاقَ، ح وَحَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَتَوَضَّأُ بَعْدَ الْغُسْلِ ‏.‏\hadithno{252}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) used not to perform Wudu' after Ghusl}}
\hadithdefcmd{nasai}{253}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عِيسَى، عَنِ الأَعْمَشِ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَتْنِي خَالَتِي، مَيْمُونَةُ قَالَتْ أَدْنَيْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم غُسْلَهُ مِنَ الْجَنَابَةِ فَغَسَلَ كَفَّيْهِ مَرَّتَيْنِ أَوْ ثَلاَثًا ثُمَّ أَدْخَلَ بِيَمِينِهِ فِي الإِنَاءِ فَأَفْرَغَ بِهَا عَلَى فَرْجِهِ ثُمَّ غَسَلَهُ بِشِمَالِهِ ثُمَّ ضَرَبَ بِشِمَالِهِ الأَرْضَ فَدَلَكَهَا دَلْكًا شَدِيدًا ثُمَّ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ أَفْرَغَ عَلَى رَأْسِهِ ثَلاَثَ حَثَيَاتٍ مِلْءَ كَفِّهِ ثُمَّ غَسَلَ سَائِرَ جَسَدِهِ ثُمَّ تَنَحَّى عَنْ مَقَامِهِ فَغَسَلَ رِجْلَيْهِ قَالَتْ ثُمَّ أَتَيْتُهُ بِالْمِنْدِيلِ فَرَدَّهُ ‏.‏\hadithno{253}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"My maternal aunt Maimunah told me: 'I brought the Messenger of Allah (ﷺ) water for his Ghusl from Janabah, and he washed his hands two or three times, then he put his right hand in the vessel and poured water over his private part, then he washed it with his left hand. Then he put his left hand on the ground and rubbed it hard. Then he performed Wudu' as for prayer,then poured three scoops with his two hands full of water over his head, then he washed his entire body, then he moved away from where he had been standing and washed his feet.' She said: 'Then I brought him a towel but he refused it}}
\hadithdefcmd{nasai}{254}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اغْتَسَلَ فَأُتِيَ بِمِنْدِيلٍ فَلَمْ يَمَسَّهُ وَجَعَلَ يَقُولُ بِالْمَاءِ هَكَذَا ‏.‏\hadithno{254}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) performed Ghusl and a cloth was brought to him, but he did not touch it, and he started doing like this with the water. [1] [1] This is a demonstration of his wiping off the water on his body with his hands}}
\hadithdefcmd{nasai}{255}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ بْنِ حَبِيبٍ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، وَعَبْدُ الرَّحْمَنِ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم - وَقَالَ عَمْرٌو كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم - إِذَا أَرَادَ أَنْ يَأْكُلَ أَوْ يَنَامَ وَهُوَ جُنُبٌ تَوَضَّأَ - زَادَ عَمْرٌو فِي حَدِيثِهِ - وُضُوءَهُ لِلصَّلاَةِ ‏.‏\hadithno{255}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"If the Prophet (ﷺ)" - (one of the narrators) 'Amr said: "If the Messenger of Allah (ﷺ)" - "wanted to eat or sleep while he was Junub, he would perform Wudu'." In his narration, 'Amr (one of the narrators) added: "Wudu' was for prayer}}
\hadithdefcmd{nasai}{256}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَنَامَ وَهُوَ جُنُبٌ تَوَضَّأَ وَإِذَا أَرَادَ أَنْ يَأْكُلَ غَسَلَ يَدَيْهِ ‏.‏\hadithno{256}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that if the Messenger of Allah (ﷺ) wanted to sleep while he was Junub, he would perform Wudu', and if he wanted to eat he would wash his hands}}
\hadithdefcmd{nasai}{257}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، أَنَّ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَنَامَ وَهُوَ جُنُبٌ تَوَضَّأَ وَإِذَا أَرَادَ أَنْ يَأْكُلَ أَوْ يَشْرَبَ - قَالَتْ - غَسَلَ يَدَيْهِ ثُمَّ يَأْكُلُ أَوْ يَشْرَبُ ‏.‏\hadithno{257}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Salamah that 'Aishah said:"If the Messenger of Allah (ﷺ) wanted to sleep while he was Junub, he would perform Wudu', and if he wanted to eat or drink," she said: "he would wash his hands and then eat or drink}}
\hadithdefcmd{nasai}{258}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَنَامَ وَهُوَ جُنُبٌ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ قَبْلَ أَنْ يَنَامَ ‏.‏\hadithno{258}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"If the Messenger of Allah (ﷺ) wanted to sleep while he was Junub, he would perform Wudu' as for prayer before sleeping}}
\hadithdefcmd{nasai}{259}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ، قَالَ يَا رَسُولَ اللَّهِ أَيَنَامُ أَحَدُنَا وَهُوَ جُنُبٌ قَالَ ‏ "‏ إِذَا تَوَضَّأَ ‏"‏ ‏.‏\hadithno{259}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that 'Umar said:"O Messenger of Allah! May any one of us sleep while he is Junub?" He said: "When he performs Wudu}}
\hadithdefcmd{nasai}{260}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ ذَكَرَ عُمَرُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ تُصِيبُهُ الْجَنَابَةُ مِنَ اللَّيْلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَوَضَّأْ وَاغْسِلْ ذَكَرَكَ ثُمَّ نَمْ ‏"‏ ‏.‏\hadithno{260}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"Umar mentioned to the Messenger of Allah (ﷺ) that he became Junub at night, and the Messenger of Allah (ﷺ) said: 'Perform Wudu' and wash you penis, then sleep}}
\hadithdefcmd{nasai}{261}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ أَنْبَأَنَا شُعْبَةُ، ح وَأَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، - وَاللَّفْظُ لَهُ - عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ، عَنْ عَبْدِ اللَّهِ بْنِ نُجَىٍّ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ صُورَةٌ وَلاَ كَلْبٌ وَلاَ جُنُبٌ ‏"‏ ‏.‏\hadithno{261}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Ali that the Prophet (ﷺ) said:"The angels do not enter a house where there is an image, a dog or a Junub person}}
\hadithdefcmd{nasai}{262}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَرَادَ أَحَدُكُمْ أَنْ يَعُودَ تَوَضَّأَ ‏"‏ ‏.‏\hadithno{262}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa'eed that the Prophet (ﷺ) said:"When any one of you a wants to return (to have intercourse again), let him perform Wudu}}
\hadithdefcmd{nasai}{263}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لإِسْحَاقَ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ عَلَى نِسَائِهِ فِي لَيْلَةٍ بِغُسْلٍ وَاحِدٍ ‏.‏\hadithno{263}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) went around all his wives and only performed Ghusl once}}
\hadithdefcmd{nasai}{264}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَطُوفُ عَلَى نِسَائِهِ فِي غُسْلٍ وَاحِدٍ ‏.‏\hadithno{264}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) used to (go around) all his wives and perform Ghusl once}}
\hadithdefcmd{nasai}{265}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، قَالَ أَتَيْتُ عَلِيًّا أَنَا وَرَجُلاَنِ، فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْرُجُ مِنَ الْخَلاَءِ فَيَقْرَأُ الْقُرْآنَ وَيَأْكُلُ مَعَنَا اللَّحْمَ وَلَمْ يَكُنْ يَحْجُبُهُ عَنِ الْقُرْآنِ شَىْءٌ لَيْسَ الْجَنَابَةَ ‏.‏\hadithno{265}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Salimah said:"I came to 'Ali with two other men and he said: 'The Messenger of Allah (ﷺ) used to come out of the toilet and recite Qur'an, and he would eat meat with us and nothing would prevent him from (reciting) Qur'an except Janabah}}
\hadithdefcmd{nasai}{266}{أَخْبَرَنَا مُحَمَّدُ بْنُ أَحْمَدَ أَبُو يُوسُفَ الصَّيْدَلاَنِيُّ الرَّقِّيُّ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، عَنْ عَلِيٍّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ الْقُرْآنَ عَلَى كُلِّ حَالٍ لَيْسَ الْجَنَابَةَ ‏.‏\hadithno{266}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah (ﷺ) used to recite Qur'an in all circumstances except when he was Junub}}
\hadithdefcmd{nasai}{267}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ الشَّيْبَانِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ حُذَيْفَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا لَقِيَ الرَّجُلَ مِنْ أَصْحَابِهِ مَاسَحَهُ وَدَعَا لَهُ - قَالَ - فَرَأَيْتُهُ يَوْمًا بُكْرَةً فَحِدْتُ عَنْهُ ثُمَّ أَتَيْتُهُ حِينَ ارْتَفَعَ النَّهَارُ فَقَالَ ‏"‏ إِنِّي رَأَيْتُكَ فَحِدْتَ عَنِّي ‏"‏ ‏.‏ فَقُلْتُ إِنِّي كُنْتُ جُنُبًا فَخَشِيتُ أَنْ تَمَسَّنِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْمُسْلِمَ لاَ يَنْجُسُ ‏"‏ ‏.‏\hadithno{267}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Huthaifah said:"When the Messenger of Allah (ﷺ) met a man from among his Companions, he would shake hands with him and supplicate for him. I saw him one day in the early morning, and I tried to avoid him, then I came to him later in the day. He said: 'I saw you but you were avoiding me.' I said: 'I was Junub and I was afraid that you would touch me.' The Messenger of Allah (ﷺ) said: 'The Muslim is not made impure (Najis)}}
\hadithdefcmd{nasai}{268}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَخْبَرَنَا يَحْيَى، قَالَ حَدَّثَنَا مِسْعَرٌ، قَالَ حَدَّثَنِي وَاصِلٌ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ النَّبِيَّ صلى الله ع��يه وسلم لَقِيَهُ وَهُوَ جُنُبٌ ‏.‏ فَأَهْوَى إِلَىَّ فَقُلْتُ إِنِّي جُنُبٌ فَقَالَ ‏ "‏ إِنَّ الْمُسْلِمَ لاَ يَنْجُسُ ‏"‏ ‏.‏\hadithno{268}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Huthaifah that the Prophet (ﷺ) met him when he was Junub:"And he came close to me and reached out his hand. I said: 'I am Junub.' He said: 'The Muslim is not made impure (Najis)}}
\hadithdefcmd{nasai}{269}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا بِشْرٌ، - وَهُوَ ابْنُ الْمُفَضَّلِ - قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ بَكْرٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَقِيَهُ فِي طَرِيقٍ مِنْ طُرُقِ الْمَدِينَةِ وَهُوَ جُنُبٌ فَانْسَلَّ عَنْهُ فَاغْتَسَلَ فَفَقَدَهُ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا جَاءَ قَالَ ‏"‏ أَيْنَ كُنْتَ يَا أَبَا هُرَيْرَةَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّكَ لَقِيتَنِي وَأَنَا جُنُبٌ فَكَرِهْتُ أَنْ أُجَالِسَكَ حَتَّى أَغْتَسِلَ ‏.‏ فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ إِنَّ الْمُؤْمِنَ لاَ يَنْجُسُ ‏"‏ ‏.‏\hadithno{269}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) met him in one of the streets of Al-Madinah while he was Junub, so he slipped away from him and performed Ghusl. The Prophet (ﷺ) noticed he was not there, and when he came he said:'Where were you, O Abu Hurairah?' He said: 'O Messenger of Allah, you met us but I was Junub, and I did not want to sit in your presence until I had performed Ghusl.' He said: 'Subhan Allah! The believer is not made impure (Najis)}}
\hadithdefcmd{nasai}{270}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ إِذْ قَالَ ‏"‏ يَا عَائِشَةُ نَاوِلِينِي الثَّوْبَ ‏"‏ ‏.‏ فَقَالَتْ إِنِّي لاَ أُصَلِّي ‏.‏ قَالَ ‏"‏ إِنَّهُ لَيْسَ فِي يَدِكِ ‏"‏ ‏.‏ فَنَاوَلَتْهُ ‏.‏\hadithno{270}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"While the Messenger of Allah (ﷺ) was in the Masjid, he said: 'O 'Aishah, hand me the garment.' She said: 'I am not praying.' He said: 'It is not in your hand.' So she gave it to him}}
\hadithdefcmd{nasai}{271}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ عَبِيدَةَ، عَنِ الأَعْمَشِ، ح وَأَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَاوِلِينِي الْخُمْرَةَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ قَالَتْ إِنِّي حَائِضٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَتْ حَيْضَتُكِ فِي يَدِكِ ‏"‏ ‏.‏\hadithno{271}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) said: 'Give me the mat from the Masjid.'" She said: "I am menstruating." The Messenger of Allah (ﷺ) said: "Your menstruation is not in you hand}}
\hadithdefcmd{nasai}{272}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{272}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{A similar Hadith was narrated from Al-A'mash with the same chain}}
\hadithdefcmd{nasai}{273}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنْ مَنْبُوذٍ، عَنْ أُمِّهِ، أَنَّ مَيْمُونَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضَعُ رَأْسَهُ فِي حِجْرِ إِحْدَانَا فَيَتْلُو الْقُرْآنَ وَهِيَ حَائِضٌ وَتَقُومُ إِحْدَانَا بِالْخُمْرَةِ إِلَى الْمَسْجِدِ فَتَبْسُطُهَا وَهِيَ حَائِضٌ ‏.‏\hadithno{273}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Maimunah said:"The Messenger of Allah (ﷺ) used to lay his head in the lap of one of us while she was menstruating and recite Qur'an, and one of us would take the mat to the Masjid and spread it out while she was menstruating}}
\hadithdefcmd{nasai}{274}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ حُجْرٍ، - وَاللَّفْظُ لَهُ - أَنْبَأَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَأْسُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حِجْرِ إِحْدَانَا وَهِيَ حَائِضٌ وَهُوَ يَتْلُو الْقُرْآنَ ‏.‏\hadithno{274}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The head of the Messenger of Allah (ﷺ) would rest in the lap of one of us when she was menstruating, and he would recite Qur'an}}
\hadithdefcmd{nasai}{275}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُومِئُ إِلَىَّ رَأْسَهُ وَهُوَ مُعْتَكِفٌ فَأَغْسِلُهُ وَأَنَا حَائِضٌ ‏.‏\hadithno{275}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Prophet (ﷺ) would put his head out while he was in I'tikaf and I would wash it, while I was menstruating}}
\hadithdefcmd{nasai}{276}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، وَذَكَرَ، آخَرُ عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُخْرِجُ إِلَىَّ رَأْسَهُ مِنَ الْمَسْجِدِ وَهُوَ مُجَاوِرٌ فَأَغْسِلُهُ وَأَنَا حَائِضٌ ‏.‏\hadithno{276}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Prophet (ﷺ) would put his head out for me while he was performing I'tikaf [1] and I would wash it, when I was menstruating." [1] Mujawir ("next door") here means while performing I'tikaf}}
\hadithdefcmd{nasai}{277}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ أُرَجِّلُ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا حَائِضٌ ‏.‏\hadithno{277}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"I used to comb the hair of the Messenger of Allah (ﷺ) when I was menstruating}}
\hadithdefcmd{nasai}{278}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، ح وَأَنْبَأَنَا عَلِيُّ بْنُ شُعَيْبٍ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - مِثْلَ ذَلِكَ ‏.‏\hadithno{278}\hadithgrade{Al-Albani: Daif}\hadithtrans{Something similar was narrated by Malik, from Az-Zuhri, from 'Urwah, from 'Aishah}}
\hadithdefcmd{nasai}{279}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ الْمِقْدَامِ بْنِ شُرَيْحِ بْنِ هَانِئٍ - عَنْ أَبِيهِ، عَنْ شُرَيْحٍ، عَنْ عَائِشَةَ، رضى الله عنها سَأَلْتُهَا هَلْ تَأْكُلُ الْمَرْأَةُ مَعَ زَوْجِهَا وَهِيَ طَامِثٌ قَالَتْ نَعَمْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُونِي فَآكُلُ مَعَهُ وَأَنَا عَارِكٌ وَكَانَ يَأْخُذُ الْعَرْقَ فُيُقْسِمُ عَلَىَّ فِيهِ فَأَعْتَرِقُ مِنْهُ ثُمَّ أَضَعُهُ فَيَأْخُذُهُ فَيَعْتَرِقُ مِنْهُ وَيَضَعُ فَمَهُ حَيْثُ وَضَعْتُ فَمِي مِنَ الْعَرْقِ وَيَدْعُو بِالشَّرَابِ فَيُقْسِمُ عَلَىَّ فِيهِ قَبْلَ أَنْ يَشْرَبَ مِنْهُ فَآخُذُهُ فَأَشْرَبُ مِنْهُ ثُمَّ أَضَعُهُ فَيَأْخُذُهُ فَيَشْرَبُ مِنْهُ وَيَضَعُ فَمَهُ حَيْثُ وَضَعْتُ فَمِي مِنَ الْقَدَحِ ‏.‏\hadithno{279}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Shuraih that he asked 'Aishah:"Can a woman eat with her husband while she is menstruating? She said: 'Yes. The Messenger of Allah (ﷺ) would call me to eat with him while I was menstruating. He would take a piece of bone on which some bits of meat were left and insist that I take it first, so I would nibble a little from it, then put it down. Then he would take it and nibble from it, and he would put his mouth where mine had been on the bone. Then he would ask for a drink and insist that I take it first before he drank from it. So I would take it and drink from it, then put it down, then he would take it and drink from it, putting his mouth where mine had been on the cup}}
\hadithdefcmd{nasai}{280}{أَخْبَرَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الْوَزَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنِ الأَعْمَشِ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضَعُ فَاهُ عَلَى الْمَوْضِعِ الَّذِي أَشْرَبُ مِنْهُ فَيَشْرَبُ مِنْ فَضْلِ سُؤْرِي وَأَنَا حَائِضٌ ‏.‏\hadithno{280}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) used to put his mouth on the place where I had drunk from, and he would drink from what was leftover by me, while I was menstruating}}
\hadithdefcmd{nasai}{281}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مِسْعَرٍ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَائِشَةَ، - رضى الله عنها - تَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنَاوِلُنِي الإِنَاءَ فَأَشْرَبُ مِنْهُ وَأَنَا حَائِضٌ ثُمَّ أُعْطِيهِ فَيَتَحَرَّى مَوْضِعَ فَمِي فَيَضَعُهُ عَلَى فِيهِ ‏.‏\hadithno{281}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Miqdam bin Shuraih that his father said:"I heard 'Aishah say: 'The Messenger of Allah (ﷺ) would hand me the vessel and I would drink from it, while I was menstruating, then I would give it to him and he would look for the place where I had put my mouth and put that to his mouth}}
\hadithdefcmd{nasai}{282}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا مِسْعَرٌ، وَسُفْيَانُ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ أَشْرَبُ وَأَنَا حَائِضٌ وَأُنَاوِلُهُ النَّبِيَّ صلى الله عليه وسلم فَيَضَعُ فَاهُ عَلَى مَوْضِعِ فِيَّ فَيَشْرَبُ وَأَتَعَرَّقُ الْعَرْقَ وَأَنَا حَائِضٌ وَأُنَاوِلُهُ النَّبِيَّ صلى الله عليه وسلم فَيَضَعُ فَاهُ عَلَى مَوْضِعِ فِيَّ ‏.‏\hadithno{282}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I would drink while I was menstruating, then I would hand it to the Prophet (ﷺ), and he would put his mouth where mine had been and drink. And I would nibble at the bone on which some bits of meat were left while I was menstruating, then I would give it to the Prophet (ﷺ) and he would put his mouth where my mouth had been}}
\hadithdefcmd{nasai}{283}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، ح وَأَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنِي أَبِي، عَنْ يَحْيَى، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، حَدَّثَتْهُ أَنَّ أُمَّ سَلَمَةَ حَدَّثَتْهَا قَالَتْ، بَيْنَمَا أَنَا مُضْطَجِعَةٌ، مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْخَمِيلَةِ إِذْ حِضْتُ فَانْسَلَلْتُ فَأَخَذْتُ ثِيَابَ حَيْضَتِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَفِسْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ فَدَعَانِي فَاضْطَجَعْتُ مَعَهُ فِي الْخَمِيلَةِ ‏.‏\hadithno{283}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umm Salamah narrated:"While I was lying down with the Messenger of Allah (ﷺ) under a blanket, my period came, so I slipped away and put on the clothes I used to wear when I was menstruating. The Messenger of Allah (ﷺ) said: 'Are you menstruating?' I said: 'Yes.' Then he called me and I lied down with him under the blanket}}
\hadithdefcmd{nasai}{284}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ جَابِرِ بْنِ صُبْحٍ، قَالَ سَمِعْتُ خِلاَسًا، يُحَدِّثُ عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم نَبِيتُ فِي الشِّعَارِ الْوَاحِدِ وَأَنَا طَامِثٌ أَوْ حَائِضٌ فَإِنْ أَصَابَهُ مِنِّي شَىْءٌ غَسَلَ مَكَانَهُ وَلَمْ يَعْدُهُ وَصَلَّى فِيهِ ثُمَّ يَعُودُ فَإِنْ أَصَابَهُ مِنِّي شَىْءٌ فَعَلَ مِثْلَ ذَلِكَ وَلَمْ يَعْدُهُ وَصَلَّى فِيهِ ‏.‏\hadithno{284}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) and I would sleep under a single blanket when I was menstruating. If anything got on him from me, he would wash that spot and no more, and pray in it, then come back. If anything got on it again from me, he would do likewise and no more, and he would pray in it}}
\hadithdefcmd{nasai}{285}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ إِحْدَانَا إِذَا كَانَتْ حَائِضًا أَنْ تَشُدَّ إِزَارَهَا ثُمَّ يُبَاشِرُهَا ‏.‏\hadithno{285}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) would tell one of us, if she was menstruating, to tie her Izar (waist wrap) tightly then he would fondle her}}
\hadithdefcmd{nasai}{286}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ إِحْدَانَا إِذَا حَاضَتْ أَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَتَّزِرَ ثُمَّ يُبَاشِرُهَا ‏.‏\hadithno{286}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that 'Aishah said:"If one of us was menstruating, the Messenger of Allah (ﷺ) would tell her to put on an Izar (waist wrap) then he would fondle her}}
\hadithdefcmd{nasai}{287}{أَخْبَرَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنْ يُونُسَ، وَاللَّيْثِ، عَنِ ابْنِ شِهَابٍ، عَنْ حَبِيبٍ، مَوْلَى عُرْوَةَ عَنْ بُدَيَّةَ، - وَكَانَ اللَّيْثُ يَقُولُ نَدَبَةَ - مَوْلاَةُ مَيْمُونَةَ عَنْ مَيْمُونَةَ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُبَاشِرُ الْمَرْأَةَ مِنْ نِسَائِهِ وَهِيَ حَائِضٌ إِذَا كَانَ عَلَيْهَا إِزَارٌ يَبْلُغُ أَنْصَافَ الْفَخِذَيْنِ وَالرُّكْبَتَيْنِ ‏.‏ فِي حَدِيثِ اللَّيْثِ مُحْتَجِزَةً بِهِ ‏.‏\hadithno{287}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Maimunah said:"The Messenger of Allah (ﷺ) would fondle one of his wives while she was menstruating, if she wore an Izar (waist wrap) that reached halfway down to the middle of her thighs or to her knees." In the narration of Al-Laith: "Being covered with it}}
\hadithdefcmd{nasai}{288}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَتِ الْيَهُودُ إِذَا حَاضَتِ الْمَرْأَةُ مِنْهُمْ لَمْ يُؤَاكِلُوهُنَّ وَلَمْ يُشَارِبُوهُنَّ وَلَمْ يُجَامِعُوهُنَّ فِي الْبُيُوتِ فَسَأَلُوا نَبِيَّ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَيَسْأَلُونَكَ عَنِ الْمَحِيضِ قُلْ هُوَ أَذًى ‏\}‏ الآيَةَ فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُؤَاكِلُوهُنَّ وَيُشَارِبُوهُنَّ وَيُجَامِعُوهُنَّ فِي الْبُيُوتِ وَأَنْ يَصْنَعُوا بِهِنَّ كُلَّ شَىْءٍ مَا خَلاَ الْجِمَاعَ ‏.‏\hadithno{288}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Anas said:"When one of their womenfolk menstruated, the Jews would not eat or drink with them, nor mix with them in their houses. They asked the Prophet of Allah (ﷺ) about that, and Allah the Mighty and Sublime revealed: The ask you concerning menstruation. Say: 'That is an Adha (a harmful thing).'[2] So the Messenger of Allah (ﷺ) commanded them to eat and drink with them (menstruating women) and to mix with them in their houses, and to do everything with them except intercourse. The Jews said: 'The Messenger of Allah (ﷺ) does not leave anything against it.' Usaid bin Hudair and 'Abbad bin Bishr went and told the Messenger of Allah (ﷺ) and they said: 'Should we have intercourse with them when they are menstruating?' The expression of the Messenger of Allah (ﷺ) changed greatly until we thought that he was angry with them, and they left. Then the Messenger of Allah (ﷺ) received a gift of milk, so he sent someone to bring them back and he gave them some to drink, so they knew that he was not angry with them." [1] Al-Baqarah 2:222. [2] Al-Baqarah 2:}}
\hadithdefcmd{nasai}{289}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الْحَمِيدِ، عَنْ مُقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرَّجُلِ يَأْتِي امْرَأَتَهُ وَهِيَ حَائِضٌ يَتَصَدَّقُ بِدِينَارٍ أَوْ بِنِصْفِ دِينَارٍ ‏.‏\hadithno{289}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas from the Prophet (ﷺ) concerning a man who has had intercourse while she was menstruating:"Let him give a Dinar or half a Dinar in charity}}
\hadithdefcmd{nasai}{290}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نُرَى إِلاَّ الْحَجَّ فَلَمَّا كَانَ بِسَرِفَ حِضْتُ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ مَا لَكِ أَنَفِسْتِ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَزَّ وَجَلَّ عَلَى بَنَاتِ آدَمَ فَاقْضِي مَا يَقْضِي الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ ‏"‏ ‏.‏ وَضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نِسَائِهِ بِالْبَقَرِ ‏.‏\hadithno{290}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"We went out with the Messenger of Allah (ﷺ) with no intention other than Hajj. When he was in Sarif [1] I began menstruating. The Messenger of Allah (ﷺ) entered upon me and I was weeping. He said: 'What is the matter with you? Has your Nifas begun?' [2] I said: 'Yes.' He said: 'This is something that Allah the Mighty and Sublime has decreed for the daughter of Adam. Do what the pilgrims do, but do not perform tawaf around the House.' And the Messenger of Allah (ﷺ) sacrificed a cow on behalf of his wives." [1] Sarif is a place between Al-Madinah and Makkah, near Makkah. [2] Here, it means menstruation. See the chapter clarifying that where it appears again, No}}
\hadithdefcmd{nasai}{291}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، أَتَيْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَسَأَلْنَاهُ عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ وَخَرَجْنَا مَعَهُ حَتَّى إِذَا أَتَى ذَا الْحُلَيْفَةِ وَلَدَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ أَصْنَعُ قَالَ ‏ "‏ اغْتَسِلِي وَاسْتَثْفِرِي ثُمَّ أَهِلِّي ‏"‏ ‏.‏\hadithno{291}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ja'far bin Muhammad said:"My father told me: 'We cam to jabir bin 'Abdullah and asked him about the hajj of the prophet (ﷺ). He narrated: 'The Messenger of Allah (ﷺ) set out when there were five (days) remaining in Dhul-Qa'dah, and we set out with him. When he came to Dhul-Hulaifah, Asma' bint 'Umais gave birth to Muhammad bin Abi Bakr. She sent word to the Messenger of Allah (ﷺ) asking what she should do. He said: 'Perform Ghusl, bind yourself with a cloth then begin (the Talbiyah for Ihram)}}
\hadithdefcmd{nasai}{292}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو الْمِقْدَامِ، ثَابِتٌ الْحَدَّادُ عَنْ عَدِيِّ بْنِ دِينَارٍ، قَالَ سَمِعْتُ أُمَّ قَيْسٍ بِنْتَ مِحْصَنٍ، أَنَّهَا سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ دَمِ الْحَيْضِ يُصِيبُ الثَّوْبَ قَالَ ‏ "‏ حُكِّيهِ بِضِلَعٍ وَاغْسِلِيهِ بِمَاءٍ وَسِدْرٍ ‏"‏ ‏.‏\hadithno{292}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Adi bin Dinar said:"I heard Umm Qais bint Mihsan say that she asked the Messenger of Allah (ﷺ) about menstrual blood that gets on one's clothes. He said: 'Scratch it with a stick and wash it with water and lotus leaves}}
\hadithdefcmd{nasai}{293}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، وَكَانَتْ، تَكُونُ فِي حِجْرِهَا أَنَّ امْرَأَةً اسْتَفْتَتِ النَّبِيَّ صلى الله عليه وسلم عَنْ دَمِ الْحَيْضِ يُصِيبُ الثَّوْبَ فَقَالَ ‏ "‏ حُتِّيهِ ثُمَّ اقْرُصِيهِ بِالْمَاءِ ثُمَّ انْضَحِيهِ وَصَلِّي فِيهِ ‏"‏ ‏.‏\hadithno{293}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Asma' bint Abi Bakr taht a woman asked the Messenger of Allah (ﷺ) about menstrual blood that gets on clothes. He said:"Scratch it, then rub it with water, then sprinkle water over it, and pray in it}}
\hadithdefcmd{nasai}{294}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، عَنْ مُعَاوِيَةَ بْنِ حُدَيْجٍ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، أَنَّهُ سَأَلَ أُمَّ حَبِيبَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي الثَّوْبِ الَّذِي كَانَ يُجَامِعُ فِيهِ قَالَتْ نَعَمْ إِذَا لَمْ يَرَ فِيهِ أَذًى ‏.‏\hadithno{294}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Mu'awiyah bin Abi Sufyan that he asked Umm Habibah, the wife of the Prophet (ﷺ):"Did the Messenger of Allah (ﷺ) pray in a garment in which he had had intercourse?" She said: "Yes, so long as he saw no filth on it}}
\hadithdefcmd{nasai}{295}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَمْرِو بْنِ مَيْمُونٍ الْجَزَرِيِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْسِلُ الْجَنَابَةَ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَخْرُجُ إِلَى الصَّلاَةِ وَإِنَّ بُقَعَ الْمَاءِ لَفِي ثَوْبِهِ ‏.‏\hadithno{295}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"I used to wash the Janabah from the garment of the Messenger of Allah (ﷺ) and he would go out to pray, with traces of water on his garment}}
\hadithdefcmd{nasai}{296}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي هَاشِمٍ، عَنْ أَبِي مِجْلَزٍ، عَنِ الْحَارِثِ بْنِ نَوْفَلٍ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْرُكُ الْجَنَابَةَ - وَقَالَتْ مَرَّةً أُخْرَى الْمَنِيَّ - مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{296}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I used to scrape the Janabah." On another occasion she said: "The semen from the garment of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{297}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ الْحَكَمُ أَخْبَرَنِي عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، أَنَّ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي وَمَا أَزِيدُ عَلَى أَنْ أَفْرُكَهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{297}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hammam bin Al-Harith that 'Aishah said:"I remember when I could do no more than rub it form the garment of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{298}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، أَنْبَأَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْرُكُهُ مِنْ ثَوْبِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{298}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I used to rub it off from the garment of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{299}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَرَاهُ فِي ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَحُكُّهُ ‏.‏\hadithno{299}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I used to see it on the garment of the Messenger of Allah (ﷺ) and scratch it off}}
\hadithdefcmd{nasai}{300}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي أَفْرُكُ الْجَنَابَةَ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{300}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I remember rubbing the Janabah from the garment of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{301}{أَخْبَرَنَا مُحَمَّدُ بْنُ كَامِلٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي أَجِدُهُ فِي ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَحُتُّهُ عَنْهُ ‏.‏\hadithno{301}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I remember finding it on the garment of the Messenger of Allah (ﷺ) and scratching it off}}
\hadithdefcmd{nasai}{302}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، أَنَّهَا أَتَتْ بِابْنٍ لَهَا صَغِيرٍ لَمْ يَأْكُلِ الطَّعَامَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَجْلَسَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجْرِهِ فَبَالَ عَلَى ثَوْبِهِ فَدَعَا بِمَاءٍ فَنَضَحَهُ وَلَمْ يَغْسِلْهُ ‏.‏\hadithno{302}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Qais bin Mihsan that she brought a small son of hers who has not started eating food to the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) took him in his lap and he urinated on his garment, so he called for some water and sprinkled it on it, but he did not wash it}}
\hadithdefcmd{nasai}{303}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَبِيٍّ فَبَالَ عَلَيْهِ فَدَعَا بِمَاءٍ فَأَتْبَعَهُ إِيَّاهُ ‏.‏\hadithno{303}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"A small boy was brought to the Messenger of Allah (ﷺ) and he urinated on him, so he called for water and poured it on the place where the urine was}}
\hadithdefcmd{nasai}{304}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ الْوَلِيدِ، قَالَ حَدَّثَنِي مُحِلُّ بْنُ خَلِيفَةَ، قَالَ حَدَّثَنِي أَبُو السَّمْحِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يُغْسَلُ مِنْ بَوْلِ الْجَارِيَةِ وَيُرَشُّ مِنْ بَوْلِ الْغُلاَمِ ‏"‏ ‏.‏\hadithno{304}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu As-Samh said:"The Prophet (ﷺ) said: 'A girl's urine should be washed away and a boy's urine should be sprinkled with water}}
\hadithdefcmd{nasai}{305}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ أُنَاسًا أَوْ رِجَالاً مِنْ عُكْلٍ قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَكَلَّمُوا بِالإِسْلاَمِ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّا أَهْلُ ضَرْعٍ وَلَمْ نَكُنْ أَهْلَ رِيفٍ ‏.‏ وَاسْتَوْخَمُوا الْمَدِينَةَ فَأَمَرَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَوْدٍ وَرَاعٍ وَأَمَرَهُمْ أَنْ يَخْرُجُوا فِيهَا فَيَشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا فَلَمَّا صَحُّوا وَكَانُوا بِنَاحِيَةِ الْحَرَّةِ كَفَرُوا بَعْدَ إِسْلاَمِهِمْ وَقَتَلُوا رَاعِيَ النَّبِيِّ صلى الله عليه وسلم وَاسْتَاقُوا الذَّوْدَ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَبَعَثَ الطَّلَبَ فِي آثَارِهْمِ فَأُتِيَ بِهِمْ فَسَمَرُوا أَعْيُنَهُمْ وَقَطَّعُوا أَيْدِيَهُمْ وَأَرْجُلَهُمْ ثُمَّ تُرِكُوا فِي الْحَرَّةِ عَلَى حَالِهِمْ حَتَّى مَاتُوا ‏.‏\hadithno{305}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik narrated that "some people from 'Ukl came to the Messenger of Allah (ﷺ) and spoke about Islam. They said:'O Messenger of Allah, we are nomads who follows the herds, not farmers and growers, and the climate of Al-Madinah does not suit us.' So the Messenger of Allah (ﷺ)told them to go out to a flock of female camels and drink their milk and urine. When they recovered - and they were in the vicinity of Al-Harrah - they apostatized after having become Muslim, killed the camel-herder of the Messenger of Allah (ﷺ) and drove the camels away. News of that reached the Messenger of Allah (ﷺ) and he sent people after them. They were brought back, their eyes were smoldered with heated nails, their hands and feet cut off, then they were left in Al-Harrah in that state until they died}}
\hadithdefcmd{nasai}{306}{أَخْبَرَنَا مُحَمَّدُ بْنُ وَهْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَدِمَ أَعْرَابٌ مِنْ عُرَيْنَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَسْلَمُوا فَاجْتَوَوُا الْمَدِينَةَ حَتَّى اصْفَرَّتْ أَلْوَانُهُمْ وَعَظُمَتْ بُطُونُهُمْ فَبَعَثَ بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى لِقَاحٍ لَهُ وَأَمَرَهُمْ أَنْ يَشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا حَتَّى صَحُّوا فَقَتَلُوا رَاعِيَهَا وَاسْتَاقُوا الإِبِلَ فَبَعَثَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فِي طَلَبِهِمْ فَأُتِيَ بِهِمْ فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَرَ أَعْيُنَهُمْ ‏.‏ قَالَ أَمِيرُ الْمُؤْمِنِينَ عَبْدُ الْمَلِكِ لأَنَسٍ وَهُوَ يُحَدِّثُهُ هَذَا الْحَدِيثَ بِكُفْرٍ أَمْ بِذَنْبٍ قَالَ بِكُفْرٍ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ نَعْلَمُ أَحَدًا قَالَ عَنْ يَحْيَى عَنْ أَنَسٍ فِي هَذَا الْحَدِيثِ غَيْرَ طَلْحَةَ وَالصَّوَابُ عِنْدِي وَاللَّهُ تَعَالَى أَعْلَمُ يَحْيَى عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ مُرْسَلٌ ‏.‏\hadithno{306}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that some Bedouins from 'Urainah came to the Prophet (ﷺ) and became Muslims, but the climate of Al-Madinah did not suit them; their skin turned yellow and their stomachs became swollen. The Messenger of Allah (ﷺ) sent them to some pregnant camels of his and told them to drink their milk and urine until they recovered. Then they killed the camel-herder and drove the camels away. The Messenger of Allah (ﷺ) sent people after then and they were brought back. their hands and feet were cut off and their eyes were smoldered with burning nails. The Commander of the Believers, 'Abdul-Malik, said to Anas - when he was narrating this Hadith to him - "(Were they being punished) for Kufr or for a sin?" He said:"For Kufr}}
\hadithdefcmd{nasai}{307}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ مَخْلَدٍ - قَالَ حَدَّثَنَا عَلِيٌّ، - وَهُوَ ابْنُ صَالِحٍ - عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، فِي بَيْتِ الْمَالِ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي عِنْدَ الْبَيْتِ وَمَلأٌ مِنْ قُرَيْشٍ جُلُوسٌ وَقَدْ نَحَرُوا جَزُورًا فَقَالَ بَعْضُهُمْ أَيُّكُمْ يَأْخُذُ هَذَا الْفَرْثَ بِدَمِهِ ثُمَّ يُمْهِلُهُ حَتَّى يَضَعَ وَجْهَهُ سَاجِدًا فَيَضَعُهُ - يَعْنِي - عَلَى ظَهْرِهِ قَالَ عَبْدُ اللَّهِ فَانْبَعَثَ أَشْقَاهَا فَأَخَذَ الْفَرْثَ فَذَهَبَ بِهِ ثُمَّ أَمْهَلَهُ فَلَمَّا خَرَّ سَاجِدًا وَضَعَهُ عَلَى ظَهْرِهِ فَأُخْبِرَتْ فَاطِمَةُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِيَ جَارِيَةٌ فَجَاءَتْ تَسْعَى فَأَخَذَتْهُ مِنْ ظَهْرِهِ فَلَمَّا فَرَغَ مِنْ صَلاَتِهِ قَالَ ‏"‏ اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏"‏ اللَّهُمَّ عَلَيْكَ بِأَبِي جَهْلِ بْنِ هِشَامٍ وَشَيْبَةَ بْنِ رَبِيعَةَ وَعُتْبَةَ بْنِ رَبِيعَةَ وَعُقْبَةَ بْنِ أَبِي مُعَيْطٍ ‏"‏ ‏.‏ حَتَّى عَدَّ سَبْعَةً مِنْ قُرَيْشٍ ‏.‏ قَالَ عَبْدُ اللَّهِ فَوَالَّذِي أَنْزَلَ عَلَيْهِ الْكِتَابَ لَقَدْ رَأَيْتُهُمْ صَرْعَى يَوْمَ بَدْرٍ فِي قَلِيبٍ وَاحِدٍ ‏.‏\hadithno{307}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Amr bin Maimun said:"Abdullah told us: 'The Messenger of Allah (ﷺ) was praying at the House (the Ka'bah) and a group of the nobles of Quraish were sitting there. They had just slaughtered a camel and one of them said: "Which of you will take these stomach contents with the blood and wait until he prostrates, then put them on his back?" 'Abdullah said: 'The one who was most doomed got up and took the stomach contents, then went and waited until he prostrated himself, and put it on his back. Fatimah, the daughter of the Messenger of Allah (ﷺ), who was a young girl, was told about that, and she came running and took it off his back. When he had finished praying he said: "O Allah! Punish the Quraish," three times, "O Allah, punish Abu Jahl bin Hisham, Shaibah bin Rabi'ah, 'Utbah bin Rabi'ah, 'Uqbah bin Abi Mu'ait" until he had listed seven men from Quraish.' 'Abdullah said: 'By the One Who revealed the Book to him, I saw them dead on the day of Badr (their corpses) in a single dry well}}
\hadithdefcmd{nasai}{308}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَخَذَ طَرَفَ رِدَائِهِ فَبَصَقَ فِيهِ فَرَدَّ بَعْضَهُ عَلَى بَعْضٍ ‏.‏\hadithno{308}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ took the hem of his garment and spat on it, rubbed it together briefly and let it drop)}}
\hadithdefcmd{nasai}{309}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ الْقَاسِمَ بْنَ مِهْرَانَ، يُحَدِّثُ عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ فَلاَ يَبْزُقْ بَيْنَ يَدَيْهِ وَلاَ عَنْ يَمِينِهِ وَلَكِنْ عَنْ يَسَارِهِ أَوْ تَحْتَ قَدَمِهِ وَإِلاَّ ‏"‏ ‏.‏ فَبَزَقَ النَّبِيُّ صلى الله عليه وسلم هَكَذَا فِي ثَوْبِهِ وَدَلَكَهُ ‏.‏\hadithno{309}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"When any one of you prays, let him not spit in front of him or to his right, rather let him spit to his left or beneath his feet." Then the Prophet (ﷺ) spat like this on his garment and rubbed it}}
\hadithdefcmd{nasai}{310}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ أَوْ ذَاتِ الْجَيْشِ انْقَطَعَ عِقْدٌ لِي فَأَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْتِمَاسِهِ وَأَقَامَ النَّاسُ مَعَهُ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ فَأَتَى النَّاسُ أَبَا بَكْرٍ - رضى الله عنه - فَقَالُوا أَلاَ تَرَى مَا صَنَعَتْ عَائِشَةُ أَقَامَتْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَبِالنَّاسِ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ ‏.‏ فَجَاءَ أَبُو بَكْرٍ - رضى الله عنه - وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاضِعٌ رَأْسَهُ عَلَى فَخِذِي قَدْ نَامَ فَقَالَ حَبَسْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالنَّاسَ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ ‏.‏ قَالَتْ عَائِشَةُ فَعَاتَبَنِي أَبُو بَكْرٍ وَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ وَجَعَلَ يَطْعُنُ بِيَدِهِ فِي خَاصِرَتِي فَمَا مَنَعَنِي مِنَ التَّحَرُّكِ إِلاَّ مَكَانُ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى فَخِذِي فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَصْبَحَ عَلَى غَيْرِ مَاءٍ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ آيَةَ التَّيَمُّمِ ‏.‏ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ مَا هِيَ بِأَوَّلِ بَرَكَتِكُمْ يَا آلَ أَبِي بَكْرٍ ‏.‏ قَالَتْ فَبَعَثْنَا الْبَعِيرَ الَّذِي كُنْتُ عَلَيْهِ فَوَجَدْنَا الْعِقْدَ تَحْتَهُ ‏.‏\hadithno{310}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"We went out with the Messenger of Allah (ﷺ) on one of his journeys, and when we were in Al-Baida' or Dhat Al-Jaish, a necklace of mine broke and fell. The Messenger of Allah (ﷺ) stayed there looking for it and the people stayed with him. There was no water near them, and they did not have water with them. The people came to Abu Bakr, may Allah be pleased with him, and said: 'Do you see what 'Aishah has done? She has made the Messenger of Allah (ﷺ) and the people stop and they are not near any water and they do not have water with them.' Abu Bakr, may Allah be pleased with him, came while the Messenger of Allah (ﷺ) was resting his head on my thigh and had gone to sleep. He said: 'You have detained the Messenger of Allah (ﷺ) and the people, and they are not near any water and they do not have any water with them.'" 'Aishah said: "Abu Bakr rebuked me and said whatever Allah willed he would say. He started poking me on my hip, and the only thing that prevented me from moving was the fact that the Messenger of Allah (ﷺ) was resting on my thigh. The Messenger of Allah (ﷺ) slept until morning when he woke up without any water. Then Allah, the Mighty and Sublime revealed the verse of Tayammum. Usaid bin Hudair said: 'This is not the first time we have been blessed because of you, O family of Abu Bakr!'" She said: "Then we made the camel that I had been riding stand up, and we found the necklace beneath it}}
\hadithdefcmd{nasai}{311}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، عَنْ أَبِيهِ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ عُمَيْرٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّهُ سَمِعَهُ يَقُولُ أَقْبَلْتُ أَنَا وَعَبْدُ اللَّهِ بْنُ يَسَارٍ، مَوْلَى مَيْمُونَةَ حَتَّى دَخَلْنَا عَلَى أَبِي جُهَيْمِ بْنِ الْحَارِثِ بْنِ الصِّمَّةِ الأَنْصَارِيِّ فَقَالَ أَبُو جُهَيْمٍ أَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نَحْوِ بِئْرِ الْجَمَلِ وَلَقِيَهُ رَجُلٌ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَقْبَلَ عَلَى الْجِدَارِ فَمَسَحَ بِوَجْهِهِ وَيَدَيْهِ ثُمَّ رَدَّ عَلَيْهِ السَّلاَمَ ‏.‏\hadithno{311}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Umair the freed slave of Ibn 'Abbas that he heard him say:"Abdullah bin Yasar the freed slave of Maimunah, and I came and entered upon Abu Juhaim bin Al-Harith bin Al-Sammah Al-Ansari. Abu Juhaim said: 'The Messenger of Allah (ﷺ) came back from the direction of Bi'r Al-jamal and was met by a man who greeted him with Salam, but the Messenger of Allah (ﷺ) did not return the greeting until he turned to the wall and wiped his face and hands, then he returned the greeting}}
\hadithdefcmd{nasai}{312}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى عُمَرَ فَقَالَ إِنِّي أَجْنَبْتُ فَلَمْ أَجِدِ الْمَاءَ ‏.‏ قَالَ عُمَرُ لاَ تُصَلِّ ‏.‏ فَقَالَ عَمَّارُ بْنُ يَاسِرٍ يَا أَمِيرَ الْمُؤْمِنِينَ أَمَا تَذْكُرُ إِذْ أَنَا وَأَنْتَ فِي سَرِيَّةٍ فَأَجْنَبْنَا فَلَمْ نَجِدِ الْمَاءَ فَأَمَّا أَنْتَ فَلَمْ تُصَلِّ وَأَمَّا أَنَا فَتَمَعَّكْتُ فِي التُّرَابِ فَصَلَّيْتُ فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَذَكَرْنَا ذَلِكَ لَهُ فَقَالَ ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ ‏"‏ ‏.‏ فَضَرَبَ النَّبِيُّ صلى الله عليه وسلم يَدَيْهِ إِلَى الأَرْضِ ثُمَّ نَفَخَ فِيهِمَا ثُمَّ مَسَحَ بِهِمَا وَجْهَهُ وَكَفَّيْهِ - وَسَلَمَةُ شَكَّ لاَ يَدْرِي فِيهِ الْمِرْفَقَيْنِ أَوْ إِلَى الْكَفَّيْنِ - فَقَالَ عُمَرُ نُوَلِّيكَ مَا تَوَلَّيْتَ ‏.‏\hadithno{312}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abdur-Rahman bin Abza from his father that a man came to 'Umar and said:"I have become Junub and I do not have any water." 'Umar said: "Do not pray." But 'Ammar bin Yasir said: "O Commander of the Believers! Don't you remember when you and I were on a campaign and we became Junub and could not find water? You did not pray, but I rolled in the dust and prayed. Then we came to the Prophet (ﷺ) and told him about that, and he said: 'It would have been sufficient for you (to do this),' then the Prophet (ﷺ) struck his hands on the ground and blew on them, then wiped his face and hands with them'" - (one of the narrators) Salamah was uncertain and did not know whether that was up to the elbows or just hands. And 'Umar said: "We will let you bear the burden of what you took upon yourself}}
\hadithdefcmd{nasai}{313}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ نَاجِيَةَ بْنِ خُفَافٍ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، قَالَ أَجْنَبْتُ وَأَنَا فِي الإِبِلِ، فَلَمْ أَجِدْ مَاءً فَتَمَعَّكْتُ فِي التُّرَابِ تَمَعُّكَ الدَّابَّةِ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ بِذَلِكَ فَقَالَ ‏ "‏ إِنَّمَا كَانَ يَجْزِيكَ مِنْ ذَلِكَ التَّيَمُّمُ ‏"‏ ‏.‏\hadithno{313}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ammar bin Yasir said:"I became Junub while I was on a camel and I could not find any water, so I rolled in the dust like an animal. I came to the Messenger of Allah (ﷺ) and told him about that, and he said: 'Tayammum would have been sufficient for you}}
\hadithdefcmd{nasai}{314}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَمَّارٍ، قَالَ عَرَّسَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِأُولاَتِ الْجَيْشِ وَمَعَهُ عَائِشَةُ زَوْجَتُهُ فَانْقَطَعَ عِقْدُهَا مِنْ جَزْعِ ظِفَارِ فَحُبِسَ النَّاسُ ابْتِغَاءَ عِقْدِهَا ذَلِكَ حَتَّى أَضَاءَ الْفَجْرُ وَلَيْسَ مَعَ النَّاسِ مَاءٌ فَتَغَيَّظَ عَلَيْهَا أَبُو بَكْرٍ فَقَالَ حَبَسْتِ النَّاسَ وَلَيْسَ مَعَهُمْ مَاءٌ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ رُخْصَةَ التَّيَمُّمِ بِالصَّعِيدِ قَالَ فَقَامَ الْمُسْلِمُونَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَضَرَبُوا بِأَيْدِيهِمُ الأَرْضَ ثُمَّ رَفَعُوا أَيْدِيَهُمْ وَلَمْ يَنْفُضُوا مِنَ التُّرَابِ شَيْئًا فَمَسَحُوا بِهَا وُجُوهَهُمْ وَأَيْدِيَهُمْ إِلَى الْمَنَاكِبِ وَمِنْ بُطُونِ أَيْدِيهِمْ إِلَى الآبَاطِ ‏.‏\hadithno{314}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Ammar said:"The Messenger of Allah (ﷺ) stopped to rest at the end of the night in Uwlat Al-Jaish. His wife 'Aishah was with him and her necklace of Zifar beads [1] broke and fell. The army was detained looking for that necklace of hers until the break of the light of dawn and the people had no water with them. Abu Bakr got angry with her and said: 'You have detained the people and they do not have any water.' Then Allah the Mighty and Sublime revealed the concession allowing Tayammum with clean earth. So the Muslims got up with the Messenger of Allah (ﷺ) and struck with their hands, then they raised their hands and did not strike them together to knock off any dust, then they wiped their faces and arms up to the shoulders, and from the inner side of their of their arms up to the armpits." [1] Black and white Yemeni beads}}
\hadithdefcmd{nasai}{315}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، قَالَ حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّهُ أَخْبَرَهُ عَنْ أَبِيهِ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، قَالَ تَيَمَّمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالتُّرَابِ فَمَسَحْنَا بِوُجُوهِنَا وَأَيْدِينَا إِلَى الْمَنَاكِبِ ‏.‏\hadithno{315}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ammar bin Yasir said:"We did Tayammum with the Messenger of Allah (ﷺ) using dust, and we wiped our faces and our arms up to the shoulders}}
\hadithdefcmd{nasai}{316}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ، عَنْ أَبِي مَالِكٍ، وَعَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، قَالَ كُنَّا عِنْدَ عُمَرَ فَأَتَاهُ رَجُلٌ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ رُبَّمَا نَمْكُثُ الشَّهْرَ وَالشَّهْرَيْنِ وَلاَ نَجِدُ الْمَاءَ ‏.‏ فَقَالَ عُمَرُ أَمَّا أَنَا فَإِذَا لَمْ أَجِدِ الْمَاءَ لَمْ أَكُنْ لأُصَلِّيَ حَتَّى أَجِدَ الْمَاءَ ‏.‏ فَقَالَ عَمَّارُ بْنُ يَاسِرٍ أَتَذْكُرُ يَا أَمِيرَ الْمُؤْمِنِينَ حَيْثُ كُنْتَ بِمَكَانِ كَذَا وَكَذَا وَنَحْنُ نَرْعَى الإِبِلَ فَتَعْلَمُ أَنَّا أَجْنَبْنَا قَالَ نَعَمْ أَمَّا أَنَا فَتَمَرَّغْتُ فِي التُّرَابِ فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَضَحِكَ فَقَالَ ‏ "‏ إِنْ كَانَ الصَّعِيدُ لَكَافِيكَ ‏"‏ ‏.‏ وَضَرَبَ بِكَفَّيْهِ إِلَى الأَرْضِ ثُمَّ نَفَخَ فِيهِمَا ثُمَّ مَسَحَ وَجْهَهُ وَبَعْضَ ذِرَاعَيْهِ ‏.‏ فَقَالَ اتَّقِ اللَّهَ يَا عَمَّارُ ‏.‏ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ إِنْ شِئْتَ لَمْ أَذْكُرْهُ ‏.‏ قَالَ لاَ وَلَكِنْ نُوَلِّيكَ مِنْ ذَلِكَ مَا تَوَلَّيْتَ ‏.‏\hadithno{316}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abddur-Rahman bin Abza said:"We were with 'Umar when a man came to him and said: 'O Commander of the Believers! sometimes we stay for a month or two without finding any water. Umar said: As if I did not find water, I would not pray until I found water.' 'Ammar bin Yasir said: 'Do you remember, O Commander of the Believer, when you were in such and such a place and we were rearing the camels, and you know that we became Junub?' He said: 'Yes.' 'As for me I rolled in the dust, then we came to the Prophet (ﷺ) and he laughed and said: "Clean earth would have been sufficient for you." And he struck his hands on the earth then blew on them, then he wiped his face and part of his forearms. He ('Umar) said: "Fear Allah, O 'Ammar!'" He said: 'O Commander of the Believers! If you wish I will not mention it.' He said: 'No, we will let you bear the burden of what you took upon yourself}}
\hadithdefcmd{nasai}{317}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا الْحَكَمُ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، أَنَّ رَجُلاً، سَأَلَ عُمَرَ بْنَ الْخَطَّابِ عَنِ التَّيَمُّمِ، فَلَمْ يَدْرِ مَا يَقُولُ فَقَالَ عَمَّارٌ أَتَذْكُرُ حَيْثُ كُنَّا فِي سَرِيَّةٍ فَأَجْنَبْتُ فَتَمَعَّكْتُ فِي التُّرَابِ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّمَا يَكْفِيكَ هَكَذَا ‏"‏ ‏.‏ وَضَرَبَ شُعْبَةُ بِيَدَيْهِ عَلَى رُكْبَتَيْهِ وَنَفَخَ فِي يَدَيْهِ وَمَسَحَ بِهِمَا وَجْهَهُ وَكَفَّيْهِ مَرَّةً وَاحِدَةً ‏.‏\hadithno{317}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abdur-Rahman bin Abza, from his father, that a man asked 'Umar bin Al-Khattab about Tayammum and he did not know what to say. 'Ammar said:"Do you remember when we were on a campaign, and I became Junub and rolled in the dust, then I came to the Prophet (ﷺ) and he said: 'This would have been sufficient.'" (One of the narrators) Shu'bah struck his hands on his knees and blew into his hands, then he wiped his face and palms with them once}}
\hadithdefcmd{nasai}{318}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، أَنْبَأَنَا خَالِدٌ، أَنْبَأَنَا شُعْبَةُ، عَنِ الْحَكَمِ، سَمِعْتُ ذَرًّا، يُحَدِّثُ عَنِ ابْنِ أَبْزَى، عَنْ أَبِيهِ، قَالَ وَقَدْ سَمِعَهُ الْحَكَمُ، مِنِ ابْنِ عَبْدِ الرَّحْمَنِ قَالَ أَجْنَبَ رَجُلٌ فَأَتَى عُمَرَ - رضى الله عنه - فَقَالَ إِنِّي أَجْنَبْتُ فَلَمْ أَجِدْ مَاءً ‏.‏ قَالَ لاَ تُصَلِّ ‏.‏ قَالَ لَهُ عَمَّارٌ أَمَا تَذْكُرُ أَنَّا كُنَّا فِي سَرِيَّةٍ فَأَجْنَبْنَا فَلَمْ نَجِدْ مَاءً فَأَمَّا أَنْتَ فَلَمْ تُصَلِّ وَأَمَّا أَنَا فَإِنِّي تَمَعَّكْتُ فَصَلَّيْتُ ثُمَّ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ ‏"‏ ‏.‏ وَضَرَبَ شُعْبَةُ بِكَفَّيْهِ ضَرْبَةً وَنَفَخَ فِيهِمَا ثُمَّ دَلَكَ إِحْدَاهُمَا بِالأُخْرَى ثُمَّ مَسَحَ بِهِمَا وَجْهَهُ ‏.‏ فَقَالَ عُمَرُ شَيْئًا لاَ أَدْرِي مَا هُوَ ‏.‏ فَقَالَ إِنْ شِئْتَ لاَ حَدَّثْتُهُ ‏.‏ وَذَكَرَ شَيْئًا فِي هَذَا الإِسْنَادِ عَنْ أَبِي مَالِكٍ وَزَادَ سَلَمَةُ قَالَ بَلْ نُوَلِّيكَ مِنْ ذَلِكَ مَا تَوَلَّيْتَ ‏.‏\hadithno{318}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abdur-Rahman said:"A man became Junub and came to 'Umar, may Allah be pleased with him, and said: 'I have become Junub and I cannot find any water.' He said: 'Do not pray.' 'Ammar said to him: 'Do you not remember when we were on a campaign and became Junub. You did not prayed, then I came to the Prophet (ﷺ) and told him that, and he said: 'This would have been sufficient for you.'" - (One of the narrators) Shu'bah struck his hands once and blew into them, then he rubbed them together, then wiped his face with them - ('Ammar said): "'Umar said something I did not understand." So he said: "If you wish, I shall not narrate it." Salamah mentioned something in this chain from Abu Malik, and Salamah added that he said: "Rather, we will let you bear the burden of what you tool upon yourself}}
\hadithdefcmd{nasai}{319}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ تَمِيمٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، وَسَلَمَةُ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، أَنَّ رَجُلاً، جَاءَ إِلَى عُمَرَ - رضى الله عنه - فَقَالَ إِنِّي أَجْنَبْتُ فَلَمْ أَجِدِ الْمَاءَ ‏.‏ فَقَالَ عُمَرُ لاَ تُصَلِّ ‏.‏ فَقَالَ عَمَّارٌ أَمَا تَذْكُرُ يَا أَمِيرَ الْمُؤْمِنِينَ إِذْ أَنَا وَأَنْتَ فِي سَرِيَّةٍ فَأَجْنَبْنَا فَلَمْ نَجِدْ مَاءً فَأَمَّا أَنْتَ فَلَمْ تُصَلِّ وَأَمَّا أَنَا فَتَمَعَّكْتُ فِي التُّرَابِ ثُمَّ صَلَّيْتُ فَلَمَّا أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ إِنَّمَا يَكْفِيكَ ‏"‏ ‏.‏ وَضَرَبَ النَّبِيُّ صلى الله عليه وسلم بِيَدَيْهِ إِلَى الأَرْضِ ثُمَّ نَفَخَ فِيهِمَا فَمَسَحَ بِهِمَا وَجْهَهُ وَكَفَّيْهِ - شَكَّ سَلَمَةُ وَقَالَ لاَ أَدْرِي فِيهِ إِلَى الْمِرْفَقَيْنِ أَوْ إِلَى الْكَفَّيْنِ - قَالَ عُمَرُ نُوَلِّيكَ مِنْ ذَلِكَ مَا تَوَلَّيْتَ قَالَ شُعْبَةُ كَانَ يَقُولُ الْكَفَّيْنِ وَالْوَجْهَ وَالذِّرَاعَيْنِ ‏.‏ فَقَالَ لَهُ مَنْصُورٌ مَا تَقُولُ فَإِنَّهُ لاَ يَذْكُرُ الذِّرَاعَيْنِ أَحَدٌ غَيْرُكَ ‏.‏ فَشَكَّ سَلَمَةُ فَقَالَ لاَ أَدْرِي ذَكَرَ الذِّرَاعَيْنِ أَمْ لاَ ‏.‏\hadithno{319}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abdur-Rahman bin Abza, from his father, that a man came to 'Umar, may Allah be please with him, and said:"I have become Junub and I cannot find any water." 'Umar said: "Do not pray." 'Ammar said: "Do you not remember, O Commander of the Believers, when you and I were on a campaign and became Junub, and we could not find any water. You did not pray, but I rolled in the dust then prayed. When we came to the Messenger of Allah (ﷺ) I told him about that and he said: 'This would have been sufficient for you,' and then Prophet (ﷺ) struck the earth with his hands then blew on them and wiped his face and hands - (one of the narrators) Salamah was uncertain and said: "I do not know if he said it should be up to the elbows or just the hands." - 'Umar said: "We will let you bear the burden of what you took upon yourself." (One of the narrators) Shu'bah said: "He used to say the hands, face and forearms." (Another) Mansur said to him: "What are you saying? No one mentions the forearms except you." Salamah was not certain and said: "I do not know whether he mentioned the forearms or not}}
\hadithdefcmd{nasai}{320}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، قَالَ كُنْتُ جَالِسًا مَعَ عَبْدِ اللَّهِ وَأَبِي مُوسَى فَقَالَ أَبُو مُوسَى أَوَلَمْ تَسْمَعْ قَوْلَ عَمَّارٍ لِعُمَرَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَاجَةٍ فَأَجْنَبْتُ فَلَمْ أَجِدِ الْمَاءَ فَتَمَرَّغْتُ بِالصَّعِيدِ ثُمَّ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَقُولَ هَكَذَا ‏"‏ ‏.‏ وَضَرَبَ بِيَدَيْهِ عَلَى الأَرْضِ ضَرْبَةً فَمَسَحَ كَفَّيْهِ ثُمَّ نَفَضَهُمَا ثُمَّ ضَرَبَ بِشِمَالِهِ عَلَى يَمِينِهِ وَبِيَمِينِهِ عَلَى شِمَالِهِ عَلَى كَفَّيْهِ وَوَجْهِهِ فَقَالَ عَبْدُ اللَّهِ أَوَلَمْ تَرَ عُمَرَ لَمْ يَقْنَعْ بِقَوْلِ عَمَّارٍ ‏.‏\hadithno{320}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Shaqiq said:"I was siting with 'Abdullah and Abu Musa, and Abu Musa said: 'Have you not heard what 'Ammar said to 'Umar: 'The Messenger of Allah (ﷺ) sent me on an errand and I became Junub, and I could not find water, so I rolled in the earth then I came to the Prophet (ﷺ) and told him about.' He said: 'It would have been sufficient for you to do this,' and he struck the earth with his hands, then wiped his hands, then knocked them together to remove the dust, then he wiped his right hand with his left and his left hand with his right, palm to palm, and wiped his face.'" Then 'Abdullah said: "Did you not see that 'Umar was not convinced by what 'Ammar said?}}
\hadithdefcmd{nasai}{321}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ عَوْفٍ، عَنْ أَبِي رَجَاءٍ، قَالَ سَمِعْتُ عِمْرَانَ بْنَ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً مُعْتَزِلاً لَمْ يُصَلِّ مَعَ الْقَوْمِ فَقَالَ ‏"‏ يَا فُلاَنُ مَا مَنَعَكَ أَنْ تُصَلِّيَ مَعَ الْقَوْمِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ أَصَابَتْنِي جَنَابَةٌ وَلاَ مَاءَ ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِالصَّعِيدِ فَإِنَّهُ يَكْفِيكَ ‏"‏ ‏.‏\hadithno{321}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Raja' said:"I heard 'Imran bin Husain (say) that the Prophet (ﷺ) saw a man who was by himself and did not pray with the people. He said: 'O So and so, what kept you from praying with the people?' He said: 'O Messenger of Allah, I have become Junub and there is no water.' He said: 'You should use earth for that will suffice you}}
\hadithdefcmd{nasai}{322}{أَخْبَرَنَا عَمْرُو بْنُ هِشَامٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، عَنْ سُفْيَانَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَمْرِو بْنِ بُجْدَانَ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصَّعِيدُ الطَّيِّبُ وَضُوءُ الْمُسْلِمِ وَإِنْ لَمْ يَجِدِ الْمَاءَ عَشْرَ سِنِينَ ‏"‏ ‏.‏\hadithno{322}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah (ﷺ) said: 'Clean earth is the Wudu' of the Muslim, even if he does not find water for ten years}}
\hadithdefcmd{nasai}{323}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم أُسَيْدَ بْنَ حُضَيْرٍ وَنَاسًا يَطْلُبُونَ قِلاَدَةً كَانَتْ لِعَائِشَةَ نَسِيَتْهَا فِي مَنْزِلٍ نَزَلَتْهُ فَحَضَرَتِ الصَّلاَةُ وَلَيْسُوا عَلَى وُضُوءٍ وَلَمْ يَجِدُوا مَاءً فَصَلُّوا بِغَيْرِ وُضُوءٍ فَذَكَرُوا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ آيَةَ التَّيَمُّمِ قَالَ أُسَيْدُ بْنُ حُضَيْرٍ جَزَاكِ اللَّهُ خَيْرًا فَوَاللَّهِ مَا نَزَلَ بِكِ أَمْرٌ تَكْرَهِينَهُ إِلاَّ جَعَلَ اللَّهُ لَكِ وَلِلْمُسْلِمِينَ فِيهِ خَيْرًا ‏.‏\hadithno{323}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) sent Usaid bin Hudair and some other people to look for a necklace that 'Aishah had left behind in a place where she had stopped (while traveling). The time for prayer came and they did not have Wudu', and they could not find any water, so they prayed without Wudu'. They mentioned that to the Messenger of Allah (ﷺ), and Allah, the Mighty and Sublime revealed the verse of Tayammum. Usaid bin Hudair said: 'May Allah reward you with good, for by Allah, nothing ever happened to you that you dislike, but Allah makes it good for you and the Muslims}}
\hadithdefcmd{nasai}{324}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، قَالَ أَنْبَأَنَا شُعْبَةُ، أَنَّ مُخَارِقًا، أَخْبَرَهُمْ عَنْ طَارِقٍ، أَنَّ رَجُلاً، أَجْنَبَ فَلَمْ يُصَلِّ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏"‏ أَصَبْتَ ‏"‏ ‏.‏ فَأَجْنَبَ رَجُلٌ آخَرُ فَتَيَمَّمَ وَصَلَّى فَأَتَاهُ فَقَالَ نَحْوَ مَا قَالَ لِلآخَرِ يَعْنِي ‏"‏ أَصَبْتَ ‏"‏ ‏.‏\hadithno{324}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Tariq that a man became Junub and did not pray, then he came to the Prophet (ﷺ) and mentioned that to him. He said:"You did the right thing." Another man became Junub and performed Tayammum and prayed, and he came to him and he said something similar to what he had told the other man - meaning, you did the right thing}}
