% Auto-generated chapter 37 for tirmidhi
% Hadiths in this chapter: 108

\hadithdefcmd{tirmidhi}{2415}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْكُمْ مِنْ رَجُلٍ إِلاَّ سَيُكَلِّمُهُ رَبُّهُ يَوْمَ الْقِيَامَةِ وَلَيْسَ بَيْنَهُ وَبَيْنَهُ تَرْجُمَانٌ فَيَنْظُرُ أَيْمَنَ مِنْهُ فَلاَ يَرَى شَيْئًا إِلاَّ شَيْئًا قَدَّمَهُ ثُمَّ يَنْظُرُ أَشْأَمَ مِنْهُ فَلاَ يَرَى شَيْئًا إِلاَّ شَيْئًا قَدَّمَهُ ثُمَّ يَنْظُرُ تِلْقَاءَ وَجْهِهِ فَتَسْتَقْبِلُهُ النَّارُ ‏". ‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَقِيَ وَجْهَهُ حَرَّ النَّارِ وَلَوْ بِشِقِّ تَمْرَةٍ فَلْيَفْعَلْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا أَبُو السَّائِبِ، حَدَّثَنَا وَكِيعٌ، يَوْمًا بِهَذَا الْحَدِيثِ عَنِ الأَعْمَشِ، فَلَمَّا فَرَغَ وَكِيعٌ مِنْ هَذَا الْحَدِيثِ قَالَ مَنْ كَانَ هَا هُنَا مِنْ أَهْلِ خُرَاسَانَ فَلْيَحْتَسِبْ فِي إِظْهَارِ هَذَا الْحَدِيثِ بِخُرَاسَانَ لأَنَّ الْجَهْمِيَّةَ يُنْكِرُونَ هَذَا ‏.‏ اسْمُ أَبِي السَّائِبِ سَلْمُ بْنُ جُنَادَةَ بْنِ سَلْمِ بْنِ خَالِدِ بْنِ جَابِرِ بْنِ سَمُرَةَ الْكُوفِيُّ ‏.‏هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏\hadithno{2415}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Adi bin Hatim narrated that the Messenger of Allah SAW said:"There is no man among you except that his Lord shall converse with him on the Day of Judgement, there being no interpreter between him and Him (Allah). Then he looks to the south (his right) and does not see anything except the things he put forward (of good), then he looks to the north (his left) and he does not see anything except the things he put forward (of evil), then he turns to look before him to find he is facing the Fire." The Messenger of Allah SAW, said: "Whoever among you is able to protect his face from [the heat of] the Fire – even with a piece of a date - then let him do so." (Sahih) [Abu 'Eisa said: This Hadith is Hasan Sahih]. Abu As-Sã'ib narrated to us: "One day, Waki' narrated this Hadith to us from Al-'Amash. When Waki' was finished with this Hadith, he said: 'Whoever is present from the inhabitants of Khurãsãn, then let him seek the reward of spreading this Hadith in Khurãsãn." Abu 'Eisa said: The Jahmiyyah rejected this. [Abu As-Sã'ib's name is Salam bin Junadah bin Khãlid bin Jäbir bin Samurah Al-Kufi]. This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{2416}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا حُصَيْنُ بْنُ نُمَيْرٍ أَبُو مِحْصَنٍ، حَدَّثَنَا حُسَيْنُ بْنُ قَيْسٍ الرَّحَبِيُّ، حَدَّثَنَا عَطَاءُ بْنُ أَبِي رَبَاحٍ، عَنِ ابْنِ عُمَرَ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَزُولُ قَدَمَا ابْنِ آدَمَ يَوْمَ الْقِيَامَةِ مِنْ عِنْدِ رَبِّهِ حَتَّى يُسْأَلَ عَنْ خَمْسٍ عَنْ عُمْرِهِ فِيمَا أَفْنَاهُ وَعَنْ شَبَابِهِ فِيمَا أَبْلاَهُ وَمَالِهِ مِنْ أَيْنَ اكْتَسَبَهُ وَفِيمَ أَنْفَقَهُ وَمَاذَا عَمِلَ فِيمَا عَلِمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ ابْنِ مَسْعُودٍ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ مِنْ حَدِيثِ الْحُسَيْنِ بْنِ قَيْسٍ ‏.‏ وَحُسَيْنُ بْنُ قَيْسٍ يُضَعَّفُ فِي الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَرْزَةَ وَأَبِي سَعِيدٍ ‏.‏\hadithno{2416}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Mas'ud narrated that the Messenger of Allah SAW said:"The feet of the son of Adam shall not move from before his Lord on the Day of Judgement, until he is asked about five things: About his life and what he did with it, about his youth and what he wore it out in, about his wealth and how he earned it, and spent it upon, and what he did with what he knew." (Da'if) [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it as a narration of Ibn Mas'üd from the Prophet except through the narration of Husain bin Qais. Husain [bin Qais] was graded weak in Hadith [due to his memory]. There are narrations on this topic from Abu Barzah and Abu Sa'eed}}
\hadithdefcmd{tirmidhi}{2417}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا الأَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ سَعِيدِ بْنِ عَبْدِ اللَّهِ بْنِ جُرَيْجٍ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَزُولُ قَدَمَا عَبْدٍ يَوْمَ الْقِيَامَةِ حَتَّى يُسْأَلَ عَنْ عُمْرِهِ فِيمَا أَفْنَاهُ وَعَنْ عِلْمِهِ فِيمَا فَعَلَ وَعَنْ مَالِهِ مِنْ أَيْنَ اكْتَسَبَهُ وَفِيمَا أَنْفَقَهُ وَعَنْ جِسْمِهِ فِيمَا أَبْلاَهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَسَعِيدُ بْنُ عَبْدِ اللَّهِ بْنِ جُرَيْجٍ هُوَ بَصْرِيٌّ وَهُوَ مَوْلَى أَبِي بَرْزَةَ وَأَبُو بَرْزَةَ اسْمُهُ نَضْلَةُ بْنُ عُبَيْدٍ ‏.‏\hadithno{2417}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Barzah Al-Aslami narrated that the Messenger of Allah (s.a.w) said:"The feet of the slave of Allah shall not move [on the Day of Judgement] until he is asked about five things: about his life and what he did with it, about his knowledge and what he did with it, about his wealth and how he earned it and where he spent it on, about his body and for what did he wear it out." [He said:] This Hadith is Hasan Sahih. Sa'eed bin Abdullah bin Juraij (a narrator in the chain) [is from Al-Basrah], and he is the freed slave of Abu Barzah AlAslami, and Abu Barzah AlAslami's name is Nadlah bin 'Ubaid}}
\hadithdefcmd{tirmidhi}{2418}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَتَدْرُونَ مَا الْمُفْلِسُ ‏"‏ ‏.‏ قَالُوا الْمُفْلِسُ فِينَا يَا رَسُولَ اللَّهِ مَنْ لاَ دِرْهَمَ لَهُ وَلاَ مَتَاعَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمُفْلِسُ مِنْ أُمَّتِي مَنْ يَأْتِي يَوْمَ الْقِيَامَةِ بِصَلاَتِهِ وَصِيَامِهِ وَزَكَاتِهِ وَيَأْتِي قَدْ شَتَمَ هَذَا وَقَذَفَ هَذَا وَأَكَلَ مَالَ هَذَا وَسَفَكَ دَمَ هَذَا وَضَرَبَ هَذَا فَيَقْعُدُ فَيَقْتَصُّ هَذَا مِنْ حَسَنَاتِهِ وَهَذَا مِنْ حَسَنَاتِهِ فَإِنْ فَنِيَتْ حَسَنَاتُهُ قَبْلَ أَنْ يُقْتَصَّ مَا عَلَيْهِ مِنَ الْخَطَايَا أُخِذَ مِنْ خَطَايَاهُمْ فَطُرِحَ عَلَيْهِ ثُمَّ طُرِحَ فِي النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2418}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Do you know who the bankrupt is?" They said: "O Messenger of Allah SAW! The bankrupt among us is the one who has no Dirham nor property." The Messenger of Allah (s.a.w) said: "The bankrupt in my Ummah is the one who comes with Salat and fasting and Zakat on the Day of Judgement, but he comes having abused this one, falsely accusing that one, wrongfully consuming the wealth of this one, spilling the blood of that one, and beating this one. So he is seated, and this one is requited from his rewards. If his rewards are exhausted before the sins that he committed are requited, then some of their sins will be taken and cast upon him, then he will be cast into the Fire." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{2419}{حَدَّثَنَا هَنَّادٌ، وَنَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، قَالَ حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ أَبِي خَالِدٍ، يَزِيدَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَحِمَ اللَّهُ عَبْدًا كَانَتْ لأَخِيهِ عِنْدَهُ مَظْلَمَةٌ فِي عِرْضٍ أَوْ مَالٍ فَجَاءَهُ فَاسْتَحَلَّهُ قَبْلَ أَنْ يُؤْخَذَ وَلَيْسَ ثَمَّ دِينَارٌ وَلاَ دِرْهَمٌ فَإِنْ كَانَتْ لَهُ حَسَنَاتٌ أُخِذَ مِنْ حَسَنَاتِهِ وَإِنْ لَمْ تَكُنْ لَهُ حَسَنَاتٌ حَمَّلُوا عَلَيْهِ مِنْ سَيِّئَاتِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ سَعِيدٍ الْمَقْبُرِيِّ ‏.‏ وَقَدْ رَوَاهُ مَالِكُ بْنُ أَنَسٍ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2419}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"May Allah have mercy upon a servant who has wronged his brother in his honor or his wealth, then he comes to him to seek his pardon before (his right) is taken, when he has no Dinar nor Dirham. Then if he has any rewards, it will be taken from his rewards, and if he have no rewards, Then some of his (brothers) bad deeds will be levied upon him." [Abu 'Eisa said:] This Hadith is Sahih [Gharib as a narration of Sa'eed Al-Maqburi]. Malik bin Anas also reported it from Sa'eed A]-Maqburl, from Abu Hurairah from the Prophet SAW, and it is similar in meaning}}
\hadithdefcmd{tirmidhi}{2420}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَتُؤَدَّنَّ الْحُقُوقُ إِلَى أَهْلِهَا حَتَّى يُقَادَ لِلشَّاةِ الْجَلْحَاءِ مِنَ الشَّاةِ الْقَرْنَاءِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي ذَرٍّ وَعَبْدِ اللَّهِ بْنِ أُنَيْسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2420}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Rights will be given to their due, such that the hornless sheep would get its claim from the horned sheep." There are narrations on this topic from Abu Dharr and 'Abdullah bin Unais. [Abu 'Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{2421}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، حَدَّثَنِي سُلَيْمُ بْنُ عَامِرٍ، حَدَّثَنَا الْمِقْدَادُ، صَاحِبُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِذَا كَانَ يَوْمُ الْقِيَامَةِ أُدْنِيَتِ الشَّمْسُ مِنَ الْعِبَادِ حَتَّى تَكُونَ قِيدَ مِيلٍ أَوِ اثْنَيْنِ ‏"‏ ‏.‏ قَالَ سُلَيْمٌ لاَ أَدْرِي أَىَّ الْمِيلَيْنِ عَنَى أَمَسَافَةَ الأَرْضِ أَمِ الْمِيلَ الَّذِي تُكْتَحَلُ بِهِ الْعَيْنُ قَالَ ‏"‏ فَتَصْهَرُهُمُ الشَّمْسُ فَيَكُونُونَ فِي الْعَرَقِ بِقَدْرِ أَعْمَالِهِمْ فَمِنْهُمْ مَنْ يَأْخُذُهُ إِلَى عَقِبَيْهِ وَمِنْهُمْ مَنْ يَأْخُذُهُ إِلَى رُكْبَتَيْهِ وَمِنْهُمْ مَنْ يَأْخُذُهُ إِلَى حَقْوَيْهِ وَمِنْهُمْ مَنْ يُلْجِمُهُ إِلْجَامًا ‏"‏ ‏.‏ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُشِيرُ بِيَدِهِ إِلَى فِيهِ أَىْ يُلْجِمُهُ إِلْجَامًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَابْنِ عُمَرَ ‏.‏\hadithno{2421}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sulaim bin 'Amir narrated from Al-Miqdad, a Companion of the Messenger of Allah (s.a.w) who said:"I heard the Messenger of Allah (s.a.w) saying: 'On the Day of Judgement, the sun will be drawn near the servants, until it has come a mile or two (away).'" Sulaim bin 'Amir said: " I do not know if it is miles that refer to distance on the land, or Al-Mil which is used to apply Kuhl for the eyes." He (the Prophet (s.a.w)): "The sun will melt them, until they will be in sweat according to their deeds. Among them one will be covered up to his ankles, and among them will be one who is covered up to his knees, and among them will be one who is covered up to his waist, and among them will be one who is bridled with it.' I saw the Messenger of Allah (s.a.w) indicating with his hand toward his mouth, meaning that one would be bridled with it.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih. There are narrations on this topic from Abu Sa'eed and Ibn 'Umar}}
\hadithdefcmd{tirmidhi}{2422}{حَدَّثَنَا أَبُو زَكَرِيَّا، يَحْيَى بْنُ دُرُسْتَ الْبَصْرِيُّ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ حَمَّادٌ وَهُوَ عِنْدَنَا مَرْفُوعٌ ‏(‏يَوْمَ يَقُومُ النَّاسُ لِرَبِّ الْعَالَمِينَ ‏)‏ قَالَ يَقُومُونَ فِي الرَّشْحِ إِلَى أَنْصَافِ آذَانِهِمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2422}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{Hammad bin Zayd narrated from Ayub, from Nafi', from Ibn 'Umar – Hammad said - :“And it is Marfu` in our view.” (He said): “The Day when all mankind will stand before the Lord of all that exists. They will be standing in their sweat up to the middle of their ears.” (Sahih) [Abu 'Eisa said:] This Hadith is Hasan Sahih. (Another chain) from the Prophet SAW with similar meaning}}
\hadithdefcmd{tirmidhi}{2423}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُحْشَرُ النَّاسُ يَوْمَ الْقِيَامَةِ حُفَاةً عُرَاةً غُرْلاً كَمَا خُلِقُوا ثُمَّ قَرَأََ ‏(‏كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ وَعْدًا عَلَيْنَا إِنَّا كُنَّا فَاعِلِينَ ‏)‏ وَأَوَّلُ مَنْ يُكْسَى مِنَ الْخَلاَئِقِ إِبْرَاهِيمُ وَيُؤْخَذُ مِنْ أَصْحَابِي بِرِجَالٍ ذَاتَ الْيَمِينِ وَذَاتَ الشِّمَالِ فَأَقُولُ يَا رَبِّ أَصْحَابِي ‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ إِنَّهُمْ لَمْ يَزَالُوا مُرْتَدِّينَ عَلَى أَعْقَابِهِمْ مُنْذُ فَارَقْتَهُمْ ‏.‏ فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُْ‏:‏ ‏(‏إِنْ تُعَذِّبْهُمْ فَإِنَّهُمْ عِبَادُكَ وَإِنْ تَغْفِرْ لَهُمْ فَإِنَّكَ أَنْتَ الْعَزِيزُ الْحَكِيمُ‏)‏ ‏"‏‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، بِهَذَا الإِسْنَادِ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2423}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (s.a.w) said:"The people will be gathered on the Day of Resurrection bare-foot, naked and uncircumcised as they were created." Then he recited: "As we begin the first creation, we shall repeat it: A promise binding upon Us. Truly We shall do it. And the first of people to be clothed will be Ibrahim. Among my companions will be some men who are taken to the right and to the left. I will say: 'O my Lord! My companions!' It will be said: 'You do not know what they innovated after you, they continued to be apostates since you parted from them.' So I will say as the righteous worshipper said: If you punish them, they are your slaves, and if You forgive them, indeed You, only You are the Almighty, the All-Wise." (Another chain) and he mentioned similarly. [Abü 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{2424}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا بَهْزُ بْنُ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّكُمْ مَحْشُورُونَ رِجَالاً وَرُكْبَانًا وَتُجَرُّونَ عَلَى وُجُوهِكُمْ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2424}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father, from his grandfather, that the Messenger of Allah (s.a.w) said:"You shall be gathered walking, riding, and dragged upon your faces." There is a narration on this topic from Abu Hurairah. [Abu 'Eisa said:] This Hadith is Hasan [Sahih]}}
\hadithdefcmd{tirmidhi}{2425}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ عَلِيٍّ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُعْرَضُ النَّاسُ يَوْمَ الْقِيَامَةِ ثَلاَثَ عَرَضَاتٍ فَأَمَّا عَرْضَتَانِ فَجِدَالٌ وَمَعَاذِيرُ وَأَمَّا الْعَرْضَةُ الثَّالِثَةُ فَعِنْدَ ذَلِكَ تَطِيرُ الصُّحُفُ فِي الأَيْدِي فَآخِذٌ بِيَمِينِهِ وَآخِذٌ بِشِمَالِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَلاَ يَصِحُّ هَذَا الْحَدِيثُ مِنْ قِبَلِ أَنَّ الْحَسَنَ لَمْ يَسْمَعْ مِنْ أَبِي هُرَيْرَةَ ‏.‏ وَقَدْ رَوَاهُ بَعْضُهُمْ عَنْ عَلِيِّ بْنِ عَلِيٍّ الرِّفَاعِيِّ عَنِ الْحَسَنِ عَنْ أَبِي مُوسَى عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَلاَ يَصِحُّ هَذَا الْحَدِيثُ مِنْ قِبَلِ أَنَّ الْحَسَنَ لَمْ يَسْمَعْ مِنْ أَبِي مُوسَى ‏.‏\hadithno{2425}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"The people will face three presentations on the Day of Judgement. As for (the first) two presentations, they are the arguments and the excuses, as for the third presentation, upon that the records will fly into the hands. Some will take them in their right hand, and some will take them in their left hand." [Abu 'Eisa said:] This Hadith is not correct, because Al-Hasan did not hear from Abu Hurairah. Some of them reported it from 'Ali bin 'Ali - and he is Ar-Rifa'i - from Al-Hasan, from Abu Musã from the Prophet SAW. [Abu 'Eisa said:] This Hadith is not correct, because Al-Hasan did not hear from Abü Musa}}
\hadithdefcmd{tirmidhi}{2426}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ عُثْمَانَ بْنِ الأَسْوَدِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ نُوقِشَ الْحِسَابَ هَلَكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ تَعَالَى يَقُولَُ‏:‏ ‏(‏فَأَمَّا مَنْ أُوتِيَ كِتَابَهُ بِيَمِينِهِ * فَسَوْفَ يُحَاسَبُ حِسَابًا يَسِيرًا ‏)‏ قَالَ ‏"‏ ذَلِكَ الْعَرْضُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ حَسَنٌ وَرَوَاهُ أَيُّوبُ أَيْضًا عَنِ ابْنِ أَبِي مُلَيْكَةَ ‏.‏\hadithno{2426}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abi Mulaikah narrated that 'Aishah said:"I heard the Messenger of Allah (s.a.w) saying: 'Whoever his account is questioned about , he shall be ruined.' I said: 'O Messenger of Allah! Indeed Allah [Most High] has said: Then as for him who shall be given his Record in his right hand. He surely will receive an easy reckoning.' Then he said: 'That is the presentation.'" [Abu 'Eisa said:] This Hadith is Sahih Hasan, Ayyub also reported it from Ibn Abi Mulaikah}}
\hadithdefcmd{tirmidhi}{2427}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ، عَنِ الْحَسَنِ، وَقَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُجَاءُ بِابْنِ آدَمَ يَوْمَ الْقِيَامَةِ كَأَنَّهُ بَذَجٌ فَيُوقَفُ بَيْنَ يَدَىِ اللَّهِ فَيَقُولُ اللَّهُ لَهُ أَعْطَيْتُكَ وَخَوَّلْتُكَ وَأَنْعَمْتُ عَلَيْكَ فَمَاذَا صَنَعْتَ ‏.‏ فَيَقُولُ يَا رَبِّ جَمَعْتُهُ وَثَمَّرْتُهُ فَتَرَكْتُهُ أَكْثَرَ مَا كَانَ فَارْجِعْنِي آتِكَ بِهِ ‏.‏ فَيَقُولُ لَهُ أَرِنِي مَا قَدَّمْتَ ‏.‏ فَيَقُولُ يَا رَبِّ جَمَعْتُهُ وَثَمَّرْتُهُ فَتَرَكْتُهُ أَكْثَرَ مَا كَانَ فَارْجِعْنِي آتِكَ بِهِ ‏.‏ فَإِذَا عَبْدٌ لَمْ يُقَدِّمْ خَيْرًا فَيُمْضَى بِهِ إِلَى النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى هَذَا الْحَدِيثَ غَيْرُ وَاحِدٍ عَنِ الْحَسَنِ قَوْلَهُ وَلَمْ يُسْنِدُوهُ ‏.‏ وَإِسْمَاعِيلُ بْنُ مُسْلِمٍ يُضَعَّفُ فِي الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ الْخُدْرِيِّ ‏.‏\hadithno{2427}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that the Prophet (s.a.w) said:"The son of Adam will be brought on the Day of Judgement as if he is a goat kid to be stood before Allah, Most High. Allah will say to him: 'I gave to you, I granted you, and I bestowed favors upon you. So what did you do?' So he says: 'I collected it, increased it, and left it as more than what it was. So return me and I shall give it all to You.' So He will say to him: 'Show me what you have prepared.' So he says: 'My Lord! I collected it, increased it and left it more than it was, So return me and I shall give it all to You.' So when the servant does not present any good he will be entered into the Fire." Abu 'Eisa said: More than one narrator reported this from Al-Hasan as his saying. And they did not rely upon Ismä'il bin Muslim who was graded weak in Hadith [due to his memory]. There are narrations on this topic from Abu Hurairah and Abu Sa'eed Al-Khudri}}
\hadithdefcmd{tirmidhi}{2428}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ الْبَصْرِيُّ، حَدَّثَنَا مَالِكُ بْنُ سُعَيْرٍ أَبُو مُحَمَّدٍ التَّمِيمِيُّ الْكُوفِيُّ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، وَعَنْ أَبِي سَعِيدٍ، قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُؤْتَى بِالْعَبْدِ يَوْمَ الْقِيَامَةِ فَيَقُولُ اللَّهُ لَهُ أَلَمْ أَجْعَلْ لَكَ سَمْعًا وَبَصَرًا وَمَالاً وَوَلَدًا وَسَخَّرْتُ لَكَ الأَنْعَامَ وَالْحَرْثَ وَتَرَكْتُكَ تَرْأَسُ وَتَرْبَعُ فَكُنْتَ تَظُنُّ أَنَّكَ مُلاَقِيَّ يَوْمَكَ هَذَا قَالَ فَيَقُولُ لاَ ‏.‏ فَيَقُولُ لَهُ الْيَوْمَ أَنْسَاكَ كَمَا نَسِيتَنِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ الْيَوْمَ أَنْسَاكَ ‏"‏ ‏.‏ يَقُولُ الْيَوْمَ أَتْرُكُكَ فِي الْعَذَابِ ‏.‏ هَكَذَا فَسَّرُوهُ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ فَسَّرَ بَعْضُ أَهْلِ الْعِلْمِ هَذِهِ الآيَةَ‏:‏ ‏(‏ الْيَوْمَ نَنْسَاهُمْ ‏)‏ قَالُوا إِنَّمَا مَعْنَاهُ الْيَوْمَ نَتْرُكُهُمْ فِي الْعَذَابِ ‏.‏\hadithno{2428}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Salih reported from Abu Hurairah and Abu Sa'eed that the Messenger of Allah (s.a.w) said:"The servant will be brought on the Day of Judgement, and He will say to hi: 'Did I not give you hearing, sight, wealth, children, and did I not make the cattle and tillage subservient to you, and did I not leave you as the head of people taking from their wealth? Did you not think that you would have to meet with Me on this Day of yours?' So he will say: 'No.' So it will be said to him: 'Today you shall be forgotten just as you have forgotten Me.'" [Abü 'Elsa said:] This Hadith is Sahih Gharib and the meaning of His saying: "Today you shall be forgotten just as you have forgotten Me" is: Today I shall leave you in chastisement. [This is how they have explained it]. [Abu 'Eisa said:] This is how some of the people of knowledge have explained this Ayah: So this Day We shall forget them...They said that it means: We shall leave them in chastisement}}
\hadithdefcmd{tirmidhi}{2429}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي سُلَيْمَانَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلمْ ‏(‏يَوْمَئِذٍ تُحَدِّثُ أَخْبَارَهَا ‏)‏ قَالَ ‏"‏ أَتَدْرُونَ مَا أَخْبَارُهَا ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ فَإِنَّ أَخْبَارَهَا أَنْ تَشْهَدَ عَلَى كُلِّ عَبْدٍ أَوْ أَمَةٍ بِمَا عَمِلَ عَلَى ظَهْرِهَا أَنْ تَقُولَ عَمِلَ كَذَا وَكَذَا يَوْمَ كَذَا وَكَذَا قَالَ فَهَذِهِ أَخْبَارُهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2429}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah (s.a.w) recited: That Day it will declare its information. And said: 'Do you know what its information is?' they said: 'Allah and His Messenger know best.' He said: 'Indeed its information is that it will testify against every servant, male and female, It will say that he did such and such, on such and such a day.' He said: 'With this it shall be ordered.'" [Abu 'Eisa said:] This Hadith is Hasan Gharib}}
\hadithdefcmd{tirmidhi}{2430}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَسْلَمَ الْعِجْلِيِّ، عَنْ بِشْرِ بْنِ شَغَافٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِي، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ مَا الصُّورُ قَالَ ‏ "‏ قَرْنٌ يُنْفَخُ فِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ عَنْ سُلَيْمَانَ التَّيْمِيِّ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِهِ ‏.‏\hadithno{2430}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin 'Amr bin Al-'As said:"A Bedouin came to the Prophet (S.a.w) and said: 'What is the Sur?' He said: 'A horn that will be blown into'" [Abu 'Eisa said:] This Hadith is Hasan Sahih. It has been reported by more than one narrator from Sulaimãn At-Taimi, and we do not know of it except as his narration}}
\hadithdefcmd{tirmidhi}{2431}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا خَالِدٌ أَبُو الْعَلاَءِ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ أَنْعَمُ وَصَاحِبُ الْقَرْنِ قَدِ الْتَقَمَ الْقَرْنَ وَاسْتَمَعَ الإِذْنَ مَتَى يُؤْمَرُ بِالنَّفْخِ فَيَنْفُخُ ‏"‏ ‏.‏ فَكَأَنَّ ذَلِكَ ثَقُلَ عَلَى أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُمْ ‏"‏ قُولُوا حَسْبُنَا اللَّهُ وَنِعْمَ الْوَكِيلُ عَلَى اللَّهِ تَوَكَّلْنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ هَذَا الْحَدِيثُ عَنْ عَطِيَّةَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2431}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated:"The Messenger of Allah (s.a.w) said: 'How can I be comfortable when the one with the horn is holding it to his lip, his ears listening for when he will be ordered to blow, so he can blow.' It was as if that was very hard upon the Companions of the Prophet (s.a.w), so he said to them: 'Say: "Allah is sufficent for us and what a good protector He is, and upon Allah we rely." [Abu' Eisa said:] This Hadith is Hasan. This Hadith has been reported through other routes from 'Atiyyah, from Abu Sa'eed [AlKhudri] from the Prophet SAW, similarly}}
\hadithdefcmd{tirmidhi}{2432}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ سَعْدٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ شِعَارُ الْمُؤْمِنِ عَلَى الصِّرَاطِ رَبِّ سَلِّمْ سَلِّمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ الْمُغِيرَةِ بْنِ شُعْبَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2432}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Mughirah bin Shu'bah narrated that The Messenger of Allah (s.a.w) said:"The sign of the believers upon the Sirat is: O lord, protect (us), protect (us).'" [Abü 'Eisa said:] This Hadith is Gharib [as a narration of AlMughirah bin Shu'bah] we do not know of it except through the narration of 'Abdur-Rahmãn bin Ishaq [and there is something on this topic from Abu Hurairah]}}
\hadithdefcmd{tirmidhi}{2433}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْهَاشِمِيُّ، حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، حَدَّثَنَا حَرْبُ بْنُ مَيْمُونٍ الأَنْصَارِيُّ أَبُو الْخَطَّابِ، حَدَّثَنَا النَّضْرُ بْنُ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم أَنْ يَشْفَعَ لِي يَوْمَ الْقِيَامَةِ فَقَالَ ‏"‏ أَنَا فَاعِلٌ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ فَأَيْنَ أَطْلُبُكَ قَالَ ‏"‏ اطْلُبْنِي أَوَّلَ مَا تَطْلُبُنِي عَلَى الصِّرَاطِ ‏"‏ ‏.‏ قَالَ قُلْتُ فَإِنْ لَمْ أَلْقَكَ عَلَى الصِّرَاطِ قَالَ ‏"‏ فَاطْلُبْنِي عِنْدَ الْمِيزَانِ ‏"‏ ‏.‏ قُلْتُ فَإِنْ لَمْ أَلْقَكَ عِنْدَ الْمِيزَانِ قَالَ ‏"‏ فَاطْلُبْنِي عِنْدَ الْحَوْضِ فَإِنِّي لاَ أُخْطِئُ هَذِهِ الثَّلاَثَ الْمَوَاطِنَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2433}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{An-Nadr bin Anas bin Malik narrated from his father who said:"I asked the Prophet (s.a.w) to intercede for me on the Day of Judgement. He said: 'I am the one to do so.'" [He said:] "I said: 'O Messenger of Allah! Then where shall I seek you?' He said: 'Seek me, the first time you should seek me is on the Sirat.'" [He said:] "I said: 'If I do not meet you upon the Sirat?' He said: 'Then seek me at the Mizan.' I said:'And if I do not meet you at the Mizan?' He said: 'Then seek me at the Hawd, for indeed I will not me missed at these three locations}}
\hadithdefcmd{tirmidhi}{2434}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا أَبُو حَيَّانَ التَّيْمِيُّ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلَحْمٍ فَرُفِعَ إِلَيْهِ الذِّرَاعُ فَأَكَلَهُ وَكَانَتْ تُعْجِبُهُ فَنَهَسَ مِنْهَا نَهْسَةً ثُمَّ قَالَ ‏ "‏ أَنَا سَيِّدُ النَّاسِ يَوْمَ الْقِيَامَةِ هَلْ تَدْرُونَ لِمَ ذَاكَ يَجْمَعُ اللَّهُ النَّاسَ الأَوَّلِينَ وَالآخِرِينَ فِي صَعِيدٍ وَاحِدٍ فَيُسْمِعُهُمُ الدَّاعِي وَيَنْفُذُهُمُ الْبَصَرُ وَتَدْنُو الشَّمْسُ مِنْهُمْ فَيَبْلُغُ النَّاسُ مِنَ الْغَمِّ وَالْكَرْبِ مَا لاَ يُطِيقُونَ وَلاَ يَحْتَمِلُونَ فَيَقُولُ النَّاسُ بَعْضُهُمْ لِبَعْضٍ أَلاَ تَرَوْنَ مَا قَدْ بَلَغَكُمْ أَلاَ تَنْظُرُونَ مَنْ يَشْفَعُ لَكُمْ إِلَى رَبِّكُمْ فَيَقُولُ النَّاسُ بَعْضُهُمْ لِبَعْضٍ عَلَيْكُمْ بِآدَمَ ‏.‏ فَيَأْتُونَ آدَمَ فَيَقُولُونَ أَنْتَ أَبُو الْبَشَرِ خَلَقَكَ اللَّهُ بِيَدِهِ وَنَفَخَ فِيكَ مِنْ رُوحِهِ وَأَمَرَ الْمَلاَئِكَةَ فَسَجَدُوا لَكَ اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى مَا نَحْنُ فِيهِ أَلاَ تَرَى مَا قَدْ بَلَغَنَا فَيَقُولُ لَهُمْ آدَمُ إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ وَإِنَّهُ قَدْ نَهَانِي عَنِ الشَّجَرَةِ فَعَصَيْتُ نَفْسِي نَفْسِي نَفْسِي اذْهَبُوا إِلَى غَيْرِي اذْهَبُوا إِلَى نُوحٍ ‏.‏ فَيَأْتُونَ نُوحًا فَيَقُولُونَ يَا نُوحُ أَنْتَ أَوَّلُ الرُّسُلِ إِلَى أَهْلِ الأَرْضِ وَقَدْ سَمَّاكَ اللَّهُ عَبْدًا شَكُورًا اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى مَا نَحْنُ فِيهِ أَلاَ تَرَى مَا قَدْ بَلَغَنَا فَيَقُولُ لَهُمْ نُوحٌ إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ وَإِنَّهُ قَدْ كَانَ لِي دَعْوَةٌ دَعَوْتُهَا عَلَى قَوْمِي نَفْسِي نَفْسِي نَفْسِي اذْهَبُوا إِلَى غَيْرِي اذْهَبُوا إِلَى إِبْرَاهِيمَ ‏.‏ فَيَأْتُونَ إِبْرَاهِيمَ فَيَقُولُونَ يَا إِبْرَاهِيمُ أَنْتَ نَبِيُّ اللَّهِ وَخَلِيلُهُ مِنْ أَهْلِ الأَرْضِ اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى مَا نَحْنُ فِيهِ فَيَقُولُ إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ وَإِنِّي قَدْ كَذَبْتُ ثَلاَثَ كَذَبَاتٍ فَذَكَرَهُنَّ أَبُو حَيَّانَ فِي الْحَدِيثِ نَفْسِي نَفْسِي نَفْسِي اذْهَبُوا إِلَى غَيْرِي اذْهَبُوا إِلَى مُوسَى ‏.‏ فَيَأْتُونَ مُوسَى فَيَقُولُونَ يَا مُوسَى أَنْتَ رَسُولُ اللَّهِ فَضَّلَكَ اللَّهُ بِرِسَالَتِهِ وَبِكَلاَمِهِ عَلَى الْبَشَرِ اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى مَا نَحْنُ فِيهِ فَيَقُولُ إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ وَإِنِّي قَدْ قَتَلْتُ نَفْسًا لَمْ أُومَرْ بِقَتْلِهَا نَفْسِي نَفْسِي نَفْسِي اذْهَبُوا إِلَى غَيْرِي اذْهَبُوا إِلَى عِيسَى ‏.‏ فَيَأْتُونَ عِيسَى فَيَقُولُونَ يَا عِيسَى أَنْتَ رَسُولُ اللَّهِ وَكَلِمَتُهُ أَلْقَاهَا إِلَى مَرْيَمَ وَرُوحٌ مِنْهُ وَكَلَّمْتَ النَّاسَ فِي الْمَهْدِ اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى مَا نَحْنُ فِيهِ فَيَقُولُ عِيسَى إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ وَلَمْ يَذْكُرْ ذَنْبًا نَفْسِي نَفْسِي نَفْسِي اذْهَبُوا إِلَى غَيْرِي اذْهَبُوا إِلَى مُحَمَّدٍ ‏.‏ قَالَ فَيَأْتُونَ مُحَمَّدًا فَيَقُولُونَ يَا مُحَمَّدُ أَنْتَ رَسُولُ اللَّهِ وَخَاتَمُ الأَنْبِيَاءِ وَقَدْ غُفِرَ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى مَا نَحْنُ فِيهِ فَأَنْطَلِقُ فَآتِي تَحْتَ الْعَرْشِ فَأَخِرُّ سَاجِدًا لِرَبِّي ثُمَّ يَفْتَحُ اللَّهُ عَلَىَّ مِنْ مَحَامِدِهِ وَحُسْنِ الثَّنَاءِ عَلَيْهِ شَيْئًا لَمْ يَفْتَحْهُ عَلَى أَحَدٍ قَبْلِي ثُمَّ يُقَالُ يَا مُحَمَّدُ ارْفَعْ رَأْسَكَ سَلْ تُعْطَهُ وَاشْفَعْ تُشَفَّعْ ‏.‏ فَأَرْفَعُ رَأْسِي فَأَقُولُ يَا رَبِّ أُمَّتِي يَا رَبِّ أُمَّتِي يَا رَبِّ أُمَّتِي ‏.‏ فَيَقُولُ يَا مُحَمَّدُ أَدْخِلْ مِنْ أُمَّتِكَ مَنْ لاَ حِسَابَ عَلَيْهِ مِنَ الْبَابِ الأَيْمَنِ مِنْ أَبْوَابِ الْجَنَّةِ وَهُمْ شُرَكَاءُ النَّاسِ فِيمَا سِوَى ذَلِكَ مِنَ الأَبْوَابِ ثُمَّ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّ مَا بَيْنَ الْمِصْرَاعَيْنِ مِنْ مَصَارِيعِ الْجَنَّةِ كَمَا بَيْنَ مَكَّةَ وَهَجَرَ وَكَمَا بَيْنَ مَكَّةَ وَبُصْرَى ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَأَنَسٍ وَعُقْبَةَ بْنِ عَامِرٍ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو حَيَّانَ التَّيْمِيُّ اسْمُهُ يَحْيَى بْنُ سَعِيدِ بْنِ حَيَّانَ كُوفِيٌّ وَهُوَ ثِقَةٌ وَأَبُو زُرْعَةَ بْنُ عَمْرِو بْنِ جَرِيرٍ اسْمُهُ هَرِمٌ ‏.‏\hadithno{2434}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:""Some meat was brought to the Prophet (s.a.w) and a foreleg was presented to him, and he used to like it, so he bit from it. Then he said: 'I will be the 'Leader' of the people on the Day of Resurrection. Do you know why that is? Allah will gather the people, the first and the last, on one level ground where they will (all) be able to hear a caller, and all of them will be visible, and the sun will be brought near such that the people will suffer distress and trouble that they cannot tolerate nor bear. Then some people will say: "Don't you see the state you have reached? Why don't you look for a person who can intercede for you with your Lord? " Some of them will say to others: " You should go to Adam." So they will go to Adam and say, "You are the father of all mankind, Allah created you with His Own Hands, and breathed into you from His spirit (which He creted for you) and ordered the angels to prostrate for you. Will you not intercede for us with your Lord? Don't you see what has happened to us? Don't you see the state we have reached?" On that Adam will reply, "Today my Lord has become angry such that He has never before been angry, and will never be thereafter. He forbade me (to eat from) the tree, but I disobeyed(Him), Myself! Myself! Myself! Go to somebody else; Go to Nuh." They will go to Nuh and say: "O Nuh! You are the first among the Messengers to the people of the earth, and Allah named you a thankful slave. Will you not intercede for us with your Lord? Don't you see what has happened to us? Don't you see the state we have reached?" Nuh will say to them : "Today my Lord has become angry as He has never before been angry, and will never be thereafter. I had been given one supplication, and I supplicated against my own people. Myself! Myself! Myself! Go to someone else! Go to Ibrahim." They will go to Ibrahim and say: "O Ibrahim! You are Allah's Prophet and His Khalil among the people of the earth, so intercede for us with your Lord, don't you see what hads happened to us?" He will say: "Today my Lord has become angry as He has never before been angry and will never be thereafter. Indeed I uttered three lies."- Abu Hayyyan (a narrator) mentioned them in his narration - " Myself! Myself! Myself! Go to someone else! Go to Musa." So they will go to Musa and say: "O Musa! You are the Messenger of Allah who Allah distinguished above the people with His Message and His Speech, intercede for us with your Lord. Don't you see what has happened to us?" So he will say "Today my Lord has become angry as He has never before been angry and will never be thereafter. Indeed I killed a person whom I was ordered not to kill. Myself! Myself! Myself! Go to someone else; Go to 'Eisa." They will go to 'Eisa and say: "O 'Eisa ! You are the Messenger of Allah and His Word which He placed into Mariam, and a Spirit from Him, and you spoke to the people in the cradle. Intercede for us with your Lord. Don't you see what has happened to us?" Then 'Eisa will say: "Today my Lord has become angry as He has never before been angry and will never be thereafter." He will not mention a sin, but will say: "Myself! Myself! Myself! Go to someone else! Go to Muhammad." He said: 'They will go to Muhammad(s.a.w) and they say: "O Muhammad! You are the Messenger of Allah and the last of the Prophets, and your past and future sins have been pardoned. Will you not intercede for us with your Lord, don't you see what has happened to us?" Then I will depart until I come to under the Throne to fall prostrating before my Lord. Then Allah will guide me to such praises and beautiful statements of glorification which He did not guide anyone to before me. Then He will say: "O Muhammad! Raise your head. Ask,so that you may be granted and intercede so that your intercession may be accepted." I will raise my head and say: "O Lord! My Ummah! O Lord! My Ummah! O Lord! My Ummah!" He will say: "O Muhammad! Let those of your Ummah who have no accounts enter the gate on the right among the gates of Paradise, and they shall share in the gates other than that with the people.'" Then he (s.a.w) said: 'By the One in Whose Hand is my soul! What is between every two gate-posts in Paradise is as what is between Makkah and Hajar, and what is between Makkah and Busra.'" Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2435}{حَدَّثَنَا الْعَبَّاسُ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ شَفَاعَتِي لأَهْلِ الْكَبَائِرِ مِنْ أُمَّتِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏\hadithno{2435}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas narrated that the Messenger of allah (s.a.w)said:"My intercession is for the people who committed the major sins in my Ummah." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2436}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، عَنْ مُحَمَّدِ بْنِ ثَابِتٍ الْبُنَانِيِّ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ شَفَاعَتِي لأَهْلِ الْكَبَائِرِ مِنْ أُمَّتِي ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ عَلِيٍّ فَقَالَ لِي جَابِرٌ يَا مُحَمَّدُ مَنْ لَمْ يَكُنْ مِنْ أَهْلِ الْكَبَائِرِ فَمَا لَهُ وَلِلشَّفَاعَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ يُسْتَغْرَبُ مِنْ حَدِيثِ جَعْفَرِ بْنِ مُحَمَّدٍ ‏.‏\hadithno{2436}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ja'far bin Muhammad narrated from his father, from Jabir bin 'Abdullah who said:"The Messenger of Allah (s.a.w) said: 'My intercession is for the people who comitted major sins in my Ummah.'" Muhammad bin 'Ali said: "Jabir said to me: 'O Muhammad! Whoever is not among the people of major sins, then there is no need in the intercession for him}}
\hadithdefcmd{tirmidhi}{2437}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ الأَلْهَانِيِّ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَعَدَنِي رَبِّي أَنْ يُدْخِلَ الْجَنَّةَ مِنْ أُمَّتِي سَبْعِينَ أَلْفًا لاَ حِسَابَ عَلَيْهِمْ وَلاَ عَذَابَ مَعَ كُلِّ أَلْفٍ سَبْعُونَ أَلْفًا وَثَلاَثُ حَثَيَاتٍ مِنْ حَثَيَاتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2437}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Umamah narrated the Messenger of Allah (s.a.w) said:"My Lord promised me that seventy thousand of my Ummah shall be admitted into Paradise without a reckoning against them nor any punishment. With every thousand, are seventy thousand and three measures from His measures}}
\hadithdefcmd{tirmidhi}{2438}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ كُنْتُ مَعَ رَهْطٍ بِإِيلِيَاءَ فَقَالَ رَجُلٌ مِنْهُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ يَدْخُلُ الْجَنَّةَ بِشَفَاعَةِ رَجُلٍ مِنْ أُمَّتِي أَكْثَرُ مِنْ بَنِي تَمِيمٍ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ سِوَاكَ قَالَ ‏"‏ سِوَاىَ ‏"‏ ‏.‏ فَلَمَّا قَامَ قُلْتُ مَنْ هَذَا قَالُوا هَذَا ابْنُ أَبِي الْجَذْعَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَابْنُ أَبِي الْجَذْعَاءِ هُوَ عَبْدُ اللَّهِ وَإِنَّمَا يُعْرَفُ لَهُ هَذَا الْحَدِيثُ الْوَاحِدُ ‏.‏\hadithno{2438}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Shaqiq narrated:" I was with a troop in Jerusalem, and a man among them said: 'I heard the Messenger of Allah (s.a.w) saying: "From the intersection of one man in my Ummah more (people) then Banu Tamim will be admitted into Paradise.' It was said: 'O Messenger of Allah! Someone other than you?' He said: 'Other than me.' So when he stood, I said: 'Who is this?' They said: 'This is Ibn Abi Al-Jadh'a}}
\hadithdefcmd{tirmidhi}{2439}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، مُحَمَّدُ بْنُ يَزِيدَ الْكُوفِيُّ حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، عَنْ جِسْرٍ أَبِي جَعْفَرٍ، عَنِ الْحَسَنِ الْبَصْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَشْفَعُ عُثْمَانُ بْنُ عَفَّانَ يَوْمَ الْقِيَامَةِ فِي مِثْلِ رَبِيعَةَ وَمُضَرَ ‏"‏ ‏.‏\hadithno{2439}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Al-Hasan Al-Basri said:"The Messenger of Allah (s.a.w) said: 'On the Day of Judgement, 'Uthman bin 'Affan will intercede for (an amount) the likes of Rabi'ah and Mudar}}
\hadithdefcmd{tirmidhi}{2440}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مِنْ أُمَّتِي مَنْ يَشْفَعُ لِلْفِئَامِ وَمِنْهُمْ مَنْ يَشْفَعُ لِلْقَبِيلَةِ وَمِنْهُمْ مَنْ يَشْفَعُ لِلْعُصْبَةِ وَمِنْهُمْ مَنْ يَشْفَعُ لِلرَّجُلِ حَتَّى يَدْخُلُوا الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2440}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated the Messenger of Allah (ﷺ) said:"Indeed in my Ummah are those who intercede for large groups of people, and among them (there are) who intercede for a tribe, and among them (there are) who intercede for a group, and among them (there are) who intercede for a man, until they are admitted to Paradise}}
\hadithdefcmd{tirmidhi}{2441}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتَانِي آتٍ مِنْ عِنْدِ رَبِّي فَخَيَّرَنِي بَيْنَ أَنْ يُدْخِلَ نِصْفَ أُمَّتِي الْجَنَّةَ وَبَيْنَ الشَّفَاعَةِ فَاخْتَرْتُ الشَّفَاعَةَ وَهِيَ لِمَنْ مَاتَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا ‏"‏ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي الْمَلِيحِ عَنْ رَجُلٍ آخَرَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ عَنْ عَوْفِ بْنِ مَالِكٍ وَفِي الْحَدِيثِ قِصَّةٌ طَوِيلَةٌ ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ عَوْفِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2441}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Al-Malih narrated from 'Awf bin Malik Al-Ashja'i who said:"The Messenger of Allah (s.a.w) said 'Someone came to me from my Lord to give me choice between the half of my Ummah being admitted into Paradise or intercession. So I chose the intercession, and it is for whoever dies and he did not associate anything with Allah."' Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2442}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا بِشْرُ بْنُ شُعَيْبِ بْنِ أَبِي حَمْزَةَ، حَدَّثَنِي أَبِي، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي حَوْضِي مِنَ الأَبَارِيقِ بِعَدَدِ نُجُومِ السَّمَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2442}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (s.a.w) said:"Indeed, at my Hawd there are drinking vessels as numerous as the stars in the heavens}}
\hadithdefcmd{tirmidhi}{2443}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ عَلِيِّ بْنِ نِيزَكَ الْبَغْدَادِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارٍ الدِّمَشْقِيُّ، حَدَّثَنَا سَعِيدُ بْنُ بَشِيرٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِكُلِّ نَبِيٍّ حَوْضًا وَإِنَّهُمْ يَتَبَاهَوْنَ أَيُّهُمْ أَكْثَرُ وَارِدَةً وَإِنِّي أَرْجُو أَنْ أَكُونَ أَكْثَرَهُمْ وَارِدَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى الأَشْعَثُ بْنُ عَبْدِ الْمَلِكِ هَذَا الْحَدِيثَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَلَمْ يَذْكُرْ فِيهِ عَنْ سَمُرَةَ وَهُوَ أَصَحُّ ‏.‏\hadithno{2443}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Samurah narrated the Messenger of Allah (s.a.w)said:"Indeed there is a Hawd for every Prophet, and indeed they compete to see which of them has the most arriving at it. Indeed I hope that mine will be the one with the most arrival}}
\hadithdefcmd{tirmidhi}{2444}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُهَاجِرِ، عَنِ الْعَبَّاسِ، عَنْ أَبِي سَلاَّمٍ الْحَبَشِيِّ، قَالَ بَعَثَ إِلَىَّ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ فَحُمِلْتُ عَلَى الْبَرِيدِ ‏.‏ قَالَ فَلَمَّا دَخَلَ عَلَيْهِ قَالَ يَا أَمِيرَ الْمُؤْمِنِينَ لَقَدْ شَقَّ عَلَى مَرْكَبِي الْبَرِيدُ ‏.‏ فَقَالَ يَا أَبَا سَلاَّمٍ مَا أَرَدْتُ أَنْ أَشُقَّ عَلَيْكَ وَلَكِنْ بَلَغَنِي عَنْكَ حَدِيثٌ تُحَدِّثُهُ عَنْ ثَوْبَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْحَوْضِ فَأَحْبَبْتُ أَنْ تُشَافِهَنِي بِهِ ‏.‏ قَالَ أَبُو سَلاَّمٍ حَدَّثَنِي ثَوْبَانُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ حَوْضِي مِنْ عَدَنَ إِلَى عَمَّانَ الْبَلْقَاءِ مَاؤُهُ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ وَأَحْلَى مِنَ الْعَسَلِ وَأَكَاوِيبُهُ عَدَدُ نُجُومِ السَّمَاءِ مَنْ شَرِبَ مِنْهُ شَرْبَةً لَمْ يَظْمَأْ بَعْدَهَا أَبَدًا أَوَّلُ النَّاسِ وُرُودًا عَلَيْهِ فُقَرَاءُ الْمُهَاجِرِينَ الشُّعْثُ رُءُوسًا الدُّنْسُ ثِيَابًا الَّذِينَ لاَ يَنْكِحُونَ الْمُتَنَعِّمَاتِ وَلاَ تُفْتَحُ لَهُمُ السُّدَدُ ‏"‏ ‏.‏ قَالَ عُمَرُ لَكِنِّي نَكَحْتُ الْمُتَنَعِّمَاتِ وَفُتِحَ لِيَ السُّدَدُ وَنَكَحْتُ فَاطِمَةَ بِنْتَ عَبْدِ الْمَلِكِ لاَ جَرَمَ أَنِّي لاَ أَغْسِلُ رَأْسِي حَتَّى يَشْعَثَ وَلاَ أَغْسِلُ ثَوْبِي الَّذِي يَلِي جَسَدِي حَتَّى يَتَّسِخَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ عَنْ ثَوْبَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَبُو سَلاَّمٍ الْحَبَشِيُّ اسْمُهُ مَمْطُورٌ وَهُوَ شَامِيٌّ ثِقَةٌ ‏.‏\hadithno{2444}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-'Abbas narrated from Abu Sallam Al-Habashi who said:"'Umar bin 'Abdul-'Aziz summoned me so I got a ride on a mule." [He said:] "When he entered upon him, he said: 'O Commander of the Believers! My riding mule was troublesome for me.' So he said: 'O Abu Sallam!I did not want to trouble you, but a Hadith which you narrated-from Thawban, from the Prophet (s.a.w) about the Hawd-was conveyed to me,and I wanted you to narrate it directly to me."'Abu Sallam said: "Thawban narrated to me from The Messenger of Allah (s.a.w) who said 'My Hawd (is as large as) from 'Adan to 'Amman of Al-Balqa', its water is whiter than milk and sweeter than honey. Its cups are as numerous as the stars, whoever drinks one drink from it, he will never be thirsty after that again. The first people to arrive at it are the poor among the Muhajirin with disheveled heads, dirty clothes, those whom the women of favor would not marry, nor would the doors be open for them.' 'Umar said: 'But I have married a women of favor and the doors are open for me. I married Fatimah bint 'Abdul-Malik. I shall certainly not wash my head until it is disheveled, nor wash my garment which touches my body until it becomes dirty." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2445}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَبْدِ الصَّمَدِ الْعَمِّيُّ عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا آنِيَةُ الْحَوْضِ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لآنِيَتُهُ أَكْثَرُ مِنْ عَدَدِ نُجُومِ السَّمَاءِ وَكَوَاكِبِهَا فِي لَيْلَةٍ مُظْلِمَةٍ مُصْحِيَةٍ مِنْ آنِيَةِ الْجَنَّةِ مَنْ شَرِبَ مِنْهَا شَرْبَةً لَمْ يَظْمَأْ آخِرَ مَا عَلَيْهِ عَرْضُهُ مِثْلُ طُولِهِ مَا بَيْنَ عَمَّانَ إِلَى أَيْلَةَ مَاؤُهُ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ وَأَحْلَى مِنَ الْعَسَلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي بَرْزَةَ الأَسْلَمِيِّ وَابْنِ عُمَرَ وَحَارِثَةَ بْنِ وَهْبٍ وَالْمُسْتَوْرِدِ بْنِ شَدَّادٍ ‏.‏ - وَرُوِيَ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ حَوْضِي كَمَا بَيْنَ الْكُوفَةِ إِلَى الْحَجَرِ الأَسْوَدِ ‏"‏ ‏.‏\hadithno{2445}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Dharr narrated:"I said: 'O Messenger of Allah! What about the vessels of the Hawd?' He said: 'By the one in Whose Hand is my soul! Its vessels number more than the stars of the heavens and the planets on a clear dark night. (They are) among the vessels of Paradise, whoever drinks from them, he will never be thirsty again. Its longest breadth is the same as its length, like that which is between 'Amman to Aylah, its water is whiter than milk and sweeter than honey.'" Another chain reports a similar narration. It has been reported from Ibn 'Umar that the Prophet SAW said: "My Hawd (covers a distance) like what is between Kufah to the Black Stone}}
\hadithdefcmd{tirmidhi}{2446}{حَدَّثَنَا أَبُو حَصِينٍ عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ يُونُسَ، كُوفِيٌّ حَدَّثَنَا عَبْثَرُ بْنُ الْقَاسِمِ، حَدَّثَنَا حُصَيْنٌ، هُوَ ابْنُ عَبْدِ الرَّحْمَنِ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا أُسْرِيَ بِالنَّبِيِّ صلى الله عليه وسلم جَعَلَ يَمُرُّ بِالنَّبِيِّ وَالنَّبِيَّيْنِ وَمَعَهُمُ الْقَوْمُ وَالنَّبِيِّ وَالنَّبِيَّيْنِ وَمَعَهُمُ الرَّهْطُ وَالنَّبِيِّ وَالنَّبِيِّينَ وَلَيْسَ مَعَهُمْ أَحَدٌ حَتَّى مَرَّ بِسَوَادٍ عَظِيمٍ فَقُلْتُ مَنْ هَذَا قِيلَ مُوسَى وَقَوْمُهُ وَلَكِنِ ارْفَعْ رَأْسَكَ فَانْظُرْ ‏.‏ قَالَ فَإِذَا سَوَادٌ عَظِيمٌ قَدْ سَدَّ الأُفُقَ مِنْ ذَا الْجَانِبِ وَمِنْ ذَا الْجَانِبِ فَقِيلَ هَؤُلاَءِ أُمَّتُكَ وَسِوَى هَؤُلاَءِ مِنْ أُمَّتِكَ سَبْعُونَ أَلْفًا يَدْخُلُونَ الْجَنَّةَ بِغَيْرِ حِسَابٍ ‏.‏ فَدَخَلَ وَلَمْ يَسْأَلُوهُ وَلَمْ يُفَسِّرْ لَهُمْ فَقَالُوا نَحْنُ هُمْ ‏.‏ وَقَالَ قَائِلُونَ هُمْ أَبْنَاؤُنَا الَّذِينَ وُلِدُوا عَلَى الْفِطْرَةِ وَالإِسْلاَمِ ‏.‏ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ هُمُ الَّذِينَ لاَ يَكْتَوُونَ وَلاَ يَسْتَرْقُونَ وَلاَ يَتَطَيَّرُونَ وَعَلَى رَبِّهِمْ يَتَوَكَّلُونَ ‏"‏ ‏.‏ فَقَامَ عُكَّاشَةُ بْنُ مِحْصَنٍ فَقَالَ أَنَا مِنْهُمْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ ثُمَّ قَامَ آخَرُ فَقَالَ أَنَا مِنْهُمْ فَقَالَ ‏"‏ سَبَقَكَ بِهَا عُكَّاشَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{2446}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abbas narrated :"When the Prophet (s.a.w) was taken for the Night Journey, he passed by a Prophet, and, some Prophets and with them were some people, and a Prophet, and some Prophets and with them was a group of people, and a Prophet, and some Prophets and with them there was no one. Until he passed by a large multitude. (The Prophet (s.a.w)said: ) I said: 'Who is this?' It was said: 'Musa and his people. But raise your head and look.' There was a large multitude that covered the horizon, from one side to the other. It was said: 'These people are your Ummah, and there are seventy thousand besides these from your Ummah that shall enter Paradise without a reckoning.' So he went inside, and they did not question him, and he gave no explanation to them. (Some of them) said: 'We are them.' Others said: 'They are the children who were born upon the Fitrah and Islam.' So the Prophet (s.a.w) came out and said: 'They are those who do not get themselves cauterized, nor seek Ruqyah, nor read omens, and upon their Lord they rely.' So 'Ukashah bin Mihsan stood and said: 'Am I among them O Messenger of Allah?' He said: 'Yes.' Then another one stood up and said: 'Am I among them?' So he said "Ukashah has preceded you to it.'" Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2447}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا زِيَادُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا أَعْرِفُ شَيْئًا مِمَّا كُنَّا عَلَيْهِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَقُلْتُ أَيْنَ الصَّلاَةُ قَالَ أَوَلَمْ تَصْنَعُوا فِي صَلاَتِكُمْ مَا قَدْ عَلِمْتُمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبِي عِمْرَانَ الْجَوْنِيِّ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ ‏.‏\hadithno{2447}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu 'Imaran Al-Jawni narrated :"From Anas bin Malik who said : 'I do not recognize anything (today) from what we were upon during the time of The Messenger of Allah (s.a.w).' So I said : 'What about the Salat?' He said: 'Have you (people) not done what you know (you have done)?'" Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2448}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الأَزْدِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هَاشِمٌ، وَهُوَ ابْنُ سَعِيدٍ الْكُوفِيُّ حَدَّثَنِي زَيْدٌ الْخَثْعَمِيُّ، عَنْ أَسْمَاءَ بِنْتِ عُمَيْسٍ الْخَثْعَمِيَّةِ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بِئْسَ الْعَبْدُ عَبْدٌ تَخَيَّلَ وَاخْتَالَ وَنَسِيَ الْكَبِيرَ الْمُتَعَالِ بِئْسَ الْعَبْدُ عَبْدٌ تَجَبَّرَ وَاعْتَدَى وَنَسِيَ الْجَبَّارَ الأَعْلَى بِئْسَ الْعَبْدُ عَبْدٌ سَهَا وَلَهَا وَنَسِيَ الْمَقَابِرَ وَالْبِلَى بِئْسَ الْعَبْدُ عَبْدٌ عَتَا وَطَغَى وَنَسِيَ الْمُبْتَدَا وَالْمُنْتَهَى بِئْسَ الْعَبْدُ عَبْدٌ يَخْتِلُ الدُّنْيَا بِالدِّينِ بِئْسَ الْعَبْدُ عَبْدٌ يَخْتِلُ الدِّينَ بِالشُّبُهَاتِ بِئْسَ الْعَبْدُ عَبْدٌ طَمَعٌ يَقُودُهُ بِئْسَ الْعَبْدُ عَبْدٌ هَوًى يُضِلُّهُ بِئْسَ الْعَبْدُ عَبْدٌ رَغَبٌ يُذِلُّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏\hadithno{2448}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Asma bint 'Umais Al-Khath'amiyyah narrated that The Messenger of Allah (s.a.w) said:"What an evil servant is the one who fancies himself and becomes vain forgetting the Most Great, the Most High. What an evil servant is the one who forces and behaves hostility, forgetting the Compeller, the Most High. What an evil servant is the one who is heedless and diverted, forgetting about the graves and the trials. What an evil servant is the one who is violent and tyrannical, forgetting his beginnings or his end. What an evil servant is the one who seeks the world through the religion. What an evil servant is the one who seeks the religion through his desires. What an evil servant is the one who puts all hope in his own zeal. What an evil servant is the worshipper who is misled by his desire. What an evil servant is the one whose aspirations humiliate him}}
\hadithdefcmd{tirmidhi}{2449}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُؤَدِّبُ، حَدَّثَنَا عَمَّارُ بْنُ مُحَمَّدِ ابْنُ أُخْتِ، سُفْيَانَ الثَّوْرِيِّ حَدَّثَنَا أَبُو الْجَارُودِ الأَعْمَى، وَاسْمُهُ، زِيَادُ بْنُ الْمُنْذِرِ الْهَمْدَانِيُّ عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا مُؤْمِنٍ أَطْعَمَ مُؤْمِنًا عَلَى جُوعٍ أَطْعَمَهُ اللَّهُ يَوْمَ الْقِيَامَةِ مِنْ ثِمَارِ الْجَنَّةِ وَأَيُّمَا مُؤْمِنٍ سَقَى مُؤْمِنًا عَلَى ظَمَإٍ سَقَاهُ اللَّهُ يَوْمَ الْقِيَامَةِ مِنَ الرَّحِيقِ الْمَخْتُومِ وَأَيُّمَا مُؤْمِنٍ كَسَا مُؤْمِنًا عَلَى عُرْىٍ كَسَاهُ اللَّهُ مِنْ خُضْرِ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَقَدْ رُوِيَ هَذَا عَنْ عَطِيَّةَ عَنْ أَبِي سَعِيدٍ مَوْقُوفٌ وَهُوَ أَصَحُّ عِنْدَنَا وَأَشْبَهُ ‏.‏\hadithno{2449}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Atiyyah Al-'Awfi narrated from Abu Sa'eed Al-Khudri,that The Messenger of Allah (s.a.w) said:"Whichever believer feeds a hungry believer , Allah feeds him from the fruits of Paradise on the Day of Resurrection. Whichever believer gives drink to a thirsty believer, Allah gives him to drink from the 'sealed nectar' on the Day of Resurrection. Whichever believer clothes a naked believer, Allah clothes him from the green garments of Paradise}}
\hadithdefcmd{tirmidhi}{2450}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي النَّضْرِ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا أَبُو عَقِيلٍ الثَّقَفِيُّ، حَدَّثَنَا أَبُو فَرْوَةَ، يَزِيدُ بْنُ سِنَانٍ التَّمِيمِيُّ حَدَّثَنِي بُكَيْرُ بْنُ فَيْرُوزَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ خَافَ أَدْلَجَ وَمَنْ أَدْلَجَ بَلَغَ الْمَنْزِلَ أَلاَ إِنَّ سِلْعَةَ اللَّهِ غَالِيَةٌ أَلاَ إِنَّ سِلْعَةَ اللَّهِ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي النَّضْرِ ‏.‏\hadithno{2450}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that The Messenger of Allah (s.a.w) said:"Whoever fears traveling at night - and whoever travels at night reaches his destination - Allah provides him with the most precious of goods, and indeed Allah's goods are but Paradise}}
\hadithdefcmd{tirmidhi}{2451}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي النَّضْرِ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا أَبُو عَقِيلٍ الثَّقَفِيُّ عَبْدُ اللَّهِ بْنُ عَقِيلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ، وَعَطِيَّةُ بْنُ قَيْسٍ، عَنْ عَطِيَّةَ السَّعْدِيِّ، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَبْلُغُ الْعَبْدُ أَنْ يَكُونَ مِنَ الْمُتَّقِينَ حَتَّى يَدَعَ مَا لاَ بَأْسَ بِهِ حَذَرًا لِمَا بِهِ الْبَأْسُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2451}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Rabi'ah bin Yazid and 'Atiyyah bin Qais narrated from 'Atiyyah As-Sa'di - and he was one of the Companions of the Prophet (ﷺ) - that the Messenger of Allah (ﷺ) said:"The servant shall not reach the state of being among the Muttaqin until he leaves what there is no harm in out of caution for its harm}}
\hadithdefcmd{tirmidhi}{2452}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ قَتَادَةَ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ حَنْظَلَةَ الأُسَيْدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّكُمْ تَكُونُونَ كَمَا تَكُونُونَ عِنْدِي لأَظَلَّتْكُمُ الْمَلاَئِكَةُ بِأَجْنِحَتِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ حَنْظَلَةَ الأُسَيْدِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2452}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Hanzalah Al-Usaiyyidi narrated that the Messenger of Allah (s.a.w) said:"If you would (always) be as you are with me, then the angels would shade you with their wings." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2453}{حَدَّثَنَا يُوسُفُ بْنُ سَلْمَانَ أَبُو عُمَرَ الْبَصْرِيُّ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ لِكُلِّ شَيْءٍ شِرَّةً وَلِكُلِّ شِرَّةٍ فَتْرَةً فَإِنْ كَانَ صَاحِبُهَا سَدَّدَ وَقَارَبَ فَارْجُوهُ وَإِنْ أُشِيرَ إِلَيْهِ بِالأَصَابِعِ فَلاَ تَعُدُّوهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ - وَقَدْ رُوِيَ عَنْ أَنَسِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ بِحَسْبِ امْرِئٍ مِنَ الشَّرِّ أَنْ يُشَارَ إِلَيْهِ بِالأَصَابِعِ فِي دِينٍ أَوْ دُنْيَا إِلاَّ مَنْ عَصَمَهُ اللَّهُ ‏"‏ ‏.‏\hadithno{2453}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"Indeed for everything there is a zeal, and for every zeal there is a slackening. So if its practitioner behaves properly,and is moderate, then hope for him (for his success). But if the fingers are pointed to him, then do not count him (among the worthy)." It has been related from Anas bin Malik that the Prophet SAW said: "It is sufficient evil for a man that fingers be raised against him, regarding religion or worldly matters, except for one whom Allah has protected}}
\hadithdefcmd{tirmidhi}{2454}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِيهِ، عَنْ أَبِي يَعْلَى، عَنِ الرَّبِيعِ بْنِ خُثَيْمٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ خَطَّ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم خَطًّا مُرَبَّعًا وَخَطَّ فِي وَسَطِ الْخَطِّ خَطًّا وَخَطَّ خَارِجًا مِنَ الْخَطِّ خَطًّا وَحَوْلَ الَّذِي فِي الْوَسَطِ خُطُوطًا فَقَالَ ‏ "‏ هَذَا ابْنُ آدَمَ وَهَذَا أَجَلُهُ مُحِيطٌ بِهِ وَهَذَا الَّذِي فِي الْوَسَطِ الإِنْسَانُ وَهَذِهِ الْخُطُوطُ عُرُوضُهُ إِنْ نَجَا مِنْ هَذَا يَنْهَشُهُ هَذَا وَالْخَطُّ الْخَارِجُ الأَمَلُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2454}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdullah bin Mas'ud narrated "The Messenger of Allah (s.a.w) drew a square line (on the ground) forus, and in the middle of the (square) line he drew another line, and he drew another line going out of the (square) line.Around the one that was in the middle, he drew (various) lines. Then he said:'This is the son of Adam, and this is his life-span encircling him, and this one in the middle in the person, and these lines are his obstacles, if he escapes this one, this one ensnares him, and the line extending outside is his hope}}
\hadithdefcmd{tirmidhi}{2455}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَهْرَمُ ابْنُ آدَمَ وَيَشِبُّ مِنْهُ اثْنَانِ الْحِرْصُ عَلَى الْمَالِ وَالْحِرْصُ عَلَى الْعُمُرِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2455}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (s.a.w)said:"The son of Adam grows old. But two things keep him young: Desire for life and desire for wealth}}
\hadithdefcmd{tirmidhi}{2456}{حَدَّثَنَا أَبُو هُرَيْرَةَ، مُحَمَّدُ بْنُ فِرَاسٍ الْبَصْرِيُّ حَدَّثَنَا أَبُو قُتَيْبَةَ، سَلْمُ بْنُ قُتَيْبَةَ حَدَّثَنَا أَبُو الْعَوَّامِ، وَهُوَ عِمْرَانُ الْقَطَّانُ عَنْ قَتَادَةَ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُثَلَ ابْنِ آدَمَ وَإِلَى جَنْبِهِ تِسْعَةٌ وَتِسْعُونَ مَنِيَّةً إِنْ أَخْطَأَتْهُ الْمَنَايَا وَقَعَ فِي الْهَرَمِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2456}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Mutarrif bin 'Abdullah bin Ash-Shikh-khir narrated from his father from the Prophet(s.a.w) who said:"The case of the son of Adam is such that he is surrounded by ninety-nine calamities, if the calamities miss him, he falls into decrepitude}}
\hadithdefcmd{tirmidhi}{2457}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا قَبِيصَةُ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الطُّفَيْلِ بْنِ أُبَىِّ بْنِ كَعْبٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ذَهَبَ ثُلُثَا اللَّيْلِ قَامَ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ اذْكُرُوا اللَّهَ اذْكُرُوا اللَّهَ جَاءَتِ الرَّاجِفَةُ تَتْبَعُهَا الرَّادِفَةُ جَاءَ الْمَوْتُ بِمَا فِيهِ جَاءَ الْمَوْتُ بِمَا فِيهِ ‏"‏ ‏.‏ قَالَ أُبَىٌّ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُكْثِرُ الصَّلاَةَ عَلَيْكَ فَكَمْ أَجْعَلُ لَكَ مِنْ صَلاَتِي فَقَالَ ‏"‏ مَا شِئْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ الرُّبُعَ ‏.‏ قَالَ ‏"‏ مَا شِئْتَ فَإِنْ زِدْتَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قُلْتُ النِّصْفَ ‏.‏ قَالَ ‏"‏ مَا شِئْتَ فَإِنْ زِدْتَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ فَالثُّلُثَيْنِ ‏.‏ قَالَ ‏"‏ مَا شِئْتَ فَإِنْ زِدْتَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قُلْتُ أَجْعَلُ لَكَ صَلاَتِي كُلَّهَا ‏.‏ قَالَ ‏"‏ إِذًا تُكْفَى هَمَّكَ وَيُغْفَرُ لَكَ ذَنْبُكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2457}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{At-Tufail bin Ubayy bin Ka'b narrated from his father who said:"When a third of the night had passed, the Messenger of Allah(s.a.w) stood and said: 'O you people! Remember Allah! Remember Allah! The Rajifah is coming, followed by the Radifah, death and what it brings is coming, death and what it brings is coming!'" Ubayy said: "I said: 'O Messenger of Allah! Indeed I say very much Salat for you. How much of my Salat should I make for you?' He said: 'As you wish.'" [He said:] "I said: 'A fourth?' He said: 'As you wish. But if you add more it would be better for you.' I said: 'Then half?' He said: 'As you wish. And if you add more it would be better [for you].'" [He said:] "I said: 'Then two-thirds? 'He said: 'As you wish, but if you add more it would be better for you.' I said: 'Should I make all of my Salat for you?' He said: 'Then your problems would be solved and your sins would be forgiven}}
\hadithdefcmd{tirmidhi}{2458}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ أَبَانَ بْنِ إِسْحَاقَ، عَنِ الصَّبَّاحِ بْنِ مُحَمَّدٍ، عَنْ مُرَّةَ الْهَمْدَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْتَحْيُوا مِنَ اللَّهِ حَقَّ الْحَيَاءِ ‏"‏ ‏.‏ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّا لَنَسْتَحْيِي وَالْحَمْدُ لِلَّهِ ‏.‏ قَالَ ‏"‏ لَيْسَ ذَاكَ وَلَكِنَّ الاِسْتِحْيَاءَ مِنَ اللَّهِ حَقَّ الْحَيَاءِ أَنْ تَحْفَظَ الرَّأْسَ وَمَا وَعَى وَتَحْفَظَ الْبَطْنَ وَمَا حَوَى وَتَتَذَكَّرَ الْمَوْتَ وَالْبِلَى وَمَنْ أَرَادَ الآخِرَةَ تَرَكَ زِينَةَ الدُّنْيَا فَمَنْ فَعَلَ ذَلِكَ فَقَدِ اسْتَحْيَا مِنَ اللَّهِ حَقَّ الْحَيَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبَانَ بْنِ إِسْحَاقَ عَنِ الصَّبَّاحِ بْنِ مُحَمَّدٍ ‏.‏\hadithno{2458}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated that the Messenger of Allah (s.a.w) said:" Have Haya' for Allah as is His due." [He said:] We said: "O Prophet of Allah! We have Haya', and all praise is due to Allah." He said: "Not that, but having the Haya' for Allah which He is due is to protect the head and what it contains and to protect the insides and what it includes, and to remember death and the trial, and whoever intends the Hereafter, he leaves the adornments of the world. So whoever does that, then he has indeed fulfilled Haya', meaning the Haya' which Allah is due}}
\hadithdefcmd{tirmidhi}{2459}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مَرْيَمَ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مَرْيَمَ، عَنْ ضَمْرَةَ بْنِ حَبِيبٍ، عَنْ شَدَّادِ بْنِ أَوْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْكَيِّسُ مَنْ دَانَ نَفْسَهُ وَعَمِلَ لِمَا بَعْدَ الْمَوْتِ وَالْعَاجِزُ مَنْ أَتْبَعَ نَفْسَهُ هَوَاهَا وَتَمَنَّى عَلَى اللَّهِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ قَالَ وَمَعْنَى قَوْلِهِ ‏"‏ مَنْ دَانَ نَفْسَهُ ‏"‏ ‏.‏ يَقُولُ حَاسَبَ نَفْسَهُ فِي الدُّنْيَا قَبْلَ أَنْ يُحَاسَبَ يَوْمَ الْقِيَامَةِ ‏.‏ وَيُرْوَى عَنْ عُمَرَ بْنِ الْخَطَّابِ قَالَ حَاسِبُوا أَنْفُسَكُمْ قَبْلَ أَنْ تُحَاسَبُوا وَتَزَيَّنُوا لِلْعَرْضِ الأَكْبَرِ وَإِنَّمَا يَخِفُّ الْحِسَابُ يَوْمَ الْقِيَامَةِ عَلَى مَنْ حَاسَبَ نَفْسَهُ فِي الدُّنْيَا ‏.‏ وَيُرْوَى عَنْ مَيْمُونِ بْنِ مِهْرَانَ قَالَ لاَ يَكُونُ الْعَبْدُ تَقِيًّا حَتَّى يُحَاسِبَ نَفْسَهُ كَمَا يُحَاسِبُ شَرِيكَهُ مِنْ أَيْنَ مَطْعَمُهُ وَمَلْبَسُهُ ‏.‏\hadithno{2459}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Shaddad bin Aws narrated that the Prophet (s.a.w) said:"The clever person ids the one who subjugates his soul, and works for what is after death. And the incapable is the one who follows his desires and merely hopes in Allah." [He said:] The meaning of his saying: "Who subjugates his soul", is to say the one who reckons with his soul in the world, before he is reckoned with, on the Day of Judgement. It has been related that 'Umar bin Al-Khattäb said: "Reckon with yourselves before you are reckoned with, and prepare for the Greatest Inquisition. The reckoning of the Day of Judgement is only light for the one who reckoned with himself in the world." And, it has been related that Maimun bin Mihran said: "The slave (of Allah) will not be a Taqi until he has reckoned himself, just as he would account for where his business partner got his food and clothing}}
\hadithdefcmd{tirmidhi}{2460}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنُ مَدُّويَهْ التِّرْمِذِيُّ، حَدَّثَنَا الْقَاسِمُ بْنُ الْحَكَمِ الْعُرَنِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ الْوَلِيدِ الْوَصَّافِيُّ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُصَلاَّهُ فَرَأَى نَاسًا كَأَنَّهُمْ يَكْتَشِرُونَ قَالَ ‏"‏ أَمَا إِنَّكُمْ لَوْ أَكْثَرْتُمْ ذِكْرَ هَاذِمِ اللَّذَّاتِ لَشَغَلَكُمْ عَمَّا أَرَى فَأَكْثِرُوا مِنْ ذِكْرِ هَاذِمِ اللَّذَّاتِ الْمَوْتِ فَإِنَّهُ لَمْ يَأْتِ عَلَى الْقَبْرِ يَوْمٌ إِلاَّ تَكَلَّمَ فِيهِ فَيَقُولُ أَنَا بَيْتُ الْغُرْبَةِ وَأَنَا بَيْتُ الْوَحْدَةِ وَأَنَا بَيْتُ التُّرَابِ وَأَنَا بَيْتُ الدُّودِ ‏.‏ فَإِذَا دُفِنَ الْعَبْدُ الْمُؤْمِنُ قَالَ لَهُ الْقَبْرُ مَرْحَبًا وَأَهْلاً أَمَا إِنْ كُنْتَ لأَحَبَّ مَنْ يَمْشِي عَلَى ظَهْرِي إِلَىَّ فَإِذْ وُلِّيتُكَ الْيَوْمَ وَصِرْتَ إِلَىَّ فَسَتَرَى صَنِيعِي بِكَ ‏.‏ قَالَ فَيَتَّسِعُ لَهُ مَدَّ بَصَرِهِ وَيُفْتَحُ لَهُ بَابٌ إِلَى الْجَنَّةِ ‏.‏ وَإِذَا دُفِنَ الْعَبْدُ الْفَاجِرُ أَوِ الْكَافِرُ قَالَ لَهُ الْقَبْرُ لاَ مَرْحَبًا وَلاَ أَهْلاً أَمَا إِنْ كُنْتَ لأَبْغَضَ مَنْ يَمْشِي عَلَى ظَهْرِي إِلَىَّ فَإِذْ وُلِّيتُكَ الْيَوْمَ وَصِرْتَ إِلَىَّ فَسَتَرَى صَنِيعِي بِكَ ‏.‏ قَالَ فَيَلْتَئِمُ عَلَيْهِ حَتَّى تَلْتَقِيَ عَلَيْهِ وَتَخْتَلِفَ أَضْلاَعُهُ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَصَابِعِهِ فَأَدْخَلَ بَعْضَهَا فِي جَوْفِ بَعْضٍ قَالَ ‏"‏ وَيُقَيِّضُ اللَّهُ لَهُ سَبْعِينَ تِنِّينًا لَوْ أَنَّ وَاحِدًا مِنْهَا نَفَخَ فِي الأَرْضِ مَا أَنْبَتَتْ شَيْئًا مَا بَقِيَتِ الدُّنْيَا فَيَنْهَشْنَهُ وَيَخْدِشْنَهُ حَتَّى يُفْضَى بِهِ إِلَى الْحِسَابِ ‏"‏ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا الْقَبْرُ رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ أَوْ حُفْرَةٌ مِنْ حُفَرِ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2460}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated:" The Messenger of Allah (s.a.w) entered his Musalla and saw the people who looked as if they were smiling. So he said: 'Indeed, if you were to increase in remembrance of the severer of pleasures, then you would find yourselves too busy for what I see. So increase in remembrance of death, the severer of pleasures. For indeed there is no day that comes upon the grave except that it speaks, saying: "I am thee house of the estranged, I am the house of the solitude, I am the house of dust, and I am the house of the worm-eaten." When the believing worshipper is buried, the grave says to him: "Welcome, make yourself comfortable. Indeed, to me, you are the most beloved of those who walked upon me. Since you have been entrusted to me and delivered to me today, you shall see what I have arranged for you." It will then widen for him so that his sight extends, and the door to Paradise is opened for him. And when the wicked worshipper or the disbeliever is buried , the grave says to him: "You are not welcome, do not get comfortable. Indeed, to me, you are the most hated of those who walked upon me. Since you have been entrusted to me and delivered to me today, you shall see what I have arranged for you.'" He said: 'It will begin closing in on him(squeezing him) until his ribs are crushing each other.'" He said: " The Messenger of Allah (s.a.w) clasped some of his fingers between others and said: 'Seventy giant serpents will constrict him, if even one of them were to hiss on the earth, nothing upon it would grow as long as it remained. They will chew on him and bite him until he is brought to the Reckoning.'" He said: " The Messenger of Allah (s.a.w) said: 'The grave is but a garden from the gardens of Paradise, or a pit from the pits of the Fire}}
\hadithdefcmd{tirmidhi}{2461}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَخْبَرَنِي عُمَرُ بْنُ الْخَطَّابِ، قَالَ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا هُوَ مُتَّكِئٌ عَلَى رَمْلِ حَصِيرٍ فَرَأَيْتُ أَثَرَهُ فِي جَنْبِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَفِي الْحَدِيثِ قِصَّةٌ طَوِيلَةٌ ‏.‏\hadithno{2461}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abbas narrated:"'Umar bin Al-Khattab informed me, saying: 'I entered upon the Messenger of Allah (s.a.w) and saw him reclining upon a mat woven from fibers, and I could see the impressions it left upon his side}}
\hadithdefcmd{tirmidhi}{2462}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، وَيُونُسَ، عَنِ الزُّهْرِيِّ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، أَخْبَرَهُ أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ أَخْبَرَهُ أَنَّ عَمْرَو بْنَ عَوْفٍ وَهُوَ حَلِيفُ بَنِي عَامِرِ بْنِ لُؤَىٍّ وَكَانَ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم - أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ فَقَدِمَ بِمَالٍ مِنَ الْبَحْرَيْنِ وَسَمِعَتِ الأَنْصَارُ بِقُدُومِ أَبِي عُبَيْدَةَ فَوَافَوْا صَلاَةَ الْفَجْرِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم انْصَرَفَ فَتَعَرَّضُوا لَهُ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ رَآهُمْ ثُمَّ قَالَ ‏"‏ أَظُنُّكُمْ سَمِعْتُمْ أَنَّ أَبَا عُبَيْدَةَ قَدِمَ بِشَيْءٍ ‏"‏ ‏.‏ قَالُوا أَجَلْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَأَبْشِرُوا وَأَمِّلُوا مَا يَسُرُّكُمْ فَوَاللَّهِ مَا الْفَقْرَ أَخْشَى عَلَيْكُمْ وَلَكِنِّي أَخْشَى أَنْ تُبْسَطَ الدُّنْيَا عَلَيْكُمْ كَمَا بُسِطَتْ عَلَى مَنْ قَبْلَكُمْ فَتَنَافَسُوهَا كَمَا تَنَافَسُوهَا فَتُهْلِكَكُمْ كَمَا أَهْلَكَتْهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2462}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Mustawrad bin Makhramah narrated that 'Amir bin 'Awf informed him- and he was an ally of Banu 'Amr bin Lu'ay who had participated with The Messenger of Allah (s.a.w) at(the battle of ) Badr, he said:"The Messenger of Allah (s.a.w) had dispatched Abu 'Ubaidah bin Al-Jarrah, so he arrived with the wealth from Al-Bahrain. When the Ansar had heard of the arrival of Abu 'Ubaidah they were attending Salat Al-Fajr. So the the Messenger of Allah (s.a.w) performed the Salat and when he finished, they assembled before him. The Messenger of Allah (s.a.w) smiled when he saw them, then he said: 'I think that you heard that Abu 'Ubaidah has arrived with something?' They said: 'Yes O Messenger of Allah! 'He said: 'Then receive good news, and hope for what will please you. By Allah! It is not poverty that I fear for you, but what I fear for you is that the world will be presented for you just as it was presented for those before you,then you will compete for it, just as they competed for it, and it will destroy you, just as it destroyed them}}
\hadithdefcmd{tirmidhi}{2463}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَابْنِ الْمُسَيَّبِ، أَنَّ حَكِيمَ بْنَ حِزَامٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ قَالَ ‏ "‏ يَا حَكِيمُ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ فَمَنْ أَخَذَهُ بِسَخَاوَةِ نَفْسٍ بُورِكَ لَهُ فِيهِ وَمَنْ أَخَذَهُ بِإِشْرَافِ نَفْسٍ لَمْ يُبَارَكْ لَهُ فِيهِ وَكَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏ ‏.‏ فَقَالَ حَكِيمٌ فَقُلْتُ يَا رَسُولَ اللَّهِ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ أَرْزَأُ أَحَدًا بَعْدَكَ شَيْئًا حَتَّى أُفَارِقَ الدُّنْيَا ‏.‏ فَكَانَ أَبُو بَكْرٍ يَدْعُو حَكِيمًا إِلَى الْعَطَاءِ فَيَأْبَى أَنْ يَقْبَلَهُ ثُمَّ إِنَّ عُمَرَ دَعَاهُ لِيُعْطِيَهُ فَأَبَى أَنْ يَقْبَلَ مِنْهُ شَيْئًا فَقَالَ عُمَرُ إِنِّي أُشْهِدُكُمْ يَا مَعْشَرَ الْمُسْلِمِينَ عَلَى حَكِيمٍ أَنِّي أَعْرِضُ عَلَيْهِ حَقَّهُ مِنْ هَذَا الْفَىْءِ فَيَأْبَى أَنْ يَأْخُذَهُ ‏.‏ فَلَمْ يَرْزَأْ حَكِيمٌ أَحَدًا مِنَ النَّاسِ شَيْئًا بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى تُوُفِّيَ ‏.‏ قَالَ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2463}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Urwah bin Az-Zubair and Ibn Musayyab narrated that Hakim bin Hizam said:"I (once) asked the Messenger of Allah (s.a.w) (for something) and he gave it to me. Then I asked him (again) and he gave it to me. Then I asked him (again) and he gave it to me. Then I asked him (again), so he gave it to me. Then he said: 'O Hakim! Indeed this wealth is green and sweet, so whoever takes it without asking for it, he will be blessed in it. And whoever takes it, insisting upon it, he will not be blessed in it. He is like the one who eats but does not get satisfied and contended. And the upper hand (giving) is better than the lower hand (receiving)." So Hakim said: "I said: 'O Messenger of Allah! By the One who sent you with the Truth! I shall not ask anyone for anything after you until I depart the world.'"So Abu Bakr used to call Hakim to give him something, but he refused to accept it. Then 'Umar called him to give to him, but he refused to accept it. So 'Umar said: "O you Muslims! I would like you to bear witness that I presented Hakim with his due of these spoils of war but he refused to accept it." So Hakim never asked anyone of the people for anything after the Messenger of Allah, until he died}}
\hadithdefcmd{tirmidhi}{2464}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو صَفْوَانَ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ ابْتُلِينَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالضَّرَّاءِ فَصَبَرْنَا ثُمَّ ابْتُلِينَا بِالسَّرَّاءِ بَعْدَهُ فَلَمْ نَصْبِرْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2464}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abdur-Rahman bin 'Awf said:"We were tested along with the Messenger of Allah(s.a.w) by adversity, so we were patient, then we were tested after him with prosperity, but we were not patient}}
\hadithdefcmd{tirmidhi}{2465}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنِ الرَّبِيعِ بْنِ صَبِيحٍ، عَنْ يَزِيدَ بْنِ أَبَانَ، وَهُوَ الرَّقَاشِيُّ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتِ الآخِرَةُ هَمَّهُ جَعَلَ اللَّهُ غِنَاهُ فِي قَلْبِهِ وَجَمَعَ لَهُ شَمْلَهُ وَأَتَتْهُ الدُّنْيَا وَهِيَ رَاغِمَةٌ وَمَنْ كَانَتِ الدُّنْيَا هَمَّهُ جَعَلَ اللَّهُ فَقْرَهُ بَيْنَ عَيْنَيْهِ وَفَرَّقَ عَلَيْهِ شَمْلَهَ وَلَمْ يَأْتِهِ مِنَ الدُّنْيَا إِلاَّ مَا قُدِّرَ لَهُ ‏"‏ ‏.‏\hadithno{2465}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (ﷺ) said:"Whoever makes the Hereafter his goal, Allah makes his heart rich, and organizes his affairs, and the world comes to him whether it wants to or not. And whoever makes the world his goal, Allah puts his poverty right before his eyes, and disorganizes his affairs, and the world does not come to him, except what has been decreed for him}}
\hadithdefcmd{tirmidhi}{2466}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ عِمْرَانَ بْنِ زَائِدَةَ بْنِ نَشِيطٍ، عَنْ أَبِيهِ، عَنْ أَبِي خَالِدٍ الْوَالِبِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ تَعَالَى يَقُولُ يَا ابْنَ آدَمَ تَفَرَّغْ لِعِبَادَتِي أَمْلأْ صَدْرَكَ غِنًى وَأَسُدَّ فَقْرَكَ وَإِلاَّ تَفْعَلْ مَلأْتُ يَدَيْكَ شُغْلاً وَلَمْ أَسُدَّ فَقْرَكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو خَالِدٍ الْوَالِبِيُّ اسْمُهُ هُرْمُزُ ‏.‏\hadithno{2466}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"Indeed Allah, Most High said: 'O son of Adam! Devote yourself to My worship, I will fill your chest with riches and alleviate your poverty. And if you do not do so, then I will fill your hands with problems and not alleviate your poverty}}
\hadithdefcmd{tirmidhi}{2467}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدَنَا شَطْرٌ مِنْ شَعِيرٍ فَأَكَلْنَا مِنْهُ مَا شَاءَ اللَّهُ ثُمَّ قُلْتُ لِلْجَارِيَةِ كِيلِيهِ فَكَالَتْهُ فَلَمْ يَلْبَثْ أَنْ فَنِيَ ‏.‏ قَالَتْ فَلَوْ كُنَّا تَرَكْنَاهُ لأَكَلْنَا مِنْهُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَمَعْنَى قَوْلِهَا شَطْرٌ تَعْنِي شَيْئًا ‏.‏\hadithno{2467}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah said :" The Messenger of Allah(s.a.w) died and we had a Shatr of barley. We ate from it as Allah willed, then I said to the slave girl: 'Measure it' so she measured it, and it was not long before it was gone." She said: "If we had left it alone then we could have eaten from it more than that." [Her saying]: "Shatr" means a small quantity of barley}}
\hadithdefcmd{tirmidhi}{2468}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ عَزْرَةَ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ لَنَا قِرَامُ سِتْرٍ فِيهِ تَمَاثِيلُ عَلَى بَابِي فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ انْزِعِيهِ فَإِنَّهُ يُذَكِّرُنِي الدُّنْيَا ‏"‏ ‏.‏ قَالَتْ وَكَانَ لَنَا سَمَلُ قَطِيفَةٍ عَلَمُهَا مِنْ حَرِيرٍ كُنَّا نَلْبَسُهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2468}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"We had a cloth which had some pictures on it as a curtain on my door. The Messenger of Allah(s.a.w) saw it and said: 'Remove it, for it reminds me of the world.'" She said: "We had a piece of velvet that had patches of silk on it which we used to wear}}
\hadithdefcmd{tirmidhi}{2469}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ وِسَادَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي يَضْطَجِعُ عَلَيْهَا مِنْ أَدَمٍ حَشْوُهَا لِيفٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2469}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated:"The Messenger of Allah (s.a.w) had a leather cushion stuffed with palm fibres which he would lean on}}
\hadithdefcmd{tirmidhi}{2470}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي مَيْسَرَةَ، عَنْ عَائِشَةَ، أَنَّهُمْ ذَبَحُوا شَاةً فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا بَقِيَ مِنْهَا ‏"‏ ‏.‏ قَالَتْ مَا بَقِيَ مِنْهَا إِلاَّ كَتِفُهَا ‏.‏ قَالَ ‏"‏ بَقِيَ كُلُّهَا غَيْرَ كَتِفِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَأَبُو مَيْسَرَةَ هُوَ الْهَمْدَانِيُّ اسْمُهُ عَمْرُو بْنُ شُرَحْبِيلَ ‏.‏\hadithno{2470}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Maisarah narrated from 'Aishah that they had slaughtered a sheep, so the Prophet (s.a.w) said:"What remains of it?" She said: "Nothing remains of it except its shoulder." He said: "All of it remains except its shoulder}}
\hadithdefcmd{tirmidhi}{2471}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كُنَّا آلَ مُحَمَّدٍ نَمْكُثُ شَهْرًا مَا نَسْتَوْقِدُ بِنَارٍ إِنْ هُوَ إِلاَّ الْمَاءُ وَالتَّمْرُ ‏.‏ قَالَ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2471}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"We, the family of Muhammad, would go for a month without kindling a fire, having only water and dates}}
\hadithdefcmd{tirmidhi}{2472}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا رَوْحُ بْنُ أَسْلَمَ أَبُو حَاتِمٍ الْبَصْرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقَدْ أُخِفْتُ فِي اللَّهِ وَمَا يُخَافُ أَحَدٌ وَلَقَدْ أُوذِيتُ فِي اللَّهِ وَمَا يُؤْذَى أَحَدٌ وَلَقَدْ أَتَتْ عَلَىَّ ثَلاَثُونَ مِنْ بَيْنِ يَوْمٍ وَلَيْلَةٍ وَمَا لِي وَلِبِلاَلٍ طَعَامٌ يَأْكُلُهُ ذُو كَبِدٍ إِلاَّ شَيْءٌ يُوَارِيهِ إِبْطُ بِلاَلٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ - وَمَعْنَى هَذَا الْحَدِيثِ حِينَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم فَارًّا مِنْ مَكَّةَ وَمَعَهُ بِلاَلٌ إِنَّمَا كَانَ مَعَ بِلاَلٍ مِنَ الطَّعَامِ مَا يَحْمِلُهُ تَحْتَ إِبْطِهِ ‏.‏\hadithno{2472}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas narrated that the Messenger of Allah (s.a.w) said:"Indeed I have feared for the sake of Allah, such that no one has feared, and I have been harmed for the sake of Allah, such that no one has been harmed. Thirty days and nights have passed over me, and there was no food with Bilal and I forced something with a liver to eat, except what Bilal could conceal under his armpit." This Hadith refers to when the Prophet SAW went out fleeing from Makkah and Bilal was with him. The only food Bilãl had was what he could carry under his arm}}
\hadithdefcmd{tirmidhi}{2473}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنَا يَزِيدُ بْنُ زِيَادٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، حَدَّثَنِي مَنْ، سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ خَرَجْتُ فِي يَوْمٍ شَاتٍ مِنْ بَيْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ أَخَذْتُ إِهَابًا مَعْطُونًا فَحَوَّلْتُ وَسَطَهُ فَأَدْخَلْتُهُ عُنُقِي وَشَدَدْتُ وَسَطِي فَحَزَمْتُهُ بِخُوصِ النَّخْلِ وَإِنِّي لَشَدِيدُ الْجُوعِ وَلَوْ كَانَ فِي بَيْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم طَعَامٌ لَطَعِمْتُ مِنْهُ فَخَرَجْتُ أَلْتَمِسُ شَيْئًا فَمَرَرْتُ بِيَهُودِيٍّ فِي مَالٍ لَهُ وَهُوَ يَسْقِي بِبَكَرَةٍ لَهُ فَاطَّلَعْتُ عَلَيْهِ مِنْ ثُلْمَةٍ فِي الْحَائِطِ فَقَالَ مَا لَكَ يَا أَعْرَابِيُّ هَلْ لَكَ فِي كُلِّ دَلْوٍ بِتَمْرَةٍ قُلْتُ نَعَمْ فَافْتَحِ الْبَابَ حَتَّى أَدْخُلَ فَفَتَحَ فَدَخَلْتُ فَأَعْطَانِي دَلْوَهُ فَكُلَّمَا نَزَعْتُ دَلْوًا أَعْطَانِي تَمْرَةً حَتَّى إِذَا امْتَلأَتْ كَفِّي أَرْسَلْتُ دَلْوَهُ وَقُلْتُ حَسْبِي فَأَكَلْتُهَا ثُمَّ جَرَعْتُ مِنَ الْمَاءِ فَشَرِبْتُ ثُمَّ جِئْتُ الْمَسْجِدَ فَوَجَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2473}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muhammad bin Ka'b Al-Qurazi said:"Someone narrated to me that he heard 'ali bin abi Talib saying: 'I went out on a cold day from the house of the Messenger of Allah (s.a.w). I had taken a tanned skin, si I tore it in the middle, and out it over my neck, and wrapped my mid-section, fastening it with a palm leave. I was severely hungry, and if there was food in the house of the Messenger of Allah (s.a.w) I would have eaten some of it. I went in search of something. I passed by a Jew on his property drawing water (from a well) with a pulley. I watched him from a gap in the fence. He said: "what is wrong with you O Arab1 Would you like to get a date for every bucket?" I said: "Yes. Open the door so I can come in." He opened the door, I entered and he gave me his bucket. Then for every bucket I pulled out, he would give me a date, until when it was enough for me. I put his bucket down and said: "I think I had enough to eat" then I scooped some water to drink it. Then I came to the Masjid and found the Messenger of Allah (s.a.w) in it}}
\hadithdefcmd{tirmidhi}{2474}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبَّاسٍ الْجُرَيْرِيِّ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ النَّهْدِيَّ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ أَصَابَهُمْ جُوعٌ فَأَعْطَاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم تَمْرَةً تَمْرَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2474}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu 'Uthman An-Nahdi narrated from Abu Hurairah that they (the Companions) were suffering from hunger so the Messenger of Allah (s.a.w) gave them each a date}}
\hadithdefcmd{tirmidhi}{2475}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ ثَلاَثُمِائَةٍ نَحْمِلُ زَادَنَا عَلَى رِقَابِنَا فَفَنِيَ زَادُنَا حَتَّى إِنْ كَانَ يَكُونُ لِلرَّجُلِ مِنَّا كُلَّ يَوْمٍ تَمْرَةٌ ‏.‏ فَقِيلَ لَهُ يَا أَبَا عَبْدِ اللَّهِ وَأَيْنَ كَانَتْ تَقَعُ التَّمْرَةُ مِنَ الرَّجُلِ فَقَالَ لَقَدْ وَجَدْنَا فَقْدَهَا حِينَ فَقَدْنَاهَا وَأَتَيْنَا الْبَحْرَ فَإِذَا نَحْنُ بِحُوتٍ قَدْ قَذَفَهُ الْبَحْرُ فَأَكَلْنَا مِنْهُ ثَمَانِيَةَ عَشَرَ يَوْمًا مَا أَحْبَبْنَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ وَرَوَاهُ مَالِكُ بْنُ أَنَسٍ عَنْ وَهْبِ بْنِ كَيْسَانَ أَتَمَّ مِنْ هَذَا وَأَطْوَلَ ‏.‏\hadithno{2475}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir bin 'Abdullah narrated:"The Messenger of Allah (s.a.w) dispatched us, and there were three-hundred of us. We were carrying our provisions on our shoulders. Then our provisions ran out such that each man among us could eat only a date per day." It was said to him: "O Abu 'Abdullah! How could one date be enough for a man?'" He said: "We realized its value when we did not even have that. Then we came to the sea where we saw a whale that the sea had tossed (on the shore). So we ate as much as we liked from it for eighteen days." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2476}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي يَزِيدُ بْنُ زِيَادٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، حَدَّثَنِي مَنْ، سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ إِنَّا لَجُلُوسٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ إِذْ طَلَعَ عَلَيْنَا مُصْعَبُ بْنُ عُمَيْرٍ مَا عَلَيْهِ إِلاَّ بُرْدَةٌ لَهُ مَرْقُوعَةٌ بِفَرْوٍ فَلَمَّا رَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بَكَى لِلَّذِي كَانَ فِيهِ مِنَ النِّعْمَةِ وَالَّذِي هُوَ الْيَوْمَ فِيهِ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ بِكُمْ إِذَا غَدَا أَحَدُكُمْ فِي حُلَّةٍ وَرَاحَ فِي حُلَّةٍ وَوُضِعَتْ بَيْنَ يَدَيْهِ صَحْفَةٌ وَرُفِعَتْ أُخْرَى وَسَتَرْتُمْ بُيُوتَكُمْ كَمَا تُسْتَرُ الْكَعْبَةُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ نَحْنُ يَوْمَئِذٍ خَيْرٌ مِنَّا الْيَوْمَ نَتَفَرَّغُ لِلْعِبَادَةِ وَنُكْفَى الْمُؤْنَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لأَنْتُمُ الْيَوْمَ خَيْرٌ مِنْكُمْ يَوْمَئِذٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَيَزِيدُ بْنُ زِيَادٍ هُوَ ابْنُ مَيْسَرَةَ وَهُوَ مَدَنِيٌّ وَقَدْ رَوَى عَنْهُ مَالِكُ بْنُ أَنَسٍ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ وَيَزِيدُ بْنُ زِيَادٍ الدِّمَشْقِيُّ الَّذِي رَوَى عَنِ الزُّهْرِيِّ رَوَى عَنْهُ وَكِيعٌ وَمَرْوَانُ بْنُ مُعَاوِيَةَ وَيَزِيدُ بْنُ أَبِي زِيَادٍ كُوفِيٌّ رَوَى عَنْهُ سُفْيَانُ وَشُعْبَةُ وَابْنُ عُيَيْنَةَ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ ‏.‏\hadithno{2476}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Yazid bin Ziyad narrated from Muhammad bin Ka'b Al-Qurazi who heard from Abi Talib narrated that he said:'I was sitting in a gathering with the Messenger of Allah (s.a.w) when Mus'ab bin 'Umair appeared before us, wearing nothing but a Burdah patched with some animal furs. When the Messenger of Allah (s.a.w) saw him he began crying because of the good life he previously had compared to the state that he was in that day. Then the Messenger of Allah (s.a.w) said: 'How will you people be, when the late morning comes upon one of you while wearing a Hullah, and at the end of the day he is in, (another) Hullah, when a platter is placed in front of him while another is removed, and you cover your houses just as the Ka'bah is covered?' They said: 'O Messenger of Allah! On that day we will be better than we are today, devoting ourselves to worship, satisfied with our good fortune.' So the Messenger of Allah (s.a.w) said: 'No, today you are better than you will be on that day}}
\hadithdefcmd{tirmidhi}{2477}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنِي عُمَرُ بْنُ ذَرٍّ، حَدَّثَنَا مُجَاهِدٌ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ أَهْلُ الصُّفَّةِ أَضْيَافَ أَهْلِ الإِسْلاَمِ لاَ يَأْوُونَ عَلَى أَهْلٍ وَلاَ مَالٍ وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ إِنْ كُنْتُ لأَعْتَمِدُ بِكَبِدِي عَلَى الأَرْضِ مِنَ الْجُوعِ وَأَشُدُّ الْحَجَرَ عَلَى بَطْنِي مِنَ الْجُوعِ وَلَقَدْ قَعَدْتُ يَوْمًا عَلَى طَرِيقِهِمُ الَّذِي يَخْرُجُونَ فِيهِ فَمَرَّ بِي أَبُو بَكْرٍ فَسَأَلْتُهُ عَنْ آيَةٍ مِنْ كِتَابِ اللَّهِ مَا سَأَلْتُهُ إِلاَّ لِيَسْتَتْبِعَنِي فَمَرَّ وَلَمْ يَفْعَلْ ثُمَّ مَرَّ بِي عُمَرُ فَسَأَلْتُهُ عَنْ آيَةٍ مِنْ كِتَابِ اللَّهِ مَا أَسْأَلُهُ إِلاَّ لِيَسْتَتْبِعَنِي فَمَرَّ وَلَمْ يَفْعَلْ ثُمَّ مَرَّ بِي أَبُو الْقَاسِمِ صلى الله عليه وسلم فَتَبَسَّمَ حِينَ رَآنِي وَقَالَ ‏"‏ أَبَا هُرَيْرَةَ ‏"‏ ‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ الْحَقْ ‏"‏ ‏.‏ وَمَضَى فَاتَّبَعْتُهُ وَدَخَلَ مَنْزِلَهُ فَاسْتَأْذَنْتُ فَأَذِنَ لِي فَوَجَدَ قَدَحًا مِنْ لَبَنٍ فَقَالَ ‏"‏ مِنْ أَيْنَ هَذَا اللَّبَنُ لَكُمْ ‏"‏ ‏.‏ قِيلَ أَهْدَاهُ لَنَا فُلاَنٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبَا هُرَيْرَةَ ‏"‏ ‏.‏ قُلْتُ لَبَّيْكَ ‏.‏ فَقَالَ ‏"‏ الْحَقْ إِلَى أَهْلِ الصُّفَّةِ فَادْعُهُمْ ‏"‏ ‏.‏ وَهُمْ أَضْيَافُ أَهْلِ الإِسْلاَمِ لاَ يَأْوُونَ عَلَى أَهْلٍ وَلاَ مَالٍ إِذَا أَتَتْهُ صَدَقَةٌ بَعَثَ بِهَا إِلَيْهِمْ وَلَمْ يَتَنَاوَلْ مِنْهَا شَيْئًا وَإِذَا أَتَتْهُ هَدِيَّةٌ أَرْسَلَ إِلَيْهِمْ فَأَصَابَ مِنْهَا وَأَشْرَكَهُمْ فِيهَا فَسَاءَنِي ذَلِكَ وَقُلْتُ مَا هَذَا الْقَدَحُ بَيْنَ أَهْلِ الصُّفَّةِ وَأَنَا رَسُولُهُ إِلَيْهِمْ فَسَيَأْمُرُنِي أَنْ أُدِيرَهُ عَلَيْهِمْ فَمَا عَسَى أَنْ يُصِيبَنِي مِنْهُ وَقَدْ كُنْتُ أَرْجُو أَنْ أُصِيبَ مِنْهُ مَا يُغْنِينِي وَلَمْ يَكُنْ بُدٌّ مِنْ طَاعَةِ اللَّهِ وَطَاعَةِ رَسُولِهِ فَأَتَيْتُهُمْ فَدَعَوْتُهُمْ فَلَمَّا دَخَلُوا عَلَيْهِ فَأَخَذُوا مَجَالِسَهُمْ فَقَالَ ‏"‏ أَبَا هُرَيْرَةَ خُذِ الْقَدَحَ وَأَعْطِهِمْ ‏"‏ ‏.‏ فَأَخَذْتُ الْقَدَحَ فَجَعَلْتُ أُنَاوِلُهُ الرَّجُلَ فَيَشْرَبُ حَتَّى يُرْوَى ثُمَّ يَرُدُّهُ فَأُنَاوِلُهُ الآخَرَ حَتَّى انْتَهَيْتُ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ رَوِيَ الْقَوْمُ كُلُّهُمْ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْقَدَحَ فَوَضَعَهُ عَلَى يَدَيْهِ ثُمَّ رَفَعَ رَأْسَهُ فَتَبَسَّمَ فَقَالَ ‏"‏ أَبَا هُرَيْرَةَ اشْرَبْ ‏"‏ ‏.‏ فَشَرِبْتُ ثُمَّ قَالَ ‏"‏ اشْرَبْ ‏"‏ ‏.‏ فَلَمْ أَزَلْ أَشْرَبُ وَيَقُولُ ‏"‏ اشْرَبْ ‏"‏ ‏.‏ حَتَّى قُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أَجِدُ لَهُ مَسْلَكًا فَأَخَذَ الْقَدَحَ فَحَمِدَ اللَّهَ وَسَمَّى ثُمَّ شَرِبَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2477}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah narrated:"The people of As-Suffah were the guests of the people of Islam,they had nothing of people nor wealth to rely upon. And By Allah, the One Whom there is none worthy of worship besides Him – I would lay on the ground on my liver (side) due to hunger, And I would fasten a stone to my stomach out of hunger. One day I sat by the way that they (the Companions) use to come out through. Abu Bakr passed and so I asked him about an Ayah from Allah's Book, not asking him except that he might tell me to follow him (for something to eat). But he passed on without doing so. Then `Umar passed, so I asked him about an Ayah from Allah's Book, not asking him except that he might tell me to follow him. But he passed on without doing so. Then Abul-Qasim (s.a.w) passed, and he smiled when he saw me, and said: 'Abu Hurairah?' I said: 'I am here O Messenger of Allah!' He said: 'Come along.' He continued and I followed him, he entered his house, so I sought permission to enter, and he permitted me. He found a bowl of milk and said: 'Where did this milk come from?' It was said: 'It was a gift to us from so – and – so.' So the Messenger of Allah (s.a.w) said: 'O Abu Hurairah' I said: 'I am here O Messenger of Allah!' He said: 'Go to the people of As-Suffah to invite them.' - Now, they were the guests of the people of Islam, they had nothing of people nor wealth to rely upon. Whenever some charity was brought to him, he would send it to them without using any of it. And when a gift was given to him (s.a.w), he would send for them to participate and share with him in it. I became upset about that, and I said (to myself): 'What good will this bowl be among the people of As-Suffah and I am the one bringing it to them?' Then he ordered me to circulate it among them (So I wondered) what of it would reach me from it, and I hoped that I would get from it what would satisfy me. But I would certainly not neglect to obey Allah and obey His Messenger, so I went to them and invited them. When they entered upon him they sat down. He said: 'Abu Hurairah, take the bowl and give it to them.' So I gave it to a man who drank his fill, then he gave it to another one, until it ended up with the Messenger of Allah (s.a.w), and all of the people had drank their fill. The Messenger of Allah (s.a.w) took the bowl, put it on his hand,then raised his head. He smiled and said: 'Abu Hurairah, drink.' So I drank, then he said: 'Drink.' I kept drinking and he kept on saying, 'Drink.' Then I said: 'By the One Who sent you with the truth! I have no more space for it.' So he took the bowl and praised Allah, mentioned His Name and drank.'” (Sahih)}}
\hadithdefcmd{tirmidhi}{2478}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الْقُرَشِيُّ، حَدَّثَنَا يَحْيَى الْبَكَّاءُ، عَنِ ابْنِ عُمَرَ، قَالَ تَجَشَّأَ رَجُلٌ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ كُفَّ عَنَّا جُشَاءَكَ فَإِنَّ أَكْثَرَهُمْ شِبَعًا فِي الدُّنْيَا أَطْوَلُهُمْ جُوعًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي جُحَيْفَةَ ‏.‏\hadithno{2478}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Yahya Al-Bakka' narrated from Ibn 'Umar who said:"A man belched in the presence of the Prophet(s.a.w), so he said: 'Restain your belching from us. For indeed those who are filled most in the world will be the hungriest on the Day of Judgement}}
\hadithdefcmd{tirmidhi}{2479}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، قَالَ يَا بُنَىَّ لَوْ رَأَيْتَنَا وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَصَابَتْنَا السَّمَاءُ لَحَسِبْتَ أَنَّ رِيحَنَا رِيحُ الضَّأْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ أَنَّهُ كَانَ ثِيَابَهُمُ الصُّوفُ فَكَانَ إِذَا أَصَابَهُمُ الْمَطَرُ يَجِيءُ مِنْ ثِيَابِهِمْ رِيحُ الضَّأْنِ ‏.‏\hadithno{2479}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Burdah bin Abi Musa narrated that his father said:"O my son! If you saw us when we were with the Prophet(s.a.w) and the sky poured upon us, you would think that our smell was the smell of sheep." The meaning of this Hadith is that their garments were of wool, so when the rain fell upon them, the smell coming from their clothes was that of sheep}}
\hadithdefcmd{tirmidhi}{2480}{حَدَّثَنَا الْجَارُودُ بْنُ مُعَاذٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ أَبِي حَمْزَةَ، عَنْ إِبْرَاهِيمَ النَّخَعِيِّ، قَالَ الْبِنَاءُ كُلُّهُ وَبَالٌ قُلْتُ أَرَأَيْتَ مَا لاَ بُدَّ مِنْهُ قَالَ لاَ أَجْرَ وَلاَ وِزْرَ ‏.‏\hadithno{2480}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad Maqtu; Al-Albani: Daif Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Sufyan Ath-Thawri narrated:From Abu Hamzah, (who said): "From Ibrahim An-Nakha'i who said: 'All buildings and concerns for them will be against you.' I said: 'What do you think about what one can not do without?' He said: 'There is no reward for that nor harm}}
\hadithdefcmd{tirmidhi}{2481}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ أَبِي مَرْحُومٍ عَبْدِ الرَّحِيمِ بْنِ مَيْمُونٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ تَرَكَ اللِّبَاسِ تَوَاضُعًا لِلَّهِ وَهُوَ يَقْدِرُ عَلَيْهِ دَعَاهُ اللَّهُ يَوْمَ الْقِيَامَةِ عَلَى رُءُوسِ الْخَلاَئِقِ حَتَّى يُخَيِّرَهُ مِنْ أَىِّ حُلَلِ الإِيمَانِ شَاءَ يَلْبَسُهَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ حُلَلِ الإِيمَانِ ‏"‏ ‏.‏ يَعْنِي مَا يُعْطَى أَهْلُ الإِيمَانِ مِنْ حُلَلِ الْجَنَّةِ ‏.‏\hadithno{2481}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bin Mu'adh bin Anas Al-Juhani narrated from his father, that the Messenger of Allah (s.a.w)said:"Whoever leaves(valuable) dress out of humility to Allah while he is able to (afford it), Allah will call him before the heads of creation on the Day of Judgement so that he can chose whichever Hulal of faith he wishes to wear." The meaning of his saying: "Hulal of faith" is the garments of Paradise which are given to the people of faith}}
\hadithdefcmd{tirmidhi}{2482}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا زَافِرُ بْنُ سُلَيْمَانَ، عَنْ إِسْرَائِيلَ، عَنْ شَبِيبِ بْنِ بَشِيرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ النَّفَقَةُ كُلُّهَا فِي سَبِيلِ اللَّهِ إِلاَّ الْبِنَاءَ فَلاَ خَيْرَ فِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ هَكَذَا قَالَ مُحَمَّدُ بْنُ حُمَيْدٍ شَبِيبُ بْنُ بَشِيرٍ وَإِنَّمَا هُوَ شَبِيبُ بْنُ بِشْرٍ ‏.‏\hadithno{2482}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Shahib bin Bashir narrated from Anas bin Malik that the Messenger of Allah (s.a.w) said:"All expenditures are in Allah's Cause, except for buildings, for there is no good in it}}
\hadithdefcmd{tirmidhi}{2483}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ مُضَرِّبٍ، قَالَ أَتَيْنَا خَبَّابًا نَعُودُهُ وَقَدِ اكْتَوَى سَبْعَ كَيَّاتٍ فَقَالَ لَقَدْ تَطَاوَلَ مَرَضِي وَلَوْلاَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تَمَنَّوُا الْمَوْتَ ‏"‏ ‏.‏ لَتَمَنَّيْتُ وَقَالَ ‏"‏ يُؤْجَرُ الرَّجُلُ فِي نَفَقَتِهِ كُلِّهَا إِلاَّ التُّرَابَ أَوْ قَالَ فِي الْبِنَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2483}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Harithah bin Mudarrib said:"We went to visit Khabbab who had himself cauterized in seven places on his body. He said: 'I have been ill for so long, and if it was not that I heard the Messenger of Allah (s.a.w) saying: "None of you should wish for death" then I would have wished for it, and he said: "A man is rewarded for [all of] his spending except for the dust" - or he said - "in the building}}
\hadithdefcmd{tirmidhi}{2484}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا خَالِدُ بْنُ طَهْمَانَ أَبُو الْعَلاَءِ، حَدَّثَنَا حُصَيْنٌ، قَالَ جَاءَ سَائِلٌ فَسَأَلَ ابْنَ عَبَّاسٍ فَقَالَ ابْنُ عَبَّاسٍ لِلسَّائِلِ أَتَشْهَدُ أَنْ لاَ، إِلَهَ إِلاَّ اللَّهُ قَالَ نَعَمْ ‏.‏ قَالَ أَتَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ قَالَ نَعَمْ ‏.‏ قَالَ وَتَصُومُ رَمَضَانَ قَالَ نَعَمْ ‏.‏ قَالَ سَأَلْتَ وَلِلسَّائِلِ حَقٌّ إِنَّهُ لَحَقٌّ عَلَيْنَا أَنْ نَصِلَكَ ‏.‏ فَأَعْطَاهُ ثَوْبًا ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ مُسْلِمٍ كَسَا مُسْلِمًا ثَوْبًا إِلاَّ كَانَ فِي حِفْظِ اللَّهِ مَا دَامَ مِنْهُ عَلَيْهِ خِرْقَةٌ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2484}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Husain said:"A beggar came to Ibn 'Abbas to beg from him. Ibn 'Abbas said to the beggar: 'Do you testify to La Ilaha Illallah?' He said: 'Yes.' He said: 'Do you testify that Muhammad is the Messenfger of Allah?' He said: 'Yes.' He said: 'You fast(the month of) Ramadan?' He said: 'Yes?' He said: 'You asked, and the one who asked has a right, so you have a right upon us that we give you.' So he gave him a garment then said: 'I heard the Messenger of Allah (s.a.w) saying: "No Muslim clothes a Muslim with a garment except that he is under the protection of Allah as long as a shred from it remains upon him}}
\hadithdefcmd{tirmidhi}{2485}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، وَابْنُ أَبِي عَدِيٍّ، وَيَحْيَى بْنُ سَعِيدٍ، عَنْ عَوْفِ بْنِ أَبِي جَمِيلَةَ الأَعْرَابِيِّ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ انْجَفَلَ النَّاسُ إِلَيْهِ وَقِيلَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجِئْتُ فِي النَّاسِ لأَنْظُرَ إِلَيْهِ فَلَمَّا اسْتَبَنْتُ وَجْهَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَرَفْتُ أَنَّ وَجْهَهُ لَيْسَ بِوَجْهِ كَذَّابٍ وَكَانَ أَوَّلَ شَيْءٍ تَكَلَّمَ بِهِ أَنْ قَالَ ‏ "‏ أَيُّهَا النَّاسُ أَفْشُوا السَّلاَمَ وَأَطْعِمُوا الطَّعَامَ وَصَلُّوا وَالنَّاسُ نِيَامٌ تَدْخُلُونَ الْجَنَّةَ بِسَلاَمٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2485}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Salam said:"When the Messenger of Allah (s.a.w) arrived- meaning in Al-Madinah – the people came out to meet him. It was said that the Messenger of Allah (s.a.w) had arrived, so I went among the people to get a look at him. When I gazed upon the face of the Messenger of Allah (s.a.w), I knew that this face was not the face of a liar. The first thing that he spoke about was that he said: 'O you people! Spread the Salam, feed(others), and perform Salat while the people are sleeping; you will enter Paradise with(the greeting of) Salam.'” (Sahih)}}
\hadithdefcmd{tirmidhi}{2486}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ مَعْنٍ الْمَدَنِيُّ الْغِفَارِيُّ، حَدَّثَنِي أَبِي، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الطَّاعِمُ الشَّاكِرُ بِمَنْزِلَةِ الصَّائِمِ الصَّابِرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2486}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Prophet(s.a.w) said:"The one who eats and is grateful is like the status of the patient fasting person}}
\hadithdefcmd{tirmidhi}{2487}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، بِمَكَّةَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ أَتَاهُ الْمُهَاجِرُونَ فَقَالُوا يَا رَسُولَ اللَّهِ مَا رَأَيْنَا قَوْمًا أَبْذَلَ مِنْ كَثِيرٍ وَلاَ أَحْسَنَ مُوَاسَاةً مِنْ قَلِيلٍ مِنْ قَوْمٍ نَزَلْنَا بَيْنَ أَظْهُرِهِمْ لَقَدْ كَفَوْنَا الْمُؤْنَةَ وَأَشْرَكُونَا فِي الْمَهْنَإِ حَتَّى خِفْنَا أَنْ يَذْهَبُوا بِالأَجْرِ كُلِّهِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ مَا دَعَوْتُمُ اللَّهَ لَهُمْ وَأَثْنَيْتُمْ عَلَيْهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2487}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas said:"When the Messenger of Allah (s.a.w) arrived in Al-Madinah the Muhajirun came to him and said: 'O Messenger of Allah! We have not seen a people more willing to sacrifice when having a lot, nor more patient when having a little than the people whom we are staying among. Our provisions are so sufficient, and we share with them in their produce such that we fear that all our reward is gone. So the Prophet (s.a.w) said: "No. As long as you supplicate to Allah for them and praise (show gratitude to) them(for it)}}
\hadithdefcmd{tirmidhi}{2488}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو الأَوْدِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أُخْبِرُكُمْ بِمَنْ يَحْرُمُ عَلَى النَّارِ أَوْ بِمَنْ تَحْرُمُ عَلَيْهِ النَّارُ عَلَى كُلِّ قَرِيبٍ هَيِّنٍ لَيِّنٍ سَهْلٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2488}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Mas'ud narrated that the Messenger of Allah (s.a.w) said:"Shall I not inform you of whom the Fire is unlawful and he is unlawful for the Fire? Every person who is near (to people), amicable, and easy (to deal with)}}
\hadithdefcmd{tirmidhi}{2489}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، قَالَ قُلْتُ لِعَائِشَةَ أَىُّ شَيْءٍ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصْنَعُ إِذَا دَخَلَ بَيْتَهُ قَالَتْ كَانَ يَكُونُ فِي مِهْنَةِ أَهْلِهِ فَإِذَا حَضَرَتِ الصَّلاَةُ قَامَ فَصَلَّى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2489}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Aswad bin Yazid narrated:"I said to Aishah: 'What would the Prophet (s.a.w) do when he entered his house?' She said: 'He would busy himself with serving his family, then when (the time for) Salat was due he would stand (to go) for it}}
\hadithdefcmd{tirmidhi}{2490}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عِمْرَانَ بْنِ زَيْدٍ التَّغْلِبِيِّ، عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا اسْتَقْبَلَهُ الرَّجُلُ فَصَافَحَهُ لاَ يَنْزِعُ يَدَهُ مِنْ يَدِهِ حَتَّى يَكُونَ الرَّجُلُ الَّذِي يَنْزِعُ وَلاَ يَصْرِفُ وَجْهَهُ عَنْ وَجْهِهِ حَتَّى يَكُونَ الرَّجُلُ هُوَ الَّذِي يَصْرِفُهُ وَلَمْ يُرَ مُقَدِّمًا رُكْبَتَيْهِ بَيْنَ يَدَىْ جَلِيسٍ لَهُ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2490}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated:"When the Prophet(s.a.w) would receive a man to shake hands with him,he would not remove his hand until he [the man]removed his, and he would not turn his face away from his face until the man turned and he would not be seen advancing his knees before one sitting with him}}
\hadithdefcmd{tirmidhi}{2491}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَرَجَ رَجُلٌ مِمَّنْ كَانَ قَبْلَكُمْ فِي حُلَّةٍ لَهُ يَخْتَالُ فِيهَا فَأَمَرَ اللَّهُ الأَرْضَ فَأَخَذَتْهُ فَهُوَ يَتَجَلْجَلُ فِيهَا أَوْ قَالَ يَتَلَجْلَجُ فِيهَا إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2491}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin 'Amr narrated that the Messenger of Allah (s.a.w) said:"A man among those before you went out arrogantly in a Hullah of his. So Allah ordered the earth to take him. He remains sinking[into it]" - or he said - "He will remain sinking into it until the Day of Judgement}}
\hadithdefcmd{tirmidhi}{2492}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُحْشَرُ الْمُتَكَبِّرُونَ يَوْمَ الْقِيَامَةِ أَمْثَالَ الذَّرِّ فِي صُوَرِ الرِّجَالِ يَغْشَاهُمُ الذُّلُّ مِنْ كُلِّ مَكَانٍ فَيُسَاقُونَ إِلَى سِجْنٍ فِي جَهَنَّمَ يُسَمَّى بُولَسَ تَعْلُوهُمْ نَارُ الأَنْيَارِ يُسْقَوْنَ مِنْ عُصَارَةِ أَهْلِ النَّارِ طِينَةِ الْخَبَالِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2492}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather from the Prophet (s.a.w) who said:"The proud will be gathered on the Day of Judgement resembling tiny particles in the image of men. They will be covered with humiliation everywhere, they will be dragged into a prison in Hell called Bulas, submerged in the Fire of Fires, drinking the drippings of the people of the Fire, filled with derangement}}
\hadithdefcmd{tirmidhi}{2493}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، وَعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، حَدَّثَنِي أَبُو مَرْحُومٍ عَبْدُ الرَّحِيمِ بْنُ مَيْمُونٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَظَمَ غَيْظًا وَهُوَ يَقْدِرُ عَلَى أَنْ يُنَفِّذَهُ دَعَاهُ اللَّهُ عَلَى رُءُوسِ الْخَلاَئِقِ يَوْمَ الْقِيَامَةِ حَتَّى يُخَيِّرَهُ فِي أَىِّ الْحُورِ شَاءَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2493}\hadithgrade{Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Sahl bin Mu'ad bin Anas narrated from his father, that the Prophet (s.a.w) said:"Whoever suppresses his rage, while he is able to exact it, Allah will call him before the heads of creation [on the Day of Judgement] so that he can chose whichever of the Hur he wishes}}
\hadithdefcmd{tirmidhi}{2494}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِبْرَاهِيمَ الْغِفَارِيُّ الْمَدَنِيُّ، حَدَّثَنِي أَبِي، عَنْ أَبِي بَكْرِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثٌ مَنْ كُنَّ فِيهِ نَشَرَ اللَّهُ عَلَيْهِ كَنَفَهُ وَأَدْخَلَهُ جَنَّتَهُ رِفْقٌ بِالضَّعِيفِ وَشَفَقَةٌ عَلَى الْوَالِدَيْنِ وَإِحْسَانٌ إِلَى الْمَمْلُوكِ ‏"‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو بَكْرِ بْنُ الْمُنْكَدِرِ هُوَ أَخُو مُحَمَّدِ بْنِ الْمُنْكَدِرِ ‏.‏\hadithno{2494}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Bakr bin Al-Munkadir narrated from Jabir that the Messenger of Allah (s.a.w) said:"There are three (characteristics) for which whomever has them,Allah will expose His side,and admit him to Paradise:Being courteous to the guest,kind to parents,and doing good for slaves}}
\hadithdefcmd{tirmidhi}{2495}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ لَيْثٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَقُولُ اللَّهُ تَعَالَى يَا عِبَادِي كُلُّكُمْ ضَالٌّ إِلاَّ مَنْ هَدَيْتُهُ فَسَلُونِي الْهُدَى أَهْدِكُمْ وَكُلُّكُمْ فَقِيرٌ إِلاَّ مَنْ أَغْنَيْتُ فَسَلُونِي أَرْزُقْكُمْ وَكُلُّكُمْ مُذْنِبٌ إِلاَّ مَنْ عَافَيْتُ فَمَنْ عَلِمَ مِنْكُمْ أَنِّي ذُو قُدْرَةٍ عَلَى الْمَغْفِرَةِ فَاسْتَغْفَرَنِي غَفَرْتُ لَهُ وَلاَ أُبَالِي وَلَوْ أَنَّ أَوَّلَكُمْ وَآخِرَكُمْ وَحَيَّكُمْ وَمَيِّتَكُمْ وَرَطْبَكُمْ وَيَابِسَكُمُ اجْتَمَعُوا عَلَى أَتْقَى قَلْبِ عَبْدٍ مِنْ عِبَادِي مَا زَادَ ذَلِكَ فِي مُلْكِي جَنَاحَ بَعُوضَةٍ وَلَوْ أَنَّ أَوَّلَكُمْ وَآخِرَكُمْ وَحَيَّكُمْ وَمَيِّتَكُمْ وَرَطْبَكُمْ وَيَابِسَكُمُ اجْتَمَعُوا عَلَى أَشْقَى قَلْبِ عَبْدٍ مِنْ عِبَادِي مَا نَقَصَ ذَلِكَ مِنْ مُلْكِي جَنَاحَ بَعُوضَةٍ وَلَوْ أَنَّ أَوَّلَكُمْ وَآخِرَكُمْ وَحَيَّكُمْ وَمَيِّتَكُمْ وَرَطْبَكُمْ وَيَابِسَكُمُ اجْتَمَعُوا فِي صَعِيدٍ وَاحِدٍ فَسَأَلَ كُلُّ إِنْسَانٍ مِنْكُمْ مَا بَلَغَتْ أُمْنِيَّتُهُ فَأَعْطَيْتُ كُلَّ سَائِلٍ مِنْكُمْ مَا سَأَلَ مَا نَقَصَ ذَلِكَ مِنْ مُلْكِي إِلاَّ كَمَا لَوْ أَنَّ أَحَدَكُمْ مَرَّ بِالْبَحْرِ فَغَمَسَ فِيهِ إِبْرَةً ثُمَّ رَفَعَهَا إِلَيْهِ ذَلِكَ بِأَنِّي جَوَادٌ مَاجِدٌ أَفْعَلُ مَا أُرِيدُ عَطَائِي كَلاَمٌ وَعَذَابِي كَلاَمٌ إِنَّمَا أَمْرِي لِشَيْءٍ إِذَا أَرَدْتُهُ أَنْ أَقُولَ لَهُ كُنْ فَيَكُونُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ شَهْرِ بْنِ حَوْشَبٍ عَنْ مَعْدِيكَرِبَ عَنْ أَبِي ذَرٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2495}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Dharr narrated that the Messenger of Allah (s.a.w) said:"Allah,Most High said: 'O My Slaves! All of you are astray except whom I guide, so ask Me for guidance and I shall guide you. All of you are poor except whom I enrich, so ask Me and I shall provide you. All of you are sinners except whom I have pardoned, so whoever among you knows that I am the One able to forgive, and seeks My forgiveness, I shall forgive him, without concern for Me (and it will not affect Me). If the first of you and the last of you, the living among you and the dead among you, the fresh among you and the dry among you were to gather together to help the heart with the most Taqwa among My slaves, that would not add a mosquito's wing to My sovereignty. If the first of you and the last of you, the living among you and the dead among you, the fresh among you and the dry among you were to gather together to help the worst heart of My slaves, that would not diminish a mosquito's wing to My sovereignty. I shall forgive him, without concern for Me (and it will not affect Me). If the first of you and the last of you, the living among you and the dead among you, the fresh among you and the dry among you were to gather together upon one plateau, and each person among them were to ask for his utmost desire, and I were to give each what he asked for, that would not diminish from My sovereignty, except as if one of you were to pass by an ocean and dip a needle into it and then remove it. That is because I am the Most Liberal without need, the Most Generous, doing as I will. I give by My speech and I punish by My speech, whenever I will something I only say: "Be" and it shall be.'" Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2496}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ الرَّازِيِّ، عَنْ سَعْدٍ، مَوْلَى طَلْحَةَ عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يُحَدِّثُ حَدِيثًا لَوْ لَمْ أَسْمَعْهُ إِلاَّ مَرَّةً أَوْ مَرَّتَيْنِ حَتَّى عَدَّ سَبْعَ مَرَّاتٍ وَلَكِنِّي سَمِعْتُهُ أَكْثَرَ مِنْ ذَلِكَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ كَانَ الْكِفْلُ مِنْ بَنِي إِسْرَائِيلَ لاَ يَتَوَرَّعُ مِنْ ذَنْبٍ عَمِلَهُ فَأَتَتْهُ امْرَأَةٌ فَأَعْطَاهَا سِتِّينَ دِينَارًا عَلَى أَنْ يَطَأَهَا فَلَمَّا قَعَدَ مِنْهَا مَقْعَدَ الرَّجُلِ مِنِ امْرَأَتِهِ أُرْعِدَتْ وَبَكَتْ فَقَالَ مَا يُبْكِيكِ أَأَكْرَهْتُكِ قَالَتْ لاَ وَلَكِنَّهُ عَمَلٌ مَا عَمِلْتُهُ قَطُّ وَمَا حَمَلَنِي عَلَيْهِ إِلاَّ الْحَاجَةُ فَقَالَ تَفْعَلِينَ أَنْتِ هَذَا وَمَا فَعَلْتِهِ اذْهَبِي فَهِيَ لَكِ ‏.‏ وَقَالَ لاَ وَاللَّهِ لاَ أَعْصِي اللَّهَ بَعْدَهَا أَبَدًا ‏.‏ فَمَاتَ مِنْ لَيْلَتِهِ فَأَصْبَحَ مَكْتُوبًا عَلَى بَابِهِ إِنَّ اللَّهَ قَدْ غَفَرَ لِلْكِفْلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ قَدْ رَوَاهُ شَيْبَانُ وَغَيْرُ وَاحِدٍ عَنِ الأَعْمَشِ نَحْوَ هَذَا وَرَفَعُوهُ وَرَوَى بَعْضُهُمْ عَنِ الأَعْمَشِ فَلَمْ يَرْفَعْهُ ‏.‏ وَرَوَى أَبُو بَكْرِ بْنُ عَيَّاشٍ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ فَأَخْطَأَ فِيهِ وَقَالَ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عُمَرَ وَهُوَ غَيْرُ مَحْفُوظٍ وَعَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ الرَّازِيُّ هُوَ كُوفِيٌّ وَكَانَتْ جَدَّتُهُ سُرِّيَّةً لِعَلِيِّ بْنِ أَبِي طَالِبٍ وَرَوَى عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ الرَّازِيِّ عُبَيْدَةُ الضَّبِّيُّ وَالْحَجَّاجُ بْنُ أَرْطَاةَ وَغَيْرُ وَاحِدٍ مِنْ كِبَارِ أَهْلِ الْعِلْمِ ‏.‏\hadithno{2496}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Umar said:"I heard the Prophet (s.a.w) narrating a hadith, not just once or twice, even seven times, but I heard him saying it more than that. I heard him saying: 'There was a man called Al-Kifl among the children of Isra'il who did not restrain himself from committing sins. A woman came to him and he gave her sixty Dinar so he could sleep with her. When he sat up from her, as a man sits up from a woman, she began to tremble and cry, so he said: "Why are you crying, did I do something to harm you?" She said: "No. But it is because of what I did, I only did so out of need." He said: "You did this without having done (it before), so leave me, and it (the money) is for you." And then he said: "By Allah! I will never disobey Allah after that." He died during the night and morning came with: " Indeed Allah has forgiven Al-Kifl" written upon his door." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2497}{حَدَّثَنَا هَنَّادٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْعُودٍ، بِحَدِيثَيْنِ أَحَدُهُمَا عَنْ نَفْسِهِ، وَالآخَرُ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ عَبْدُ اللَّهِ إِنَّ الْمُؤْمِنَ يَرَى ذُنُوبَهُ كَأَنَّهُ فِي أَصْلِ جَبَلٍ يَخَافُ أَنْ يَقَعَ عَلَيْهِ وَإِنَّ الْفَاجِرَ يَرَى ذُنُوبَهُ كَذُبَابٍ وَقَعَ عَلَى أَنْفِهِ قَالَ بِهِ هَكَذَا فَطَارَ ‏.‏\hadithno{2497}\hadithgrade{Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Harith bin Suwaid said:" 'Abdullah [bin Mas'ud] narrated two Ahadith to us, one of them from himself and the other from the Prophet (s.a.w). 'Abdullah said: 'The believer sees his sins as if he was at the base of a mountain, fearing that it was about to fall upon him. The wicked person sees his sins as if (they are) flies are hitting his nose" he said: "Like this" - motioning with his hand - "to get them to fly away}}
\hadithdefcmd{tirmidhi}{2498}{وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَلَّهُ أَفْرَحُ بِتَوْبَةِ أَحَدِكُمْ مِنْ رَجُلٍ بِأَرْضٍ دَوِيَّةٍ مُهْلِكَةٍ مَعَهُ رَاحِلَتُه�� عَلَيْهَا زَادُهُ وَطَعَامُهُ وَشَرَابُهُ وَمَا يُصْلِحُهُ فَأَضَلَّهَا فَخَرَجَ فِي طَلَبِهَا حَتَّى إِذَا أَدْرَكَهُ الْمَوْتُ قَالَ أَرْجِعُ إِلَى مَكَانِي الَّذِي أَضْلَلْتُهَا فِيهِ فَأَمُوتُ فِيهِ فَرَجَعَ إِلَى مَكَانِهِ فَغَلَبَتْهُ عَيْنُهُ فَاسْتَيْقَظَ فَإِذَا رَاحِلَتُهُ عِنْدَ رَأْسِهِ عَلَيْهَا طَعَامُهُ وَشَرَابُهُ وَمَا يُصْلِحُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِيهِ عَنْ أَبِي هُرَيْرَةَ وَالنُّعْمَانِ بْنِ بَشِيرٍ وَأَنَسِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2498}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{And the Messenger of Allah (s.a.w) said:"Allah is more pleased with the repentance of one of you that a man in a desolate, barren, destructive wasteland, who has his mount carrying his provisions, his food, and his drink and what he needs with him. Then it wanders away. So he goes to find it until he is on the brink of death. He says: 'I will return to the place where I lost it, to die.' So he returns to his place and his eyes become heavy (falling asleep). Then he awakens to find his mount at his head carrying his food, drink and what he needs." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2499}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، حَدَّثَنَا عَلِيُّ بْنُ مَسْعَدَةَ الْبَاهِلِيُّ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ ابْنِ آدَمَ خَطَّاءٌ وَخَيْرُ الْخَطَّائِينَ التَّوَّابُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَلِيِّ بْنِ مَسْعَدَةَ عَنْ قَتَادَةَ ‏.‏\hadithno{2499}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that the Prophet (ﷺ) said:"Every son of Adam sins, and the best of the sinners are the repentant}}
\hadithdefcmd{tirmidhi}{2500}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا أَوْ لِيَصْمُتْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَنَسٍ وَأَبِي شُرَيْحٍ الْعَدَوِيِّ الْكَعْبِيِّ الْخُزَاعِيِّ وَاسْمُهُ خُوَيْلِدُ بْنُ عَمْرٍو ‏.‏\hadithno{2500}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Prophet(s.a.w) said:"Whoever believes in Allah and the Last Day, then let him honor his guest. And whoever believes in Allah and the Last Day, then let him say what is good or remain silent." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2501}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ عَمْرٍو الْمُعَافِرِيِّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَمَتَ نَجَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ لَهِيعَةَ ‏.‏ وَأَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ هُوَ عَبْدُ اللَّهِ بْنُ يَزِيدَ ‏.‏\hadithno{2501}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin 'Amr narrated that the Messenger of Allah (s.a.w) said:"Whoever is silent, he is saved}}
\hadithdefcmd{tirmidhi}{2502}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنْ أَبِي حُذَيْفَةَ، وَكَانَ، مِنْ أَصْحَابِ ابْنِ مَسْعُودٍ عَنْ عَائِشَةَ، قَالَتْ حَكَيْتُ لِلنَّبِيِّ صلى الله عليه وسلم رَجُلاً فَقَالَ ‏"‏ مَا يَسُرُّنِي أَنِّي حَكَيْتُ رَجُلاً وَأَنَّ لِي كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ صَفِيَّةَ امْرَأَةٌ وَقَالَتْ بِيَدِهَا هَكَذَا كَأَنَّهَا تَعْنِي قَصِيرَةً ‏.‏ فَقَالَ ‏"‏ لَقَدْ مَزَجْتِ بِكَلِمَةٍ لَوْ مَزَجْتِ بِهَا مَاءَ الْبَحْرِ لَمُزِجَ ‏"‏ ‏.‏\hadithno{2502}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hudhaifah narrated - and he was one of the companions of 'Abdullãh bin Mas'üd - from 'Aishah who said:"I told the Prophet (ﷺ) about a man, so he said: 'I do not like to talk about a man, even if I were to get this or that (for doing so)." She said: "I said: 'O Messenger of Allah! Safiyyah is a woman who is ..." and she used her hand as if to indicate that she is short - "So he said: 'You have said a statement which, if it were mixed in with the water of the sea, it would pollute it}}
\hadithdefcmd{tirmidhi}{2503}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنْ أَبِي حُذَيْفَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أُحِبُّ أَنِّي حَكَيْتُ أَحَدًا وَأَنَّ لِي كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو حُذَيْفَةَ هُوَ كُوفِيٌّ مِنْ أَصْحَابِ ابْنِ مَسْعُودٍ وَيُقَالُ اسْمُهُ سَلَمَةُ بْنُ صُهَيْبَةَ ‏.‏\hadithno{2503}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated that the Messenger of Allah (s.a.w) said:"I do not like to talk about anyone, even if I were to get this or that}}
\hadithdefcmd{tirmidhi}{2504}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا بُرَيْدُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىُّ الْمُسْلِمِينَ أَفْضَلُ قَالَ ‏ "‏ مَنْ سَلِمَ الْمُسْلِمُونَ مِنْ لِسَانِهِ وَيَدِهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبِي مُوسَى ‏.‏\hadithno{2504}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Musa said:"The Messenger of Allah (s.a.w) was asked: 'Which of the Muslims is the most virtuous?' He said: 'The one whom the Muslims are safe from his tongue and his hand}}
\hadithdefcmd{tirmidhi}{2505}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْحَسَنِ بْنِ أَبِي يَزِيدَ الْهَمْدَانِيُّ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَيَّرَ أَخَاهُ بِذَنْبٍ لَمْ يَمُتْ حَتَّى يَعْمَلَهُ ‏"‏ ‏.‏ قَالَ أَحْمَدُ مِنْ ذَنْبٍ قَدْ تَابَ مِنْهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَلَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ ‏.‏ وَخَالِدُ بْنُ مَعْدَانَ لَمْ يُدْرِكْ مُعَاذَ بْنَ جَبَلٍ وَرُوِيَ عَنْ خَالِدِ بْنِ مَعْدَانَ أَنَّهُ أَدْرَكَ سَبْعِينَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَمَاتَ مُعَاذُ بْنُ جَبَلٍ فِي خِلاَفَةِ عُمَرَ بْنِ الْخَطَّابِ وَخَالِدُ بْنُ مَعْدَانَ رَوَى عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ مُعَاذٍ عَنْ مُعَاذٍ غَيْرَ حَدِيثٍ ‏.‏\hadithno{2505}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Khalid bin Ma'dan narrated from Mu'adh bin Jabal that the Messenger of Allah (s.a.w) said:"Whoever shames his brother for a sin, he shall not die until he (himself) commits it." (One of the narrators) Ahmad said: They said: 'From a sin he has repented from}}
\hadithdefcmd{tirmidhi}{2506}{حَدَّثَنَا عُمَرُ بْنُ إِسْمَاعِيلَ بْنِ مُجَالِدِ بْنِ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، ح قَالَ وَأَخْبَرَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا أُمَيَّةُ بْنُ الْقَاسِمِ الْحَذَّاءُ الْبَصْرِيُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ بُرْدِ بْنِ سِنَانٍ، عَنْ مَكْحُولٍ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُظْهِرِ الشَّمَاتَةَ لأَخِيكَ فَيَرْحَمُهُ اللَّهُ وَيَبْتَلِيكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَمَكْحُولٌ قَدْ سَمِعَ مِنْ وَاثِلَةَ بْنِ الأَسْقَعِ وَأَنَسِ بْنِ مَالِكٍ وَأَبِي هِنْدٍ الدَّارِيِّ وَيُقَالُ إِنَّهُ لَمْ يَسْمَعْ مِنْ أَحَدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ مِنْ هَؤُلاَءِ الثَّلاَثَةِ ‏.‏ وَمَكْحُولٌ شَامِيٌّ يُكْنَى أَبَا عَبْدِ اللَّهِ وَكَانَ عَبْدًا فَأُعْتِقَ وَمَكْحُولٌ الأَزْدِيُّ بَصْرِيٌّ سَمِعَ مِنْ عَبْدِ اللَّهِ بْنِ عُمَرَ يَرْوِي عَنْهُ عُمَارَةُ بْنُ زَاذَانَ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ تَمِيمِ بْنِ عَطِيَّةَ، قَالَ كَثِيرًا مَا كُنْتُ أَسْمَعُ مَكْحُولاً يُسْأَلُ فَيَقُولُ نَدَانَمْ ‏.‏\hadithno{2506}\hadithgrade{Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Wathilah bin Al-Asqa' narrated that the Messenger of Allah (s.a.w) said:"Do not rejoice over the mishaps of your brother so that Allah has mercy on him and subjects you to trials}}
\hadithdefcmd{tirmidhi}{2507}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ يَحْيَى بْنِ وَثَّابٍ، عَنْ شَيْخٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏الْمُسْلِمَ إِذَا كَانَ يُخَالِطَ النَّاسَ وَيَصْبِرُ عَلَى أَذَاهُمْ خَيْرٌ مِنَ الْمُسْلِمِ الَّذِي لاَ يُخَالِطُ النَّاسَ وَلاَ يَصْبِرُ عَلَى أَذَاهُمْ ‏"‏ ‏.‏ قَالَ أَبُو مُوسَى قَالَ ابْنُ أَبِي عَدِيٍّ كَانَ شُعْبَةُ يَرَى أَنَّهُ ابْنُ عُمَرَ ‏.‏\hadithno{2507}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Yahya bin Wath-thab narrated:"From a Shaikh among the Companions of the Prophet (s.a.w) , I think it is from the Prophet(s.a.w), who said: 'The Muslim who mixes with the people and he is patient with their harm is better than the Muslim who does not mix with the people and is not patient with their harm}}
\hadithdefcmd{tirmidhi}{2508}{حَدَّثَنَا أَبُو يَحْيَى، مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ الْبَغْدَادِيُّ حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمَخْرَمِيُّ، هُوَ مِنْ وَلَدِ الْمِسْوَرِ بْنِ مَخْرَمَةَ عَنْ عُثْمَانَ بْنِ مُحَمَّدٍ الأَخْنَسِيِّ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَسُوءَ ذَاتِ الْبَيْنِ فَإِنَّهَا الْحَالِقَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ وَسُوءَ ذَاتِ الْبَيْنِ ‏"‏ ‏.‏ إِنَّمَا يَعْنِي الْعَدَاوَةَ وَالْبَغْضَاءَ وَقَوْلُهُ ‏"‏ الْحَالِقَةُ ‏"‏ ‏.‏ يَقُولُ إِنَّهَا تَحْلِقُ الدِّينَ ‏.‏\hadithno{2508}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"Beware of evil with each other, for indeed it is the Haliqah." [The meaning of his saying]: "Süw'a Dhãt Al-Bain (evil with each other) is enmity and hatred, and his saying: "The Haliqah" [it is said] that it severs the religion}}
\hadithdefcmd{tirmidhi}{2509}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أُخْبِرُكُمْ بِأَفْضَلَ مِنْ دَرَجَةِ الصِّيَامِ وَالصَّلاَةِ وَالصَّدَقَةِ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ صَلاَحُ ذَاتِ الْبَيْنِ فَإِنَّ فَسَادَ ذَاتِ الْبَيْنِ هِيَ الْحَالِقَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَيُرْوَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ هِيَ الْحَالِقَةُ لاَ أَقُولُ تَحْلِقُ الشَّعْرَ وَلَكِنْ تَحْلِقُ الدِّينَ ‏"‏ ‏.‏\hadithno{2509}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Ad-Darda' narrated that the Messenger of Allah (s.a.w) said:"Shall I not inform you of what is more virtuous than the rank of fasting, Salat, and charity?" They said: "But of course!" He said: "Making peace between each other. For indeed spoiling relations with each other is the Haliqah." It has been related that the Prophet SAW said: "It is the Haliqah, I do not speak of what cuts hair, but it severs the religion}}
\hadithdefcmd{tirmidhi}{2510}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ حَرْبِ بْنِ شَدَّادٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ يَعِيشَ بْنِ الْوَلِيدِ، أَنَّ مَوْلَى الزُّبَيْرِ، حَدَّثَهُ أَنَّ الزُّبَيْرَ بْنَ الْعَوَّامِ حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ دَبَّ إِلَيْكُمْ دَاءُ الأُمَمِ قَبْلَكُمُ الْحَسَدُ وَالْبَغْضَاءُ هِيَ الْحَالِقَةُ لاَ أَقُولُ تَحْلِقُ الشَّعْرَ وَلَكِنْ تَحْلِقُ الدِّينَ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَدْخُلُوا الْجَنَّةَ حَتَّى تُؤْمِنُوا وَلاَ تُؤْمِنُوا حَتَّى تَحَابُّوا أَفَلاَ أُنَبِّئُكُمْ بِمَا يُثَبِّتُ ذَاكُمْ لَكُمْ أَفْشُوا السَّلاَمَ بَيْنَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ قَدِ اخْتَلَفُوا فِي رِوَايَتِهِ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ فَرَوَى بَعْضُهُمْ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ يَعِيشَ بْنِ الْوَلِيدِ عَنْ مَوْلَى الزُّبَيْرِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرُوا فِيهِ عَنِ الزُّبَيْرِ ‏.‏\hadithno{2510}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Az-Zubair bin Al-'Awwam narrated that the Prophet (s.a.w) said:"The disease of the nations before you is creeping towards you: Envy and hatred, it is the Haliqah. I do not speak of what cuts the hair, but what severs the religion. By the One in Whose Hand is my soul! You will not enter Paradise until you believe, and you will not believe until you love each other. Shall I tell you about what will strengthen that for you? Spread the Salam among each other}}
\hadithdefcmd{tirmidhi}{2511}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ عُيَيْنَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ ذَنْبٍ أَجْدَرُ أَنْ يُعَجِّلَ اللَّهُ لِصَاحِبِهِ الْعُقُوبَةَ فِي الدُّنْيَا مَعَ مَا يَدَّخِرُ لَهُ فِي الآخِرَةِ مِنَ الْبَغْىِ وَقَطِيعَةِ الرَّحِمِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2511}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Bakrah narrated that the Messenger of Allah (s.a.w) said:"There is no sin more worthy of Allah hastening the punishment upon its practitioner in the world – along with what is in store for him in the Hereafter – than tyranny and severing the ties of kinship.” (Sahih)}}
\hadithdefcmd{tirmidhi}{2512}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنِ الْمُثَنَّى بْنِ الصَّبَّاحِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَصْلَتَانِ مَنْ كَانَتَا فِيهِ كَتَبَهُ اللَّهُ شَاكِرًا صَابِرًا وَمَنْ لَمْ تَكُونَا فِيهِ لَمْ يَكْتُبْهُ اللَّهُ شَاكِرًا وَلاَ صَابِرًا مَنْ نَظَرَ فِي دِينِهِ إِلَى مَنْ هُوَ فَوْقَهُ فَاقْتَدَى بِهِ وَنَظَرَ فِي دُنْيَاهُ إِلَى مَنْ هُوَ دُونَهُ فَحَمِدَ اللَّهَ عَلَى مَا فَضَّلَهُ بِهِ عَلَيْهِ كَتَبَهُ اللَّهُ شَاكِرًا صَابِرًا وَمَنْ نَظَرَ فِي دِينِهِ إِلَى مَنْ هُوَ دُونَهُ وَنَظَرَ فِي دُنْيَاهُ إِلَى مَنْ هُوَ فَوْقَهُ فَأَسِفَ عَلَى مَا فَاتَهُ مِنْهُ لَمْ يَكْتُبْهُ اللَّهُ شَاكِرًا وَلاَ صَابِرًا ‏"‏ ‏.‏ أَخْبَرَنَا مُوسَى بْنُ حِزَامٍ الرَّجُلُ الصَّالِحُ، حَدَّثَنَا عَلِيُّ بْنُ إِسْحَاقَ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا الْمُثَنَّى بْنُ الصَّبَّاحِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَلَمْ يَذْكُرْ سُوَيْدُ بْنُ نَصْرٍ فِي حَدِيثِهِ عَنْ أَبِيهِ ‏.‏\hadithno{2512}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu'aib narrated from his grandfather 'Abdullah bin 'Amr, that the Messenger of Allah (s.a.w) said:"There are two traits, whoever has them in him, Allah writes him down as grateful and patient. And whoever does not have them, Allah does not write him down as grateful, nor patient. Whoever looks to one above him for his religion, and follows him in it, and whoever looks to one who is below him in worldly matters, and praises Allah for the blessings He has favored the one who is above him with, then Allah writes him down as grateful and patient. And whoever looks to one who is below him for his religion, and looks to one who is above him for worldly matters, and grieves over what missed him of it, Allah does not write him down as grateful nor as patient." (Another chain reaching to) 'Amr bin Shu'aib, from his father, from his grandfather from the Prophet (s.a.w) with similar narration}}
\hadithdefcmd{tirmidhi}{2513}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ انْظُرُوا إِلَى مَنْ هُوَ أَسْفَلَ مِنْكُمْ وَلاَ تَنْظُرُوا إِلَى مَنْ هُوَ فَوْقَكُمْ فَإِنَّهُ أَجْدَرُ أَنْ لاَ تَزْدَرُوا نِعْمَةَ اللَّهِ عَلَيْكُمْ ‏"‏ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2513}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Look to one who is lower than you, and do not look to one who is above you. For indeed that is more worthy(so that you will) not belittle Allah's favors upon you}}
\hadithdefcmd{tirmidhi}{2514}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الْبَصْرِيُّ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، ح قَالَ وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْبَزَّازُ، حَدَّثَنَا سَيَّارٌ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ الْمَعْنَى، وَاحِدٌ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ حَنْظَلَةَ الأُسَيْدِيِّ، وَكَانَ، مِنْ كُتَّابِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ مَرَّ بِأَبِي بَكْرٍ وَهُوَ يَبْكِي فَقَالَ مَا لَكَ يَا حَنْظَلَةُ قَالَ نَافَقَ حَنْظَلَةُ يَا أَبَا بَكْرٍ نَكُونُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم يُذَكِّرُنَا بِالنَّارِ وَالْجَنَّةِ كَأَنَّا رَأْىَ عَيْنٍ فَإِذَا رَجَعْنَا إِلَى الأَزْوَاجِ وَالضَّيْعَةِ نَسِينَا كَثِيرًا ‏.‏ قَالَ فَوَاللَّهِ إِنَّا لَكَذَلِكَ انْطَلِقْ بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَانْطَلَقْنَا فَلَمَّا رَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا لَكَ يَا حَنْظَلَةُ ‏"‏ ‏.‏ قَالَ نَافَقَ حَنْظَلَةُ يَا رَسُولَ اللَّهِ نَكُونُ عِنْدَكَ تُذَكِّرُنَا بِالنَّارِ وَالْجَنَّةِ كَأَنَّا رَأْىَ عَيْنٍ فَإِذَا رَجَعْنَا عَافَسْنَا الأَزْوَاجَ وَالضَّيْعَةَ وَنَسِينَا كَثِيرًا ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ تَدُومُونَ عَلَى الْحَالِ الَّذِي تَقُومُونَ بِهَا مِنْ عِنْدِي لَصَافَحَتْكُمُ الْمَلاَئِكَةُ فِي مَجَالِسِكُمْ وَفِي طُرُقِكُمْ وَعَلَى فُرُشِكُمْ وَلَكِنْ يَا حَنْظَلَةُ سَاعَةً وَسَاعَةً وَسَاعَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2514}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu 'Uthman narrated from Hanzalah Al-Usaidi – and he was one of the scribes of the Messenger of Allah (s.a.w)- that he passed by Abu Bakr while he was crying, so he(Abu Bakr) said to him:“What is wrong with you, O Hanzalah?” He replied: “Hanzalah has become a hypocrite O Abu Bakr! When we are with the Messenger of Allah (s.a.w) we remember the Fire and Paradise as if we are looking at them with the naked eye. But when we return we busy ourselves with our wives and livelihood and we forget so much.” He(Abu Bakr) said: “By Allah! The same thing happens to me. Let us go to the Messenger of Allah (s.a.w).” (Hanzalah said:) “So he went." When the Messenger of Allah (s.a.w) saw him, he said: “What is wrong with you O Hanzalah?” He said: “Hanzalah has become a hypocrite O Messenger of Allah! When we are with you we remember the Fire and Paradise as if we can see them with the naked eye. But when we return we are busy with our wives and livelihood, and we forget so much.” He said: “So the Messenger of Allah (s.a.w) said: 'If you were to abide in the state that you are in when you are with me, then the Angels would shake hands with you in your gatherings, and upon your bedding, and in your paths. But O Hanzalah! There is a time for this and a time for that.'” (Sahih)}}
\hadithdefcmd{tirmidhi}{2515}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُؤْمِنُ أَحَدُكُمْ حَتَّى يُحِبَّ لأَخِيهِ مَا يُحِبُّ لِنَفْسِهِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2515}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas narrated that the Prophet(s.a.w) said:"None of you believes until he loves for his brother what he loves for himself}}
\hadithdefcmd{tirmidhi}{2516}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا لَيْثُ بْنُ سَعْدٍ، وَابْنُ، لَهِيعَةَ عَنْ قَيْسِ بْنِ الْحَجَّاجِ، قَالَ وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، حَدَّثَنِي قَيْسُ بْنُ الْحَجَّاجِ الْمَعْنَى، وَاحِدٌ، عَنْ حَنَشٍ الصَّنْعَانِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمًا فَقَالَ ‏ "‏ يَا غُلاَمُ إِنِّي أُعَلِّمُكَ كَلِمَاتٍ احْفَظِ اللَّهَ يَحْفَظْكَ احْفَظِ اللَّهَ تَجِدْهُ تُجَاهَكَ إِذَا سَأَلْتَ فَاسْأَلِ اللَّهَ وَإِذَا اسْتَعَنْتَ فَاسْتَعِنْ بِاللَّهِ وَاعْلَمْ أَنَّ الأُمَّةَ لَوِ اجْتَمَعَتْ عَلَى أَنْ يَنْفَعُوكَ بِشَيْءٍ لَمْ يَنْفَعُوكَ إِلاَّ بِشَيْءٍ قَدْ كَتَبَهُ اللَّهُ لَكَ وَلَوِ اجْتَمَعُوا عَلَى أَنْ يَضُرُّوكَ بِشَيْءٍ لَمْ يَضُرُّوكَ إِلاَّ بِشَيْءٍ قَدْ كَتَبَهُ اللَّهُ عَلَيْكَ رُفِعَتِ الأَقْلاَمُ وَجَفَّتِ الصُّحُفُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2516}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn 'Abbas narrated:"I was behind the Prophet(s.a.w) one day when he said: 'O boy! I will teach you a statement: Be mindful of Allah and He will protect you. Be mindful of Allah and you will find Him before you. When you ask, ask Allah, and when you seek aid, seek Allah's aid. Know that if the entire creation were to gather together to do something to benefit you- you would never get any benefit except that Allah had written for you. And if they were to gather to do something to harm you- you would never be harmed except that Allah had written for you. The pens are lifted and the pages are dried}}
\hadithdefcmd{tirmidhi}{2517}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا الْمُغِيرَةُ بْنُ أَبِي قُرَّةَ السَّدُوسِيُّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَعْقِلُهَا وَأَتَوَكَّلُ أَوْ أُطْلِقُهَا وَأَتَوَكَّلُ قَالَ ‏ "‏ اعْقِلْهَا وَتَوَكَّلْ ‏"‏ ‏.‏ قَالَ عَمْرُو بْنُ عَلِيٍّ قَالَ يَحْيَى وَهَذَا عِنْدِي حَدِيثٌ مُنْكَرٌ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ أَنَسٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ عَنْ عَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏\hadithno{2517}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik narrated that a man said:"O Messenger of Allah! Shall I tie it and rely(upon Allah), or leave it loose and rely(upon Allah)?" He said: "Tie it and rely(upon Allah)." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2518}{حَدَّثَنَا أَبُو مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، حَدَّثَنَا شُعْبَةُ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي الْحَوْرَاءِ السَّعْدِيِّ، قَالَ قُلْتُ لِلْحَسَنِ بْنِ عَلِيٍّ مَا حَفِظْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ حَفِظْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعْ مَا يَرِيبُكَ إِلَى مَا لاَ يَرِيبُكَ فَإِنَّ الصِّدْقَ طُمَأْنِينَةٌ وَإِنَّ الْكَذِبَ رِيبَةٌ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ وَأَبُو الْحَوْرَاءِ السَّعْدِيُّ اسْمُهُ رَبِيعَةُ بْنُ شَيْبَانَ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ بُرَيْدٍ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2518}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Hasan bin 'Ali said:"I remember that the Messenger of Allah (s.a.w) said: 'Leave what makes you in doubt for what does not make you in doubt. The truth brings tranquility while falsehood sows doubt.'" Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2519}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ الْبَصْرِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي الْوَزِيرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمَخْرَمِيُّ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نُبَيْهٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ ذُكِرَ رَجُلٌ عِنْدَ النَّبِيِّ صلى الله عليه وسلم بِعِبَادَةٍ وَاجْتِهَادٍ وَذُكِرَ عِنْدَهُ آخَرُ بِرِعَةٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَعْدِلْ بِالرِّعَةِ ‏"‏ ‏.‏ وَعَبْدُ اللَّهِ بْنُ جَعْفَرٍ هُوَ مِنْ وَلَدِ الْمِسْوَرِ بْنِ مَخْرَمَةَ وَهُوَ مَدَنِيٌّ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2519}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muhammad bin Al-Munkadir narrated from Jabir, that a man was mentioned in the presence of the Prophet (s.a.w) for his worship and striving in it, and another man was mentioned for his cautious piety. So the Prophet (s.a.w) said:"Nothing is equal to cautious piety}}
\hadithdefcmd{tirmidhi}{2520}{حَدَّثَنَا هَنَّادٌ، وَأَبُو زُرْعَةَ وَغَيْرُ وَاحِدٍ قَالُوا أَخْبَرَنَا قَبِيصَةُ، عَنْ إِسْرَائِيلَ، عَنْ هِلاَلِ بْنِ مِقْلاَصٍ الصَّيْرَفِيِّ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَكَلَ طَيِّبًا وَعَمِلَ فِي سُنَّةٍ وَأَمِنَ النَّاسُ بَوَائِقَهُ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنَّ هَذَا الْيَوْمَ فِي النَّاسِ لَكَثِيرٌ ‏.‏ قَالَ ‏"‏ وَسَيَكُونُ فِي قُرُونٍ بَعْدِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ إِسْرَائِيلَ ‏.‏\hadithno{2520}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah (s.a.w) said:"Whoever eats the Tayyib and acts in accordance with the Sunnah, and the people are safe from his harm, he will enter Paradise." So a man said: "O Messenger of Allah! This is the case with many people today." So he said: "It shall be so in the generation after me}}
\hadithdefcmd{tirmidhi}{2521}{حَدَّثَنَا عَبَّاسٌ الدُّورِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، عَنْ إِسْرَائِيلَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا الْحَدِيثِ، فَلَمْ يَعْرِفْهُ إِلاَّ مِنْ حَدِيثِ إِسْرَائِيلَ وَلَمْ يَعْرِفِ اسْمَ أَبِي بِشْرٍ ‏.‏ حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ أَبِي مَرْحُومٍ عَبْدِ الرَّحِيمِ بْنِ مَيْمُونٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْطَى لِلَّهِ وَمَنَعَ لِلَّهِ وَأَحَبَّ لِلَّهِ وَأَبْغَضَ لِلَّهِ وَأَنْكَحَ لِلَّهِ فَقَدِ اسْتَكْمَلَ إِيمَانَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏\hadithno{2521}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bin Mu'adh[bin Anas] Al-Juhni narrated from his father that the Prophet (s.a.w) said:"Whoever gives for the sake of Allah, withholds for the sake of Allah, loves for the sake of Allah, hates for the sake of Allah, and marries for the sake of Allah, he has indeed perfected his faith}}
\hadithdefcmd{tirmidhi}{2522}{حَدَّثَنَا العَبَّاسُ الدُّورِيُّ حَدَّثَنَا عُبيْدُ اللهِ بْنُ مُوسَى أََخْبَرَنَا شَيْبَانُُ عَنْ فِرَاسٍ عَنْ عَطِيَّةَ عَنْ أَبِي سَعِيدٍ الخُدْرِيِّ ، عَنِ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ قَالَ : " أَوَّلُ زُمْرَةٍ تَدْخُلُ الجَنَّةَ عَلَى صُورَةِ القَمَرِ لَيْلَةَ البَدْرِ ، وَالثَّانِيَةُ عَلَى لَوْنِ أَحْسَنِ كَوْكَبٍ دُرِّيٍّ فِي السَّمَاءِ ، لِكُلِّ رَجُلٍ مِنْهُمْ زَوْجَتَانِ عَلَى كُلِّ زَوْجَةٍ سَبْعُونَ حُلَّةً يَبْدُو مُخُّ سَاقِهَا مِنْ وَرَائِهَا\hadithno{2522}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Prophet (s.a.w) said:"The first batch to enter Paradise will appear like the moon of a night that is full. The second will appear like the color of the most beautiful star in the sky. Each man among them shall have two wives, each wife wearing seventy bracelets, with the marrow of their shins being visible from behind them}}
