% Auto-generated chapter 22 for nasai
% Hadiths in this chapter: 345

\hadithdefcmd{nasai}{2090}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - قَالَ حَدَّثَنَا أَبُو سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، أَنَّ أَعْرَابِيًّا، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثَائِرَ الرَّأْسِ فَقَالَ يَا رَسُولَ اللَّهِ أَخْبِرْنِي مَاذَا فَرَضَ اللَّهُ عَلَىَّ مِنَ الصَّلاَةِ قَالَ ‏"‏ الصَّلَوَاتُ الْخَمْسُ إِلاَّ أَنْ تَطَوَّعَ شَيْئًا ‏"‏ ‏.‏ قَالَ أَخْبِرْنِي بِمَا افْتَرَضَ اللَّهُ عَلَىَّ مِنَ الصِّيَامِ قَالَ ‏"‏ صِيَامُ شَهْرِ رَمَضَانَ إِلاَّ أَنْ تَطَوَّعَ شَيْئًا ‏"‏ ‏.‏ قَالَ أَخْبِرْنِي بِمَا افْتَرَضَ اللَّهُ عَلَىَّ مِنَ الزَّكَاةِ فَأَخْبَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَرَائِعِ الإِسْلاَمِ ‏.‏ فَقَالَ وَالَّذِي أَكْرَمَكَ لاَ أَتَطَوَّعُ شَيْئًا وَلاَ أَنْقُصُ مِمَّا فَرَضَ اللَّهُ عَلَىَّ شَيْئًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفْلَحَ إِنْ صَدَقَ ‏"‏ ‏.‏ أَوْ ‏"‏ دَخَلَ الْجَنَّةَ إِنْ صَدَقَ ‏"‏ ‏.‏\hadithno{2090}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Talhah bin 'Ubaidullah that:a Bedouin came to the Messenger of Allah with unkempt hair and said: "O Allah has enjoined upon me of Salah." He said: "The five daily prayers, unless you do any more voluntarily." He said: "Tell me what Allah has enjoined upon me voluntarily." He said: "Tell me what Allah has enjoined upon me of fasting." He said: "Fasting the month of Ramadan, unless you do any more voluntarily." He said: "Tell me what Allah has enjoined upon me of Zakah." The Messenger of Allah told him of the laws of Islam, He said: "By the One Who has honored you, I will not do anything voluntarily, and I will not do anything voluntarily, and I will not do less than that which Allah has enjoined upon, me: The Messenger of Allah said: "He will succeed if he is sincere," or "He will enter Paradise if he is sincere}}
\hadithdefcmd{nasai}{2091}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ نُهِينَا فِي الْقُرْآنِ أَنْ نَسْأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ شَىْءٍ فَكَانَ يُعْجِبُنَا أَنْ يَجِيءَ الرَّجُلُ الْعَاقِلُ مِنْ أَهْلِ الْبَادِيَةِ فَيَسْأَلَهُ فَجَاءَ رَجُلٌ مِنْ أَهْلِ الْبَادِيَةِ فَقَالَ يَا مُحَمَّدُ أَتَانَا رَسُولُكَ فَأَخْبَرَنَا أَنَّكَ تَزْعُمُ أَنَّ اللَّهَ عَزَّ وَجَلَّ أَرْسَلَكَ قَالَ ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَ فَمَنْ خَلَقَ السَّمَاءَ قَالَ ‏"‏ اللَّهُ ‏"‏ ‏.‏ قَالَ فَمَنْ خَلَقَ الأَرْضَ قَالَ ‏"‏ اللَّهُ ‏"‏ ‏.‏ قَالَ فَمَنْ نَصَبَ فِيهَا الْجِبَالَ قَالَ ‏"‏ اللَّهُ ‏"‏ ‏.‏ قَالَ فَمَنْ جَعَلَ فِيهَا الْمَنَافِعَ قَالَ ‏"‏ اللَّهُ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي خَلَقَ السَّمَاءَ وَالأَرْضَ وَنَصَبَ فِيهَا الْجِبَالَ وَجَعَلَ فِيهَا الْمَنَافِعَ آللَّهُ أَرْسَلَكَ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ وَزَعَمَ رَسُولُكَ أَنَّ عَلَيْنَا خَمْسَ صَلَوَاتٍ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ قَالَ ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي أَرْسَلَكَ آللَّهُ أَمَرَكَ بِهَذَا قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ وَزَعَمَ رَسُولُكَ أَنَّ عَلَيْنَا زَكَاةَ أَمْوَالِنَا قَالَ ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي أَرْسَلَكَ آللَّهُ أَمَرَكَ بِهَذَا قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ وَزَعَمَ رَسُولُكَ أَنَّ عَلَيْنَا صَوْمَ شَهْرِ رَمَضَانَ فِي كُلِّ سَنَةٍ ‏.‏ قَالَ ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي أَرْسَلَكَ آللَّهُ أَمَرَكَ بِهَذَا قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ وَزَعَمَ رَسُولُكَ أَنَّ عَلَيْنَا الْحَجَّ مَنِ اسْتَطَاعَ إِلَيْهِ سَبِيلاً ‏.‏ قَالَ ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي أَرْسَلَكَ آللَّهُ أَمَرَكَ بِهَذَا قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَوَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ أَزِيدَنَّ عَلَيْهِنَّ شَيْئًا وَلاَ أَنْقُصُ ‏.‏ فَلَمَّا وَلَّى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَئِنْ صَدَقَ لَيَدْخُلَنَّ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{2091}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"We were forbidden in the Quran to ask the Prophet about anything not imperative, so we liked it when a wise man from among the people of the desert came and asked him. A man from among the desert people came and said: 'O Muhammad, your messenger came to us and told us that you say that Allah, the Mighty and Sublime, has sent you.' He said: 'He spoke the truth.' He said: 'Who created the heavens?' He said: 'Allah.' He said: 'Who created the Earth?' He said: 'Allah.' He said: 'Who set up the mountains in it?' He said: 'Allah.' He said: 'Who created beneficial things in them?' He said: 'Allah.' He said: 'By the One Who created the heavens and the Earth, and set up the mountains therein, and created beneficial things in them, has Allah sent you?' He said: 'Yes.' He said: 'Your messenger said that we have to offer five prayers each day and night.' He said: 'He spoke the truth.' He said: 'By the One Who sent you, has Allah commanded you to do this?' He said: 'Yes.' He said: 'Your messenger said that we have to pay Zakah on our wealth.' He said: 'He spoke the truth.' He said: 'By the One Who sent you, has Allah commanded you to do this?' He said: 'Yes.' He said: 'Your messenger said that we have to fast the month of Ramadan each year.' He said: 'He spoke the truth.' He said: 'By the One Who sent You, has Allah commanded you to do this?' He said: 'Yes.' He said: 'Your messenger said that we have to perform Hajj, those who can afford it.' He said: 'He spoke the truth.' He said: 'By the One Who sent you, has Allah commanded you to do this?' He said: 'Yes.' He said: 'By the One Who sent you with the truth, I will not do more than this or less.' When he left, the Prophet said: 'If he is sincere, he will certainly enter paradise}}
\hadithdefcmd{nasai}{2092}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، عَنِ اللَّيْثِ، عَنْ سَعِيدٍ، عَنْ شَرِيكِ بْنِ أَبِي نَمِرٍ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ بَيْنَا نَحْنُ جُلُوسٌ فِي الْمَسْجِدِ جَاءَ رَجُلٌ عَلَى جَمَلٍ فَأَنَاخَهُ فِي الْمَسْجِدِ ثُمَّ عَقَلَهُ فَقَالَ لَهُمْ أَيُّكُمْ مُحَمَّدٌ - وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُتَّكِئٌ بَيْنَ ظَهْرَانَيْهِمْ - قُلْنَا لَهُ هَذَا الرَّجُلُ الأَبْيَضُ الْمُتَّكِئُ فَقَالَ لَهُ الرَّجُلُ يَا ابْنَ عَبْدِ الْمُطَّلِبِ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أَجَبْتُكَ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ إِنِّي سَائِلُكَ يَا مُحَمَّدُ فَمُشَدِّدٌ عَلَيْكَ فِي الْمَسْأَلَةِ فَلاَ تَجِدَنَّ فِي نَفْسِكَ ‏.‏ قَالَ ‏"‏ سَلْ مَا بَدَا لَكَ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ نَشَدْتُكَ بِرَبِّكَ وَرَبِّ مَنْ قَبْلَكَ آللَّهُ أَرْسَلَكَ إِلَى النَّاسِ كُلِّهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ اللَّهَ آللَّهُ أَمَرَكَ أَنْ تُصَلِّيَ الصَّلَوَاتِ الْخَمْسَ فِي الْيَوْمِ وَاللَّيْلَةِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ اللَّهَ آللَّهُ أَمَرَكَ أَنْ تَصُومَ هَذَا الشَّهْرَ مِنَ السَّنَةِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ اللَّهَ آللَّهُ أَمَرَكَ أَنْ تَأْخُذَ هَذِهِ الصَّدَقَةَ مِنْ أَغْنِيَائِنَا فَتَقْسِمَهَا عَلَى فُقَرَائِنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ آمَنْتُ بِمَا جِئْتَ بِهِ وَأَنَا رَسُولُ مَنْ وَرَائِي مِنْ قَوْمِي وَأَنَا ضِمَامُ بْنُ ثَعْلَبَةَ أَخُو بَنِي سَعْدِ بْنِ بَكْرٍ ‏.‏ خَالَفَهُ يَعْقُوبُ بْنُ إِبْرَاهِيمَ ‏.‏\hadithno{2092}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:"While we were sitting in the Masjid, a man came on a camel and made it keneel in the Masjid, then he hobbled it and said to them: 'Which of you is Muhammad?' The Messenger of Allah was reclining amid his Companions, and we said to him: This white man who is reclining.' The man said to him: 'O son of 'Abdul-Muttalib.' The Messenger of Allah said: ' I have answered you.' The man said; 'O Muhammad, I am going to ask you questions, and I will be harsh in asking; do not get upset.; The man said: 'I adjure you by your Lord and the Lord of those who cam before you, has Allah sent you to all the people?' The Messenger of Allah said: 'By Allah, yes.' He said; 'I adjure you by Allah, has Allah commanded you to offer five prayers each day and night?' The Messenger of Allah said: 'By Allah, yes.; He said: 'I adjure you by Allah, has Allah commanded you to fast this month each year? The Messenger of Allah said: 'By Allah, Yes.' He said: 'I adjure you by Allah, has Allah commanded you to take this charity from our rich and distribute it among our poor?' The Messenger of Allah said. 'By Allah, yes.' The man said: 'I believe in that which you have brought, and I am the envoy of my people who are coming after me. I am Dimam bin Thalabah, the brother of Banu sad bin Bakr."' Yaqub bin Ibrahim contradicted him}}
\hadithdefcmd{nasai}{2093}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، مِنْ كِتَابِهِ قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنَا ابْنُ عَجْلاَنَ، وَغَيْرُهُ، مِنْ إِخْوَانِنَا عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ بَيْنَمَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم جُلُوسٌ فِي الْمَسْجِدِ دَخَلَ رَجُلٌ عَلَى جَمَلٍ فَأَنَاخَهُ فِي الْمَسْجِدِ ثُمَّ عَقَلَهُ ثُمَّ قَالَ أَيُّكُمْ مُحَمَّدٌ - وَهُوَ مُتَّكِئٌ بَيْنَ ظَهْرَانَيْهِمْ - فَقُلْنَا لَهُ هَذَا الرَّجُلُ الأَبْيَضُ الْمُتَّكِئُ فَقَالَ لَهُ الرَّجُلُ يَا ابْنَ عَبْدِ الْمُطَّلِبِ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أَجَبْتُكَ ‏"‏ ‏.‏ قَالَ الرَّجُلُ يَا مُحَمَّدُ إِنِّي سَائِلُكَ فَمُشَدِّدٌ عَلَيْكَ فِي الْمَسْأَلَةِ ‏.‏ قَالَ ‏"‏ سَلْ عَمَّا بَدَا لَكَ ‏"‏ ‏.‏ قَالَ أَنْشُدُكَ بِرَبِّكَ وَرَبِّ مَنْ قَبْلَكَ آللَّهُ أَرْسَلَكَ إِلَى النَّاسِ كُلِّهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ اللَّهَ آللَّهُ أَمَرَكَ أَنْ تَصُومَ هَذَا الشَّهْرَ مِنَ السَّنَةِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ اللَّهَ آللَّهُ أَمَرَكَ أَنْ تَأْخُذَ هَذِهِ الصَّدَقَةَ مِنْ أَغْنِيَائِنَا فَتَقْسِمَهَا عَلَى فُقَرَائِنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ إِنِّي آمَنْتُ بِمَا جِئْتَ بِهِ وَأَنَا رَسُولُ مَنْ وَرَائِي مِنْ قَوْمِي وَأَنَا ضِمَامُ بْنُ ثَعْلَبَةَ أَخُو بَنِي سَعْدِ بْنِ بَكْرٍ ‏.‏ خَالَفَهُ عُبَيْدُ اللَّهِ بْنُ عُمَرَ ‏.‏\hadithno{2093}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik said:"while we were with the Messenger of Allah, sitting in the Masjid, a man entered on a camel. He made it kneel in the Masjid, then he hobbled it. Then he said; 'Which of you is Muhammad?' He was reclining among them, and we said to him: 'This white man who is reclining.' The man said to him: 'O son of 'Abdul-Muttalib.' The Messenger of Allah said to him: 'I have answered you.' The man said: 'O Muhammad, I am going to ask you questions and I will be harsh in asking.' He said; 'Ask whatever you like.' The man said; 'I adjure you by your Lord, and the Lord of those who came begfore you, has Allah sent you to all the people?' The messenger of Allah said: 'by Allah, yes,' He said: 'Iadjure you by Allah, has Allah commanded you to fast this month each year?' The Messenger of Allah said: 'I adjure you by Allah, has Allah commanded you to take this charity from our rich and divide it among our poor?' The Messenger of Allah said: 'By Allah, Yes.' The ma said; 'I believe in that which you have brought, and I am the envoy of my people who are coming after me. I am Dimam bin Thalabah, the brother of Banu sad bin Bakr."' (Sahih) 'Ubaidullah bin 'Umar contradicted him}}
\hadithdefcmd{nasai}{2094}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا إِسْحَاقُ، قَالَ حَدَّثَنَا أَبُو عُمَارَةَ، حَمْزَةُ بْنُ الْحَارِثِ بْنِ عُمَيْرٍ قَالَ سَمِعْتُ أَبِي يَذْكُرُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَمَا النَّبِيُّ صلى الله عليه وسلم مَعَ أَصْحَابِهِ جَاءَ رَجُلٌ مِنْ أَهْلِ الْبَادِيَةِ قَالَ أَيُّكُمُ ابْنُ عَبْدِ الْمُطَّلِبِ قَالُوا هَذَا الأَمْغَرُ الْمُرْتَفِقُ - قَالَ حَمْزَةُ الأَمْغَرُ الأَبْيَضُ مُشْرَبٌ حُمْرَةً - فَقَالَ إِنِّي سَائِلُكَ فَمُشْتَدٌّ عَلَيْكَ فِي الْمَسْأَلَةِ قَالَ ‏"‏ سَلْ عَمَّا بَدَا لَكَ ‏"‏ ‏.‏ قَالَ أَسْأَلُكَ بِرَبِّكَ وَرَبِّ مَنْ قَبْلَكَ وَرَبِّ مَنْ بَعْدَكَ آللَّهُ أَرْسَلَكَ قَالَ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ بِهِ آللَّهُ أَمَرَكَ أَنْ تُصَلِّيَ خَمْسَ صَلَوَاتٍ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ قَالَ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ بِهِ آللَّهُ أَمَرَكَ أَنْ تَأْخُذَ مِنْ أَمْوَالِ أَغْنِيَائِنَا فَتَرُدَّهُ عَلَى فُقَرَائِنَا قَالَ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ بِهِ آللَّهُ أَمَرَكَ أَنْ تَصُومَ هَذَا الشَّهْرَ مِنَ اثْنَىْ عَشَرَ شَهْرًا قَالَ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ بِهِ آللَّهُ أَمَرَكَ أَنْ يَحُجَّ هَذَا الْبَيْتَ مَنِ اسْتَطَاعَ إِلَيْهِ سَبِيلاً قَالَ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنِّي آمَنْتُ وَصَدَّقْتُ وَأَنَا ضِمَامُ بْنُ ثَعْلَبَةَ ‏.‏\hadithno{2094}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"While the Prophet was with his Companions a man from among the desert people came and said: 'Which of you is the son of 'Abdul-Muttalib?' They said: 'This Anghar man who is reclining on a pillow.' (One of the narrators) Hamzah said: "Amghar means white with a reddish complexion.'- The man said: 'I am going to ask you questions and I will be harsh in asking.' He said: 'ask whatever you like.' He said: 'I ask you by your Lord and the Lord of those who came before you, and the Lord of those who will come after you; has Allah sent you?' He said: 'By Allah, yes.' He said: 'I adjure you by Him, has Allah commanded you to offer five prayers each day and night?' He said: 'By Allah, yes.; He said: 'I adjure you by Him, has Allah commanded you to take from the wealth of our rich and give it to our poor?' he said: 'By Allah, yes He said: 'I adjure you by Allah, has Allah commanded you to fast this month out of the twelve months?' He said: 'By Allah, yes.' He said: 'I adjure you by Him, has Allah commanded you to go on pilgrimage to this House, where can afford it?' He said: 'By Allah yes.' He said: 'I belive, and I am Dimam bin Thalabah}}
\hadithdefcmd{nasai}{2095}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَجْوَدَ النَّاسِ وَكَانَ أَجْوَدَ مَا يَكُونُ فِي رَمَضَانَ حِينَ يَلْقَاهُ جِبْرِيلُ وَكَانَ جِبْرِيلُ يَلْقَاهُ فِي كُلِّ لَيْلَةٍ مِنْ شَهْرِ رَمَضَانَ فَيُدَارِسُهُ الْقُرْآنَ ‏.‏ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ يَلْقَاهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ أَجْوَدَ بِالْخَيْرِ مِنَ الرِّيحِ الْمُرْسَلَةِ ‏.‏\hadithno{2095}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah bin 'Utabah that 'Abdullah bin 'Abbas used to say:"The Messenger of Allah was the most generous of people, and he was most generous in Ramadan when Jibril met him. Jibril use to meet him every night during the month of Ramadan and study Quran with him." And he said: "When Jibril met him, the Messenger of Allah was more generous in doing good than the blowing wind}}
\hadithdefcmd{nasai}{2096}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي حَفْصُ بْنُ عُمَرَ بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا مَعْمَرٌ، وَالنُّعْمَانُ بْنُ رَاشِدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ مَا لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ لَعْنَةٍ تُذْكَرُ وَكَانَ إِذَا كَانَ قَرِيبَ عَهْدٍ بِجِبْرِيلَ عَلَيْهِ السَّلاَمُ يُدَارِسُهُ كَانَ أَجْوَدَ بِالْخَيْرِ مِنَ الرِّيحِ الْمُرْسَلَةِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ حَدِيثُ يُونُسَ بْنِ يَزِيدَ وَأَدْخَلَ هَذَا حَدِيثًا فِي حَدِيثٍ ‏.‏\hadithno{2096}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"Hardly anyone every remembered the Messenger of Allah cursing anyone, and if he had recently met with Jibril and studied the Quran with him, he was more generous in doing good than the blowing with. "(Sahih) Abu 'Abdur-Rehman (An-Nasai) said; This is a mistake, and what is correct is the (previous) narration of Yunus bin Yazid, he put this narration in the Hadith}}
\hadithdefcmd{nasai}{2097}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا أَبُو سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ شَهْرُ رَمَضَانَ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ وَغُلِّقَتْ أَبْوَابُ النَّارِ وَصُفِّدَتِ الشَّيَاطِينُ ‏"‏ ‏.‏\hadithno{2097}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"When the month of Ramadan begins, the gates of Paradise are opened and the gates of Hell are shut, and the devils are fettered}}
\hadithdefcmd{nasai}{2098}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ الْجُوزَجَانِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ أَنْبَأَنَا نَافِعُ بْنُ يَزِيدَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ وَغُلِّقَتْ أَبْوَابُ النَّارِ وَصُفِّدَتِ الشَّيَاطِينُ ‏"‏ ‏.‏\hadithno{2098}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It Was narrated from Abu Hurairah that the Messenger of Allah said:'When Ramadan begins, the gates of Paradise are opened, the gates of Hell are closed, and the devils are fettered}}
\hadithdefcmd{nasai}{2099}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي نَافِعُ بْنُ أَنَسٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ وَغُلِّقَتْ أَبْوَابُ جَهَنَّمَ وَسُلْسِلَتِ الشَّيَاطِينُ ‏"‏ ‏.‏\hadithno{2099}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said; 'The Messenger of Allah said:'When Ramadan begins, the gates of Paradise are opened, the gates of Hell are closed, and the devils are chained up}}
\hadithdefcmd{nasai}{2100}{أَخْبَرَنَا مُحَمَّدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي ابْنُ أَبِي أَنَسٍ، مَوْلَى التَّيْمِيِّينَ أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا جَاءَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الرَّحْمَةِ وَغُلِّقَتْ أَبْوَابُ جَهَنَّمَ وَسُلْسِلَتِ الشَّيَاطِينُ ‏"‏ ‏.‏\hadithno{2100}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'When Ramadan comes, the gates of mercy are opened, the gates of Hell are closed, and the devils are chained up}}
\hadithdefcmd{nasai}{2101}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، فِي حَدِيثِهِ عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ أَبِي أَنَسٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ وَغُلِّقَتْ أَبْوَابُ جَهَنَّمَ وَسُلْسِلَتِ الشَّيَاطِينُ ‏"‏ ‏.‏ رَوَاهُ ابْنُ إِسْحَاقَ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{2101}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurariah said; 'The Messenger of Allah said:'When it is Ramadan, the gates of Paradise are opened, the gates of Hell are closed, and the devils are chained up."' It was narrated by Ibn Ishaq from Az-Zuhri}}
\hadithdefcmd{nasai}{2102}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ أَبِي أَنَسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ شَهْرُ رَمَضَانَ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ وَغُلِّقَتْ أَبْوَابُ النَّارِ وَسُلْسِلَتِ الشَّيَاطِينُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا - يَعْنِي حَدِيثَ ابْنِ إِسْحَاقَ - خَطَأٌ وَلَمْ يَسْمَعْهُ ابْنُ إِسْحَاقَ مِنَ الزُّهْرِيِّ وَالصَّوَابُ مَا تَقَدَّمَ ذِكْرُنَا لَهُ ‏.‏\hadithno{2102}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated form Abu Hurairah that the Prophet said:"When the month of Ramadan beings, the gates of Paradise are opened. The gates of the Fire are closed and the devils are chained up." (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: This meaning, the narration of Ibn Ishaq - is a mistake. Ibn Ishaq did not hear from Az-Zuhri. What is correct is what we mentioned it previously}}
\hadithdefcmd{nasai}{2103}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ وَذَكَرَ مُحَمَّدُ بْنُ مُسْلِمٍ عَنْ أُوَيْسِ بْنِ أَبِي أُوَيْسٍ، عَدِيدِ بَنِي تَيْمٍ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ هَذَا رَمَضَانُ قَدْ جَاءَكُمْ تُفَتَّحُ فِيهِ أَبْوَابُ الْجَنَّةِ وَتُغَلَّقُ فِيهِ أَبْوَابُ النَّارِ وَتُسَلْسَلُ فِيهِ الشَّيَاطِينُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الْحَدِيثُ خَطَأٌ ‏.‏\hadithno{2103}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated form Anas bin Malik that the Messenger of Allah said:" There has come to you Ramadan in which the gates of Paradise are opened, the gates of the fire are closed and the devils are chained up." (Sahih) Abu 'Abdur-Rahman said: this narration is a mistake}}
\hadithdefcmd{nasai}{2104}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُرَغِّبُ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ عَزِيمَةٍ وَقَالَ ‏ "‏ إِذَا دَخَلَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ وَغُلِّقَتْ أَبْوَابُ الْجَحِيمِ وَسُلْسِلَتْ فِيهِ الشَّيَاطِينُ ‏"‏ ‏.‏ أَرْسَلَهُ ابْنُ الْمُبَارَكِ ‏.‏\hadithno{2104}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Az-Zuhri, from Abu Salamah, from Abu Hurairah that:the Prophet used to encourage praying Qiyam Al-Lail in Ramadan, but not forcibly. And he said: "When Ramadan begins, the gates of Paradise are opened and the gates of Hell are close, and the devils are chained up." Ibn Al-Mubarak narrated it in Mursal from:}}
\hadithdefcmd{nasai}{2105}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ بْنُ مُوسَى، - خُرَاسَانِيٌّ - قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الرَّحْمَةِ وَغُلِّقَتْ أَبْوَابُ جَهَنَّمَ وَسُلْسِلَتِ الشَّيَاطِينُ ‏"‏ ‏.‏\hadithno{2105}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated Az-Zuhri, from Abu Hurairah that the Prophet said:"When Ramadan begins, the gates of mercy are opened and the gates of Hall are closed, and the devils are chained up}}
\hadithdefcmd{nasai}{2106}{أَخْبَرَنَا بِشْرُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتَاكُمْ رَمَضَانُ شَهْرٌ مُبَارَكٌ فَرَضَ اللَّهُ عَزَّ وَجَلَّ عَلَيْكُمْ صِيَامَهُ تُفْتَحُ فِيهِ أَبْوَابُ السَّمَاءِ وَتُغْلَقُ فِيهِ أَبْوَابُ الْجَحِيمِ وَتُغَلُّ فِيهِ مَرَدَةُ الشَّيَاطِينِ لِلَّهِ فِيهِ لَيْلَةٌ خَيْرٌ مِنْ أَلْفِ شَهْرٍ مَنْ حُرِمَ خَيْرَهَا فَقَدْ حُرِمَ ‏"‏ ‏.‏\hadithno{2106}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'There has come to you Ramadan, a blessed month, which Allah, the Mighty and Sublime, has enjoined you to fast. In it the gates of heavens are opened and the gates of Hell are closed, and every devil is chained up. In it Allah has a night which is better than a thousand months; whoever is deprived of its goodness is indeed deprived}}
\hadithdefcmd{nasai}{2107}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَرْفَجَةَ، قَالَ عُدْنَا عُتْبَةَ بْنَ فَرْقَدٍ فَتَذَاكَرْنَا شَهْرَ رَمَضَانَ فَقَالَ مَا تَذْكُرُونَ قُلْنَا شَهْرَ رَمَضَانَ ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تُفْتَحُ فِيهِ أَبْوَابُ الْجَنَّةِ وَتُغْلَقُ فِيهِ أَبْوَابُ النَّارِ وَتُغَلُّ فِيهِ الشَّيَاطِينُ وَيُنَادِي مُنَادٍ كُلَّ لَيْلَةٍ يَا بَاغِيَ الْخَيْرِ هَلُمَّ وَيَا بَاغِيَ الشَّرِّ أَقْصِرْ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ ‏.‏\hadithno{2107}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Arfajah said; 'We visited 'Utbah bin Farqad (when he was ill) and we talked about the month of Ramadan. He said; 'What are you talking about?' We said:'The month of Ramadan. He said: "I heard the Messenger of Allah say: In it the gates of Paradise are opened and the gates of the Fire are closed, and the devils are chained up, and a caller calls out every night: O doer of good, proceed; O doer of evil, desist}}
\hadithdefcmd{nasai}{2108}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَرْفَجَةَ، قَالَ كُنْتُ فِي بَيْتٍ فِيهِ عُتْبَةُ بْنُ فَرْقَدٍ فَأَرَدْتُ أَنْ أُحَدِّثَ بِحَدِيثٍ وَكَانَ رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم كَأَنَّهُ أَوْلَى بِالْحَدِيثِ مِنِّي فَحَدَّثَ الرَّجُلُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فِي رَمَضَانَ تُفْتَحُ فِيهِ أَبْوَابُ السَّمَاءِ وَتُغْلَقُ فِيهِ أَبْوَابُ النَّارِ وَيُصَفَّدُ فِيهِ كُلُّ شَيْطَانٍ مَرِيدٍ وَيُنَادِي مُنَادٍ كُلَّ لَيْلَةٍ يَا طَالِبَ الْخَيْرِ هَلُمَّ وَيَا طَالِبَ الشَّرِّ أَمْسِكْ ‏"‏ ‏.‏\hadithno{2108}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Arfajah said:" I was in a house with 'Utbah bin Farqad, and I wanted to narrate a Hadith, but there was a man from among the Companions of the Prophet there, and I felt it was more appropriate fro him to narrate the Hadith than I. The man narrated that the Prophet said. Concerning of the Prophet there, and I felt it was more appropriate for him to narrate the Hadith than I. the man narrated that the Prophet said, concerning Ramadan: 'In it the gates of Heavens are opened and the gates of the Fire are shut, and every devil is fettered. A caller calls out every night: O seeker of good, proceed; O seeker of evil, desist}}
\hadithdefcmd{nasai}{2109}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَنْبَأَنَا الْمُهَلَّبُ بْنُ أَبِي حَبِيبَةَ، ح وَأَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ الْمُهَلَّبِ بْنِ أَبِي حَبِيبَةَ، قَالَ أَخْبَرَنِي الْحَسَنُ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ صُمْتُ رَمَضَانَ وَلاَ قُمْتُهُ كُلَّهُ ‏"‏ ‏.‏ وَلاَ أَدْرِي كَرِهَ التَّزْكِيَةَ أَوْ قَالَ لاَ بُدَّ مِنْ غَفْلَةٍ وَرَقْدَةٍ اللَّفْظُ لِعُبَيْدِ اللَّهِ ‏.‏\hadithno{2109}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from abu Bakrah that the Prophet said; 'None of you should say:'I fasted Ramadan' or 'I prayed Qiyam throughout the whole month."' I do not know whether he dislike self-praise or he said: "Inevitably there will be heedlessness and sleep." (Da 'if)}}
\hadithdefcmd{nasai}{2110}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ بْنِ خَالِدٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يُخْبِرُنَا قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاِمْرَأَةٍ مِنَ الأَنْصَارِ ‏ "‏ إِذَا كَانَ رَمَضَانُ فَاعْتَمِرِي فِيهِ فَإِنَّ عُمْرَةً فِيهِ تَعْدِلُ حَجَّةً ‏"‏ ‏.‏\hadithno{2110}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abbas told us:"The Messenger of Allah said to a woman from among the Ansar: 'When it is Ramadan, perform 'Umrah then, for 'Umrah during it is equivalent to Hajj}}
\hadithdefcmd{nasai}{2111}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ أَبِي حَرْمَلَةَ - قَالَ أَخْبَرَنِي كُرَيْبٌ، أَنَّ أُمَّ الْفَضْلِ، بَعَثَتْهُ إِلَى مُعَاوِيَةَ بِالشَّامِ - قَالَ - فَقَدِمْتُ الشَّامَ فَقَضَيْتُ حَاجَتَهَا وَاسْتَهَلَّ عَلَىَّ هِلاَلُ رَمَضَانَ وَأَنَا بِالشَّامِ فَرَأَيْتُ الْهِلاَلَ لَيْلَةَ الْجُمُعَةِ ثُمَّ قَدِمْتُ الْمَدِينَةَ فِي آخِرِ الشَّهْرِ فَسَأَلَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ ثُمَّ ذَكَرَ الْهِلاَلَ فَقَالَ مَتَى رَأَيْتُمْ فَقُلْتُ رَأَيْنَاهُ لَيْلَةَ الْجُمُعَةِ ‏.‏ قَالَ أَنْتَ رَأَيْتَهُ لَيْلَةَ الْجُمُعَةِ قُلْتُ نَعَمْ وَرَآهُ النَّاسُ فَصَامُوا وَصَامَ مُعَاوِيَةُ ‏.‏ قَالَ لَكِنْ رَأَيْنَاهُ لَيْلَةَ السَّبْتِ فَلاَ نَزَالُ نَصُومُ حَتَّى نُكْمِلَ ثَلاَثِينَ يَوْمًا أَوْ نَرَاهُ ‏.‏ فَقُلْتُ أَوَلاَ تَكْتَفِي بِرُؤْيَةِ مُعَاوِيَةَ وَأَصْحَابِهِ قَالَ لاَ هَكَذَا أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2111}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Kuraib narrated that Umm Al-Fadl sent him to Muawiyah in Ash-Sham. He said:"I came to Ash-Sham. He said: "I came to Ash-Sham and complete her errand. Then the new crescent of Ramadan was sighted while I was in Ash-Sham. I saw the new crescent on the night of Friday, then I came to Al-Madinah at the end of the month. 'Abdullah bin 'Abbas asked me about the sighting of the moon and said: ' When did you see it?' I said: 'We saw it on the night of Friday.' He said; 'You saw it on the ninth of Friday?' I said: 'Yes, and the people saw it and started fasting, and so did Muawiyah. He said: 'But we saw it on the night of Saturday, so we will continue fasting until we have completed thirty days or we see it.' I said: 'Will you not be content with the sighting of Muawiyah and his companions? He said; 'No; this is what the Messenger of Allah enjoined upon us}}
\hadithdefcmd{nasai}{2112}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ سُفْيَانَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ رَأَيْتُ الْهِلاَلَ ‏.‏ فَقَالَ ‏"‏ أَتَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَنَادَى النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَنْ صُومُوا ‏"‏ ‏.‏\hadithno{2112}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said; "A Bedouin came to the Prphet and said:'I have sighted the crescent.' He said: 'Do you bear witness that there is none worthy of worship except Allah, and that Muhammad is His slave and Messenger?' He said: 'Yes.' So the Prophet gave the call saying: 'Fast}}
\hadithdefcmd{nasai}{2113}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَبْصَرْتُ الْهِلاَلَ اللَّيْلَةَ ‏.‏ قَالَ ‏"‏ أَتَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ يَا بِلاَلُ أَذِّنْ فِي النَّاسِ فَلْيَصُومُوا غَدًا ‏"‏ ‏.‏\hadithno{2113}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"A Bedouin come to the Prophet and said; 'I have sighted the crescent tonight.' He said: 'Do you bear witness that there is none worthy of worship except Allah, and that Messenger?' He said: 'Yes.' He said: 'O Bilal, announce to the people that they should fast tomorrow}}
\hadithdefcmd{nasai}{2114}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، عَنْ أَبِي دَاوُدَ، عَنْ سُفْيَانَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، مُرْسَلٌ ‏.‏\hadithno{2114}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ikramah:A similar, Mursal, report was narrated from 'Ikramah}}
\hadithdefcmd{nasai}{2115}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ نُعَيْمٍ، - مِصِّيصِيٌّ - قَالَ أَنْبَأَنَا حِبَّانُ بْنُ مُوسَى الْمَرْوَزِيُّ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، مُرْسَلٌ ‏.‏\hadithno{2115}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ikramah:A similar, Mursal, report was narrated from 'Ikrimah}}
\hadithdefcmd{nasai}{2116}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ شَبِيبٍ أَبُو عُثْمَانَ، - وَكَانَ شَيْخًا صَالِحًا بِطَرَسُوسَ - قَالَ أَنْبَأَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ حُسَيْنِ بْنِ الْحَارِثِ الْجَدَلِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ، أَنَّهُ خَطَبَ النَّاسَ فِي الْيَوْمِ الَّذِي يُشَكُّ فِيهِ فَقَالَ أَلاَّ إِنِّي جَالَسْتُ أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَسَاءَلْتُهُمْ وَأَنَّهُمْ حَدَّثُونِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ وَانْسُكُوا لَهَا فَإِنْ غُمَّ عَلَيْكُمْ فَأَكْمِلُوا ثَلاَثِينَ فَإِنْ شَهِدَ شَاهِدَانِ فَصُومُوا وَأَفْطِرُوا ‏"‏ ‏.‏\hadithno{2116}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:'Abdur-Rahman bin Zaid bin Al-Khattab addressed the people on the day concerning which there was doubt (as to whether the month had begun) and said: "I sat with the Companions of the Messenger of Allah and asked them, and they a narrated that the Messenger of Allah said: 'Fast when you see it and stop fasting when you see it, and perform the rites on that basis. If it is obscured, then complete thirty days, and if two witnesses testify then fast and stop fasting}}
\hadithdefcmd{nasai}{2117}{أَخْبَرَنَا مُؤَمَّلُ بْنُ هِشَامٍ، عَنْ إِسْمَاعِيلَ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ غُمَّ عَلَيْكُمُ الشَّهْرُ فَعُدُّوا ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2117}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"the Messenger of Allah said: 'Fast when you see it and stop fasting when you see it, and if it is obscured from you (too cloudy), then count it as thirty (days)}}
\hadithdefcmd{nasai}{2118}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا وَرْقَاءُ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2118}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated It was narrated that Abu Hurairah said:: "The Messenger of Allah said: 'Fast when you see it and stop fasting when you see it, and if it is obscured from you (too cloudy), then count it as thirty (days)}}
\hadithdefcmd{nasai}{2119}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتُمُ الْهِلاَلَ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَصُومُوا ثَلاَثِينَ يَوْمًا ‏"‏ ‏.‏\hadithno{2119}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of allah sadi:"When you see the crescent then fast, and when you crescent then fast, and when you see it, stop fasting. If it is obscured from you (too cloudy), then fast thirty days}}
\hadithdefcmd{nasai}{2120}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا رَأَيْتُمُ الْهِلاَلَ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ‏"‏ ‏.‏\hadithno{2120}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin 'Umar said:" I heard the messenger of Allah say: 'When you see the crescent then fast, and when you see it, then stop fasting, and if it is obscured from you (too cloudy), then work it out (fro the beginning of the month, to complete thirty days)}}
\hadithdefcmd{nasai}{2121}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ رَمَضَانَ فَقَالَ ‏ "‏ لاَ تَصُومُوا حَتَّى تَرَوُا الْهِلاَلَ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ‏"‏ ‏.‏\hadithno{2121}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah mentioned Ramadan and said:"Do not fast until you see the crescent, and do not stop fasting until you see it, and if it is obscured from you (too cloudy), then work it out}}
\hadithdefcmd{nasai}{2122}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصُومُوا حَتَّى تَرَوْهُ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ‏"‏ ‏.‏\hadithno{2122}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated form Ibn 'Umar that the Prophet said:"D not fast until you see it , and do not stop fasting until you see it, and if it is obscured from you (too cloudy), then work it out}}
\hadithdefcmd{nasai}{2123}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، صَاحِبُ حِمْصَ قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْهِلاَلَ فَقَالَ ‏ "‏ إِذَا رَأَيْتُمُوهُ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَعُدُّوا ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2123}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah mentioned the crescent and said: 'When you see it, fast and when you see it, stop fasting, and if it is obscured from you (too cloudy), then count thirty days}}
\hadithdefcmd{nasai}{2124}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ أَبُو الْجَوْزَاءِ، - وَهُوَ ثِقَةٌ بَصْرِيٌّ أَخُو أَبِي الْعَالِيَةِ - قَالَ أَنْبَأَنَا حَبَّانُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ غُمَّ عَلَيْكُمْ فَأَكْمِلُوا الْعِدَّةَ ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2124}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allah said; 'Fast when you see it and stop fasting when you see it, and if it is obscured from you (too cloudy), then complete thirty (days)}}
\hadithdefcmd{nasai}{2125}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ حُنَيْنٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ عَجِبْتُ مِمَّنْ يَتَقَدَّمُ الشَّهْرَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمُ الْهِلاَلَ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَأَكْمِلُوا الْعِدَّةَ ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2125}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:" I am surprised at those who anticipate the moth, when the Messenger of Allah said: 'When you see the new crescent then fast, and when you see it, then stop fasting, and if it is obscured from you (too cloudy), then complete thirty days}}
\hadithdefcmd{nasai}{2126}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقَدَّمُوا الشَّهْرَ حَتَّى تَرَوُا الْهِلاَلَ قَبْلَهُ أَوْ تُكْمِلُوا الْعِدَّةَ ثُمَّ صُومُوا حَتَّى تَرَوُا الْهِلاَلَ أَوْ تُكْمِلُوا الْعِدَّةَ قَبْلَهُ ‏"‏ ‏.‏\hadithno{2126}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ribii bin Hirash, from Hudhaifah bin Al-Yaman, that the Messenger of Allah said:"Do not anticipate the month until you see the crescent before it, or you complete the number of days. Then fast until you see the new moon, or you complete the number of days}}
\hadithdefcmd{nasai}{2127}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، عَنْ بَعْضِ، أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقَدَّمُوا الشَّهْرَ حَتَّى تُكْمِلُوا الْعِدَّةَ أَوْ تَرَوُا الْهِلاَلَ ثُمَّ صُومُوا وَلاَ تُفْطِرُوا حَتَّى تَرَوُا الْهِلاَلَ أَوْ تُكْمِلُوا الْعِدَّةَ ثَلاَثِينَ ‏"‏ ‏.‏ أَرْسَلَهُ الْحَجَّاجُ بْنُ أَرْطَاةَ ‏.‏\hadithno{2127}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ribi that one of the Companions of the Prophet said:"The Messenger of Allah said: 'D not anticipate the month until you complete the number, or you see the crescent. Then fast, and do not stop fasting until you see the crescent, or your complete thirty days."' (Sahih) Al-Hajjaj bin Artah reported it in a Mursal from}}
\hadithdefcmd{nasai}{2128}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمُ الْهِلاَلَ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَأَتِمُّوا شَعْبَانَ ثَلاَثِينَ إِلاَّ أَنْ تَرَوُا الْهِلاَلَ قَبْلَ ذَلِكَ ثُمَّ صُومُوا رَمَضَانَ ثَلاَثِينَ إِلاَّ أَنْ تَرَوُا الْهِلاَلَ قَبْلَ ذَلِكَ ‏"‏ ‏.‏\hadithno{2128}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ribi said; "the Messenger of Allah said:"The Messenger of Allah said: 'When you see the crescent then fast, and when you see it, then stop fasting. If it is too cloudy then complete Shaban as thirty days, unless you see the crescent before that, then fast Ramadan as thirty days, unless you see the new crescent before that}}
\hadithdefcmd{nasai}{2129}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ أَبِي صَغِيرَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، قَالَ حَدَّثَنَا ابْنُ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ حَالَ بَيْنَكُمْ وَبَيْنَهُ سَحَابٌ فَأَكْمِلُوا الْعِدَّةَ وَلاَ تَسْتَقْبِلُوا الشَّهْرَ اسْتِقْبَالاً ‏"‏ ‏.‏\hadithno{2129}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah said:"Fast when you see it, and stop fasting when you see it, and if clouds prevent you from seeing it, then complete the number, and do not fast ahead of Ramadan}}
\hadithdefcmd{nasai}{2130}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَصُومُوا قَبْلَ رَمَضَانَ صُومُوا لِلرُّؤْيَةِ وَأَفْطِرُوا لِلرُّؤْيَةِ فَإِنْ حَالَتْ دُونَهُ غَيَايَةٌ فَأَكْمِلُوا ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2130}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said: "The Messenger of Allah said: Do not fast before Ramadan. Fast when you see it and stop fasting when you see it, and if clouds prevent you from seeing it, then complete Thirty (Days)}}
\hadithdefcmd{nasai}{2131}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، عَنْ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ أَقْسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ لاَ يَدْخُلَ عَلَى نِسَائِهِ شَهْرًا فَلَبِثَ تِسْعًا وَعِشْرِينَ فَقُلْتُ أَلَيْسَ قَدْ كُنْتَ آلَيْتَ شَهْرًا فَعَدَدْتُ الأَيَّامَ تِسْعًا وَعِشْرِينَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏\hadithno{2131}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah swore not to come to his wives for a month, and twenty-nine days passed. I said: 'Did you not wives to keep away from you wives for a month? I have counted twenty-nine days.' The Messenger of Allah said: 'The month is twenty-nine days}}
\hadithdefcmd{nasai}{2132}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، حَدَّثَهُ ح، وَأَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، قَالَ أَنْبَأَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمْ أَزَلْ حَرِيصًا أَنْ أَسْأَلَ عُمَرَ بْنَ الْخَطَّابِ عَنِ الْمَرْأَتَيْنِ مِنْ أَزْوَاجِ رَسُولِ اللَّهِ صلى الله عليه وسلم اللَّتَيْنِ قَالَ اللَّهُ لَهُمَا ‏\{‏ إِنْ تَتُوبَا إِلَى اللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا ‏\}‏ وَسَاقَ الْحَدِيثَ وَقَالَ فِيهِ فَاعْتَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ مِنْ أَجْلِ ذَلِكَ الْحَدِيثِ حِينَ أَفْشَتْهُ حَفْصَةُ إِلَى عَائِشَةَ تِسْعًا وَعِشْرِينَ لَيْلَةً ‏.‏ قَالَتْ عَائِشَةُ وَكَانَ قَالَ ‏"‏ مَا أَنَا بِدَاخِلٍ عَلَيْهِنَّ شَهْرًا ‏"‏ ‏.‏ مِنْ شِدَّةِ مَوْجِدَتِهِ عَلَيْهِنَّ حِينَ حَدَّثَهُ اللَّهُ عَزَّ وَجَلَّ حَدِيثَهُنَّ فَلَمَّا مَضَتْ تِسْعٌ وَعِشْرُونَ لَيْلَةً دَخَلَ عَلَى عَائِشَةَ فَبَدَأَ بِهَا فَقَالَتْ لَهُ عَائِشَةُ إِنَّكَ قَدْ كُنْتَ آلَيْتَ يَا رَسُولَ اللَّهِ أَنْ لاَ تَدْخُلَ عَلَيْنَا شَهْرًا وَإِنَّا أَصْبَحْنَا مِنْ تِسْعٍ وَعِشْرِينَ لَيْلَةً نَعُدُّهَا عَدَدًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ لَيْلَةً ‏"‏ ‏.‏\hadithno{2132}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"I was very keen to ask 'Umar bin Al-Khattab about the two wives of the Messenger of Allah to whom Allah said: If you two turn in repentance to Allah, (it will be better for you), your hearts are indeed so inclined." And he quoted the Hadith. He said concerning it:' "The from his wives for twenty-nine days because of that, when Hafsah had made her disclosure to Aishah. He had said: 'I will not enter upon them for a month,' because he was so upset with them when Allah, the Mighty and Sublime, informed him of what they had said. When twenty-nine days had passed, he entered upon 'Aishah, so he started with her. Aishah, said to him: 'O Messenger of Allah, you swore not to enter upon us for a month, and now twenty-nine days have passed; we have been counting them.' The Messenger of Allah said; 'The month is twenty-nine days}}
\hadithdefcmd{nasai}{2133}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، - هُوَ أَبُو بُرَيْدٍ الْجَرْمِيُّ بَصْرِيٌّ - عَنْ بَهْزٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، عَنْ أَبِي الْحَكَمِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَتَانِي جِبْرِيلُ عَلَيْهِ السَّلاَمُ فَقَالَ الشَّهْرُ تِسْعٌ وَعِشْرُونَ يَوْمًا ‏"‏ ‏.‏\hadithno{2133}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet said:"Jibril, peace be upon him, came to me and said: 'The month is twenty-nine days}}
\hadithdefcmd{nasai}{2134}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، وَذَكَرَ، كَلِمَةً مَعْنَاهَا حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، قَالَ سَمِعْتُ أَبَا الْحَكَمِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ يَوْمًا ‏"‏ ‏.‏\hadithno{2134}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said: 'The month is twenty-nine days}}
\hadithdefcmd{nasai}{2135}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ ضَرَبَ بِيَدِهِ عَلَى الأُخْرَى وَقَالَ ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَنَقَصَ فِي الثَّالِثَةِ إِصْبَعًا ‏.‏\hadithno{2135}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated form Muhammad bin Sad Abi Waqqas, from his father, that:the Prophet struck one hand with the other and said: "The month is like this and like this and like this," retaining one finger the third time}}
\hadithdefcmd{nasai}{2136}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ إِسْمَاعِيلَ، عَنْ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ يَعْنِي تِسْعَةً وَعِشْرِينَ ‏.‏ رَوَاهُ يَحْيَى بْنُ سَعِيدٍ وَغَيْرُهُ عَنْ إِسْمَاعِيلَ عَنْ مُحَمَّدِ بْنِ سَعْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2136}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muhammad bin Sad that his father said:"The Messenger of Allah said: "The month is like this and like this and like this,"' meaning twenty-nine. Yahya bin Saeed and others narrated it from Ismail, from Muhammad bin Sad, from the Prophet}}
\hadithdefcmd{nasai}{2137}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَصَفَّقَ مُحَمَّدُ بْنُ عُبَيْدٍ بِيَدَيْهِ يَنْعَتُهَا ثَلاَثًا ثُمَّ قَبَضَ فِي الثَّالِثَةِ الإِبْهَامَ فِي الْيُسْرَى ‏.‏ قَالَ يَحْيَى بْنُ سَعِيدٍ قُلْتُ لإِسْمَاعِيلَ عَنْ أَبِيهِ قَالَ لاَ ‏.‏\hadithno{2137}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Muhammad bin Sad bin Abi Waqqas said:"The Messenger of Allah said: 'The month is like this and like this and like this." (One of the narrators) Muhammad bin 'Ubaid clapped his hands three time to demonstrate it, then he withheld his left thumb the third time. Yahya bin Saeed said to Ismail (One of the narrators): "Form his father?' He said: "No}}
\hadithdefcmd{nasai}{2138}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا هَارُونُ، قَالَ حَدَّثَنَا عَلِيٌّ، - هُوَ ابْنُ الْمُبَارَكِ - قَالَ حَدَّثَنَا يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ يَكُونُ تِسْعَةً وَعِشْرِينَ وَيَكُونُ ثَلاَثِينَ فَإِذَا رَأَيْتُمُوهُ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَأَكْمِلُوا الْعِدَّةَ ‏"‏ ‏.‏\hadithno{2138}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: The month may be twenty-nine days or it may be thirty. When you see it, then stop fasting, and it is obscured from you (too cloudy), then complete the count}}
\hadithdefcmd{nasai}{2139}{أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا مُعَاوِيَةُ، ح وَأَخْبَرَنِي أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ سَعِيدٍ، عَنْ مُعَاوِيَةَ، - وَاللَّفْظُ لَهُ - عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، أَنَّ أَبَا سَلَمَةَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ، وَهُوَ - ابْنُ عُمَرَ - يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏\hadithno{2139}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah Ibn ' Umar said:" I heard the Messenger of Allah say: 'The month is twenty-nine days}}
\hadithdefcmd{nasai}{2140}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ سَعِيدِ بْنِ عَمْرٍو، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّا أُمَّةٌ أُمِّيَّةٌ لاَ نَكْتُبُ وَلاَ نَحْسِبُ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ ثَلاَثًا حَتَّى ذَكَرَ تِسْعًا وَعِشْرِينَ ‏.‏\hadithno{2140}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet said:"We are an unlettered Ummah, we do not use astronomical counting or computation. The month is like this, and this, and this," he did three times, showing it as twenty-nine}}
\hadithdefcmd{nasai}{2141}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، عَنْ شُعْبَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ عَمْرِو بْنِ سَعِيدِ بْنِ أَبِي الْعَاصِ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّا أُمَّةٌ أُمِّيَّةٌ لاَ نَحْسِبُ وَلاَ نَكْتُبُ وَالشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَعَقَدَ الإِبْهَامَ فِي الثَّالِثَةِ ‏"‏ وَالشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ تَمَامَ الثَّلاَثِينَ ‏.‏\hadithno{2141}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Saeed bin 'Amr bin Saeed bin Abi Al-As, that:he heard Ibn 'Umar narrate that the Prophet said; "We are an unlettered Ummah; we do not use computation. The month is like this, and this, and this," and he held down his thumb the last time. "And the month is like this, and this, and this," completing thirty}}
\hadithdefcmd{nasai}{2142}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ جَبَلَةَ بْنِ سُحَيْمٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّهْرُ هَكَذَا ‏"‏ ‏.‏ وَوَصَفَ شُعْبَةُ عَنْ صِفَةِ جَبَلَةَ عَنْ صِفَةِ ابْنِ عُمَرَ أَنَّهُ تِسْعٌ وَعِشْرُونَ فِيمَا حَكَى مِنْ صَنِيعِهِ مَرَّتَيْنِ بِأَصَابِعِ يَدَيْهِ وَنَقَصَ فِي الثَّالِثَةِ إِصْبَعًا مِنْ أَصَابِعِ يَدَيْهِ ‏.‏\hadithno{2142}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet said:"The month is like this," and (one of the narrators) Shubah did the same gesture as Jabalah had done, copying, Ibn 'Umar: "It is twenty-nine, as he gestured twice with all fingers of both hands, and putting down one of his fingers the third time}}
\hadithdefcmd{nasai}{2143}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عُقْبَةَ، - يَعْنِي ابْنَ حُرَيْثٍ - قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏\hadithno{2143}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Umar said:"The Messenger of Allah said: "The month is twenty-nine (days)}}
\hadithdefcmd{nasai}{2144}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏"‏ ‏.‏ وَقَفَهُ عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ ‏.‏\hadithno{2144}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"Messenger of Allah said: "The Messenger of Allah said: 'Take Sahur, for in Sahur there is blessing."' 'Ubaidullah bin Saeed narrated it in Mawquaf from}}
\hadithdefcmd{nasai}{2145}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ تَسَحَّرُوا ‏.‏ قَالَ عُبَيْدُ اللَّهِ لاَ أَدْرِي كَيْفَ لَفْظُهُ ‏.‏\hadithno{2145}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"Take Sahur." 'Ubaidullah said: "I do not know how he said it}}
\hadithdefcmd{nasai}{2146}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، وَعَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏"‏ ‏.‏\hadithno{2146}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah said: 'Take Sahur, for in Sahur there is blessing." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2147}{أَخْبَرَنَا عَلِيُّ بْنُ سَعِيدِ بْنِ جَرِيرٍ، - نَسَائِيٌّ - قَالَ حَدَّثَنَا أَبُو الرَّبِيعِ، قَالَ حَدَّثَنَا مَنْصُورُ بْنُ أَبِي الأَسْوَدِ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏"‏ ‏.‏\hadithno{2147}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said; 'Take Sahur, for in Sahur there is blessing}}
\hadithdefcmd{nasai}{2148}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏.‏ رَفَعَهُ ابْنُ أَبِي لَيْلَى ‏.‏\hadithno{2148}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"Eat Sahur, for in Sahur there is blessing." (Sahih Mawquf) while Ibn Abi Laila narrated it in Marfu form:}}
\hadithdefcmd{nasai}{2149}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ أَبِي لَيْلَى، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏"‏ ‏.‏\hadithno{2149}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Take Sahur, for in Sahur there is blessing}}
\hadithdefcmd{nasai}{2150}{أَخْبَرَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏"‏ ‏.‏\hadithno{2150}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said :"The Messenger of Allah said: 'Eat Sahur, for in Sahur there is blessing}}
\hadithdefcmd{nasai}{2151}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ حَدِيثُ يَحْيَى بْنِ سَعِيدٍ هَذَا إِسْنَادُهُ حَسَنٌ وَهُوَ مُنْكَرٌ وَأَخَافُ أَنْ يَكُونَ الْغَلَطُ مِنْ مُحَمَّدِ بْنِ فُضَيْلٍ ‏.‏\hadithno{2151}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said :"The Messenger of Allah said: 'Eat Sahur, for in Sahur there is blessing." (Hasan) Abu 'Abdur-Rahman (An-Nasai) said: In this narration of Yahya bin Saeed, its chain is Hasan but it is Munkar, and I fear that the error is from Muhammad bin Fudail}}
\hadithdefcmd{nasai}{2152}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، قَالَ قُلْنَا لِحُذَيْفَةَ أَىَّ سَاعَةٍ تَسَحَّرْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ هُوَ النَّهَارُ إِلاَّ أَنَّ الشَّمْسَ لَمْ تَطْلُعْ ‏.‏\hadithno{2152}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zirr said:"We said to Hudhaifah: 'At what time did you take Sahur with the Messenger of Allah?' He said: 'It was daytime, but before the sun had risen." (Daif)}}
\hadithdefcmd{nasai}{2153}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، قَالَ سَمِعْتُ زِرَّ بْنَ حُبَيْشٍ، قَالَ تَسَحَّرْتُ مَعَ حُذَيْفَةَ ثُمَّ خَرَجْنَا إِلَى الصَّلاَةِ فَلَمَّا أَتَيْنَا الْمَسْجِدَ صَلَّيْنَا رَكْعَتَيْنِ وَأُقِيمَتِ الصَّلاَةُ وَلَيْسَ بَيْنَهُمَا إِلاَّ هُنَيْهَةٌ ‏.‏\hadithno{2153}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Zirr bin Hubaish said:"I had Sahur with Hudhaifah, then we went out to pray. When we came to the Masjid we prayed two Rakahs, then the Iqamah for prayer was said, and there was only a short time between them." Abu Hurairah said : "The Messenger of Allah said: 'Eat Sahur, for in Sahur there is blessing}}
\hadithdefcmd{nasai}{2154}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالَ حَدَّثَنَا أَبُو يَعْفُورٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ، عَنْ صِلَةَ بْنِ زُفَرَ، قَالَ تَسَحَّرْتُ مَعَ حُذَيْفَةَ ثُمَّ خَرَجْنَا إِلَى الْمَسْجِدِ فَصَلَّيْنَا رَكْعَتَىِ الْفَجْرِ ثُمَّ أُقِيمَتِ الصَّلاَةُ فَصَلَّيْنَا ‏.‏\hadithno{2154}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Silah bin Zufar said:"I had Sahur with Hudhaifah, then we went out to the Masjid. We prayed the two Rakahs of Fajr, then the Iqamah for prayer was made, and we prayed}}
\hadithdefcmd{nasai}{2155}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ تَسَحَّرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قُمْنَا إِلَى الصَّلاَةِ ‏.‏ قُلْتُ كَمْ كَانَ بَيْنَهُمَا قَالَ قَدْرَ مَا يَقْرَأُ الرَّجُلُ خَمْسِينَ آيَةً ‏.‏\hadithno{2155}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Hisam reported from Qatadah, from Anas, that Zaid bin Thabir said; "We took Sahur with the Messenger of Allah then we went to pray." I said:"How long was there between them?" He said: "As long as it takes a man to recite fifty verses}}
\hadithdefcmd{nasai}{2156}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ تَسَحَّرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قُمْنَا إِلَى الصَّلاَةِ ‏.‏ قُلْتُ زُعِمَ أَنَّ أَنَسًا الْقَائِلُ مَا كَانَ بَيْنَ ذَلِكَ قَالَ قَدْرَ مَا يَقْرَأُ الرَّجُلُ خَمْسِينَ آيَةً ‏.‏\hadithno{2156}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that Zaid bin Thabit said:"We had Sahur with the Messenger of Allah then we went to pray." I (one of the narrators) said: "It is claimed that Anas said: 'How long was there between them?' He said: 'As long as it takes a man to recite fifty verses}}
\hadithdefcmd{nasai}{2157}{أَخْبَرَنَا أَبُو الأَشْعَثِ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، رضى الله عنه قَالَ تَسَحَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَزَيْدُ بْنُ ثَابِتٍ ثُمَّ قَامَا فَدَخَلاَ فِي صَلاَةِ الصُّبْحِ ‏.‏ فَقُلْنَا لأَنَسٍ كَمْ كَانَ بَيْنَ فَرَاغِهِمَا وَدُخُولِهِمَا فِي الصَّلاَةِ قَالَ قَدْرَ مَا يَقْرَأُ الإِنْسَانُ خَمْسِينَ آيَةً ‏.‏\hadithno{2157}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah and Zaid bin Thabit had Sahur, then they went and started to pray Subh." We said to Anas: "How long was there between their finishing and their starting to pray?" He said: "As long as it takes a man to recite fifty Verses}}
\hadithdefcmd{nasai}{2158}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ خَيْثَمَةَ، عَنْ أَبِي عَطِيَّةَ، قَالَ قُلْتُ لِعَائِشَةَ فِينَا رَجُلاَنِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَحَدُهُمَا يُعَجِّلُ الإِفْطَارَ وَيُؤَخِّرُ السُّحُورَ وَالآخَرُ يُؤَخِّرُ الإِفْطَارَ وَيُعَجِّلُ السُّحُورَ ‏.‏ قَالَتْ أَيُّهُمَا الَّذِي يُعَجِّلُ الإِفْطَارَ وَيُؤَخِّرُ السُّحُورَ قُلْتُ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ ‏.‏ قَالَتْ هَكَذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏\hadithno{2158}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu 'Atiyyah said:"I said to 'Aishah: 'Among us there are two of the Companions of the Prophet, one of whom hastens Iftar and delays Sahur, and the other delays Iftar and hastens Sahur.' She said: 'Which of them is the one who hastens Ifar and delays Sahur?' I said: "Abdullah bin Masud.' She said: 'That is what the Messenger of Allah used to do}}
\hadithdefcmd{nasai}{2159}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنْ أَبِي عَطِيَّةَ، قَالَ قُلْتُ لِعَائِشَةَ فِينَا رَجُلاَنِ أَحَدُهُمَا يُعَجِّلُ الإِفْطَارَ وَيُؤَخِّرُ السُّحُورَ وَالآخَرُ يُؤَخِّرُ الْفِطْرَ وَيُعَجِّلُ السُّحُورَ ‏.‏ قَالَتْ أَيُّهُمَا الَّذِي يُعَجِّلُ الإِفْطَارَ وَيُؤَخِّرُ السُّحُورَ قُلْتُ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ ‏.‏ قَالَتْ هَكَذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏\hadithno{2159}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu 'Atiyyah said:"I said to 'Aishah: 'Among us there are two men, one of whom hastens Iftar and delays Sahur, and the other delays Iftar and hastens Sahur.' She said; 'Which of them is the one who hastens Iftar and delays Sahur?' I said: "Abdullah bin Masud.' She said; 'This is what the Messenger of Allah used to do}}
\hadithdefcmd{nasai}{2160}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ أَبِي عَطِيَّةَ، قَالَ دَخَلْتُ أَنَا وَمَسْرُوقٌ، عَلَى عَائِشَةَ فَقَالَ لَهَا مَسْرُوقٌ رَجُلاَنِ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم كِلاَهُمَا لاَ يَأْلُو عَنِ الْخَيْرِ أَحَدُهُمَا يُؤَخِّرُ الصَّلاَةَ وَالْفِطْرَ وَالآخَرُ يُعَجِّلُ الصَّلاَةَ وَالْفِطْرَ ‏.‏ فَقَالَتْ عَائِشَةُ أَيُّهُمَا الَّذِي يُعَجِّلُ الصَّلاَةَ وَالْفِطْرَ قَالَ مَسْرُوقٌ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ ‏.‏ فَقَالَتْ عَائِشَةُ هَكَذَا كَانَ يَصْنَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2160}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu 'Atiyyah said:"Masruq and I came to 'Aishah, and Masruq said to her: 'There are two men from among the Companions of the Messenger of Allah both of whom are good; one of them delays the prayer and Ifar, and the other hastens the prayer and Iftar.' 'Aishah said: 'Which of them is the one who hastens the prayer and Iftar?' Masruq said: 'That is what the Messenger of Allah used to do}}
\hadithdefcmd{nasai}{2161}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ أَبِي عَطِيَّةَ، قَالَ دَخَلْتُ أَنَا وَمَسْرُوقٌ، عَلَى عَائِشَةَ فَقُلْنَا لَهَا يَا أُمَّ الْمُؤْمِنِينَ رَجُلاَنِ مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم أَحَدُهُمَا يُعَجِّلُ الإِفْطَارَ وَيُعَجِّلُ الصَّلاَةَ وَالآخَرُ يُؤَخِّرُ الإِفْطَارَ وَيُؤَخِّرُ الصَّلاَةَ ‏.‏ فَقَالَتْ أَيُّهُمَا يُعَجِّلُ الإِفْطَارَ وَيُعَجِّلُ الصَّلاَةَ قُلْنَا عَبْدُ اللَّهِ بْنُ مَسْعُودٍ ‏.‏ قَالَتْ هَكَذَا كَانَ يَصْنَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَالآخَرُ أَبُو مُوسَى رضى الله عنهما ‏.‏\hadithno{2161}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu 'Atiyyah said:"Masruq and I came to 'Aishah and we said to her: 'O mother of the Believers, two men from among the Companions of Muhammad; one of them hastens the Iftar and hastens the prayer, and the other delays Iftar and delays the prayer; She said: 'Which one of them hastens Iftar and has hastens the prayer?' we said : 'Abdullah bin Masud.' She said: 'That is what the Messenger of Allah used to do."" And the other was Abu Musa}}
\hadithdefcmd{nasai}{2162}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْحَمِيدِ، صَاحِبِ الزِّيَادِيِّ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الْحَارِثِ، يُحَدِّثُ عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَتَسَحَّرُ فَقَالَ ‏ "‏ إِنَّهَا بَرَكَةٌ أَعْطَاكُمُ اللَّهُ إِيَّاهَا فَلاَ تَدَعُوهُ ‏"‏ ‏.‏\hadithno{2162}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Al-Harith narrated that a man from among the Companions of th Prophet said:"I entered upon the Prophet when he was having Sahur. He sadi: 'It is a blessing that Allah has given to you, so do not neglect it}}
\hadithdefcmd{nasai}{2163}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، - بَصْرِيٌّ - قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ يُونُسَ بْنِ سَيْفٍ، عَنِ الْحَارِثِ بْنِ زِيَادٍ، عَنْ أَبِي رُهْمٍ، عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَدْعُو إِلَى السَّحُورِ فِي شَهْرِ رَمَضَانَ وَقَالَ ‏ "‏ هَلُمُّوا إِلَى الْغَدَاءِ الْمُبَارَكِ ‏"‏ ‏.‏\hadithno{2163}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that AL-'Irbad bin Sariyah said:"I heard the Messenger of Allah inviting people to have Sahur in Ramadan. He said: 'Come to the blessed breakfast." (Hasan) Chatper 26. Calling Sahur "Ghada" (Breakfast)}}
\hadithdefcmd{nasai}{2164}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ بَقِيَّةَ بْنِ الْوَلِيدِ، قَالَ أَخْبَرَنِي بَحِيرُ بْنُ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَيْكُمْ بِغَدَاءِ السُّحُورِ فَإِنَّهُ هُوَ الْغَدَاءُ الْمُبَارَكُ ‏"‏ ‏.‏\hadithno{2164}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Miqdam bin Madikarib that the Prophet said:"You should take Sahur for it is the blessed breakfast}}
\hadithdefcmd{nasai}{2165}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ ثَوْرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِرَجُلٍ ‏ "‏ هَلُمَّ إِلَى الْغَدَاءِ الْمُبَارَكِ ‏"‏ ‏.‏ يَعْنِي السَّحُورَ ‏.‏\hadithno{2165}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Khalid bin Ma'dan said:"The Messenger of Allah said to a man: 'Come to the blessed breakfast, - meaning Sahur}}
\hadithdefcmd{nasai}{2166}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ مُوسَى بْنِ عُلَىٍّ، عَنْ أَبِيهِ، عَنْ أَبِي قَيْسٍ، عَنْ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ فَصْلَ مَا بَيْنَ صِيَامِنَا وَصِيَامِ أَهْلِ الْكِتَابِ أَكْلَةُ السُّحُورِ ‏"‏ ‏.‏\hadithno{2166}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Amr bin Al-As said:"The Messenger of Allah said: 'The difference between our fasting and the fasting of the people of the Book, is eating Sahur}}
\hadithdefcmd{nasai}{2167}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَذَلِكَ عِنْدَ السُّحُورِ ‏"‏ يَا أَنَسُ إِنِّي أُرِيدُ الصِّيَامَ أَطْعِمْنِي شَيْئًا ‏"‏ ‏.‏ فَأَتَيْتُهُ بِتَمْرٍ وَإِنَاءٍ فِيهِ مَاءٌ وَذَلِكَ بَعْدَ مَا أَذَّنَ بِلاَلٌ فَقَالَ ‏"‏ يَا أَنَسُ انْظُرْ رَجُلاً يَأْكُلُ مَعِي ‏"‏ ‏.‏ فَدَعَوْتُ زَيْدَ بْنَ ثَابِتٍ فَجَاءَ فَقَالَ إِنِّي قَدْ شَرِبْتُ شَرْبَةَ سَوِيقٍ وَأَنَا أُرِيدُ الصِّيَامَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَنَا أُرِيدُ الصِّيَامَ ‏"‏ ‏.‏ فَتَسَحَّرَ مَعَهُ ثُمَّ قَامَ فَصَلَّى رَكْعَتَيْنِ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ ‏.‏\hadithno{2167}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah said, at the time of Sahur. 'O Anas, I want to fast, so give me something to eat.' So I brought him some dates and a vessel of water. That was after the Adhan of Bilal. He said: 'O Anas, find a man to come and eat with me.' So I called Zaid bin Thabit, who came and said: "I drank some Sawiq and I want to fast.' The Messenger of Allah said: "I also want to fast.' So he ate Sahr with him, then he got up and prayed two Rak'ahs, then he went out to the prayer}}
\hadithdefcmd{nasai}{2168}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ بْنِ هِلاَلٍ، قَالَ حَدَّثَنَا حُسَيْنُ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ أَحَدَهُمْ، كَانَ إِذَا نَامَ قَبْلَ أَنْ يَتَعَشَّى لَمْ يَحِلَّ لَهُ أَنْ يَأْكُلَ شَيْئًا وَلاَ يَشْرَبَ لَيْلَتَهُ وَيَوْمَهُ مِنَ الْغَدِ حَتَّى تَغْرُبَ الشَّمْسُ حَتَّى نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَكُلُوا وَاشْرَبُوا ‏\}‏ إِلَى ‏\{‏ الْخَيْطِ الأَسْوَدِ ‏\}‏ قَالَ وَنَزَلَتْ فِي أَبِي قَيْسِ بْنِ عَمْرٍو أَتَى أَهْلَهُ وَهُوَ صَائِمٌ بَعْدَ الْمَغْرِبِ فَقَالَ هَلْ مِنْ شَىْءٍ فَقَالَتِ امْرَأَتُهُ مَا عِنْدَنَا شَىْءٌ وَلَكِنْ أَخْرُجُ أَلْتَمِسُ لَكَ عَشَاءً ‏.‏ فَخَرَجَتْ وَوَضَعَ رَأْسَهُ فَنَامَ فَرَجَعَتْ إِلَيْهِ فَوَجَدَتْهُ نَائِمًا وَأَيْقَظَتْهُ فَلَمْ يَطْعَمْ شَيْئًا وَبَاتَ وَأَصْبَحَ صَائِمًا حَتَّى انْتَصَفَ النَّهَارُ فَغُشِيَ عَلَيْهِ وَذَلِكَ قَبْلَ أَنْ تَنْزِلَ هَذِهِ الآيَةُ فَأَنْزَلَ اللَّهُ فِيهِ ‏.‏\hadithno{2168}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Al-Bara bin Azib that:if one of them went to sleep before eating supper, it was not permissible for him to eat or drink anything that night or the following day, until the sun had set. (That continued) until this Verse was revealed: "And eat and drink until the white thread (light) of dawn appears to you distinct from the black thread (darkness of night)." He said: "This was revealed concerning Abu Qais bin 'Amr who came to his family after Maghrib when he was fasting, and said: 'Is there anything to eat?" His wife said: 'No , but I will go out, and he lay down and slept. She came back and found him sleeping, so she woke him up, but he did not eat anything. He spent the night fasting and woke up the next day fasting, until he passed out at midday. That was before this Verse was revealed, and Allah revealed it concerning him}}
\hadithdefcmd{nasai}{2169}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مُطَرِّفٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ قَوْلِهِ تَعَالَى ‏\{‏ حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ ‏\}‏ قَالَ ‏"‏ هُوَ سَوَادُ اللَّيْلِ وَبَيَاضُ النَّهَارِ ‏"‏ ‏.‏\hadithno{2169}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Adiyy bin Hatim that:he asked the Messenger of Allah about the verse "Until the white thread (light) of dawn appears to you distinct from the black thread (darkness of night)." He said: "It is the blackness of the night and the whiteness of the day}}
\hadithdefcmd{nasai}{2170}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ لِيُنَبِّهَ نَائِمَكُمْ وَيُرْجِعَ قَائِمَكُمْ وَلَيْسَ الْفَجْرُ أَنْ يَقُولَ هَكَذَا ‏"‏ ‏.‏ وَأَشَارَ بِكَفِّهِ ‏"‏ وَلَكِنِ الْفَجْرُ أَنْ يَقُولَ هَكَذَا ‏"‏ ‏.‏ وَأَشَارَ بِالسَّبَّابَتَيْنِ ‏.‏\hadithno{2170}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Mas'ud that the Prophet said:"Bilal calls the Adhan at night to awaken those of you who are asleep, and so that those who are praying Qiyam cam return. Dawn is not when the light appears like this" - and he gestured with his hand - "rather dawn is when it appears like this: - and he gestured with his two forefingers}}
\hadithdefcmd{nasai}{2171}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، أَنْبَأَنَا سَوَادَةُ بْنُ حَنْظَلَةَ، قَالَ سَمِعْتُ سَمُرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَغُرَّنَّكُمْ أَذَانُ بِلاَلٍ وَلاَ هَذَا الْبَيَاضُ حَتَّى يَنْفَجِرَ الْفَجْرُ هَكَذَا وَهَكَذَا ‏"‏ ‏.‏ يَعْنِي مُعْتَرِضًا ‏.‏ قَالَ أَبُو دَاوُدَ وَبَسَطَ بِيَدَيْهِ يَمِينًا وَشِمَالاً مَادًّا يَدَيْهِ ‏.‏\hadithno{2171}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Samurah said:"The Messenger of Allah said; 'DO not be confused by the Adhan of Bilal, or by this whiteness, until dawn appears like this" - meaning horizontally. (One of the narrators) Abu Dawud said: "And he spread out his hands gesturing to the right and left}}
\hadithdefcmd{nasai}{2172}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقَدَّمُوا قَبْلَ الشَّهْرِ بِصِيَامٍ إِلاَّ رَجُلٌ كَانَ يَصُومُ صِيَامًا أَتَى ذَلِكَ الْيَوْمُ عَلَى صِيَامِهِ ‏"‏ ‏.‏\hadithno{2172}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Do not fast ahead of the month, except for a man who habitually fasts, and that day happenes to be one of his regular fasts}}
\hadithdefcmd{nasai}{2173}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ بْنِ خَالِدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، قَالَ أَنْبَأَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، قَالَ أَخْبَرَنِي أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَقَدَّمَنَّ أَحَدٌ الشَّهْرَ بِيَوْمٍ وَلاَ يَوْمَيْنِ إِلاَّ أَحَدٌ كَانَ يَصُومُ صِيَامًا قَبْلَهُ فَلْيَصُمْهُ ‏"‏ ‏.‏\hadithno{2173}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that the Messengre of Allah said:"None should fast one or two days ahead of the month except, someone who had a prior habit for fasting, in which case let him fast}}
\hadithdefcmd{nasai}{2174}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو خَالِدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَتَقَدَّمُوا الشَّهْرَ بِصِيَامِ يَوْمٍ وَلاَ يَوْمَيْنِ إِلاَّ أَنْ يُوَافِقَ ذَلِكَ يَوْمًا كَانَ يَصُومُهُ أَحَدُكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ ‏.‏\hadithno{2174}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The messenger of Allah said: 'Do not fast one or two days ahead of the month, unless that happens to be a day that one of you habitually fasts."' Abu 'Abdur-Rahman (An-Nasai) said: This is a mistake}}
\hadithdefcmd{nasai}{2175}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ سَالِمٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصُومُ شَهْرَيْنِ مُتَتَابِعَيْنِ إِلاَّ أَنَّهُ كَانَ يَصِلُ شَعْبَانَ بِرَمَضَانَ ‏.‏\hadithno{2175}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Salamah that Umm Salamah said:"U never saw the Messenger of Allah fast two consecutive months, but he used to join shaban to Ramadan}}
\hadithdefcmd{nasai}{2176}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ تَوْبَةَ الْعَنْبَرِيِّ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصِلُ شَعْبَانَ بِرَمَضَانَ ‏.‏\hadithno{2176}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Umm Salamah said:"The Messenger of Allah used to join Shaban to Ramadan}}
\hadithdefcmd{nasai}{2177}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، أَنَّ مُحَمَّدَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ صِيَامِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ لاَ يُفْطِرُ وَيُفْطِرُ حَتَّى نَقُولَ لاَ يَصُومُ وَكَانَ يَصُومُ شَعْبَانَ أَوْ عَامَّةَ شَعْبَانَ ‏.‏\hadithno{2177}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Salamah bin 'Abdur-Rahman that he asked Aishah about the fasting of the Messenger of Allah. She said:"The Messenger of Allah used to fast until we said: 'He will not fast.' And he used to fast Shaban, or most of Shaban}}
\hadithdefcmd{nasai}{2178}{أَخْبَرَنَا أَحْمَدُ بْنُ سَعْدِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا نَافِعُ بْنُ يَزِيدَ، أَنَّ ابْنَ الْهَادِ، حَدَّثَهُ أَنَّ مُحَمَّدَ بْنَ إِبْرَاهِيمَ حَدَّثَهُ عَنْ أَبِي سَلَمَةَ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ عَائِشَةَ، قَالَتْ لَقَدْ كَانَتْ إِحْدَانَا تُفْطِرُ فِي رَمَضَانَ فَمَا تَقْدِرُ عَلَى أَنْ تَقْضِيَ حَتَّى يَدْخُلَ شَعْبَانُ وَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ فِي شَهْرٍ مَا يَصُومُ فِي شَعْبَانَ كَانَ يَصُومُهُ كُلَّهُ إِلاَّ قَلِيلاً بَلْ كَانَ يَصُومُهُ كُلَّهُ ‏.‏\hadithno{2178}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aishah said:"One of us (women) would miss some fasts in Ramadan and she would not be able to make it up until Shaban began, and the Messenger of Allah did not fast in any month as he fasted in Shaban; he used to fast all of it, except a little, he used to fast all of it}}
\hadithdefcmd{nasai}{2179}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ فَقُلْتُ أَخْبِرِينِي عَنْ صِيَامِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ كَانَ يَصُومُ حَتَّى نَقُولَ قَدْ صَامَ وَيُفْطِرُ حَتَّى نَقُولَ قَدْ أَفْطَرَ وَلَمْ يَكُنْ يَصُومُ شَهْرًا أَكْثَرَ مِنْ شَعْبَانَ كَانَ يَصُومُ شَعْبَانَ إِلاَّ قَلِيلاً كَانَ يَصُومُ شَعْبَانَ كُلَّهُ ‏.‏\hadithno{2179}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Salamah said:"I asked Aishah: 'Tell me about the fasting of the Messenger of Allah.' She said: 'he used to fast until we said: he is going to fast until we said: He is not going to fast. He never fasted any month more than Shaban. He used to fast (all) of Shaban except a little, he used to fast all of Shaban}}
\hadithdefcmd{nasai}{2180}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي شَهْرٍ مِنَ السَّنَةِ أَكْثَرَ صِيَامًا مِنْهُ فِي شَعْبَانَ كَانَ يَصُومُ شَعْبَانَ كُلَّهُ ‏.‏\hadithno{2180}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Messenger of Allah did not fast in any month of the year more than he did in Shaban. He used to fast all of Shaban}}
\hadithdefcmd{nasai}{2181}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ خَالِدِ بْنِ سَعْدٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصُومُ شَعْبَانَ ‏.‏\hadithno{2181}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"The Prophet used to fast Shaban}}
\hadithdefcmd{nasai}{2182}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ، عَنْ عَبْدَةَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ لاَ أَعْلَمُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ الْقُرْآنَ كُلَّهُ فِي لَيْلَةٍ وَلاَ قَامَ لَيْلَةً حَتَّى الصَّبَاحِ وَلاَ صَامَ شَهْرًا كَامِلاً قَطُّ غَيْرَ رَمَضَانَ ‏.‏\hadithno{2182}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Aishah said:"I do not know that the Messenger of Allah recited the whole Quran in one night, or prayed Qiyam until morning, or ever fasted an entire month except Ramadan}}
\hadithdefcmd{nasai}{2183}{أَخْبَرَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي يُوسُفَ الصَّيْدَلاَنِيُّ، - حَرَّانِيٌّ - قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَ سَأَلْتُهَا عَنْ صِيَامِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ قَدْ صَامَ وَيُفْطِرُ حَتَّى نَقُولَ قَدْ أَفْطَرَ وَلَمْ يَصُمْ شَهْرًا تَامًّا مُنْذُ أَتَى الْمَدِينَةَ إِلاَّ أَنْ يَكُونَ رَمَضَانُ ‏.‏\hadithno{2183}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah bin Shaqiq said:""I asked 'Aishah about the fasting of the Messenger of Allah. She said: 'The Messenger of Allah used to fast until we said that he is going to fast (continually), and he used not to fast until we said: he is not going to fast. And he did not fast for a whole month from the time he came to Al-Madinah, apart from Ramadan}}
\hadithdefcmd{nasai}{2184}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ أَنْبَأَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ كَهْمَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي صَلاَةَ الضُّحَى قَالَتْ لاَ إِلاَّ أَنْ يَجِيءَ مِنْ مَغِيبِهِ ‏.‏ قُلْتُ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ شَهْرًا كُلَّهُ قَالَتْ لاَ مَا عَلِمْتُ صَامَ شَهْرًا كُلَّهُ إِلاَّ رَمَضَانَ وَلاَ أَفْطَرَ حَتَّى يَصُومَ مِنْهُ حَتَّى مَضَى لِسَبِيلِهِ ‏.‏\hadithno{2184}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Shaqiq said:"I said to Aishah: 'Did the Messenger of Allah offer Duha prayer? She said: "No, unless he was returning from a journey, I Did the Messenger of Allah fast an entire month?' She said: 'No, I do not remember him fasting any month in full apart from Ramadan, and he did not break his fast for a whole month, rather he would fast some of (each month) until he passed away}}
\hadithdefcmd{nasai}{2185}{أَخْبَرَنَا أَبُو الأَشْعَثِ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي صَلاَةَ الضُّحَى قَالَتْ لاَ إِلاَّ أَنْ يَجِيءَ مِنْ مَغِيبِهِ ‏.‏ قُلْتُ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَهُ صَوْمٌ مَعْلُومٌ سِوَى رَمَضَانَ قَالَتْ وَاللَّهِ إِنْ صَامَ شَهْرًا مَعْلُومًا سِوَى رَمَضَانَ حَتَّى مَضَى لِوَجْهِهِ وَلاَ أَفْطَرَ حَتَّى يَصُومَ مِنْهُ ‏.‏\hadithno{2185}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah bin Shaqiq said:'I said to Aishah: 'did the Messenger of Allah offer Duah prayer?' she said: 'No, unless he was returning from a journey.' I said: 'was the Messenger of Allah known to observe any fast regularly apart from Ramadan?'' She said: 'by Allah, he did not observe any fast regularly apart from amadan until he passed away, and he did not break his fast for a whole month, rather he would fast some of it (each month)}}
\hadithdefcmd{nasai}{2186}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، عَنْ بَقِيَّةَ، قَالَ حَدَّثَنَا بَحِيرٌ، عَنْ خَالِدٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، أَنَّ رَجُلاً، سَأَلَ عَائِشَةَ عَنِ الصِّيَامِ، فَقَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ شَعْبَانَ كُلَّهُ وَيَتَحَرَّى صِيَامَ الاِثْنَيْنِ وَالْخَمِيسِ ‏.‏\hadithno{2186}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jubair bin Nufair that a man asked Aishah about fasting and she said:"The Messenger of Allah used to fast all of Shaban, and he made sure to fast on Mondays and Thursdays}}
\hadithdefcmd{nasai}{2187}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، قَالَ حَدَّثَنَا ثَوْرٌ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ رَبِيعَةَ الْجُرَشِيِّ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ شَعْبَانَ وَرَمَضَانَ وَيَتَحَرَّى الاِثْنَيْنِ وَالْخَمِيسَ ‏.‏\hadithno{2187}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to fast Sha`ban and Ramadan, and he made sure to fast on Mondays and Thursday}}
\hadithdefcmd{nasai}{2188}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الأَشَجُّ، عَنْ أَبِي خَالِدٍ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ، قَالَ كُنَّا عِنْدَ عَمَّارٍ فَأُتِيَ بِشَاةٍ مَصْلِيَّةٍ فَقَالَ كُلُوا ‏.‏ فَتَنَحَّى بَعْضُ الْقَوْمِ قَالَ إِنِّي صَائِمٌ ‏.‏ فَقَالَ عَمَّارٌ مَنْ صَامَ الْيَوْمَ الَّذِي يُشَكُّ فِيهِ فَقَدْ عَصَى أَبَا الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{2188}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Silah said:"We were with 'Ammar and a roast sheep was brought and he said: 'Eat.' One of the people turned away and said: 'I am fasting 'Ammar said: Whoever fasts on the day concerning which there is doubt, has disobeyed Abu Al-Qasim}}
\hadithdefcmd{nasai}{2189}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ أَبِي يُونُسَ، عَنْ سِمَاكٍ، قَالَ دَخَلْتُ عَلَى عِكْرِمَةَ فِي يَوْمٍ قَدْ أُشْكِلَ مِنْ رَمَضَانَ هُوَ أَمْ مِنْ شَعْبَانَ وَهُوَ يَأْكُلُ خُبْزًا وَبَقْلاً وَلَبَنًا فَقَالَ لِي هَلُمَّ ‏.‏ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ قَالَ وَحَلَفَ بِاللَّهِ لَتُفْطِرَنَّ قُلْتُ سُبْحَانَ اللَّهِ مَرَّتَيْنِ فَلَمَّا رَأَيْتُهُ يَحْلِفُ لاَ يَسْتَثْنِي تَقَدَّمْتُ قُلْتُ هَاتِ الآنَ مَا عِنْدَكَ قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ حَالَ بَيْنَكُمْ وَبَيْنَهُ سَحَابَةٌ أَوْ ظُلْمَةٌ فَأَكْمِلُوا الْعِدَّةَ عِدَّةَ شَعْبَانَ وَلاَ تَسْتَقْبِلُوا الشَّهْرَ اسْتِقْبَالاً وَلاَ تَصِلُوا رَمَضَانَ بِيَوْمٍ مِنْ شَعْبَانَ ‏"‏ ‏.‏\hadithno{2189}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Simak said:"I entered upon 'Ikrimah on the day concerning which there was doubt as to whether it was Ramadan or Shaban, and he was eating bread, vegetables and milk. He said: 'Come and eat.' I said: 'I am fasting.' He adjured me by Allah to break my fast. I said Subhan-Allah twice. When I saw that he was insisting, I went forward and said: 'Give me what you have.' He said: 'I heard Ibn 'Abbas say: The Messenger of Allah said: 'Fast when you see it (the crescent) and stop fasting when you see it, and if clouds or darkness prevent you from seeing it, then complete the number of days of Shaban, and do not fast ahead of the month, and do not join Ramadan to a day of Shaban}}
\hadithdefcmd{nasai}{2190}{أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ جَدِّي، قَالَ أَخْبَرَنِي شُعَيْبُ بْنُ إِسْحَاقَ، عَنِ الأَوْزَاعِيِّ، وَابْنِ أَبِي عَرُوبَةَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏ "‏ أَلاَ لاَ تَقَدَّمُوا الشَّهْرَ بِيَوْمٍ أَوِ اثْنَيْنِ إِلاَّ رَجُلٌ كَانَ يَصُومُ صِيَامًا فَلْيَصُمْهُ ‏"‏ ‏.‏\hadithno{2190}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah used to say:"Do not fast one or two days ahead of the month, unless the one who used to observe a regular fast. In that case let him fast}}
\hadithdefcmd{nasai}{2191}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، قَالَ أَنْبَأَنَا خَالِدٌ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2191}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Saeed bin Al-Musayyab that the Messenger of Allah said:"Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2192}{أَخْبَرَنَا مُحَمَّدُ بْنُ جَبَلَةَ، قَالَ حَدَّثَنَا الْمُعَافَى، قَالَ حَدَّثَنَا مُوسَى، عَنْ إِسْحَاقَ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُرَغِّبُ النَّاسَ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ أَنْ يَأْمُرَهُمْ بِعَزِيمَةِ أَمْرٍ فِيهِ فَيَقُولُ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2192}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Urwah bin Az-Zubair narrated that Aishah told him that:the Messenger of Allah used to encourage the people to pray Qiyam in Ramadan, without insisting on that. He said: "Whoever spends the nights of Ramadan in prayer out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2193}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ أَنْبَأَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ، عَنْ يُونُسَ الأَيْلِيِّ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ فِي جَوْفِ اللَّيْلِ يُصَلِّي فِي الْمَسْجِدِ فَصَلَّى بِالنَّاسِ وَسَاقَ الْحَدِيثَ وَفِيهِ قَالَتْ فَكَانَ يُرَغِّبُهُمْ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ أَنْ يَأْمُرَهُمْ بِعَزِيمَةٍ وَيَقُولُ ‏ "‏ مَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالأَمْرُ عَلَى ذَلِكَ ‏.‏\hadithno{2193}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Az-Zuhir said:"Urwah bin Az-Zubair told me that 'Aishah told him: 'The Messenger of Allah went out in the middle of the night to pray in the Masjid, and he led the people in prayer; and he quoted the same Hadith, in which she said: 'He used to encourage the people to pray Qiyam n Ramadan, without insisting on that.' He said: 'Whoever spends the night of Lailat Al-Qadr in prayer out of faith and in the hope of reward, he will be forgiven his previous sins.' He said: 'And the Messenger of Allah passed away when this was the state of affairs}}
\hadithdefcmd{nasai}{2194}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي رَمَضَانَ ‏ "‏ مَنْ قَامَهُ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2194}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Salamah bin 'Abdur-Rahman narrated that Abu Hurairah said:"I heard the Messenger of Allah say concerning Ramadan: 'Whoever spends its night in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2195}{أَخْبَرَنِي مُحَمَّدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مِنْ جَوْفِ اللَّيْلِ فَصَلَّى فِي الْمَسْجِدِ وَسَاقَ الْحَدِيثَ وَقَالَ فِيهِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُرَغِّبُهُمْ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ أَنْ يَأْمُرَهُمْ بِعَزِيمَةِ أَمْرٍ فِيهِ فَيَقُولُ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2195}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Urwah bin Az-Zubair narrated that 'Aishah told him:"The Messenger of Allah went out in the middle of the night and prayed in the Masjid," and he quoted the same Hadith, in which he said: "nd he encouraged them to pray Qiyam in Ramadan, without insisting on that, and he said: 'Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2196}{أَخْبَرَنَا مُحَمَّدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لِرَمَضَانَ ‏ "‏ مَنْ قَامَهُ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2196}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Salamah bin 'Abdur-Rahman narrated that Abu Hurairah said:"I heard the Messenger of Allah say concerning Ramadan: 'Whoeve spends its nights in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2197}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا سَلَمَةَ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2197}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Shahab that Abu Salamah told him that Abu Hurairah said:"The Messenger of Allah said: 'Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2198}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُرَغِّبُ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ أَنْ يَأْمُرَهُمْ بِعَزِيمَةٍ قَالَ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2198}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah used to encourage (us) to pray Qiyam during Ramadan, without insisting on that, and he said: 'Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2199}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2199}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2200}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2200}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever spends the nights of Ramadan n prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2201}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، قَالَ حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، قَالَ الزُّهْرِيُّ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَحُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2201}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever spends the night of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2202}{أَخْبَرَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ صَامَ رَمَضَانَ ‏"‏ ‏.‏ وَفِي حَدِيثِ قُتَيْبَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قَامَ شَهْرَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2202}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Whoever fasts during Ramadan" and according to the Hadith of Qutaibah, the Prophet said: "Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins, and whoever spends the night of Lailat Al-Qadr in prayer out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2203}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2203}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Whoever fasts in Ramadan out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2204}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2204}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever fasts Ramadan out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2205}{أَخْبَرَنَا عَلِيُّ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا ابْنُ فُضَيْلٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2205}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever fasts Ramadan out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2206}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، وَمُحَمَّدُ بْنُ هِشَامٍ، وَأَبُو الأَشْعَثِ، - وَاللَّفْظُ لَهُ - قَالُوا حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2206}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Salamah bin 'Abdur-Rahman said:"Abu Hurairah told me that the Messenger of Allah said: 'Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins, and whoever spends the night of Lailat Al-Qadr in prayer out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2207}{أَخْبَرَنِي مَحْمُودُ بْنُ خَالِدٍ، عَنْ مَرْوَانَ، أَنْبَأَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَامَ شَهْرَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{2207}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will be forgiven his previous sins, and whoever spends the night of Lailat Al-Qadr in prayer out of faith and in the hope of reward, he will be forgiven his previous sins}}
\hadithdefcmd{nasai}{2208}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، قَالَ حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنِي النَّضْرُ بْنُ شَيْبَانَ، أَنَّهُ لَقِيَ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ فَقَالَ لَهُ حَدِّثْنِي بِأَفْضَلِ، شَىْءٍ سَمِعْتَهُ يُذْكَرُ، فِي شَهْرِ رَمَضَانَ ‏.‏ فَقَالَ أَبُو سَلَمَةَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ ذَكَرَ شَهْرَ رَمَضَانَ فَفَضَّلَهُ عَلَى الشُّهُورِ وَقَالَ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا خَرَجَ مِنْ ذُنُوبِهِ كَيَوْمِ وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ أَبُو سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2208}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{An-Nadr bin Shaiban narrated that he met Abu Salamah bin 'Abdur-Rahman and said to him:"Tell me of the best thing you heard about the month of Ramadan." Abu Salamah said: "Abdur-Rahman bin 'Awf told me that the Messenger of Allah mentioned Ramadan and said that it is superior to other months, and he said: 'Whoever spends the nights of Ramadan in prayer (Qiyam) out of faith and in the hope of reward, he will emerge from his sins as on the day his mother bore him."'(Daif) Abu 'Abdur-Rahman (An-Nasai) said: This is a mistake, and what is correct is "Abu Salamah, from Abu Hurairah}}
\hadithdefcmd{nasai}{2209}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ أَنْبَأَنَا الْقَاسِمُ بْنُ الْفَضْلِ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شَيْبَانَ، عَنْ أَبِي سَلَمَةَ، فَذَكَرَ مِثْلَهُ وَقَالَ ‏ "‏ مَنْ صَامَهُ وَقَامَهُ إِيمَانًا وَاحْتِسَابًا ‏"‏ ‏.‏\hadithno{2209}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar report was narrated from Abu Salamah and he said:"Whoever fasts it and spends its nights in prayer out of faith and in the hope of reward." (Daif)}}
\hadithdefcmd{nasai}{2210}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ، قَالَ حَدَّثَنَا الْقَاسِمُ بْنُ الْفَضْلِ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شَيْبَانَ، قَالَ قُلْتُ لأَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ حَدِّثْنِي بِشَىْءٍ، سَمِعْتَهُ مِنْ، أَبِيكَ سَمِعَهُ أَبُوكَ، مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْسَ بَيْنَ أَبِيكَ وَبَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَدٌ فِي شَهْرِ رَمَضَانَ ‏.‏ قَالَ نَعَمْ حَدَّثَنِي أَبِي قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى فَرَضَ صِيَامَ رَمَضَانَ عَلَيْكُمْ وَسَنَنْتُ لَكُمْ قِيَامَهُ فَمَنْ صَامَهُ وَقَامَهُ إِيمَانًا وَاحْتِسَابًا خَرَجَ مِنْ ذُنُوبِهِ كَيَوْمِ وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏\hadithno{2210}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{An-Nadr bin Shaiban said:"I said to Abu Salamah bin 'Abdur-Rahman: 'Tell me of something that you heard from your father, that he heard from the Messenger of Allah, with no one in between your father and Messenge of Allah concerning the month of Ramadan. He said: 'Yes; my father said: The Messenger of Allah said: Allah, may He be blessed and exalted, enjoined the fast of Ramadan upon you, and I have made it Sunnah for you to spend its nights in prayer. Whoever fasts it and spends its nights in prayer out of faith and in the hope of reward, he will emerge from his sins as on the day his mother bore him."' (Daif)}}
\hadithdefcmd{nasai}{2211}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ زَيْدٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ الصَّوْمُ لِي وَأَنَا أَجْزِي بِهِ وَلِلصَّائِمِ فَرْحَتَانِ حِينَ يُفْطِرُ وَحِينَ يَلْقَى رَبَّهُ وَالَّذِي نَفْسِي بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2211}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ali bin Abi Talib that the Messenger of Allah said:"Allah, may He be blessed and exalted, says: 'Fasting is for me and I shall reward for it. The fasting person has two moments of joy: When he breaks his fast and when he meets his Lord.' By the One in whose hand is my soul, the smell that comes from the mouth of the fasting person is better before Allah than the fragrance of musk}}
\hadithdefcmd{nasai}{2212}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، قَالَ عَبْدُ اللَّهِ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ الصَّوْمُ لِي وَأَنَا أَجْزِي بِهِ وَلِلصَّائِمِ فَرْحَتَانِ فَرْحَةٌ حِينَ يَلْقَى رَبَّهُ وَفَرْحَةٌ عِنْدَ إِفْطَارِهِ وَلَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2212}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Al-Ahwas that 'Abdullah said:"Allah, may He be exalted, said: 'Fasting is for me and I shall reward for it. The fasting person has two moments of joy: When he breaks his fast and when he meets his Lord. And the smell that comes from the mouth of the fasting person is better before Allah than the fragrance of musk}}
\hadithdefcmd{nasai}{2213}{أَخْبَرَنَا عَلِيُّ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالَ حَدَّثَنَا أَبُو سِنَانٍ، ضِرَارُ بْنُ مُرَّةَ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ الصَّوْمُ لِي وَأَنَا أَجْزِي بِهِ وَلِلصَّائِمِ فَرْحَتَانِ إِذَا أَفْطَرَ فَرِحَ وَإِذَا لَقِيَ اللَّهَ فَجَزَاهُ فَرِحَ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2213}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Saeed said:"The Prophet said: 'Allah, may He be blessed and exalted, says: Fasting is for me I shall reward for it. The fasting person has two moments of joy: When he breaks his fast and when he meets his Lord. By the One in Whose hand is the soul of Muhammad, the smell that comes from the mouth of the fasting person is better before Allah than the fragrance of musk}}
\hadithdefcmd{nasai}{2214}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ الْمُنْذِرَ بْنَ عُبَيْدٍ، حَدَّثَهُ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الصِّيَامُ لِي وَأَنَا أَجْزِي بِهِ وَالصَّائِمُ يَفْرَحُ مَرَّتَيْنِ عِنْدَ فِطْرِهِ وَيَوْمَ يَلْقَى اللَّهَ وَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2214}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"(Allah says) fasting is for me and I shall reward for it. The fasting person rejoices twice: when he breaks his fast and the day when he meets his Lord. And the smell that come from the mouth of the fasting person is better before Allah than the fragrance of musk}}
\hadithdefcmd{nasai}{2215}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ حَسَنَةٍ عَمِلَهَا ابْنُ آدَمَ إِلاَّ كُتِبَ لَهُ عَشْرُ حَسَنَاتٍ إِلَى سَبْعِمِائَةِ ضِعْفٍ قَالَ اللَّهُ عَزَّ وَجَلَّ إِلاَّ الصِّيَامَ فَإِنَّهُ لِي وَأَنَا أَجْزِي بِهِ يَدَعُ شَهْوَتَهُ وَطَعَامَهُ مِنْ أَجْلِي الصِّيَامُ جُنَّةٌ لِلصَّائِمِ فَرْحَتَانِ فَرْحَةٌ عِنْدَ فِطْرِهِ وَفَرْحَةٌ عِنْدَ لِقَاءِ رَبِّهِ وَلَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2215}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"There is no good deed that the son of Adam does, but between ten and seven hundred Hasanahs will be recorded for him. Allah, the mighty and sublime, said: 'Except fasing, for it is for me and I shall reward for it. He gives up his desires and his food for my sake. Fasting is a shield, and the fasting person has two moments of joy. One when he breaks his fast and another when he meets his Lord. And the smell that comes from the mouth of the fasting person is better before Allah than the fragrance of musk}}
\hadithdefcmd{nasai}{2216}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَطَاءٌ، عَنْ أَبِي صَالِحٍ الزَّيَّاتِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ عَمَلِ ابْنِ آدَمَ لَهُ إِلاَّ الصِّيَامَ هُوَ لِي وَأَنَا أَجْزِي بِهِ وَالصِّيَامُ جُنَّةٌ إِذَا كَانَ يَوْمُ صِيَامِ أَحَدِكُمْ فَلاَ يَرْفُثْ وَلاَ يَصْخَبْ فَإِنْ شَاتَمَهُ أَحَدٌ أَوْ قَاتَلَهُ فَلْيَقُلْ إِنِّي صَائِمٌ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ مِنْ رِيحِ الْمِسْكِ لِلصَّائِمِ فَرْحَتَانِ يَفْرَحُهُمَا إِذَا أَفْطَرَ فَرِحَ بِفِطْرِهِ وَإِذَا لَقِيَ رَبَّهُ عَزَّ وَجَلَّ فَرِحَ بِصَوْمِهِ ‏"‏ ‏.‏\hadithno{2216}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: '(Allah says) Every deed of the son of Adam is for him, except fasting; it is for me and I shall reward for it. Fasting is a shield. If any one of you is fasting, let him no utter obscene talk or raise his voice in anger, and if anyone insults him or wants to fight, let him say: I am fasting. By the One in whose hand is the soul of Muhammad, the smell coming from the mouth of the fasting person is better before Allah than the fragrance of musk. The fasting person has two moments of joy: When he breaks his fast he rejoices at breaking his fast and when he meets his Lord, the Mighty and Sublime, he will rejoice at having fasted}}
\hadithdefcmd{nasai}{2217}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ جُرَيْجٍ، قِرَاءَةً عَلَيْهِ عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، قَالَ أَخْبَرَنِي عَطَاءٌ الزَّيَّاتُ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ كُلُّ عَمَلِ ابْنِ آدَمَ لَهُ إِلاَّ الصِّيَامَ هُوَ لِي وَأَنَا أَجْزِي بِهِ الصِّيَامُ جُنَّةٌ فَإِذَا كَانَ يَوْمُ صَوْمِ أَحَدِكُمْ فَلاَ يَرْفُثْ وَلاَ يَصْخَبْ فَإِنْ شَاتَمَهُ أَحَدٌ أَوْ قَاتَلَهُ فَلْيَقُلْ إِنِّي امْرُؤٌ صَائِمٌ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ عَنْ أَبِي هُرَيْرَةَ سَعِيدُ بْنُ الْمُسَيَّبِ ‏.‏\hadithno{2217}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'Allah, the Mighty and sublime, said: Every deed of the son of Adam is for him, except fasting; it is for me and I shall reward for it. Fasting is a shield. If any one of you is observing a fast, let him not utte obscene a fast, let him not utter obscene talk or raise his voice in anger, and if anyone insults him or wants to fight, let him say: I am a person who is fasting. By the One in Whose hand is the soul of Muhammad, the smell coming from the mouth of the fasting person is better before Allah than the fragrance of musk." ' (Sahih) This Hadith was narrated from Abu Hurairah by Saeed bin Al-Musayyab}}
\hadithdefcmd{nasai}{2218}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْ��َرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ كُلُّ عَمَلِ ابْنِ آدَمَ لَهُ إِلاَّ الصِّيَامَ هُوَ لِي وَأَنَا أَجْزِي بِهِ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخِلْفَةُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2218}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah say: 'Allah, the mighty and sublime, said: Every deed of the son of Adam is for him, except fasting; it is for me and I shall reward for it. By the one in whose hand is the soul of Muhmmad, the smell coming from the mouth of the fasting person is better before Allah than the fragrance of musk}}
\hadithdefcmd{nasai}{2219}{أَخْبَرَنَا أَحْمَدُ بْنُ عِيسَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرٍو، عَنْ بُكَيْرٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ حَسَنَةٍ يَعْمَلُهَا ابْنُ آدَمَ فَلَهُ عَشْرُ أَمْثَالِهَا إِلاَّ الصِّيَامَ لِي وَأَنَا أَجْزِي بِهِ ‏"‏ ‏.‏\hadithno{2219}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said (that Allah said):"For every good deed that the son of Adam does, he will have (the reward of) ten the like thereof, except for fasting. It is for Me and I shall reward for it}}
\hadithdefcmd{nasai}{2220}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي يَعْقُوبَ، قَالَ أَخْبَرَنِي رَجَاءُ بْنُ حَيْوَةَ، عَنْ أَبِي أُمَامَةَ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ مُرْنِي بِأَمْرٍ آخُذُهُ عَنْكَ ‏.‏ قَالَ ‏ "‏ عَلَيْكَ بِالصَّوْمِ فَإِنَّهُ لاَ مِثْلَ لَهُ ‏"‏ ‏.‏\hadithno{2220}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin 'Abdullah bin Abi Yaqub said:"Raja bin Haiwah narrated that Abu Umamah said: 'I came to the Messenger of Allah and said: Tel l me of something that I may take (learn) from you. He said: "Take to fasting, for there is nothing like it}}
\hadithdefcmd{nasai}{2221}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، أَنَّ مُحَمَّدَ بْنَ عَبْدِ اللَّهِ بْنِ أَبِي يَعْقُوبَ الضَّبِّيَّ، حَدَّثَهُ عَنْ رَجَاءِ بْنِ حَيْوَةَ، قَالَ حَدَّثَنَا أَبُو أُمَامَةَ الْبَاهِلِيُّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مُرْنِي بِأَمْرٍ يَنْفَعُنِي اللَّهُ بِهِ ‏.‏ قَالَ ‏ "‏ عَلَيْكَ بِالصِّيَامِ فَإِنَّهُ لاَ مِثْلَ لَهُ ‏"‏ ‏.‏\hadithno{2221}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Raja bin Haiwah said:"Abu Umamah Al-Bahili narrated to me: 'I said: O Messenger of Allah, tell me of something by which Allah will benefic me. He said: Take to fasting, for there is nothing like it}}
\hadithdefcmd{nasai}{2222}{أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الضَّعِيفُ، - شَيْخٌ صَالِحٌ وَالضَّعِيفُ لَقَبٌ لِكَثْرَةِ عِبَادَتِهِ - قَالَ أَخْبَرَنَا يَعْقُوبُ الْحَضْرَمِيُّ قَالَ حَدَّثَنَا شُعْبَةُ عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي يَعْقُوبَ عَنْ أَبِي نَصْرٍ عَنْ رَجَاءِ بْنِ حَيْوَةَ عَنْ أَبِي أُمَامَةَ أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَىُّ الْعَمَلِ أَفْضَلُ قَالَ ‏ "‏ عَلَيْكَ بِالصَّوْمِ فَإِنَّهُ لاَ عِدْلَ لَهُ ‏"‏ ‏.‏\hadithno{2222}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Umamah that he asked the Messenger of Allah:"Which deed is best?" he said: "Take to fasting, for there is nothing equal to it}}
\hadithdefcmd{nasai}{2223}{أَخْبَرَنَا يَحْيَى بْنُ مُحَمَّدٍ، - هُوَ ابْنُ السَّكَنِ أَبُو عُبَيْدِ اللَّهِ - قَالَ حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ أَبِي يَعْقُوبَ الضَّبِّيِّ، عَنْ أَبِي نَصْرٍ الْهِلاَلِيِّ، عَنْ رَجَاءِ بْنِ حَيْوَةَ، عَنْ أَبِي أُمَامَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مُرْنِي بِعَمَلٍ ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِالصَّوْمِ فَإِنَّهُ لاَ عِدْلَ لَهُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ مُرْنِي بِعَمَلٍ ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِالصَّوْمِ فَإِنَّهُ لاَ عِدْلَ لَهُ ‏"‏ ‏.‏\hadithno{2223}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Umamah said:"I said: 'O Messenger of Allah, tell me of an action (I should do).' He said: 'Take to fasting, for there is nothing equal to it}}
\hadithdefcmd{nasai}{2224}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، قَالَ حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ فِطْرٍ، أَخْبَرَنِي حَبِيبُ بْنُ أَبِي ثَابِتٍ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصَّوْمُ جُنَّةٌ ‏"‏ ‏.‏\hadithno{2224}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Muadh bin Jabal said:"The Messenger of Allah said: 'Fasting is a shield}}
\hadithdefcmd{nasai}{2225}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُلَيْمَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، وَالْحَكَمِ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصَّوْمُ جُنَّةٌ ‏"‏ ‏.‏\hadithno{2225}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Muadh bin Jabal said:"The Messenger of Allah said: 'Fasting is a shield}}
\hadithdefcmd{nasai}{2226}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ عُرْوَةَ بْنَ النَّزَّالِ، يُحَدِّثُ عَنْ مُعَاذٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصَّوْمُ جُنَّةٌ ‏"‏ ‏.‏\hadithno{2226}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Muadh bin Jabal said:"The Messenger of Allah said: 'Fasting is a shield}}
\hadithdefcmd{nasai}{2227}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجٍ، عَنْ شُعْبَةَ، قَالَ لِي الْحَكَمُ سَمِعْتُهُ مِنْهُ، مُنْذُ أَرْبَعِينَ سَنَةً ثُمَّ قَالَ الْحَكَمُ وَحَدَّثَنِي بِهِ مَيْمُونُ بْنُ أَبِي شَبِيبٍ عَنْ مُعَاذِ بْنِ جَبَلٍ ‏.‏\hadithno{2227}\hadithgrade{Al-Albani: Daif}\hadithtrans{It was narrated from Shubah:"Al-Hakam said to me: 'I heard it from him forty years age; Then Al-Hakam said: 'And Maimum bin Abi Shabib narrated it to me from Muadh bin Jabal." (Sahih)}}
\hadithdefcmd{nasai}{2228}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجٍ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَطَاءٌ، عَنْ أَبِي صَالِحٍ الزَّيَّاتِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصِّيَامُ جُنَّةٌ ‏"‏ ‏.‏\hadithno{2228}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'Fasting is a shield."' (Sahih)}}
\hadithdefcmd{nasai}{2229}{وَأَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، أَنْبَأَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ جُرَيْجٍ، قِرَاءَةً عَنْ عَطَاءٍ، قَالَ أَنْبَأَنَا عَطَاءٌ الزَّيَّاتُ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصِّيَامُ جُنَّةٌ ‏"‏ ‏.‏\hadithno{2229}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'Fasting is a shield."' (Sahih)}}
\hadithdefcmd{nasai}{2230}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، أَنَّ مُطَرِّفًا، - رَجُلٌ مِنْ بَنِي عَامِرِ بْنِ صَعْصَعَةَ - حَدَّثَهُ أَنَّ عُثْمَانَ بْنَ أَبِي الْعَاصِ دَعَا لَهُ بِلَبَنٍ لِيَسْقِيَهُ فَقَالَ مُطَرِّفٌ إِنِّي صَائِمٌ فَقَالَ عُثْمَانُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الصِّيَامُ جُنَّةٌ كَجُنَّةِ أَحَدِكُمْ مِنَ الْقِتَالِ ‏"‏ ‏.‏\hadithno{2230}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Saeed bin Abi Hind that Mutarrif a man from Banu 'Amir bin Sa'sa'ah told him that:'Uthman bin Abi Al-As called for milk to be given to him (Mutarrif) to drink. Mutarrif said: 'I heard the Messenger of Allah say: 'Fasting is a shield like the shield of any one of you in battle."' Abu Hurairah said: "The Messenger of Allah said: 'Fasting is a shield."' (Sahih)}}
\hadithdefcmd{nasai}{2231}{أَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ مُطَرِّفٍ، قَالَ دَخَلْتُ عَلَى عُثْمَانَ بْنِ أَبِي الْعَاصِ فَدَعَا بِلَبَنٍ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الصَّوْمُ جُنَّةٌ مِنَ النَّارِ كَجُنَّةِ أَحَدِكُمْ مِنَ الْقِتَالِ ‏"‏ ‏.‏\hadithno{2231}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mutarrif said:"I entered upon 'Uthman bin Abi Al-As and he called for milk. I said: I am fasting; He said: "I heard the Messenger of Allah say: 'Fasting is a shield like the of any one of you in battle."' Abu Hurairah said: "The Messenger of Allah said: 'Fasting is a shield."' (Sahih)}}
\hadithdefcmd{nasai}{2232}{أَخْبَرَنِي زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا أَبُو مُصْعَبٍ، عَنِ الْمُغِيرَةِ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، قَالَ دَخَلَ مُطَرِّفٌ عَلَى عُثْمَانَ نَحْوَهُ مُرْسَلٌ ‏.‏\hadithno{2232}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Saeed bin Abi Hind said:"Mutarrif entered upon 'Uthman" and he narrated something similar in Mursal from. Abu Hurairah said: "The Messenger of Allah said: 'Fasting is a shield."' (Sahih)}}
\hadithdefcmd{nasai}{2233}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا وَاصِلٌ، عَنْ بَشَّارِ بْنِ أَبِي سَيْفٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عِيَاضِ بْنِ غُطَيْفٍ، قَالَ أَبُو عُبَيْدَةَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الصَّوْمُ جُنَّةٌ مَا لَمْ يَخْرِقْهَا ‏"‏ ‏.‏\hadithno{2233}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu 'Ubaidah said:"I heard the Messenger of Allah say: 'Fasting is a shield, so long as you do not damage it}}
\hadithdefcmd{nasai}{2234}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَزِيدَ الآدَمِيُّ، قَالَ حَدَّثَنَا مَعْنٌ، عَنْ خَارِجَةَ بْنِ سُلَيْمَانَ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الصِّيَامُ جُنَّةٌ مِنَ النَّارِ فَمَنْ أَصْبَحَ صَائِمًا فَلاَ يَجْهَلْ يَوْمَئِذٍ وَإِنِ امْرُؤٌ جَهِلَ عَلَيْهِ فَلاَ يَشْتِمْهُ وَلاَ يَسُبَّهُ وَلْيَقُلْ إِنِّي صَائِمٌ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2234}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said that the Prophet said:"Fasting is a shield against the Fire. Whoever starts the day of fasting, let him not act in an ignorant manner during that day. If anyone treats him in an ignorant maner, let him not insult him or curse him, rather let him say: "I am fasting.' By the One in whole hand is the soul of Muhammad, the smell that comes from the mouth of a fasting person is better before Allah than the fragrance of musk}}
\hadithdefcmd{nasai}{2235}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مِسْعَرٍ، عَنِ الْوَلِيدِ بْنِ أَبِي مَالِكٍ، قَالَ حَدَّثَنَا أَصْحَابُنَا، عَنْ أَبِي عُبَيْدَةَ، قَالَ الصِّيَامُ جُنَّةٌ مَا لَمْ يَخْرِقْهَا ‏.‏\hadithno{2235}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Walid bin Abi Malik said:"Our companions narrated to us that Abu 'Ubaidah said: 'Fasting is a shield, so long as you do not damage it}}
\hadithdefcmd{nasai}{2236}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لِلصَّائِمِينَ بَابٌ فِي الْجَنَّةِ يُقَالُ لَهُ الرَّيَّانُ لاَ يَدْخُلُ فِيهِ أَحَدٌ غَيْرُهُمْ فَإِذَا دَخَلَ آخِرُهُمْ أُغْلِقَ مَنْ دَخَلَ فِيهِ شَرِبَ وَمَنْ شَرِبَ لَمْ يَظْمَأْ أَبَدًا ‏"‏ ‏.‏\hadithno{2236}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sahi bin Sad that the Prophet said:"For those who fast there is a gate in Paradise called Ar-Rayyan, through which no one but they will enter. When the last of them has entered it, it will be closed. Whoever enters through it will drink, and whoever drinks will never thirst again}}
\hadithdefcmd{nasai}{2237}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَعْقُوبُ، عَنْ أَبِي حَازِمٍ، قَالَ حَدَّثَنِي سَهْلٌ، أَنَّ فِي الْجَنَّةِ، بَابًا يُقَالُ لَهُ الرَّيَّانُ يُقَالُ يَوْمَ الْقِيَامَةِ أَيْنَ الصَّائِمُونَ هَلْ لَكُمْ إِلَى الرَّيَّانِ مَنْ دَخَلَهُ لَمْ يَظْمَأْ أَبَدًا فَإِذَا دَخَلُوا أُغْلِقَ عَلَيْهِمْ فَلَمْ يَدْخُلْ فِيهِ أَحَدٌ غَيْرُهُمْ ‏.‏\hadithno{2237}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Hasan}\hadithtrans{Sahi narrated that:in Paradise there is a gate called Ar'Rayyan, it will be said on the Day of Resurrection: "Where are those who used to fast? Would you like to enter through Ar-Rayyan?" whoever enters through it will never thirst again. Then when they have entered it will be closed behind them, and no one but they will enter through it}}
\hadithdefcmd{nasai}{2238}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي مَالِكٌ، وَيُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ نُودِيَ فِي الْجَنَّةِ يَا عَبْدَ اللَّهِ هَذَا خَيْرٌ فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ يُدْعَى مِنْ بَابِ الصَّلاَةِ وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ يُدْعَى مِنْ بَابِ الْجِهَادِ وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ يُدْعَى مِنْ بَابِ الصَّدَقَةِ وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ بَابِ الرَّيَّانِ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ الصِّدِّيقُ يَا رَسُولَ اللَّهِ مَا عَلَى أَحَدٍ يُدْعَى مِنْ تِلْكَ الأَبْوَابِ مِنْ ضَرُورَةٍ فَهَلْ يُدْعَى أَحَدٌ مِنْ تِلْكَ الأَبْوَابِ كُلِّهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ وَأَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏ ‏.‏\hadithno{2238}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever spends on a pair (of things) in the cause of Allah, the Mighty and Sublime, he will be called in Paradise: 'O slave of Allah, here is prosperity, Whoever is one of the people of Salah, he will be called from the gate of salah. Whoever is on of the people of charity, he will be called from the gate of Ar-Rayyan.' Abu Bakr As-Siddiq said: 'O Messenger of Allah, no distress or need will befall the one who is called from those gates. Will there be anyone who will be called from all these gates?' The Messenger of Allah said: 'Yes, and I hope that you will be one of them}}
\hadithdefcmd{nasai}{2239}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ شَبَابٌ لاَ نَقْدِرُ عَلَى شَىْءٍ قَالَ ‏ "‏ يَا مَعْشَرَ الشَّبَابِ عَلَيْكُمْ بِالْبَاءَةِ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لَمْ يَسْتَطِعْ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{2239}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"We went out with the Messenger of Allah and we were young men who could not afford anything. He said: 'O young men, you should get married, for it is more effective in lowering the gaze and protecting one's chastity. Whoever cannot afford it should fast, for it will be a restraint Wija, for him}}
\hadithdefcmd{nasai}{2240}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، أَنَّ ابْنَ مَسْعُودٍ، لَقِيَ عُثْمَانَ بِعَرَفَاتٍ فَخَلاَ بِهِ فَحَدَّثَهُ وَأَنَّ، عُثْمَانَ قَالَ لاِبْنِ مَسْعُودٍ هَلْ لَكَ فِي فَتَاةٍ أُزَوِّجُكَهَا فَدَعَا عَبْدُ اللَّهِ عَلْقَمَةَ فَحَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لَمْ يَسْتَطِعْ فَلْيَصُمْ فَإِنَّ الصَّوْمَ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{2240}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Alqamah that:Ibn Masud met 'Uthman at 'Arafat and spoke to him in private. Uthman said to Ibn Masud: "Are you interested in a girl so that I marry her to you?" 'Abdullah called 'Alqamah and he told him that the Prophet said: 'Whoever among you can afford to get married, let him do so. Whoever cannot afford it, let him fast, for fasting will be a restraint (Wija) for him}}
\hadithdefcmd{nasai}{2241}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا الْمُحَارِبِيُّ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ وَمَنْ لَمْ يَجِدْ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{2241}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah said: 'Whoever among you can afford to get married, let him do so, and whoever cannot afford it should fast, for it will be a restraint (Wija) for him}}
\hadithdefcmd{nasai}{2242}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ بْنِ هِلاَلٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا عَلِيُّ بْنُ هَاشِمٍ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ دَخَلْنَا عَلَى عَبْدِ اللَّهِ وَمَعَنَا عَلْقَمَةُ وَالأَسْوَدُ وَجَمَاعَةٌ فَحَدَّثَنَا بِحَدِيثٍ مَا رَأَيْتُهُ حَدَّثَ بِهِ الْقَوْمَ إِلاَّ مِنْ أَجْلِي لأَنِّي كُنْتُ أَحْدَثَهُمْ سِنًّا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ ‏"‏ ‏.‏ قَالَ عَلِيٌّ وَسُئِلَ الأَعْمَشُ عَنْ حَدِيثِ إِبْرَاهِيمَ فَقَالَ عَنْ إِبْرَاهِيمَ عَنْ عَلْقَمَةَ عَنْ عَبْدِ اللَّهِ مِثْلَهُ قَالَ نَعَمْ ‏.‏\hadithno{2242}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdur-Rahman bin Yazid said:"We entered upon 'Abdullah along with 'Alqamah, Al-Aswad and a group (of others). He told us a Hadith which he only narrated to the people because of me, as I was the youngest of them. The Messenger of Allah said: 'O young men, whoever among you can afford to get married let him do so, for it is more effective in lowering the gaze and guarding one's chastity."' (One of the narrators) 'Ali said: "Al-Amash was asked about the narrated of Ibrahim, so he (the questioner) said: 'Form Ibrahim, from 'Alqamah, from 'Abdullah; similarly?. Which he (Al-'Amash) replied: 'Yes}}
\hadithdefcmd{nasai}{2243}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا يُونُسُ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ كُنْتُ مَعَ ابْنِ مَسْعُودٍ وَهُوَ عِنْدَ عُثْمَانَ فَقَالَ عُثْمَانُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى فِتْيَةٍ فَقَالَ ‏"‏ مَنْ كَانَ مِنْكُمْ ذَا طَوْلٍ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لاَ فَالصَّوْمُ لَهُ وِجَاءٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَبُو مَعْشَرٍ هَذَا اسْمُهُ زِيَادُ بْنُ كُلَيْبٍ وَهُوَ ثِقَةٌ وَهُوَ صَاحِبُ إِبْرَاهِيمَ رَوَى عَنْهُ مَنْصُورٌ وَمُغِيرَةُ وَشُعْبَةُ وَأَبُو مَعْشَرٍ الْمَدَنِيُّ اسْمُهُ نَجِيحٌ وَهُوَ ضَعِيفٌ وَمَعَ ضَعْفِهِ أَيْضًا كَانَ قَدِ اخْتَلَطَ عِنْدَهُ أَحَادِيثُ مَنَاكِيرُ مِنْهَا مُحَمَّدُ بْنُ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ قِبْلَةٌ ‏"‏ ‏.‏ وَمِنْهَا هِشَامُ بْنُ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ تَقْطَعُوا اللَّحْمَ بِالسِّكِّينِ وَلَكِنِ انْهَسُوا نَهْسًا ‏"‏ ‏.‏\hadithno{2243}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Alqamah said:"I was with Ibn Masud when he was with "uthman, and 'Uthman said: 'Whoever among you has the means, let him get married, for it is more effective in lowering the gaze and guarding one's chastity. And whoever cannot, then fasting will be a shield for him." (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: This (narrator) is Abu Mashar, his name is Ziyad bin Kulaib, and he is trustworthy. He was a companion of Ibrahim. Mansur, Mughirah, and Shubah reported from him. (As for) Abu Mashar AL-Madini; his name is Najih and he is weak, and with his weakness, he also became confused, he narrated Munkar narrations, among them: Muhammad bin 'Amr from Abu Salamah, from Abu Hurairah, from the Prophet, who said: "What is between the east and the west is the Qiblah. And among them: Hisham bin 'Urwah, from his father, from 'Aishah, from the Prophet: "Do not cut meat with the knife, rather gnaw at it}}
\hadithdefcmd{nasai}{2244}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَخْبَرَنِي أَنَسٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ زَحْزَحَ اللَّهُ وَجْهَهُ عَنِ النَّارِ بِذَلِكَ الْيَوْمِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2244}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever fasts one day in the cause of Allah, the Mighty and sublime, Allah will remove his face away from the fire in return for the day (the distance of) seventy autumns}}
\hadithdefcmd{nasai}{2245}{أَخْبَرَنَا دَاوُدُ بْنُ سُلَيْمَانَ بْنِ حَفْصٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ الضَّرِيرُ، عَنْ سُهَيْلٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ بَاعَدَ اللَّهُ بَيْنَهُ وَبَيْنَ النَّارِ بِذَلِكَ الْيَوْمِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2245}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Saeed Al-Khudri said:"The Messenger of Allah said: 'Whoever fasts one day in the cause of Allah, Allah will separate between his face and the fire by (a distance of) seventy autumns in return for that day}}
\hadithdefcmd{nasai}{2246}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنِي سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ بَاعَدَ اللَّهُ عَزَّ وَجَلَّ وَجْهَهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2246}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever fasts one day in the cause of Allah, Allah, the mighty and sublime, will separate his face from the fire by (a distance of)seventy autumns}}
\hadithdefcmd{nasai}{2247}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُهَيْلٍ، عَنْ صَفْوَانَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ بَاعَدَ اللَّهُ وَجْهَهُ مِنْ جَهَنَّمَ سَبْعِينَ عَامًا ‏"‏ ‏.‏\hadithno{2247}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa`eed that the Prophet (ﷺ) said:"Whoever fasts one day in the cause of Allah, the Mighty and Sublime, Allah will separate his face from the fire by (a distance of) seventy years}}
\hadithdefcmd{nasai}{2248}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ سُهَيْلٍ، عَنِ ابْنِ أَبِي عَيَّاشٍ، عَنْ أَبِي سَعِيدٍ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ يَصُومُ يَوْمًا فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ إِلاَّ بَعَّدَ اللَّهُ عَزَّ وَجَلَّ بِذَلِكَ الْيَوْمِ وَجْهَهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2248}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Saeed that he heard the Messenger of Allah say:"There is no worshipper who fasts a day in the cause of Allah, the mighty and sublime, but Allah the mighty and sublime, will separate his face from the fire by (a distance of) seventy autumns in return for that day}}
\hadithdefcmd{nasai}{2249}{أَخْبَرَنَا الْحَسَنُ بْنُ قَزَعَةَ، عَنْ حُمَيْدِ بْنِ الأَسْوَدِ، قَالَ حَدَّثَنَا سُهَيْلٌ، عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ بَاعَدَهُ اللَّهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2249}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that An-Numan bin Abi 'Ayyash said:"I heard Abu Saeed Al-Khudri say: 'The Messenger of Allah said: Whoever fasts one day in the cause of Allah will separate his face from the fire by (a distance of) seventy autumns}}
\hadithdefcmd{nasai}{2250}{أَخْبَرَنَا مُؤَمَّلُ بْنُ إِهَابٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ سَعِيدٍ، وَسُهَيْلُ بْنُ أَبِي صَالِحٍ، سَمِعَا النُّعْمَانَ بْنَ أَبِي عَيَّاشٍ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ تَبَارَكَ وَتَعَالَى بَاعَدَ اللَّهُ وَجْهَهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2250}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Saeed Al-Khudi said:"I heard the Messenger of Allah say: 'Whoever fasts one day in the cause of Allah, Allah will separate his face from the Fire by (a distance of) seventy autumns}}
\hadithdefcmd{nasai}{2251}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، - نَيْسَابُورِيٌّ - قَالَ حَدَّثَنَا يَزِيدُ الْعَدَنِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَصُومُ عَبْدٌ يَوْمًا فِي سَبِيلِ اللَّهِ إِلاَّ بَاعَدَ اللَّهُ تَعَالَى بِذَلِكَ الْيَوْمِ النَّارَ عَنْ وَجْهِهِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2251}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Saeed Al-khudi said:"The Messenger of Allah: 'There is no worshipper who fasts a day in the cause of Allah, but Allah, the most high, will separate (a distance of) seventy autumns between his face and the fire in return for that day}}
\hadithdefcmd{nasai}{2252}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا قَاسِمٌ، عَنْ سُفْيَانَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ بَاعَدَ اللَّهُ بِذَلِكَ الْيَوْمِ حَرَّ جَهَنَّمَ عَنْ وَجْهِهِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2252}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Saeed Al-Khudri that the Prophet said:"Whoever fasts a day in the cause of Allah, Allah will separate his face from the heat of Hell (a distance of) seventy autumns}}
\hadithdefcmd{nasai}{2253}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ مُحَمَّدِ بْنِ حَنْبَلٍ، قَالَ قَرَأْتُ عَلَى أَبِي حَدَّثَكُمُ ابْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سُمَىٍّ، عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ بَاعَدَ اللَّهُ بِذَلِكَ الْيَوْمِ النَّارَ عَنْ وَجْهِهِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2253}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Saeed Al-Khudri said:"The Messenger of Allah said: Whoever fasts a day in the cause of Allah, Allah will separate his face (a distance of) seventy autumns from the fire in return for that day}}
\hadithdefcmd{nasai}{2254}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، عَنْ مُحَمَّدِ بْنِ شُعَيْبٍ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ الْحَارِثِ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّهُ حَدَّثَهُ عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ بَاعَدَ اللَّهُ مِنْهُ جَهَنَّمَ مَسِيرَةَ مِائَةِ عَامٍ ‏"‏ ‏.‏\hadithno{2254}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that the Messenger of Allah said:"Whoever fasts one day in the cause of Allah, the mighty and sublime, Allah will separate him the distance of one hundred years from the fire}}
\hadithdefcmd{nasai}{2255}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ صَفْوَانَ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ كَعْبِ بْنِ عَاصِمٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{2255}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Kab bin 'Asim said:"I heard the Messenger of Allah say; 'It is not righteousness to fast when traveling}}
\hadithdefcmd{nasai}{2256}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ الَّذِي قَبْلَهُ لاَ نَعْلَمُ أَحَدًا تَابَعَ ابْنَ كَثِيرٍ عَلَيْهِ ‏.‏\hadithno{2256}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Saeed bin Al-Musayyab said:"The Messenger of Allah said: 'It is not righteousness to fast when traveling."' (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: This is a mistake, and what is correct is the one that is before it. We do not know of anyone who followed up Ibn Kathir}}
\hadithdefcmd{nasai}{2257}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرٌ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى نَاسًا مُجْتَمِعِينَ عَلَى رَجُلٍ فَسَأَلَ فَقَالُوا رَجُلٌ أَجْهَدَهُ الصَّوْمُ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{2257}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:the Messenger of Allah saw some people gathered around a man, so he asked (what was happening) and they said: "It is a man who is exhausted because of fasting." The Messenger of Allah said: "It is not righteousness to fast when traveling}}
\hadithdefcmd{nasai}{2258}{أَخْبَرَنِي شُعَيْبُ بْنُ شُعَيْبِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِرَجُلٍ فِي ظِلِّ شَجَرَةٍ يُرَشُّ عَلَيْهِ الْمَاءُ قَالَ ‏"‏ مَا بَالُ صَاحِبِكُمْ هَذَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ صَائِمٌ ‏.‏ قَالَ ‏"‏ إِنَّهُ لَيْسَ مِنَ الْبِرِّ أَنْ تَصُومُوا فِي السَّفَرِ وَعَلَيْكُمْ بِرُخْصَةِ اللَّهِ الَّتِي رَخَّصَ لَكُمْ فَاقْبَلُوهَا ‏"‏ ‏.‏\hadithno{2258}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir bin 'Abdullah narrated that:the Messenger of Allah passed by a man in the shade of a tree on whom water was being sprinkled. He said: "What is the matter with your companion?" They said: "O Messenger of Allah, he is fasting." He said: "It is not righteousness to fast when traveling. Take to the concession which Allah has granted you, accept it}}
\hadithdefcmd{nasai}{2259}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْفِرْيَابِيُّ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي مَنْ، سَمِعَ جَابِرًا، نَحْوَهُ ‏.‏\hadithno{2259}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Muhammad bin 'Abdur-Rahman said:"Someone who heard it from Jabir told me something similar}}
\hadithdefcmd{nasai}{2260}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، رضى الله عنهما عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ عَلَيْكُمْ بِرُخْصَةِ اللَّهِ عَزَّ وَجَلَّ فَاقْبَلُوهَا ‏"‏ ‏.‏\hadithno{2260}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah said:"It is not righteousness to fast when traveling. Take to the concession which Allah, the mighty and sublime, has granted you, accept it}}
\hadithdefcmd{nasai}{2261}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عُثْمَانَ بْنِ عُمَرَ، قَالَ أَنْبَأَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ رَجُلٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{2261}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from a man, from Jabir that the Messenger of Allah said:"It is not righteousness to fast when traveling}}
\hadithdefcmd{nasai}{2262}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَخَالِدُ بْنُ الْحَارِثِ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَسَنٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً قَدْ ظُلِّلَ عَلَيْهِ فِي السَّفَرِ فَقَالَ ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{2262}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jabir bin Abdullah that:the Messenger of Allah saw a man who was being shaded on a journey. He said: "It is not righteousness to fast when traveling}}
\hadithdefcmd{nasai}{2263}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى مَكَّةَ عَامَ الْفَتْحِ فِي رَمَضَانَ فَصَامَ حَتَّى بَلَغَ كُرَاعَ الْغَمِيمِ فَصَامَ النَّاسُ فَبَلَغَهُ أَنَّ النَّاسَ قَدْ شَقَّ عَلَيْهِمُ الصِّيَامُ فَدَعَا بِقَدَحٍ مِنَ الْمَاءِ بَعْدَ الْعَصْرِ فَشَرِبَ وَالنَّاسُ يَنْظُرُونَ فَأَفْطَرَ بَعْضُ النَّاسِ وَصَامَ بَعْضٌ فَبَلَغَهُ أَنَّ نَاسًا صَامُوا فَقَالَ ‏ "‏ أُولَئِكَ الْعُصَاةُ ‏"‏ ‏.‏\hadithno{2263}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah went out to Makkah in the year of the Conquest in Ramadan. He fasted until he reached Kura Al-Ghamim, and the people fast, so he called for a vessel of water after 'Asr and drank it while the people were looking on. Then some of the people broke their fast and some continued to fast. He heard that some people were still fasting and he said: 'Those are the disobedient ones}}
\hadithdefcmd{nasai}{2264}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَعَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالاَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ سُفْيَانَ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِطَعَامٍ بِمَرِّ الظَّهْرَانِ فَقَالَ لأَبِي بَكْرٍ وَعُمَرَ ‏"‏ أَدْنِيَا فَكُلاَ ‏"‏ ‏.‏ فَقَالاَ إِنَّا صَائِمَانِ ‏.‏ فَقَالَ ‏"‏ ارْحَلُوا لِصَاحِبَيْكُمُ اعْمَلُوا لِصَاحِبَيْكُمْ ‏"‏ ‏.‏\hadithno{2264}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"Some food was brought to the Messenger of Allah at Marr Az-Zahran, and he said to Abu Bakr and 'Umar: 'Come and eat.' They said: 'We are fasting.' He said: 'Saddle the camels for your companions, and help your companions."'(Daif)}}
\hadithdefcmd{nasai}{2265}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، قَالَ أَخْبَرَنِي الأَوْزَاعِيُّ، عَنْ يَحْيَى، أَنَّهُ حَدَّثَهُ عَنْ أَبِي سَلَمَةَ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَغَدَّى بِمَرِّ الظَّهْرَانِ وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ فَقَالَ ‏ "‏ الْغَدَاءَ ‏"‏ ‏.‏ مُرْسَلٌ ‏.‏\hadithno{2265}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Salamah said:"When the Messenger of Allah was eating breakfast in Marr Az-Zahran, and Abu Bakr and 'Umar were with him, he said: '(Come and eat) breakfast." (Daif) He narrated it in Mursal form}}
\hadithdefcmd{nasai}{2266}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا عَلِيٌّ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ كَانُوا بِمَرِّ الظَّهْرَانِ مُرْسَلٌ ‏.‏\hadithno{2266}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Salamah:That the Messenger of Allah , Abu Bakr and 'Umar were in Marr Az-Zahran. He narrated it in Mursal from. (Daif)}}
\hadithdefcmd{nasai}{2267}{أَخْبَرَنِي عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، عَنْ مُحَمَّدِ بْنِ شُعَيْبٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ أُمَيَّةَ الضَّمْرِيُّ، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ سَفَرٍ فَقَالَ ‏"‏ انْتَظِرِ الْغَدَاءَ يَا أَبَا أُمَيَّةَ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ ‏"‏ تَعَالَ ادْنُ مِنِّي حَتَّى أُخْبِرَكَ عَنِ الْمُسَافِرِ إِنَّ اللَّهَ عَزَّ وَجَلَّ وَضَعَ عَنْهُ الصِّيَامَ وَنِصْفَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2267}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Amr bin Umayyah Ad-Damri said:"I came to the Messenger of Allah from a journey and he said: 'Stay and have a meal to break the fast, O Abu Umayyah.' I said: 'I am fasting.' He said: 'Come close to me and I will tell you about the traveler. Allah, the mighty and sublime, has waived fasting and half of the prayer for him}}
\hadithdefcmd{nasai}{2268}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ عَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيُّ، عَنْ أَبِيهِ، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ تَنْتَظِرُ الْغَدَاءَ يَا أَبَا أُمَيَّةَ ‏"‏ ‏.‏ قُلْتُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ ‏"‏ تَعَالَ أُخْبِرْكَ عَنِ الْمُسَافِرِ إِنَّ اللَّهَ وَضَعَ عَنْهُ الصِّيَامَ وَنِصْفَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2268}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Jafar bin 'Amr bin Umayyah Ad-Damri narrated that his father said:"I came to the Messenger of Allah and the Messenger of Allah said to me: 'Stay and have a meal for breakfast, O Abu Umayyah.' I said: I am fasting.' He said: 'Come and I will tell you about the traveler. Allah has waived meaning the fasting and half the prayer for him}}
\hadithdefcmd{nasai}{2269}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا أَبُو الْمُغِيرَةِ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَاجِرِ، عَنْ أَبِي أُمَيَّةَ الضَّمْرِيِّ، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ سَفَرٍ فَسَلَّمْتُ عَلَيْهِ فَلَمَّا ذَهَبْتُ لأَخْرُجَ قَالَ ‏"‏ انْتَظِرِ الْغَدَاءَ يَا أَبَا أُمَيَّةَ ‏"‏ ‏.‏ قُلْتُ إِنِّي صَائِمٌ يَا نَبِيَّ اللَّهِ ‏.‏ قَالَ ‏"‏ تَعَالَ أُخْبِرْكَ عَنِ الْمُسَافِرِ إِنَّ اللَّهَ تَعَالَى وَضَعَ عَنْهُ الصِّيَامَ وَنِصْفَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2269}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Umayyah Ad-Damri said:"I came to the Messenger of Allah from a journey and greeted him with Salam. When I was going to leave he said: 'Stay and have meal for breakfast, O Abu Umayyah.' I said: 'I am fasting, O Prophet of Allah.' He said: 'Come and I will tell about the traveler. Allah, most high, has waived fasting and of the prayer for him}}
\hadithdefcmd{nasai}{2270}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُوسَى بْنُ مَرْوَانَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الأَوْزَاعِيِّ، قَالَ أَخْبَرَنِي يَحْيَى، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ، قَالَ حَدَّثَنِي أَبُو الْمُهَاجِرِ، قَالَ حَدَّثَنِي أَبُو أُمَيَّةَ يَعْنِي الضَّمْرِيَّ، أَنَّهُ قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2270}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Abu Umayyah Ad-Damri narrated:That he came to Prophet, and he mentioned something similar}}
\hadithdefcmd{nasai}{2271}{أَخْبَرَنِي شُعَيْبُ بْنُ شُعَيْبِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ حَدَّثَنِي الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ الْجَرْمِيُّ، أَنَّ أَبَا أُمَيَّةَ الضَّمْرِيَّ، حَدَّثَهُمْ أَنَّهُ، قَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ سَفَرٍ فَقَالَ ‏"‏ انْتَظِرِ الْغَدَاءَ يَا أَبَا أُمَيَّةَ ‏"‏ ‏.‏ قُلْتُ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ ادْنُ أُخْبِرْكَ عَنِ الْمُسَافِرِ إِنَّ اللَّهَ وَضَعَ عَنْهُ الصِّيَامَ وَنِصْفَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2271}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Qilabah AL-Jarmi narrated that Abu Umayyah Ad-Damri told them that:he came to the Messenger of Allah from a journey and he said: "Come and have a meal for breakfast, O Abu Umayyah." I said: 'I am fasting; He said: 'Come close and I will tell you about the traveler. Allah, most high, has waived fasting and half of the prayer for him}}
\hadithdefcmd{nasai}{2272}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ بْنِ يَزِيدَ بْنِ إِبْرَاهِيمَ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا عُثْمَانُ، قَالَ حَدَّثَنَا مُعَاوِيَةُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، أَنَّ أَبَا أُمَيَّةَ الضَّمْرِيَّ، أَخْبَرَهُ أَنَّهُ، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ سَفَرٍ وَهُوَ صَائِمٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ تَنْتَظِرِ الْغَدَاءَ ‏"‏ ‏.‏ قَالَ إِنِّي صَائِمٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَعَالَ أُخْبِرْكَ عَنِ الصِّيَامِ إِنَّ اللَّهَ عَزَّ وَجَلَّ وَضَعَ عَنِ الْمُسَافِرِ الصِّيَامَ وَنِصْفَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2272}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Qilabah that Abu Umayyah Ad-Damri told him that:he came to the Messenger of Allah from a journey and he was fasting. The Messenger of Allah said to him, "Won't you come and have meal for the breakfast?" He said: "I am fasting." The Messenger of Allah said: "Come and I will tell you about fasting. Allah, the mighty and sublime, has waived fasting and half of the prayer from the traveler}}
\hadithdefcmd{nasai}{2273}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ أَنْبَأَنَا عَلِيٌّ، عَنْ يَحْيَى، عَنْ أَبِي قِلاَبَةَ، عَنْ رَجُلٍ، أَنَّ أَبَا أُمَيَّةَ، أَخْبَرَهُ أَنَّهُ، أَتَى النَّبِيَّ صلى الله عليه وسلم مِنْ سَفَرٍ نَحْوَهُ ‏.‏\hadithno{2273}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Oilabah, from a man, that Abu Umayyah told him:That he came to the Prophet from a journey, and he narrated something similar}}
\hadithdefcmd{nasai}{2274}{أَخْبَرَنَا عُمَرُ بْنُ مُحَمَّدِ بْنِ الْحَسَنِ بْنِ التَّلِّ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ وَضَعَ عَنِ الْمُسَافِرِ نِصْفَ الصَّلاَةِ وَالصَّوْمَ وَعَنِ الْحُبْلَى وَالْمُرْضِعِ ‏"‏ ‏.‏\hadithno{2274}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that the Prophet said:"Allah has waived meaning half of the prayer and fasting for the traveler, and from pregnant women and the sick. "(Hanas)}}
\hadithdefcmd{nasai}{2275}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ شَيْخٍ، مِنْ قُشَيْرٍ عَنْ عَمِّهِ، حَدَّثَنَا ثُمَّ، أَلْفَيْنَاهُ فِي إِبِلٍ لَهُ فَقَالَ لَهُ أَبُو قِلاَبَةَ حَدِّثْهُ فَقَالَ الشَّيْخُ حَدَّثَنِي عَمِّي أَنَّهُ ذَهَبَ فِي إِبِلٍ لَهُ فَانْتَهَى إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَأْكُلُ أَوْ قَالَ يَطْعَمُ فَقَالَ ‏"‏ ادْنُ فَكُلْ أَوْ قَالَ ‏"‏ ادْنُ فَاطْعَمْ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ وَضَعَ عَنِ الْمُسَافِرِ شَطْرَ الصَّلاَةِ وَالصِّيَامَ وَعَنِ الْحَامِلِ وَالْمُرْضِعِ ‏"‏ ‏.‏\hadithno{2275}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ayyub, from a Shailh of Qushair, from his paternal uncle; then we met him concerning some camels of his, and Bu Qilabah said to him:"Tell it to us." The old man said: "My paternal uncle told me that he went to the Prophet, concerning some camels of his, while he was eating. He said: 'Come and eat.' I said: 'I am fasting.' He said: 'Allah, the mighty and sublime, has waived half of the prayer and fasting for the traveler, the pregnant woman and the sick}}
\hadithdefcmd{nasai}{2276}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا سُرَيْجٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ، هَذَا الْحَدِيثَ ثُمَّ قَالَ هَلْ لَكَ فِي صَاحِبِ الْحَدِيثِ فَدَلَّنِي عَلَيْهِ فَلَقِيتُهُ فَقَالَ حَدَّثَنِي قَرِيبٌ لِي يُقَالُ لَهُ أَنَسُ بْنُ مَالِكٍ قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي إِبِلٍ كَانَتْ لِي أُخِذَتْ فَوَافَقْتُهُ وَهُوَ يَأْكُلُ فَدَعَانِي إِلَى طَعَامِهِ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ ‏ "‏ ادْنُ أُخْبِرْكَ عَنْ ذَلِكَ إِنَّ اللَّهَ وَضَعَ عَنِ الْمُسَافِرِ الصَّوْمَ وَشَطْرَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2276}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ayyub said:"Abu Qilabah narrated this Hadith to us, then he said: 'Do you want to meet the one who narrated this Hadith?' He directed me to him and I met him and he said: 'A relative of mine who was called to the Messenger of Allah concerning some camels of mine that had been taken away. When I saw him he was eating, and he called me to eat with him, but I said: 'I saw him he was eating, and he called me to eat with him, but I said: I am fasting.' He said: 'Come close and I will tell you but that. Allah has waived fasting and half of the prayer for the traveler}}
\hadithdefcmd{nasai}{2277}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ رَجُلٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم لِحَاجَةٍ فَإِذَا هُوَ يَتَغَدَّى قَالَ ‏"‏ هَلُمَّ إِلَى الْغَدَاءِ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ هَلُمَّ أُخْبِرْكَ عَنِ الصَّوْمِ إِنَّ اللَّهَ وَضَعَ عَنِ الْمُسَافِرِ نِصْفَ الصَّلاَةِ وَالصَّوْمَ وَرَخَّصَ لِلْحُبْلَى وَالْمُرْضِعِ ‏"‏ ‏.‏\hadithno{2277}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Qilabah that a man said:"I came to the Prophet to discuss something and he was eating breakfast. He said: 'Come and eat.' I said: 'I am fasting.' He said: 'Come and I will tell you about fasting. Allah has waived half of prayer and fasting from the traveler, and he has granted a concession to pregnant women and the sick}}
\hadithdefcmd{nasai}{2278}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي الْعَلاَءِ بْنِ الشِّخِّيرِ، عَنْ رَجُلٍ، نَحْوَهُ ‏.‏\hadithno{2278}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated from Abu Al-Ala bin Ash-Shikhkhir:A similar report was narrated from Abu Al-Ala bin Ash-Shikhkhir, from a man}}
\hadithdefcmd{nasai}{2279}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ هَانِئِ بْنِ الشِّخِّيرِ، عَنْ رَجُلٍ، مِنْ بَلْحَرِيشٍ عَنْ أَبِيهِ، قَالَ كُنْتُ مُسَافِرًا فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَأَنَا صَائِمٌ وَهُوَ يَأْكُلُ قَالَ ‏"‏ هَلُمَّ ‏"‏ ‏.‏ قُلْتُ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ تَعَالَ أَلَمْ تَعْلَمْ مَا وَضَعَ اللَّهُ عَنِ الْمُسَافِرِ ‏"‏ ‏.‏ قُلْتُ وَمَا وَضَعَ عَنِ الْمُسَافِرِ قَالَ ‏"‏ الصَّوْمَ وَنِصْفَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2279}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hani bin Ash-Shikhkhir, from a man from Balharish, that his father said:"I was traveling and I came to the Prophet when I was fasting, and he was eating. He said:'Come (and eat).' I said: 'I am fasting.' He said: 'Come here; do you not know what Allah has waived for the traveler?' I said: 'What has Allah waived for the traveler?' He said: 'Fasting and half of the prayer}}
\hadithdefcmd{nasai}{2280}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ هَانِئِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ رَجُلٍ، مِنْ بَلْحَرِيشٍ عَنْ أَبِيهِ، قَالَ كُنَّا نُسَافِرُ مَا شَاءَ اللَّهُ فَأَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَطْعَمُ فَقَالَ ‏"‏ هَلُمَّ فَاطْعَمْ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أُحَدِّثُكُمْ عَنِ الصِّيَامِ إِنَّ اللَّهَ وَضَعَ عَنِ الْمُسَافِرِ الصَّوْمَ وَشَطْرَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2280}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hani bin 'Abdullah bin Ash-Shikhkhir from Balharish, from a man from Balharish, that his father said:"we had been travelijng for as long as Allah willed, then we came to the Messenger of Allah and he was eating. He said: 'Come and eat.' I said: 'I am fasting.' The Messenger of Allah said: 'I will tell you about fasting. Allah has waived fasting and half of the prayer for the traveler}}
\hadithdefcmd{nasai}{2281}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْكَرِيمِ، قَالَ حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ هَانِئِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ أَبِيهِ، قَالَ كُنْتُ مُسَافِرًا فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يَأْكُلُ وَأَنَا صَائِمٌ فَقَالَ ‏"‏ هَلُمَّ ‏"‏ ‏.‏ قُلْتُ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ أَتَدْرِي مَا وَضَعَ اللَّهُ عَنِ الْمُسَافِرِ ‏"‏ ‏.‏ قُلْتُ وَمَا وَضَعَ اللَّهُ عَنِ الْمُسَافِرِ قَالَ ‏"‏ الصَّوْمَ وَشَطْرَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2281}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hani bin 'Abdullah bin Shikhkhir that his father said:"I was traveling and I came to the Prophet when he was eating and I was fasting. He said: 'Come and eat.' I said: 'I am fasting.' He said: 'Do you know what Allah has waived for the traveler?' he said: 'Do you know what Allah has waived for the traveler?' I said: 'What has Allah waived for the traveler?' He said: 'Fasting and half of the prayer}}
\hadithdefcmd{nasai}{2282}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ أَنْبَأَنَا إِسْرَائِيلُ، عَنْ مُوسَى، - هُوَ ابْنُ أَبِي عَائِشَةَ - عَنْ غَيْلاَنَ، قَالَ خَرَجْتُ مَعَ أَبِي قِلاَبَةَ فِي سَفَرٍ فَقَرَّبَ طَعَامًا فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ فِي سَفَرٍ فَقَرَّبَ طَعَامًا فَقَالَ لِرَجُلٍ ‏"‏ ادْنُ فَاطْعَمْ ‏"‏ ‏.‏ قَالَ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ وَضَعَ عَنِ الْمُسَافِرِ نِصْفَ الصَّلاَةِ وَالصِّيَامَ فِي السَّفَرِ ‏"‏ ‏.‏ فَادْنُ فَاطْعَمْ فَدَنَوْتُ فَطَعِمْتُ ‏.‏\hadithno{2282}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ghalian said:"I went out with Abu Qilabah on a journey and he brought some food. I said: 'I am fasting.' He said: 'The Messenger of Allah went out on a journey and brought some food, and said to a man: Come and eat. He said: I am fasting. He said: Allah has waived for the traveler half of the prayer and fasting when traveling, so come and eat. So I came close and ate}}
\hadithdefcmd{nasai}{2283}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ مُوَرِّقٍ الْعِجْلِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ فَمِنَّا الصَّائِمُ وَمِنَّا الْمُفْطِرُ فَنَزَلْنَا فِي يَوْمٍ حَارٍّ وَاتَّخَذْنَا ظِلاَلاً فَسَقَطَ الصُّوَّامُ وَقَامَ الْمُفْطِرُونَ فَسَقَوُا الرِّكَابَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ذَهَبَ الْمُفْطِرُونَ الْيَوْمَ بِالأَجْرِ ‏"‏ ‏.‏\hadithno{2283}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"We were with the Messenger of Allah on a journey, and some of us were fasting and some of us were not. We made a stop on a hot day and looked for shade. Those who were fasting fell to the ground, but those who were not fasting got up and watered the animals. The Messenger of Allah said: 'Those who were not fasting today have taken the reward}}
\hadithdefcmd{nasai}{2284}{أَخْبَرَنَا مُحَمَّدُ بْنُ أَبَانَ الْبَلْخِيُّ، قَالَ حَدَّثَنَا مَعْنٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ يُقَالُ الصِّيَامُ فِي السَّفَرِ كَالإِفْطَارِ فِي الْحَضَرِ ‏.‏\hadithno{2284}\hadithgrade{Abu Ghuddah: Daif Muquf; Al-Albani: Daif Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdur-Rahman bin 'Awf said:"It is said that fasting while traveling is like not fasting while a resident." (Daif)}}
\hadithdefcmd{nasai}{2285}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ الْخَيَّاطِ، وَأَبُو عَامِرٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ الصَّائِمُ فِي السَّفَرِ كَالْمُفْطِرِ فِي الْحَضَرِ ‏.‏\hadithno{2285}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdur-Rahman bin 'Awf said:"The one who fasts while traveling is like one who does not fast while a resident." (Daif)}}
\hadithdefcmd{nasai}{2286}{أَخْبَرَنِي مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِيهِ، قَالَ الصَّائِمُ فِي السَّفَرِ كَالْمُفْطِرِ فِي الْحَضَرِ ‏.‏\hadithno{2286}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Humaid bin 'Abdur-Rahman bin 'Awf that his father said:"The one who fasts while traveling is like one who does not fast while a resident.' (Daif)}}
\hadithdefcmd{nasai}{2287}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا سُوَيْدٌ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ فِي رَمَضَانَ فَصَامَ حَتَّى أَتَى قُدَيْدًا ثُمَّ أُتِيَ بِقَدَحٍ مِنْ لَبَنٍ فَشَرِبَ وَأَفْطَرَ هُوَ وَأَصْحَابُهُ ‏.‏\hadithno{2287}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that:the Prophet went out in Ramadan and fasted until he came to Qudaid, then a cup of milk was brought to him and he drank and broke his fast; he and his Companions}}
\hadithdefcmd{nasai}{2288}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا عَبْثَرٌ، عَنِ الْعَلاَءِ بْنِ الْمُسَيَّبِ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ حَتَّى أَتَى قُدَيْدًا ثُمَّ أَفْطَرَ حَتَّى أَتَى مَكَّةَ ‏.‏\hadithno{2288}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah fasted from Al-Madinah until he came to Qudaid, then he broke his fast until he reached Makkah}}
\hadithdefcmd{nasai}{2289}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ أَنْبَأَنَا الْحَسَنُ بْنُ عِيسَى، قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَامَ فِي السَّفَرِ حَتَّى أَتَى قُدَيْدًا ثُمَّ دَعَا بِقَدَحٍ مِنْ لَبَنٍ فَشَرِبَ فَأَفْطَرَ هُوَ وَأَصْحَابُهُ ‏.‏\hadithno{2289}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:the Messenger of Allah fasted while traveling until he reached Qudaid, then he called for a cup of milk and drank and broke his fast; he and his Companions}}
\hadithdefcmd{nasai}{2290}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى مَكَّةَ فَصَامَ حَتَّى أَتَى عُسْفَانَ فَدَعَا بِقَدَحٍ فَشَرِبَ - قَالَ شُعْبَةُ - فِي رَمَضَانَ فَكَانَ ابْنُ عَبَّاسٍ يَقُولُ مَنْ شَاءَ صَامَ وَمَنْ شَاءَ أَفْطَرَ ‏.‏\hadithno{2290}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah went out to Makkah, and he fasted until he came to 'Usfan. Then he called for a cup and drank." (One of the narrators) Shubah said: "(That was) in Ramadan. Ibn 'Abbas used to say: 'Whoever wants to fast, may fast, and whoever wants to break may break his fast}}
\hadithdefcmd{nasai}{2291}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَافَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَصَامَ حَتَّى بَلَغَ عُسْفَانَ ثُمَّ دَعَا بِإِنَاءٍ فَشَرِبَ نَهَارًا يَرَاهُ النَّاسُ ثُمَّ أَفْطَرَ ‏.‏\hadithno{2291}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah traveled during Ramadan and fasted until he reached 'Usfan. Then he called for a vessel and drank during the day when the prople could see him, then he did not fast}}
\hadithdefcmd{nasai}{2292}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الْعَوَّامِ بْنِ حَوْشَبٍ، قَالَ قُلْتُ لِمُجَاهِدٍ الصَّوْمُ فِي السَّفَرِ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ وَيُفْطِرُ ‏.‏\hadithno{2292}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-'Awwam bin Hawshab said:"I said to Mujahid: 'What about fasting while traveling?' He said: 'The Messenger of Allah used to fast (sometimes) and not fast (sometimes)}}
\hadithdefcmd{nasai}{2293}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا حُسَيْنٌ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ أَخْبَرَنِي مُجَاهِدٌ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَامَ فِي شَهْرِ رَمَضَانَ وَأَفْطَرَ فِي السَّفَرِ ‏.‏\hadithno{2293}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Mujahid narrated:That the Messenger of Allah fasted during Ramadan and broke his fast when traveling}}
\hadithdefcmd{nasai}{2294}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا أَزْهَرُ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ حَمْزَةَ بْنِ عَمْرٍو الأَسْلَمِيِّ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّوْمِ فِي السَّفَرِ قَالَ ‏ "‏ إِنْ - ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا إِنْ - شِئْتَ صُمْتَ وَإِنْ شِئْتَ أَفْطَرْتَ ‏"‏ ‏.‏\hadithno{2294}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hamza bin 'Amr Al-Aslami that:he asked the Messenger of Allah about fasting while traveling. He said: "If," then he said something to the effect that: "If you want, then fast, and if you want, then do not fast}}
\hadithdefcmd{nasai}{2295}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ حَمْزَةَ بْنَ عَمْرٍو، قَالَ يَا رَسُولَ اللَّهِ مِثْلَهُ مُرْسَلٌ ‏.‏\hadithno{2295}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sulaiman bin Yasar that Hamzah bin 'Amr said:"O Messenger of Allah." (And he narrated) something similar, in Mursal from}}
\hadithdefcmd{nasai}{2296}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ حَمْزَةَ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّوْمِ فِي السَّفَرِ قَالَ ‏ "‏ إِنْ شِئْتَ أَنْ تَصُومَ فَصُمْ وَإِنْ شِئْتَ أَنْ تُفْطِرَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2296}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hamzah said:"I asked the Messenger of Allah about fasting while traveling. He said: 'If you wish to fast then fast, and if you wish not to fast then do not fast}}
\hadithdefcmd{nasai}{2297}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو بَكْرٍ، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ حَمْزَةَ بْنِ عَمْرٍو، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّوْمِ فِي السَّفَرِ فَقَالَ ‏ "‏ إِنْ شِئْتَ أَنْ تَصُومَ فَصُمْ وَإِنْ شِئْتَ أَنْ تُفْطِرَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2297}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hamzah bin 'Amr said:"I asked the Messenger of Allah about fasting while traveling. He said: 'If you wish to fast then fast, and if you wish not to fast then do not fast}}
\hadithdefcmd{nasai}{2298}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، وَاللَّيْثُ، وَذَكَرَ، آخَرَ عَنْ بُكَيْرٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ حَمْزَةَ بْنِ عَمْرٍو الأَسْلَمِيِّ، قَالَ يَا رَسُولَ اللَّهِ إِنِّي أَجِدُ قُوَّةً عَلَى الصِّيَامِ فِي السَّفَرِ قَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2298}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hamzah bin 'Amr Al-Aslami said:"O Messenger of Allah, I feel able to fast while traveling." He said: "If you wish then fast and if you wish then do not fast}}
\hadithdefcmd{nasai}{2299}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، قَالَ أَنْبَأَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي عِمْرَانُ بْنُ أَبِي أَنَسٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَمْزَةَ بْنِ عَمْرٍو، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّوْمِ فِي السَّفَرِ قَالَ ‏ "‏ إِنْ شِئْتَ أَنْ تَصُومَ فَصُمْ وَإِنْ شِئْتَ أَنْ تُفْطِرَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2299}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hamzah bin 'Amr that:he asked the Messenger of Allah about fasting while traveling. He said: "If you wish to fast then fast, and if you wish not to fast then do not fast}}
\hadithdefcmd{nasai}{2300}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، وَحَنْظَلَةَ بْنِ عَلِيٍّ، قَالَ حَدَّثَانِي جَمِيعًا، عَنْ حَمْزَةَ بْنِ عَمْرٍو، قَالَ كُنْتُ أَسْرُدُ الصِّيَامَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَسْرُدُ الصِّيَامَ فِي السَّفَرِ فَقَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2300}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hamzah bin 'Amr said:"I used to fast continually at the time of the Messenger of Allah. I said: 'O continually while traveling.' He said: 'If you wish then fast, and if you wish then do not fast}}
\hadithdefcmd{nasai}{2301}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ حَنْظَلَةَ بْنِ عَلِيٍّ، عَنْ حَمْزَةَ، قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ إِنِّي رَجُلٌ أَسْرُدُ الصِّيَامَ أَفَأَصُومُ فِي السَّفَرِ قَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2301}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hamzah said:"I said: 'O Prophet of Allah, I am a man who fasts continually, so should I fast while traveling?' He said: 'If you wish then fast, and if you wish then do not fast}}
\hadithdefcmd{nasai}{2302}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي عِمْرَانُ بْنُ أَبِي أَنَسٍ، أَنَّ سُلَيْمَانَ بْنَ يَسَارٍ، حَدَّثَهُ أَنَّ أَبَا مُرَاوِحٍ حَدَّثَهُ أَنَّ حَمْزَةَ بْنَ عَمْرٍو حَدَّثَهُ أَنَّهُ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَكَانَ رَجُلاً يَصُومُ فِي السَّفَرِ فَقَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2302}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hamzah bin 'Amr narrated that he asked the Messenger of Allah, and he wsa a man who used to fast while traveling. He said:"If you wish then fast, and if you wish then fast, and if you wish then do not fast}}
\hadithdefcmd{nasai}{2303}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا عَمْرٌو، وَذَكَرَ، آخَرَ عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ أَبِي مُرَاوِحٍ، عَنْ حَمْزَةَ بْنِ عَمْرٍو، أَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَجِدُ فِيَّ قُوَّةً عَلَى الصِّيَامِ فِي السَّفَرِ فَهَلْ عَلَىَّ جُنَاحٌ قَالَ ‏ "‏ هِيَ رُخْصَةٌ مِنَ اللَّهِ عَزَّ وَجَلَّ فَمَنْ أَخَذَ بِهَا فَحَسَنٌ وَمَنْ أَحَبَّ أَنْ يَصُومَ فَلاَ جُنَاحَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2303}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hamzah bin 'Amr that he said to the Messenger of Allah:"I feel able to fast while traveling; is there any sin on me?" He said: "It is a concession from Allah, the mighty and sublime, so whoever accepts it has done well, and whoever wants to fast, there is no sin on him}}
\hadithdefcmd{nasai}{2304}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ بِشْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ حَمْزَةَ بْنِ عَمْرٍو الأَسْلَمِيِّ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَصُومُ فِي السَّفَرِ قَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2304}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hamzah bin 'Amr Al-Aslami that he asked the Messenger of Allah:"Should I fast while traveling?" He said: "If you wish then fast, and if you wish then do not fast}}
\hadithdefcmd{nasai}{2305}{أَخْبَرَنَا عَلِيُّ بْنُ الْحَسَنِ اللاَّنِيُّ، بِالْكُوفَةِ قَالَ حَدَّثَنَا عَبْدُ الرَّحِيمِ الرَّازِيُّ، عَنْ هِشَامٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنْ حَمْزَةَ بْنِ عَمْرٍو، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ أَصُومُ أَفَأَصُومُ فِي السَّفَرِ قَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2305}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that Hamzah bin 'Amr said:O Messenger of Allah, I am a man who fasts, so should I fast while traveling? He said: "If you wish then fast, and if you wish then do not fast}}
\hadithdefcmd{nasai}{2306}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ حَمْزَةَ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ أَصُومُ فِي السَّفَرِ وَكَانَ كَثِيرَ الصِّيَامِ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2306}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"Hamzah said to the Messenger of Allah: 'O Messenger of Allah, should I fast while traveling?' He used to fast a great deal. The Messenger of Allah said to him: "If you wish then fast and if you wish then do not fast}}
\hadithdefcmd{nasai}{2307}{أَخْبَرَنِي عَمْرُو بْنُ هِشَامٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ حَمْزَةَ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَصُومُ فِي السَّفَرِ فَقَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2307}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"Hamzah asked the Messenger of Allah: 'O Messenger of Allah, should I fast while then fast and if you wish then do not fast}}
\hadithdefcmd{nasai}{2308}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ حَمْزَةَ الأَسْلَمِيَّ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّوْمِ فِي السَّفَرِ وَكَانَ رَجُلاً يَسْرُدُ الصِّيَامَ ‏.‏ فَقَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2308}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Aishah that Hamzah Al-Aslami asked the Messenger of Allah about fasting while traveling as he was a man who used to fast continually. He said:"If you wish then fast and if you wish then do not fast}}
\hadithdefcmd{nasai}{2309}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، قَالَ حَدَّثَنَا أَبُو سَعِيدٍ، قَالَ كُنَّا نُسَافِرُ فِي رَمَضَانَ فَمِنَّا الصَّائِمُ وَمِنَّا الْمُفْطِرُ لاَ يَعِيبُ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ يَعِيبُ الْمُفْطِرُ عَلَى الصَّائِمِ ‏.‏\hadithno{2309}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Saeed said:"We were traveling in Ramadan and among us were some who were fasting and some who were not. Those who were fasting did not criticize those who were not, and those who were not fasting did not criticize those who were}}
\hadithdefcmd{nasai}{2310}{أَخْبَرَنَا سَعِيدُ بْنُ يَعْقُوبَ الطَّالْقَانِيُّ، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ - عَنْ أَبِي مَسْلَمَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ كُنَّا نُسَافِرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمِنَّا الصَّائِمُ وَمِنَّا الْمُفْطِرُ وَلاَ يَعِيبُ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ يَعِيبُ الْمُفْطِرُ عَلَى الصَّائِمِ ‏.‏\hadithno{2310}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Saeed said:"We were traveling with the Prophet and among us were some who were fasting and some who were not criticize those who were not, and those who were not fasting did not criticize those who were}}
\hadithdefcmd{nasai}{2311}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا الْقَوَارِيرِيُّ، قَالَ حَدَّثَنَا بِشْرُ بْنُ مَنْصُورٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي نَضْرَةَ، عَنْ جَابِرٍ، قَالَ سَافَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَامَ بَعْضُنَا وَأَفْطَرَ بَعْضُنَا ‏.‏\hadithno{2311}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"We traveled with the Messenger of Allah and some of us fasted and some of us did not}}
\hadithdefcmd{nasai}{2312}{أَخْبَرَنِي أَيُّوبُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَرْوَانُ، قَالَ حَدَّثَنَا عَاصِمٌ، عَنْ أَبِي نَضْرَةَ الْمُنْذِرِ، عَنْ أَبِي سَعِيدٍ، وَجَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُمَا سَافَرَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَصُومُ الصَّائِمُ وَيُفْطِرُ الْمُفْطِرُ وَلاَ يَعِيبُ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ الْمُفْطِرُ عَلَى الصَّائِمِ ‏.‏\hadithno{2312}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Saeed and Jabir bin 'Abdullah:That they traveled with the Messenger of Allah. Some fasted and some did not, and those who were fasting did not criticize those who were not, and those who were not fasting did not criticize those who were}}
\hadithdefcmd{nasai}{2313}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ صَائِمًا فِي رَمَضَانَ حَتَّى إِذَا كَانَ بِالْكَدِيدِ أَفْطَرَ ‏.‏\hadithno{2313}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger Allah went out in the year of the Conquest, fasting during Ramadan. Then when he was in Al-Kadid, he broke his fast}}
\hadithdefcmd{nasai}{2314}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا مُفَضَّلٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَافَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَامَ حَتَّى بَلَغَ عُسْفَانَ ثُمَّ دَعَا بِإِنَاءٍ فَشَرِبَ نَهَارًا لِيَرَاهُ النَّاسُ ثُمَّ أَفْطَرَ حَتَّى دَخَلَ مَكَّةَ فَافْتَتَحَ مَكَّةَ فِي رَمَضَانَ قَالَ ابْنُ عَبَّاسٍ فَصَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ وَأَفْطَرَ فَمَنْ شَاءَ صَامَ وَمَنْ شَاءَ أَفْطَرَ ‏.‏\hadithno{2314}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah traveled and fasted until he reached 'Usfan, then he called for a cup and drank durink the day when the people could see him. Hen he did not fast until he reached Makkah, and he conquered Makkah during Ramadan." Ibn 'Abbas said: "And the Messenger of Allah fasted until he reach Makkah, and he conquered Makkah during Ramadan." Ibn 'Abbas said: "And the Messenger of Allah fasted and broke his fast while traveling, so whoever wishes may fast, and whoever wishes may not fast}}
\hadithdefcmd{nasai}{2315}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، عَنْ وُهَيْبِ بْنِ خَالِدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَوَادَةَ الْقُشَيْرِيُّ، عَنْ أَبِيهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، رَجُلٌ مِنْهُمْ أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم بِالْمَدِينَةِ وَهُوَ يَتَغَدَّى فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلُمَّ إِلَى الْغَدَاءِ ‏"‏ ‏.‏ فَقَالَ إِنِّي صَائِمٌ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ وَضَعَ لِلْمُسَافِرِ الصَّوْمَ وَشَطْرَ الصَّلاَةِ وَعَنِ الْحُبْلَى وَالْمُرْضِعِ ‏"‏ ‏.‏\hadithno{2315}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Anas bin Malik that:he came to Prophet in Al-Madinah when he was eating breakfast. The Prophet said to him: "Come and eat the breakfast." He said: "I am fasting." The Prophet said to him: "Allah, the mighty and sublime, has waived fasting and half of the prayer for the traveler and for pregnant and breastfeeding women}}
\hadithdefcmd{nasai}{2316}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ أَنْبَأَنَا بَكْرٌ، - وَهُوَ ابْنُ مُضَرَ - عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرٍ، عَنْ يَزِيدَ، مَوْلَى سَلَمَةَ بْنِ الأَكْوَعِ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَعَلَى الَّذِينَ يُطِيقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ ‏\}‏ كَانَ مَنْ أَرَادَ مِنَّا أَنْ يُفْطِرَ وَيَفْتَدِيَ حَتَّى نَزَلَتِ الآيَةُ الَّتِي بَعْدَهَا فَنَسَخَتْهَا ‏.‏\hadithno{2316}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that salamah bin Al-Akwa said:"When this verse was revealed 'And as for those who can fast with difficulty, (e.g. an old man), they have (a choice either to fast or) to feed a miskin (poor person) (for every day). Those among us who did not want to fast would pay the fidyah, until the verse after it was revealed and abrogated this}}
\hadithdefcmd{nasai}{2317}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا وَرْقَاءُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَعَلَى الَّذِينَ يُطِيقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ ‏\}‏ يُطِيقُونَهُ يُكَلَّفُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ وَاحِدٍ ‏\{‏ فَمَنْ تَطَوَّعَ خَيْرًا ‏\}‏ طَعَامُ مِسْكِينٍ آخَرَ لَيْسَتْ بِمَنْسُوخَةٍ ‏\{‏ فَهُوَ خَيْرٌ لَهُ وَأَنْ تَصُومُوا خَيْرٌ لَكُمْ ‏\}‏ لاَ يُرَخَّصُ فِي هَذَا إِلاَّ لِلَّذِي لاَ يُطِيقُ الصِّيَامَ أَوْ مَرِيضٍ لاَ يُشْفَى ‏.‏\hadithno{2317}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Ata from Ibn 'Abbas:concerning this verse "And as for those who can fast with difficulty, (a choice either to fast or) to feed a Miskin (poor person) (for every day)." That for those who can fast with difficulty means they find it hard; to feed a Miskin means feeding one poor person for each day. But whoever does good of his own accord means feeding another poor person. This is not abrogated, and it is bette for him. And: that "you fast is better for you" means there is no concession regarding this except for those who are not able to fast, or who are incurably sick}}
\hadithdefcmd{nasai}{2318}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عَلِيٌّ، - يَعْنِي ابْنَ مُسْهَرٍ - عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ مُعَاذَةَ الْعَدَوِيَّةِ، أَنَّ امْرَأَةً، سَأَلَتْ عَائِشَةَ أَتَقْضِي الْحَائِضُ الصَّلاَةَ إِذَا طَهُرَتْ قَالَتْ أَحَرُورِيَّةٌ أَنْتِ كُنَّا نَحِيضُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ نَطْهُرُ فَيَأْمُرُنَا بِقَضَاءِ الصَّوْمِ وَلاَ يَأْمُرُنَا بِقَضَاءِ الصَّلاَةِ ‏.‏\hadithno{2318}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muadhah Al-Adawiyyah that a woman asked 'Aishah:"Should a menstruating woman make up the prayers when she becomes pure?" she said: "Are youa Haruri? We used to menstruate at the time of the Messenger of Allah then we would become pure. He told us to make up the fast, but he did not tell us to make up the prayers}}
\hadithdefcmd{nasai}{2319}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، يُحَدِّثُ عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ لَيَكُونُ عَلَىَّ الصِّيَامُ مِنْ رَمَضَانَ فَمَا أَقْضِيهِ حَتَّى يَجِيءَ شَعْبَانُ ‏.‏\hadithno{2319}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"I would own fasts from Ramadan and I would not make them up until Shaban came}}
\hadithdefcmd{nasai}{2320}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ عَبْدِ اللَّهِ بْنِ يُونُسَ أَبُو حَصِينٍ، قَالَ حَدَّثَنَا عَبْثَرٌ، قَالَ حَدَّثَنَا حُصَيْنٌ، عَنِ الشَّعْبِيِّ، عَنْ مُحَمَّدِ بْنِ صَيْفِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ عَاشُورَاءَ ‏"‏ أَمِنْكُمْ أَحَدٌ أَكَلَ الْيَوْمَ ‏"‏ ‏.‏ فَقَالُوا مِنَّا مَنْ صَامَ وَمِنَّا مَنْ لَمْ يَصُمْ ‏.‏ قَالَ ‏"‏ فَأَتِمُّوا بَقِيَّةَ يَوْمِكُمْ وَابْعَثُوا إِلَى أَهْلِ الْعَرُوضِ فَلْيُتِمُّوا بَقِيَّةَ يَوْمِهِمْ ‏"‏ ‏.‏\hadithno{2320}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Muhammad bin Saifi said:"The Messenger of Allah said on the day of Ashura: Is there anyone among you who has eaten today?' They said: Some of us are fasting and some of us are not.' He said: 'Do not eat for the rest of the day, and send word to the people of Al-Al-Arud telling them not to eat for the rest of the day}}
\hadithdefcmd{nasai}{2321}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنْ يَزِيدَ، قَالَ حَدَّثَنَا سَلَمَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏ "‏ أَذِّنْ - يَوْمَ عَاشُورَاءَ - مَنْ كَانَ أَكَلَ فَلْيُتِمَّ بَقِيَّةَ يَوْمِهِ وَمَنْ لَمْ يَكُنْ أَكَلَ فَلْيَصُمْ ‏"‏ ‏.‏\hadithno{2321}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Yazid said:"Salamah told us that the Messenger of Allah said to a man: 'Announce the day of Ashura. Whoever has eaten let him not eat for the rest of the day, and whoever has not eaten, let him fast}}
\hadithdefcmd{nasai}{2322}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ طَلْحَةَ بْنِ يَحْيَى بْنِ طَلْحَةَ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ شَىْءٌ ‏"‏ ‏.‏ فَقُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَإِنِّي صَائِمٌ ‏"‏ ‏.‏ ثُمَّ مَرَّ بِي بَعْدَ ذَلِكَ الْيَوْمِ وَقَدْ أُهْدِيَ إِلَىَّ حَيْسٌ فَخَبَأْتُ لَهُ مِنْهُ وَكَانَ يُحِبُّ الْحَيْسَ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّهُ أُهْدِيَ لَنَا حَيْسٌ فَخَبَأْتُ لَكَ مِنْهُ ‏.‏ قَالَ ‏"‏ أَدْنِيهِ أَمَا إِنِّي قَدْ أَصْبَحْتُ وَأَنَا صَائِمٌ ‏"‏ ‏.‏ فَأَكَلَ مِنْهُ ثُمَّ قَالَ ‏"‏ إِنَّمَا مَثَلُ صَوْمِ الْمُتَطَوِّعِ مَثَلُ الرَّجُلِ يُخْرِجُ مِنْ مَالِهِ الصَّدَقَةَ فَإِنْ شَاءَ أَمْضَاهَا وَإِنْ شَاءَ حَبَسَهَا ‏"‏ ‏.‏\hadithno{2322}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah came to me one day and said: 'Do you have anything (to eat)?' I said: 'No.' he said: 'Then I am fasting.' Then he came to me after that day, and I had been given some Hais. I had kept some for him as he liked Hais. She said: 'O Messenger of Allah, we have been given some Hais and I kept some for you.' He said: 'Bring it here. I started the day fasting.' Then he ate some of it, then he said: 'The likeness of a voluntary fast is that of a man who allocated some of his wealth to give in charity; if he wishes he may go ahead and give it, and if he wishes he may keep it}}
\hadithdefcmd{nasai}{2323}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَزِيدُ، أَنْبَأَنَا شَرِيكٌ، عَنْ طَلْحَةَ بْنِ يَحْيَى بْنِ طَلْحَةَ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ دَارَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم دَوْرَةً قَالَ ‏"‏ أَعِنْدَكِ شَىْءٌ ‏"‏ ‏.‏ قَالَتْ لَيْسَ عِنْدِي شَىْءٌ ‏.‏ قَالَ ‏"‏ فَأَنَا صَائِمٌ ‏"‏ ‏.‏ قَالَتْ ثُمَّ دَارَ عَلَىَّ الثَّانِيَةَ وَقَدْ أُهْدِيَ لَنَا حَيْسٌ فَجِئْتُ بِهِ فَأَكَلَ فَعَجِبْتُ مِنْهُ فَقُلْتُ يَا رَسُولَ اللَّهِ دَخَلْتَ عَلَىَّ وَأَنْتَ صَائِمٌ ثُمَّ أَكَلْتَ حَيْسًا ‏.‏ قَالَ ‏"‏ نَعَمْ يَا عَائِشَةُ إِنَّمَا مَنْزِلَةُ مَنْ صَامَ فِي غَيْرِ رَمَضَانَ - أَوْ غَيْرِ قَضَاءِ رَمَضَانَ أَوْ فِي التَّطَوُّعِ - بِمَنْزِلَةِ رَجُلٍ أَخْرَجَ صَدَقَةَ مَالِهِ فَجَادَ مِنْهَا بِمَا شَاءَ فَأَمْضَاهُ وَبَخِلَ مِنْهَا بِمَا بَقِيَ فَأَمْسَكَهُ ‏"‏ ‏.‏\hadithno{2323}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah passed by my door. He said: 'Do you have anything (to eat)?' I said 'I do not have anything.' He said 'Then I am fasting.' Then he passed by my door a second time and we had been given some Hais. I brought it to him and he ate, and I was surprised. I said: 'O Messenger of Allah, you were fasting, then you ate Hais.' He said: 'Yes, O 'Aishah. The one who observes a fast other than in Ramadan, or making up a missed Ramadan, fast, is like a man who allocated some of is wealth to give in charity; if he wishes he may go ahead and give it, and if he wishes he may keep it}}
\hadithdefcmd{nasai}{2324}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْهَيْثَمِ، قَالَ حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجِيءُ وَيَقُولُ ‏"‏ هَلْ عِنْدَكُمْ غَدَاءٌ ‏"‏ ‏.‏ فَنَقُولُ لاَ ‏.‏ فَيَقُولُ ‏"‏ إِنِّي صَائِمٌ ‏"‏ ‏.‏ فَأَتَانَا يَوْمًا وَقَدْ أُهْدِيَ لَنَا حَيْسٌ فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ شَىْءٌ ‏"‏ ‏.‏ قُلْنَا نَعَمْ أُهْدِيَ لَنَا حَيْسٌ ‏.‏ قَالَ ‏"‏ أَمَا إِنِّي قَدْ أَصْبَحْتُ أُرِيدُ الصَّوْمَ ‏"‏ ‏.‏ فَأَكَلَ خَالَفَهُ قَاسِمُ بْنُ يَزِيدَ ‏.‏\hadithno{2324}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said the Messenger of Allah would come and say:"Do you have any food for breakfast?" and we would say no, so he would say: "I am fasting." One day he came to us and we had been given some Hais. He said: "Do you have anything (to eat)?" and we said: "Yes, we have been given some Hais." He said: "I started the day wanting to fast," but then he ate}}
\hadithdefcmd{nasai}{2325}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا قَاسِمٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَقُلْنَا أُهْدِيَ لَنَا حَيْسٌ قَدْ جَعَلْنَا لَكَ مِنْهُ نَصِيبًا ‏.‏ فَقَالَ ‏ "‏ إِنِّي صَائِمٌ ‏"‏ ‏.‏ فَأَفْطَرَ ‏.‏\hadithno{2325}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah came to us one day and we said: 'We have been given some Hais and we set aside some for you.' He said: 'I am fasting, but he broke his fast}}
\hadithdefcmd{nasai}{2326}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، قَالَ حَدَّثَتْنِي عَائِشَةُ بِنْتُ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَأْتِيهَا وَهُوَ صَائِمٌ فَقَالَ ‏"‏ أَصْبَحَ عِنْدَكُمْ شَىْءٌ تُطْعِمِينِيهِ ‏"‏ ‏.‏ فَنَقُولُ لاَ ‏.‏ فَيَقُولُ ‏"‏ إِنِّي صَائِمٌ ‏"‏ ‏.‏ ثُمَّ جَاءَهَا بَعْدَ ذَلِكَ فَقَالَتْ أُهْدِيَتْ لَنَا هَدِيَّةٌ ‏.‏ فَقَالَ ‏"‏ مَا هِيَ ‏"‏ ‏.‏ قَالَتْ حَيْسٌ ‏.‏ قَالَ ‏"‏ قَدْ أَصْبَحْتُ صَائِمًا ‏"‏ ‏.‏ فَأَكَلَ ‏.‏\hadithno{2326}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah, the mother of the Believers, that the Prophet used to come to her when he was fasting and say:"Do you have anything this morning that you can give me to eat?" we would say no, and he would say: "I am fasting." Then after that he came and she said: "I have been given a gift." He said: "What is it?" she said: "Hais." He said: "I started the day fasting," but then he ate}}
\hadithdefcmd{nasai}{2327}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ عَمَّتِهِ، عَائِشَةَ بِنْتِ طَلْحَةَ عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ شَىْءٌ ‏"‏ ‏.‏ قُلْنَا لاَ ‏.‏ قَالَ ‏"‏ فَإِنِّي صَائِمٌ ‏"‏ ‏.‏\hadithno{2327}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah, the mother of the Believers, said:"The Messenger of Allah came to me one day and said: 'Do you have anything (to eat) we said: 'No.' he said: 'Then I am fasting}}
\hadithdefcmd{nasai}{2328}{أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ أَخْبَرَنِي أَبِي، عَنِ الْقَاسِمِ بْنِ مَعْنٍ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، وَمُجَاهِدٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَاهَا فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ طَعَامٌ ‏"‏ ‏.‏ فَقُلْتُ لاَ ‏.‏ قَالَ ‏"‏ إِنِّي صَائِمٌ ‏"‏ ‏.‏ ثُمَّ جَاءَ يَوْمًا آخَرَ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ إِنَّا قَدْ أُهْدِيَ لَنَا حَيْسٌ فَدَعَا بِهِ فَقَالَ ‏"‏ أَمَا إِنِّي قَدْ أَصْبَحْتُ صَائِمًا ‏"‏ ‏.‏ فَأَكَلَ ‏.‏\hadithno{2328}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah came to her and said:"Do you have any food?" and Aishah said: "O Messenger of Allah, we have been given some Hais." So he called for it, and said: "I started the day fasting," then he ate}}
\hadithdefcmd{nasai}{2329}{أَخْبَرَنِي عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا الْمُعَافَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا الْقَاسِمُ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ مُجَاهِدٍ، وَأُمِّ كُلْثُومٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَى عَائِشَةَ فَقَالَ ‏ "‏ هَلْ عِنْدَكُمْ طَعَامٌ ‏"‏ ‏.‏ نَحْوَهُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَقَدْ رَوَاهُ سِمَاكُ بْنُ حَرْبٍ قَالَ حَدَّثَنِي رَجُلٌ عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ ‏.‏\hadithno{2329}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Mujahid and Umm Kulthum that:the Messenger of Allah entered upon 'Aishah and said: "Do you have any food?" a similar report}}
\hadithdefcmd{nasai}{2330}{أَخْبَرَنِي صَفْوَانُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ حَدَّثَنِي رَجُلٌ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ مِنْ طَعَامٍ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ إِذًا أَصُومَ ‏"‏ ‏.‏ قَالَتْ وَدَخَلَ عَلَىَّ مَرَّةً أُخْرَى فَقُلْتُ يَا رَسُولَ اللَّهِ قَدْ أُهْدِيَ لَنَا حَيْسٌ ‏.‏ فَقَالَ ‏"‏ إِذًا أُفْطِرَ الْيَوْمَ وَقَدْ فَرَضْتُ الصَّوْمَ ‏"‏ ‏.‏\hadithno{2330}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah the mother of the Believers, said:"The Messenger of Allah came one day and said: 'Do you have any food?' I said: 'No.' He came in to me on another occasion, and I said: 'O Messenger of Allah, we have been given some Hais.' He said: "Then I will break my fast today, although I had started my day fasting}}
\hadithdefcmd{nasai}{2331}{أَخْبَرَنِي الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ شُرَحْبِيلَ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ حَفْصَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يُبَيِّتِ الصِّيَامَ قَبْلَ الْفَجْرِ فَلاَ صِيَامَ لَهُ ‏"‏ ‏.‏\hadithno{2331}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hafsah that the Prophet said:"Whoever does not have the intention of fasting before dawn, then there is no fast for him."(Daif)}}
\hadithdefcmd{nasai}{2332}{أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ، عَنْ حَفْصَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يُبَيِّتِ الصِّيَامَ قَبْلَ الْفَجْرِ فَلاَ صِيَامَ لَهُ ‏"‏ ‏.‏\hadithno{2332}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hafsah that the Prophet said:"Whoever does not have the intention of fasting before dawn, then there is no fast for him." (Daif)}}
\hadithdefcmd{nasai}{2333}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ أَشْهَبَ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، وَذَكَرَ، آخَرَ أَنَّ عَبْدَ اللَّهِ بْنَ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، حَدَّثَهُمَا عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ حَفْصَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يُجْمِعِ الصِّيَامَ قَبْلَ طُلُوعِ الْفَجْرِ فَلاَ يَصُومُ ‏"‏ ‏.‏\hadithno{2333}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hafsah that the Prophet said:"Whoever does not intend to fast before dawn comes, should not fast." (Daif)}}
\hadithdefcmd{nasai}{2334}{أَخْبَرَنَا أَحْمَدُ بْنُ الأَزْهَرِ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يُبَيِّتِ الصِّيَامَ مِنَ اللَّيْلِ فَلاَ صِيَامَ لَهُ ‏"‏ ‏.‏\hadithno{2334}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hafsah that the Prophet said:"Whoever does not have the intention of fasting from the night before, then there is no fast for him." (Daif)}}
\hadithdefcmd{nasai}{2335}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ، عَنْ حَفْصَةَ، أَنَّهَا كَانَتْ تَقُولُ مَنْ لَمْ يُجْمِعِ الصِّيَامَ مِنَ اللَّيْلِ فَلاَ يَصُومُ ‏.‏\hadithno{2335}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hafsah that she used to say:"Whoever does not intend to fast from the night before, should not fast." (Daif)}}
\hadithdefcmd{nasai}{2336}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي حَمْزَةُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ قَالَتْ حَفْصَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم لاَ صِيَامَ لِمَنْ لَمْ يُجْمِعْ قَبْلَ الْفَجْرِ ‏.‏\hadithno{2336}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hamzah bin 'Abdullah bin 'Umar narrated that his father said:"Hafsah, the wife of the Prophet said: 'There is no fast for the one who does not intend (to fast) before dawn}}
\hadithdefcmd{nasai}{2337}{أَخْبَرَنِي زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ عِيسَى، قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ حَفْصَةَ، قَالَتْ لاَ صِيَامَ لِمَنْ لَمْ يُجْمِعْ قَبْلَ الْفَجْرِ ‏.‏\hadithno{2337}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hafsah that:"There is no fast for one who does not intend (to fast) before dawn}}
\hadithdefcmd{nasai}{2338}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ، وَمَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنْ حَفْصَةَ، قَالَتْ لاَ صِيَامَ لِمَنْ لَمْ يُجْمِعِ الصِّيَامَ قَبْلَ الْفَجْرِ ‏.‏\hadithno{2338}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hafsah that:"There is no fast for the one who does not intend to fast before dawn}}
\hadithdefcmd{nasai}{2339}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ حَفْصَةَ، قَالَتْ لاَ صِيَامَ لِمَنْ لَمْ يُجْمِعِ الصِّيَامَ قَبْلَ الْفَجْرِ ‏.‏\hadithno{2339}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hafsah said:"There is no fast for the one who does not intend to fast before dawn}}
\hadithdefcmd{nasai}{2340}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ، عَنْ حَفْصَةَ، قَالَتْ لاَ صِيَامَ لِمَنْ لَمْ يُجْمِعِ الصِّيَامَ قَبْلَ الْفَجْرِ ‏.‏ أَرْسَلَهُ مَالِكُ بْنُ أَنَسٍ ‏.‏\hadithno{2340}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hafsah said:"There is no fast for the one who does not intend to fast before dawn." Malik bin Anas narrated it in Mursla from}}
\hadithdefcmd{nasai}{2341}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَائِشَةَ، وَحَفْصَةَ، مِثْلَهُ لاَ يَصُومُ إِلاَّ مَنْ أَجْمَعَ الصِّيَامَ قَبْلَ الْفَجْرِ ‏.‏\hadithno{2341}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Something similar was narrated from 'Aishah and Hafsah:"There is no fast except for one who intends to fast before dawn." (Daif)}}
\hadithdefcmd{nasai}{2342}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ إِذَا لَمْ يُجْمِعِ الرَّجُلُ الصَّوْمَ مِنَ اللَّيْلِ فَلاَ يَصُمْ ‏.‏\hadithno{2342}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"If a man does not intend to fast from the night before, he should not fast}}
\hadithdefcmd{nasai}{2343}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ لاَ يَصُومُ إِلاَّ مَنْ أَجْمَعَ الصِّيَامَ قَبْلَ الْفَجْرِ ‏.‏\hadithno{2343}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that he used to say:"None should fast except the one who intended to fast before dawn}}
\hadithdefcmd{nasai}{2344}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحَبُّ الصِّيَامِ إِلَى اللَّهِ عَزَّ وَجَلَّ صِيَامُ دَاوُدَ عَلَيْهِ السَّلاَمُ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا وَأَحَبُّ الصَّلاَةِ إِلَى اللَّهِ عَزَّ وَجَلَّ صَلاَةُ دَاوُدَ عَلَيْهِ السَّلاَمُ كَانَ يَنَامُ نِصْفَ اللَّيْلِ وَيَقُومُ ثُلُثَهُ وَيَنَامُ سُدُسَهُ ‏"‏ ‏.‏\hadithno{2344}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin 'Amr bin Al-As said:"The Messenger of Allah said: 'The most beloved fasting to Allah, the mighty and sublime, is the fast of Dawud, peace be upon him. He used to fast one day and not the next. And the most beloved prayer to Allah, the mighty and sublime, is the prayer of Dawud, peace be upon him. He used to sleep half the night, stand for one-third of it (in prayer), and sleep for one-sixth of it}}
\hadithdefcmd{nasai}{2345}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنَا يَعْقُوبُ، عَنْ جَعْفَرٍ، عَنْ سَعِيدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُفْطِرُ أَيَّامَ الْبِيضِ فِي حَضَرٍ وَلاَ سَفَرٍ ‏.‏\hadithno{2345}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah would not break fast on the days of Al-Bid whether he was a resident or traveling}}
\hadithdefcmd{nasai}{2346}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ لاَ يُفْطِرُ وَيُفْطِرُ حَتَّى نَقُولَ مَا يُرِيدُ أَنْ يَصُومَ وَمَا صَامَ شَهْرًا مُتَتَابِعًا غَيْرَ رَمَضَانَ مُنْذُ قَدِمَ الْمَدِينَةَ ‏.‏\hadithno{2346}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah would fast until we said he would not break his fast, and he would not fast until we said he does not want to fast. And he never fasted any month in full apart from Ramadan, from the time he came to Al-Madinah}}
\hadithdefcmd{nasai}{2347}{أَخْبَرَنَا مُحَمَّدُ بْنُ النَّضْرِ بْنِ مُسَاوِرٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ مَرْوَانَ أَبِي لُبَابَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ مَا يُرِيدُ أَنْ يُفْطِرَ وَيُفْطِرُ حَتَّى نَقُولَ مَا يُرِيدُ أَنْ يَصُومَ ‏.‏\hadithno{2347}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to fast until we said: 'He does not want to break his fast.' And he used not to fast until we said: 'He does not want to fast}}
\hadithdefcmd{nasai}{2348}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ خَالِدٍ، قَالَ حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ لاَ أَعْلَمُ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَرَأَ الْقُرْآنَ كُلَّهُ فِي لَيْلَةٍ وَلاَ قَامَ لَيْلَةً حَتَّى الصَّبَاحِ وَلاَ صَامَ شَهْرًا قَطُّ كَامِلاً غَيْرَ رَمَضَانَ ‏.‏\hadithno{2348}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"I do not know that the Messenger of Allah recited the whole Quran in one night, or prayed Qiyam until morning, or ever fasted an entire month, except Ramadan}}
\hadithdefcmd{nasai}{2349}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ صِيَامِ النَّبِيِّ، صلى الله عليه وسلم قَالَتْ كَانَ يَصُومُ حَتَّى نَقُولَ قَدْ صَامَ وَيُفْطِرُ حَتَّى نَقُولَ قَدْ أَفْطَرَ وَمَا صَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهْرًا كَامِلاً مُنْذُ قَدِمَ الْمَدِينَةَ إِلاَّ رَمَضَانَ ‏.‏\hadithno{2349}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah bin Shaqiq said:"I asked 'Aishah about the fasting of the Messenger of Allah. She said: "The Messenger of Allah used to fast until we said: He is going to (continue to) fast, and he used not to fast until we said: He is not going to, and he did not fast for a whole month from the time he came to Al-Madinah, apart from Ramadan}}
\hadithdefcmd{nasai}{2350}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، أَنَّ عَبْدَ اللَّهِ بْنَ أَبِي قَيْسٍ، حَدَّثَهُ أَنَّهُ، سَمِعَ عَائِشَةَ، تَقُولُ كَانَ أَحَبَّ الشُّهُورِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ يَصُومَهُ شَعْبَانُ بَلْ كَانَ يَصِلُهُ بِرَمَضَانَ ‏.‏\hadithno{2350}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah said:"The month which the Messenger of Allah most liked to fast was Shaban; indeed he used to join it to Ramadan}}
\hadithdefcmd{nasai}{2351}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَالِكٌ، وَعَمْرُو بْنُ الْحَارِثِ، وَذَكَرَ، آخَرَ قَبْلَهُمَا أَنَّ أَبَا النَّضْرِ، حَدَّثَهُمْ عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ مَا يُفْطِرُ وَيُفْطِرُ حَتَّى نَقُولَ مَا يَصُومُ وَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي شَهْرٍ أَكْثَرَ صِيَامًا مِنْهُ فِي شَعْبَانَ ‏.‏\hadithno{2351}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to fast until we said: 'He will not break his fast.' And he used not to fast until we said: 'He will not fast.' And I never saw the Messenger of Allah fast more in any month than in Shaban}}
\hadithdefcmd{nasai}{2352}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ سَمِعْتُ سَالِمَ بْنَ أَبِي الْجَعْدِ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَصُومُ شَهْرَيْنِ مُتَتَابِعَيْنِ إِلاَّ شَعْبَانَ وَرَمَضَانَ ‏.‏\hadithno{2352}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Umm Salamah:That the Messenger of Allah would not fast any two consecutive months except Shaban and Ramadan}}
\hadithdefcmd{nasai}{2353}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ تَوْبَةَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ لَمْ يَكُنْ يَصُومُ مِنَ السَّنَةِ شَهْرًا تَامًّا إِلاَّ شَعْبَانَ وَيَصِلُ بِهِ رَمَضَانَ ‏.‏\hadithno{2353}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Umm Salamah:That the Prophet would not fast any month of the year in full except Shaban and he used to join it to Ramadan}}
\hadithdefcmd{nasai}{2354}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم لِشَهْرٍ أَكْثَرَ صِيَامًا مِنْهُ لِشَعْبَانَ كَانَ يَصُومُهُ أَوْ عَامَّتَهُ ‏.‏\hadithno{2354}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah did not fast any month more than Shaban; he used to fast (all of) it, or most of it}}
\hadithdefcmd{nasai}{2355}{أَخْبَرَنِي عَمْرُو بْنُ هِشَامٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ شَعْبَانَ إِلاَّ قَلِيلاً ‏.‏\hadithno{2355}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to fast (all of) Shaban except a little}}
\hadithdefcmd{nasai}{2356}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنَا بَحِيرٌ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، أَنَّ عَائِشَةَ، قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ شَعْبَانَ كُلَّهُ ‏.‏\hadithno{2356}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jubair bin Nufair that 'Aishah said:"The Messenger of Allah used to fast all of Shaban}}
\hadithdefcmd{nasai}{2357}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا ثَابِتُ بْنُ قَيْسٍ أَبُو الْغُصْنِ، - شَيْخٌ مِنْ أَهْلِ الْمَدِينَةِ - قَالَ حَدَّثَنِي أَبُو سَعِيدٍ الْمَقْبُرِيُّ، قَالَ حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ لَمْ أَرَكَ تَصُومُ شَهْرًا مِنَ الشُّهُورِ مَا تَصُومُ مِنْ شَعْبَانَ ‏.‏ قَالَ ‏ "‏ ذَلِكَ شَهْرٌ يَغْفُلُ النَّاسُ عَنْهُ بَيْنَ رَجَبٍ وَرَمَضَانَ وَهُوَ شَهْرٌ تُرْفَعُ فِيهِ الأَعْمَالُ إِلَى رَبِّ الْعَالَمِينَ فَأُحِبُّ أَنْ يُرْفَعَ عَمَلِي وَأَنَا صَائِمٌ ‏"‏ ‏.‏\hadithno{2357}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Usamah bin Zaid said:"I said: 'O Messenger of Allah, I do not see you fasting any month as much as Shaban.' He said: 'That is a month to which people do not pay much attention, between Rajab and Ramadan. It is a month in which the deeds are taken up to the Lord of the worlds, and I like that my deeds be taken up when I am fasting}}
\hadithdefcmd{nasai}{2358}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا ثَابِتُ بْنُ قَيْسٍ أَبُو الْغُصْنِ، - شَيْخٌ مِنْ أَهْلِ الْمَدِينَةِ - قَالَ حَدَّثَنِي أَبُو سَعِيدٍ الْمَقْبُرِيُّ، قَالَ حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ تَصُومُ حَتَّى لاَ تَكَادَ تُفْطِرُ وَتُفْطِرُ حَتَّى لاَ تَكَادَ أَنْ تَصُومَ إِلاَّ يَوْمَيْنِ إِنْ دَخَلاَ فِي صِيَامِكَ وَإِلاَّ صُمْتَهُمَا ‏.‏ قَالَ ‏"‏ أَىُّ يَوْمَيْنِ ‏"‏ ‏.‏ قُلْتُ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ ‏.‏ قَالَ ‏"‏ ذَانِكَ يَوْمَانِ تُعْرَضُ فِيهِمَا الأَعْمَالُ عَلَى رَبِّ الْعَالَمِينَ فَأُحِبُّ أَنْ يُعْرَضَ عَمَلِي وَأَنَا صَائِمٌ ‏"‏ ‏.‏\hadithno{2358}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Usamah bin Zaid said:"I said: 'O Messenger of Allah, sometimes you fast, and you hardly ever break your hardly ever fast, except two days which, if you are fasting, you include them in your fast, and if you are not fasting, then you fast them on your own.' He said: 'Which two days?' I said: 'Monday and Thursday.' He said: 'Those are two days in which deeds are shown to the Lord of the worlds, and I like my deeds to be shown (to Him) when I am fasting}}
\hadithdefcmd{nasai}{2359}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ أَخْبَرَنِي ثَابِتُ بْنُ قَيْسٍ الْغِفَارِيُّ، قَالَ حَدَّثَنِي أَبُو سَعِيدٍ الْمَقْبُرِيُّ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسْرُدُ الصَّوْمَ فَيُقَالُ لاَ يُفْطِرُ وَيُفْطِرُ فَيُقَالُ لاَ يَصُومُ ‏.‏\hadithno{2359}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Usamah bin Zaid:That the Messenger of Allah used to fast continually and it ws said that he would not break his fast, and he used not to fast and it was said that he would not fast}}
\hadithdefcmd{nasai}{2360}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، عَنْ بَقِيَّةَ، قَالَ حَدَّثَنَا بَحِيرٌ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، أَنَّ عَائِشَةَ، قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَحَرَّى صِيَامَ الاِثْنَيْنِ وَالْخَمِيسِ ‏.‏\hadithno{2360}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrate from Jubair bin Nufair that 'Aishah said:"The Messenger of Allah used to be keen to fast on Mondays and Thursday}}
\hadithdefcmd{nasai}{2361}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، قَالَ أَخْبَرَنِي ثَوْرٌ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ رَبِيعَةَ الْجُرَشِيِّ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَحَرَّى يَوْمَ الاِثْنَيْنِ وَالْخَمِيسِ ‏.‏\hadithno{2361}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to be keen to fast on Mondays and Thursday}}
\hadithdefcmd{nasai}{2362}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ الأُمَوِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ ثَوْرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَحَرَّى الاِثْنَيْنِ وَالْخَمِيسَ ‏.‏\hadithno{2362}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to be keen to fast on Mondays and Thursday}}
\hadithdefcmd{nasai}{2363}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ خَالِدِ بْنِ سَعْدٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَحَرَّى يَوْمَ الاِثْنَيْنِ وَالْخَمِيسِ ‏.‏\hadithno{2363}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to be keen to fast on Mondays and Thursday}}
\hadithdefcmd{nasai}{2364}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبِ بْنِ الشَّهِيدِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ يَمَانٍ، عَنْ سُفْيَانَ، عَنْ عَاصِمٍ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ سَوَاءٍ الْخُزَاعِيِّ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصُومُ الاِثْنَيْنِ وَالْخَمِيسَ ‏.‏\hadithno{2364}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to be keen to fast on Mondays and Thursday}}
\hadithdefcmd{nasai}{2365}{أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو نَصْرٍ التَّمَّارُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَاصِمٍ، عَنْ سَوَاءٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ الاِثْنَيْنِ وَالْخَمِيسَ مِنْ هَذِهِ الْجُمُعَةِ وَالاِثْنَيْنِ مِنَ الْمُقْبِلَةِ ‏.‏\hadithno{2365}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Salamah said:"The Messenger of Allah used to fast three days of every month: the Monday and Thursday of the first week and the Monday of the following week}}
\hadithdefcmd{nasai}{2366}{أَخْبَرَنِي زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا النَّضْرُ، قَالَ أَنْبَأَنَا حَمَّادٌ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ سَوَاءٍ، عَنْ حَفْصَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ مِنْ كُلِّ شَهْرٍ يَوْمَ الْخَمِيسِ وَيَوْمَ الاِثْنَيْنِ وَمِنَ الْجُمُعَةِ الثَّانِيَةِ يَوْمَ الاِثْنَيْنِ ‏.‏\hadithno{2366}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Hafsah said:"The Messenger of Allah used to fast Thursday and Monday of each month, and Monday of the following week}}
\hadithdefcmd{nasai}{2367}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ عَاصِمٍ، عَنِ الْمُسَيَّبِ، عَنْ حَفْصَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَخَذَ مَضْجَعَهُ جَعَلَ كَفَّهُ الْيُمْنَى تَحْتَ خَدِّهِ الأَيْمَنِ وَكَانَ يَصُومُ الاِثْنَيْنَ وَالْخَمِيسَ ‏.‏\hadithno{2367}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hafsah said:"When the Messenger of Allah would lie down, he would place his right hand under his right cheek, and he used to fast on Mondays and Thursday}}
\hadithdefcmd{nasai}{2368}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ أَبِي أَنْبَأَنَا أَبُو حَمْزَةَ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ ثَلاَثَةَ أَيَّامٍ مِنْ غُرَّةِ كُلِّ شَهْرٍ وَقَلَّمَا يُفْطِرُ يَوْمَ الْجُمُعَةِ ‏.‏\hadithno{2368}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin Masud said:"The Messenger of Allah used to fast three days in the middle of every month, and he rarely did not fast on Friday}}
\hadithdefcmd{nasai}{2369}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا أَبُو كَامِلٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ رَجُلٍ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَكْعَتَىِ الضُّحَى وَأَنْ لاَ أَنَامَ إِلاَّ عَلَى وِتْرٍ وَصِيَامِ ثَلاَثَةِ أَيَّامٍ مِنَ الشَّهْرِ ‏.‏\hadithno{2369}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah commanded me to pray two Rakahs of Duha, and not to sleep until I had prayed witr, and to fast three days each month}}
\hadithdefcmd{nasai}{2370}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، وَسُئِلَ، عَنْ صِيَامِ، عَاشُورَاءَ قَالَ مَا عَلِمْتُ النَّبِيَّ صلى الله عليه وسلم صَامَ يَوْمًا يَتَحَرَّى فَضْلَهُ عَلَى الأَيَّامِ إِلاَّ هَذَا الْيَوْمَ يَعْنِي شَهْرَ رَمَضَانَ وَيَوْمَ عَاشُورَاءَ ‏.‏\hadithno{2370}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Ubaidullah that:he heard Ibn 'Abbas, when he was asked about the fast of 'Ashura' say: "I do not know that the Prophet fasted any day because of its virtue, except this day" meaning the month of Ramadan and the day of Ashura}}
\hadithdefcmd{nasai}{2371}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ سَمِعْتُ مُعَاوِيَةَ، يَوْمَ عَاشُورَاءَ وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ يَا أَهْلَ الْمَدِينَةِ أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي هَذَا الْيَوْمِ ‏ "‏ إِنِّي صَائِمٌ فَمَنْ شَاءَ أَنْ يَصُومَ فَلْيَصُمْ ‏"‏ ‏.‏\hadithno{2371}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Humaid bin 'Abdur-Rahman bin 'Awf said:"I heard Mu'awiyah say on the day of 'Ashura when he was on the Mindar: O people of Al-Madinah, where are your scholars? I heard the Messenger of Allah say on this day: "I am fasting, so whoever wants to fast let him do so}}
\hadithdefcmd{nasai}{2372}{أَخْبَرَنِي زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا شَيْبَانُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الْحُرِّ بْنِ صَيَّاحٍ، عَنْ هُنَيْدَةَ بْنِ خَالِدٍ، عَنِ امْرَأَتِهِ، قَالَتْ حَدَّثَتْنِي بَعْضُ، نِسَاءِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَصُومُ يَوْمَ عَاشُورَاءَ وَتِسْعًا مِنْ ذِي الْحِجَّةِ وَثَلاَثَةَ أَيَّامٍ مِنَ الشَّهْرِ أَوَّلَ اثْنَيْنِ مِنَ الشَّهْرِ وَخَمِيسَيْنِ ‏.‏\hadithno{2372}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Hunaidah bin Khalid that his wife said:"One of the wives of the Prophet said: "The Prophet used to fast on the day of 'Ashura, nine days of Dhul-Hijjah and three days each month: The first Monday of the month, and two Thursday}}
\hadithdefcmd{nasai}{2373}{أَخْبَرَنِي حَاجِبُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا الْحَارِثُ بْنُ عَطِيَّةَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ الأَبَدَ فَلاَ صَامَ ‏"‏ ‏.‏\hadithno{2373}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"The Messenger of Allah said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2374}{حَدَّثَنَا عِيسَى بْنُ مُسَاوِرٍ، عَنِ الْوَلِيدِ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ عَبْدِ اللَّهِ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنَا عَطَاءٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ الأَبَدَ فَلاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏\hadithno{2374}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"The Messenger of Allah said: 'Whoever fasts every day of is life, then he has neither fasted, nor broken the fast}}
\hadithdefcmd{nasai}{2375}{أَخْبَرَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنَا أَبِي وَعُقْبَةُ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي عَطَاءٌ، قَالَ حَدَّثَنِي مَنْ، سَمِعَ ابْنَ عُمَرَ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ الأَبَدَ فَلاَ صَامَ ‏"‏ ‏.‏\hadithno{2375}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ata said:"someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2376}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا أَبِي، عَنِ الأَوْزَاعِيِّ، عَنْ عَطَاءٍ، قَالَ حَدَّثَنِي مَنْ، سَمِعَ ابْنَ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ الأَبَدَ فَلاَ صَامَ ‏"‏ ‏.‏\hadithno{2376}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ata said:"someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2377}{أَخْبَرَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا ابْنُ عَائِذٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ الأَوْزَاعِيِّ، عَنْ عَطَاءٍ، أَنَّهُ حَدَّثَهُ قَالَ حَدَّثَنِي مَنْ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ الأَبَدَ فَلاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏\hadithno{2377}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Ata that he narrated that someone who heard him said that 'Abdullah bin 'Amr bin AL-As said:"The Messenger of Allah said: 'The one who fasts every day of his life has neither fasted, nor broken the fast."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2378}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ سَمِعْتُ عَطَاءً، أَنَّ أَبَا الْعَبَّاسِ الشَّاعِرَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، قَالَ بَلَغَ النَّبِيَّ صلى الله عليه وسلم أَنِّي أَصُومُ أَسْرُدُ الصَّوْمَ وَسَاقَ الْحَدِيثَ ‏.‏ قَالَ قَالَ عَطَاءٌ لاَ أَدْرِي كَيْفَ ذَكَرَ صِيَامَ الأَبَدِ لاَ صَامَ مَنْ صَامَ الأَبَدَ ‏.‏\hadithno{2378}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin 'Amr bin Al-As said:"The Prophet heard that I was fasting continually," and he quoted this Hadith. 'Ata said: "I am not sure how he put it, but I think he said: 'There is no fast for one who fats continually." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2379}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنِ الْجُرَيْرِيِّ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ أَخِيهِ، مُطَرِّفٍ عَنْ عِمْرَانَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ إِنَّ فُلاَنًا لاَ يُفْطِرُ نَهَارًا الدَّهْرَ ‏.‏ قَالَ ‏ "‏ لاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏\hadithno{2379}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Imran said:"It was said: 'O Messenger of Allah, so and so never broke his fast, even for one day for the rest of his life.' He said: 'He has neither fasted nor broken his fast."" 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2380}{أَخْبَرَنِي عَمْرُو بْنُ هِشَامٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، عَنِ الأَوْزَاعِيِّ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، أَخْبَرَنِي أَبِي أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَذُكِرَ عِنْدَهُ رَجُلٌ يَصُومُ الدَّهْرَ قَالَ ‏ "‏ لاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏\hadithno{2380}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mutarrif bin 'Abdullah bin 'Abdullah bin Ash-Shikhkhir:"My father told me that he heard the Messenger of Allah say, when mention was made in his presence of a man who fasted for the rest of his life: 'He neither fasted nor broke his fast."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2381}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ مُطَرِّفَ بْنَ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي صَوْمِ الدَّهْرِ ‏ "‏ لاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏\hadithno{2381}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mutarrif bin 'Abdullah bin Ash-Shikhkhir narrated from his father that:the Messenger of Allah said, concerning one who fasted for the rest of his life: "He neither fasted nor broke his fast." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2382}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، قَالَ أَنْبَأَنَا أَبُو هِلاَلٍ، قَالَ حَدَّثَنَا غَيْلاَنُ، - وَهُوَ ابْنُ جَرِيرٍ - قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، - وَهُوَ ابْنُ مَعْبَدٍ الزِّمَّانِيُّ - عَنْ أَبِي قَتَادَةَ، عَنْ عُمَرَ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَرَرْنَا بِرَجُلٍ فَقَالُوا يَا نَبِيَّ اللَّهِ هَذَا لاَ يُفْطِرُ مُنْذُ كَذَا وَكَذَا ‏.‏ فَقَالَ ‏ "‏ لاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏\hadithno{2382}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Umar said:"We were with the Messenger of Allah and we passed by a man. They said: 'O Prophet of Allah, this man has not broken his fast for such and such a time.' He said: 'He has neither fasted nor broken his fast."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2383}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ غَيْلاَنَ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ مَعْبَدٍ الزِّمَّانِيَّ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْ صَوْمِهِ فَغَضِبَ فَقَالَ عُمَرُ رَضِينَا بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ رَسُولاً ‏.‏ وَسُئِلَ عَمَّنْ صَامَ الدَّهْرَ فَقَالَ ‏ "‏ لاَ صَامَ وَلاَ أَفْطَرَ أَوْ مَا صَامَ وَمَا أَفْطَرَ ‏"‏ ‏.‏\hadithno{2383}\hadithgrade{Abu Ghuddah: -; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Qatadah that:the Messenger of Allah was asked about his fasting and he got angry. 'Umr said: "We are content with Allah as our lord, Islam as our religion and Muhammad as or Prophet." And he was aksed about someone who fasted for the rest of his life and said: "He neither fasted nor broke his fast." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2384}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ حَمْزَةَ بْنَ عَمْرٍو الأَسْلَمِيَّ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ أَسْرُدُ الصَّوْمَ أَفَأَصُومُ فِي السَّفَرِ قَالَ ‏ "‏ صُمْ إِنْ شِئْتَ أَوْ أَفْطِرْ إِنْ شِئْتَ ‏"‏ ‏.‏\hadithno{2384}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that Hamzah bin 'Amr Al-Aslami asked the Messenger of Allah:"O Messenger of Allah, I am a man who fasts continually: shoud I fast when traveling?" He said: "Fast if you wish and break you fast if you wish." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, and then he has not fasted}}
\hadithdefcmd{nasai}{2385}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي عَمَّارٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم رَجُلٌ يَصُومُ الدَّهْرَ ‏.‏ قَالَ ‏"‏ وَدِدْتُ أَنَّهُ لَمْ يَطْعَمِ الدَّهْرَ ‏"‏ ‏.‏ قَالُوا فَثُلُثَيْهِ قَالَ ‏"‏ أَكْثَرَ ‏"‏ ‏.‏ قَالُوا فَنِصْفَهُ قَالَ ‏"‏ أَكْثَرَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ أُخْبِرُكُمْ بِمَا يُذْهِبُ وَحَرَ الصَّدْرِ صَوْمُ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏"‏ ‏.‏\hadithno{2385}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin Shurahbil that a man from among the Companions of the Prophet said:'It was said to the Prophet that a man fasted for the rest of his life. He said: 'I wish that he had never eaten.' They said: 'Two-thirds (of a lifetime)?' He said: 'That is too much.' Then he said: 'Shall I not tell you of that which will take away impurity from the heart? Fasting three days each month." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2386}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي عَمَّارٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، قَالَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ مَا تَقُولُ فِي رَجُلٍ صَامَ الدَّهْرَ كُلَّهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَدِدْتُ أَنَّهُ لَمْ يَطْعَمِ الدَّهْرَ شَيْئًا ‏"‏ ‏.‏ قَالَ فَثُلُثَيْهِ قَالَ ‏"‏ أَكْثَرَ ‏"‏ ‏.‏ قَالَ فَنِصْفَهُ قَالَ ‏"‏ أَكْثَرَ ‏"‏ ‏.‏ قَالَ ‏"‏ أَفَلاَ أُخْبِرُكُمْ بِمَا يُذْهِبُ وَحَرَ الصَّدْرِ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ صِيَامُ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏"‏ ‏.‏\hadithno{2386}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin Shurahbil said:"A man came to the Messenger of Allah and said: 'O Messenger of Allah, what do you say about a man who fated for the rest of his life?' The Messenger of Allah said: 'I wish that he would never eat for the rest of his life.' He said: 'Two-thirds ( of a lifetime)?' he said: 'That is too much.' He said: 'Half?' He said: 'Shall I not tell you of that which will take away impurity from the heart?' He said: 'Yes.' He said: 'Fasting for three days each month."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2387}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ عُمَرُ يَا رَسُولَ اللَّهِ كَيْفَ بِمَنْ يَصُومُ الدَّهْرَ كُلَّهُ قَالَ ‏"‏ لاَ صَامَ وَلاَ أَفْطَرَ أَوْ لَمْ يَصُمْ وَلَمْ يُفْطِرْ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ كَيْفَ بِمَنْ يَصُومُ يَوْمَيْنِ وَيُفْطِرُ يَوْمًا قَالَ ‏"‏ أَوَيُطِيقُ ذَلِكَ أَحَدٌ ‏"‏ ‏.‏ قَالَ فَكَيْفَ بِمَنْ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا قَالَ ‏"‏ ذَلِكَ صَوْمُ دَاوُدَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ قَالَ فَكَيْفَ بِمَنْ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمَيْنِ قَالَ ‏"‏ وَدِدْتُ أَنِّي أُطِيقُ ذَلِكَ ‏"‏ ‏.‏ قَالَ ثُمَّ قَالَ ‏"‏ ثَلاَثٌ مِنْ كُلِّ شَهْرٍ وَرَمَضَانُ إِلَى رَمَضَانَ هَذَا صِيَامُ الدَّهْرِ كُلِّهِ ‏"‏ ‏.‏\hadithno{2387}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Qatadah said:"Umar said: 'O Messenger of Allah, what about a person who fasted for an entire lifetime?' He said: 'He neither fasted nor broke his fast for one day?' He said: 'Can anyone do that?' He said: 'What about a person who fasted for one day?' He said: 'That is the fast of Dawud, peace be upon him.' He said: 'What about a person who fasted for one day, and broke his fast for two days?' he said: 'I wish that I could do that.' Then he said: 'Three days of each month, and from Ramadan to Ramadan, this is fasting for an entire lifetime."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2388}{قَالَ وَفِيمَا قَرَأَ عَلَيْنَا أَحْمَدُ بْنُ مَنِيعٍ قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا حُصَيْنٌ، وَمُغِيرَةُ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصِّيَامِ صِيَامُ دَاوُدَ عَلَيْهِ السَّلاَمُ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏ ‏.‏\hadithno{2388}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah said: "The best of fasting is the fast of Dawud, peace be upon him. He used to fast for one day and break his fast for one day."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2389}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ مُجَاهِدٍ، قَالَ قَالَ لِي عَبْدُ اللَّهِ بْنُ عَمْرٍو أَنْكَحَنِي أَبِي امْرَأَةً ذَاتَ حَسَبٍ فَكَانَ يَأْتِيهَا فَيَسْأَلُهَا عَنْ بَعْلِهَا، فَقَالَتْ نِعْمَ الرَّجُلُ مِنْ رَجُلٍ لَمْ يَطَأْ لَنَا فِرَاشًا وَلَمْ يُفَتِّشْ لَنَا كَنَفًا مُنْذُ أَتَيْنَاهُ ‏.‏ فَذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ ائْتِنِي بِهِ ‏"‏ ‏.‏ فَأَتَيْتُهُ مَعَهُ فَقَالَ ‏"‏ كَيْفَ تَصُومُ ‏"‏ ‏.‏ قُلْتُ كُلَّ يَوْمٍ ‏.‏ قَالَ ‏"‏ صُمْ مِنْ كُلِّ جُمُعَةٍ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ يَوْمَيْنِ وَأَفْطِرْ يَوْمًا ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ أَفْضَلَ الصِّيَامِ صِيَامَ دَاوُدَ عَلَيْهِ السَّلاَمُ صَوْمُ يَوْمٍ وَفِطْرُ يَوْمٍ ‏"‏ ‏.‏\hadithno{2389}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Muhajid said:"Abdullah bin 'Amr said to me: My father got me married to a woman from a noble family, and he used to come to her and ask her about her husband. She said: What a wonderful man he is! He never comes to my bed. And he has never approached me since he married me. He mentioned that to the Prophet and he said: Bring him to me. So he brought him with him and (the Prophet) said: How do you fast? I said: "Every day." He said: "Fast three days of every month." I said: "I am able to do better than that." He said: "Fast for two days, and break your fast for one day." He said; "I am able to do better than that". He said: "Observe the best of fasts, the fast of Dawud, peace be upon him: Fasting for one day and breaking the fast for one day." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2390}{أَخْبَرَنَا أَبُو حَصِينٍ عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ عَبْدِ اللَّهِ بْنِ يُونُسَ، قَالَ حَدَّثَنَا عَبْثَرٌ، قَالَ حَدَّثَنَا حُصَيْنٌ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ زَوَّجَنِي أَبِي امْرَأَةً فَجَاءَ يَزُورُهَا فَقَالَ كَيْفَ تَرَيْنَ بَعْلَكِ فَقَالَتْ نِعْمَ الرَّجُلُ مِنْ رَجُلٍ لاَ يَنَامُ اللَّيْلَ وَلاَ يُفْطِرُ النَّهَارَ ‏.‏ فَوَقَعَ بِي وَقَالَ زَوَّجْتُكَ امْرَأَةً مِنَ الْمُسْلِمِينَ فَعَضَلْتَهَا ‏.‏ قَالَ فَجَعَلْتُ لاَ أَلْتَفِتُ إِلَى قَوْلِهِ مِمَّا أَرَى عِنْدِي مِنَ الْقُوَّةِ وَالاِجْتِهَادِ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ لَكِنِّي أَنَا أَقُومُ وَأَنَامُ وَأَصُومُ وَأُفْطِرُ فَقُمْ وَنَمْ وَصُمْ وَأَفْطِرْ ‏"‏ ‏.‏ قَالَ ‏"‏ صُمْ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏ فَقُلْتُ أَنَا أَقْوَى مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ صَوْمَ دَاوُدَ عَلَيْهِ السَّلاَمُ صُمْ يَوْمًا وَأَفْطِرْ يَوْمًا ‏"‏ ‏.‏ قُلْتُ أَنَا أَقْوَى مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ اقْرَإِ الْقُرْآنَ فِي كُلِّ شَهْرٍ ‏"‏ ‏.‏ ثُمَّ انْتَهَى إِلَى خَمْسَ عَشْرَةَ وَأَنَا أَقُولُ أَنَا أَقْوَى مِنْ ذَلِكَ ‏.‏\hadithno{2390}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"My father got me married to a woman and he came to visit her and said: 'What do you think of your husband?' She said: 'What a wonderful man he is. He does not sleep at night and he does not break his fast during the day.' He got upset with me and said: 'I got you married to a woman from among the Muslims and you have neglected her.' I did not pay attention to what he said because of my energy and love of worship. News of that reached the Prophet and he said: 'But I stand (in prayer) and I sleep, I fast and I break my fast. So stand (in prayer) and sleep, fast and break your fast.' He said: 'Fast three days of every month.' I said: 'I am able to do more than that.' He said: 'O bserve the fast of Dawud, peace be upon him: fast one day and break your fast one day.' I said: 'I am able to do more than that.' He said: 'Read the Quran (once) every month.' Then it ended up being every fifteen days, and I still said: 'I am able to do more than that."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2391}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم حُجْرَتِي فَقَالَ ‏"‏ أَلَمْ أُخْبَرْ أَنَّكَ تَقُومُ اللَّيْلَ وَتَصُومُ النَّهَارَ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلَنَّ نَمْ وَقُمْ وَصُمْ وَأَفْطِرْ فَإِنَّ لِعَيْنِكَ عَلَيْكَ حَقًّا وَإِنَّ لِجَسَدِكَ عَلَيْكَ حَقًّا وَإِنَّ لِزَوْجَتِكَ عَلَيْكَ حَقًّا وَإِنَّ لِضَيْفِكَ عَلَيْكَ حَقًّا وَإِنَّ لِصَدِيقِكَ عَلَيْكَ حَقًّا وَإِنَّهُ عَسَى أَنْ يَطُولَ بِكَ عُمُرٌ وَإِنَّهُ حَسْبُكَ أَنْ تَصُومَ مِنْ كُلِّ شَهْرٍ ثَلاَثًا فَذَلِكَ صِيَامُ الدَّهْرِ كُلِّهِ وَالْحَسَنَةُ بِعَشْرِ أَمْثَالِهَا ‏"‏ ‏.‏ قُلْتُ إِنِّي أَجِدُ قُوَّةً فَشَدَّدْتُ فَشُدِّدَ عَلَىَّ ‏.‏ قَالَ ‏"‏ صُمْ مِنْ كُلِّ جُمُعَةٍ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ فَشَدَّدْتُ فَشُدِّدَ عَلَىَّ ‏.‏ قَالَ ‏"‏ صُمْ صَوْمَ نَبِيِّ اللَّهِ دَاوُدَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ قُلْتُ وَمَا كَانَ صَوْمُ دَاوُدَ قَالَ ‏"‏ نِصْفُ الدَّهْرِ ‏"‏ ‏.‏\hadithno{2391}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah entered my apartment and said: "I have been told that you stand all night (in prayer) and fast all day.' I said: 'Yes (I do).' He said: 'Do not do that. Sleep and stand (in prayer); fast and break your fast. For your eyes have a right over you, your body has a right over you, your body has a right over you, your wife has a right over you, your guest has a right over you, and your friend has a right over you. I hope that you will have a long life and that it will be sufficient for you to fast three days of each month. That is fasting for a lifetime, because a good deed is equal to ten like it.' I said : 'I feel able to do more.' I was strict, so I was dealt with strictly. He said: 'Fast three days each week.' I said: 'I am ableto do more thtn that; I was strict, so I was dealt with strictly. He said: 'Observe the fast of the Prophet of Allah, Dawud, peace be upon him. I said: 'What was the fast of Dawud?' he said: 'Half of a lifetime."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2392}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، قَالَ ذُكِرَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ يَقُولُ لأَقُومَنَّ اللَّيْلَ وَلأَصُومَنَّ النَّهَارَ مَا عِشْتُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنْتَ الَّذِي تَقُولُ ذَلِكَ ‏"‏ ‏.‏ فَقُلْتُ لَهُ قَدْ قُلْتُهُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّكَ لاَ تَسْتَطِيعُ ذَلِكَ فَصُمْ وَأَفْطِرْ وَنَمْ وَقُمْ وَصُمْ مِنَ الشَّهْرِ ثَلاَثَةَ أَيَّامٍ فَإِنَّ الْحَسَنَةَ بِعَشْرِ أَمْثَالِهَا وَذَلِكَ مِثْلُ صِيَامِ الدَّهْرِ ‏"‏ ‏.‏ قُلْتُ فَإِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ يَوْمًا وَأَفْطِرْ يَوْمَيْنِ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَصُمْ يَوْمًا وَأَفْطِرْ يَوْمًا وَذَلِكَ صِيَامُ دَاوُدَ وَهُوَ أَعْدَلُ الصِّيَامِ ‏"‏ ‏.‏ قُلْتُ فَإِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ أَفْضَلَ مِنْ ذَلِكَ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو لأَنْ أَكُونَ قَبِلْتُ الثَّلاَثَةَ الأَيَّامَ الَّتِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحَبُّ إِلَىَّ مِنْ أَهْلِي وَمَالِي ‏.‏\hadithno{2392}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Amr bin Al-As that it was mentioned to the Messenger of Allah that he had said:"I will certainly stand all night (in prayer) and fast every day for as long as I live." The Messenger of Allah said: "Are you the one who said that?" I said: 'I said it, O Messenger of Allah.' The Messenger of Allah said: 'You cannot do that. Fast and break your fast, sleep and stand (in prayer), and fast three days of each month. For a good deed is equal to ten like it, and that is like fasting for a lifetime.' I said: 'But I am able to do bette than that.' He said: 'Fast for one day and break your fast for two days.' I said: 'I am able to do better than that, O Messenger of Allah.' He said: 'Then fast for one day and break your fast for two days.' I said: 'I am able to do better than that, O Messenger of Allah said : 'There is noting better than that."' 'Abdullah said: "If I had accepted the three days that the Messenger of Allah said, that would be dearer to me than my family and my wealth." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2393}{أَخْبَرَنِي أَحْمَدُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ سَلَمَةَ - عَنِ ابْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ دَخَلْتُ عَلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو قُلْتُ أَىْ عَمِّ حَدِّثْنِي عَمَّا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ يَا ابْنَ أَخِي إِنِّي كُنْتُ أَجْمَعْتُ عَلَى أَنْ أَجْتَهِدَ اجْتِهَادًا شَدِيدًا حَتَّى قُلْتُ لأَصُومَنَّ الدَّهْرَ وَلأَقْرَأَنَّ الْقُرْآنَ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ فَسَمِعَ بِذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَتَانِي حَتَّى دَخَلَ عَلَىَّ فِي دَارِي فَقَالَ ‏"‏ بَلَغَنِي أَنَّكَ قُلْتَ لأَصُومَنَّ الدَّهْرَ وَلأَقْرَأَنَّ الْقُرْآنَ ‏"‏ ‏.‏ فَقُلْتُ قَدْ قُلْتُ ذَلِكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلْ صُمْ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏ قُلْتُ إِنِّي أَقْوَى عَلَى أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَصُمْ مِنَ الْجُمُعَةِ يَوْمَيْنِ الاِثْنَيْنِ وَالْخَمِيسَ ‏"‏ ‏.‏ قُلْتُ فَإِنِّي أَقْوَى عَلَى أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَصُمْ صِيَامَ دَاوُدَ عَلَيْهِ السَّلاَمُ فَإِنَّهُ أَعْدَلُ الصِّيَامِ عِنْدَ اللَّهِ يَوْمًا صَائِمًا وَيَوْمًا مُفْطِرًا وَإِنَّهُ كَانَ إِذَا وَعَدَ لَمْ يُخْلِفْ وَإِذَا لاَقَى لَمْ يَفِرَّ ‏"‏ ‏.‏\hadithno{2393}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Salamah bin 'Abdur-Rahman said:"I entered upon 'Abdullah bin 'Amr and said: O uncle, tell me what the Messenger of Allah said to you. He said: O son of my brother, I had resolved to strive very hard until I said: I will fast for the rest of my life and I will read the whole Quran every day and night. The Messenger of Allah heard about that, and came in to me in my house, and said: I have heard that you said, I will fast for a lifetime and will read the Quran. I said: I did say that, O Messenger of Allah. He said; Do not do that. Fast three days of each month. I said: I am able to do more than that. He said: fast two days of each week, Monday and Thursday. I said: I am able to do more than that. He said; Observe the fast of Dawud, peace be upon him, for it is the best kind of fasting before Allah; one day fasting, and one day not fasting. And when he made a promise he did not break it, and when he met (the enemy in battle) he did not flee." 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2394}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ زِيَادِ بْنِ فَيَّاضٍ، سَمِعْتُ أَبَا عِيَاضٍ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ صُمْ يَوْمًا وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ مِنَ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ يَوْمَيْنِ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ أَرْبَعَةَ أَيَّامٍ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ أَفْضَلَ الصِّيَامِ عِنْدَ اللَّهِ صَوْمَ دَاوُدَ عَلَيْهِ السَّلاَمُ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏ ‏.‏\hadithno{2394}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that the Messenger of Allah (ﷺ) said to him:"Fast one day, and you will have the reward of what is left." He said: "I am able to do more than that." He (ﷺ) said: "Fast two days, and you will have the reward of what is left." He said: "I am able to do more than that." He (ﷺ) said: "Fast three days and you will have the reward of what is left." He said: "I am able to do more than that." He (ﷺ) said: "Fast four days and you will have the reward of what is left." He said: "I am able to do more than that." He (ﷺ) said: "Observe the best kind of fasting before Allah, the fast of Dawud, peace be upon him; he used to fast one day and break his fast for one day." 'Ata said: "Someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2395}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، قَالَ حَدَّثَنَا أَبُو الْعَلاَءِ، عَنْ مُطَرِّفٍ، عَنِ ابْنِ أَبِي رَبِيعَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ ذَكَرْتُ لِلنَّبِيِّ صلى الله عليه وسلم الصَّوْمَ فَقَالَ ‏"‏ صُمْ مِنْ كُلِّ عَشْرَةِ أَيَّامٍ يَوْمًا وَلَكَ أَجْرُ تِلْكَ التِّسْعَةِ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي أَقْوَى مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ مِنْ كُلِّ تِسْعَةِ أَيَّامٍ يَوْمًا وَلَكَ أَجْرُ تِلْكَ الثَّمَانِيَةِ ‏"‏ ‏.‏ قُلْتُ إِنِّي أَقْوَى مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَصُمْ مِنْ كُلِّ ثَمَانِيَةِ أَيَّامٍ يَوْمًا وَلَكَ أَجْرُ تِلْكَ السَّبْعَةِ ‏"‏ ‏.‏ قُلْتُ إِنِّي أَقْوَى مِنْ ذَلِكَ قَالَ فَلَمْ يَزَلْ حَتَّى قَالَ ‏"‏ صُمْ يَوْمًا وَأَفْطِرْ يَوْمًا ‏"‏ ‏.‏\hadithno{2395}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:'Amr said: "I spoke to the Prophet and he said: 'Fast one day out of ten and you will have the reward of the other nine.' I said: 'I am able to do more than that.' He said: 'Fast one day out of eight and you will have the reward of the other eight.' I said: 'I am able to do more than that.' He said: 'Fast one day out of eight and you will have the reward of the other seven.' I said: 'I am able to do more than that.' 'Fast one day and not the next}}
\hadithdefcmd{nasai}{2396}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا حَمَّادٌ، ح وَأَخْبَرَنِي زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ شُعَيْبِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِيهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صُمْ يَوْمًا وَلَكَ أَجْرُ عَشْرَةٍ ‏"‏ ‏.‏ فَقُلْتُ زِدْنِي ‏.‏ فَقَالَ ‏"‏ صُمْ يَوْمَيْنِ وَلَكَ أَجْرُ تِسْعَةٍ ‏"‏ ‏.‏ قُلْتُ زِدْنِي ‏.‏ قَالَ ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ وَلَكَ أَجْرُ ثَمَانِيَةٍ ‏"‏ ‏.‏ قَالَ ثَابِتٌ فَذَكَرْتُ ذَلِكَ لِمُطَرِّفٍ فَقَالَ مَا أُرَاهُ إِلاَّ يَزْدَادُ فِي الْعَمَلِ وَيَنْقُصُ مِنَ الأَجْرِ وَاللَّفْظُ لِمُحَمَّدٍ ‏.‏\hadithno{2396}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Shuaib bin 'Abdullah bin 'Amr that his father said:"The Messenger of Allah said to me: 'Fast one day and you will have the reward of ten.' I said: 'Let me fast more.' He said: 'Fast two days and you will have the reward of nine.' I said: 'Let me fast more than that.' He said: 'Fast three days and you will have the reward of eight." (One of the narrators) Thabit said: "I mentioned that to Mutarrif and he said: 'I only see that he is making more effort for less reward}}
\hadithdefcmd{nasai}{2397}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ أَسْبَاطٍ، عَنْ مُطَرِّفٍ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ بَلَغَنِي أَنَّكَ تَقُومُ اللَّيْلَ وَتَصُومُ النَّهَارَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ مَا أَرَدْتُ بِذَلِكَ إِلاَّ الْخَيْرَ ‏.‏ قَالَ ‏"‏ لاَ صَامَ مَنْ صَامَ الأَبَدَ وَلَكِنْ أَدُلُّكَ عَلَى صَوْمِ الدَّهْرِ ثَلاَثَةُ أَيَّامٍ مِنَ الشَّهْرِ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ خَمْسَةَ أَيَّامٍ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَصُمْ عَشْرًا ‏"‏ ‏.‏ فَقُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ صَوْمَ دَاوُدَ عَلَيْهِ السَّلاَمُ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏ ‏.‏\hadithno{2397}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah said: 'I have heard that you stand (in prayer) all night and fast all day.' I said: 'O Messenger of Allah, I only meant good by that.' He said: 'One who fasts every day of his life has not truly fasted. But I will tell you what fasting for a lifetime means: Three days of every month.' I said: 'O Messenger of Allah, I said: 'I am able to do more than that.' He said 'Observe the fast of Dawud, peace be upon him; he used to fast one day and not the next."' 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2398}{أَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ، قَالَ حَدَّثَنَا أُمَيَّةُ، عَنْ شُعْبَةَ، عَنْ حَبِيبٍ، قَالَ حَدَّثَنِي أَبُو الْعَبَّاسِ، - وَكَانَ رَجُلاً مِنْ أَهْلِ الشَّامِ وَكَانَ شَاعِرًا وَكَانَ صَدُوقًا - عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{2398}\hadithgrade{Al-Albani: Daif}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah said to me" and he quoted the same Hadith. 'Ata said: "someone who heard him told me that Ibn 'Umar (said) that the Prophet said: 'Whoever fasts every day of his life, then he has not fasted}}
\hadithdefcmd{nasai}{2399}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي حَبِيبُ بْنُ أَبِي ثَابِتٍ، قَالَ سَمِعْتُ أَبَا الْعَبَّاسِ، - هُوَ الشَّاعِرُ - يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو إِنَّكَ تَصُومُ الدَّهْرَ وَتَقُومُ اللَّيْلَ وَإِنَّكَ إِذَا فَعَلْتَ ذَلِكَ هَجَمَتِ الْعَيْنُ وَنَفِهَتْ لَهُ النَّفْسُ لاَ صَامَ مَنْ صَامَ الأَبَدَ صَوْمُ الدَّهْرِ ثَلاَثَةُ أَيَّامٍ مِنَ الشَّهْرِ صَوْمُ الدَّهْرِ كُلِّهِ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ صَوْمَ دَاوُدَ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا وَلاَ يَفِرُّ إِذَا لاَقَى ‏"‏ ‏.‏\hadithno{2399}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah said to me: 'O 'Abdullah bin 'Amr, you fast all the time and you do stand (in prayer) at night, but if you do that your eyes will become sunken and you will become exhausted. There is no fast for one who fasts every day of his life. Fasting a lifetime means fasting three days each month}}
\hadithdefcmd{nasai}{2400}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَإِ الْقُرْآنَ فِي شَهْرٍ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ فَلَمْ أَزَلْ أَطْلُبُ إِلَيْهِ حَتَّى قَالَ ‏"‏ فِي خَمْسَةِ أَيَّامٍ ‏"‏ ‏.‏ وَقَالَ ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ مِنَ الشَّهْرِ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ فَلَمْ أَزَلْ أَطْلُبُ إِلَيْهِ حَتَّى قَالَ ‏"‏ صُمْ أَحَبَّ الصِّيَامِ إِلَى اللَّهِ عَزَّ وَجَلَّ صَوْمَ دَاوُدَ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏ ‏.‏\hadithno{2400}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah said to me: 'Read the Qur'an in a month.' I said: 'I am able to do more than that. ' And I kept asking him until he said: 'In five days.' And he said: 'Fast three days a month.' I said: 'I am able to do more than that.' And 'Observe thhe most beloved of fasting to Allah, the Mighty and Sublime, the fast one day and not the next." (Suahih)}}
\hadithdefcmd{nasai}{2401}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ سَمِعْتُ عَطَاءً، يَقُولُ إِنَّ أَبَا الْعَبَّاسِ الشَّاعِرَ أَخْبَرَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، قَالَ بَلَغَ النَّبِيَّ صلى الله عليه وسلم أَنِّي أَصُومُ أَسْرُدُ الصَّوْمَ وَأُصَلِّي اللَّيْلَ فَأَرْسَلَ إِلَيْهِ وَلَمَّا لَقِيَهُ قَالَ ‏"‏ أَلَمْ أُخْبَرْ أَنَّكَ تَصُومُ وَلاَ تُفْطِرُ وَتُصَلِّي اللَّيْلَ فَلاَ تَفْعَلْ فَإِنَّ لِعَيْنِكَ حَظًّا وَلِنَفْسِكَ حَظًّا وَلأَهْلِكَ حَظًّا وَصُمْ وَأَفْطِرْ وَصَلِّ وَنَمْ وَصُمْ مِنْ كُلِّ عَشْرَةِ أَيَّامٍ يَوْمًا وَلَكَ أَجْرُ تِسْعَةٍ ‏"‏ ‏.‏ قَالَ إِنِّي أَقْوَى لِذَلِكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ صُمْ صِيَامَ دَاوُدَ إِذًا ‏"‏ ‏.‏ قَالَ وَكَيْفَ كَانَ صِيَامُ دَاوُدَ يَا نَبِيَّ اللَّهِ قَالَ ‏"‏ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا وَلاَ يَفِرُّ إِذَا لاَقَى ‏"‏ ‏.‏ قَالَ وَمَنْ لِي بِهَذَا يَا نَبِيَّ اللَّهِ ‏.‏\hadithno{2401}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Abduallah bin amr bin Al-'As said:"The Messenger of Allah heard that I was fasting continually and praying all night." Either he sent for him, or he happened to meet him and he said: "Have I not been told that you fast and never break your fast, and you pray all night? Do not do that, for do that, for your eyes should have a share, your self should have a share, and your family should have a share. Fast and break your fast; pray and sleep. Fast one day out of every ten, and your will have the reward of the other nine." He said: " I am able to do more than that, O Messenger of Allah." He said: "Observe the fast of Dawud then." " I said: 'How did Dawud fast, O Prophet of Allah? He said: 'He used to fast one day, and not the next, and he never fled if he met(the enemy in battle)."' He said: "How can I compare to him, O Prophet of Allah?}}
\hadithdefcmd{nasai}{2402}{أَخْبَرَنَا زَكَرِيَّاءُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، قَالَ أَنْبَأَنَا خَالِدٌ، عَنْ خَالِدٍ، - وَهُوَ الْحَذَّاءُ - عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمَلِيحِ، قَالَ دَخَلْتُ مَعَ أَبِيكَ زَيْدٍ عَلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو فَحَدَّثَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذُكِرَ لَهُ صَوْمِي فَدَخَلَ عَلَىَّ فَأَلْقَيْتُ لَهُ وِسَادَةَ أَدَمٍ رَبْعَةً حَشْوُهَا لِيفٌ فَجَلَسَ عَلَى الأَرْضِ وَصَارَتِ الْوِسَادَةُ فِيمَا بَيْنِي وَبَيْنَهُ قَالَ ‏"‏ أَمَا يَكْفِيكَ مِنْ كُلِّ شَهْرٍ ثَلاَثَةُ أَيَّامٍ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ خَمْسًا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ سَبْعًا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ تِسْعًا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِحْدَى عَشْرَةَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ صَوْمَ فَوْقَ صَوْمِ دَاوُدَ شَطْرَ الدَّهْرِ صِيَامُ يَوْمٍ وَفِطْرُ يَوْمٍ ‏"‏ ‏.‏\hadithno{2402}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Al-Malih said:"I entered with Zaid upon 'Abdullah bin Amr and he narrated: 'The Messenger of Allah was told about my fasting, so the entered upon me and I gave him an average-sized leather pillow that was stuffed with palm fibvers. He sat in the ground with the pillow between myself and him, and said: "Whill it not be sufficient for you to fast three days each months?" I said: O Messenger of Allah! He said: "O Messenger of Allah!" He said: "Eleven." I said: "O Messenger of Allah!" Then the Prophet said: "There is not fast better than the fast of Dawud, half of a lifetime, fasting one day and not next}}
\hadithdefcmd{nasai}{2403}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي شُعْبَةُ، عَنْ زِيَادِ بْنِ فَيَّاضٍ، قَالَ سَمِعْتُ أَبَا عِيَاضٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صُمْ مِنَ الشَّهْرِ يَوْمًا وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَصُمْ يَوْمَيْنِ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَصُمْ ثَلاَثَةَ أَيَّامٍ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ أَرْبَعَةَ أَيَّامٍ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفْضَلُ الصَّوْمِ صَوْمُ دَاوُدَ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏ ‏.‏\hadithno{2403}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Amr said:"The Messenger of Allah said to me: 'Fast one day of the month and you will have the reward of what is left.' I said: 'I am able to do more than that.' He said: 'Fast two days and you will have the reward of what is left.' I said: 'I am able to do more than that.' He said: 'Fast three days and you will have the reward of what is left.' I said: 'I am able to do more than that.' He said: 'Fast four days and you will have the reward of what is left.' I said: ' I am able to do more than that.' The messenger of Allah said: 'The best fasting is the fast of Dawud; he used to fast one day and not the next."' 2406. It was narrated that Abu Dharr said: "My beloved Prophet advised me to do three things which I will never give up, if Allah wills. He advised me to pray Duha to pray Witr before sleeping, and to fast three days of each month}}
\hadithdefcmd{nasai}{2404}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حَرْمَلَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي ذَرٍّ، قَالَ أَوْصَانِي حَبِيبِي صلى الله عليه وسلم بِثَلاَثَةٍ لاَ أَدَعُهُنَّ إِنْ شَاءَ اللَّهُ تَعَالَى أَبَدًا أَوْصَانِي بِصَلاَةِ الضُّحَى وَبِالْوِتْرِ قَبْلَ النَّوْمِ وَبِصِيَامِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏.‏\hadithno{2404}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Dharr said:"My beloved Prophet advised me to do three things which I will never give up, if Allah wills. He advised me to pray Duha, to pray Witr before sleeping, and to fast three days of each month}}
\hadithdefcmd{nasai}{2405}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحَسَنِ، قَالَ سَمِعْتُ أَبِي قَالَ، أَنْبَأَنَا أَبُو حَمْزَةَ، عَنْ عَاصِمٍ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِثَلاَثٍ بِنَوْمٍ عَلَى وِتْرٍ وَالْغُسْلِ يَوْمَ الْجُمُعَةِ وَصَوْمِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏.‏\hadithno{2405}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah enjoyed three things upon me: To sleep after praying Witr, to perform Ghusal on Friday, and to fast three days of each month." (Sahih)}}
\hadithdefcmd{nasai}{2406}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا أَبُو كَامِلٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ رَجُلٍ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَكْعَتَىِ الضُّحَى وَأَنْ لاَ أَنَامَ إِلاَّ عَلَى وِتْرٍ وَصِيَامِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏.‏\hadithno{2406}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah commanded me to pray two Rakahs of Duah,nt to sleep until after praying Witr and to fast three days of each month. (Sahih)}}
\hadithdefcmd{nasai}{2407}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَوْمٍ عَلَى وِتْرٍ وَالْغُسْلِ يَوْمَ الْجُمُعَةِ وَصِيَامِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏.‏\hadithno{2407}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah commanded me to sleep after praying Witr, to perform Ghusl on Friday and to fast three days of each month." (Sahih)}}
\hadithdefcmd{nasai}{2408}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي عُثْمَانَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ شَهْرُ الصَّبْرِ وَثَلاَثَةُ أَيَّامٍ مِنْ كُلِّ شَهْرٍ صَوْمُ الدَّهْرِ ‏"‏ ‏.‏\hadithno{2408}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:" I heard the Messenger of Allah say: 'The month of patience ( Ramadan) and three days of each month is fasting for a lifetime."' (Sahih)}}
\hadithdefcmd{nasai}{2409}{أَخْبَرَنَا عَلِيُّ بْنُ الْحَسَنِ اللاَّنِيُّ، بِالْكُوفَةِ عَنْ عَبْدِ الرَّحِيمِ، - وَهُوَ ابْنُ سُلَيْمَانَ - عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَامَ ثَلاَثَةَ أَيَّامٍ مِنَ الشَّهْرِ فَقَدْ صَامَ الدَّهْرَ كُلَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ صَدَقَ اللَّهُ فِي كِتَابِهِ ‏\{‏ مَنْ جَاءَ بِالْحَسَنَةِ فَلَهُ عَشْرُ أَمْثَالِهَا ‏\}‏ ‏"‏ ‏.‏\hadithno{2409}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah said: 'Whoever fasts for three days of each month, he has fasted for a whole lifetime.' Then he said: Allah has spoken the truth in His book: Whoever brings a good deed shall have ten times the like thereof to his credit}}
\hadithdefcmd{nasai}{2410}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ رَجُلٍ، قَالَ أَبُو ذَرٍّ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَامَ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ فَقَدْ تَمَّ صَوْمُ الشَّهْرِ أَوْ فَلَهُ صَوْمُ الشَّهْرِ ‏"‏ ‏.‏ شَكَّ عَاصِمٌ ‏.‏\hadithno{2410}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Abu 'Uthman reported from a man, that Abu Dharrr said:"I heard the Messenger of Allah say: "Whoever fasts three days of each month has fasted the month in full' or 'will have (the reward of) fasting the month."' 'Asim was in doubt}}
\hadithdefcmd{nasai}{2411}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، أَنَّ مُطَرِّفًا، حَدَّثَهُ أَنَّ عُثْمَانَ بْنَ أَبِي الْعَاصِ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ صِيَامٌ حَسَنٌ ثَلاَثَةُ أَيَّامٍ مِنَ الشَّهْرِ ‏"‏ ‏.‏\hadithno{2411}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Uthman bin Abi Al-As said:"I heard the Messenger of Allah say: 'It is a good fast to fast three days of each month}}
\hadithdefcmd{nasai}{2412}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ أَنْبَأَنَا أَبُو مُصْعَبٍ، عَنْ مُغِيرَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، قَالَ عُثْمَانُ بْنُ أَبِي الْعَاصِ نَحْوَهُ مُرْسَلٌ ‏.‏\hadithno{2412}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Sa'eed bin Abi Hind said:"Uthman bin Abi Al-As" and he narrated something similar in Mursal form}}
\hadithdefcmd{nasai}{2413}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنْ شَرِيكٍ، عَنِ الْحُرِّ بْنِ صَيَّاحٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصُومُ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏.‏\hadithno{2413}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Al-Hurr bin Sayyah said:"I heard Ibn 'Umar say" "The Prophet used to fast three days of each month}}
\hadithdefcmd{nasai}{2414}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، عَنْ شَرِيكٍ، عَنِ الْحُرِّ بْنِ صَيَّاحٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ يَوْمَ الاِثْنَيْنِ مِنْ أَوَّلِ الشَّهْرِ وَالْخَمِيسَ الَّذِي يَلِيهِ ثُمَّ الْخَمِيسَ الَّذِي يَلِيهِ ‏.‏\hadithno{2414}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah used to fast three days of each month: Monday at the beginning of the month, the following Thursday, then the Thursday after that}}
\hadithdefcmd{nasai}{2415}{أَخْبَرَنَا عَلِيُّ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ، قَالَ حَدَّثَنَا خَلَفُ بْنُ تَمِيمٍ، عَنْ زُهَيْرٍ، عَنِ الْحُرِّ بْنِ الصَّيَّاحِ، قَالَ سَمِعْتُ هُنَيْدَةَ الْخُزَاعِيَّ، قَالَ دَخَلْتُ عَلَى أُمِّ الْمُؤْمِنِينَ سَمِعْتُهَا تَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ أَوَّلَ اثْنَيْنِ مِنَ الشَّهْرِ ثُمَّ الْخَمِيسَ ثُمَّ الْخَمِيسَ الَّذِي يَلِيهِ ‏.‏\hadithno{2415}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Hunaidah Al-Khuza'i said:"I entered upon the Mother of the Believers and heard her say: 'The Messenger of Allah used to fast three days of each month: The first Monday of the month, then Thursday, then the following Thursday}}
\hadithdefcmd{nasai}{2416}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ أَبِي النَّضْرِ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ الأَشْجَعِيُّ، - كُوفِيٌّ - عَنْ عَمْرِو بْنِ قَيْسٍ الْمُلاَئِيِّ، عَنِ الْحُرِّ بْنِ الصَّيَّاحِ، عَنْ هُنَيْدَةَ بْنِ خَالِدٍ الْخُزَاعِيِّ، عَنْ حَفْصَةَ، قَالَتْ أَرْبَعٌ لَمْ يَكُنْ يَدَعُهُنَّ النَّبِيُّ صلى الله عليه وسلم صِيَامَ عَاشُورَاءَ وَالْعَشْرَ وَثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ وَرَكْعَتَيْنِ قَبْلَ الْغَدَاةِ ‏.‏\hadithno{2416}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Hafsah said:"There are four things which the Prophet never gave up: Fasting 'Ashura', (fasting during) the ten days, (fasting) three days of each month, and praying two Rak'ahs before Al-Ghadah (Fajr)}}
\hadithdefcmd{nasai}{2417}{أَخْبَرَنِي أَحْمَدُ بْنُ يَحْيَى، عَنْ أَبِي نُعَيْمٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الْحُرِّ بْنِ الصَّيَّاحِ، عَنْ هُنَيْدَةَ بْنِ خَالِدٍ، عَنِ امْرَأَتِهِ، عَنْ بَعْضِ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ تِسْعًا مِنْ ذِي الْحِجَّةِ وَيَوْمَ عَاشُورَاءَ وَثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ أَوَّلَ اثْنَيْنِ مِنَ الشَّهْرِ وَخَمِيسَيْنِ ‏.‏\hadithno{2417}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Hunaidah bin Khalid, from his wife, from one of the wives of the Prophet, that:the Messenger of Allah used to fast nine days of Dhul-Hijjah, the day of 'Ashura', and three days of each month: The first Monday of the month, and two Thursday}}
\hadithdefcmd{nasai}{2418}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُثْمَانَ بْنِ أَبِي صَفْوَانَ الثَّقَفِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الْحُرِّ بْنِ الصَّيَّاحِ، عَنْ هُنَيْدَةَ بْنِ خَالِدٍ، عَنِ امْرَأَتِهِ، عَنْ بَعْضِ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصُومُ الْعَشْرَ وَثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ الاِثْنَيْنِ وَالْخَمِيسَ ‏.‏\hadithno{2418}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hunaidah bin Khalid, from his wife, that one of the wives of the Prophet said:"The Prophet used to fast the ten (days), and three days of each month: Monday and Thursday}}
\hadithdefcmd{nasai}{2419}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ هُنَيْدَةَ الْخُزَاعِيِّ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِصِيَامِ ثَلاَثَةِ أَيَّامٍ أَوَّلِ خَمِيسٍ وَالاِثْنَيْنِ وَالاِثْنَيْنِ ‏.‏\hadithno{2419}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Salamah said:"The Messenger of Allah used to enjoin fasting three days: The first Thursday, and Monday and Monday}}
\hadithdefcmd{nasai}{2420}{أَخْبَرَنَا مَخْلَدُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صِيَامُ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ صِيَامُ الدَّهْرِ وَأَيَّامُ الْبِيضِ صَبِيحَةَ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏"‏ ‏.‏\hadithno{2420}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jarir bin 'Abdullah that the Prophet said:"Fasting three days of each month is fasting for a lifetime, and the shining days of Al-Bid, the thirteenth, fourteenth and fifteenth}}
\hadithdefcmd{nasai}{2421}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِأَرْنَبٍ قَدْ شَوَاهَا فَوَضَعَهَا بَيْنَ يَدَيْهِ فَأَمْسَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَأْكُلْ وَأَمَرَ الْقَوْمَ أَنْ يَأْكُلُوا وَأَمْسَكَ الأَعْرَابِيُّ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا يَمْنَعُكَ أَنْ تَأْكُلَ ‏"‏ ‏.‏ قَالَ إِنِّي أَصُومُ ثَلاَثَةَ أَيَّامٍ مِنَ الشَّهْرِ ‏.‏ قَالَ ‏"‏ إِنْ كُنْتَ صَائِمًا فَصُمِ الْغُرَّ ‏"‏ ‏.‏\hadithno{2421}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"A Bedouin came to the Prophet with a rabbit that he had grilled it and placed it in front of him. The Messenger of Allah refrained from eating, but he told the people to eat. The Bedouin also refrained, and the Prophet said to him: 'What is keeping you from eating?' He said: 'I fast three days of the month.' He said: 'If you was to fast, fast the shining days}}
\hadithdefcmd{nasai}{2422}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ فِطْرٍ، عَنْ يَحْيَى بْنِ سَامٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِي ذَرٍّ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَصُومَ مِنَ الشَّهْرِ ثَلاَثَةَ أَيَّامِ الْبِيضِ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏.‏\hadithno{2422}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah commanded us to fast the three days of Al-Bid, the thirteenth, fourteenth and fifteenth}}
\hadithdefcmd{nasai}{2423}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَامٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِي ذَرٍّ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَصُومَ مِنَ الشَّهْرِ ثَلاَثَةَ أَيَّامِ الْبِيضِ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏.‏\hadithno{2423}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah commanded us to fast three days of Al-Bid, the thirteenth, fourteenth and fifteenth}}
\hadithdefcmd{nasai}{2424}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَامٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، قَالَ سَمِعْتُ أَبَا ذَرٍّ، بِالرَّبَذَةِ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صُمْتَ شَيْئًا مِنَ الشَّهْرِ فَصُمْ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏"‏ ‏.‏\hadithno{2424}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Musa bin Talhah said:"I heard Abu Dharr, at Ar-Rabadhah, saying: 'The Messenger of Allah said: if you want to fast at any time during the monthm then fast on the thirteenth, fourteenth and fifteenth}}
\hadithdefcmd{nasai}{2425}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنْ بَيَانِ بْنِ بِشْرٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنِ ابْنِ الْحَوْتَكِيَّةِ، عَنْ أَبِي ذَرٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏ "‏ عَلَيْكَ بِصِيَامِ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ لَيْسَ مِنْ حَدِيثِ بَيَانٍ وَلَعَلَّ سُفْيَانَ قَالَ حَدَّثَنَا اثْنَانِ فَسَقَطَ الأَلِفُ فَصَارَ بَيَانٌ ‏.‏\hadithno{2425}\hadithgrade{Abu Ghuddah: Hasan Lighairihi; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Dharr that the Prophet said to a man:"You should fast the thirteenth, fourteenth and fifteenth." (Hasan) Abu 'Abdur-Rahman (An-Nasai) said: This is a mistake, it is not a narration of Bayan; perhaps Sufyan said: "It was narrated to us by two (Ithnan)" and the 'Alif was dropped so it became Bayan}}
\hadithdefcmd{nasai}{2426}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا رَجُلاَنِ، مُحَمَّدٌ وَحَكِيمٌ عَنْ مُوسَى بْنِ طَلْحَةَ، عَنِ ابْنِ الْحَوْتَكِيَّةِ، عَنْ أَبِي ذَرٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ رَجُلاً بِصِيَامِ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏.‏\hadithno{2426}\hadithgrade{Abu Ghuddah: Hasan Lighairihi; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Dharr:That the Prophet commanded a man to fast on the thirteenth, fourteenth and fifteenth}}
\hadithdefcmd{nasai}{2427}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، عَنْ بَكْرٍ، عَنْ عِيسَى، عَنْ مُحَمَّدٍ، عَنِ الْحَكَمِ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنِ ابْنِ الْحَوْتَكِيَّةِ، قَالَ قَالَ أُبَىٌّ جَاءَ أَعْرَابِيٌّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَهُ أَرْنَبٌ قَدْ شَوَاهَا وَخُبْزٌ فَوَضَعَهَا بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَالَ إِنِّي وَجَدْتُهَا تَدْمَى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ لاَ يَضُرُّ كُلُوا ‏"‏ ‏.‏ وَقَالَ لِلأَعْرَابِيِّ ‏"‏ كُلْ ‏"‏ ‏.‏ قَالَ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ صَوْمُ مَاذَا ‏"‏ ‏.‏ قَالَ صَوْمُ ثَلاَثَةِ أَيَّامٍ مِنَ الشَّهْرِ ‏.‏ قَالَ ‏"‏ إِنْ كُنْتَ صَائِمًا فَعَلَيْكَ بِالْغُرِّ الْبِيضِ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الصَّوَابُ عَنْ أَبِي ذَرٍّ وَيُشْبِهُ أَنْ يَكُونَ وَقَعَ مِنَ الْكُتَّابِ ذَرٌّ فَقِيلَ أُبَىٌّ ‏.‏\hadithno{2427}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Al-Hawtakiyyah said:"Ubayy said: 'A Bedouin came to the Messenger of Allah, and he had a rabbit that he had grilled and some bread. He placed it before the Prophet then he said: "I found it bleeding." The Messenger of Allah said to his Companions: "It doesn't matter; eat." And he said to the Bedouin: "Eat," He said: "I am fasting." He said: "If you want to fast then you should fast the shining days of Al-Bid: The thirteenth, fourteenth and fifteenth}}
\hadithdefcmd{nasai}{2428}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا الْمُعَافَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا الْقَاسِمُ بْنُ مَعْنٍ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ مُوسَى بْنِ طَلْحَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم بِأَرْنَبٍ وَكَانَ النَّبِيُّ صلى الله عليه وسلم مَدَّ يَدَهُ إِلَيْهَا فَقَالَ الَّذِي جَاءَ بِهَا إِنِّي رَأَيْتُ بِهَا دَمًا ‏.‏ فَكَفَّ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ وَأَمَرَ الْقَوْمَ أَنْ يَأْكُلُوا وَكَانَ فِي الْقَوْمِ رَجُلٌ مُنْتَبِذٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا لَكَ ‏"‏ ‏.‏ قَالَ إِنِّي صَائِمٌ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَهَلاَّ ثَلاَثَ الْبِيضِ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏"‏ ‏.‏\hadithno{2428}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Musa bin Talhah that:a man brought a rabbit to the Prophet, and the prophet stretched out his hand toward it, then the one who had brought it said: "I saw some blood on it," So the Prophet drew his hand back, but he told the people to eat. Among the people there was a man who held back. The Prophet said: "What is the matter with you?" He said: "I am fasting." The Prophet said to him: "Why don't you fast on the three days of Al-Bid, the thirteenth, fourteenth and fifteenth?}}
\hadithdefcmd{nasai}{2429}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَعْلَى، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ مُوسَى بْنِ طَلْحَةَ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِأَرْنَبٍ قَدْ شَوَاهَا رَجُلٌ فَلَمَّا قَدَّمَهَا إِلَيْهِ قَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ رَأَيْتُ بِهَا دَمًا فَتَرَكَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَأْكُلْهَا وَقَالَ لِمَنْ عِنْدَهُ ‏"‏ كُلُوا فَإِنِّي لَوِ اشْتَهَيْتُهَا أَكَلْتُهَا ‏"‏ ‏.‏ وَرَجُلٌ جَالِسٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ادْنُ فَكُلْ مَعَ الْقَوْمِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ فَهَلاَّ صُمْتَ الْبِيضَ ‏"‏ ‏.‏ قَالَ وَمَا هُنَّ قَالَ ‏"‏ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏"‏ ‏.‏\hadithno{2429}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Musa bin Talhah said:"A rabbit that a man had grilled was brought to the Prophet and when he offered it to him he said: 'O Messenger of Allah, I saw some blood on it." The Messenger of Allah did not eat it, but he said to those who were with him: "Eat; if I felt like it, I would have eaten it.' There was a man sitting, and the Messenger of Allah said: 'Come and eat with the people.' He said: 'O Messenger of Allah, I am fasting.' He said: 'Why don't you fast Al-Bid?' He said: 'What are they?' He said: "The thirteenth, fourteenth and fifteenth?}}
\hadithdefcmd{nasai}{2430}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، قَالَ أَنْبَأَنَا أَنَسُ بْنُ سِيرِينَ، عَنْ رَجُلٍ، يُقَالُ لَهُ عَبْدُ الْمَلِكِ يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ بِهَذِهِ الأَيَّامِ الثَّلاَثِ الْبِيضِ وَيَقُولُ ‏ "‏ هُنَّ صِيَامُ الشَّهْرِ ‏"‏ ‏.‏\hadithno{2430}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that a man called 'Abdul-Malik narrated from his father, that:the Messenger of Allah used to enjoin (fasting) these days of Al-Bid and he said: "That is (equivalent to) fasting for the whole month}}
\hadithdefcmd{nasai}{2431}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَمِعْتُ عَبْدَ الْمَلِكِ بْنَ أَبِي الْمِنْهَالِ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُمْ بِصِيَامِ ثَلاَثَةِ أَيَّامِ الْبِيضِ قَالَ ‏ "‏ هِيَ صَوْمُ الشَّهْرِ ‏"‏ ‏.‏\hadithno{2431}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdul-Malik bin Abi Al-Minhai narrated from his father that:the Prophet commanded them to fast the three days of Al-Bid. He said: "That is (equivalent to) fasting for the whole month}}
\hadithdefcmd{nasai}{2432}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا أَنَسُ بْنُ سِيرِينَ، قَالَ حَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ قُدَامَةَ بْنِ مِلْحَانَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا بِصَوْمِ أَيَّامِ اللَّيَالِي الْغُرِّ الْبِيضِ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏.‏\hadithno{2432}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdul-Malik bin Qudamah bin Milhan narrated that his father said:"The Messenger of Allah used to command us to fast the three days with the shining bright nights (Al-Ayam Al-Bid), the thirteenth, fourteenth and fifteenth}}
\hadithdefcmd{nasai}{2433}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنِي سَيْفُ بْنُ عُبَيْدِ اللَّهِ، مِنْ خِيَارِ الْخَلْقِ قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ شَيْبَانَ، عَنْ أَبِي نَوْفَلِ بْنِ أَبِي عَقْرَبٍ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّوْمِ فَقَالَ ‏"‏ صُمْ يَوْمًا مِنَ الشَّهْرِ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ زِدْنِي زِدْنِي ‏.‏ قَالَ ‏"‏ تَقُولُ يَا رَسُولَ اللَّهِ زِدْنِي زِدْنِي يَوْمَيْنِ مِنْ كُلِّ شَهْرٍ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ زِدْنِي زِدْنِي إِنِّي أَجِدُنِي قَوِيًّا ‏.‏ فَقَالَ ‏"‏ زِدْنِي زِدْنِي أَجِدُنِي قَوِيًّا ‏"‏ ‏.‏ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى ظَنَنْتُ أَنَّهُ لَيَرُدُّنِي قَالَ ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏"‏ ‏.‏\hadithno{2433}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Nawfal bin Abi 'Aqrab that his father said:"I asked the Messenger of Allah about fasting and he said: 'Fast one day of the month.' I said: 'Fast one day of the month.' I said: 'O Messenger of Allah, let me do more, let me do more.' He said: 'Let me do more, let mo do more; I am able for it.' Then the Messenger of Allah fell silent until I thought that he was going to refuse my request. Then he said: 'fast three days of each month}}
\hadithdefcmd{nasai}{2434}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا الأَسْوَدُ بْنُ شَيْبَانَ، عَنْ أَبِي نَوْفَلِ بْنِ أَبِي عَقْرَبٍ، عَنْ أَبِيهِ، أَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ الصَّوْمِ فَقَالَ ‏"‏ صُمْ يَوْمًا مِنْ كُلِّ شَهْرٍ ‏"‏ ‏.‏ وَاسْتَزَادَهُ قَالَ بِأَبِي أَنْتَ وَأُمِّي أَجِدُنِي قَوِيًّا فَزَادَهُ قَالَ ‏"‏ صُمْ يَوْمَيْنِ مِنْ كُلِّ شَهْرٍ ‏"‏ ‏.‏ فَقَالَ بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ إِنِّي أَجِدُنِي قَوِيًّا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي أَجِدُنِي قَوِيًّا إِنِّي أَجِدُنِي قَوِيًّا ‏"‏ ‏.‏ فَمَا كَادَ أَنْ يَزِيدَهُ فَلَمَّا أَلَحَّ عَلَيْهِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏"‏ ‏.‏\hadithno{2434}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Nawfal bin Abi 'Aqrab, from his father, that he asked the Prophet about fasting and he said:"Fast one day of each month." He asked him for more, saying: "May my father and mother be ransomed for you, I am able." He said: "Fast two days of each month." He said" May my father and mother be sacrificed for you, O Messenger of Allah, I am able." The Messenger of Allah said: "I am able, I am able." He did not want to increase it, but when I insisted, the Messenger of Allah said: "Fast three days of each month." (Sahih) The end of what the Shaikh had about fasting, all praise is due to Allah the Lord of the worlds}}
