% Auto-generated chapter 5 for ibnmajah
% Hadiths in this chapter: 630

\hadithdefcmd{ibnmajah}{803}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ الطَّنَافِسِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، قَالَ سَمِعْتُ أَبَا حُمَيْدٍ السَّاعِدِيَّ، يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا قَامَ إِلَى الصَّلَاةِ اسْتَقْبَلَ الْقِبْلَةَ وَرَفَعَ يَدَيْهِ وَقَالَ ‏ "‏ اللَّهُ أَكْبَرُ ‏"‏ ‏.‏\hadithno{803}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Muhammad bin ‘Amr bin ‘Ata’ said:“I heard Abu Humaid As-Sa’idi say: ‘When the Messenger of Allah (ﷺ) stood up for prayer, he would face the prayer direction, raise his hands, and say: “Allahu Akbar (Allah is Most Great).”}}
\hadithdefcmd{ibnmajah}{804}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنِي جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، حَدَّثَنِي عَلِيُّ بْنُ عَلِيٍّ الرِّفَاعِيُّ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَسْتَفْتِحُ صَلاَتَهُ يَقُولُ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ وَتَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ‏"‏ ‏.‏\hadithno{804}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) used to start his prayer by saying: ‘Subhanaka Allahumma wa bi hamdika, wa tabarakas-muka, wa ta’ala jadduka, wa la ilaha ghairuka (Glory and praise be to You, O Allah, blessed be Your Name and exalted be Your majesty, none has the right to be worshipped but you).”}}
\hadithdefcmd{ibnmajah}{805}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا كَبَّرَ سَكَتَ بَيْنَ التَّكْبِيرِ وَالْقِرَاءَةِ ‏.‏ قَالَ فَقُلْتُ بِأَبِي أَنْتَ وَأُمِّي أَرَأَيْتَ سُكُوتَكَ بَيْنَ التَّكْبِيرِ وَالْقِرَاءَةِ فَأَخْبِرْنِي مَا تَقُولُ قَالَ ‏ "‏ أَقُولُ اللَّهُمَّ بَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ اللَّهُمَّ نَقِّنِي مِنْ خَطَايَاىَ كَالثَّوْبِ الأَبْيَضِ مِنَ الدَّنَسِ اللَّهُمَّ اغْسِلْنِي مِنْ خَطَايَاىَ بِالْمَاءِ وَالثَّلْجِ وَالْبَرَدِ ‏"‏ ‏.‏\hadithno{805}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“When the Messenger of Allah (ﷺ) said the Takbir (Allah Akbar), he would remain silent between the Takbir and the recitation. I said: ‘May my father and mother be ransomed for you! I noticed that you are silent between the Takbir and the recitation; please tell me what you say then.’ He said: ‘I say: ‘Allahumma ba’id baini wa baina khatayaya kama ba’adta bainal-mashriqi wal-maghrib; Allahumma naqqini min khatayay kath-thawbil abyad minad- danas; Allahummaghsilni min khatayaya bil-ma’i waththalji wal-barad (O Allah, distance me from my sins as You have distanced the east from the west; O Allah purify me of my sins as a white garment is purified of dirt; O Allah, cleanse me of my sins with water and snow and hail).”}}
\hadithdefcmd{ibnmajah}{806}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَبْدُ اللَّهِ بْنُ عِمْرَانَ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا حَارِثَةُ بْنُ أَبِي الرِّجَالِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا افْتَتَحَ الصَّلاَةَ قَالَ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ تَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ‏"‏ ‏.‏\hadithno{806}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Aishah that when the Prophet (ﷺ) started Salat he would say:“Subhanak Allahumma wa bi hamdika, wa tabarakas- muka wa ta’ala jadduka, wa la ilaha ghayruk (Glory and praise is to You, O Allah, blessed is Your Name and exalted is Your majesty, none has the right to be worshipped but You).”}}
\hadithdefcmd{ibnmajah}{807}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَاصِمٍ الْعَنَزِيِّ، عَنِ ابْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ حِينَ دَخَلَ فِي الصَّلاَةِ قَالَ ‏ "‏ اللَّهُ أَكْبَرُ كَبِيرًا اللَّهُ أَكْبَرُ كَبِيرًا - ثَلاَثًا - الْحَمْدُ لِلَّهِ كَثِيرًا الْحَمْدُ لِلَّهِ كَثِيرًا - ثَلاَثًا - سُبْحَانَ اللَّهِ بُكْرَةً وَأَصِيلاً - ثَلاَثَ مَرَّاتٍ - اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الشَّيْطَانِ الرَّجِيمِ مِنْ هَمْزِهِ وَنَفْخِهِ وَنَفْثِهِ ‏"‏ ‏.‏ قَالَ عَمْرٌو هَمْزُهُ الْمُوتَةُ وَنَفْثُهُ الشِّعْرُ وَنَفْخُهُ الْكِبْرُ ‏.‏\hadithno{807}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Jubair bin Mut’im that his father said:“I saw the Messenger of Allah (ﷺ) when he started the prayer. He said: ‘Allahu Akbaru kabiran, Allahu Akbaru kabiran (Allah is the Most Great indeed),’ three times; ‘Al-hamdu Lillahi kathiran, al-hamdu Lillahi kathiran (Much praise is to Allah),’ three times; ‘Subhan Allahi bukratan wa asilan (Glory is to Allah morning and evening),’ three times; ‘Allahumma inni a’udhu bika minash-Shaitanir-rajim, min hamzihi wa nafkhihi wa nafthihi (O Allah, I seek refuge in You from the accursed Satan, from his madness, his poetry, and his pride).”}}
\hadithdefcmd{ibnmajah}{808}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الشَّيْطَانِ الرَّجِيمِ وَهَمْزِهِ وَنَفْخِهِ وَنَفْثِهِ ‏"‏ ‏.‏ قَالَ هَمْزُهُ الْمُوتَةُ وَنَفْثُهُ الشِّعْرُ وَنَفْخُهُ الْكِبْرُ ‏.‏\hadithno{808}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Mas’ud that the Prophet (ﷺ) said:“Allahumma inni a’udhu bika minash-Shaitanir-rajim, wa hamzihi wa nafkhihi wa nafthihi (O Allah, I seek refuge in You from the accursed Satan, from his madness, his pride, and his poetry).”}}
\hadithdefcmd{ibnmajah}{809}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ قَبِيصَةَ بْنِ هُلْبٍ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَؤُمُّنَا فَيَأْخُذُ شِمَالَهُ بِيَمِينِهِ ‏.‏\hadithno{809}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Qabisah bin Hulb that his father said:“The Prophet (ﷺ) used to lead us in prayer, and he would take hold of his left hand with his right.”}}
\hadithdefcmd{ibnmajah}{810}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، ح وَحَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الضَّرِيرُ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، قَالاَ حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يُصَلِّي فَأَخَذَ شِمَالَهُ بِيَمِينِهِ ‏.‏\hadithno{810}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Wa’il bin Hujr said:“I saw the Prophet (ﷺ) performing prayer, and he took hold of his left hand with his right.”}}
\hadithdefcmd{ibnmajah}{811}{حَدَّثَنَا أَبُو إِسْحَاقَ الْهَرَوِيُّ، إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حَاتِمٍ أَنْبَأَنَا هُشَيْمٌ، أَنْبَأَنَا الْحَجَّاجُ بْنُ أَبِي زَيْنَبَ السُّلَمِيُّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ مَرَّ بِي النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَنَا وَاضِعٌ يَدِي الْيُسْرَى عَلَى الْيُمْنَى فَأَخَذَ بِيَدِي الْيُمْنَى فَوَضَعَهَا عَلَى الْيُسْرَى ‏.‏\hadithno{811}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah bin Mas’ud said:“The Prophet (ﷺ) passed by me, and I was putting my left hand on my right. He took hold of my right hand and put it on my left.”}}
\hadithdefcmd{ibnmajah}{812}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ أَبِي الْجَوْزَاءِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَفْتَتِحُ الْقِرَاءَةَ بِـ ‏\{الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ \}‏\hadithno{812}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ), Abu Bakr, ‘Umar and ‘Uthman used to start their recitation with “All praises and thanks are to Allah, the Lord of all that exists. (Al- hamdu Lillahi Rabbil-‘Alamin).’” [1:]}}
\hadithdefcmd{ibnmajah}{813}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، ح وَحَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبُو بَكْرٍ وَعُمَرُ يَفْتَتِحُونَ الْقِرَاءَةَ بِـ ‏\{الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ\}‏\hadithno{813}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ), Abu Bakr and ‘Umar used to start their recitation with ‘All the praises and thanks are to Allah, the Lord of all that exists (Al-hamdu Lillahi Rabbil-‘Alamin).” [1:]}}
\hadithdefcmd{ibnmajah}{814}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَبَكْرُ بْنُ خَلَفٍ، وَعُقْبَةُ بْنُ مُكْرَمٍ، قَالُوا حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا بِشْرُ بْنُ رَافِعٍ، عَنْ أَبِي عَبْدِ اللَّهِ ابْنِ عَمِّ أَبِي هُرَيْرَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَفْتَتِحُ الْقِرَاءَةَ بِـ ‏\{الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ\}‏ ‏.‏\hadithno{814}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) used to start his recitation with ‘All the praises and thanks are to Allah, the Lord of all that exists’ (Al-hamdu Lillahi Rabbil-‘Alamin),’ [1:]}}
\hadithdefcmd{ibnmajah}{815}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ الْجُرَيْرِيِّ، عَنْ قَيْسِ بْنِ عَبَايَةَ، حَدَّثَنِي ابْنُ عَبْدِ اللَّهِ بْنِ الْمُغَفَّلِ، عَنْ أَبِيهِ، قَالَ وَقَلَّمَا رَأَيْتُ رَجُلاً أَشَدَّ عَلَيْهِ فِي الإِسْلاَمِ حَدَثًا مِنْهُ فَسَمِعَنِي وَأَنَا أَقْرَأُ ‏\{بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ\}‏ فَقَالَ أَىْ بُنَىَّ إِيَّاكَ وَالْحَدَثَ فَإِنِّي صَلَّيْتُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَمَعَ أَبِي بَكْرٍ وَمَعَ عُمَرَ وَمَعَ عُثْمَانَ فَلَمْ أَسْمَعْ رَجُلاً مِنْهُمْ يَقُولُهُ فَإِذَا قَرَأْتَ فَقُلِ ‏\{الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ\}‏ ‏.‏\hadithno{815}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abdullah bin Mughaffal narrated from his father and he said:“I have rarely seen a man for whom innovation in Islam was harder to bear than him. He heard me reciting: ‘In the Name of Allah, the Most Gracious, the Most Merciful’ Bismillahir-Rahmanir-Rahim [1:1] and he said: ‘O my son, beware of innovation, for I prayed with the Messenger of Allah (ﷺ), and with Abu Bakr, and with ‘Umar, and with ‘Uthman, and I never heard any of them saying this. When you (begin to) recite, say: ‘All the praises and thanks are to Allah, the Lord of all that exists.’ (Al-hamdu Lillahi Rabbil-‘Alamin).’” [1:]}}
\hadithdefcmd{ibnmajah}{816}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، وَسُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ قُطْبَةَ بْنِ مَالِكٍ، سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقْرَأُ فِي الصُّبْحِ ‏\{وَالنَّخْلَ بَاسِقَاتٍ لَهَا طَلْعٌ نَضِيدٌ \}‏ ‏.‏\hadithno{816}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Qutbah bin Malik that he heard the Prophet (ﷺ) recite:“And tall date palms, with ranged clusters” [50:10] in the Subh}}
\hadithdefcmd{ibnmajah}{817}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ أَصْبَغَ، مَوْلَى عَمْرِو بْنِ حُرَيْثٍ عَنْ عَمْرِو بْنِ حُرَيْثٍ، قَالَ صَلَّيْنَا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَكَانَ يَقْرَأُ فِي الْفَجْرِ فَكَأَنِّي أَسْمَعُ قِرَاءَتَهُ ‏\{فَلاَ أُقْسِمُ بِالْخُنَّسِ الْجَوَارِ الْكُنَّسِ\}‏ ‏.‏\hadithno{817}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Amr bin Huraith said:“I performed prayer with the Prophet (ﷺ) when he was reciting in the Fajr, and it is as if I can hear him reciting: ‘So verily, I swear by the planets that recede. And by the planets that move swiftly and hide themselves.’”[81:]}}
\hadithdefcmd{ibnmajah}{818}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ عَوْفٍ، عَنْ أَبِي الْمِنْهَالِ، عَنْ أَبِي بَرْزَةَ، ح وَحَدَّثَنَا سُوَيْدٌ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، حَدَّثَهُ أَبُو الْمِنْهَالِ، عَنْ أَبِي بَرْزَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَقْرَأُ فِي الْفَجْرِ مَا بَيْنَ السِّتِّينَ إِلَى الْمِائَةِ ‏.‏\hadithno{818}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Barzah that the Messenger of Allah (ﷺ) used to recite between sixty and one hundred (Verses) in Fajr prayer}}
\hadithdefcmd{ibnmajah}{819}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حَجَّاجٍ الصَّوَّافِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، وَعَنْ أَبِي سَلَمَةَ، عَنْ أَبِي قَتَادَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي بِنَا فَيُطِيلُ فِي الرَّكْعَةِ الأُولَى مِنَ الظُّهْرِ وَيُقْصِرُ فِي الثَّانِيَةِ وَكَذَلِكَ فِي الصُّبْحِ ‏.‏\hadithno{819}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Qatadah said:“The Messenger of Allah (ﷺ) used to lead us in prayer, and he would lengthen the first Rak’ah of the Zuhr and shorten the second Rak’ah, and he would do likewise in the Subh.”}}
\hadithdefcmd{ibnmajah}{820}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، قَالَ قَرَأَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي صَلاَةِ الصُّبْحِ بـ ‏\{الْمُؤْمِنُونَ\}‏ فَلَمَّا أَتَى عَلَى ذِكْرِ عِيسَى أَصَابَتْهُ شَرْقَةٌ فَرَكَعَ ‏.‏ يَعْنِي سَعْلَةً ‏.‏\hadithno{820}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin Sa’ib said:“The Messenger of Allah (ﷺ) recited Al-Mu’minun [Al-Mu’minun 23] in the Subh prayer, and when he came to the mention of ‘Eisa, he was overcome with a cough, so he bowed in Ruku’.”}}
\hadithdefcmd{ibnmajah}{821}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا وَكِيعٌ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ مُخَوَّلٍ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْرَأُ فِي صَلاَةِ الصُّبْحِ يَوْمَ الْجُمُعَةِ ‏\{الم * تَنْزِيلُ \}‏ وَ ‏\{هَلْ أَتَى عَلَى الإِنْسَانِ\}‏\hadithno{821}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“For the Subh prayer on Fridays, the Messenger of Allah (ﷺ) used to recite ‘Alif-Lam-Mim. The revelation...’ [32:1] and ‘Has there not been over man...’” [76:]}}
\hadithdefcmd{ibnmajah}{822}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا الْحَارِثُ بْنُ نَبْهَانَ، حَدَّثَنَا عَاصِمُ بْنُ بَهْدَلَةَ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْرَأُ فِي صَلاَةِ الْفَجْرِ يَوْمَ الْجُمُعَةِ ‏\{الم * تَنْزِيلُ\}‏ وَ ‏\{هَلْ أَتَى عَلَى الإِنْسَانِ\}‏\hadithno{822}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mus’ab bin Sa’d that his father said:“For the Fajr prayer on Fridays, the Messenger of Allah (ﷺ) used to recite ‘Alif-Lam-Mim. The revelation...’ [32:1] and ‘Has there not been over man...’” [76:]}}
\hadithdefcmd{ibnmajah}{823}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَقْرَأُ فِي صَلاَةِ الْفَجْرِ يَوْمَ الْجُمُعَةِ ‏\{الم * تَنْزِيلُ\}‏ وَ ‏\{هَلْ أَتَى عَلَى الإِنْسَانِ\}‏\hadithno{823}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that for the Subh prayer on Fridays, the Messenger of Allah (ﷺ) used to recite ‘Alif-Lam-Mim’. The revelation...’[32:1] and ‘Has there not been over man...” [76:]}}
\hadithdefcmd{ibnmajah}{824}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، أَنْبَأَنَا عَمْرُو بْنُ أَبِي قَيْسٍ، عَنْ أَبِي فَرْوَةَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَقْرَأُ فِي صَلاَةِ الْفَجْرِ يَوْمَ الْجُمُعَةِ ‏\{الم * تَنْزِيلُ\}‏ وَ ‏\{هَلَ أَتَى عَلَى الإِنْسَانِ\}‏ ‏.‏ قَالَ إِسْحَاقُ هَكَذَا حَدَّثَنَا عَمْرٌو عَنْ عَبْدِ اللَّهِ لاَ أَشُكُّ فِيهِ ‏.‏\hadithno{824}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that for the Subh prayer on Fridays, the Messenger of Allah (ﷺ) used to recite “Alif-Lam-Mim. The revelation...” [32:1] and “Has there not been over man..” [76:]}}
\hadithdefcmd{ibnmajah}{825}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، حَدَّثَنَا رَبِيعَةُ بْنُ يَزِيدَ، عَنْ قَزَعَةَ، قَالَ سَأَلْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ عَنْ صَلاَةِ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ لَيْسَ لَكَ فِي ذَلِكَ خَيْرٌ ‏.‏ قُلْتُ بَيِّنْ رَحِمَكَ اللَّهُ ‏.‏ قَالَ كَانَتِ الصَّلاَةُ تُقَامُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ الظُّهْرَ فَيَخْرُجُ أَحَدُنَا إِلَى الْبَقِيعِ فَيَقْضِي حَاجَتَهُ وَيَجِيءُ فَيَتَوَضَّأُ فَيَجِدُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الرَّكْعَةِ الأُولَى مِنَ الظُّهْرِ ‏.‏\hadithno{825}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Qaza’ah said:“I asked Abu Sa’eed Al-Khudri about the prayer of the Messenger of Allah (ﷺ). He said: ‘There is nothing good in that for you.’* I said: ‘Explain it, may Allah have mercy on you.’ He said: ‘The Iqamah would be given for the Zuhr prayer for the Messenger of Allah (ﷺ), then one of us would go out to Al- Baqi’, relieve himself, then come back and perform ablution, and he would find the Messenger of Allah (ﷺ) still in the first Rak’ah of Zuhr.’”}}
\hadithdefcmd{ibnmajah}{826}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، قَالَ قُلْتُ لِخَبَّابٍ بِأَىِّ شَىْءٍ كُنْتُمْ تَعْرِفُونَ قِرَاءَةَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الظُّهْرِ وَالْعَصْرِ قَالَ بِاضْطِرَابِ لِحْيَتِهِ ‏.‏\hadithno{826}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Ma’mar said:“I said to Khabbab: ‘How did you recognize that the Messenger of Allah (ﷺ) was reciting in the Zuhr and the ‘Asr?’ He said: ‘From the movement of his beard.’”}}
\hadithdefcmd{ibnmajah}{827}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، حَدَّثَنِي بُكَيْرُ بْنُ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا رَأَيْتُ أَحَدًا أَشْبَهَ صَلاَةً بِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ فُلاَنٍ ‏.‏ قَالَ وَكَانَ يُطِيلُ الأُولَيَيْنِ مِنَ الظُّهْرِ وَيُخَفِّفُ الأُخْرَيَيْنِ وَيُخَفِّفُ الْعَصْرَ ‏.‏\hadithno{827}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“I have never seen anyone whose prayer more closely resembles that of the Messenger of Allah (ﷺ) than so-and-so. He used to lengthen the first two Rak’ah of the Zuhr and shorten the last two Rak’ah, and he used to shorten the ‘Asr.”}}
\hadithdefcmd{ibnmajah}{828}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا الْمَسْعُودِيُّ، حَدَّثَنَا زَيْدٌ الْعَمِّيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ اجْتَمَعَ ثَلاَثُونَ بَدْرِيًّا مِنْ أَصْحَابِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالُوا تَعَالَوْا حَتَّى نَقِيسَ قِرَاءَةَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِيمَا لَمْ يَجْهَرْ فِيهِ مِنَ الصَّلاَةِ ‏.‏ فَمَا اخْتَلَفَ مِنْهُمْ رَجُلاَنِ فَقَاسُوا قِرَاءَتَهُ فِي الرَّكْعَةِ الأُولَى مِنَ الظُّهْرِ بِقَدْرِ ثَلاَثِينَ آيَةً وَفِي الرَّكْعَةِ الأُخْرَى قَدْرَ النِّصْفِ مِنْ ذَلِكَ وَقَاسُوا ذَلِكَ فِي صَلاَةِ الْعَصْرِ عَلَى قَدْرِ النِّصْفِ مِنَ الرَّكْعَتَيْنِ الأُخْرَيَيْنِ مِنَ الظُّهْرِ ‏.‏\hadithno{828}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“Thirty of the Companions of the Messenger of Allah (ﷺ) who had been at Badr came together and said: ‘Come, let us estimate the length of the recitation of the Messenger of Allah (ﷺ) for the prayer in which Qur’an is not recited out aloud.’ No two men among them disagreed, and they estimated the length of his recitation in the first Rak’ah of the Zuhr to be thirty Verses and in the second Rak’ah to be half of that. They estimated his recitation in ‘Asr to be half of the last two Rak’ah of Zuhr.”}}
\hadithdefcmd{ibnmajah}{829}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْرَأُ بِنَا فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنْ صَلاَةِ الظُّهْرِ وَيُسْمِعُنَا الآيَةَ أَحْيَانًا ‏.‏\hadithno{829}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Abdullah bin Abu Qatadah that his father said:“The Messenger of Allah (ﷺ) used to recite when leading us in the first two Rak’ah of the Zuhr prayer, and sometimes he would recite such that we could hear the Verse.”}}
\hadithdefcmd{ibnmajah}{830}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ، عَنْ هَاشِمِ بْنِ الْبَرِيدِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي بِنَا الظُّهْرَ فَنَسْمَعُ مِنْهُ الآيَةَ بَعْدَ الآيَاتِ مِنْ سُورَةِ لُقْمَانَ وَالذَّارِيَاتِ ‏.‏\hadithno{830}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Bara’ bin ‘Azib said:“The Messenger of Allah (ﷺ) used to lead us for the Zuhr, and we would hear him reciting a Verse after the Verses from Surat Luqman (31) and Adh-Dhariyat (51).”}}
\hadithdefcmd{ibnmajah}{831}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُمِّهِ، - قَالَ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ هِيَ لُبَابَةُ - أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْرَأُ فِي الْمَغْرِبِ بِالْمُرْسَلاَتِ عُرْفًا ‏.‏\hadithno{831}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said, narrating from his mother (one of the narrators) Abu Bakr bin Abu Shaibah said:“(She was) Lubabah” that she heard the Messenger of Allah (ﷺ) reciting ‘By the winds sent forth one after another...’[Al-Mursalat (77)] in the Maghrib}}
\hadithdefcmd{ibnmajah}{832}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقْرَأُ فِي الْمَغْرِبِ بِالطُّورِ ‏.‏ قَالَ جُبَيْرٌ فِي غَيْرِ هَذَا الْحَدِيثِ فَلَمَّا سَمِعْتُهُ يَقْرَأُ ‏\{أَمْ خُلِقُوا مِنْ غَيْرِ شَىْءٍ أَمْ هُمُ الْخَالِقُونَ\}‏ إِلَى قَوْلِهِ ‏\{فَلْيَأْتِ مُسْتَمِعُهُمْ بِسُلْطَانٍ مُبِينٍ \}‏ كَادَ قَلْبِي يَطِيرُ ‏.‏\hadithno{832}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Muhammad bin Jubair bin Mut’im that his father said:“I heard the Prophet (ﷺ) reciting At-Tur (52) in the Maghrib.” In a different narration, Jubair said: “And when I heard him recite: ‘Were they created by nothing? Or were they themselves the creators?’ up to: ‘Then let their listener produce some manifest proof’,[52:35-38] it was as if my heart were about to take flight.”}}
\hadithdefcmd{ibnmajah}{833}{حَدَّثَنَا أَحْمَدُ بْنُ بُدَيْلٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَقْرَأُ فِي الْمَغْرِبِ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ\}‏ وَ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ\}‏ ‏.‏\hadithno{833}\hadithgrade{Al-Albani: Shadh; Muhammad Fouad Abd al-Baqi: Shadh; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Prophet (ﷺ) used to recite in the Maghrib: ‘Say: O you disbelievers!’[Al-Kafirun (109)] and ‘Say: He is Allah, (the) One.’”[Al-Ikhlas]}}
\hadithdefcmd{ibnmajah}{834}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، جَمِيعًا عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّهُ صَلَّى مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ الْعِشَاءَ الآخِرَةَ قَالَ فَسَمِعْتُهُ يَقْرَأُ بِالتِّينِ وَالزَّيْتُونِ\hadithno{834}\hadithgrade{Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Bara’ bin ‘Azib that he performed the ‘Isha’, the later, with the Prophet (ﷺ). He said:“I heard him reciting ‘By the fig, and the olive’.”[Al-Tin]}}
\hadithdefcmd{ibnmajah}{835}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، جَمِيعًا عَنْ مِسْعَرٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ، مِثْلَهُ ‏.‏ قَالَ فَمَا سَمِعْتُ إِنْسَانًا، أَحْسَنَ صَوْتًا أَوْ قِرَاءَةً مِنْهُ ‏.‏\hadithno{835}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Adi bin Thabit narrated something similar from Bara’ and said:“I have never heard any man with a better voice or who recites better than him.”}}
\hadithdefcmd{ibnmajah}{836}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، صَلَّى بِأَصْحَابِهِ الْعِشَاءَ فَطَوَّلَ عَلَيْهِمْ فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ اقْرَأْ بِالشَّمْسِ وَضُحَاهَا وَسَبِّحِ اسْمَ رَبِّكَ الأَعْلَى وَاللَّيْلِ إِذَا يَغْشَى وَاقْرَأْ بِسْمِ رَبِّكَ ‏"‏ ‏.‏\hadithno{836}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that Mu’adh bin Jabal led his companions for the ‘Isha’ and he made the prayer too long for them. The Prophet (ﷺ) said:“Recite ‘By the sun and its brightness,’[Al-Shams (91)] ‘Glorify the Name of your Lord, the Most High,’ [Al-A’la (87)] ‘By the night as it envelops,’ [Al-Lail (92)] or, ‘Read! In the Name of your Lord Who has created.’” [Al-‘Alaq]}}
\hadithdefcmd{ibnmajah}{837}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، وَإِسْحَاقُ بْنُ إِسْمَاعِيلَ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ فِيهَا بِفَاتِحَةِ الْكِتَابِ ‏"‏ ‏.‏\hadithno{837}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Ubadah bin Samit that the Prophet (ﷺ) said:“There is no prayer for the one who does not recite Fatihatil-Kitab in it.”}}
\hadithdefcmd{ibnmajah}{838}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، أَنَّ أَبَا السَّائِبِ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَلَّى صَلاَةً لَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ فَهِيَ خِدَاجٌ غَيْرُ تَمَامٍ ‏"‏ ‏.‏ فَقُلْتُ يَا أَبَا هُرَيْرَةَ فَإِنِّي أَكُونُ أَحْيَانًا وَرَاءَ الإِمَامِ ‏.‏ فَغَمَزَ ذِرَاعِي وَقَالَ يَا فَارِسِيُّ اقْرَأْ بِهَا فِي نَفْسِكَ ‏.‏\hadithno{838}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa’ib that he heard Abu Hurairah say:“The Messenger of Allah (ﷺ) said: ‘Whoever performs a prayer in which he does not recite Ummul Qur’an (the Mother of the Qur’an, i.e., Al- Fatihah), it is deficient; not complete.’” I said: ‘O Abu Hurairah, sometimes I am behind the Imam. He pressed my forearm and said: ‘O Persian! Recite it to yourself.’”}}
\hadithdefcmd{ibnmajah}{839}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، ح وَحَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، جَمِيعًا عَنْ أَبِي سُفْيَانَ السَّعْدِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ فِي كُلِّ رَكْعَةٍ بِـ ‏\{الْحَمْدُ لِلَّهِ‏\}‏ وَسُورَةٍ فِي فَرِيضَةٍ أَوْ غَيْرِهَا ‏"‏ ‏.‏\hadithno{839}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) said: ‘There is no prayer for the one who does not recite in every Rak’ah: Al-Hamd (Al-Fatihah) and a Surah whether in an obligatory prayer or another.’”}}
\hadithdefcmd{ibnmajah}{840}{حَدَّثَنَا الْفَضْلُ بْنُ يَعْقُوبَ الْجَزَرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ كُلُّ صَلاَةٍ لاَ يُقْرَأُ فِيهَا بِأُمِّ الْكِتَابِ فَهِيَ خِدَاجٌ ‏"‏ ‏.‏\hadithno{840}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“I heard the Messenger of Allah (ﷺ) say: ‘Every prayer in which the Ummul-Kitab (the Mother of the Book) is not recited is deficient.’”}}
\hadithdefcmd{ibnmajah}{841}{حَدَّثَنَا الْوَلِيدُ بْنُ عَمْرِو بْنِ السُّكَيْنِ، حَدَّثَنَا يُوسُفُ بْنُ يَعْقُوبَ السَّلْعِيُّ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُلُّ صَلاَةٍ لاَ يُقْرَأُ فِيهَا بِفَاتِحَةِ الْكِتَابِ فَهِيَ خِدَاجٌ فَهِيَ خِدَاجٌ ‏"‏ ‏.‏\hadithno{841}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that from ‘Amr bin Shu’aib, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:“Every prayer in which Fatihatil-Kitab (the Opening of the Book) is not recited, it is deficient, it is deficient.”}}
\hadithdefcmd{ibnmajah}{842}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ يَحْيَى، عَنْ يُونُسَ بْنِ مَيْسَرَةَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ سَأَلَهُ رَجُلٌ فَقَالَ أَقْرَأُ وَالإِمَامُ يَقْرَأُ قَالَ سَأَلَ رَجُلٌ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَفِي كُلِّ صَلاَةٍ قِرَاءَةٌ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ وَجَبَ هَذَا ‏.‏\hadithno{842}\hadithgrade{Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Idris Al-Khawlani narrated that a man asked Abu Darda’:“Should I recite when the Imam is reciting?” He said: “A man asked the Prophet (ﷺ) whether there was recitation in every prayer. The Messenger of Allah (ﷺ) said: ‘Yes.’ A man among the people said: ‘It has become obligatory.’”}}
\hadithdefcmd{ibnmajah}{843}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مِسْعَرٍ، عَنْ يَزِيدَ الْفَقِيرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا نَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ خَلْفَ الإِمَامِ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ بِفَاتِحَةِ الْكِتَابِ وَسُورَةٍ وَفِي الأُخْرَيَيْنِ بِفَاتِحَةِ الْكِتَابِ ‏.‏\hadithno{843}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“We used to recite the Opening of the Book and a Surah behind the Imam in the first two Rak’ah of the Zuhr and the ‘Asr, and in the last wo Rak’ah (we would recite) the Opening of the Book.”}}
\hadithdefcmd{ibnmajah}{844}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ بْنِ جَمِيلٍ الْعَتَكِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ سَكْتَتَانِ حَفِظْتُهُمَا عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَأَنْكَرَ ذَلِكَ عِمْرَانُ بْنُ الْحُصَيْنِ فَكَتَبْنَا إِلَى أُبَىِّ بْنِ كَعْبٍ بِالْمَدِينَةِ فَكَتَبَ أَنَّ سَمُرَةَ قَدْ حَفِظَ ‏.‏ قَالَ سَعِيدٌ فَقُلْنَا لِقَتَادَةَ مَا هَاتَانِ السَّكْتَتَانِ قَالَ إِذَا دَخَلَ فِي صَلاَتِهِ وَإِذَا فَرَغَ مِنَ الْقِرَاءَةِ ‏.‏ ثُمَّ قَالَ بَعْدُ وَإِذَا قَرَأَ ‏\{غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ\}‏ ‏.‏ قَالَ وَكَانَ يُعْجِبُهُمْ إِذَا فَرَغَ مِنَ الْقِرَاءَةِ أَنْ يَسْكُتَ حَتَّى يَتَرَادَّ إِلَيْهِ نَفَسُهُ ‏.‏\hadithno{844}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Samurah bin Jundab said:“There are two pauses which I memorized from the Messenger of Allah (ﷺ), but `Imran bin Husain denied that. We wrote to Ubayy bin Ka`b in Al-Madinah, and he wrote that Samurah had indeed memorized them.” (One of the narrators) Sa`eed said: "We said to Qatadah: 'What are these two pauses?' He said: 'When he started his prayer, and when he finished reciting.' Then later he said: 'And when he recited: 'Not (the way) of those who earned your anger, nor of those who went astray.' They used to like (for the Imam) when he had finished reciting to remain silent until he had caught his breath}}
\hadithdefcmd{ibnmajah}{845}{حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خِدَاشٍ، وَعَلِيُّ بْنُ الْحُسَيْنِ بْنِ إِشْكَابَ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، قَالَ قَالَ سَمُرَةُ حَفِظْتُ سَكْتَتَيْنِ فِي الصَّلاَةِ سَكْتَةً قَبْلَ الْقِرَاءَةِ وَسَكْتَةً عِنْدَ الرُّكُوعِ ‏.‏ فَأَنْكَرَ ذَلِكَ عَلَيْهِ عِمْرَانُ بْنُ الْحُصَيْنِ فَكَتَبُوا إِلَى الْمَدِينَةِ إِلَى أُبَىِّ بْنِ كَعْبٍ فَصَدَّقَ سَمُرَةَ ‏.‏\hadithno{845}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Samurah said:“I memorized two pauses in the prayer, a pause before reciting and a pause when bowing. ‘Imran bin Husain denied that, so they wrote to Al-Madinah, to Ubayy bin Ka’b, and he said that Samurah was speaking the truth.”}}
\hadithdefcmd{ibnmajah}{846}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا قَرَأَ فَأَنْصِتُوا وَإِذَا قَالَ ‏\{غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ\}‏ فَقُولُوا آمِينَ وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا وَلَكَ الْحَمْدُ وَإِذَا سَجَدَ فَاسْجُدُوا وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا أَجْمَعِينَ ‏"‏ ‏.‏\hadithno{846}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘The Imam has been appointed to be followed, so when he says Allahu Akbar, then say Allahu Akbar, when he recites, then listen attentively; when he says: Not (the way) of those who earned Your anger, nor of those who went astray,[1:7] then say Amin; when he bows then bow; when he says Sami’ Allahu liman hamidah (Allah hears those who praise Him), then say Allahumma Rabbana wa lakal-hamd (O Allah, our Lord, to You is the praise);” when he prostrates then prostrate; and if he prays sitting down then all of you pray sitting down.’”}}
\hadithdefcmd{ibnmajah}{847}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى الْقَطَّانُ، حَدَّثَنَا جَرِيرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ قَتَادَةَ، عَنْ أَبِي غَلاَّبٍ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ الرَّقَاشِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا قَرَأَ الإِمَامُ فَأَنْصِتُوا فَإِذَا كَانَ عِنْدَ الْقَعْدَةِ فَلْيَكُنْ أَوَّلَ ذِكْرِ أَحَدِكُمُ التَّشَهُّدُ ‏"‏ ‏.‏\hadithno{847}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Musa Al-Ash’ari said:“The Messenger of Allah (ﷺ) said: ‘When the Imam recites, then listen attentively, and if he is sitting (in the prayer) then the first remembrance that anyone of you recites should be the Tashahhud.’”}}
\hadithdefcmd{ibnmajah}{848}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ أُكَيْمَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ صَلَّى النَّبِيُّ ـ صلى الله عليه وسلم ـ بِأَصْحَابِهِ صَلاَةً نَظُنُّ أَنَّهَا الصُّبْحُ فَقَالَ ‏"‏ هَلْ قَرَأَ مِنْكُمْ مِنْ أَحَدٍ ‏"‏ ‏.‏ قَالَ رَجُلٌ أَنَا ‏.‏ قَالَ ‏"‏ إِنِّي أَقُولُ مَا لِي أُنَازَعُ الْقُرْآنَ ‏"‏ ‏.‏\hadithno{848}\hadithgrade{Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Ukaimah said:“I heard Abu Hurairah say: ‘The Prophet (ﷺ) led his Companions in a prayer; we think it was the Subh. He said: “Did anyone among you recite?” A man said: “I did.” He said: “I was saying to myself, what is wrong with me that someone is fighting to wrest the Qur’an from me?”}}
\hadithdefcmd{ibnmajah}{849}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ أُكَيْمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَكَرَ نَحْوَهُ وَزَادَ فِيهِ قَالَ فَسَكَتُوا بَعْدُ فِيمَا جَهَرَ فِيهِ الإِمَامُ ‏.‏\hadithno{849}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) led us in prayer,” and he mentioned a similar report, and added to it, and he said: “And after that they were quiet in the prayers in which the Imam recites aloud.”}}
\hadithdefcmd{ibnmajah}{850}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ جَابِرٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَانَ لَهُ إِمَامٌ فَإِنَّ قِرَاءَةَ الإِمَامِ لَهُ قِرَاءَةٌ ‏"‏ ‏.‏\hadithno{850}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) said: ‘Whoever has an Imam, the recitation of the Imam is his recitation.’”}}
\hadithdefcmd{ibnmajah}{851}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا أَمَّنَ الْقَارِئُ فَأَمِّنُوا فَإِنَّ الْمَلاَئِكَةَ تُؤَمِّنُ فَمَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{851}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When the reciter says Amin, then say Amin, for the angels say Amin, and if a person’s Amin coincides with the Amin of the angels, his previous sins will be forgiven.”}}
\hadithdefcmd{ibnmajah}{852}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ، وَجَمِيلُ بْنُ الْحَسَنِ، قَالاَ حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مَعْمَرٌ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، وَهَاشِمُ بْنُ الْقَاسِمِ الْحَرَّانِيُّ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يُونُسَ، جَمِيعًا عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَمَّنَ الْقَارِئُ فَأَمِّنُوا فَمَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{852}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:The Messenger of Allah (ﷺ) said: “When the reciter says Amin, then say Amin, for if a person’s Amin coincides with the Amin of the angels, his previous sins will be forgiven.”}}
\hadithdefcmd{ibnmajah}{853}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا بِشْرُ بْنُ رَافِعٍ، عَنْ أَبِي عَبْدِ اللَّهِ ابْنِ عَمِّ أَبِي هُرَيْرَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ تَرَكَ النَّاسُ التَّأْمِينَ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا قَالَ ‏"‏ ‏\{غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ\}‏ ‏"‏ ‏.‏ قَالَ ‏"‏ آمِينَ ‏"‏ ‏.‏ حَتَّى يَسْمَعَهَا أَهْلُ الصَّفِّ الأَوَّلِ فَيَرْتَجُّ بِهَا الْمَسْجِدُ ‏.‏\hadithno{853}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The people stopped saying Amin, but when the Messenger of Allah (ﷺ) said ‘Not (the way) of those who earned Your Anger, nor of those who went astray’[1:7] he would say Amin, until the people in the first row could hear it, and the mosque would shake with it}}
\hadithdefcmd{ibnmajah}{854}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا ابْنُ أَبِي لَيْلَى، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ حُجَيَّةَ بْنِ عَدِيٍّ، عَنْ عَلِيٍّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا قَالَ ‏\{وَلاَ الضَّالِّينَ\}‏ قَالَ ‏ "‏ آمِينَ ‏"‏ ‏.‏\hadithno{854}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Ali said:“I heard the Messenger of Allah (ﷺ) saying ‘Amin’ after he said, ‘nor of those who went astray.’[1:]}}
\hadithdefcmd{ibnmajah}{855}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَعَمَّارُ بْنُ خَالِدٍ الْوَاسِطِيُّ، قَالاَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلٍ، عَنْ أَبِيهِ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَلَمَّا قَالَ ‏\{وَلاَ الضَّالِّينَ\}‏ ‏.‏ قَالَ ‏ "‏ آمِينَ ‏"‏ ‏.‏ فَسَمِعْنَاهَا مِنْهُ ‏.‏\hadithno{855}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdul-Jabbar bin Wa’il that his father said:“I performed prayer with the Prophet (ﷺ) and when he said: ‘Nor of those who went astray’,[1:7] he said Amin and we heard that from him.”}}
\hadithdefcmd{ibnmajah}{856}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا حَسَدَتْكُمُ الْيَهُودُ عَلَى شَىْءٍ مَا حَسَدَتْكُمْ عَلَى السَّلاَمِ وَالتَّأْمِينِ ‏"‏ ‏.‏\hadithno{856}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said:“The Jews do not envy you for anything more than they envy you for the Salam and (saying) ‘Amin’.”}}
\hadithdefcmd{ibnmajah}{857}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الْخَلاَّلُ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، وَأَبُو مُسْهِرٍ قَالاَ حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ بْنِ صَالِحِ بْنِ صُبَيْحٍ الْمُرِّيُّ، حَدَّثَنَا طَلْحَةُ بْنُ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا حَسَدَتْكُمُ الْيَهُودُ عَلَى شَىْءٍ مَا حَسَدَتْكُمْ عَلَى آمِينَ فَأَكْثِرُوا مِنْ قَوْلِ آمِينَ ‏"‏ ‏.‏\hadithno{857}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“The Jews do not envy you for anything more than they envy you for the Salam and (saying) Amin, so say Amin a great deal.”}}
\hadithdefcmd{ibnmajah}{858}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَهِشَامُ بْنُ عَمَّارٍ، وَأَبُو عُمَرَ الضَّرِيرُ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا افْتَتَحَ الصَّلاَةَ، رَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ، وَإِذَا رَكَعَ، وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ. وَلاَ يَرْفَعُ بَيْنَ السَّجْدَتَيْنِ ‏.‏\hadithno{858}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“I saw the Messenger of Allah (ﷺ) raising his hands until they were parallel to his shoulders when he started the prayer, and when he bowed in Ruku’, and when he raised his head from Ruku’, but he did not raise them between the two prostrations.”}}
\hadithdefcmd{ibnmajah}{859}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا كَبَّرَ رَفَعَ يَدَيْهِ حَتَّى يَجْعَلَهُمَا قَرِيبًا مِنْ أُذُنَيْهِ، وَإِذَا رَكَعَ صَنَعَ مِثْلَ ذَلِكَ، وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ، صَنَعَ مِثْلَ ذَلِكَ ‏.‏\hadithno{859}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Malik bin Huwairith said that when the Messenger of Allah (ﷺ) said Allahu Akbar, he would raise his hands until they were close to his ears; when he bowed in Ruku’ he did likewise, and when he raised his head from Ruku’ he did likewise}}
\hadithdefcmd{ibnmajah}{860}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَرْفَعُ يَدَيْهِ فِي الصَّلاَةِ حَذْوَ مَنْكِبَيْهِ حِينَ يَفْتَتِحُ الصَّلاَةَ، وَحِينَ يَرْكَعُ، وَحِينَ يَسْجُدُ ‏.‏\hadithno{860}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“I saw the Messenger of Allah (ﷺ) raising his hands during prayer until they were parallel with his shoulders when he started to pray, when he bowed and when he prostrated.”}}
\hadithdefcmd{ibnmajah}{861}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا رِفْدَةُ بْنُ قُضَاعَةَ الْغَسَّانِيُّ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عُمَيْرِ بْنِ حَبِيبٍ قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَرْفَعُ يَدَيْهِ مَعَ كُلِّ تَكْبِيرَةٍ فِي الصَّلاَةِ الْمَكْتُوبَةِ ‏.‏\hadithno{861}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Umair bin Habib said:“The Messenger of Allah (ﷺ) used to raise his hands at every Takbir (saying Allahu Akbar) in the obligatory prayer.”}}
\hadithdefcmd{ibnmajah}{862}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ: حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ: حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ: حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ سَمِعْتُهُ، وَهُوَ فِي عَشَرَةٍ مِنْ أَصْحَابِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ، أَحَدُهُمْ أَبُو قَتَادَةَ بْنُ رِبْعِيٍّ قَالَ أَنَا أَعْلَمُكُمْ بِصَلاَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا قَامَ فِي الصَّلاَةِ اعْتَدَلَ قَائِمًا، وَرَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ، ثُمَّ قَالَ ‏"‏ اللَّهُ أَكْبَرُ ‏"‏ ‏.‏ وَإِذَا أَرَادَ أَنْ يَرْكَعَ، رَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ، فَإِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ رَفَعَ يَدَيْهِ فَاعْتَدَلَ، فَإِذَا قَامَ مِنَ الثِّنْتَيْنِ، كَبَّرَ وَرَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ، كَمَا صَنَعَ حِينَ افْتَتَحَ الصَّلاَةَ ‏.‏\hadithno{862}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Muhammad bin `Amr bin `Ata’ said, concerning Abu Humaid As-Sa`di:“I heard him when he was among ten of the Companions of the Messenger of Allah (ﷺ), one of whom was Abu Qatadah bin Rib`i, saying: ‘I am the most knowledgeable of you about the prayer of the Messenger of Allah (ﷺ). When he stood up for prayer, he stood up straight and raised his hands until they were parallel to his shoulders, then he said: Allahu Akbar. When he wanted to bow in Ruku`, he raised his hands until they were parallel to his shoulders. When he said Sami` Allahu liman hamidah (Allah hears those who praise Him), he raised his hands and stood up straight. When he stood up after two Rak`ah, he said Allahu Akbar and raised his hands until they were parallel to his shoulders, as he did when he started the prayer.’”}}
\hadithdefcmd{ibnmajah}{863}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبَّاسُ بْنُ سَهْلٍ السَّاعِدِيُّ، قَالَ اجْتَمَعَ أَبُو حُمَيْدٍ وَأَبُو أُسَيْدٍ السَّاعِدِيُّ وَسَهْلُ بْنُ سَعْدٍ وَمُحَمَّدُ بْنُ مَسْلَمَةَ فَذَكَرُوا صَلاَةَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ أَبُو حُمَيْدٍ أَنَا أَعْلَمُكُمْ بِصَلاَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَامَ فَكَبَّرَ وَرَفَعَ يَدَيْهِ، ثُمَّ رَفَعَ حِينَ كَبَّرَ لِلرُّكُوعِ، ثُمَّ قَامَ فَرَفَعَ يَدَيْهِ، وَاسْتَوَى حَتَّى رَجَعَ كُلُّ عَظْمٍ إِلَى مَوْضِعِهِ ‏.‏\hadithno{863}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Abbas bin Sahl As-Sa’di said:“Abu Humaid, Abu Usaid As-Sa’di, Sahl bin Sa’d, and Muhammad bin Maslamah came together and spoke about the prayer of the Messenger of Allah (ﷺ). Abu Humaid said: ‘I am the most knowledgeable of you about the prayer of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) stood up and said Allahu Akbar, and raised his hands, then he raised them when he said Allahu Akbar for Ruku’, then he stood up and raised his hands, and stood straight until every bone had returned to its place.’”}}
\hadithdefcmd{ibnmajah}{864}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ أَبُو أَيُّوبَ الْهَاشِمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا قَامَ إِلَى الصَّلاَةِ الْمَكْتُوبَةِ كَبَّرَ وَرَفَعَ يَدَيْهِ حَتَّى يَكُونَا حَذْوَ مَنْكِبَيْهِ وَإِذَا أَرَادَ أَنْ يَرْكَعَ فَعَلَ مِثْلَ ذَلِكَ، وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَعَلَ مِثْلَ ذَلِكَ، وَإِذَا قَامَ مِنَ السَّجْدَتَيْنِ فَعَلَ مِثْلَ ذَلِكَ ‏.‏\hadithno{864}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Ali bin Abu Talib said:“When the Prophet (ﷺ) stood up to offer a prescribed prayer, he said Allahu Akbar and raised his hands until they were parallel to his shoulders. When he wanted to bow he did likewise; when he raised his head from bowing he did likewise; and when he stood up after the two prostrations he did likewise.”}}
\hadithdefcmd{ibnmajah}{865}{حَدَّثَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الْهَاشِمِيُّ، حَدَّثَنَا عُمَرُ بْنُ رِيَاحٍ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَرْفَعُ يَدَيْهِ عِنْدَ كُلِّ تَكْبِيرَةٍ ‏.‏\hadithno{865}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) used to raise his hands at every Takbir (saying Allahu Akbar)}}
\hadithdefcmd{ibnmajah}{866}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَرْفَعُ يَدَيْهِ إِذَا دَخَلَ فِي الصَّلاَةِ، وَإِذَا رَكَعَ ‏.‏\hadithno{866}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) used to raise his hands when he entered prayer, and when he bowed in Ruku’}}
\hadithdefcmd{ibnmajah}{867}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الضَّرِيرُ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ قُلْتُ لأَنْظُرَنَّ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ كَيْفَ يُصَلِّي، فَقَامَ فَاسْتَقْبَلَ الْقِبْلَةَ فَرَفَعَ يَدَيْهِ حَتَّى حَاذَتَا أُذُنَيْهِ، فَلَمَّا رَكَعَ رَفَعَهُمَا مِثْلَ ذَلِكَ، فَلَمَّا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَهُمَا مِثْلَ ذَلِكَ ‏.‏\hadithno{867}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Wa’il bin Hujr said:“I said: ‘I will look at the Messenger of Allah (ﷺ) and see how he performs the prayer.’ He stood up and faced the Qiblah, and raised his hands until they were parallel to his ears. When he bowed, he raised them likewise, and when he raised his head from Ruku’, he raised them likewise.”}}
\hadithdefcmd{ibnmajah}{868}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو حُذَيْفَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ أَبِي الزُّبَيْرِ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، كَانَ إِذَا افْتَتَحَ الصَّلاَةَ رَفَعَ يَدَيْهِ وَإِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَعَلَ مِثْلَ ذَلِكَ وَيَقُولُ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَعَلَ مِثْلَ ذَلِكَ ‏.‏ وَرَفَعَ إِبْرَاهِيمُ بْنُ طَهْمَانَ يَدَيْهِ إِلَى أُذُنَيْهِ ‏.‏\hadithno{868}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Zubair that Jabir bin ‘Abdullah would raise his hands when he began the prayer, and when he bowed, and when he raised (his head) from Ruku’ he would do likewise, and he said:“I saw the Messenger of Allah (ﷺ) doing that.” (One of the narrators) said: “Ibrahim bin Tahman (one of the narrators) raised his hands to his ears.”}}
\hadithdefcmd{ibnmajah}{869}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ بُدَيْلٍ، عَنْ أَبِي الْجَوْزَاءِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا رَكَعَ لَمْ يَشْخَصْ رَأْسَهُ وَلَمْ يُصَوِّبْهُ، وَلَكِنْ بَيْنَ ذَلِكَ ‏.‏\hadithno{869}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“When the Messenger of Allah (ﷺ) bowed, he neither raised his head nor lowered it, rather (he did something) between that.”}}
\hadithdefcmd{ibnmajah}{870}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ أَبِي مَعْمَرٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُجْزِئُ صَلاَةٌ لاَ يُقِيمُ الرَّجُلُ فِيهَا صُلْبَهُ فِي الرُّكُوعِ وَالسُّجُودِ ‏"‏ ‏.‏\hadithno{870}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Mas’ud said:“The Messenger of Allah (ﷺ) said: ‘No prayer is acceptable in which a man does not settle his spine when bowing and when prostrating.’”}}
\hadithdefcmd{ibnmajah}{871}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ بَدْرٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَلِيِّ بْنِ شَيْبَانَ، عَنْ أَبِيهِ، ‏.‏ عَلِيِّ بْنِ شَيْبَانَ - وَكَانَ مِنَ الْوَفْدِ - قَالَ خَرَجْنَا حَتَّى قَدِمْنَا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَبَايَعْنَاهُ وَصَلَّيْنَا خَلْفَهُ فَلَمَحَ بِمُؤْخِرِ عَيْنِهِ رَجُلاً لاَ يُقِيمُ صَلاَتَهُ - يَعْنِي صُلْبَهُ - فِي الرُّكُوعِ وَالسُّجُودِ فَلَمَّا قَضَى النَّبِيُّ ـ صلى الله عليه وسلم ـ الصَّلاَةَ قَالَ ‏ "‏ يَا مَعْشَرَ الْمُسْلِمِينَ لاَ صَلاَةَ لِمَنْ لاَ يُقِيمُ صُلْبَهُ فِي الرُّكُوعِ وَالسُّجُودِ ‏"‏ ‏.‏\hadithno{871}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Ali bin Shaiban who was part of a delegation (to the Prophet (ﷺ)) said:“We set out until we came to the Messenger of Allah (ﷺ), and we gave him our oath of allegiance and performed prayer behind him. He glanced out of the corner of his eye at a man who was not settling his spine when he bowed and prostrated. When the Prophet (ﷺ) finished the prayer, he said: ‘O Muslims, there is no prayer for the one who does not settle his spine when bowing and prostrating.’”}}
\hadithdefcmd{ibnmajah}{872}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ يُوسُفَ الْفِرْيَابِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ عَطَاءٍ، حَدَّثَنَا طَلْحَةُ بْنُ زَيْدٍ، عَنْ رَاشِدٍ، قَالَ سَمِعْتُ وَابِصَةَ بْنَ مَعْبَدٍ، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي فَكَانَ إِذَا رَكَعَ سَوَّى ظَهْرَهُ حَتَّى لَوْ صُبَّ عَلَيْهِ الْمَاءُ لاَسْتَقَرَّ ‏.‏\hadithno{872}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Rashid said:“I heard Wabisah bin Ma’bad saying: ‘I saw the Messenger of Allah (ﷺ) performing prayer, and when he bowed he made his back so straight that if water were poured on it, it would have stayed there.’”}}
\hadithdefcmd{ibnmajah}{873}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، قَالَ رَكَعْتُ إِلَى جَنْبِ أَبِي فَطَبَّقْتُ فَضَرَبَ يَدِي وَقَالَ قَدْ كُنَّا نَفْعَلُ هَذَا، ثُمَّ أُمِرْنَا أَنْ نَرْفَعَ إِلَى الرُّكَبِ ‏.‏\hadithno{873}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Mus’ab bin Sa’d said:“I bowed (in prayer) beside my father, and I put my hands between my knees. He struck my hand and said: ‘We used to do that, then we were commanded to put them on the knees.’”}}
\hadithdefcmd{ibnmajah}{874}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ حَارِثَةَ بْنِ أَبِي الرِّجَالِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَرْكَعُ فَيَضَعُ يَدَيْهِ عَلَى رُكْبَتَيْهِ وَيُجَافِي بِعَضُدَيْهِ ‏.‏\hadithno{874}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) used to bow with his hands on his knees and his upper arms held away from his sides.”}}
\hadithdefcmd{ibnmajah}{875}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ قَالاَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ قَالَ ‏"‏ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{875}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that when the Messenger of Allah (ﷺ) said:“Sami’ Allahu liman hamidah (Allah hears those who praise Him),” he said: “Rabbana wa lakal-hamd (O our Lord, to You is the praise).”}}
\hadithdefcmd{ibnmajah}{876}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا قَالَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{876}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“When the Imam says: ‘Sami’ Allahu liman hamidah (Allah hears those who praise Him),’ say: ‘Rabbana wa lakal-hamd (O our Lord, to You is the praise).’”}}
\hadithdefcmd{ibnmajah}{877}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا قَالَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{877}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that he heard the Messenger of Allah (ﷺ) say:“When the Imam says: ‘Sami’ Allahu liman hamidah (Allah hears those who praise Him),’ say: ‘Allahumma, Rabbana wa lakal-hamd (O Allah! O our Lord! To You is the praise).’”}}
\hadithdefcmd{ibnmajah}{878}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عُبَيْدِ بْنِ الْحَسَنِ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ ‏"‏ ‏.‏\hadithno{878}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Abu Awfa said:“When the Messenger of Allah (ﷺ) raised his head from Ruku’, he said: ‘Sami’ Allahu liman hamidah, Allahumma, Rabbana lakal-hamd, mil’ as-samawati wa mil’ al- ard wa mil’ ma shi’ta min shay’in ba’d (Allah hears those who praise Him. O Allah! O our Lord, to You is the praise as much as fills the heavens, as much as fills the earth and as much as You will after that).’”}}
\hadithdefcmd{ibnmajah}{879}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى السُّدِّيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي عُمَرَ، قَالَ سَمِعْتُ أَبَا جُحَيْفَةَ، يَقُولُ ذُكِرَتِ الْجُدُودُ عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ فِي الصَّلاَةِ فَقَالَ رَجُلٌ جَدُّ فُلاَنٍ فِي الْخَيْلِ ‏.‏ وَقَالَ آخَرُ جَدُّ فُلاَنٍ فِي الإِبِلِ ‏.‏ وَقَالَ آخَرُ جَدُّ فُلاَنٍ فِي الْغَنَمِ ‏.‏ وَقَالَ آخَرُ جَدُّ فُلاَنٍ فِي الرَّقِيقِ ‏.‏ فَلَمَّا قَضَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَلاَتَهُ وَرَفَعَ رَأْسَهُ مِنْ آخِرِ الرَّكْعَةِ قَالَ ‏ "‏ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏ وَطَوَّلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَوْتَهُ بِالْجَدِّ لِيَعْلَمُوا أَنَّهُ لَيْسَ كَمَا يَقُولُونَ ‏.‏\hadithno{879}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu ‘Umar said:“I heard Abu Juhaifah say: Good fortune was mentioned in the presence of the Messenger of Allah (ﷺ) while he was performing prayer. A man said: ‘so-and-so’s fortune is in horses.’ Another man said: ‘So-and-so’s fortune is in camels.’ Another man said: ‘So-and-so’s fortune is in sheep.’ Another man said: ‘So- and-so’s fortune is in slaves.’ While the Messenger of Allah (ﷺ) was finishing his prayer, he raised his head at the end of the last Rak’ah and said: ‘Allahumma Rabbana lakal-hamd mil’ as-samawati wa mil’ al- ard wa mil’ ma shi’ta min shai’in ba’du. Allahumma la mani’ lima a’taita wa la mu’ti lima mana’ta, wa la yanfa’u dhal-jaddi minkal-jadd (Allah hears those who praise Him. O Allah! O our Lord! To You is the praise as much as fills the heavens, as much as fills the earth and as much as You will after that. O Allah, there is none who can withhold what You give, and none who can give what You withhold, and the good fortune of any fortunate person is to no avail against You).’ The Messenger of Allah (ﷺ) elongated the word Jadd (fortune) so that they would know that it was not as they had said.”}}
\hadithdefcmd{ibnmajah}{880}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ الأَصَمِّ، عَنْ عَمِّهِ، يَزِيدَ بْنِ الأَصَمِّ عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا سَجَدَ جَافَى يَدَيْهِ فَلَوْ أَنَّ بَهْمَةً أَرَادَتْ أَنْ تَمُرَّ بَيْنَ يَدَيْهِ لَمَرَّتْ ‏.‏\hadithno{880}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Maimunah that when the Prophet (ﷺ) prostrated, he would hold his forearms away from his sides, such that if a lamb wanted to pass under his arms, it would be able to do so}}
\hadithdefcmd{ibnmajah}{881}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَقْرَمَ الْخُزَاعِيِّ، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ أَبِي بِالْقَاعِ مِنْ نَمِرَةَ فَمَرَّ بِنَا رَكْبٌ فَأَنَاخُوا بِنَاحِيَةِ الطَّرِيقِ فَقَالَ لِي أَبِي كُنْ فِي بَهْمِكَ حَتَّى آتِيَ هَؤُلاَءِ الْقَوْمَ فَأُسَائِلَهُمْ ‏.‏ قَالَ فَخَرَجَ وَجِئْتُ - يَعْنِي دَنَوْتُ - فَإِذَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَحَضَرْتُ الصَّلاَةَ فَصَلَّيْتُ مَعَهُمْ فَكُنْتُ أَنْظُرُ إِلَى عُفْرَتَىْ إِبْطَىْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ كُلَّمَا سَجَدَ‏.‏ ‏ قَالَ ابْنُ مَاجَهْ النَّاسُ يَقُولُونَ عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ وَقَالَ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ يَقُولُ النَّاسُ عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ‏‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَصَفْوَانُ بْنُ عِيسَى، وَأَبُو دَاوُدَ قَالُوا حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَقْرَمَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ‏.‏\hadithno{881}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from (`Ubaidullah bin `Abdullah) bin Aqram Al-Khuza`i that his father said:“I was with my father on the plain in Namirah,* when some riders passed us and made their camels kneel down at the side of the road. My father said to me: ‘Stay with your lambs until I go to those people and see what they want.’ He said: Then he (my father) went out and I came, (i.e., I came near,) then there was the Messenger of Allah (ﷺ), and the time for prayer came so I prayed with them, and I was looking at the whiteness of the armpits of the Messenger of Allah (ﷺ) every time he prostrated.” Ibn Majah said: The people say `Ubaidullah bin `Abdullah, but Abu Bakr bin Abu Shaibah said: "The people say `Abdullah bin `Ubaidullah." Muhammad bin Bashshar said: "`Abdur-Rahman bin Mahdi, Safwan bin `Eisa and Abu Dawud all said: 'Dawud bin Qais narrated to us, from `Ubaidullah bin `Abdullah bin Aqram, from his father, from the Prophet (ﷺ).'" With similar wording}}
\hadithdefcmd{ibnmajah}{882}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا شَرِيكٌ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ إِذَا سَجَدَ وَضَعَ رُكْبَتَيْهِ قَبْلَ يَدَيْهِ وَإِذَا قَامَ مِنَ السُّجُودِ رَفَعَ يَدَيْهِ قَبْلَ رُكْبَتَيْهِ ‏.‏\hadithno{882}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Wa’il bin Hujr said:“I saw the Prophet (ﷺ) when he prostrated and put his knees on the ground before his hands, and when he stood up after prostrating, he took his hands off the ground before his knees.”}}
\hadithdefcmd{ibnmajah}{883}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الضَّرِيرُ، حَدَّثَنَا أَبُو عَوَانَةَ، وَحَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ ‏"‏ ‏.‏\hadithno{883}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said:“I have been commanded to prostrate on seven bones.”}}
\hadithdefcmd{ibnmajah}{884}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعٍ وَلاَ أَكُفَّ شَعَرًا وَلاَ ثَوْبًا ‏"‏ ‏.‏ قَالَ ابْنُ طَاوُسٍ فَكَانَ أَبِي يَقُولُ الْيَدَيْنِ وَالرُّكْبَتَيْنِ وَالْقَدَمَيْنِ وَكَانَ يَعُدُّ الْجَبْهَةَ وَالأَنْفَ وَاحِدًا ‏.‏\hadithno{884}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:The Messenger of Allah (ﷺ) said: “I have been commanded to prostrate on seven, but not to tuck up my hair or my garment.”}}
\hadithdefcmd{ibnmajah}{885}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا سَجَدَ الْعَبْدُ سَجَدَ مَعَهُ سَبْعَةُ آرَابٍ: وَجْهُهُ وَكَفَّاهُ وَرُكْبَتَاهُ وَقَدَمَاهُ ‏"‏ ‏.‏\hadithno{885}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abbas bin ‘Abdul-Muttalib that he heard the Prophet (ﷺ) say:“When a person prostrates, seven parts of his body prostrate with him: His face, his two hands, his two knees, and his two feet.”}}
\hadithdefcmd{ibnmajah}{886}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَبَّادُ بْنُ رَاشِدٍ، عَنِ الْحَسَنِ، حَدَّثَنَا أَحْمَرُ، صَاحِبُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ إِنْ كُنَّا لَنَأْوِي لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِمَّا يُجَافِي بِيَدَيْهِ عَنْ جَنْبَيْهِ إِذَا سَجَدَ ‏.‏\hadithno{886}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ahmar, the Companion of the Messenger of Allah (ﷺ), narrated to us:“We used to feel sorry for the Messenger of Allah (ﷺ) because he took pains to keep his arms away from his sides when he prostrated.”}}
\hadithdefcmd{ibnmajah}{887}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ الْبَجَلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مُوسَى بْنِ أَيُّوبَ الْغَافِقِيِّ، قَالَ سَمِعْتُ عَمِّي، إِيَاسَ بْنَ عَامِرٍ يَقُولُ سَمِعْتُ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، يَقُولُ لَمَّا نَزَلَتْ ‏\{فَسَبِّحْ بِاسْمِ رَبِّكَ الْعَظِيمِ\}‏ قَالَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اجْعَلُوهَا فِي رُكُوعِكُمْ ‏"‏ ‏.‏ فَلَمَّا نَزَلَتْ ‏\{سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى\}‏ قَالَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اجْعَلُوهَا فِي سُجُودِكُمْ ‏"‏ ‏.‏\hadithno{887}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Uqbah bin ‘Amir Al-Juhani said:“When the following was revealed: ‘So glorify the Name of your Lord, the Most Great’,[69:52] the Messenger of Allah (ﷺ) said to us: ‘Say this in your Ruku’.’ And when the following was revealed: ‘Glorify the Name of your Lord, the Most High.’[87:1] the Messenger of Allah (ﷺ) said to us: ‘Say this in your prostrations.’”}}
\hadithdefcmd{ibnmajah}{888}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا ابْنُ لَهِيعَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ أَبِي الأَزْهَرِ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ إِذَا رَكَعَ: ‏"‏ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏"‏ ‏ ثَلاَثَ مَرَّاتٍ، وَإِذَا سَجَدَ قَالَ: ‏"‏ سُبْحَانَ رَبِّيَ الأَعْلَى ‏"‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{888}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hudhaifah bin Al-Yaman that he heard the Messenger of Allah (ﷺ) say when he bowed:“Subhana Rabbiyal-‘Azim (Glory is to my Lord, the Most Great)” three times, and when he prostrated he said: “Subhana Rabbiyal-A’la (Glory is to my Lord the Most High)” three times}}
\hadithdefcmd{ibnmajah}{889}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُكْثِرُ أَنْ يَقُولَ فِي رُكُوعِهِ وَسُجُودِهِ: ‏ "‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ. اللَّهُمَّ اغْفِرْ لِي ‏"‏ ‏.‏ يَتَأَوَّلُ الْقُرْآنَ ‏.‏\hadithno{889}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) often used to say when bowing and prostrating: ‘Subhanak Allahumma wa bi hamdika, Allahummaghfir li (Glory be to You, O Allah, and praise; O Allah forgive me),’ following the command given by the Qur’an.”[Surat An-Nasr]}}
\hadithdefcmd{ibnmajah}{890}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ إِسْحَاقَ بْنِ يَزِيدَ الْهُذَلِيِّ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا رَكَعَ أَحَدُكُمْ فَلْيَقُلْ فِي رُكُوعِهِ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏.‏ ثَلاَثًا فَإِذَا فَعَلَ ذَلِكَ فَقَدْ تَمَّ رُكُوعُهُ وَإِذَا سَجَدَ أَحَدُكُمْ فَلْيَقُلْ فِي سُجُودِهِ سُبْحَانَ رَبِّيَ الأَعْلَى ثَلاَثًا. فَإِذَا فَعَلَ ذَلِكَ فَقَدْ تَمَّ سُجُودُهُ، وَذَلِكَ أَدْنَاهُ ‏"‏ ‏.‏\hadithno{890}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Mas’ud said:“The Messenger of Allah (ﷺ) said: ‘When anyone of you bows, let him say in his bowing: “Subhana Rabbiyal-‘Azim (Glory is to my Lord, the Most Great)” three times; if he does that his bowing will be complete. And when anyone of you prostrates, let him say in his prostration, ‘Subhana Rabbiyal-A’la (Glory if to my Lord, the Most High)” three times; if he does that, his prostration will be complete, and that is the minimum.’”}}
\hadithdefcmd{ibnmajah}{891}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا سَجَدَ أَحَدُكُمْ فَلْيَعْتَدِلْ، وَلاَ يَفْتَرِشْ ذِرَاعَيْهِ افْتِرَاشَ الْكَلْبِ ‏"‏ ‏.‏\hadithno{891}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:The Messenger of Allah (ﷺ) said: “When anyone of you prostrates let him be balanced in prostration, and not spread his arms as a dog does.”}}
\hadithdefcmd{ibnmajah}{892}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ اعْتَدِلُوا فِي السُّجُودِ، وَلاَ يَسْجُدْ أَحَدُكُمْ وَهُوَ بَاسِطٌ ذِرَاعَيْهِ كَالْكَلْبِ ‏"‏ ‏.‏\hadithno{892}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) said:“Be balanced in prostration; none of you should prostrate with his arms spread out like a dog.”}}
\hadithdefcmd{ibnmajah}{893}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ بُدَيْلٍ، عَنْ أَبِي الْجَوْزَاءِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ لَمْ يَسْجُدْ حَتَّى يَسْتَوِيَ قَائِمًا، فَإِذَا سَجَدَ فَرَفَعَ رَأْسَهُ، لَمْ يَسْجُدْ حَتَّى يَسْتَوِيَ جَالِسًا، وَكَانَ يَفْتَرِشُ رِجْلَهُ الْيُسْرَى ‏.‏\hadithno{893}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“When the Messenger of Allah (ﷺ) raised his head from bowing, he would not prostrate until he had stood up straight. When he prostrated, he would raise his head and not prostrate again until he had sat up straight. And he used to spread out his left leg.”}}
\hadithdefcmd{ibnmajah}{894}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُقْعِ بَيْنَ السَّجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{894}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:The Messenger of Allah (ﷺ) said to me: “Do not squat between the two prostrations.”}}
\hadithdefcmd{ibnmajah}{895}{حَدَّثَنَا مُحَمَّدُ بْنُ ثَوَابٍ، حَدَّثَنَا أَبُو نُعَيْمٍ النَّخَعِيُّ، عَنْ أَبِي مَالِكٍ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، وَأَبِي، إِسْحَاقَ عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا عَلِيُّ، لاَ تُقْعِ إِقْعَاءَ الْكَلْبِ ‏"‏ ‏.‏\hadithno{895}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The Prophet (ﷺ) said: ‘O ‘Ali, do not squat like a dog.’”}}
\hadithdefcmd{ibnmajah}{896}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا الْعَلاَءُ أَبُو مُحَمَّدٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ لِي النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا رَفَعْتَ رَأْسَكَ مِنَ السُّجُودِ فَلاَ تُقْعِ كَمَا يُقْعِي الْكَلْبُ ضَعْ أَلْيَتَيْكَ بَيْنَ قَدَمَيْكَ، وَأَلْزِقْ ظَاهِرَ قَدَمَيْكَ بِالأَرْضِ ‏"‏ ‏.‏\hadithno{896}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Prophet (ﷺ) said to me: ‘When you raise your head from prostration, do not squat like a dog. Put your buttocks between your feet and let the tops of your feet touch the ground.”}}
\hadithdefcmd{ibnmajah}{897}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، حَدَّثَنَا الْعَلاَءُ بْنُ الْمُسَيَّبِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ طَلْحَةَ بْنِ يَزِيدَ، عَنْ حُذَيْفَةَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْمُسْتَوْرِدِ بْنِ الأَحْنَفِ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ بَيْنَ السَّجْدَتَيْنِ ‏ "‏ رَبِّ اغْفِرْ لِي، رَبِّ اغْفِرْ لِي ‏"‏ ‏.‏\hadithno{897}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hudhaifah that the Prophet (ﷺ) used to say between the two prostrations:“Rabbighfir li, Rabbighfir li (O Lord forgive me, O Lord forgive me).”}}
\hadithdefcmd{ibnmajah}{898}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا إِسْمَاعِيلُ بْنُ صَبِيحٍ، عَنْ كَامِلٍ أَبِي الْعَلاَءِ، قَالَ سَمِعْتُ حَبِيبَ بْنَ أَبِي ثَابِتٍ، يُحَدِّثُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ بَيْنَ السَّجْدَتَيْنِ فِي صَلاَةِ اللَّيْلِ ‏ "‏ رَبِّ اغْفِرْ لِي وَارْحَمْنِي وَاجْبُرْنِي وَارْزُقْنِي وَارْفَعْنِي ‏"‏ ‏.‏\hadithno{898}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“When praying at night (Qiyamul-Lail), the Messenger of Allah (ﷺ) used to say between the two prostrations: ‘Rabbighfir li warhamni wajburni warzuqni warfa’ni (O Lord, forgive me, have mercy on me, improve my situation, grant me provision and raise me in status).’”}}
\hadithdefcmd{ibnmajah}{899}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كُنَّا إِذَا صَلَّيْنَا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ قُلْنَا السَّلاَمُ عَلَى اللَّهِ قَبْلَ عِبَادِهِ السَّلاَمُ عَلَى جِبْرَائِيلَ وَمِيكَائِيلَ وَعَلَى فُلاَنٍ وَفُلاَنٍ ‏.‏ يَعْنُونَ الْمَلاَئِكَةَ ‏.‏ فَسَمِعَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ لاَ تَقُولُوا السَّلاَمُ عَلَى اللَّهِ فَإِنَّ اللَّهَ هُوَ السَّلاَمُ فَإِذَا جَلَسْتُمْ فَقُولُوا التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ فَإِنَّهُ إِذَا قَالَ ذَلِكَ أَصَابَتْ كُلَّ عَبْدٍ صَالِحٍ فِي السَّمَاءِ وَالأَرْضِ ‏.‏ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا الثَّوْرِيُّ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، وَحُصَيْنٍ، وَأَبِي، هَاشِمٍ وَحَمَّادٍ عَنْ أَبِي وَائِلٍ، وَعَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، وَأَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا قَبِيصَةُ، أَنْبَأَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، وَمَنْصُورٍ، وَحُصَيْنٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، ح قَالَ وَحَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، وَالأَسْوَدِ، وَأَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُعَلِّمُهُمُ التَّشَهُّدَ. فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{899}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdullah bin Mas’ud said:“When we performed prayer with the Prophet (ﷺ) we said: ‘Peace be upon Allah from His slaves, peace be upon Jibra’il and Mika’il and so-and-so and so-and- so.’ The Messenger of Allah (ﷺ) heard us and said: ‘Do not say peace (Salam) be upon Allah, for He is As-Salam. When you sit (during prayer) say: At-Tahiyyatu lillahi was-salawatu wat-tayyibatu; as- salamu ‘alayka ayyuhan-Nabiyyu wa rahmatullahi wa barakatuhu; as- salamu ‘alayna wa ‘ala ‘ibadillahis-salihin (All compliments, prayers and good words are due to Allah; peace be upon you, O Prophet, and the mercy of Allah and His blessings; peace be upon us and upon the righteous slaves of Allah).” For as you say that it will reach every righteous slave in the heavens and on earth. (Then say:) “Ashhadu an la ilaha illallah wa ashhadu anna Muhammadan ‘abduhu wa Rasuluhu (I bear witness that none has the right to be worshipped but Allah, and I bear witness that Muhammad is His slave and Messenger).” (Another chain) with similar wording. (Another chain) that `Abdullah bin Mas`ud said: "The Prophet (ﷺ) used to teach us the Tashahhud." And he mentioned similarly}}
\hadithdefcmd{ibnmajah}{900}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَطَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ فَكَانَ يَقُولُ ‏ "‏ التَّحِيَّاتُ الْمُبَارَكَاتُ الصَّلَوَاتُ الطَّيِّبَاتُ لِلَّهِ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{900}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) used to teach us the Tashah-hud as he used to teach us a Surah of the Qur’an. He used to say: ‘At-Tahiyyatul-Mubarakatus salawatut-tayyibatu lillah; As-salamu ‘alayka ayyuhan-Nabiyyu wa rahmatullahi wa barakatuhu; as-salamu ‘alayna wa ‘ala ‘ibadillahis-salihin. Ashhadu an la ilaha illallah wa ashhadu anna Muhammadan ‘abduhu wa Rasuluhu (All blessed compliments and good prayers are due to Allah; peace be upon you, O Prophet, and the mercy of Allah and His blessings; peace be upon us and upon the righteous slaves of Allah. I bear witness that none has the right to be worshipped but Allah and I bear witness that Muhammad is His slave and Messenger).’”}}
\hadithdefcmd{ibnmajah}{901}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُمَرَ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، وَهِشَامُ بْنُ أَبِي عَبْدِ اللَّهِ، عَنْ قَتَادَةَ، ‏.‏ وَهَذَا حَدِيثُ عَبْدِ الرَّحْمَنِ عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ خَطَبَنَا وَبَيَّنَ لَنَا سُنَّتَنَا وَعَلَّمَنَا صَلاَتَنَا، فَقَالَ ‏ "‏ إِذَا صَلَّيْتُمْ، فَكَانَ عِنْدَ الْقَعْدَةِ، فَلْيَكُنْ مِنْ أَوَّلِ قَوْلِ أَحَدِكُمُ التَّحِيَّاتُ الطَّيِّبَاتُ الصَّلَوَاتُ لِلَّهِ، السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ، سَبْعُ كَلِمَاتٍ هُنَّ تَحِيَّةُ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{901}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Musa Al-Ash’ari:“The Messenger of Allah (ﷺ) addressed us and explained the Sunnah for us, and he taught us our prayer. He said: ‘When you perform prayer, and you are sitting, let the first thing you say be: At-Tahiyyatut-tayyibatus-salawatu lillah; as-salamu ‘alayka ayyuhan-Nabiyyu wa rahmatullahi wa barakatuhu; as-salamu ‘alayna wa ‘ala ‘ibadillahis-salihin. Ashhadu an la ilaha illallah wa ashhadu anna Muhammadan ‘abduhu wa Rasuluhu (All compliments, good words and prayers are due to Allah; peace be upon you, O Prophet, and the mercy of Allah and His blessings; peace be upon us and upon the righteous slaves of Allah. I bear witness that none has the right to be worshipped but Allah and I bear witness that Muhammad is His slave and Messenger). Seven phrases which are the greeting of the prayer.’”}}
\hadithdefcmd{ibnmajah}{902}{حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، قَالاَ حَدَّثَنَا أَيْمَنُ بْنُ نَابِلٍ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ ‏ "‏ بِاسْمِ اللَّهِ وَبِاللَّهِ، التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ لِلَّهِ، السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ، أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ أَسْأَلُ اللَّهَ الْجَنَّةَ، وَأَعُوذُ بِاللَّهِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{902}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) used to teach us the Tashah-hud as he used to teach us a Surah from the Qur’an: ‘Bismillahi wa Billahi; at-tahiyyatu lillahi was-salawatu wat-tayyibatu lillahi; as-salamu ‘alayka ayyuhan- Nabiyyu wa rahmatullahi wa barakatuhu; as-salamu ‘alayna wa ‘ala ‘ibadillahis-salihin. Ashhadu an la ilaha illallah wa ashhadu anna Muhammadan ‘abduhu wa rasuluhu. As’alu Allahal-jannah, wa a’udhu billahi minannar (In the name of Allah and by the grace of Allah. All compliments are due to Allah and all prayers and good words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah and His blessings; peace be upon us and upon the righteous slaves of Allah. I bear witness that none has the right to be worshipped but Allah and I bear witness that Muhammad is His slave and Messenger. I ask Allah for Paradise and I seek refuge with Allah from the Fire).’”}}
\hadithdefcmd{ibnmajah}{903}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَامِرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ هَذَا السَّلاَمُ عَلَيْكَ قَدْ عَرَفْنَاهُ فَكَيْفَ الصَّلاَةُ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ عَبْدِكَ وَرَسُولِكَ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ، وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ ‏"‏ ‏.‏\hadithno{903}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“We said: ‘O Messenger of Allah! We know what it means to send greetings upon you, but what does it mean to send peace and blessings upon you?’ He said: ‘Say: “Allahumma salli ‘ala Muhammadin ‘abdika wa Rasulika kama salayta ‘ala Ibrahima, wa barik ‘ala Muhammad (wa ‘ala ali Muhammadin) kama barakta ‘ala Ibrahima [O Allah, send Your grace, honor and mercy upon Muhammad, Your slave and Messenger, as You sent Your (grace, honour and mercy) upon Ibrahim, and send Your blessings upon Muhammad (and the family of Muhammad) as You sent Your blessings upon Ibrahim].”}}
\hadithdefcmd{ibnmajah}{904}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ ابْنَ أَبِي لَيْلَى، قَالَ لَقِيَنِي كَعْبُ بْنُ عُجْرَةَ فَقَالَ أَلاَ أُهْدِي لَكَ هَدِيَّةً خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقُلْنَا قَدْ عَرَفْنَا السَّلاَمَ عَلَيْكَ فَكَيْفَ الصَّلاَةُ عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى، إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ. اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏\hadithno{904}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Hakam said:“I heard Ibn Abi Laila say: ‘Ka’b bin ‘Ujrah met me and said: “Shall I not give you a gift? The Messenger of Allah (ﷺ) came out to us and we said: ‘We know what it means to send greetings on you, but what does it mean to send peace and blessings upon you?’ He said: ‘Say: Allahumma salli ‘ala Muhammadin wa ‘ala ali Muhammadin, kama sallayta ‘ala Ibrahima, innaka Hamidun Majid; Allahumma barik ‘ala Muhammadin wa ‘ala ali Muhammadin, kama barakta ‘ala Ibrahima, innaka Hamidun Majid (O Allah, send your grace, honour and mercy upon Muhammad and upon the family of Muhammad, as You sent Your grace, honour and mercy upon Ibrahim, You are indeed Praiseworthy, Most Glorious. O Allah, send Your blessings upon Muhammad and the family of Muhammad, as You sent Your blessings upon Ibrahim, You are indeed Praiseworthy, Most Glorious).’”}}
\hadithdefcmd{ibnmajah}{905}{حَدَّثَنَا عَمَّارُ بْنُ طَالُوتَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَبْدِ الْعَزِيزِ الْمَاجِشُونُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ أُمِرْنَا بِالصَّلاَةِ عَلَيْكَ فَكَيْفَ نُصَلِّي عَلَيْكَ فَقَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ، كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ، وَبَارِكْ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ، كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ فِي الْعَالَمِينَ، إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏\hadithno{905}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Humaid As-Sa’di that they said:“O Messenger of Allah! We have been commanded to send peace and blessings upon you. How should we send peace and blessings upon you?” He said: “Say: Allahumma salli ‘ala Muhammadin wa azwajihi wa dhurriyatihi, kama sallayta ‘ala Ibrahim; wa barik ‘ala Muhammadin wa azwajihi wa dhurriyatihi kama barakta ‘ala ali Ibrahim fil-‘alamin, innaka Hamidum Majid (O Allah, send Your grace, honour and mercy upon Muhammad and his wives and offspring, as You sent Your grace, honour and mercy upon Ibrahim. O Allah, send Your blessings upon Muhammad and his wives and offspring, as You sent Your blessings upon the family of Ibrahim among the nations, You are indeed Praiseworthy, Most Glorious).”}}
\hadithdefcmd{ibnmajah}{906}{حَدَّثَنَا الْحُسَيْنُ بْنُ بَيَانٍ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي فَاخِتَةَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ إِذَا صَلَّيْتُمْ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَحْسِنُوا الصَّلاَةَ عَلَيْهِ فَإِنَّكُمْ لاَ تَدْرُونَ لَعَلَّ ذَلِكَ يُعْرَضُ عَلَيْهِ ‏.‏ قَالَ فَقَالُوا لَهُ فَعَلِّمْنَا ‏.‏ قَالَ قُولُوا اللَّهُمَّ اجْعَلْ صَلاَتَكَ وَرَحْمَتَكَ وَبَرَكَاتِكَ عَلَى سَيِّدِ الْمُرْسَلِينَ وَإِمَامِ الْمُتَّقِينَ وَخَاتَمِ النَّبِيِّينَ مُحَمَّدٍ عَبْدِكَ وَرَسُولِكَ إِمَامِ الْخَيْرِ وَقَائِدِ الْخَيْرِ وَرَسُولِ الرَّحْمَةِ اللَّهُمَّ ابْعَثْهُ مَقَامًا مَحْمُودًا يَغْبِطُهُ بِهِ الأَوَّلُونَ وَالآخِرُونَ اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ وَعَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ وَعَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏.‏\hadithno{906}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aswad bin Yazid narrated that ‘Abdullah bin Mas’ud said:“When you send peace and blessings upon the Messenger of Allah (ﷺ), then do it well, for you do not know, that may be shown to him.” They said to him: “Teach us.” He said: “Say: ‘Allahumma aj’al salataka wa rahmataka wa barakatika ‘ala sayyidil-mursalin wa imamil-muttaqin wa khatamin- nabiyyin, Muhammad ‘abdika wa Rasulika imamil-khayri (wa qa’idil- khair), wa Rasulir-Rahmah. Allahummab’athhu maqaman mahmudan yaghbituhu bihil-awwaluna wal-akhirun. Allahumma salli ‘ala Muhammadin wa ‘ala ali Muhammadin kama sallayta ‘ala Ibrahim wa ‘ala ali Ibrahim; Allahumma barik ‘ala Muhammadin wa ‘ala ali Muhammadin kama barakta ‘ala Ibrahim wa ‘ala ali Ibrahim, innaka Hamidum Majid (O Allah, send Your grace, honour, mercy and blessings upon the leader of the Messengers, the imam of the pious and the seal of the Prophets, Muhammad, Your slave and Messenger, the Imam of the good (and the leader) of the good, and the Messenger of mercy. O Allah, raise him to a station of praise and glory that will be the envy of the first and the last. O Allah, send Your grace, honour and mercy upon Muhammad and upon the family of Muhammad, as You sent Your grace, honour and mercy upon Ibrahim, You are indeed Praiseworthy, Most Glorious. O Allah, send blessings upon Muhammad and upon the family of Muhammad as You sent blessings upon Ibrahim and the family of Ibrahim, You are Praiseworthy, Most Glorious).’”}}
\hadithdefcmd{ibnmajah}{907}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ شُعْبَةَ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا مِنْ مُسْلِمٍ يُصَلِّي عَلَىَّ إِلاَّ صَلَّتْ عَلَيْهِ الْمَلاَئِكَةُ مَا صَلَّى عَلَىَّ فَلْيُقِلَّ الْعَبْدُ مِنْ ذَلِكَ أَوْ لِيُكْثِرْ ‏"‏ ‏.‏\hadithno{907}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Asim bin ‘Ubaidullah said:“I heard ‘Abdullah bin ‘Amir bin Rabi’ah narrating from his father that the Prophet (ﷺ) said: “There is no Muslim who sends peace and blessings upon me, but the angels will send peace and blessings upon him as long as he sends peace and blessings upon me. So let a person do a little of that or a lot.”}}
\hadithdefcmd{ibnmajah}{908}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ نَسِيَ الصَّلاَةَ عَلَىَّ خَطِئَ طَرِيقَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{908}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) said: ‘Whoever forgets to send peace and blessings upon me, then he has missed the road to Paradise.’”}}
\hadithdefcmd{ibnmajah}{909}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي حَسَّانُ بْنُ عَطِيَّةَ، حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي عَائِشَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا فَرَغَ أَحَدُكُمْ مِنَ التَّشَهُّدِ الأَخِيرِ فَلْيَتَعَوَّذْ بِاللَّهِ مِنْ أَرْبَعٍ مِنْ عَذَابِ جَهَنَّمَ، وَمِنْ عَذَابِ الْقَبْرِ، وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ، وَمِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{909}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Muhammad bin Abi ‘Aishah said:“I heard Abu Hurairah say that the Messenger of Allah (ﷺ) said: ‘When anyone of you finishes the last Tashah-hud, let him seek refuge with Allah from four things: From the torment of Hell, from the torment of the grave, from the trials of life and death, and from the Fitnah (tribulation) of Masihud-Dajjal.’}}
\hadithdefcmd{ibnmajah}{910}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى الْقَطَّانُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِرَجُلٍ ‏"‏ مَا تَقُولُ فِي الصَّلاَةِ ‏"‏ ‏.‏ قَالَ أَتَشَهَّدُ ثُمَّ أَسْأَلُ اللَّهَ الْجَنَّةَ وَأَعُوذُ بِهِ مِنَ النَّارِ أَمَا وَاللَّهِ مَا أُحْسِنُ دَنْدَنَتَكَ وَلاَ دَنْدَنَةَ مُعَاذٍ ‏.‏ فَقَالَ ‏"‏ حَوْلَهُمَا نُدَنْدِنُ ‏"‏ ‏.‏\hadithno{910}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said to a man: ‘What do you say during your Salat?’ He said: ‘The Tashah-hud, then I ask Allah for Paradise, and I seek refuge with Him from Hell, but I do not understand what you and Mu’adh murmur (during Salat). He said: ‘Our murmuring revolves around the same things.’”}}
\hadithdefcmd{ibnmajah}{911}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عِصَامِ بْنِ قُدَامَةَ، عَنْ مَالِكِ بْنِ نُمَيْرٍ الْخُزَاعِيِّ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَاضِعًا يَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى فِي الصَّلاَةِ وَيُشِيرُ بَإِصْبَعِهِ ‏.‏\hadithno{911}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Malik bin Numair Al-Khuza’i that his father said:“I saw the Prophet (ﷺ) putting his right hand on his right thigh during prayer, and pointing with his finger.”}}
\hadithdefcmd{ibnmajah}{912}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَدْ حَلَّقَ الإِبْهَامَ وَالْوُسْطَى وَرَفَعَ الَّتِي تَلِيهِمَا يَدْعُو بِهَا فِي التَّشَهُّدِ ‏.‏\hadithno{912}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Wa’il bin Hujr said:“I saw the Prophet (ﷺ) making a circle with his thumb and middle finger, and raising the one next to it (the index finger), supplicating with it during the Tashah-hud.”}}
\hadithdefcmd{ibnmajah}{913}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَالْحَسَنُ بْنُ عَلِيٍّ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا جَلَسَ فِي الصَّلاَةِ وَضَعَ يَدَيْهِ عَلَى رُكْبَتَيْهِ وَرَفَعَ إِصْبَعَهُ الْيُمْنَى الَّتِي تَلِي الإِبْهَامَ فَيَدْعُو بِهَا وَالْيُسْرَى عَلَى رُكْبَتِهِ بَاسِطَهَا عَلَيْهَا ‏.‏\hadithno{913}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) used to sit during prayer, putting his hands on his knees and raising his right finger which was next to his thumb, supplicating with it, and with his left hand (spread out) on his knee}}
\hadithdefcmd{ibnmajah}{914}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ حَتَّى يُرَى بَيَاضُ خَدِّهِ ‏ "‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏\hadithno{914}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) used to say the Salam to his right and his left, until the whiteness of his cheek could be seen (saying):“As-salamu ‘alaikum wa rahmatullah (Peace be upon you and the mercy of Allah).”}}
\hadithdefcmd{ibnmajah}{915}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، عَنْ مُصْعَبِ بْنِ ثَابِتِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ ‏.‏\hadithno{915}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Amir bin Sa’d, from his father, that the Messenger of Allah (ﷺ) used to say the Salam to his right and to his left}}
\hadithdefcmd{ibnmajah}{916}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ حَتَّى يُرَى بَيَاضُ خَدِّهِ ‏ "‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏.‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏\hadithno{916}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Ammar bin Yasir said:“The Messenger of Allah (ﷺ) used to say the Salam to his right and to his left, until the whiteness of his cheek could be seen (saying): ‘As-salamu ‘alaikum wa rahmatullah, as-salamu ‘alaikum wa rahmatullah.’”}}
\hadithdefcmd{ibnmajah}{917}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي مُوسَى، قَالَ صَلَّى بِنَا عَلِيٌّ يَوْمَ الْجَمَلِ صَلاَةً ذَكَّرَنَا صَلاَةَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَإِمَّا أَنْ نَكُونَ نَسِينَاهَا وَإِمَّا أَنْ نَكُونَ تَرَكْنَاهَا فَسَلَّمَ عَلَى يَمِينِهِ وَعَلَى شِمَالِهِ ‏.‏\hadithno{917}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Musa said:“Ali led us in prayer on the day of (the battle of) the Camel, in a way that reminded us of the prayer of the Messenger of Allah (ﷺ). Either we had forgotten it or we had abandoned it. He said the Salam to his right and to his left.”}}
\hadithdefcmd{ibnmajah}{918}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدِينِيُّ، أَحْمَدُ بْنُ أَبِي بَكْرٍ حَدَّثَنَا عَبْدُ الْمُهَيْمِنِ بْنُ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سَلَّمَ تَسْلِيمَةً وَاحِدَةً تِلْقَاءَ وَجْهِهِ ‏.‏\hadithno{918}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abdul-Muhaimin bin ‘Abbas bin Sahl bin Sa’d As-Sa’idi narrated from his father, from his grandfather, that the Messenger of Allah (ﷺ) said one Taslim to the front}}
\hadithdefcmd{ibnmajah}{919}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مُحَمَّدٍ الصَّنْعَانِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُسَلِّمُ تَسْلِيمَةً وَاحِدَةً تِلْقَاءَ وَجْهِهِ ‏.‏\hadithno{919}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hisham bin ‘Urwah, from his father, from ‘Aishah, that the Messenger of Allah (saW) used to say one Salam, to the front}}
\hadithdefcmd{ibnmajah}{920}{حَدَّثَنَا مُحَمَّدُ بْنُ الْحَارِثِ الْمِصْرِيُّ، حَدَّثَنَا يَحْيَى بْنُ رَاشِدٍ، عَنْ يَزِيدَ، مَوْلَى سَلَمَةَ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى فَسَلَّمَ مَرَّةً وَاحِدَةً ‏.‏\hadithno{920}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Salamah bin Akwa’ said:“I saw the Messenger of Allah (ﷺ) performing the prayer, and he said one Salam.”}}
\hadithdefcmd{ibnmajah}{921}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو بَكْرٍ الْهُذَلِيُّ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا سَلَّمَ الإِمَامُ فَرُدُّوا عَلَيْهِ ‏"‏ ‏.‏\hadithno{921}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Samurah bin Jundub that the Prophet (ﷺ) said:“When the Imam says the Salam, then respond to him.”}}
\hadithdefcmd{ibnmajah}{922}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَلِيُّ بْنُ الْقَاسِمِ، أَنْبَأَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نُسَلِّمَ عَلَى أَئِمَّتِنَا وَأَنْ يُسَلِّمَ بَعْضُنَا عَلَى بَعْضٍ\hadithno{922}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Samurah bin Jundab said:“The Messenger of Allah (ﷺ) commanded us to greet our Imam with Salam, and to greet one another with Salam.”}}
\hadithdefcmd{ibnmajah}{923}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ حَبِيبِ بْنِ صَالِحٍ، عَنْ يَزِيدَ بْنِ شُرَيْحٍ، عَنْ أَبِي حَىٍّ الْمُؤَذِّنِ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَؤُمُّ عَبْدٌ فَيَخُصَّ نَفْسَهُ بِدَعْوَةٍ دُونَهُمْ فَإِنْ فَعَلَ فَقَدْ خَانَهُمْ ‏"‏ ‏.‏\hadithno{923}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Thawban said:“The Messenger of Allah (ﷺ) said: ‘No person should lead others in prayer, then supplicate only for himself and not for them. If he does that, he has betrayed them.’”}}
\hadithdefcmd{ibnmajah}{924}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، قَالَ حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا سَلَّمَ لَمْ يَقْعُدْ إِلاَّ مِقْدَارَ مَا يَقُولُ ‏ "‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ، تَبَارَكْتَ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{924}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“When the Messenger of Allah (ﷺ) said the Salam, he would sit only for as long as it took to say: ‘Allahumma Antas-Salam wa minkas-salam. Tabarakta ya Dhal-jalali wal- ikram. (O Allah, You are As-Salam, From You is all peace, blessed are You O Possessor of majesty and honour).’”}}
\hadithdefcmd{ibnmajah}{925}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ مَوْلًى، لأُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ إِذَا صَلَّى الصُّبْحَ حِينَ يُسَلِّمُ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ عِلْمًا نَافِعًا، وَرِزْقًا طَيِّبًا، وَعَمَلاً مُتَقَبَّلاً ‏"‏ ‏.‏\hadithno{925}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that when the Prophet (ﷺ) performed the Subh (morning prayer), while he said the Salam, he would say:‘Allahumma inni as’aluka ‘ilman nafi’an, wa rizqan tayyiban, wa ‘amalan mutaqabbalan (O Allah, I ask You for beneficial knowledge, goodly provision and acceptable deeds).’”}}
\hadithdefcmd{ibnmajah}{926}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، وَمُحَمَّدُ بْنُ فُضَيْلٍ، وَأَبُو يَحْيَى التَّيْمِيُّ وَابْنُ الأَجْلَحِ عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ خَصْلَتَانِ لاَ يُحْصِيهِمَا رَجُلٌ مُسْلِمٌ إِلاَّ دَخَلَ الْجَنَّةَ وَهُمَا يَسِيرٌ وَمَنْ يَعْمَلُ بِهِمَا قَلِيلٌ يُسَبِّحُ اللَّهَ فِي دُبُرِ كُلِّ صَلاَةٍ عَشْرًا وَيُكَبِّرُ عَشْرًا وَيَحْمَدُهُ عَشْرًا ‏"‏ ‏.‏ فَرَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَعْقِدُهَا بِيَدِهِ ‏"‏ فَذَلِكَ خَمْسُونَ وَمِائَةٌ بِاللِّسَانِ، وَأَلْفٌ وَخَمْسُمِائَةٍ فِي الْمِيزَانِ، وَإِذَا أَوَى إِلَى فِرَاشِهِ سَبَّحَ وَحَمِدَ وَكَبَّرَ مِائَةً، فَتِلْكَ مِائَةٌ بِاللِّسَانِ، وَأَلْفٌ فِي الْمِيزَانِ، فَأَيُّكُمْ يَعْمَلُ فِي الْيَوْمِ أَلْفَيْنِ وَخَمْسَمِائَةِ سَيِّئَةٍ ‏"‏ ‏.‏ قَالُوا: وَكَيْفَ لاَ يُحْصِيهِمَا قَالَ ‏"‏ يَأْتِي أَحَدَكُمُ الشَّيْطَانُ، وَهُوَ فِي الصَّلاَةِ، فَيَقُولُ: اذْكُرْ كَذَا وَكَذَا، حَتَّى يَنْفَكَّ الْعَبْدُ لاَ يَعْقِلُ، وَيَأْتِيهِ وَهُوَ فِي مَضْجَعِهِ، فَلاَ يَزَالُ يُنَوِّمُهُ حَتَّى يَنَامَ ‏"‏ ‏.‏\hadithno{926}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“The Messenger of Allah (ﷺ) said: ‘There are two characteristics which no Muslim man acquires but he will enter Paradise. They are easy but those who do them are few. At the end of every prayer he should glorify Allah (by saying Subhan Allah) ten times, extol Him (by saying Allahu Akbar) ten times, and praise Him (by saying Al-Hamdu Lillah) ten times.’ I saw the Messenger of Allah (ﷺ) counting them on his hand. ‘That is one hundred and fifty (after all the prayers of the day) on the tongue, and one thousand and five hundred on the Scale. And when he goes to his bed, let him glorify Allah and praise Him and extol Him one hundred times. That will be one hundred on the tongue and one thousand on the Scale. Who among you does two thousand and five hundred evil actions in one day?’ They said: ‘Who would not be keen to do that?’ He said: ‘But the Shaitan comes to anyone of you while he is performing prayer and says: ‘Remember such and such, remember such and such,” until the person becomes distracted and does not understand (what he is saying). And he comes to him when he is in his bed, and makes him sleepy such that he sleeps.’”}}
\hadithdefcmd{ibnmajah}{927}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ بِشْرِ بْنِ عَاصِمٍ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ قِيلَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ - وَرُبَّمَا قَالَ سُفْيَانُ قُلْتُ - يَا رَسُولَ اللَّهِ ذَهَبَ أَهْلُ الأَمْوَالِ وَالدُّثُورِ بِالأَجْرِ يَقُولُونَ كَمَا نَقُولُ وَيُنْفِقُونَ وَلاَ نُنْفِقُ ‏.‏ قَالَ لِي ‏ "‏ أَلاَ أُخْبِرُكُمْ بِأَمْرٍ إِذَا فَعَلْتُمُوهُ أَدْرَكْتُمْ مَنْ قَبْلَكُمْ وَفُتُّمْ مَنْ بَعْدَكُمْ، تَحْمَدُونَ اللَّهَ فِي دُبُرِ كُلِّ صَلاَةٍ وَتُسَبِّحُونَهُ، وَتُكَبِّرُونَهُ ثَلاَثًا وَثَلاَثِينَ، وَثَلاَثًا وَثَلاَثِينَ، وَأَرْبَعًا وَثَلاَثِينَ ‏"‏ ‏.‏ قَالَ سُفْيَانُ لاَ أَدْرِي أَيَّتُهُنَّ أَرْبَعٌ ‏.‏\hadithno{927}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Dharr said:“It was said to the Prophet (ﷺ) and perhaps (one of the narrators) Sufyan said: I said: O Messenger of Allah! Those who have property and wealth have surpassed us in reward. They say the same as we do, and they spend but we do not spend.’ He said to me: ‘Shall I not tell you something which, if you do it, you will catch up with those who have surpassed you and you will excel over those who come after you? Praise Allah (by saying Al- Hamdu Lillah) after every prayer, and glorify Him (by saying Subhan- Allah) and extol Him (by saying Allahu Akbar), thirty-three, thirty- three, and thirty-four times.’” Sufyan said: “I do not know which of them was to be recited thirty-four times.”}}
\hadithdefcmd{ibnmajah}{928}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبٍ، حَدَّثَنَا الأَوْزَاعِيُّ، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي شَدَّادٌ أَبُو عَمَّارٍ، حَدَّثَنَا أَبُو أَسْمَاءَ الرَّحَبِيُّ، حَدَّثَنِي ثَوْبَانُ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا انْصَرَفَ مِنْ صَلاَتِهِ اسْتَغْفَرَ ثَلاَثَ مَرَّاتٍ ثُمَّ يَقُولُ ‏ "‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ تَبَارَكْتَ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{928}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thawban narrated that when he finished his prayer, the Messenger of Allah (ﷺ) would ask for forgiveness three times, then he would say:“Allahumma Antas-Salam wa minkas-salam tabarakta ya Dhal-jalali wal- ikram” (O Allah, You are As-Salam and from You is all peace, Blessed are You O Possessor of majesty and honour).”}}
\hadithdefcmd{ibnmajah}{929}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ قَبِيصَةَ بْنِ هُلْبٍ، عَنْ أَبِيهِ، قَالَ أَمَّنَا النَّبِيُّ ـ صلى الله عليه وسلم ـ فَكَانَ يَنْصَرِفُ عَنْ جَانِبَيْهِ جَمِيعًا ‏.‏\hadithno{929}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Qabisah bin Hulb that his father said:“The Prophet (ﷺ) led us (in prayer), and he used to depart from both sides. (i.e. from either side).”}}
\hadithdefcmd{ibnmajah}{930}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ، عَنِ الأَسْوَدِ، قَالَ قَالَ عَبْدُ اللَّهِ لاَ يَجْعَلَنَّ أَحَدُكُمْ لِلشَّيْطَانِ فِي نَفْسِهِ جُزْءًا يَرَى أَنَّ حَقًّا لِلَّهِ عَلَيْهِ أَنْ لاَ يَنْصَرِفَ إِلاَّ عَنْ يَمِينِهِ قَدْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَكْثَرُ انْصِرَافِهِ عَنْ يَسَارِهِ ‏.‏\hadithno{930}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Aswad said:“ ‘Abdullah (bin Mas’ud) said: ‘None of you should apportion within himself a part (of his prayer) thinking that it is a right of Allah upon him that he must only turn to his right to leave after finishing the prayer. I saw the Messenger of Allah (ﷺ) and most of the time he turned to his left.’”}}
\hadithdefcmd{ibnmajah}{931}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَنْفَتِلُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ فِي الصَّلاَةِ ‏.‏\hadithno{931}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, that his grandfather said:“I saw the Prophet (ﷺ) departing to his right and to his left when he finished the prayer.”}}
\hadithdefcmd{ibnmajah}{932}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الْمَلِكِ بْنِ وَاقِدٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ هِنْدٍ بِنْتِ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا سَلَّمَ قَامَ النِّسَاءُ حِينَ يَقْضِي تَسْلِيمَهُ ثُمَّ يَلْبَثُ فِي مَكَانِهِ يَسِيرًا قَبْلَ أَنْ يَقُومَ ‏.‏\hadithno{932}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Salamah said:“When the Messenger of Allah (ﷺ) said the Salam, the women would stand up when he finished his Taslim, and he would stay where he was for a little while before standing up. (i.e. to depart).”}}
\hadithdefcmd{ibnmajah}{933}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا وُضِعَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ، فَابْدَءُوا بِالْعَشَاءِ ‏"‏ ‏.‏\hadithno{933}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“If food is served and the Iqamah for prayer is given, then start with the food.”}}
\hadithdefcmd{ibnmajah}{934}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وُضِعَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ ‏"‏ ‏.‏ قَالَ فَتَعَشَّى ابْنُ عُمَرَ لَيْلَةً وَهُوَ يَسْمَعُ الإِقَامَةَ ‏.‏\hadithno{934}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Nafi’ that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘If food is served and the Iqamah for prayer is given, then start with the food.” He said: "Ibn 'Umar ate dinner one night while he could hear the Iqamah}}
\hadithdefcmd{ibnmajah}{935}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا حَضَرَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ، فَابْدَءُوا بِالْعَشَاءِ ‏"‏ ‏.‏\hadithno{935}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:“If food is ready and the Iqamah is being given, then start with the food.”}}
\hadithdefcmd{ibnmajah}{936}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي الْمَلِيحِ، قَالَ خَرَجْتُ فِي لَيْلَةٍ مَطِيرَةٍ فَلَمَّا رَجَعْتُ اسْتَفْتَحْتُ فَقَالَ أَبِي مَنْ هَذَا قَالَ أَبُو الْمَلِيحِ ‏.‏ قَالَ لَقَدْ رَأَيْتُنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ الْحُدَيْبِيَةِ وَأَصَابَتْنَا سَمَاءٌ لَمْ تَبُلَّ أَسَافِلَ نِعَالِنَا فَنَادَى مُنَادِي رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلُّوا فِي رِحَالِكُمْ ‏"‏ ‏.‏\hadithno{936}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Malih said:“I went out on a rainy night (for congregational prayer), and when I came back I asked for the door to be opened. My father said: ‘Who is this?’ I said: ‘Abu Malih.’ He said: ‘We were with the Messenger of Allah (ﷺ) at Hudaybiyah and it rained a little, such that the soles of our sandals did not get wet. The announcer of the Messenger of Allah (ﷺ) called out: ‘Perform your prayer at your camps.’”}}
\hadithdefcmd{ibnmajah}{937}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُنَادِي مُنَادِيهِ فِي اللَّيْلَةِ الْمَطِيرَةِ أَوِ اللَّيْلَةِ الْبَارِدَةِ ذَاتِ الرِّيحِ ‏ "‏ صَلُّوا فِي رِحَالِكُمْ ‏"‏ ‏.‏\hadithno{937}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“On rainy nights or on cold windy nights, the Messenger of Allah (ﷺ) would summon his announcer to call out: ‘Perform your prayer at your camps.’”}}
\hadithdefcmd{ibnmajah}{938}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، عَنْ عَبَّادِ بْنِ مَنْصُورٍ، قَالَ سَمِعْتُ عَطَاءً، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ فِي يَوْمِ جُمُعَةٍ مَطِيرَةٍ ‏ "‏ صَلُّوا فِي رِحَالِكُمْ ‏"‏ ‏.‏\hadithno{938}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said, on a Friday that was rainy:“Perform your prayer at your camps.”}}
\hadithdefcmd{ibnmajah}{939}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ الْمُهَلَّبِيُّ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، أَنَّ ابْنَ عَبَّاسٍ، أَمَرَ الْمُؤَذِّنَ أَنْ يُؤَذِّنَ، يَوْمَ الْجُمُعَةِ وَذَلِكَ يَوْمٌ مَطِيرٌ فَقَالَ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏.‏ ثُمَّ قَالَ نَادِ فِي النَّاسِ فَلْيُصَلُّوا فِي بُيُوتِهِمْ ‏.‏ فَقَالَ لَهُ النَّاسُ مَا هَذَا الَّذِي صَنَعْتَ قَالَ قَدْ فَعَلَ هَذَا مَنْ هُوَ خَيْرٌ مِنِّي تَأْمُرُنِي أَنْ أُخْرِجَ النَّاسَ مِنْ بُيُوتِهِمْ فَيَأْتُونِي يَدُوسُونَ الطِّينَ إِلَى رُكَبِهِمْ ‏.‏\hadithno{939}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Abdullah bin Harith bin Nawfal that Ibn ‘Abbas commanded the Mu’adh-dhin to call the Adhan one Friday, which was a rainy day. He said:“Allahu Akbar, Allahu Akbar, Ashhadu an la ilaha illallah, Ashhadu anna Muhammadan Rasulullah (Allah is the Most Great, Allah is Most Great, I bear witness that none has the right to be worshipped but Allah, I bear witness that Muhammad is the Messenger of Allah).” Then he (Ibn ‘Abbas) said: “Proclaim to the people that they should pray in their houses.” The people said to him: “What is this that you have done?” He said: “One who is better than me did that. Are you telling me that I should bring the people out of their houses and make them come to me wading through the mud up to their knees?”}}
\hadithdefcmd{ibnmajah}{940}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عُمَرُ ��ْنُ عُبَيْدٍ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِيهِ، قَالَ كُنَّا نُصَلِّي وَالدَّوَابُّ تَمُرُّ بَيْنَ أَيْدِينَا فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ مِثْلُ مُؤْخِرَةِ الرَّحْلِ تَكُونُ بَيْنَ يَدَىْ أَحَدِكُمْ فَلاَ يَضُرُّهُ مَنْ مَرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏\hadithno{940}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Musa bin Talhah that his father said:“We used to perform prayer while the beasts were passing in front of us. That was mentioned to the Messenger of Allah (ﷺ) and he said: ‘If something like the hand of a saddle* is placed in front of anyone of you, it will not matter whoever passes in front of him.” * It is the piece of wood on the camel saddle which is held on to (to climb onto the camel)}}
\hadithdefcmd{ibnmajah}{941}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ تُخْرَجُ لَهُ حَرْبَةٌ فِي السَّفَرِ، فَيَنْصِبُهَا فَيُصَلِّي إِلَيْهَا ‏.‏\hadithno{941}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“A small spear (Harbah) would be brought out to the Prophet (ﷺ) when he was travelling; he would plant it (in the ground) to perform prayer while facing it.”}}
\hadithdefcmd{ibnmajah}{942}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَصِيرٌ يُبْسَطُ بِالنَّهَارِ وَيَحْتَجِرُهُ بِاللَّيْلِ يُصَلِّي إِلَيْهِ ‏.‏\hadithno{942}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah had a reed mat that he would spread out during the day, and make into a compartment at night, towards which he would perform prayer.”}}
\hadithdefcmd{ibnmajah}{943}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا حُمَيْدُ بْنُ الأَسْوَدِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أُمَيَّةَ، ح وَحَدَّثَنَا عَمَّارُ بْنُ خَالِدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ أَبِي عَمْرِو بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حُرَيْثٍ، عَنْ جَدِّهِ، حُرَيْثِ بْنِ سُلَيْمٍ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ فَلْيَجْعَلْ تِلْقَاءَ وَجْهِهِ شَيْئًا فَإِنْ لَمْ يَجِدْ فَلْيَنْصِبْ عَصًا فَإِنْ لَمْ يَجِدْ فَلْيَخُطَّ خَطًّا ثُمَّ لاَ يَضُرُّهُ مَا مَرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏\hadithno{943}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“When anyone of you performs prayer, let him put something in front of him. If he cannot find anything then let him put a stick. If he cannot find one, then let him draw a line. Then it will not matter if anything passes in front of him.”}}
\hadithdefcmd{ibnmajah}{944}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، قَالَ أَرْسَلُونِي إِلَى زَيْدِ بْنِ خَالِدٍ أَسْأَلُهُ عَنِ الْمُرُورِ، بَيْنَ يَدَىِ الْمُصَلِّي فَأَخْبَرَنِي عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لأَنْ يَقُومَ أَرْبَعِينَ خَيْرٌ لَهُ مِنْ أَنْ يَمُرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏ قَالَ سُفْيَانُ فَلاَ أَدْرِي أَرْبَعِينَ سَنَةً أَوْ شَهْرًا أَوْ صَبَاحًا أَوْ سَاعَةً ‏.‏\hadithno{944}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Busr bin Sa’eed said:“They sent me to Zaid bin Khalid to ask him about passing in front of one who is performing prayer. He told me that the Prophet (ﷺ) said: ‘Waiting for forty is better than passing in front of one who is performing prayer.’” (One of the narrators) Sufyan said: "I do not know if he meant forty years, months, days, or hours}}
\hadithdefcmd{ibnmajah}{945}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ زَيْدَ بْنَ خَالِدٍ، أَرْسَلَ إِلَى أَبِي جُهَيْمٍ الأَنْصَارِيِّ يَسْأَلُهُ مَا سَمِعْتَ مِنَ النَّبِيِّ، ـ صلى الله عليه وسلم ـ فِي الرَّجُلِ يَمُرُّ بَيْنَ يَدَىِ الرَّجُلِ وَهُوَ يُصَلِّي فَقَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لَوْ يَعْلَمُ أَحَدُكُمْ مَالَهُ أَنْ يَمُرَّ بَيْنَ يَدَىْ أَخِيهِ وَهُوَ يُصَلِّي كَانَ لأَنْ يَقِفَ أَرْبَعِينَ - قَالَ لاَ أَدْرِي أَرْبَعِينَ عَامًا أَوْ أَرْبَعِينَ شَهْرًا أَوْ أَرْبَعِينَ يَوْمًا - خَيْرٌ لَهُ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{945}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Busr bin Sa’eed that Zaid bin Khalid sent word to Abu Juhaim Al-Ansari asking him:“What did you hear from the Prophet (ﷺ) about a man when he is performing prayer?” He said: “I heard the Prophet (ﷺ) saying: ‘If anyone of you knew (how great is the sin involved) when he passed in front of his brother who is performing prayer, then waiting for forty’,” (one of the narrators) said: “I do not know if he meant forty years, forty months, or forty days, ‘would be better for him than that.”}}
\hadithdefcmd{ibnmajah}{946}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَوْهَبٍ، عَنْ عَمِّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْ يَعْلَمُ أَحَدُكُمْ مَا لَهُ فِي أَنْ يَمُرَّ بَيْنَ يَدَىْ أَخِيهِ مُعْتَرِضًا فِي الصَّلاَةِ كَانَ لأَنْ يُقِيمَ مِائَةَ عَامٍ خَيْرٌ لَهُ مِنَ الْخَطْوَةِ الَّتِي خَطَاهَا ‏"‏ ‏.‏\hadithno{946}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) said: ‘If anyone of you knew (how great is the sin involved) in passing in front of his brother while he is performing prayer, waiting for one hundred years would be better for him than one step that he takes.’”}}
\hadithdefcmd{ibnmajah}{947}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي بِعَرَفَةَ، فَجِئْتُ أَنَا وَالْفَضْلُ عَلَى أَتَانٍ، فَمَرَرْنَا عَلَى بَعْضِ الصَّفِّ، فَنَزَلْنَا عَنْهَا وَتَرَكْنَاهَا، ثُمَّ دَخَلْنَا فِي الصَّفِّ ‏.‏\hadithno{947}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) was performing prayer at ‘Arafat, and Fadl and I came riding a female donkey. We passed in front of part of the row, then we dismounted and left the donkey, and we came and joined the row.”}}
\hadithdefcmd{ibnmajah}{948}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ مُحَمَّدِ بْنِ قَيْسٍ، - هُوَ قَاصُّ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ - عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي فِي حُجْرَةِ أُمِّ سَلَمَةَ فَمَرَّ بَيْنَ يَدَيْهِ عَبْدُ اللَّهِ أَوْ عُمَرُ بْنُ أَبِي سَلَمَةَ فَقَالَ بِيَدِهِ فَرَجَعَ فَمَرَّتْ زَيْنَبُ بِنْتُ أُمِّ سَلَمَةَ فَقَالَ بِيَدِهِ هَكَذَا فَمَضَتْ فَلَمَّا صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ هُنَّ أَغْلَبُ ‏"‏ ‏.‏\hadithno{948}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Salamah said:“The Prophet (ﷺ) was performing prayer in the house of Umm Salamah, and ‘Abdullah or ‘Umar bin Abu Salamah passed in front of him; he gestured his hand, and he went back. Then Zainab bint Umm Salamah passed in front of him, and he gestured his hand, but she kept going. When the Messenger of Allah (ﷺ) finished his prayer, he said: ‘These (women) are more stubborn.’”}}
\hadithdefcmd{ibnmajah}{949}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا جَابِرُ بْنُ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يَقْطَعُ الصَّلاَةَ الْكَلْبُ الأَسْوَدُ، وَالْمَرْأَةُ الْحَائِضُ ‏"‏ ‏.‏\hadithno{949}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said:“The prayer is severed by a black dog and a woman who has reached the age of menstruation.”}}
\hadithdefcmd{ibnmajah}{950}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ أَبُو طَالِبٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يَقْطَعُ الصَّلاَةَ الْمَرْأَةُ وَالْكَلْبُ وَالْحِمَارُ ‏"‏ ‏.‏\hadithno{950}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The prayer is severed by a woman, a dog and a donkey.”}}
\hadithdefcmd{ibnmajah}{951}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يَقْطَعُ الصَّلاَةَ الْمَرْأَةُ وَالْكَلْبُ وَالْحِمَارُ ‏"‏ ‏.‏\hadithno{951}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin Mughaffal that the Prophet (ﷺ) said:“The prayer is severed by a woman, a dog and a donkey.”}}
\hadithdefcmd{ibnmajah}{952}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ يَقْطَعُ الصَّلاَةَ إِذَا لَمْ يَكُنْ بَيْنَ يَدَىِ الرَّجُلِ مِثْلُ مُؤْخِرَةِ الرَّحْلِ الْمَرْأَةُ وَالْحِمَارُ وَالْكَلْبُ الأَسْوَدُ ‏"‏ ‏.‏ قَالَ قُلْتُ مَا بَالُ الأَسْوَدِ مِنَ الأَحْمَرِ فَقَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَمَا سَأَلْتَنِي فَقَالَ ‏"‏ الْكَلْبُ الأَسْوَدُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{952}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin Samit from Abu Dharr, that the Prophet (ﷺ) said:“The prayer is severed by a woman, a donkey, and a black dog, if there is not something like the handle of a saddle in front of a man.” I (‘Abdullah) said: “What is wrong with a black dog and not a red one?” He (Abu Dharr) said: ‘I asked the Messenger of Allah (ﷺ) the same question, and he said: “The black dog is a Shaitan (satan).”}}
\hadithdefcmd{ibnmajah}{953}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا يَحْيَى أَبُو الْمُعَلَّى، عَنِ الْحَسَنِ الْعُرَنِيِّ، قَالَ ذُكِرَ عِنْدَ ابْنِ عَبَّاسٍ مَا يَقْطَعُ الصَّلاَةَ فَذَكَرُوا الْكَلْبَ وَالْحِمَارَ وَالْمَرْأَةَ فَقَالَ مَا تَقُولُونَ فِي الْجَدْىِ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي يَوْمًا فَذَهَبَ جَدْىٌ يَمُرُّ بَيْنَ يَدَيْهِ فَبَادَرَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْقِبْلَةَ ‏.‏\hadithno{953}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Hasan Al-‘Urani said:‘Mention was made in the presence of Ibn ‘Abbas about what severs the prayer. They mentioned a dog, a donkey and a woman. He said: ‘What do you say about kids (young goats)? The Messenger of Allah (ﷺ) was performing prayer one day, when a kid came and wanted to pass in front of him. The Messenger of Allah (ﷺ) preceded it toward the Qiblah. (to tighten the space and prevent it from passing in front of him).’”}}
\hadithdefcmd{ibnmajah}{954}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ فَلْيُصَلِّ إِلَى سُتْرَةٍ. وَلْيَدْنُ مِنْهَا. وَلاَ يَدَعْ أَحَدًا يَمُرُّ بَيْنَ يَدَيْهِ. فَإِنْ جَاءَ أَحَدٌ يَمُرَّ فَلْيُقَاتِلْهُ. فَإِنَّهُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{954}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Abu Sa’eed that his father said:“The Messenger of Allah (ﷺ) said: ‘When anyone of you performs prayer, let him pray facing towards a Sutrah, and let him get close to it, and not let anyone pass in front of him. If someone comes and wants to pass in front of him, let him fight him, for he is a Shaitan (satan).’”}}
\hadithdefcmd{ibnmajah}{955}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، وَالْحَسَنُ بْنُ دَاوُدَ الْمُنْكَدِرِيُّ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ صَدَقَةَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ يُصَلِّي فَلاَ يَدَعْ أَحَدًا يَمُرُّ بَيْنَ يَدَيْهِ فَإِنْ أَبَى فَلْيُقَاتِلْهُ فَإِنَّ مَعَهُ الْقَرِينَ ‏"‏ ‏.‏ وَقَالَ الْمُنْكَدِرِيُّ فَإِنَّ مَعَهُ الْعُزَّى ‏.‏\hadithno{955}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:“When anyone of you is performing prayer, he should not let anyone pass in front of him. If he insists then let him fight him, for he has a Qarin (devil-companion) with him.”}}
\hadithdefcmd{ibnmajah}{956}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي مِنَ اللَّيْلِ، وَأَنَا مُعْتَرِضَةٌ بَيْنَهُ وَبَيْنَ الْقِبْلَةِ، كَاعْتِرَاضِ الْجِنَازَةِ ‏.‏\hadithno{956}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Aishah:“The Prophet (ﷺ) used to pray at night, and I was laying between him and the prayer direction, as a (body for a) funeral horizontally.’”}}
\hadithdefcmd{ibnmajah}{957}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّهَا، قَالَتْ كَانَ فِرَاشُهَا بِحِيَالِ مَسْجِدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{957}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Zainab bint Umm Salamah that her mother said that her bed was in front of the place where the Messenger of Allah (ﷺ) prostrated}}
\hadithdefcmd{ibnmajah}{958}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، قَالَ حَدَّثَتْنِي مَيْمُونَةُ، زَوْجُ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي وَأَنَا بِحِذَائِهِ وَرُبَّمَا أَصَابَنِي ثَوْبُهُ إِذَا سَجَدَ ‏.‏\hadithno{958}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Maimunah, the wife of the Prophet (ﷺ), said:“The Prophet (ﷺ) used to perform prayer when I was opposite to him, and his garment would sometimes touch me when he prostrated.”}}
\hadithdefcmd{ibnmajah}{959}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنِي أَبُو الْمِقْدَامِ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُصَلَّى خَلْفَ الْمُتَحَدِّثِ وَالنَّائِمِ ‏.‏\hadithno{959}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) forbade performing prayer behind one who is engaged in conversation or one who is sleeping.”}}
\hadithdefcmd{ibnmajah}{960}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُعَلِّمُنَا أَنْ لاَ نُبَادِرَ الإِمَامَ بِالرُّكُوعِ وَالسُّجُودِ وَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا سَجَدَ فَاسْجُدُوا ‏.‏\hadithno{960}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) used to teach us not to bow or prostrate before the Imam; when he says the Takbir then say the Takbir, and when he prostrates, you should prostrate.”}}
\hadithdefcmd{ibnmajah}{961}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَلاَ يَخْشَى الَّذِي يَرْفَعُ رَأْسَهُ قَبْلَ الإِمَامِ أَنْ يُحَوِّلَ اللَّهُ رَأْسَهُ رَأْسَ حِمَارٍ؟ ‏"‏ ‏.‏\hadithno{961}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Does not the one who raises his head before the Imam fear that Allah may turn his head into the head of a donkey?’”}}
\hadithdefcmd{ibnmajah}{962}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو بَدْرٍ، شُجَاعُ بْنُ الْوَلِيدِ عَنْ زِيَادِ بْنِ خَيْثَمَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ دَارِمٍ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي قَدْ بَدَّنْتُ، فَإِذَا رَكَعْتُ فَارْكَعُوا، وَإِذَا رَفَعْتُ فَارْفَعُوا، وَإِذَا سَجَدْتُ فَاسْجُدُوا، وَلاَ أُلْفِيَنَّ رَجُلاً يَسْبِقُنِي إِلَى الرُّكُوعِ، وَلاَ إِلَى السُّجُودِ ‏"‏ ‏.‏\hadithno{962}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Musa said:“The Messenger of Allah (ﷺ) said: ‘I have gained weight, so when I bow, then bow, and when I stand up, then stand up, and when I prostrate, then prostrate. I should never find anyone preceding me in bowing or prostration.’”}}
\hadithdefcmd{ibnmajah}{963}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، ح وَحَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ عَجْلاَنَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُبَادِرُونِي بِالرُّكُوعِ وَلاَ بِالسُّجُودِ، فَمَهْمَا أَسْبِقْكُمْ بِهِ إِذَا رَكَعْتُ، تُدْرِكُونِي بِهِ إِذَا رَفَعْتُ، وَمَهْمَا أَسْبِقْكُمْ بِهِ إِذَا سَجَدْتُ، تُدْرِكُونِي بِهِ إِذَا رَفَعْتُ، إِنِّي قَدْ بَدَّنْتُ ‏"‏ ‏.‏\hadithno{963}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mu’awiyah bin Abu Sufyan said:“The Messenger of Allah (ﷺ) said: ‘Do not bow or prostrate before me. No matter how far ahead of you I bow, you will catch up with me when I stand up, and no matter how far ahead of you I prostrate, you will catch up with me when I raise my head. I have become bulky.’”}}
\hadithdefcmd{ibnmajah}{964}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ بْنِ الْهُدَيْرِ التَّيْمِيُّ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ مِنَ الْجَفَاءِ أَنْ يُكْثِرَ الرَّجُلُ مَسْحَ جَبْهَتِهِ، قَبْلَ الْفَرَاغِ مِنْ صَلاَتِهِ ‏"‏ ‏.‏\hadithno{964}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“It is impolite for a man to wipe his forehead a great deal before he finishes prayer.”}}
\hadithdefcmd{ibnmajah}{965}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو قُتَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، وَإِسْرَائِيلُ بْنُ يُونُسَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تُفَقِّعْ أَصَابِعَكَ وَأَنْتَ فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{965}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Ali that the Messenger of Allah (ﷺ) said:“Do not crack your fingers during the prayer.”}}
\hadithdefcmd{ibnmajah}{966}{حَدَّثَنَا أَبُو سَعِيدٍ، سُفْيَانُ بْنُ زِيَادٍ الْمُؤَدِّبُ حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، عَنِ الْحَسَنِ بْنِ ذَكْوَانَ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُغَطِّيَ الرَّجُلُ فَاهُ فِي الصَّلاَةِ ‏.‏\hadithno{966}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade a man to cover his mouth during the prayer.”}}
\hadithdefcmd{ibnmajah}{967}{حَدَّثَنَا عَلْقَمَةُ بْنُ عَمْرٍو الدَّارِمِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى رَجُلاً قَدْ شَبَّكَ أَصَابِعَهُ فِي الصَّلاَةِ فَفَرَّجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَيْنَ أَصَابِعِهِ ‏.‏\hadithno{967}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ka’b bin ‘Ujrah that the Messenger of Allah (ﷺ) saw a man who had interlocked his fingers during the prayer, so the Messenger of Allah (ﷺ) separated his fingers}}
\hadithdefcmd{ibnmajah}{968}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا تَثَاءَبَ أَحَدُكُمْ فَلْيَضَعْ يَدَهُ عَلَى فِيهِ، وَلاَ يَعْوِي، فَإِنَّ الشَّيْطَانَ يَضْحَكُ مِنْهُ ‏"‏ ‏.‏\hadithno{968}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When anyone of you yawns, let him put his hand over his mouth and not make a sound, because Satan laughs at him.”}}
\hadithdefcmd{ibnmajah}{969}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، عَنْ شَرِيكٍ، عَنْ أَبِي الْيَقْظَانِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْبُزَاقُ وَالْمُخَاطُ وَالْحَيْضُ وَالنُّعَاسُ فِي الصَّلاَةِ مِنَ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{969}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Adi bin Thabit, from his father, from his grandfather, that the Prophet (ﷺ) said:“Spitting, blowing one’s nose, menstruating and drowsiness during the prayer are from Satan.”}}
\hadithdefcmd{ibnmajah}{970}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَجَعْفَرُ بْنُ عَوْنٍ، عَنِ الإِفْرِيقِيِّ، عَنْ عِمْرَانَ بْنِ عَبْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ثَلاَثَةٌ لاَ تُقْبَلُ لَهُمْ صَلاَةٌ الرَّجُلُ يَؤُمُّ الْقَوْمَ وَهُمْ لَهُ كَارِهُونَ، وَالرَّجُلُ لاَ يَأْتِي الصَّلاَةَ إِلاَّ دِبَارًا - يَعْنِي بَعْدَ مَا يَفُوتُهُ الْوَقْتُ - وَمَنِ اعْتَبَدَ مُحَرَّرًا ‏"‏ ‏.‏\hadithno{970}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“The Messenger of Allah (ﷺ) said: ‘There are three whose prayer are not accepted: A man who leads people while they do not like him; a man who does not come to prayer until its end – meaning after its time has expired – and one who enslaves a freed person.’”}}
\hadithdefcmd{ibnmajah}{971}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ هَيَّاجٍ، حَدَّثَنَا يَحْيَى بْنُ عَبْدِ الرَّحْمَنِ الأَرْحَبِيُّ، حَدَّثَنَا عُبَيْدَةُ بْنُ الأَسْوَدِ، عَنِ الْقَاسِمِ بْنِ الْوَلِيدِ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ ثَلاَثَةٌ لاَ تَرْتَفِعُ صَلاَتُهُمْ فَوْقَ رُءُوسِهِمْ شِبْرًا رَجُلٌ أَمَّ قَوْمًا وَهُمْ لَهُ كَارِهُونَ، وَامْرَأَةٌ بَاتَتْ وَزَوْجُهَا عَلَيْهَا سَاخِطٌ وَأَخَوَانِ مُتَصَارِمَانِ ‏"‏ ‏.‏\hadithno{971}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“There are three whose prayer do not rise more than a hand span above their heads: A man who leads people (in prayer) when they do not like him; a woman who has spent the night with her husband angry with her; and two brothers who have severed contact with one another.”}}
\hadithdefcmd{ibnmajah}{972}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الرَّبِيعُ بْنُ بَدْرٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَمْرِو بْنِ جَرَادٍ عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اثْنَانِ، فَمَا فَوْقَهُمَا، جَمَاعَةٌ ‏"‏ ‏.‏\hadithno{972}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Musa Al-Ash’ari said:“The Messenger of Allah (ﷺ) said: ‘Two or more people are a congregation.’”}}
\hadithdefcmd{ibnmajah}{973}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عَاصِمٌ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ فَقَامَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي مِنَ اللَّيْلِ فَقُمْتُ عَنْ يَسَارِهِ فَأَخَذَ بِيَدِي فَأَقَامَنِي عَنْ يَمِينِهِ ‏.‏\hadithno{973}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“I stayed overnight with my maternal aunt Maimunah, and the Prophet (ﷺ) got up during the night to perform prayer. So I got up and stood on his left. He took me by the hand and made me stand on his right.”}}
\hadithdefcmd{ibnmajah}{974}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، حَدَّثَنَا شُرَحْبِيلُ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي الْمَغْرِبَ، فَجِئْتُ فَقُمْتُ عَنْ يَسَارِهِ، فَأَقَامَنِي عَنْ يَمِينِهِ ‏.‏\hadithno{974}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Shurahbil said:“I heard Jabir bin ‘Abdullah say: ‘The Messenger of Allah (ﷺ) was performing Maghrib, and I came and stood on his left, but he made me stand on his right.’”}}
\hadithdefcmd{ibnmajah}{975}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُخْتَارِ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَنَسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِامْرَأَةٍ مِنْ أَهْلِهِ، وَبِي، فَأَقَامَنِي عَنْ يَمِينِهِ وَصَلَّتِ الْمَرْأَةُ خَلْفَنَا ‏.‏\hadithno{975}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:“The Messenger of Allah (ﷺ) led a woman of his household and myself in prayer. I stood to his right and the woman stood behind us.”}}
\hadithdefcmd{ibnmajah}{976}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَمْسَحُ مَنَاكِبَنَا فِي الصَّلاَةِ وَيَقُولُ ‏ "‏ لاَ تَخْتَلِفُوا، فَتَخْتَلِفَ قُلُوبُكُمْ، لِيَلِيَنِي مِنْكُمْ أُولُو الأَحْلاَمِ وَالنُّهَى، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏\hadithno{976}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Mas’ud Al-Ansari said:“The Messenger of Allah (ﷺ) used to gently pat our shoulders (to make sure the row was straight) at the time of prayer, saying: ‘Keep (the rows) straight, do not differ from one another lest your hearts should suffer from discord. Let those who are forbearing and wise stand closest to me, then those who are next to them, then those who are next to them.’”}}
\hadithdefcmd{ibnmajah}{977}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ يُحِبُّ أَنْ يَلِيَهُ الْمُهَاجِرُونَ وَالأَنْصَارُ، لِيَأْخُذُوا عَنْهُ ‏.‏\hadithno{977}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:“The Messenger of Allah (ﷺ) liked the Muhajirun and Ansar to stand closest to him, so that they could learn from him.”}}
\hadithdefcmd{ibnmajah}{978}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ أَبِي الأَشْهَبِ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى فِي أَصْحَابِهِ تَأَخُّرًا فَقَالَ ‏ "‏ تَقَدَّمُوا فَأْتَمُّوا بِي، وَلْيَأْتَمَّ بِكُمْ مَنْ بَعْدَكُمْ، لاَ يَزَالُ قَوْمٌ يَتَأَخَّرُونَ حَتَّى يُؤَخِّرَهُمُ اللَّهُ ‏"‏ ‏.‏\hadithno{978}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) saw that some of his Companions tended to stand in the rear, so he said:“Come forward and follow me, and let those who are behind you follow your lead. If people continue to lag behind, Allah will put them back.”}}
\hadithdefcmd{ibnmajah}{979}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَنَا وَصَاحِبٌ لِي فَلَمَّا أَرَدْنَا الاِنْصِرَافَ قَالَ لَنَا ‏ "‏ إِذَا حَضَرَتِ الصَّلاَةُ فَأَذِّنَا وَأَقِيمَا، وَلْيَؤُمَّكُمَا أَكْبَرُكُمَا ‏"‏ ‏.‏\hadithno{979}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Malik bin Huwairith said:“I came to the Prophet (ﷺ) with a friend of mine, and when we wanted to leave, he said to us: ‘When the time for prayer comes, say the Adhan and Iqamah, then let the older of you lead the prayer.’”}}
\hadithdefcmd{ibnmajah}{980}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، قَالَ سَمِعْتُ أَوْسَ بْنَ ضَمْعَجٍ، قَالَ سَمِعْتُ أَبَا مَسْعُودٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَؤُمُّ الْقَوْمَ أَقْرَؤُهُمْ لِكِتَابِ اللَّهِ، فَإِنْ كَانَتْ قِرَاءَتُهُمْ سَوَاءً، فَلْيَؤُمَّهُمْ أَقْدَمُهُمْ هِجْرَةً، فَإِنْ كَانَتِ الْهِجْرَةُ سَوَاءً، فَلْيَؤُمَّهُمْ أَكْبَرُهُمْ سِنًّا، وَلاَ يُؤَمَّ الرَّجُلُ فِي أَهْلِهِ وَلاَ فِي سُلْطَانِهِ، وَلاَ يُجْلَسْ عَلَى تَكْرِمَتِهِ فِي بَيْتِهِ، إِلاَّ بِإِذْنٍ، أَوْ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{980}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Mas’ud said:“The Messenger of Allah (ﷺ) said: ‘The people should be lead by the one who is most well-Versed in recitation of the Book of Allah. If they are equal in recitation, then they should be led by the one who emigrated first. If they are equal in emigration, then they should be led by the eldest. A man should not be led among his family or in his place of authority; no one should be sat in his place of honor in his house without permission, or without his permission.’”}}
\hadithdefcmd{ibnmajah}{981}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ سُلَيْمَانَ، أَخُو فُلَيْحٍ حَدَّثَنَا أَبُو حَازِمٍ، قَالَ كَانَ سَهْلُ بْنُ سَعْدٍ السَّاعِدِيُّ يُقَدِّمُ فِتْيَانَ قَوْمِهِ يُصَلُّونَ بِهِمْ فَقِيلَ لَهُ تَفْعَلُ وَلَكَ مِنَ الْقِدَمِ مَا لَكَ قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الإِمَامُ ضَامِنٌ، فَإِنْ أَحْسَنَ، فَلَهُ وَلَهُمْ، وَإِنْ أَسَاءَ - يَعْنِي - فَعَلَيْهِ وَلاَ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{981}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Abu Hazim said:“Sahl bin Sa’d As-Sa’idi used to give preference to the young to lead his people in prayer. It was said to him: “Do you do that, when you have such seniority (in Islam)?” He said: “I heard the Messenger of Allah (ﷺ) say: ‘The Imam is responsible. If he does well, then he will have the reward and so will they, but if he does badly, then that will be counted against him but not against them.’”}}
\hadithdefcmd{ibnmajah}{982}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أُمِّ غُرَابٍ، عَنِ امْرَأَةٍ، يُقَالُ لَهَا عَقِيلَةُ عَنْ سَلاَمَةَ بِنْتِ الْحُرِّ، أُخْتِ خَرَشَةَ قَالَتْ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ يَقُومُونَ سَاعَةً، لاَ يَجِدُونَ إِمَامًا يُصَلِّي بِهِمْ ‏"‏ ‏.‏\hadithno{982}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Salamah bint Hurr, the sister of Kharashah, said:“I heard the Prophet (ﷺ) say: ‘A time will come when the people will stand for a long time and will not be able to find any Imam to lead them in prayer.”}}
\hadithdefcmd{ibnmajah}{983}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، عَنْ أَبِي عَلِيٍّ الْهَمْدَانِيِّ، أَنَّهُ خَرَجَ فِي سَفِينَةٍ فِيهَا عُقْبَةُ بْنُ عَامِرٍ الْجُهَنِيُّ فَحَانَتْ صَلاَةٌ مِنَ الصَّلَوَاتِ فَأَمَرْنَاهُ أَنْ يَؤُمَّنَا وَقُلْنَا لَهُ إِنَّكَ أَحَقُّنَا بِذَلِكَ أَنْتَ صَاحِبُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَبَى فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ أَمَّ النَّاسَ فَأَصَابَ، فَالصَّلاَةُ لَهُ وَلَهُمْ، وَمَنِ انْتَقَصَ مِنْ ذَلِكَ شَيْئًا فَعَلَيْهِ، وَلاَ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{983}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu ‘Ali Al-Hamdani that he went out in a ship in which ‘Uqbah bin ‘Amir Al-Juhani was present. The time for prayer came, and we told him to lead us in prayer and said to him:“You are the most deserving of that, you were the Companion of the Messenger of Allah (ﷺ).” But he refused and said: “I heard the Messenger of Allah (ﷺ) say: ‘Whoever leads the people and gets it right, the prayer will be for him and for them, but if he falls short, then that will be counted against him but not against them.”}}
\hadithdefcmd{ibnmajah}{984}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي لأَتَأَخَّرُ فِي صَلاَةِ الْغَدَاةِ مِنْ أَجْلِ فُلاَنٍ لِمَا يُطِيلُ بِنَا فِيهَا ‏.‏ قَالَ فَمَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَطُّ فِي مَوْعِظَةٍ أَشَدَّ غَضَبًا مِنْهُ يَوْمَئِذٍ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّ مِنْكُمْ مُنَفِّرِينَ فَأَيُّكُمْ مَا صَلَّى بِالنَّاسِ فَلْيُجَوِّزْ فَإِنَّ فِيهِمُ الضَّعِيفَ وَالْكَبِيرَ وَذَا الْحَاجَةِ ‏"‏ ‏.‏\hadithno{984}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Mas’ud said:“A man came to the Prophet (ﷺ) and said: ‘O Messenger of Allah! I stay behind and do not perform the morning prayer (in congregation) because of so-and-so, for he makes it too long for us.’ I never saw the Messenger of Allah (ﷺ) preaching with such anger as he did that day. He said; ‘O people! There are among you those who repel others. Whoever among you leads others in prayer, let him keep it short, for among them are those who are weak and elderly, and those who have pressing needs.’”}}
\hadithdefcmd{ibnmajah}{985}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، أَنْبَأَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُوجِزُ وَيُتِمُّ الصَّلاَةَ ‏.‏\hadithno{985}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) used to make his prayer brief but perfect.”}}
\hadithdefcmd{ibnmajah}{986}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ صَلَّى مُعَاذُ بْنُ جَبَلٍ الأَنْصَارِيُّ بِأَصْحَابِهِ صَلاَةَ الْعِشَاءِ فَطَوَّلَ عَلَيْهِمْ فَانْصَرَفَ رَجُلٌ مِنَّا فَصَلَّى فَأُخْبِرَ مُعَاذٌ عَنْهُ فَقَالَ إِنَّهُ مُنَافِقٌ ‏.‏ فَلَمَّا بَلَغَ ذَلِكَ الرَّجُلَ دَخَلَ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَخْبَرَهُ مَا قَالَ لَهُ مُعَاذٌ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ أَتُرِيدُ أَنْ تَكُونَ فَتَّانًا يَا مُعَاذُ إِذَا صَلَّيْتَ بِالنَّاسِ فَاقْرَأْ بِالشَّمْسِ وَضُحَاهَا وَسَبِّحِ اسْمَ رَبِّكَ الأَعْلَى وَاللَّيْلِ إِذَا يَغْشَى وَاقْرَأْ بِاسْمِ رَبِّكَ ‏"‏ ‏.‏\hadithno{986}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“Mu’adh bin Jabal Al-Ansari led his companions in the ‘Isha’ prayer and he made it long. A man among us went away and prayed by himself. Mu’adh was told about that and he said: ‘He is a hypocrite.’ When the man heard about that, he went to the Messenger of Allah (ﷺ) and told him what Mu’adh had said to him. The Prophet (ﷺ) said: ‘Do you want to be a cause of Fitnah (trial, tribulation), O Mu’adh? When you lead the people in prayer, recite “By the sun and its brightness,”[Ash-Shams 91] and “Glorify the Name of your Lord the Most High,” [Al-A’la 87] and “By the night as it envelopes,” [Al-Lail 92] and “Recite in the Name of your Lord.’”[Al-‘Alaq]}}
\hadithdefcmd{ibnmajah}{987}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ أَبِي الْعَاصِ، يَقُولُ كَانَ آخِرَ مَا عَهِدَ إِلَىَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ حِينَ أَمَّرَنِي عَلَى الطَّائِفِ قَالَ لِي ‏ "‏ يَا عُثْمَانُ تَجَاوَزْ فِي الصَّلاَةِ وَاقْدِرِ النَّاسَ بِأَضْعَفِهِمْ فَإِنَّ فِيهِمُ الْكَبِيرَ وَالصَّغِيرَ وَالسَّقِيمَ وَالْبَعِيدَ وَذَا الْحَاجَةِ ‏"‏ ‏.‏\hadithno{987}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mutarrif bin ‘Abdullah bin Shikhkhir said:“I heard ‘Uthman bin Abul-‘As say: “The last thing that the Prophet (ﷺ) enjoined on me when he appointed me governor of Ta’if was that he said: “O ‘Uthman! Be tolerable in prayer and estimate the people based upon the weakest among them, for among them are the elderly, the young, the sick, those who live far from the mosque, and those who have pressing needs.”}}
\hadithdefcmd{ibnmajah}{988}{حَدَّثَنَا عَلِيُّ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ حَدَّثَ عُثْمَانُ بْنُ أَبِي الْعَاصِ، أَنَّ آخِرَ، مَا قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَمَمْتَ قَوْمًا فَأَخِفَّ بِهِمْ ‏"‏ ‏.‏\hadithno{988}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{‘Uthman bin Abul-‘As narrated that the last thing the Messenger of Allah (ﷺ) enjoined on him was that he said:“When you lead people, keep it short for them.”}}
\hadithdefcmd{ibnmajah}{989}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي لأَدْخُلُ فِي الصَّلاَةِ وَأَنَا أُرِيدُ إِطَالَتَهَا فَأَسْمَعُ بُكَاءَ الصَّبِيِّ فَأَتَجَوَّزُ فِي صَلاَتِي مِمَّا أَعْلَمُ لِوَجْدِ أُمِّهِ بِبُكَائِهِ ‏"‏ ‏.‏\hadithno{989}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) said: ‘I start prayer and I want to make it long, but then I hear an infant crying, so I make my prayer short, because I know the distress caused to the mother by his crying.’”}}
\hadithdefcmd{ibnmajah}{990}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي كَرِيمَةَ الْحَرَّانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عُلاَثَةَ، عَنْ هِشَامِ بْنِ حَسَّانٍ، عَنِ الْحَسَنِ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي لأَسْمَعُ بُكَاءَ الصَّبِيِّ فَأَتَجَوَّزُ فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{990}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Uthman bin Abul-‘As said:“The Messenger of Allah (ﷺ) said: ‘I hear an infant crying so I make the prayer short.’”}}
\hadithdefcmd{ibnmajah}{991}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ الْوَاحِدِ، وَبِشْرُ بْنُ بَكْرٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي لأَقُومُ فِي الصَّلاَةِ وَأَنَا أُرِيدُ أَنْ أُطَوِّلَ فِيهَا فَأَسْمَعُ بُكَاءَ الصَّبِيِّ فَأَتَجَوَّزُ كَرَاهِيَةَ أَنْ أَشُقَّ عَلَى أُمِّهِ ‏"‏ ‏.‏\hadithno{991}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from ‘Abdullah bin Abu Qatadah that his father said:“The Messenger of Allah (ﷺ) said: ‘I get up to perform prayer and I intend to make it long, but then I hear an infant crying, so I make it short, because I do not like to cause distress to his mother.’”}}
\hadithdefcmd{ibnmajah}{992}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ جَابِرِ بْنِ سَمُرَةَ السُّوَائِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَلاَ تَصُفُّونَ كَمَا تَصُفُّ الْمَلاَئِكَةُ عِنْدَ رَبِّهَا ‏"‏ ‏.‏ قَالَ قُلْنَا وَكَيْفَ تَصُفُّ الْمَلاَئِكَةُ عِنْدَ رَبِّهَا قَالَ ‏"‏ يُتِمُّونَ الصُّفُوفَ الأُوَلَ وَيَتَرَاصُّونَ فِي الصَّفِّ ‏"‏ ‏.‏\hadithno{992}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah As-Suwa’i said:“The Messenger of Allah (ﷺ) said: ‘Will you not form your rows as the angels form their rows before their Lord?’ We said: ‘How do the angels form their rows before their Lord?’ He said: ‘They complete the first row and they stand close of one another in the line (leaving no gaps between one another).’”}}
\hadithdefcmd{ibnmajah}{993}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبِي وَبِشْرُ بْنُ عُمَرَ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سَوُّوا صُفُوفَكُمْ فَإِنَّ تَسْوِيَةَ الصُّفُوفِ مِنْ تَمَامِ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{993}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) said: ‘Make your rows straight, for straightening the rows is part of completing the prayer.’”}}
\hadithdefcmd{ibnmajah}{994}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، أَنَّهُ سَمِعَ النُّعْمَانَ بْنَ بَشِيرٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُسَوِّي الصَّفَّ حَتَّى يَجْعَلَهُ مِثْلَ الرُّمْحِ أَوِ الْقِدْحِ ‏.‏ قَالَ فَرَأَى صَدْرَ رَجُلٍ نَاتِئًا فَقَالَ رَسُولُ اللَّهِ ‏ "‏ سَوُّوا صُفُوفَكُمْ أَوْ لَيُخَالِفَنَّ اللَّهُ بَيْنَ وُجُوهِكُمْ ‏"‏ ‏.‏\hadithno{994}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Simak bin Harb narrated that he heard Nu’man bin Bashir say:“The Messenger of Allah (ﷺ) used to straighten the rows until he made them like a spear or an arrow-shaft. Once he saw a man’s chest (sticking out) so the Messenger of Allah (ﷺ) said: ‘Make your rows straight or Allah will create division among you.’”}}
\hadithdefcmd{ibnmajah}{995}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ وَمَلاَئِكَتَهُ يُصَلُّونَ عَلَى الَّذِينَ يَصِلُونَ الصُّفُوفَ وَمَنْ سَدَّ فُرْجَةً رَفَعَهُ اللَّهُ بِهَا دَرَجَةً ‏"‏ ‏.‏\hadithno{995}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) said: ‘Allah and His angels send blessings upon those who complete the rows, and whoever fills a gap, Allah will raise him one degree in status thereby.’”}}
\hadithdefcmd{ibnmajah}{996}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عِرْبَاضِ بْنِ سَارِيَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَسْتَغْفِرُ لِلصَّفِّ الْمُقَدَّمِ، ثَلاَثًا، وَلِلثَّانِي، مَرَّةً ‏.‏\hadithno{996}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Irbad bin Sariyah that the Messenger of Allah (ﷺ) used to ask for forgiveness for the first row three times and for the second row twice}}
\hadithdefcmd{ibnmajah}{997}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ طَلْحَةَ بْنَ مُصَرِّفٍ، يَقُولُ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ عَوْسَجَةَ، يَقُولُ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ اللَّهَ وَمَلاَئِكَتَهُ يُصَلُّونَ عَلَى الصُّفُوفِ الأُوَلِ ‏"‏ ‏.‏\hadithno{997}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Bara’ bin ‘Azib said:“I heard the Messenger of Allah (ﷺ) say: ‘Allah and the angels send blessings upon the first row.’”}}
\hadithdefcmd{ibnmajah}{998}{حَدَّثَنَا أَبُو ثَوْرٍ، إِبْرَاهِيمُ بْنُ خَالِدٍ حَدَّثَنَا أَبُو قَطَنٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ خِلاَسٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْ يَعْلَمُونَ مَا فِي الصَّفِّ الأَوَّلِ لَكَانَتْ قُرْعَةٌ ‏"‏ ‏.‏\hadithno{998}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘If they knew what (goodness) there is in the first row, they would cast lots for it.’”}}
\hadithdefcmd{ibnmajah}{999}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَلْقَمَةَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ وَمَلاَئِكَتَهُ يُصَلُّونَ عَلَى الصَّفِّ الأَوَّلِ ‏"‏ ‏.‏\hadithno{999}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibrahim bin ‘Abdur-Rahman bin ‘Awf that his father said:“The Messenger of Allah (ﷺ) said: ‘Allah and the angels send blessings upon the first row.’”}}
\hadithdefcmd{ibnmajah}{1000}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، وَعَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَيْرُ صُفُوفِ النِّسَاءِ آخِرُهَا، وَشَرُّهَا أَوَّلُهَا، وَخَيْرُ صُفُوفِ الرِّجَالِ أَوَّلُهَا، وَشَرُّهَا آخِرُهَا ‏"‏ ‏.‏\hadithno{1000}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘The best rows for women are the back rows, and the worst are the front rows, and the best rows for men are the front rows, and the worst are the back rows.’”}}
\hadithdefcmd{ibnmajah}{1001}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَيْرُ صُفُوفِ الرِّجَالِ مُقَدَّمُهَا، وَشَرُّهَا مُؤَخَّرُهَا، وَخَيْرُ صُفُوفِ النِّسَاءِ مُؤَخَّرُهَا، وَشَرُّهَا مُقَدَّمُهَا ‏"‏ ‏.‏\hadithno{1001}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) said: ‘The best rows for men are the front rows and the worst rows are the back rows, and the best rows for women are the back rows and the worst are the front rows.’”}}
\hadithdefcmd{ibnmajah}{1002}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ أَبُو طَالِبٍ، حَدَّثَنَا أَبُو دَاوُدَ، وَأَبُو قُتَيْبَةَ قَالاَ حَدَّثَنَا هَارُونُ بْنُ مُسْلِمٍ، عَنْ قَتَادَةَ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَبِيهِ، قَالَ كُنَّا نُنْهَى أَنْ نَصُفَّ، بَيْنَ السَّوَارِي عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَنُطْرَدُ عَنْهَا طَرْدًا ‏.‏\hadithno{1002}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mu’awiyah bin Qurrah that his father said:“We were forbidden to form a row between two pillars at the time of the Messenger of Allah (ﷺ), and we would be repelled from them forcefully.”}}
\hadithdefcmd{ibnmajah}{1003}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ بَدْرٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَلِيِّ بْنِ شَيْبَانَ، عَنْ أَبِيهِ، عَلِيِّ بْنِ شَيْبَانَ - وَكَانَ مِنَ الْوَفْدِ - قَالَ خَرَجْنَا حَتَّى قَدِمْنَا عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَبَايَعْنَاهُ وَصَلَّيْنَا خَلْفَهُ ثُمَّ صَلَّيْنَا وَرَاءَهُ صَلاَةً أُخْرَى فَقَضَى الصَّلاَةَ فَرَأَى رَجُلاً فَرْدًا يُصَلِّي خَلْفَ الصَّفِّ ‏.‏ قَالَ فَوَقَفَ عَلَيْهِ نَبِيُّ اللَّهِ ـ صلى الله عليه وسلم ـ حِينَ انْصَرَفَ قَالَ ‏ "‏ اسْتَقْبِلْ صَلاَتَكَ، لاَ صَلاَةَ لِلَّذِي خَلْفَ الصَّفِّ ‏"‏ ‏.‏\hadithno{1003}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Abdur-Rahman bin ‘Ali bin Shaiban narrated that his father, ‘Ali bin Shaiban, who was part of the delegation, said:“We set out until we came to the Prophet (ﷺ). We gave him our oath of allegiance and performed prayer behind him. Then we offered another prayer behind him. He finished the prayer and saw a man on his own, praying behind the row.” He said: “The Prophet of Allah (ﷺ) stood beside him and when he finished he said: ‘Repeat your prayer; there is no prayer for the one who is behind the row.’”}}
\hadithdefcmd{ibnmajah}{1004}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، عَنْ هِلاَلِ بْنِ يَسَافٍ، قَالَ أَخَذَ بِيَدِي زِيَادُ بْنُ أَبِي الْجَعْدِ فَأَوْقَفَنِي عَلَى شَيْخٍ بِالرَّقَّةِ يُقَالُ لَهُ وَابِصَةُ بْنُ مَعْبَدٍ فَقَالَ صَلَّى رَجُلٌ خَلْفَ الصَّفِّ وَحْدَهُ فَأَمَرَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ يُعِيدَ ‏.‏\hadithno{1004}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hilal bin Yasaf said:“Ziyad bin Abu-Ja’d took me by the hand and made me stand near an old man at Raqqah, whose name was Wabisah bin Ma’bad. He said: ‘A man performed prayer behind the row on his own, and the Prophet (ﷺ) commanded him to repeat the prayer.’”}}
\hadithdefcmd{ibnmajah}{1005}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عُثْمَانَ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ وَمَلاَئِكَتَهُ يُصَلُّونَ عَلَى مَيَامِنِ الصُّفُوفِ ‏"‏ ‏.‏\hadithno{1005}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) said: ‘Allah and His angels send blessings upon the right side of the rows.’”}}
\hadithdefcmd{ibnmajah}{1006}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ ابْنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنِ الْبَرَاءِ، قَالَ كُنَّا إِذَا صَلَّيْنَا خَلْفَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ - قَالَ مِسْعَرٌ - مِمَّا نُحِبُّ أَوْ مِمَّا أُحِبُّ أَنْ نَقُومَ عَنْ يَمِينِهِ ‏.‏\hadithno{1006}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Bara’ said:“When we performed prayer behind the Messenger of Allah (ﷺ) (One of the narrators) Mis’ar said: ‘One of the things we liked, or one of the things I liked’ ‘was to stand to his right.’”}}
\hadithdefcmd{ibnmajah}{1007}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي الْحُسَيْنِ أَبُو جَعْفَرٍ، حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ الْكِلاَبِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو الرَّقِّيُّ، عَنْ لَيْثِ بْنِ أَبِي سُلَيْمٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قِيلَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ إِنَّ مَيْسَرَةَ الْمَسْجِدِ تَعَطَّلَتْ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ عَمَّرَ مَيْسَرَةَ الْمَسْجِدِ كُتِبَ لَهُ كِفْلاَنِ مِنَ الأَجْرِ ‏"‏ ‏.‏\hadithno{1007}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“It was said to the Prophet (ﷺ): ‘The left side of the mosque has been abandoned. The Prophet (ﷺ) said: “Whoever frequents the left side of the mosque, two Kifl* of reward will be recorded for him.”}}
\hadithdefcmd{ibnmajah}{1008}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ لَمَّا فَرَغَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ طَوَافِ الْبَيْتِ أَتَى مَقَامَ إِبْرَاهِيمَ فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ هَذَا مَقَامُ أَبِينَا إِبْرَاهِيمَ الَّذِي قَالَ اللَّهُ ‏\{وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى \}‏ ‏.‏ قَالَ الْوَلِيدُ فَقُلْتُ لِمَالِكٍ أَهَكَذَا قَرَأَ ‏\{وَاتَّخِذُوا\}‏ قَالَ نَعَمْ ‏.‏\hadithno{1008}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“When the Messenger of Allah (ﷺ) finished Tawaf around the House (the Ka’bah), he came to Maqam of Ibrahim (the Station of Ibrahim). ‘Umar said: ‘O Messenger of Allah, this is the Station of our father Ibrahim about which Allah said: “And take you (people) the Maqam of Ibrahim as a place of prayer.’” [2:]}}
\hadithdefcmd{ibnmajah}{1009}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا هُشَيْمٌ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ عُمَرُ قُلْتُ يَا رَسُولَ اللَّهِ لَوِ اتَّخَذْتَ مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى فَنَزَلَتْ ‏\{وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى\}‏ ‏.‏\hadithno{1009}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik told that ‘Umar said:“I said: ‘O Messenger of Allah (ﷺ), why do you not take the Maqam of Ibrahim as a place of prayer?’ Then the following was revealed: ‘And take you (people) the Maqam of Ibrahim as a place of prayer.’” [2:]}}
\hadithdefcmd{ibnmajah}{1010}{حَدَّثَنَا عَلْقَمَةُ بْنُ عَمْرٍو الدَّارِمِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ صَلَّيْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ نَحْوَ بَيْتِ الْمَقْدِسِ ثَمَانِيَةَ عَشَرَ شَهْرًا وَصُرِفَتِ الْقِبْلَةُ إِلَى الْكَعْبَةِ بَعْدَ دُخُولِهِ إِلَى الْمَدِينَةِ بِشَهْرَيْنِ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا صَلَّى إِلَى بَيْتِ الْمَقْدِسِ أَكْثَرَ تَقَلُّبَ وَجْهِهِ فِي السَّمَاءِ وَعَلِمَ اللَّهُ مِنْ قَلْبِ نَبِيِّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ يَهْوَى الْكَعْبَةَ فَصَعِدَ جِبْرِيلُ فَجَعَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُتْبِعُهُ بَصَرَهُ وَهُوَ يَصْعَدُ بَيْنَ السَّمَاءِ وَالأَرْضِ يَنْظُرُ مَا يَأْتِيهِ بِهِ فَأَنْزَلَ اللَّهُ ‏\{قَدْ نَرَى تَقَلُّبَ وَجْهِكَ فِي السَّمَاءِ\}‏ الآيَةَ فَأَتَانَا آتٍ فَقَالَ إِنَّ الْقِبْلَةَ قَدْ صُرِفَتْ إِلَى الْكَعْبَةِ وَقَدْ صَلَّيْنَا رَكْعَتَيْنِ إِلَى بَيْتِ الْمَقْدِسِ وَنَحْنُ رُكُوعٌ فَتَحَوَّلْنَا فَبَنَيْنَا عَلَى مَا مَضَى مِنْ صَلاَتِنَا فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ يَا جِبْرِيلُ كَيْفَ حَالُنَا فِي صَلاَتِنَا إِلَى بَيْتِ الْمَقْدِسِ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{وَمَا كَانَ اللَّهُ لِيُضِيعَ إِيمَانَكُمْ\}‏ ‏.‏\hadithno{1010}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Bara’ said:“We prayed with the Messenger of Allah (ﷺ) facing towards Baitul-Maqdis (Jerusalem) for eighteen months, then the Qiblah was changed to the Ka’bah two months after the Prophet (ﷺ) entered Al-Madinah. When the Messenger of Allah (ﷺ) prayed towards Baitul-Maqdis, he would often lift his face towards the heavens, and Allah knew what was in the heart of His Prophet and how he longed to face the Ka’bah (during prayer). Jibril appeared (in the sky), and the Messenger of Allah (ﷺ) started watching him as he was descending between the heavens and the earth, waiting to see what he would bring. Then Allah revealed the words: ‘Verily, We have seen the turning of your face towards the heaven. Surely, We shall turn you to a Qiblah that shall please you, so turn your face in the direction of Al-Masjid Al-Haram (at Makkah). And wherever you people are, turn your faces (during prayer) in that direction.’ [2:144] Then someone came to us and said: ‘The Qiblah has been changed to the Ka’bah.’ We had performed two Rak’ah facing towards Jerusalem. And we were bowing. So we turned around, and we continued our prayer. The Messenger of Allah (ﷺ) said: ‘O Jibril! What about our prayer facing towards Baitul- Maqdis?’ Then Allah revealed the words: “And Allah would never make your faith to be lost.” [2:]}}
\hadithdefcmd{ibnmajah}{1011}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الأَزْدِيُّ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا أَبُو مَعْشَرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ قِبْلَةٌ ‏"‏ ‏.‏\hadithno{1011}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘What is between the east and the west is the Qiblah (prayer direction).’”* *This refers to the Qiblah for the the inhabitants of Al-Madinah. (Makkah is to the exact south of Al-Madinah)}}
\hadithdefcmd{ibnmajah}{1012}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنِ الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلاَ يَجْلِسْ حَتَّى يَرْكَعَ رَكْعَتَيْنِ ‏"‏ ‏.‏\hadithno{1012}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When anyone of you enters the mosque, let him not sit down until he performs two Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1013}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي قَتَادَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلْيُصَلِّ رَكْعَتَيْنِ قَبْلَ أَنْ يَجْلِسَ ‏"‏ ‏.‏\hadithno{1013}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Qatadah that the Prophet (ﷺ) said:“When one of you enters the mosque, let him perform two Rak’ah before he sits down.”}}
\hadithdefcmd{ibnmajah}{1014}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ الْغَطَفَانِيِّ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمُرِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَامَ يَوْمَ الْجُمُعَةِ خَطِيبًا - أَوْ خَطَبَ يَوْمَ الْجُمُعَةِ - فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ يَا أَيُّهَا النَّاسُ إِنَّكُمْ تَأْكُلُونَ شَجَرَتَيْنِ لاَ أُرَاهُمَا إِلاَّ خَبِيثَتَيْنِ هَذَا الثُّومُ وَهَذَا الْبَصَلُ وَلَقَدْ كُنْتُ أَرَى الرَّجُلَ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يُوجَدُ رِيحُهُ مِنْهُ فَيُؤْخَذُ بِيَدِهِ حَتَّى يُخْرَجَ إِلَى الْبَقِيعِ فَمَنْ كَانَ آكِلَهَا لاَ بُدَّ فَلْيُمِتْهَا طَبْخًا ‏.‏\hadithno{1014}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ma’dan bin Abu Talhah Al-Ya’muri that ‘Umar bin Khattab stood up one Friday to deliver a sermon, or, he delivered a sermon one Friday. He praised Allah, then he said:“O people, you eat two plants that I find are nothing but obnoxious; this garlic and this onion. At the time of the Messenger of Allah (ﷺ), if a foul odour was detected from a man, I would see him seized by the arm and taken out to Al-Baqi’. Whoever must eat them, let him cook them to death.”}}
\hadithdefcmd{ibnmajah}{1015}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ الثُّومِ فَلاَ يُؤْذِينَا بِهَا فِي مَسْجِدِنَا هَذَا ‏"‏ ‏.‏ قَالَ إِبْرَاهِيمُ وَكَانَ أَبِي يَزِيدُ فِيهِ الْكُرَّاثَ وَالْبَصَلَ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏ يَعْنِي أَنَّهُ يَزِيدُ عَلَى حَدِيثِ أَبِي هُرَيْرَةَ فِي الثُّومِ ‏.‏\hadithno{1015}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever eats from this plant; garlic, let him not annoy us with it in this mosque of ours.’”}}
\hadithdefcmd{ibnmajah}{1016}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ شَيْئًا فَلاَ يَأْتِيَنَّ الْمَسْجِدَ ‏"‏ ‏.‏\hadithno{1016}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘Whoever eats anything from this plant, let him not come to the mosque.’”}}
\hadithdefcmd{ibnmajah}{1017}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ الطَّنَافِسِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ أَتَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَسْجِدَ قُبَاءٍ يُصَلِّي فِيهِ، فَجَاءَتْ رِجَالٌ مِنَ الأَنْصَارِ يُسَلِّمُونَ عَلَيْهِ، فَسَأَلْتُ صُهَيْبًا، وَكَانَ مَعَهُ: كَيْفَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَرُدُّ عَلَيْهِمْ؟ قَالَ: كَانَ يُشِيرُ بِيَدِهِ ‏.‏\hadithno{1017}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“The Messenger of Allah (ﷺ) came to the mosque at Quba’ and performed prayer there. Some men of the Ansar came and greeted him. I asked Suhaib, who was with him: ‘How did the Messenger of Allah (ﷺ) respond to them?’ He said: ‘He gestured with his hand.’”}}
\hadithdefcmd{ibnmajah}{1018}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ بَعَثَنِي النَّبِيُّ ـ صلى الله عليه وسلم ـ لِحَاجَةٍ ثُمَّ أَدْرَكْتُهُ وَهُوَ يُصَلِّي فَسَلَّمْتُ عَلَيْهِ فَأَشَارَ إِلَىَّ فَلَمَّا فَرَغَ دَعَانِي فَقَالَ ‏ "‏ إِنَّكَ سَلَّمْتَ عَلَىَّ آنِفًا وَأَنَا أُصَلِّي ‏"‏ ‏.‏\hadithno{1018}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“The Prophet (ﷺ) sent me on an errand, then I caught up with him while he was performing prayer, and I greeted him. He gestured to me, then when he finished, he called me and said: ‘You greeted me before, but I was performing prayer.’”}}
\hadithdefcmd{ibnmajah}{1019}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا نُسَلِّمُ فِي الصَّلاَةِ فَقِيلَ لَنَا إِنَّ فِي الصَّلاَةِ لَشُغْلاً ‏.‏\hadithno{1019}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah said:“We would greet others during the prayer, and it was said to us: ‘During the prayer one is preoccupied.’”}}
\hadithdefcmd{ibnmajah}{1020}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا أَشْعَثُ بْنُ سَعِيدٍ أَبُو الرَّبِيعِ السَّمَّانُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ فَتَغَيَّمَتِ السَّمَاءُ وَأَشْكَلَتْ عَلَيْنَا الْقِبْلَةُ فَصَلَّيْنَا وَأَعْلَمْنَا فَلَمَّا طَلَعَتِ الشَّمْسُ إِذَا نَحْنُ قَدْ صَلَّيْنَا لِغَيْرِ الْقِبْلَةِ فَذَكَرْنَا ذَلِكَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَنْزَلَ اللَّهُ ‏\{فَأَيْنَمَا تُوَلُّوا فَثَمَّ وَجْهُ اللَّهِ\}‏ ‏.‏\hadithno{1020}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amir bin Rabi’ah that his father said:“We were with the Messenger of Allah (ﷺ) on a journey, and the sky was overcast so it was difficult for us to determine the Qiblah. So we performed prayer, and we marked the location.* Later, when the sun reappeared, we realized that we had prayed facing a direction other than the Qiblah. We mentioned that to the Prophet (ﷺ), then the Words were revealed: ‘So wherever you turn there is the Face of Allah.’” [2:]}}
\hadithdefcmd{ibnmajah}{1021}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ طَارِقِ بْنِ عَبْدِ اللَّهِ الْمُحَارِبِيِّ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا صَلَّيْتَ فَلاَ تَبْزُقَنَّ بَيْنَ يَدَيْكَ، وَلاَ عَنْ يَمِينِكَ، وَلَكِنِ ابْزُقْ عَنْ يَسَارِكَ، أَوْ تَحْتَ قَدَمِكَ ‏"‏ ‏.‏\hadithno{1021}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Tariq bin ‘Abdullah Al-Muharibi said:“The Prophet (ﷺ) said: ‘When you perform prayer, do not spit in front of you or to your right, but spit to your left or beneath your feet.’”}}
\hadithdefcmd{ibnmajah}{1022}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ الْقَاسِمِ بْنِ مِهْرَانَ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ فَأَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏ "‏ مَا بَالُ أَحَدِكُمْ يَقُومُ مُسْتَقْبِلَهُ - يَعْنِي رَبَّهُ - فَيَتَنَخَّعُ أَمَامَهُ أَيُحِبُّ أَحَدُكُمْ أَنْ يُسْتَقْبَلَ فَيُتَنَخَّعَ فِي وَجْهِهِ إِذَا بَزَقَ أَحَدُكُمْ فَلْيَبْزُقَنَّ عَنْ شِمَالِهِ أَوْ لِيَقُلْ هَكَذَا فِي ثَوْبِهِ ‏"‏ ‏.‏ ثُمَّ أَرَانِي إِسْمَاعِيلُ يَبْزُقُ فِي ثَوْبِهِ ثُمَّ يَدْلُكُهُ ‏.‏\hadithno{1022}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) saw some sputum in the direction of the Qiblah of the mosque. He turned to the people and said:“What is wrong with one of you that he stands facing Him (meaning his Lord) and spits in front of Him? Would anyone like to be faced by someone who spits in his face? If anyone of you needs to spit, then let him spit to his left, or let him do like this in his garment.” Then Ismail (Abu Bakr bin Abu Shuaibah) showed me how he spat in his garment then rubbed it}}
\hadithdefcmd{ibnmajah}{1023}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، وَعَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، قَالاَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّهُ رَأَى شَبَثَ بْنَ رِبْعِيٍّ بَزَقَ بَيْنَ يَدَيْهِ فَقَالَ يَا شَبَثُ لاَ تَبْزُقْ بَيْنَ يَدَيْكَ فَإِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَنْهَى عَنْ ذَلِكَ وَقَالَ ‏ "‏ إِنَّ الرَّجُلَ إِذَا قَامَ يُصَلِّي أَقْبَلَ اللَّهُ عَلَيْهِ بِوَجْهِهِ حَتَّى يَنْقَلِبَ أَوْ يُحْدِثَ حَدَثَ سُوءٍ ‏"‏ ‏.‏\hadithno{1023}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hudhaifah that he saw Shabath bin Rib’i spitting in front of him. He said:“O Shabath! Do not spit in front of you, for the Messenger of Allah (ﷺ) used to forbid that, and he said: ‘When a man stands up to perform prayer, Allah turns His Face towards him until he turns away or he commits an evil Hadath.’”* * In Injah Al-Hajah, 'Abdul-Ghani Dehlawi said: "Meaning he does a matter that negates the Khushu'(submissiveness) and attentiveness of his prayer. Or, the meaning of Hadath is invalidating the ablution. The only reason that he described it as 'evil' is because in most cases, its occurrence during prayer is from Shaitan}}
\hadithdefcmd{ibnmajah}{1024}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ، وَعَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بَزَقَ فِي ثَوْبِهِ وَهُوَ فِي الصَّلاَةِ ثُمَّ دَلَكَهُ ‏.‏\hadithno{1024}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) spat on his garment while he was performing prayer, then he rubbed it}}
\hadithdefcmd{ibnmajah}{1025}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ مَسَّ الْحَصَى فَقَدْ لَغَا ‏"‏ ‏.‏\hadithno{1025}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:The Messenger of Allah (ﷺ) said: “Whoever smoothes the pebbles, then he has engaged in Laghw.”* *Meaning he has done what is not suitable}}
\hadithdefcmd{ibnmajah}{1026}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَعَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ، قَالَ حَدَّثَنِي مُعَيْقِيبٌ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي مَسْحِ الْحَصَى فِي الصَّلاَةِ ‏ "‏ إِنْ كُنْتَ فَاعِلاً فَمَرَّةً وَاحِدَةً ‏"‏ ‏.‏\hadithno{1026}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Mu’aiqib said:“The Messenger of Allah (ﷺ) said, concerning smoothing the pebbles during prayer: ‘If you must do that, then do it only once.’”}}
\hadithdefcmd{ibnmajah}{1027}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي الأَحْوَصِ اللَّيْثِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا قَامَ أَحَدُكُمْ إِلَى الصَّلاَةِ فَإِنَّ الرَّحْمَةَ تُوَاجِهُهُ فَلاَ يَمْسَحِ الْحَصَى ‏"‏ ‏.‏\hadithno{1027}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Dharr said:“The Messenger of Allah (ﷺ) said: ‘When anyone of you gets up to perform prayer, then indeed mercy is facing him, so he should not smooth the pebbles.’”}}
\hadithdefcmd{ibnmajah}{1028}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، حَدَّثَتْنِي مَيْمُونَةُ، زَوْجُ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي عَلَى الْخُمْرَةِ ‏.‏\hadithno{1028}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Maimunah the wife of the Prophet (ﷺ) said:“The Messenger of Allah (ﷺ) used to perform prayer on a Khumrah.”}}
\hadithdefcmd{ibnmajah}{1029}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، عَنْ أَبِي سَعِيدٍ، قَالَ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى حَصِيرٍ ‏.‏\hadithno{1029}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) performed prayer on a reed mat.”}}
\hadithdefcmd{ibnmajah}{1030}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي زَمْعَةُ بْنُ صَالِحٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ صَلَّى ابْنُ عَبَّاسٍ وَهُوَ بِالْبَصْرَةِ عَلَى بِسَاطِهِ ثُمَّ حَدَّثَ أَصْحَابَهُ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي عَلَى بِسَاطِهِ ‏.‏\hadithno{1030}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Amr bin Dinar said:“When Ibn ‘Abbas was in Basrah, he performed prayer on his rug, then he told his companions that the Messenger of Allah (ﷺ) used to perform prayer on his rug.”}}
\hadithdefcmd{ibnmajah}{1031}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَبِيبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ جَاءَنَا النَّبِيُّ ـ صلى الله عليه وسلم ـ فَصَلَّى بِنَا فِي مَسْجِدِ بَنِي عَبْدِ الأَشْهَلِ فَرَأَيْتُهُ وَاضِعًا يَدَيْهِ عَلَى ثَوْبِهِ إِذَا سَجَدَ ‏.‏\hadithno{1031}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin ‘Abdur-Rahman said:“The Prophet (ﷺ) came to us and led us in prayer in the mosque of Banu ‘Abdul- Ashhal, and I saw him putting his hands on his garment when he prostrated.”}}
\hadithdefcmd{ibnmajah}{1032}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، أَخْبَرَنِي إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ الأَشْهَلِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَابِتِ بْنِ الصَّامِتِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى فِي بَنِي عَبْدِ الأَشْهَلِ وَعَلَيْهِ كِسَاءٌ مُتَلَفِّفٌ بِهِ يَضَعُ يَدَيْهِ عَلَيْهِ يَقِيهِ بَرْدَ الْحَصَى ‏.‏\hadithno{1032}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin ‘Abdur-Rahman bin Thabit bin Samit, from his father, from his grandfather, that the Messenger of Allah (ﷺ) performed prayer among Banu ‘Abdul-Ashhal, wearing a cloak in which he was wrapped and putting his hands on it to protect them from the cold of the pebbles}}
\hadithdefcmd{ibnmajah}{1033}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ غَالِبٍ الْقَطَّانِ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا نُصَلِّي مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي شِدَّةِ الْحَرِّ فَإِذَا لَمْ يَقْدِرْ أَحَدُنَا أَنْ يُمَكِّنَ جَبْهَتَهُ بَسَطَ ثَوْبَهُ فَسَجَدَ عَلَيْهِ ‏.‏\hadithno{1033}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“We used to perform prayer with the Prophet (ﷺ) when it was very hot. When one of us could not place his forehead firmly on the ground, he would spread his garment and prostrate on it.”}}
\hadithdefcmd{ibnmajah}{1034}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{1034}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The Tasbih (saying Subhan-Allah) is for men and clapping is for women.”}}
\hadithdefcmd{ibnmajah}{1035}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{1035}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sahl bin Sa’d As-Sa’idi that the Messenger of Allah (ﷺ) said:“The Tasbih is for men and clapping is for women.”}}
\hadithdefcmd{ibnmajah}{1036}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، وَعُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّهُ كَانَ يَقُولُ قَالَ ابْنُ عُمَرَ رَخَّصَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِلنِّسَاءِ فِي التَّصْفِيقِ وَلِلرِّجَالِ فِي التَّسْبِيحِ ‏.‏\hadithno{1036}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Nafi’ used to say:“Ibn ‘Umar said: ‘The Messenger of Allah (ﷺ) granted a concession for the women to clap, and for the men to say the Tasbih.”}}
\hadithdefcmd{ibnmajah}{1037}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنِ ابْنِ أَبِي أَوْسٍ، قَالَ كَانَ جَدِّي أَوْسٌ يُصَلِّي فَيُشِيرُ إِلَىَّ وَهُوَ فِي الصَّلاَةِ فَأُعْطِيهِ نَعْلَيْهِ وَيَقُولُ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي فِي نَعْلَيْهِ ‏.‏\hadithno{1037}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Abu Aws said:“My grandfather, Aws, used to perform prayer, and sometimes he would make a gesture while praying, and I would give him his sandals. He said: ‘I saw the Messenger of Allah (ﷺ) performing prayer in his sandals.’”}}
\hadithdefcmd{ibnmajah}{1038}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي حَافِيًا وَمُنْتَعِلاً ‏.‏\hadithno{1038}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, that his grandfather said:“I saw the Messenger of Allah (ﷺ) performing prayer both barefoot, and while wearing sandals.”}}
\hadithdefcmd{ibnmajah}{1039}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَقَدْ رَأَيْنَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي فِي النَّعْلَيْنِ وَالْخُفَّيْنِ ‏.‏\hadithno{1039}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah said:“We saw the Messenger of Allah (ﷺ) performing prayer wearing sandals and leather slippers.”}}
\hadithdefcmd{ibnmajah}{1040}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الضَّرِيرُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، وَأَبُو عَوَانَةَ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ أُمِرْتُ أَنْ لاَ أَكُفَّ شَعْرًا وَلاَ ثَوْبًا ‏"‏ ‏.‏\hadithno{1040}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:The Prophet (ﷺ) said: “I was commanded not to tuck up my hair or my garment.”* *Drawing together during prostration to protect it from the dirt}}
\hadithdefcmd{ibnmajah}{1041}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ أُمِرْنَا أَلاَّ نَكُفَّ شَعَرًا وَلاَ ثَوْبًا وَلاَ نَتَوَضَّأَ مِنْ مَوْطَإٍ ‏.‏\hadithno{1041}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah said:“We were ordered to not (tuck up our) hair (nor garment) and not to repeat ablution for what we stepped on.”}}
\hadithdefcmd{ibnmajah}{1042}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي مُخَوَّلُ بْنُ رَاشِدٍ، قَالَ سَمِعْتُ أَبَا سَعْدٍ، - رَجُلاً مِنْ أَهْلِ الْمَدِينَةِ - يَقُولُ رَأَيْتُ أَبَا رَافِعٍ مَوْلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى الْحَسَنَ بْنَ عَلِيٍّ وَهُوَ يُصَلِّي وَقَدْ عَقَصَ شَعْرَهُ فَأَطْلَقَهُ أَوْ نَهَى عَنْهُ وَقَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُصَلِّيَ الرَّجُلُ وَهُوَ عَاقِصٌ شَعْرَهُ ‏.‏\hadithno{1042}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Mukhawwal said:“I heard Abu Sa’d, a man from the people of Madinah, say: ‘I saw Abu Rafi’, the freed slave of the Messenger of Allah (ﷺ), when he saw Hasan bin ‘Ali performing prayer, with his hair braided. He undid it, or told him not to do that, and said: “The Messenger of Allah (ﷺ) forbade a man from performing prayer with his hair braided.”}}
\hadithdefcmd{ibnmajah}{1043}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَرْفَعُوا أَبْصَارَكُمْ إِلَى السَّمَاءِ أَنْ تَلْتَمِعَ ‏"‏ ‏.‏ يَعْنِي فِي الصَّلاَةِ ‏.‏\hadithno{1043}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘Do not lift your gaze to the heavens lest your sight be snatched away,” meaning during prayer}}
\hadithdefcmd{ibnmajah}{1044}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمًا بِأَصْحَابِهِ فَلَمَّا قَضَى الصَّلاَةَ أَقْبَلَ عَلَى الْقَوْمِ بِوَجْهِهِ فَقَالَ ‏"‏ مَا بَالُ أَقْوَامٍ يَرْفَعُونَ أَبْصَارَهُمْ إِلَى السَّمَاءِ ‏"‏ ‏.‏ حَتَّى اشْتَدَّ قَوْلُهُ فِي ذَلِكَ ‏"‏ لَيَنْتَهُنَّ عَنْ ذَلِكَ أَوْ لَيَخْطَفَنَّ اللَّهُ أَبْصَارَهُمْ ‏"‏ ‏.‏\hadithno{1044}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) led his Companions in prayer one day. When he had finished prayer he turned to face the people and said: ‘What is wrong with some people that they lift their gaze to the heavens?’ He spoke severely concerning that: ‘They should certainly abstain from that or Allah will snatch away their sight.’”}}
\hadithdefcmd{ibnmajah}{1045}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَيَنْتَهِيَنَّ أَقْوَامٌ يَرْفَعُونَ أَبْصَارَهُمْ إِلَى السَّمَاءِ أَوْ لاَ تَرْجِعُ أَبْصَارُهُمْ ‏"‏ ‏.‏\hadithno{1045}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin Samurah that the Prophet (ﷺ) said:“Let those who lift their gaze to the heavens desist, or their sight will not come back.”}}
\hadithdefcmd{ibnmajah}{1046}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالاَ حَدَّثَنَا نُوحُ بْنُ قَيْسٍ، حَدَّثَنَا عَمْرُو بْنُ مَالِكٍ، عَنْ أَبِي الْجَوْزَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتِ امْرَأَةٌ تُصَلِّي خَلْفَ النَّبِيِّ ـ صلى الله عليه وسلم ـ حَسْنَاءُ مِنْ أَحْسَنِ النَّاسِ فَكَانَ بَعْضُ الْقَوْمِ يَسْتَقْدِمُ فِي الصَّفِّ الأَوَّلِ لِئَلاَّ يَرَاهَا وَيَسْتَأْخِرُ بَعْضُهُمْ حَتَّى يَكُونَ فِي الصَّفِّ الْمُؤَخَّرِ فَإِذَا رَكَعَ قَالَ هَكَذَا يَنْظُرُ مِنْ تَحْتِ إِبْطِهِ فَأَنْزَلَ اللَّهُ ‏\{وَلَقَدْ عَلِمْنَا الْمُسْتَقْدِمِينَ مِنْكُمْ وَلَقَدْ عَلِمْنَا الْمُسْتَأْخِرِينَ\}‏ فِي شَأْنِهَا ‏.‏\hadithno{1046}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A woman used to perform prayer behind the Prophet (ﷺ), and she was one of the most beautiful of people. Some of the people used to go into the first row so that they would not see her, and some of them used to lag behind so that they would be in the last row, and when they bowed, they would do like this so that they could see her from beneath their armpits. Then Allah revealed: “And indeed, We know the first generations of you who had passed away, and indeed, We know the present generations of you (mankind), and also those who will some afterwards.” [15:24] concerning her matter}}
\hadithdefcmd{ibnmajah}{1047}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَى رَجُلٌ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ أَحَدُنَا يُصَلِّي فِي الثَّوْبِ الْوَاحِدِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ أَوَكُلُّكُمْ يَجِدُ ثَوْبَيْنِ ‏"‏ ‏.‏\hadithno{1047}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“A man came to the Prophet (ﷺ) and said: ‘O Messenger of Allah! One of us performs prayer in a single garment.’ The Prophet (ﷺ) said: ‘Does everyone have two garments?’”}}
\hadithdefcmd{ibnmajah}{1048}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ، أَنَّهُ دَخَلَ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ يُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُتَوَشِّحًا بِهِ ‏.‏\hadithno{1048}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa’eed Al-Khudri narrated that he entered upon the Messenger of Allah (ﷺ) when he was performing prayer in a single garment, wrapping himself in it}}
\hadithdefcmd{ibnmajah}{1049}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُتَوَشِّحًا بِهِ وَاضِعًا طَرَفَيْهِ عَلَى عَاتِقَيْهِ ‏.‏\hadithno{1049}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Umar bin Abu Salamah said:“I saw the Messenger of Allah (ﷺ) performing prayer in a single garment, wrapping himself in it and throwing the ends over his shoulders.”}}
\hadithdefcmd{ibnmajah}{1050}{حَدَّثَنَا أَبُو إِسْحَاقَ الشَّافِعِيُّ، إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ الْعَبَّاسِ حَدَّثَنَا مُحَمَّدُ بْنُ حَنْظَلَةَ بْنِ مُحَمَّدِ بْنِ عَبَّادٍ الْمَخْزُومِيُّ، عَنْ مَعْرُوفِ بْنِ مُشْكَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَيْسَانَ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي بِالْبِئْرِ الْعُلْيَا فِي ثَوْبٍ ‏.‏\hadithno{1050}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Kaisan that his father said:“I saw the Messenger of Allah (ﷺ) performing prayer at Bi’r ‘Ulya, in a garment.”}}
\hadithdefcmd{ibnmajah}{1051}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عَمْرُو بْنُ كَثِيرٍ، حَدَّثَنَا ابْنُ كَيْسَانَ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يُصَلِّي الظُّهْرَ وَالْعَصْرَ فِي ثَوْبٍ وَاحِدٍ مُتَلَبِّبًا بِهِ ‏.‏\hadithno{1051}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ibn Kaisan narrated that his father said:“I saw the Prophet (ﷺ) performing the Zuhr and the ‘Asr in a single garment, wrapping it around his chest.”}}
\hadithdefcmd{ibnmajah}{1052}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا قَرَأَ ابْنُ آدَمَ السَّجْدَةَ فَسَجَدَ اعْتَزَلَ الشَّيْطَانُ يَبْكِي يَقُولُ يَا وَيْلَهُ أُمِرَ ابْنُ آدَمَ بِالسُّجُودِ فَسَجَدَ فَلَهُ الْجَنَّةُ وَأُمِرْتُ بِالسُّجُودِ فَأَبَيْتُ فَلِيَ النَّارُ ‏"‏ ‏.‏\hadithno{1052}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘When a son of Adam recites a Sajdah* and prostrates, Satan withdraws weeping, saying: ‘Woe is me! The son of Adam was commanded to prostrate and he prostrated, and Paradise will be his; I was commanded to prostrate and I refused, so I am doomed to Hell.’” * An Ayah indicating prostration}}
\hadithdefcmd{ibnmajah}{1053}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ بْنِ خُنَيْسٍ، عَنِ الْحَسَنِ بْنِ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، قَالَ قَالَ لِي ابْنُ جُرَيْجٍ يَا حَسَنُ أَخْبَرَنِي جَدُّكَ، عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَتَاهُ رَجُلٌ فَقَالَ إِنِّي رَأَيْتُ الْبَارِحَةَ فِيمَا يَرَى النَّائِمُ كَأَنِّي أُصَلِّي إِلَى أَصْلِ شَجَرَةٍ فَقَرَأْتُ السَّجْدَةَ فَسَجَدْتُ فَسَجَدَتِ الشَّجَرَةُ لِسُجُودِي فَسَمِعْتُهَا تَقُولُ اللَّهُمَّ احْطُطْ عَنِّي بِهَا وِزْرًا وَاكْتُبْ لِي بِهَا أَجْرًا وَاجْعَلْهَا لِي عِنْدَكَ ذُخْرًا.‏ قَالَ ابْنُ عَبَّاسٍ فَرَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَرَأَ السَّجْدَةَ فَسَجَدَ فَسَمِعْتُهُ يَقُولُ فِي سُجُودِهِ مِثْلَ الَّذِي أَخْبَرَهُ الرَّجُلُ عَنْ قَوْلِ الشَّجَرَةِ.‏\hadithno{1053}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“I was with the Prophet (ﷺ), and a man came to him and said: ‘Last night while I was sleeping, I saw that I was praying towards the base of a tree. I recited (an Ayah of) prostration and prostrated, and the tree prostrated when I did, and I heard it saying: Allahummah-tut anni biha wizran, waktub li biha ajran, waj’al-ha li ‘indaka dhukhran (O Allah, reduce my burden of sin thereby, reward me for it and store it for me with You).’ Ibn ‘Abbas said: “I saw the Prophet (ﷺ) recite (an Ayah of) prostration and then prostrate, and I heard him saying in his prostration something like that which the man had told him the tree said.”}}
\hadithdefcmd{ibnmajah}{1054}{حَدَّثَنَا عَلِيُّ بْنُ عَمْرٍو الأَنْصَارِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الأُمَوِيُّ، عَنِ ابْنِ جُرَيْجٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنِ الأَعْرَجِ، عَنِ ابْنِ أَبِي رَافِعٍ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا سَجَدَ قَالَ ‏ "‏ اللَّهُمَّ لَكَ سَجَدْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ أَنْتَ رَبِّي سَجَدَ وَجْهِي لِلَّذِي شَقَّ سَمْعَهُ وَبَصَرَهُ تَبَارَكَ اللَّهُ أَحْسَنُ الْخَالِقِينَ ‏"‏ ‏.‏\hadithno{1054}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Ali that whenever the Prophet (ﷺ) prostrated he would say:“Allahumma laka sajadtu, wa bika amantu, wa laka aslamtu, Anta rabbi, sajada wajhi lilladhi shaqqa sam’ahu wa basarahu, tabarak Allah ahsanul-khaliqin (O Allah, to You I have prostrated, and in You I have believed, and to You I have submitted. You are my Lord; my face has prostrated to the One Who gave it hearing and sight. Blessed is Allah the best of Creators).”}}
\hadithdefcmd{ibnmajah}{1055}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ عُمَرَ الدِّمَشْقِيِّ، عَنْ أُمِّ الدَّرْدَاءِ، قَالَتْ حَدَّثَنِي أَبُو الدَّرْدَاءِ، أَنَّهُ سَجَدَ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ إِحْدَى عَشْرَةَ سَجْدَةً مِنْهُنَّ النَّجْمُ ‏.‏\hadithno{1055}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Darda’ said:“Abu Darda’ told me that he did eleven prostrations* with the Prophet (ﷺ), including An-Najm.” *Eleven Ayaat of prostrations}}
\hadithdefcmd{ibnmajah}{1056}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ فَائِدٍ، حَدَّثَنَا عَاصِمُ بْنُ رَجَاءِ بْنِ حَيْوَةَ، عَنِ الْمَهْدِيِّ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عُيَيْنَةَ بْنِ خَاطِرٍ، قَالَ حَدَّثَتْنِي عَمَّتِي أُمُّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ سَجَدْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ إِحْدَى عَشْرَةَ سَجْدَةً لَيْسَ فِيهَا مِنَ الْمُفَصَّلِ شَىْءٌ الأَعْرَافُ وَالرَّعْدُ وَالنَّحْلُ وَبَنِي إِسْرَائِيلَ وَمَرْيَمُ وَالْحَجُّ وَسَجْدَةُ الْفُرْقَانِ وَسُلَيْمَانُ سُورَةُ النَّمْلِ وَالسَّجْدَةُ وَفِي ص وَسَجْدَةُ الْحَوَامِيمِ ‏.‏\hadithno{1056}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Darda’ said:“I performed eleven prostrations with the Prophet (ﷺ) of which there were none in the Mufassal. Al-A’raf, Ar-Ra’d, An-Nahl, Bani Isra’il, Maryam, Al-Hajj, the prostration in Al-Furqan, Surat An-Naml (mentioning) Sulaiman, As- Sajdah, Sad, and the Ha-Mim Surah.”}}
\hadithdefcmd{ibnmajah}{1057}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، عَنْ نَافِعِ بْنِ يَزِيدَ، حَدَّثَنَا الْحَارِثُ بْنُ سَعِيدٍ الْعُتَقِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ مُنَيْنٍ، - مِنْ بَنِي عَبْدِ كِلاَلٍ - عَنْ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَقْرَأَهُ خَمْسَ عَشْرَةَ سَجْدَةً فِي الْقُرْآنِ مِنْهَا ثَلاَثٌ فِي الْمُفَصَّلِ وَفِي الْحَجِّ سَجْدَتَيْنِ ‏.‏\hadithno{1057}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Amr bin ‘As that the Messenger of Allah (ﷺ) taught him fifteen prostrations in the Qur’an, including three in the Mufassal and two in Al-Hajj}}
\hadithdefcmd{ibnmajah}{1058}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَطَاءِ بْنِ مِينَاءَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي ‏\{إِذَا السَّمَاءُ انْشَقَّتْ\}‏ وَ ‏\{اقْرَأْ بِاسْمِ رَبِّكَ\}‏\hadithno{1058}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“We prostrated with the Messenger of Allah (ﷺ) in “When the heaven is split asunder” [84:1] and “Read! In the Name of your Lord.” [96:]}}
\hadithdefcmd{ibnmajah}{1059}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ سَجَدَ فِي ‏\{إِذَا السَّمَاءُ انْشَقَّتْ\}‏.‏ قَالَ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ هَذَا الْحَدِيثُ مِنْ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ مَا سَمِعْتُ أَحَدًا يَذْكُرُهُ غَيْرَهُ.‏\hadithno{1059}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) prostrated in “When the heaven is split asunder.” [84:1] Abu Bakr bin Abu Shaibah said:"This Hadith was narrated from Yahya bin Sa'eed; I did not hear it from anyone but him}}
\hadithdefcmd{ibnmajah}{1060}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ فَصَلَّى وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي نَاحِيَةٍ مِنَ الْمَسْجِدِ فَجَاءَ فَسَلَّمَ فَقَالَ ‏"‏ وَعَلَيْكَ فَارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَرَجَعَ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ وَعَلَيْكَ فَارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ بَعْدُ ‏"‏ ‏.‏ قَالَ فِي الثَّالِثَةَ فَعَلِّمْنِي يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏إِذَا قُمْتَ إِلَى الصَّلاَةِ فَأَسْبِغِ الْوُضُوءَ ثُمَّ اسْتَقْبِلِ الْقِبْلَةَ وَكَبِّرْ، ثُمَّ اقْرَأْ مَا تَيَسَّرَ مَعَكَ مِنَ الْقُرْآنِ، ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا، ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ قَائِمًا، ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا، ثُمَّ ارْفَعْ رَأْسَكَ حَتَّى تَسْتَوِيَ قَاعِدًا، ثُمَّ افْعَلْ ذَلِكَ فِي صَلاَتِكَ كُلِّهَا"‏ ‏.‏\hadithno{1060}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that a man entered the mosque and performed prayer, and the Prophet (ﷺ) was in a corner of the mosque. The man came and greeted him, and he said:“And also upon you. Go back and repeat your prayer, for you have not prayed.” So he went back and repeated his prayer, then he came and greeted the Prophet (ﷺ). He said: “And also upon you. Go back and repeat your prayer, for you have not prayed.” On the third occasion, the man said: “Teach me, O Messenger of Allah!” He said: “When you stand up to offer the prayer, perform ablution properly, then stand to face the prayer direction and say Allahu Akbar. Then recite whatever you can of Qur’an, and then bow until you can feel at ease bowing. Then stand up until you feel at ease standing, then prostrate until you feel at ease prostrating. Then raise your head until you are sitting up straight. Do that throughout your prayer.”}}
\hadithdefcmd{ibnmajah}{1061}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، قَالَ سَمِعْتُ أَبَا حُمَيْدٍ السَّاعِدِيَّ، فِي عَشْرَةٍ مِنْ أَصْحَابِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِيهِمْ أَبُو قَتَادَةَ فَقَالَ أَبُو حُمَيْدٍ أَنَا أَعْلَمُكُمْ بِصَلاَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالُوا لِمَ فَوَاللَّهِ مَا كُنْتَ بِأَكْثَرِنَا لَهُ تَبَعَةً وَلاَ أَقْدَمَنَا لَهُ صُحْبَةً ‏.‏ قَالَ بَلَى ‏.‏ قَالُوا فَاعْرِضْ ‏.‏ قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا قَامَ إِلَى الصَّلاَةِ كَبَّرَ ثُمَّ رَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ وَيَقِرَّ كُلُّ عُضْوٍ مِنْهُ فِي مَوْضِعِهِ ثُمَّ يَقْرَأُ ثُمَّ يُكَبِّرُ وَيَرْفَعُ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ ثُمَّ يَرْكَعُ وَيَضَعُ رَاحَتَيْهِ عَلَى رُكْبَتَيْهِ مُعْتَمِدًا لاَ يَصُبُّ رَأْسَهُ وَلاَ يُقْنِعُ مُعْتَدِلاً ثُمَّ يَقُولُ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ وَيَرْفَعُ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ حَتَّى يَقِرَّ كُلُّ عَظْمٍ إِلَى مَوْضِعِهِ ثُمَّ يَهْوِي إِلَى الأَرْضِ وَيُجَافِي يَدَيْهِ عَنْ جَنْبَيْهِ ثُمَّ يَرْفَعُ رَأْسَهُ وَيَثْنِي رِجْلَهُ الْيُسْرَى فَيَقْعُدُ عَلَيْهَا وَيَفْتَخُ أَصَابِعَ رِجْلَيْهِ إِذَا سَجَدَ ثُمَّ يَسْجُدُ ثُمَّ يُكَبِّرُ وَيَجْلِسُ عَلَى رِجْلِهِ الْيُسْرَى حَتَّى يَرْجِعَ كُلُّ عَظْمٍ مِنْهُ إِلَى مَوْضِعِهِ ثُمَّ يَقُومُ فَيَصْنَعُ فِي الرَّكْعَةِ الأُخْرَى مِثْلَ ذَلِكَ ثُمَّ إِذَا قَامَ مِنَ الرَّكْعَتَيْنِ رَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ كَمَا صَنَعَ عِنْدَ افْتِتَاحِ الصَّلاَةِ ثُمَّ يُصَلِّي بَقِيَّةَ صَلاَتِهِ هَكَذَا حَتَّى إِذَا كَانَتِ السَّجْدَةُ الَّتِي يَنْقَضِي فِيهَا التَّسْلِيمُ أَخَّرَ إِحْدَى رِجْلَيْهِ وَجَلَسَ عَلَى شِقِّهِ الأَيْسَرِ مُتَوَرِّكًا ‏.‏ قَالُوا صَدَقْتَ هَكَذَا كَانَ يُصَلِّي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1061}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Muhammad bin ‘Amr bin ‘Ata’ said:‘While he was among ten of the Companions of the Messenger of Allah (ﷺ) including Abu Qatadah: “I heard Abu Humaid As-Sa’idi say: ‘I am the most knowledgeable of you concerning the prayer of the Messenger of Allah (ﷺ).’ They said: ‘Why? By Allah, you did not follow him more than we did, and you did not accompany him for longer.’ He said: ‘Yes I am.’ They said: ‘Show us.’ He said: ‘When the Messenger of Allah (ﷺ) stood up for prayer, he would say the Takbir, then he would raise his hands parallel to his shoulders, and every part of his body would settle in place. Then he would recite, then he would raise his hands parallel to his shoulders and bow, placing his palms on his knees and supporting his weight on them. He neither lowered his head, nor raised it up, it was evenly balanced (between either extreme). Then he would say: “Sami’ Allahu liman hamidah (Allah hears those who praise Him); and he would raise his hands parallel with his shoulders, until every bone returned to its place. Then he would prostrate himself on the ground, keeping his arms away from his sides. Then he would raise his head and tuck his left foot under him and sit on it, and he would spread his toes when he prostrated.* Then he would prostrate, then say the Takbir and sit on his left foot, until every bone returned to its place. Then he would stand up and do the same in the next Rak’ah. Then when he stood up after two Rak’ah, he would raise his hands level with his shoulders as he did at the beginning of the prayer. Then he would offer the rest of his prayer in like manner until, when he did the prostration after which the Taslim comes, he would push one of his feet back and sit with his weight on his left side, Mutawarrikan.’** They said: ‘You have spoken the truth; this is how the Messenger of Allah (ﷺ) used to perform the prayer.’” * Meaning that he would plant them in such a way that they were facing the Qiblah. ** Mutawarrikan: i.e., sitting with the left foot brought forward so that one's buttocks are in direct contact with the ground}}
\hadithdefcmd{ibnmajah}{1062}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ حَارِثَةَ بْنِ أَبِي الرِّجَالِ، عَنْ عَمْرَةَ، قَالَتْ سَأَلْتُ عَائِشَةَ كَيْفَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا تَوَضَّأَ فَوَضَعَ يَدَيْهِ فِي الإِنَاءِ سَمَّى اللَّهَ وَيُسْبِغُ الْوُضُوءَ ثُمَّ يَقُومُ فَيَسْتَقْبِلُ الْقِبْلَةَ فَيُكَبِّرُ وَيَرْفَعُ يَدَيْهِ حِذَاءَ مَنْكِبَيْهِ ثُمَّ يَرْكَعُ فَيَضَعُ يَدَيْهِ عَلَى رُكْبَتَيْهِ وَيُجَافِي بِعَضُدَيْهِ ثُمَّ يَرْفَعُ رَأْسَهُ فَيُقِيمُ صُلْبَهُ وَيَقُومُ قِيَامًا هُوَ أَطْوَلُ مِنْ قِيَامِكُمْ قَلِيلاً ثُمَّ يَسْجُدُ فَيَضَعُ يَدَيْهِ تِجَاهَ الْقِبْلَةِ وَيُجَافِي بِعَضُدَيْهِ مَا اسْتَطَاعَ فِيمَا رَأَيْتُ ثُمَّ يَرْفَعُ رَأْسَهُ فَيَجْلِسُ عَلَى قَدَمِهِ الْيُسْرَى وَيَنْصِبُ الْيُمْنَى وَيَكْرَهُ أَنْ يَسْقُطَ عَلَى شِقِّهِ الأَيْسَرِ ‏.‏\hadithno{1062}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Amrah said:“I asked ‘Aishah: ‘How did the Messenger of Allah (ﷺ) perform prayer?’ She said: ‘When the Prophet (ﷺ) performed ablution, he would put his hand in the vessel and say Bismillah, and he would perform ablution properly. Then he would stand and face the Qiblah. He would say the Takbir raising his hands parallel to his shoulders. Then he would bow, putting his hands on his knees and keeping his arms away from his sides. Then he would raise his head and straighten his back, and he would stand a little longer than your standing. Then he would prostrate, pointing his hands towards the Qiblah, keeping his arms away (from his sides) as much as possible, according to what I have seen. Then he would raise his head and sit on his left foot with his right foot held upright, and he disliked leaning towards his left side.’”}}
\hadithdefcmd{ibnmajah}{1063}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ زُبَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عُمَرَ، قَالَ صَلاَةُ السَّفَرِ رَكْعَتَانِ وَالْجُمُعَةُ رَكْعَتَانِ وَالْعِيدُ رَكْعَتَانِ تَمَامٌ غَيْرُ قَصْرٍ عَلَى لِسَانِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1063}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Umar said:“The prayer while traveling is two Rak’ah, and Friday is two Rak’ah, and ‘Eid is two Rak’ah. They are complete and are not shortened, as told by Muhammad (ﷺ).”}}
\hadithdefcmd{ibnmajah}{1064}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، أَنْبَأَنَا يَزِيدُ بْنُ زِيَادِ بْنِ أَبِي الْجَعْدِ، عَنْ زُبَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنْ عُمَرَ، قَالَ صَلاَةُ السَّفَرِ رَكْعَتَانِ وَصَلاَةُ الْجُمُعَةِ رَكْعَتَانِ وَالْفِطْرُ وَالأَضْحَى رَكْعَتَانِ تَمَامٌ غَيْرُ قَصْرٍ عَلَى لِسَانِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1064}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Umar said:“The prayer when traveling is two Rak’ah, and Friday is two Rak’ah, and Al-Fitr and Al-Adha are two Rak’ah, complete, not shortened, as told by Muhammad (ﷺ).”}}
\hadithdefcmd{ibnmajah}{1065}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي عَمَّارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَيْهِ، عَنْ يَعْلَى بْنِ أُمَيَّةَ، قَالَ سَأَلْتُ عُمَرَ بْنَ الْخَطَّابِ قُلْتُ لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَقْصُرُوا مِنَ الصَّلاَةِ إِنْ خِفْتُمْ أَنْ يَفْتِنَكُمُ الَّذِينَ كَفَرُوا وَقَدْ أَمِنَ النَّاسُ فَقَالَ عَجِبْتُ مِمَّا عَجِبْتَ مِنْهُ فَسَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ ذَلِكَ فَقَالَ ‏ "‏ صَدَقَةٌ تَصَدَّقَ اللَّهُ بِهَا عَلَيْكُمْ، فَاقْبَلُوا صَدَقَتَهُ ‏"‏ ‏.‏\hadithno{1065}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ya’la bin Umayyah said:“I asked ‘Umar bin Khattab: ‘Allah says: “And when you travel in the land, there is no sin on you if you shorten the prayer if you fear that the disbelievers may put you in trial (attack you), verily, the disbelievers are ever to you open enemies,” [4:101] but now there is security and people are safe.’ He said: ‘I found it strange just as you do, so I asked the Messenger of Allah (ﷺ) about that, and he said: “It is charity that Allah has bestowed upon you, so accept His charity.”}}
\hadithdefcmd{ibnmajah}{1066}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمَيَّةَ بْنِ عَبْدِ اللَّهِ بْنِ خَالِدٍ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ إِنَّا نَجِدُ صَلاَةَ الْحَضَرِ وَصَلاَةَ الْخَوْفِ فِي الْقُرْآنِ وَلاَ نَجِدُ صَلاَةَ السَّفَرِ فَقَالَ لَهُ عَبْدُ اللَّهِ إِنَّ اللَّهَ بَعَثَ إِلَيْنَا مُحَمَّدًا ـ صلى الله عليه وسلم ـ وَلاَ نَعْلَمُ شَيْئًا فَإِنَّمَا نَفْعَلُ كَمَا رَأَيْنَا مُحَمَّدًا ـ صلى الله عليه وسلم ـ يَفْعَلُ ‏.‏\hadithno{1066}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Umayyah bin ‘Abdullah bin Khalid that he said to ‘Abdullah bin ‘Umar:“We find (mention of) the prayer of the resident and the prayer in a state of fear in the Qur’an, but we do not find any mention of the prayer of the traveler. ‘Abdullah said to him: “Allah sent Muhammad (ﷺ) to us, and we did not know anything, rather we do what we saw Muhammad (ﷺ) doing.”}}
\hadithdefcmd{ibnmajah}{1067}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ بِشْرِ بْنِ حَرْبٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا خَرَجَ مِنْ هَذِهِ الْمَدِينَةِ لَمْ يَزِدْ عَلَى رَكْعَتَيْنِ، حَتَّى يَرْجِعَ إِلَيْهَا ‏.‏\hadithno{1067}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“When the Messenger of Allah (ﷺ) went out from this city (Al-Madinah) he did not perform more than two Rak’ah for prayer until he returned.”}}
\hadithdefcmd{ibnmajah}{1068}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، وَجُبَارَةُ بْنُ الْمُغَلِّسِ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: افْتَرَضَ اللَّهُ الصَّلاَةَ عَلَى لِسَانِ نَبِيِّكُمْ ـ صلى الله عليه وسلم ـ فِي الْحَضَرِ أَرْبَعًا وَفِي السَّفَرِ رَكْعَتَيْنِ ‏.‏\hadithno{1068}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Allah enjoined the prayer upon the tongue of your Prophet (ﷺ): Four Rak’ah while a resident and two Rak’ah when traveling.”}}
\hadithdefcmd{ibnmajah}{1069}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ إِبْرَاهِيمَ بْنِ إِسْمَاعِيلَ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ مُجَاهِدٍ، وَسَعِيدِ بْنِ جُبَيْرٍ، وَعَطَاءِ بْنِ أَبِي رَبَاحٍ، وَطَاوُسٍ، أَخْبَرُوهُ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ أَخْبَرَهُمْ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ فِي السَّفَرِ مِنْ غَيْرِ أَنْ يُعْجِلَهُ شَىْءٌ وَلاَ يَطْلُبَهُ عَدُوٌّ وَلاَ يَخَافَ شَيْئًا ‏.‏\hadithno{1069}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mujahid, Sa’eed bin Jubair, ‘Ata’ bin Abi Rabah and Tawus that Ibn ‘Abbas told them that the Messenger of Allah (ﷺ) used to combine the Maghrib and ‘Isha’ when traveling, although there was nothing to make him hurry and no enemy pursuing him, and he was not afraid of anything}}
\hadithdefcmd{ibnmajah}{1070}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ أَبِي الطُّفَيْلِ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ جَمَعَ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ فِي غَزْوَةِ تَبُوكَ فِي السَّفَرِ ‏.‏\hadithno{1070}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Mu’adh bin Jabal that the Prophet (ﷺ) combined the Zuhr and ‘Asr, and the Maghrib and ‘Isha’ when traveling during the campaign of Tabuk}}
\hadithdefcmd{ibnmajah}{1071}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا أَبُو عَامِرٍ، عَنْ عِيسَى بْنِ حَفْصِ بْنِ عَاصِمِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، حَدَّثَنِي أَبِي قَالَ، كَنَّا مَعَ ابْنِ عُمَرَ فِي سَفَرٍ فَصَلَّى بِنَا ثُمَّ انْصَرَفْنَا مَعَهُ وَانْصَرَفَ ‏.‏ قَالَ فَالْتَفَتَ فَرَأَى أُنَاسًا يُصَلُّونَ فَقَالَ مَا يَصْنَعُ هَؤُلاَءِ قُلْتُ يُسَبِّحُونَ ‏.‏ قَالَ لَوْ كُنْتُ مُسَبِّحًا لأَتْمَمْتُ صَلاَتِي يَا ابْنَ أَخِي إِنِّي صَحِبْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ فِي السَّفَرِ حَتَّى قَبَضَهُ اللَّهُ ثُمَّ صَحِبْتُ أَبَا بَكْرٍ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ ثُمَّ صَحِبْتُ عُمَرَ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ ثُمَّ صَحِبْتُ عُثْمَانَ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُمُ اللَّهُ وَاللَّهُ يَقُولُ ‏\{لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ ‏\}‏ ‏.‏\hadithno{1071}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Isa bin Hafs bin ‘Asim bin ‘Umar bin Khattab that his father told him:“We were with Ibn ‘Umar on a journey, and he led us in prayer. Then we finished with him and he finished turning around, and saw some people praying. He said: ‘What are these people doing?’ I said: ‘Glorifying Allah.’* He said: ‘If I wanted to glorify Allah (perform voluntary prayer) I would have completed my prayer. O son of my brother! I accompanied the Messenger of Allah (ﷺ) and he never prayed more than two Rak’ah when he was traveling, until Allah took his soul. Then I accompanied Abu Bakr and he never prayed more than two Rak’ah (when he was traveling), until Allah took his soul. Then I accompanied ‘Umar and he never prayed more than two Rak’ah, until Allah took his soul. Then I accompanied ‘Uthman and he never prayed more than two Rak’ah, until Allah took his soul. Allah says: ‘Indeed in the Messenger of Allah (Muhammad (ﷺ)) you have a good example to follow.’” [33:21] * Meaning, they were offering voluntary prayer}}
\hadithdefcmd{ibnmajah}{1072}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، قَالَ سَأَلْتُ طَاوُسًا عَنِ السُّبْحَةِ، فِي السَّفَرِ - وَالْحَسَنُ بْنُ مُسْلِمِ بْنِ يَنَّاقٍ جَالِسٌ عِنْدَهُ - فَقَالَ حَدَّثَنِي طَاوُسٌ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ فَرَضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَلاَةَ الْحَضَرِ وَصَلاَةَ السَّفَرِ فَكُنَّا نُصَلِّي فِي الْحَضَرِ قَبْلَهَا وَبَعْدَهَا وَكُنَّا نُصَلِّي فِي السَّفَرِ قَبْلَهَا وَبَعْدَهَا ‏.‏\hadithno{1072}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Usamah bin Zaid said:“I asked Tawus about performing voluntary prayer while traveling. Al-Hasan bin Muslim bin Yannaq was sitting with him and he said: ‘Tawus told me that he heard Ibn ‘Abbas say: “The Messenger of Allah (ﷺ) enjoined prayer while a resident and prayer when one is traveling. We used to pray when we were residents both before and after (the obligatory prayer), and we used to pray both before and after (the obligatory prayer) when we were traveling.’”}}
\hadithdefcmd{ibnmajah}{1073}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ الزُّهْرِيِّ، قَالَ سَأَلْتُ السَّائِبَ بْنَ يَزِيدَ مَاذَا سَمِعْتَ فِي، سُكْنَى مَكَّةَ قَالَ سَمِعْتُ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ، يَقُولُ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ ثَلاَثًا لِلْمُهَاجِرِ بَعْدَ الصَّدَرِ ‏"‏ ‏.‏\hadithno{1073}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdur-Rahman bin Humaid Az-Zuhri said:“I asked Sa’ib bin Yazid: ‘What have you heard about staying in Makkah?’ He said: ‘I heard ‘Ala’ bin Hadrami say: “The Prophet (ﷺ) said: ‘Three (days) for the Muhajir after departing (from Mina).’”* * The meaning of it is: being hished from the rites (of Hajj)}}
\hadithdefcmd{ibnmajah}{1074}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو عَاصِمٍ، وَقَرَأْتُهُ، عَلَيْهِ أَنْبَأَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، فِي أُنَاسٍ مَعِي قَالَ قَدِمَ النَّبِيُّ ـ صلى الله عليه وسلم ـ مَكَّةَ صُبْحَ رَابِعَةٍ مَضَتْ مِنْ شَهْرِ ذِي الْحِجَّةِ ‏.‏\hadithno{1074}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{‘Ata’ narrated:“Jabir bin ‘Abdullah, who was among the people with me, told me that the Prophet (ﷺ) arrived in Makkah in the morning of the fourth day of Dhul-Hijjah.”}}
\hadithdefcmd{ibnmajah}{1075}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَقَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ تِسْعَةَ عَشَرَ يَوْمًا يُصَلِّي رَكْعَتَيْنِ رَكْعَتَيْنِ، فَنَحْنُ إِذَا أَقَمْنَا تِسْعَةَ عَشَرَ يَوْمًا، نُصَلِّي رَكْعَتَيْنِ رَكْعَتَيْنِ، فَإِذَا أَقَمْنَا أَكْثَرَ مِنْ ذَلِكَ، صَلَّيْنَا أَرْبَعًا ‏.‏\hadithno{1075}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) stayed for nineteen days in which he shortened his prayer to two Rak’ah. So, whenever we stayed for nineteen days we would shorten our prayer to two Rak’ah, but if we stayed more than that we would pray four Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1076}{حَدَّثَنَا أَبُو يُوسُفَ الصَّيْدَلاَنِيُّ، مُحَمَّدُ بْنُ أَحْمَدَ الرَّقِّيُّ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَقَامَ بِمَكَّةَ عَامَ الْفَتْحِ خَمْسَ عَشْرَةَ لَيْلَةً يَقْصُرُ الصَّلاَةَ ‏.‏\hadithno{1076}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) stayed in Makkah for fifteen nights during the year of the Conquest, (during which time) he shortened his prayer}}
\hadithdefcmd{ibnmajah}{1077}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، وَعَبْدُ الأَعْلَى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ أَنَسٍ قَالَ: خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِنَ الْمَدِينَةِ إِلَى مَكَّةَ. فَصَلَّى رَكْعَتَيْنِ رَكْعَتَيْنِ، حَتَّى رَجَعْنَا ‏.‏ قُلْتُ: كَمْ أَقَامَ بِمَكَّةَ؟ قَالَ: عَشْرًا ‏.‏\hadithno{1077}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Yahya bin Abu Ishaq narrated that Anas said:“We went out with the Messenger of Allah (ﷺ) from Al-Madinah to Makkah, during which time we shortened our prayer to two Rak’ah, until we came back.” I asked: “How long did he stay in Makkah?” He said: “Ten (days).”}}
\hadithdefcmd{ibnmajah}{1078}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ بَيْنَ الْعَبْدِ وَبَيْنَ الْكُفْرِ تَرْكُ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1078}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) said: ‘Between a person and Kufr (disbelief) is abandoning the prayer.’”}}
\hadithdefcmd{ibnmajah}{1079}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الْبَالِسِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ شَقِيقٍ، حَدَّثَنَا حُسَيْنُ بْنُ وَاقِدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْعَهْدُ الَّذِي بَيْنَنَا وَبَيْنَهُمُ الصَّلاَةُ، فَمَنْ تَرَكَهَا فَقَدْ كَفَرَ ‏"‏ ‏.‏\hadithno{1079}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Abdullah bin Buraidah narrated that his father said:“The Messenger of Allah (ﷺ) said: ‘The covenant that distinguishes between us and them is prayer; so whoever leaves it, he has committed Kufr.’”}}
\hadithdefcmd{ibnmajah}{1080}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَمْرِو بْنِ سَعْدٍ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَيْسَ بَيْنَ الْعَبْدِ وَالشِّرْكِ إِلاَّ تَرْكُ الصَّلاَةِ، فَإِذَا تَرَكَهَا فَقَدْ أَشْرَكَ ‏"‏ ‏.‏\hadithno{1080}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) said:“There is nothing standing between a person and Shirk (polytheism) except leaving the prayer, so if he leaves it he has committed Shirk.”}}
\hadithdefcmd{ibnmajah}{1081}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا الْوَلِيدُ بْنُ بُكَيْرٍ أَبُو خَبَّابٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْعَدَوِيُّ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ تُوبُوا إِلَى اللَّهِ قَبْلَ أَنْ تَمُوتُوا وَبَادِرُوا بِالأَعْمَالِ الصَّالِحَةِ قَبْلَ أَنْ تُشْغَلُوا وَصِلُوا الَّذِي بَيْنَكُمْ وَبَيْنَ رَبِّكُمْ بِكَثْرَةِ ذِكْرِكُمْ لَهُ وَكَثْرَةِ الصَّدَقَةِ فِي السِّرِّ وَالْعَلاَنِيَةِ تُرْزَقُوا وَتُنْصَرُوا وَتُجْبَرُوا وَاعْلَمُوا أَنَّ اللَّهَ قَدِ افْتَرَضَ عَلَيْكُمُ الْجُمُعَةَ فِي مَقَامِي هَذَا فِي يَوْمِي هَذَا فِي شَهْرِي هَذَا مِنْ عَامِي هَذَا إِلَى يَوْمِ الْقِيَامَةِ فَمَنْ تَرَكَهَا فِي حَيَاتِي أَوْ بَعْدِي وَلَهُ إِمَامٌ عَادِلٌ أَوْ جَائِرٌ اسْتِخْفَافًا بِهَا أَوْ جُحُودًا بِهَا فَلاَ جَمَعَ اللَّهُ لَهُ شَمْلَهُ وَلاَ بَارَكَ لَهُ فِي أَمْرِهِ أَلاَ وَلاَ صَلاَةَ لَهُ وَلاَ زَكَاةَ لَهُ وَلاَ حَجَّ لَهُ وَلاَ صَوْمَ لَهُ وَلاَ بِرَّ لَهُ حَتَّى يَتُوبَ فَمَنْ تَابَ تَابَ اللَّهُ عَلَيْهِ أَلاَ لاَ تَؤُمَّنَّ امْرَأَةٌ رَجُلاً وَلاَ يَؤُمَّنَّ أَعْرَابِيٌّ مُهَاجِرًا وَلاَ يَؤُمَّ فَاجِرٌ مُؤْمِنًا إِلاَّ أَنْ يَقْهَرَهُ بِسُلْطَانٍ يَخَافُ سَيْفَهُ وَسَوْطَهُ ‏"‏ ‏.‏\hadithno{1081}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) delivered a sermon to us and said: ‘O people! Repent to Allah before you die. Hasten to do good deeds before you become preoccupied (because of sickness and old age). Uphold the relationship that exists between you and your Lord by remembering Him a great deal and by giving a great deal of charity in secret and openly. (Then) you will be granted provision and Divine support, and your condition will improve. Know that Allah has enjoined Friday upon you in this place of mine, on this day, in this month, in this year, until the Day of Resurrection. Whoever abandons it, whether during my lifetime or after I am gone, whether he has a just or an unjust ruler, whether he takes it lightly or denies (that it is obligatory), may Allah cause him to lose all sense of tranquility and contentment, and may He not bless him in his affairs. Indeed, his prayer will not be valid, his Zakat will not be valid, his Hajj will not be valid, his fasting will not be valid, and his righteous deeds will not be accepted, until he repents. Whoever repents, Allah will accept his repentance. No woman should be appointed as Imam over a man, no Bedouin should be appointed as Imam over a Muhajir, no immoral person should be appointed as Imam over a (true) believer, unless that is forced upon him and he fears his sword or whip.’”}}
\hadithdefcmd{ibnmajah}{1082}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ أَبُو سَلَمَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِيهِ أَبِي أُمَامَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، قَالَ: كُنْتُ قَائِدَ أَبِي حِينَ ذَهَبَ بَصَرُهُ، وَكُنْتُ إِذَا خَرَجْتُ بِهِ إِلَى الْجُمُعَةِ فَسَمِعَ الأَذَانَ اسْتَغْفَرَ لأَبِي أُمَامَةَ، أَسْعَدَ بْنِ زُرَارَةَ، وَدَعَا لَهُ، فَمَكَثْتُ حِينًا أَسْمَعُ ذَلِكَ مِنْهُ، ثُمَّ قُلْتُ فِي نَفْسِي: وَاللَّهِ إِنَّ ذَا لَعَجْزٌ، إِنِّي أَسْمَعُهُ كُلَّمَا سَمِعَ أَذَانَ الْجُمُعَةِ يَسْتَغْفِرُ لأَبِي أُمَامَةَ وَيُصَلِّي عَلَيْهِ، وَلاَ أَسْأَلُهُ عَنْ ذَلِكَ لِمَ هُوَ؟ فَخَرَجْتُ بِهِ كَمَا كُنْتُ أَخْرُجُ بِهِ إِلَى الْجُمُعَةِ. فَلَمَّا سَمِعَ الأَذَانَ اسْتَغْفَرَ كَمَا كَانَ يَفْعَلُ. فَقُلْتُ لَهُ: يَا أَبَتَاهُ أَرَأَيْتَكَ صَلاَتَكَ عَلَى أَسْعَدَ بْنِ زُرَارَةَ كُلَّمَا سَمِعْتَ النِّدَاءَ بِالْجُمُعَةِ لِمَ هُوَ؟ قَالَ: أَىْ بُنَىَّ كَانَ أَوَّلَ مَنْ صَلَّى بِنَا صَلاَةَ الْجُمُعَةِ قَبْلَ مَقْدَمِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ مَكَّةَ، فِي نَقِيعِ الْخَضِمَاتِ، فِي هَزْمٍ مِنْ حَرَّةِ بَنِي بَيَاضَةَ ‏.‏ قُلْتُ: كَمْ كُنْتُمُ يَوْمَئِذٍ؟ قَالَ: أَرْبَعِينَ رَجُلاً ‏.‏\hadithno{1082}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Abdur-Rahman bin Ka’b bin Malik said:“I used to guide my father after he lost his sight, and when I took him out for the Friday (prayer), when he heard the Adhan he would pray for forgiveness for Abu Umamah As’ad bin Zurarah, and supplicate for him. I heard that from him for a while, then I said to myself: ‘By Allah! What is this weakness? Every time he heard the Adhan for Friday (prayer) I hear him praying for forgiveness for Abu Umamah and supplicate for him, and I do not ask him about why he does that.’ Then I took him out for Friday (prayer), as I used to take him out, and when he heard the Adhan he prayed for forgiveness as he used to do. I said to him: ‘O my father! I see you supplicating for As’ad bin Zurarah every time you hear the call for Friday; why is that?’ He said: ‘O my son, he was the first one who led us for the Friday prayer before the Messenger of Allah (ﷺ) came from Makkah, in Naqi’ Al- Khadamat (a place near Al-Madinah), in the plain of Harrah Banu Bayadah.’ I asked: ‘How many of you were there at that time?’ He said: ‘Forty men.’”}}
\hadithdefcmd{ibnmajah}{1083}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا أَبُو مَالِكٍ الأَشْجَعِيُّ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، وَعَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَضَلَّ اللَّهُ عَنِ الْجُمُعَةِ مَنْ كَانَ قَبْلَنَا. كَانَ لِلْيَهُودِ يَوْمُ السَّبْتِ. وَالأَحَدُ لِلنَّصَارَى. فَهُمْ لَنَا تَبَعٌ إِلَى يَوْمِ الْقِيَامَةِ. نَحْنُ الآخِرُونَ مِنْ أَهْلِ الدُّنْيَا، وَالأَوَّلُونَ الْمَقْضِيُّ لَهُمْ قَبْلَ الْخَلاَئِقِ ‏"‏ ‏.‏\hadithno{1083}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Allah led those who came before us astray from Friday. Saturday was for the Jews and Sunday was for the Christians. And they will lag behind us until the Day of Resurrection. We are the last of the people of this world but we will be the first to be judged among all of creation.’”}}
\hadithdefcmd{ibnmajah}{1084}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ الأَنْصَارِيِّ، عَنْ أَبِي لُبَابَةَ بْنِ عَبْدِ الْمُنْذِرِ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ يَوْمَ الْجُمُعَةِ سَيِّدُ الأَيَّامِ، وَأَعْظَمُهَا عِنْدَ اللَّهِ. وَهُوَ أَعْظَمُ عِنْدَ اللَّهِ مِنْ يَوْمِ الأَضْحَى وَيَوْمِ الْفِطْرِ. فِيهِ خَمْسُ خِلاَلٍ. خَلَقَ اللَّهُ فِيهِ آدَمَ. وَأَهْبَطَ اللَّهُ فِيهِ آدَمَ إِلَى الأَرْضِ. وَفِيهِ تَوَفَّى اللَّهُ آدَمَ. وَفِيهِ سَاعَةٌ لاَ يَسْأَلُ اللَّهَ فِيهَا الْعَبْدُ شَيْئًا إِلاَّ أَعْطَاهُ. مَا لَمْ يَسْأَلْ حَرَامًا. وَفِيهِ تَقُومُ السَّاعَةُ. مَا مِنْ مَلَكٍ مُقَرَّبٍ وَلاَ سَمَاءٍ وَلاَ أَرْضٍ وَلاَ رِيَاحٍ وَلاَ جِبَالٍ وَلاَ بَحْرٍ إِلاَّ وَهُنَّ يُشْفِقْنَ مِنْ يَوْمِ الْجُمُعَةِ ‏"‏ ‏.‏\hadithno{1084}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Lubabah bin ‘Abdul-Mundhir said:“The Prophet (ﷺ) said: ‘Friday is the chief of days, the greatest day before Allah. It is greater before Allah then the Day of Adha and the Day of Fitr. It has five characteristics: On it Allah created Adam; on it Allah sent down Adam to this earth; on it there is a time during which a person does not ask Allah for anything but He will give it to him, so long as he does not ask for anything that is forbidden; on it the Hour will begin. There is no angel who is close to Allah, no heaven, no earth, no wind, no mountain, and no sea that does not fear Friday.’”}}
\hadithdefcmd{ibnmajah}{1085}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ مِنْ أَفْضَلِ أَيَّامِكُمْ يَوْمَ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ النَّفْخَةُ وَفِيهِ الصَّعْقَةُ فَأَكْثِرُوا عَلَىَّ مِنَ الصَّلاَةِ فِيهِ فَإِنَّ صَلاَتَكُمْ مَعْرُوضَةٌ عَلَىَّ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ كَيْفَ تُعْرَضُ صَلاَتُنَا عَلَيْكَ وَقَدْ أَرَمْتَ - يَعْنِي بَلِيتَ - ‏.‏ فَقَالَ ‏"‏ إِنَّ اللَّهَ قَدْ حَرَّمَ عَلَى الأَرْضِ أَنْ تَأْكُلَ أَجْسَادَ الأَنْبِيَاءِ ‏"‏ ‏.‏\hadithno{1085}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi}\hadithtrans{It was narrated that Shaddad bin Aws said:“The Messenger of Allah (ﷺ) said: ‘The best of your days is Friday. On it Adam was created, on it the Trumpet will be blown, on it all creatures will swoon. So send a great deal of peace and blessings upon me on that day, for your peace and blessings will be presented to me.’ A man said: ‘O Messenger of Allah, how will our peace and blessings be shown to you when you will have disintegrated?’ He said: ‘Allah has forbidden the earth to consume the bodies of the Prophets.’”}}
\hadithdefcmd{ibnmajah}{1086}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْجُمُعَةُ إِلَى الْجُمُعَةِ كَفَّارَةُ مَا بَيْنَهُمَا. مَا لَمْ تُغْشَ الْكَبَائِرُ ‏"‏ ‏.‏\hadithno{1086}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“From one Friday to the next is an expiation for whatever was committed in between, so long as one does not commit any major sin.”}}
\hadithdefcmd{ibnmajah}{1087}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنَا حَسَّانُ بْنُ عَطِيَّةَ، حَدَّثَنِي أَبُو الأَشْعَثِ، حَدَّثَنِي أَوْسُ بْنُ أَوْسٍ الثَّقَفِيُّ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ غَسَّلَ يَوْمَ الْجُمُعَةِ وَاغْتَسَلَ، وَبَكَّرَ وَابْتَكَرَ، وَمَشَى وَلَمْ يَرْكَبْ، وَدَنَا مِنَ الإِمَامِ، فَاسْتَمَعَ، وَلَمْ يَلْغُ، كَانَ لَهُ بِكُلِّ خَطْوَةٍ عَمَلُ سَنَةٍ، أَجْرُ صِيَامِهَا وَقِيَامِهَا ‏"‏ ‏.‏\hadithno{1087}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aws bin Aws Ath-Thaqafi said:“I heard the Prophet (ﷺ) say: ‘Whoever takes a bath on Friday, and bathes completely, and goes early, arriving early,* and walks and does not ride (to the mosque), and sits close to the Imam and listens to him, and does not engage in idle talk; for every step he takes he will have the reward of one year, the reward of a year’s fasting and praying (at night).”}}
\hadithdefcmd{ibnmajah}{1088}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ عَلَى الْمِنْبَرِ ‏ "‏ مَنْ أَتَى الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{1088}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“I heard the Prophet (ﷺ) say from the pulpit: ‘Whoever comes to Friday, let him take a bath.’”}}
\hadithdefcmd{ibnmajah}{1089}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ غُسْلُ يَوْمِ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏ ‏.‏\hadithno{1089}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“Bath on Fridays is obligatory for every male who has reached the age of puberty.”}}
\hadithdefcmd{ibnmajah}{1090}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ، ثُمَّ أَتَى الْجُمُعَةَ، فَدَنَا وَأَنْصَتَ وَاسْتَمَعَ، غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الْجُمُعَةِ الأُخْرَى، وَزِيَادَةُ ثَلاَثَةِ أَيَّامٍ. وَمَنْ مَسَّ الْحَصَى فَقَدْ لَغَا ‏"‏ ‏.‏\hadithno{1090}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever performs ablution and performs ablution well, then comes to Friday (prayer) and sits near (the Imam), and keeps quiet and listens, he will be forgiven for what was between that and the previous Friday (of sins), and three days more. And whoever touches the pebbles then he has engaged in Laghw (idle talk or behaviour).”}}
\hadithdefcmd{ibnmajah}{1091}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ الْمَكِّيُّ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ تَوَضَّأَ يَوْمَ الْجُمُعَةِ فَبِهَا وَنِعْمَتْ يُجْزِئُ عَنْهُ الْفَرِيضَةُ وَمَنِ اغْتَسَلَ فَالْغُسْلُ أَفْضَلُ ‏"‏ ‏.‏\hadithno{1091}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) said:“Whoever performs ablution on Friday, it is well and good for him, and he has done what is obligatory for him. But whoever takes a bath, bath is better.”}}
\hadithdefcmd{ibnmajah}{1092}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ إِذَا كَانَ يَوْمُ الْجُمُعَةِ، كَانَ عَلَى كُلِّ بَابٍ مِنْ أَبْوَابِ الْمَسْجِدِ مَلاَئِكَةٌ يَكْتُبُونَ النَّاسَ عَلَى قَدْرِ مَنَازِلِهِمُ. الأَوَّلَ فَالأَوَّلَ. فَإِذَا خَرَجَ الإِمَامُ طَوَوُا الصُّحُفَ، وَاسْتَمَعُوا الْخُطْبَةَ. فَالْمُهَجِّرُ إِلَى الصَّلاَةِ كَالْمُهْدِي بَدَنَةً. ثُمَّ الَّذِي يَلِيهِ كَمُهْدِي بَقَرَةٍ. ثُمَّ الَّذِي يَلِيهِ كَمُهْدِي كَبْشٍ ‏"‏ ‏.‏ حَتَّى ذَكَرَ الدَّجَاجَةَ وَالْبَيْضَةَ زَادَ سَهْلٌ فِي حَدِيثِهِ ‏"‏ فَمَنْ جَاءَ بَعْدَ ذَلِكَ فَإِنَّمَا يَجِيءُ بِحَقٍّ إِلَى الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1092}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When Friday comes, angels stand at every door of the mosque and record the names of the people who come, in order of arrival. When the Imam comes out, they close their records and listen to the sermon. The first one who comes to the prayer is like one who sacrifices a camel; the one who comes after him is like one who sacrifices a cow; the one who comes after him is like one who sacrifices a ram,” (and so on) until he made mention of a hen and an egg. Sahl added in his Hadith: “And whoever comes after that comes only to do his duty with regard to the prayer.”}}
\hadithdefcmd{ibnmajah}{1093}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سَعِيدِ بْنِ بَشِيرٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ضَرَبَ مَثَلَ الْجُمُعَةِ ثُمَّ التَّبْكِيرِ، كَنَاحِرِ الْبَدَنَةِ، كَنَاحِرِ الْبَقَرَةِ، كَنَاحِرِ الشَّاةِ، حَتَّى ذَكَرَ الدَّجَاجَةَ ‏.‏\hadithno{1093}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Samurah bin Jundab that the Messenger of Allah (ﷺ) described the likeness of Friday, saying that those who come earliest are like the one who sacrifices a camel, then like one who sacrifices a cow, then like one who sacrifices a sheep, until he made mention of a chicken}}
\hadithdefcmd{ibnmajah}{1094}{حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ الْحِمْصِيُّ، حَدَّثَنَا عَبْدُ الْمَجِيدِ بْنُ عَبْدِ الْعَزِيزِ، عَنْ مَعْمَرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ خَرَجْتُ مَعَ عَبْدِ اللَّهِ إِلَى الْجُمُعَةِ فَوَجَدَ ثَلاَثَةً قَدْ سَبَقُوهُ فَقَالَ رَابِعُ أَرْبَعَةٍ وَمَا رَابِعُ أَرْبَعَةٍ بِبَعِيدٍ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ النَّاسَ يَجْلِسُونَ مِنَ اللَّهِ يَوْمَ الْقِيَامَةِ عَلَى قَدْرِ رَوَاحِهِمْ إِلَى الْجُمُعَاتِ الأَوَّلَ وَالثَّانِيَ وَالثَّالِثَ ‏"‏ ‏.‏ ثُمَّ قَالَ رَابِعُ أَرْبَعَةٍ وَمَا رَابِعُ أَرْبَعَةٍ بِبَعِيدٍ ‏.‏\hadithno{1094}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Alqamah said:“I went out with ‘Abdullah to Friday (prayer), and he found three men who arrived before him. He said: ‘The fourth of four, and the fourth of four is not far away. I heard the Messenger of Allah (ﷺ) say: “On the Day of Resurrection people will gather near Allah according to how early they came to Friday (prayer), the first, second, and third.’” Then he said: ‘The fourth of four, and the fourth of four is not far away.’”}}
\hadithdefcmd{ibnmajah}{1095}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مُوسَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ عَلَى الْمِنْبَرِ فِي يَوْمِ الْجُمُعَةِ ‏ "‏ مَا عَلَى أَحَدِكُمْ لَوِ اشْتَرَى ثَوْبَيْنِ لِيَوْمِ الْجُمُعَةِ، سِوَى ثَوْبِ مِهْنَتِهِ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَيْخٌ، لَنَا عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، عَنْ أَبِيهِ، قَالَ خَطَبَنَا النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏.‏ فَذَكَرَ ذَلِكَ ‏.‏\hadithno{1095}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Abdullah bin Salam that he heard the Messenger of Allah (ﷺ) saying on the pulpit one Friday:“There is nothing wrong with anyone of you buying two garments for Friday (prayer), other than his daily work clothes.” (Another chain) from Yusuf bin Abdullah bin Salam that his father said: "The Prophet delivered a sermon to us" and he mentioned that}}
\hadithdefcmd{ibnmajah}{1096}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، عَنْ زُهَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ خَطَبَ النَّاسَ يَوْمَ الْجُمُعَةِ فَرَأَى عَلَيْهِمْ ثِيَابَ النِّمَارِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا عَلَى أَحَدِكُمْ، إِنْ وَجَدَ سَعَةً، أَنْ يَتَّخِذَ ثَوْبَيْنِ لِجُمُعَتِهِ، سِوَى ثَوْبَىْ مِهْنَتِهِ ‏"‏ ‏.‏\hadithno{1096}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) delivered a sermon to the people one Friday, and he saw them wearing woollen clothes. The Messenger of Allah (ﷺ) said:“There is nothing wrong with any one of you, if he can afford it, buying two garments for Friday, other than his daily work clothes.”}}
\hadithdefcmd{ibnmajah}{1097}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، وَحَوْثَرَةُ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ وَدِيعَةَ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ فَأَحْسَنَ غُسْلَهُ، وَتَطَهَّرَ فَأَحْسَنَ طُهُورَهُ، وَلَبِسَ مِنْ أَحْسَنِ ثِيَابِهِ، وَمَسَّ مَا كَتَبَ اللَّهُ لَهُ مِنْ طِيبِ أَهْلِهِ، ثُمَّ أَتَى الْجُمُعَةَ وَلَمْ يَلْغُ وَلَمْ يُفَرِّقْ بَيْنَ اثْنَيْنِ، غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الْجُمُعَةِ الأُخْرَى ‏"‏ ‏.‏\hadithno{1097}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Dharr that the Prophet (ﷺ) said:“Whoever takes a bath on a Friday and does it well, and purifies himself and does it well, and puts on his best clothes, and puts on whatever Allah decrees for him of the perfume of his family, then comes to the mosque and does not engage in idle talk or separate (pushing between) two people; he will be forgiven for (his sins) between that day and the previous Friday.”}}
\hadithdefcmd{ibnmajah}{1098}{حَدَّثَنَا عَمَّارُ بْنُ خَالِدٍ الْوَاسِطِيُّ، حَدَّثَنَا عَلِيُّ بْنُ غُرَابٍ، عَنْ صَالِحِ بْنِ أَبِي الأَخْضَرِ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ بْنِ السَّبَّاقِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ هَذَا يَوْمُ عِيدٍ، جَعَلَهُ اللَّهُ لِلْمُسْلِمِينَ. فَمَنْ جَاءَ إِلَى الْجُمُعَةِ فَلْيَغْتَسِلْ. وَإِنْ كَانَ طِيبٌ فَلْيَمَسَّ مِنْهُ. وَعَلَيْكُمْ بِالسِّوَاكِ ‏"‏ ‏.‏\hadithno{1098}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) said: ‘This day is an ‘Eid (festival) which Allah has ordained for the Muslims. Whoever comes to Friday (prayer), let him take a bath and if he has perfume then let him put some on. And upon you (I urge to use) is the tooth stick.”}}
\hadithdefcmd{ibnmajah}{1099}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ مَا كُنَّا نَقِيلُ وَلاَ نَتَغَدَّى إِلاَّ بَعْدَ الْجُمُعَةِ ‏.‏\hadithno{1099}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Sahl bin Sa’d said:“We did not take a Qailulah nor eat Ghada’ until after Friday (prayer).”}}
\hadithdefcmd{ibnmajah}{1100}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا يَعْلَى بْنُ الْحَارِثِ، قَالَ سَمِعْتُ إِيَاسَ بْنَ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ كُنَّا نُصَلِّي مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ الْجُمُعَةَ ثُمَّ نَرْجِعُ، فَلاَ نَرَى لِلْحِيطَانِ فَيْئًا نَسْتَظِلُّ بِهِ ‏.‏\hadithno{1100}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Iyas bin Salamah bin Akwa’ narrated that his father said:“We used to perform Friday (prayer) with the Prophet (ﷺ), then we would return, and we would not see any shadow from the walls in which we could seek shade.”}}
\hadithdefcmd{ibnmajah}{1101}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ عَمَّارِ بْنِ سَعْدٍ، مُؤَذِّنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ حَدَّثَنِي أَبِي عَنْ أَبِيهِ عَنْ جَدِّهِ أَنَّهُ كَانَ يُؤَذِّنُ يَوْمَ الْجُمُعَةِ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا كَانَ الْفَىْءُ مِثْلَ الشِّرَاكِ ‏.‏\hadithno{1101}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abdur-Rahman bin Sa’d bin ‘Ammar bin Sad, the Mu’adh-dhin of the Prophet (ﷺ), said:“My father told me, narrating from his father, from his grandfather, that during the time of the Messenger of Allah (ﷺ), he used to call the Adhan on Fridays when the shadow was like a sandal strap.”}}
\hadithdefcmd{ibnmajah}{1102}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ كُنَّا نُجَمِّعُ ثُمَّ نَرْجِعُ فَنَقِيلُ ‏.‏\hadithno{1102}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:“We used to perform the Friday (prayer), then we would return for a nap (Qailulah).”}}
\hadithdefcmd{ibnmajah}{1103}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ح وَحَدَّثَنَا يَحْيَى بْنُ خَلَفٍ أَبُو سَلَمَةَ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَخْطُبُ خُطْبَتَيْنِ يَجْلِسُ بَيْنَهُمَا جَلْسَةً ‏.‏ زَادَ بِشْرٌ وَهُوَ قَائِمٌ ‏.‏\hadithno{1103}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) used to deliver two sermons, and he would sit briefly between the two. (One of the narrators) Bishr added:“While he was standing.”}}
\hadithdefcmd{ibnmajah}{1104}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُسَاوِرٍ الْوَرَّاقِ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَخْطُبُ عَلَى الْمِنْبَرِ، وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{1104}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ja’far bin ‘Amr bin Huraith that his father said:“I saw the Prophet (ﷺ) delivering the sermon on the pulpit, wearing a black turban.”}}
\hadithdefcmd{ibnmajah}{1105}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَخْطُبُ قَائِمًا، غَيْرَ أَنَّهُ كَانَ يَقْعُدُ قَعْدَةً، ثُمَّ يَقُومُ ‏.‏\hadithno{1105}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Simak bin Harb said:“I heard Jabir bin Samurah say: ‘The Messenger of Allah (ﷺ) used to deliver the sermon standing, but he used to sit down briefly, then stand up.’”}}
\hadithdefcmd{ibnmajah}{1106}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَخْطُبُ قَائِمًا. ثُمَّ يَجْلِسُ. ثُمَّ يَقُومُ فَيَقْرَأُ آيَاتٍ. وَيَذْكُرُ اللَّ.هَ وَكَانَتْ خُطْبَتُهُ قَصْدًا، وَصَلاَتُهُ قَصْدًا ‏.‏\hadithno{1106}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:“The Prophet (ﷺ) used to deliver the sermon standing, then he would sit down, then he would stand up and recite some Verses and remember Allah. His sermon was moderate, and his prayer was moderate (i.e., neither too long nor too short).”}}
\hadithdefcmd{ibnmajah}{1107}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ عَمَّارِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا خَطَبَ فِي الْحَرْبِ، خَطَبَ عَلَى قَوْسٍ. وَإِذَا خَطَبَ فِي الْجُمُعَةِ، خَطَبَ عَلَى عَصًا ‏.‏\hadithno{1107}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abdur-Rahman bin Sa’d bin ‘Ammar bin Sa’d narrated that his father told him, from his father, from his grandfather, that when the Messenger of Allah (ﷺ) delivered a speech on the battlefield he would do so leaning on a bow, and when he delivered a sermon on Friday, he would do so leaning on his staff}}
\hadithdefcmd{ibnmajah}{1108}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي غَنِيَّةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ سُئِلَ أَكَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَخْطُبُ قَائِمًا أَوْ قَاعِدًا؟ قَالَ أَوَمَا تَقْرَأُ \{وَتَرَكُوكَ قَائِمًا\}‏ قَالَ أَبُو عَبْدِ اللَّهِ غَرِيبٌ لاَ يُحَدِّثُ بِهِ إِلاَّ ابْنُ أَبِي شَيْبَةَ وَحْدَهُ ‏.‏\hadithno{1108}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{‘Alqamah narrated that ‘Abdullah was asked whether the Prophet (ﷺ) used to deliver the sermon standing or sitting. He said:“Have you not read the Verse: ‘...and leave you (Muhammad) standing (while delivering the Friday sermon?” [62:)}}
\hadithdefcmd{ibnmajah}{1109}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ مُحَمَّدِ بْنِ زَيْدِ بْنِ مُهَاجِرٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا صَعِدَ الْمِنْبَرَ سَلَّمَ ‏.‏\hadithno{1109}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that whenever the Prophet (ﷺ) ascended the pulpit he would greet (the people with Salam)}}
\hadithdefcmd{ibnmajah}{1110}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا قُلْتَ لِصَاحِبِكَ: أَنْصِتْ، يَوْمَ الْجُمُعَةِ، وَالإِمَامُ يَخْطُبُ، فَقَدْ لَغَوْتَ ‏"‏ ‏.‏\hadithno{1110}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“If you say to your companions: ‘Be quiet’ on a Friday while the Imam is delivering the sermon, you have engaged in Laghw (idle talk or behaviour).”}}
\hadithdefcmd{ibnmajah}{1111}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَرَأَ يَوْمَ الْجُمُعَةِ تَبَارَكَ، وَهُوَ قَائِمٌ. فَذَكَّرَنَا بِأَيَّامِ اللَّهِ وَأَبُو الدَّرْدَاءِ أَوْ أَبُو ذَرٍّ يَغْمِزُنِي. فَقَالَ: مَتَى أُنْزِلَتْ هَذِهِ السُّورَةُ. إِنِّي لَمْ أَسْمَعْهَا إِلاَّ الآنَ ‏.‏ فَأَشَارَ إِلَيْهِ، أَنِ اسْكُتْ. فَلَمَّا انْصَرَفُوا قَالَ: سَأَلْتُكَ مَتَى أُنْزِلَتْ هَذِهِ السُّورَةُ فَلَمْ تُخْبِرْنِي؟ فَقَالَ أُبَىٌّ: لَيْسَ لَكَ مِنْ صَلاَتِكَ الْيَوْمَ إِلاَّ مَا لَغَوْتَ‏.‏ فَذَهَبَ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَكَرَ ذَلِكَ لَهُ وَأَخْبَرَهُ بِالَّذِي قَالَ أُبَىٌّ. فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَدَقَ أُبَىٌّ ‏"‏ ‏.‏\hadithno{1111}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Ata’ bin Yasar narrated from Ubayy bin Ka’b:“The Messenger of Allah (ﷺ) recited Tabarak [Al-Mulk (67)] one Friday, while he was standing and reminding us of the Days of Allah (i.e., preaching to us). Abu Darda’ or Abu Dharr raised an eyebrow at me and said: ‘When was this Surah revealed? For I have not heard it before now.’ He (Ubayy) gestured to him that he should remain silent. When they finished, he said: ‘I asked you when this Surah was revealed and you did not answer me.” Ubayy said: ‘You have gained nothing from your prayer today except the idle talk that you engaged in.’ He went to the Prophet (ﷺ) and told him about that, and what Ubayy had said to him. The Messenger of Allah (ﷺ) said: ‘Ubayy spoke the truth.’”}}
\hadithdefcmd{ibnmajah}{1112}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، سَمِعَ جَابِرًا، وَأَبُو الزُّبَيْرِ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ دَخَلَ سُلَيْكٌ الْغَطَفَانِيُّ الْمَسْجِدَ وَالنَّبِيُّ ـ صلى الله عليه وسلم ـ يَخْطُبُ ‏.‏ فَقَالَ ‏"‏ أَصَلَّيْتَ؟ ‏"‏ ‏.‏ قَالَ: لاَ ‏.‏ قَالَ ‏"‏ فَصَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏ وَأَمَّا عَمْرٌو فَلَمْ يَذْكُرْ سُلَيْكًا ‏.‏\hadithno{1112}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“Sulaik Ghatafani entered the mosque when the Prophet (ﷺ) was delivering the sermon. He said: ‘Have you prayed?’ He said: ‘No.’ He said: ‘Then perform two Rak’ah.’”}}
\hadithdefcmd{ibnmajah}{1113}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ، قَالَ جَاءَ رَجُلٌ وَالنَّبِيُّ ـ صلى الله عليه وسلم ـ يَخْطُبُ فَقَالَ ‏"‏ أَصَلَّيْتَ؟‏"‏ ‏.‏ قَالَ: لاَ ‏.‏ قَالَ: ‏"‏ فَصَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏\hadithno{1113}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa’eed said:“A man entered the mosque when the Prophet (ﷺ) was delivering the sermon. He said: ‘Have you prayed?’ He said: ‘No.’ He said: ‘Then pray two Rak’ah.’”}}
\hadithdefcmd{ibnmajah}{1114}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، وَعَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالاَ جَاءَ سُلَيْكٌ الْغَطَفَانِيُّ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَخْطُبُ فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَصَلَّيْتَ رَكْعَتَيْنِ قَبْلَ أَنْ تَجِيءَ؟ ‏"‏ قَالَ: لاَ ‏.‏ قَالَ: ‏"‏ فَصَلِّ رَكْعَتَيْنِ وَتَجَوَّزْ فِيهِمَا ‏"‏ ‏.‏\hadithno{1114}\hadithgrade{Al-Albani: Shadh; Muhammad Fouad Abd al-Baqi: Shadh; Shuaib Al Arnaut: Shadh; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“Sulaik Al-Ghatafani came while the Messenger of Allah (ﷺ) was delivering the sermon. The Prophet (ﷺ) said to him: ‘Did you perform two Rak’ah before you came?’ He said: ‘No.’ He said: ‘Then perform two Rak’ah, but make them brief.’”}}
\hadithdefcmd{ibnmajah}{1115}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنِ الْحَسَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ يَوْمَ الْجُمُعَةِ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَخْطُبُ فَجَعَلَ يَتَخَطَّى النَّاسَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اجْلِسْ فَقَدْ آذَيْتَ وَآنَيْتَ ‏"‏ ‏.‏\hadithno{1115}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that a man entered the mosque one Friday when the Messenger of Allah (ﷺ) was delivering the sermon. He started stepping over the people’s shoulders, and the Messenger of Allah (ﷺ) said:‘Sit down, for you have annoyed (people) and you are late.’”}}
\hadithdefcmd{ibnmajah}{1116}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ زَبَّانَ بْنِ فَائِدٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَخَطَّى رِقَابَ النَّاسِ يَوْمَ الْجُمُعَةِ اتُّخِذَ جِسْرًا إِلَى جَهَنَّمَ ‏"‏ ‏.‏\hadithno{1116}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sahl bin Mu’adh bin Anas that his father said:“The Messenger of Allah (ﷺ) said: ‘Whoever steps over the people’s necks on Friday has built a bridge to Hell.’”}}
\hadithdefcmd{ibnmajah}{1117}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُكَلَّمُ فِي الْحَاجَةِ إِذَا نَزَلَ عَنِ الْمِنْبَرِ يَوْمَ الْجُمُعَةِ ‏.‏\hadithno{1117}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Shadh; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the people used to speak to the Prophet (ﷺ) about their needs when he came down from the pulpit on Friday}}
\hadithdefcmd{ibnmajah}{1118}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ الْمَدَنِيُّ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، قَالَ: اسْتَخْلَفَ مَرْوَانُ أَبَا هُرَيْرَةَ عَلَى الْمَدِينَةِ. فَخَرَجَ إِلَى مَكَّةَ. فَصَلَّى بِنَا أَبُو هُرَيْرَةَ يَوْمَ الْجُمُعَةِ فَقَرَأَ بِسُورَةِ الْجُمُعَةِ، فِي السَّجْدَةِ الأُولَى. وَفِي الآخِرَةِ ‏\{إِذَا جَاءَكَ الْمُنَافِقُونَ\}‏ ‏.‏ قَالَ عُبَيْدُ اللَّهِ: فَأَدْرَكْتُ أَبَا هُرَيْرَةَ حِينَ انْصَرَفَ. فَقُلْتُ لَهُ: إِنَّكَ قَرَأْتَ بِسُورَتَيْنِ كَانَ عَلِيٌّ يَقْرَأُ بِهِمَا بِالْكُوفَةِ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ. إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْرَأُ بِهِمَا ‏.‏\hadithno{1118}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Ubaidullah bin Abu Rafi’ said:“Marwan appointed Abu Hurairah in charge of Al-Madinah, and set out for Makkah. Abu Hurairah led us in prayer on Friday, and he recited Surat Al-Jumu’ah in the first Rak’ah, and in the second, ‘When the hypocrites come to you,” [Al-Munafiqun (63)] ‘Ubaidullah said: “I caught up with Abu Hurairah when he finished and said to him: ‘You recited two Surah that ‘Ali used to recite in Kufah.’ Abu Hurairah said: ‘I heard the Messenger of Allah (ﷺ) reciting them.’”}}
\hadithdefcmd{ibnmajah}{1119}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، أَنْبَأَنَا ضَمْرَةُ بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ كَتَبَ الضَّحَّاكُ بْنُ قَيْسٍ إِلَى النُّعْمَانِ بْنِ بَشِيرٍ أَخْبِرْنَا بِأَىِّ، شَىْءٍ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَقْرَأُ يَوْمَ الْجُمُعَةِ مَعَ سُورَةِ الْجُمُعَةِ قَالَ كَانَ يَقْرَأُ فِيهَا ‏\{هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ‏\}‏ ‏.‏\hadithno{1119}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Ubaidullah bin ‘Abdullah said:“Dahhak bin Qais wrote to Nu’man bin Bashir, saying: ‘Tell us what the Messenger of Allah (ﷺ) used to recite on Friday along with Surah Al-Jumu’ah.’ He said: ‘He used to recite: “Has there come to you the narration of the overwhelming (i.e., the Day of Resurrection)?’” [Al-Ghashiyah]}}
\hadithdefcmd{ibnmajah}{1120}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ سِنَانٍ، عَنْ أَبِي الزَّاهِرِيَّةِ، عَنْ أَبِي عِنَبَةَ الْخَوْلاَنِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقْرَأُ فِي الْجُمُعَةِ بِـ ‏\{سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى\}‏ وَ ‏\{هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ\}‏ ‏.‏\hadithno{1120}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu ‘Inabah Al-Khawlani that the Prophet (ﷺ) used to recite “Glorify the Name of your Lord the Most High” and “Has there come to you the narration of the overwhelming (i.e., the Day of Resurrection)? [Al-A’la (87) and Al-Ghashiyah (88)] on Friday}}
\hadithdefcmd{ibnmajah}{1121}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عُمَرُ بْنُ حَبِيبٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الْجُمُعَةِ رَكْعَةً فَلْيُصَلِّ إِلَيْهَا أُخْرَى ‏"‏ ‏.‏\hadithno{1121}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever catches one Rak’ah of Friday, let him add another Rak’ah to it.”}}
\hadithdefcmd{ibnmajah}{1122}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصَّلاَةِ رَكْعَةً فَقَدْ أَدْرَكَ ‏"‏ ‏.‏\hadithno{1122}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever catches one Rak’ah of prayer, he has caught it.’”}}
\hadithdefcmd{ibnmajah}{1123}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ الأَيْلِيُّ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنْ صَلاَةِ الْجُمُعَةِ أَوْ غَيْرِهَا، فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{1123}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘Whoever catches one Rak’ah of Friday prayer or other than it, then he has caught the prayer.’”}}
\hadithdefcmd{ibnmajah}{1124}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ إِنَّ أَهْلَ قُبَاءَ كَانُوا يُجَمِّعُونَ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ الْجُمُعَةِ ‏.‏\hadithno{1124}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn ‘Umar said:“The people of Quba’ used to pray with the Messenger of Allah (ﷺ) on Fridays.”}}
\hadithdefcmd{ibnmajah}{1125}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَيَزِيدُ بْنُ هَارُونَ، وَمُحَمَّدُ بْنُ بِشْرٍ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنِي عَبِيدَةُ بْنُ سُفْيَانَ الْحَضْرَمِيُّ، عَنْ أَبِي الْجَعْدِ الضَّمْرِيِّ، - وَكَانَ لَهُ صُحْبَةٌ - قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَرَكَ الْجُمُعَةَ ثَلاَثَ مَرَّاتٍ، تَهَاوُنًا بِهَا، طُبِعَ عَلَى قَلْبِهِ ‏"‏ ‏.‏\hadithno{1125}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Ja’d Ad-Damri who was a Companion said that the Prophet (ﷺ) said:“Whoever abandons Friday (prayer) three times, neglecting it, a seal will be placed over his heart.”}}
\hadithdefcmd{ibnmajah}{1126}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَسِيدِ بْنِ أَبِي أَسِيدٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عِيسَى الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ أَسِيدِ بْنِ أَبِي أَسِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَرَكَ الْجُمُعَةَ، ثَلاَثًا، مِنْ غَيْرِ ضَرُورَةٍ، طَبَعَ اللَّهُ عَلَى قَلْبِهِ ‏"‏ ‏.‏\hadithno{1126}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) said: ‘Whoever abandons Friday (prayer) three times, for no necessary reason, Allah will place a seal over his heart.’”}}
\hadithdefcmd{ibnmajah}{1127}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مَعْدِيُّ بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَلاَ هَلْ عَسَى أَحَدُكُمْ أَنْ يَتَّخِذَ الصُّبَّةَ مِنَ الْغَنَمِ عَلَى رَأْسِ مِيلٍ أَوْ مِيلَيْنِ، فَيَتَعَذَّرَ عَلَيْهِ الْكَلأُ، فَيَرْتَفِعَ. ثُمَّ تَجِيءُ الْجُمُعَةُ فَلاَ يَجِيءُ وَلاَ يَشْهَدُهَا وَتَجِيءُ الْجُمُعَةُ فَلاَ يَشْهَدُهَا. وَتَجِيءُ الْجُمُعَةُ فَلاَ يَشْهَدُهَا. حَتَّى يُطْبَعَ عَلَى قَلْبِهِ ‏"‏ ‏.‏\hadithno{1127}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:The Messenger of Allah (ﷺ) said: “What if one of you were to take a flock of sheep and look for grass for them one or two miles away, but he cannot find any at that distance, so he goes further away? Then (the time for) Friday comes but he does not attend it, then (another) Friday comes but he does not attend it, and (another) Friday comes but he does not attend it, until Allah places a seal on his heart.”}}
\hadithdefcmd{ibnmajah}{1128}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا نُوحُ بْنُ قَيْسٍ، عَنْ أَخِيهِ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ تَرَكَ الْجُمُعَةَ مُتَعَمِّدًا، فَلْيَتَصَدَّقْ بِدِينَارٍ، فَإِنْ لَمْ يَجِدْ، فَبِنِصْفِ دِينَارٍ ‏"‏ ‏.‏\hadithno{1128}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Samurah bin Jundab that the Prophet (ﷺ) said:“Whoever abandons Friday deliberately, let him give a Dinar in charity, and if he cannot afford that, then (let him give) half a Dinar.”}}
\hadithdefcmd{ibnmajah}{1129}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ رَبِّهِ، حَدَّثَنَا بَقِيَّةُ، عَنْ مُبَشِّرِ بْنِ عُبَيْدٍ، عَنْ حَجَّاجِ بْنِ أَرْطَاةَ، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَرْكَعُ مِنْ قَبْلِ الْجُمُعَةِ أَرْبَعًا، لاَ يَفْصِلُ فِي شَىْءٍ مِنْهُنَّ ‏.‏\hadithno{1129}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) used to perform four Rak’ah before Friday (prayer), and he did not separate any of them.”}}
\hadithdefcmd{ibnmajah}{1130}{حَدَّثَنَا مُحَمَّدُ بْنَ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ إِذَا صَلَّى الْجُمُعَةَ انْصَرَفَ فَصَلَّى سَجْدَتَيْنِ فِي بَيْتِهِ ثُمَّ قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَصْنَعُ ذَلِكَ ‏.‏\hadithno{1130}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that when ‘Abdullah bin ‘Umar had prayed Friday, he went and prayed two Rak’ah in his house. Then he said:“The Messenger of Allah (ﷺ) used to do that.”}}
\hadithdefcmd{ibnmajah}{1131}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ ‏.‏\hadithno{1131}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim, from his father, that the Prophet (ﷺ) used to pray two Rak’ah after Jumu’ah}}
\hadithdefcmd{ibnmajah}{1132}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو السَّائِبِ، سَلْمُ بْنُ جُنَادَةَ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا صَلَّيْتُمْ بَعْدَ الْجُمُعَةِ، فَصَلُّوا أَرْبَعًا ‏"‏ ‏.‏\hadithno{1132}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘If you pray after Friday, then pray four (Rak’ah).’”}}
\hadithdefcmd{ibnmajah}{1133}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا ابْنُ لَهِيعَةَ، جَمِيعًا عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُحَلَّقَ فِي الْمَسْجِدِ يَوْمَ الْجُمُعَةِ قَبْلَ الصَّلاَةِ ‏.‏\hadithno{1133}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, from his grandfather, that the Messenger of Allah (ﷺ) forbade sitting in circles in the mosque on Fridays before the prayer}}
\hadithdefcmd{ibnmajah}{1134}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ عَبْدِ اللَّهِ بْنِ وَاقِدٍ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ الاِحْتِبَاءِ يَوْمَ الْجُمُعَةِ - يَعْنِي - وَالإِمَامُ يَخْطُبُ ‏.‏\hadithno{1134}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) forbade Ihtiba’ (sitting with one's thighs gathered up against the stomach while wrapping one's arm or garment around them) on Fridays, meaning, when the Imam is delivering the sermon.”}}
\hadithdefcmd{ibnmajah}{1135}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى الْقَطَّانُ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، جَمِيعًا عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ مَا كَانَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِلاَّ مُؤَذِّنٌ وَاحِدٌ. فَإِذَا خَرَجَ أَذَّنَ، وَإِذَا نَزَلَ أَقَامَ. وَأَبُو بَكْرٍ وَعُمَرُ كَذَلِكَ. فَلَمَّا كَانَ عُثْمَانُ، وَكَثُرَ النَّاسُ، زَادَ النِّدَاءَ الثَّالِثَ عَلَى دَارٍ فِي السُّوقِ، يُقَالُ لَهَا الزَّوْرَاءُ. فَإِذَا خَرَجَ أَذَّنَ، وَإِذَا نَزَلَ أَقَامَ ‏.‏\hadithno{1135}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa’ib bin Yazid said:“The Messenger of Allah (ﷺ) had only one Mu’adh-dhin. When he came out he would give the Adhan and when he came down (from the pulpit) he would give the Iqamah. Abu Bakr and ‘Umar did likewise, but when ‘Uthman (became caliph) the numbers of people had increased, he added the third call from atop a house in the marketplace that was called Zawra’. When he came out (the Mu’adh-dhin) would call the Adhan, and when he came down from the pulpit, he would call the Iqamah}}
\hadithdefcmd{ibnmajah}{1136}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْهَيْثَمُ بْنُ جَمِيلٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ أَبَانَ بْنِ تَغْلِبَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا قَامَ عَلَى الْمِنْبَرِ اسْتَقْبَلَهُ أَصْحَابُهُ بِوُجُوهِهِمْ ‏.‏\hadithno{1136}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Adi bin Thabit that his father said:“When the Prophet (ﷺ) stood on the pulpit, his Companions would turn to face him.”}}
\hadithdefcmd{ibnmajah}{1137}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ فِي الْجُمُعَةِ سَاعَةً، لاَ يُوَافِقُهَا رَجُلٌ مُسْلِمٌ، قَائِمٌ يُصَلِّي، يَسْأَلُ اللَّهَ فِيهَا خَيْرًا، إِلاَّ أَعْطَاهُ ‏"‏ ‏.‏ وَقَلَّلَهَا بِيَدِهِ ‏.‏\hadithno{1137}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘On Friday there is a time when no Muslim man happens to stand in prayer at that time, asking Allah for good things, but He will give that to him.” And he gestured with his hand to indicate how short that time is}}
\hadithdefcmd{ibnmajah}{1138}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ الْمُزَنِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ: ‏"‏ فِي يَوْمِ الْجُمُعَةِ سَاعَةٌ مِنَ النَّهَارِ، لاَ يَسْأَلُ اللَّهَ فِيهَا الْعَبْدُ شَيْئًا إِلاَّ أُعْطِيَ سُؤْلَهُ ‏"‏ قِيلَ: أَىُّ سَاعَةٍ؟ قَالَ ‏"‏ حِينَ تُقَامُ الصَّلاَةُ إِلَى الاِنْصِرَافِ مِنْهَا ‏"‏ ‏.‏\hadithno{1138}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin ‘Abdullah bin ‘Amr bin ‘Awf Al-Muzani narrated from his father, that his grandfather said:“I heard the Messenger of Allah (ﷺ) say: ‘On Friday there is a time of the day during which no person asks Allah for something but He will give him what he asks for.’” It was said: ‘When is that time?’ He said: ‘When the Iqamah for prayer (is called), until the prayer ends.’”}}
\hadithdefcmd{ibnmajah}{1139}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، قَالَ قُلْتُ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ جَالِسٌ إِنَّا لَنَجِدُ فِي كِتَابِ اللَّهِ فِي يَوْمِ الْجُمُعَةِ سَاعَةٌ لاَ يُوَافِقُهَا عَبْدٌ مُؤْمِنٌ يُصَلِّي يَسْأَلُ اللَّهَ فِيهَا شَيْئًا إِلاَّ قَضَى لَهُ حَاجَتَهُ ‏.‏ قَالَ عَبْدُ اللَّهِ فَأَشَارَ إِلَىَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَوْ بَعْضُ سَاعَةٍ ‏.‏ فَقُلْتُ صَدَقْتَ، أَوْ بَعْضُ سَاعَةٍ ‏.‏ قُلْتُ: أَىُّ سَاعَةٍ هِيَ؟ قَالَ: ‏"‏ هِيَ آخِرُ سَاعَةٍ مِنْ سَاعَاتِ النَّهَارِ ‏"‏ قُلْتُ: إِنَّهَا لَيْسَتْ سَاعَةَ صَلاَةٍ ‏.‏ قَالَ: ‏"‏ بَلَى. إِنَّ الْعَبْدَ الْمُؤْمِنَ إِذَا صَلَّى ثُمَّ جَلَسَ، لاَ يَحْبِسُهُ إِلاَّ الصَّلاَةُ، فَهُوَ فِي صَلاَةٍ ‏"‏ ‏.‏\hadithno{1139}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah bin Salam said:“I said, when the Messenger of Allah (ﷺ) was sitting: ‘We find in the Book of Allah that on Friday there is an hour when no believing slave performs prayer and asks Allah for anything at that time, but Allah will fulfill his need.’” ‘Abdullah said: “The Messenger of Allah (ﷺ) pointed to me, saying: ‘Or some part of an hour.’ I said: ‘you are right, or some part of an hour.’ I said: ‘What time is that?’ He said: ‘It is the last hours of the day.’ I said: ‘It is not the time of the prayer?’ He said: ‘Yes (it is so), when a believing slave performs prayer and then sits with nothing but the prayer keeping him, he is still in a state of prayer.’”}}
\hadithdefcmd{ibnmajah}{1140}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ الرَّازِيُّ، عَنْ مُغِيرَةَ بْنِ زِيَادٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ ثَابَرَ عَلَى ثِنْتَىْ عَشْرَةَ رَكْعَةً مِنَ السُّنَّةِ، بُنِيَ لَهُ بَيْتٌ فِي الْجَنَّةِ. أَرْبَعٍ قَبْلَ الظُّهْرِ، وَرَكْعَتَيْنِ بَعْدَ الظُّهْرِ، وَرَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ، وَرَكْعَتَيْنِ بَعْدَ الْعِشَاءِ، وَرَكْعَتَيْنِ قَبْلَ الْفَجْرِ ‏"‏ ‏.‏\hadithno{1140}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) said: ‘Whoever persists in performing twelve Rak’ah from the Sunnah, a house will be built for him in Paradise: four before the Zuhr, two Rak’ah after Zuhr, two Rak’ah after Maghrib, two Rak’ah after the ‘Isha’ and two Rak’ah before Fajr.’”}}
\hadithdefcmd{ibnmajah}{1141}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّ حَبِيبَةَ بِنْتِ أَبِي سُفْيَانَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ صَلَّى فِي يَوْمٍ وَلَيْلَةٍ ثِنْتَىْ عَشْرَةَ رَكْعَةً، بُنِيَ لَهُ بَيْتٌ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1141}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Umm Habibah bint Abi Sufyan that the Prophet (ﷺ) said:“Whoever performs twelve Rak’ah (of Sunnah) during the day and night, a house will be built for him in Paradise.”}}
\hadithdefcmd{ibnmajah}{1142}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ بْنِ الأَصْبَهَانِيِّ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَلَّى فِي يَوْمٍ ثِنْتَىْ عَشْرَةَ رَكْعَةً بُنِيَ لَهُ بَيْتٌ فِي الْجَنَّةِ رَكْعَتَيْنِ قَبْلَ الْفَجْرِ وَرَكْعَتَيْنِ قَبْلَ الظُّهْرِ وَرَكْعَتَيْنِ بَعْدَ الظُّهْرِ وَرَكْعَتَيْنِ - أَظُنُّهُ قَالَ - قَبْلَ الْعَصْرِ وَرَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ - أَظُنُّهُ قَالَ - وَرَكْعَتَيْنِ بَعْدَ الْعِشَاءِ الآخِرَةِ ‏"‏ ‏.‏\hadithno{1142}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever performs twelve Rak’ah (of Sunnah) each day, a house will be built for him in Paradise: two Rak’ah before Fajr, two Rak’ah before the Zuhr, two Rak’ah after the Zuhr, two Rak’ah, I think he said, before ‘Asr, two Rak’ah after Maghrib, and I think he said two Rak’ah after the ‘Isha’.’”}}
\hadithdefcmd{ibnmajah}{1143}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أَضَاءَ الْفَجْرُ صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{1143}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that when the dawn illuminated, the Prophet (ﷺ) would pray two Rak’ah}}
\hadithdefcmd{ibnmajah}{1144}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي الرَّكْعَتَيْنِ قَبْلَ الْغَدَاةِ كَأَنَّ الأَذَانَ بِأُذُنَيْهِ ‏.‏\hadithno{1144}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) used to pray two Rak’ah before the morning (prayer), as if the Adhan were in his ears. (i.e., he would pray them briefly)}}
\hadithdefcmd{ibnmajah}{1145}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ بِنْتِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا نُودِيَ لِصَلاَةِ الصُّبْحِ رَكَعَ رَكْعَتَيْنِ خَفِيفَتَيْنِ قَبْلَ أَنْ يَقُومَ إِلَى الصَّلاَةِ ‏.‏\hadithno{1145}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Hafsah bint ‘Umar that when the call for the Subh prayer was given, the Messenger of Allah (ﷺ) would pray two short Rak’ah before going to the prayer}}
\hadithdefcmd{ibnmajah}{1146}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا تَوَضَّأَ صَلَّى رَكْعَتَيْنِ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ ‏.‏\hadithno{1146}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“When he performed ablution the Prophet (ﷺ) would pray two (short) Rak’ah and then go out for the prayer.”}}
\hadithdefcmd{ibnmajah}{1147}{حَدَّثَنَا الْخَلِيلُ بْنُ عَمْرٍو أَبُو عَمْرٍو، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي الرَّكْعَتَيْنِ عِنْدَ الإِقَامَةِ ‏.‏\hadithno{1147}\hadithgrade{Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The Prophet (ﷺ) used to perform two Rak’ah at the time of the Iqamah.”}}
\hadithdefcmd{ibnmajah}{1148}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَرَأَ فِي الرَّكْعَتَيْنِ قَبْلَ الْفَجْرِ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ‏\}‏ وَ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏\hadithno{1148}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that in the two Rak’ah before the Fajr, the Prophet (ﷺ) used to recite:“Say: ‘O you disbelievers!” [Al-Kafirun (109)] and “Say: Allah is One.” [Al-Ikhlas]}}
\hadithdefcmd{ibnmajah}{1149}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، وَمُحَمَّدُ بْنُ عَبَادَةَ الْوَاسِطِيَّانِ، قَالاَ حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَمَقْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ شَهْرًا فَكَانَ يَقْرَأُ فِي الرَّكْعَتَيْنِ قَبْلَ الْفَجْرِ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ\}‏ وَ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ\}‏ ‏.‏\hadithno{1149}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“I watched the Prophet (ﷺ) for a month, and in the two Rak’ah before Fajr he used to recite: “Say: O you disbelievers!” [Al-Kafirun (109)] and “Say: Allah is One.” [Al- Ikhlas]}}
\hadithdefcmd{ibnmajah}{1150}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي رَكْعَتَيْنِ قَبْلَ الْفَجْرِ وَكَانَ يَقُولُ ‏"‏ نِعْمَ السُّورَتَانِ هُمَا يُقْرَأُ بِهِمَا فِي رَكْعَتَىِ الْفَجْرِ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ وَ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ\}‏ ‏.‏\hadithno{1150}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) used to perform two Rak’ah before Fajr, and he used to say: ‘The best two Surah to recite in the two Rak’ah of Fajr are: “Say: Allah is One” [Al-Ikhlas (112)] and “Say: O you disbelievers.” [Al-Kafirun]}}
\hadithdefcmd{ibnmajah}{1151}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَزْهَرُ بْنُ الْقَاسِمِ، ح وَحَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، قَالاَ حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ، فَلاَ صَلاَةَ إِلاَّ الْمَكْتُوبَةُ ‏"‏ ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِمِثْلِهِ ‏.‏\hadithno{1151}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Once the Iqamah has been called, there should be no prayer but the obligatory one.” Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{1152}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى رَجُلاً يُصَلِّي الرَّكْعَتَيْنِ قَبْلَ صَلاَةِ الْغَدَاةِ وَهُوَ فِي الصَّلاَةِ فَلَمَّا صَلَّى قَالَ لَهُ: ‏ "‏ بِأَىِّ صَلاَتَيْكَ اعْتَدَدْتَ؟ ‏"‏ ‏.‏\hadithno{1152}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin Sarjis that the Messenger of Allah (ﷺ) saw a man performing the two Rak’ah before the morning prayer while he himself was performing prayer. When he had finished praying he said to him:“Which of your two prayers did you intend to be counted (i.e., accepted)?”}}
\hadithdefcmd{ibnmajah}{1153}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكِ ابْنِ بُحَيْنَةَ، قَالَ مَرَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِرَجُلٍ وَقَدْ أُقِيمَتْ صَلاَةُ الصُّبْحِ وَهُوَ يُصَلِّي فَكَلَّمَهُ بِشَىْءٍ لاَ أَدْرِي مَا هُوَ فَلَمَّا انْصَرَفَ أَحَطْنَا بِهِ نَقُولُ لَهُ مَاذَا قَالَ لَكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ قَالَ لِي ‏ "‏ يُوشِكُ أَحَدُكُمْ أَنْ يُصَلِّيَ الْفَجْرَ أَرْبعًا ‏"‏ ‏.‏\hadithno{1153}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdullah bin Malik bin Buhainah said:“The Prophet (ﷺ) passed by a man who was praying when the Iqamah for Subh prayer had been called, and he said something to him, I do not know what he said. When he finished, we surrounded the man and asked him: ‘What did the Messenger of Allah (ﷺ) say to you?’ He said: ‘He said to me: “Soon one of you will pray Fajr with four Rak’ah.’”}}
\hadithdefcmd{ibnmajah}{1154}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ، حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنْ قَيْسِ بْنِ عَمْرٍو، قَالَ رَأَى النَّبِيُّ ـ صلى الله عليه وسلم ـ رَجُلاً يُصَلِّي بَعْدَ صَلاَةِ الصُّبْحِ رَكْعَتَيْنِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ أَصَلاَةَ الصُّبْحِ مَرَّتَيْنِ؟ ‏"‏ ‏.‏ فَقَالَ لَهُ الرَّجُلُ إِنِّي لَمْ أَكُنْ صَلَّيْتُ الرَّكْعَتَيْنِ اللَّتَيْنِ قَبْلَهَا فَصَلَّيْتُهُمَا ‏.‏ قَالَ فَسَكَتَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1154}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qais bin ‘Amr said:“The Prophet (ﷺ) saw a man praying two Rak’ah after the Subh prayer and said, ‘Is the Subh prayer to be offered twice?’ The man said to him: ‘I did not pray the two Rak’ah before it, so I prayed them (now).’ The Messenger of Allah (ﷺ) remained silent.”}}
\hadithdefcmd{ibnmajah}{1155}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَامَ عَنْ رَكْعَتَىِ الْفَجْرِ. فَقَضَاهُمَا بَعْدَ مَا طَلَعَتِ الشَّمْسُ ‏.‏\hadithno{1155}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) slept and missed the two Rak’ah before Fajr, so he made them up after the sun had risen}}
\hadithdefcmd{ibnmajah}{1156}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ قَابُوسَ، عَنْ أَبِيهِ، قَالَ أَرْسَلَ أَبِي إِلَى عَائِشَةَ أَىُّ صَلاَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ أَحَبَّ إِلَيْهِ أَنْ يُوَاظِبَ عَلَيْهَا؟ قَالَتْ: كَانَ يُصَلِّي أَرْبَعًا قَبْلَ الظُّهْرِ. يُطِيلُ فِيهِنَّ الْقِيَامَ، وَيُحْسِنُ فِيهِنَّ الرُّكُوعَ وَالسُّجُودَ ‏.‏\hadithno{1156}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Qabus that his father said:“My father sent word to ‘Aishah, asking which prayer the Prophet (ﷺ) most liked to perform regularly. She said: ‘He used to perform four Rak’ah before the Zuhr, in which he would stand for a long time and bow and prostrate perfectly.’”}}
\hadithdefcmd{ibnmajah}{1157}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عُبَيْدَةَ بْنِ مُعَتِّبٍ الضَّبِّيِّ، عَنْ إِبْرَاهِيمَ، عَنْ سَهْمِ بْنِ مِنْجَابٍ، عَنْ قَزَعَةَ، عَنْ قَرْثَعٍ، عَنْ أَبِي أَيُّوبَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي قَبْلَ الظُّهْرِ أَرْبَعًا إِذَا زَالَتِ الشَّمْسُ لاَ يَفْصِلُ بَيْنَهُنَّ بِتَسْلِيمٍ وَقَالَ ‏ "‏ إِنَّ أَبْوَابَ السَّمَاءِ تُفْتَحُ إِذَا زَالَتِ الشَّمْسُ ‏"‏ ‏.‏\hadithno{1157}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Ayyub that the Prophet (ﷺ) used to perform four Rak’ah before the Zuhr when the sun had passed its zenith, and he did not separate them with a Taslim. He said, “The gates of heaven are opened when the sun passes its zenith.”}}
\hadithdefcmd{ibnmajah}{1158}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَزَيْدُ بْنُ أَخْزَمَ، وَمُحَمَّدُ بْنُ مَعْمَرٍ، قَالُوا حَدَّثَنَا مُوسَى بْنُ دَاوُدَ الْكُوفِيُّ، حَدَّثَنَا قَيْسُ بْنُ الرَّبِيعِ، عَنْ شُعْبَةَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا فَاتَتْهُ الأَرْبَعُ قَبْلَ الظُّهْرِ صَلاَّهَا بَعْدَ الرَّكْعَتَيْنِ بَعْدَ الظُّهْرِ.‏ قَالَ أَبُو عَبْدِ اللَّهِ لَمْ يُحَدِّثْ بِهِ إِلاَّ قَيْسٌ عَنْ شُعْبَةَ. ‏‏\hadithno{1158}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“If the Messenger of Allah (ﷺ) missed the four Rak’ah before the Zuhr, he would perform them after the two Rak’ah which come after the Zuhr.”}}
\hadithdefcmd{ibnmajah}{1159}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، قَالَ أَرْسَلَ مُعَاوِيَةُ إِلَى أُمِّ سَلَمَةَ فَانْطَلَقْتُ مَعَ الرَّسُولِ فَسَأَلَ أُمَّ سَلَمَةَ فَقَالَتْ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بَيْنَمَا هُوَ يَتَوَضَّأُ فِي بَيْتِي لِلظُّهْرِ وَكَانَ قَدْ بَعَثَ سَاعِيًا وَكَثُرَ عِنْدَهُ الْمُهَاجِرُونَ وَكَانَ قَدْ أَهَمَّهُ شَأْنُهُمْ إِذْ ضُرِبَ الْبَابُ فَخَرَجَ إِلَيْهِ فَصَلَّى الظُّهْرَ ثُمَّ جَلَسَ يَقْسِمُ مَا جَاءَ بِهِ ‏.‏ قَالَتْ فَلَمْ يَزَلْ كَذَلِكَ حَتَّى الْعَصْرِ ‏.‏ ثُمَّ دَخَلَ مَنْزِلِي فَصَلَّى رَكْعَتَيْنِ ثُمَّ قَالَ ‏ "‏ أَشْغَلَنِي أَمْرُ السَّاعِي أَنْ أُصَلِّيَهُمَا بَعْدَ الظُّهْرِ فَصَلَّيْتُهُمَا بَعْدَ الْعَصْرِ ‏"‏ ‏.‏\hadithno{1159}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin Harith said:“Mu’awiyah sent word to Umm Salamah, and I went with his envoy who put the question to Umm Salamah. She said: ‘While the Messenger of Allah (ﷺ) was performing ablution for the Zuhr in my house and he had sent a Sa’i,* the Muhajirun gathered around him in large numbers, and he was busy dealing with them. When a knock on the door came, he went out and performed the Zuhr, then he sat and distributed what had been brought to him.’ She said: ‘He continued doing that until the ‘Asr. Then he came into my house and performed two Rak’ah. Then he said: “The matter of the Sa’i kept me from praying them after Zuhr, so I prayed them after ‘Asr.”}}
\hadithdefcmd{ibnmajah}{1160}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الشُّعَيْثِيُّ، عَنْ أَبِيهِ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّ حَبِيبَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ صَلَّى قَبْلَ الظُّهْرِ أَرْبَعًا، وَبَعْدَهَا أَرْبَعًا، حَرَّمَهُ اللَّهُ عَلَى النَّارِ ‏"‏ ‏.‏\hadithno{1160}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Umm Habibah that the Prophet (ﷺ) said:“Whoever prays four Rak’ah before the Zuhr and four afterwards, Allah will forbid him to the Fire.”}}
\hadithdefcmd{ibnmajah}{1161}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، وَأَبِي، وَإِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ السَّلُولِيِّ، قَالَ سَأَلْنَا عَلِيًّا عَنْ تَطَوُّعِ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِالنَّهَارِ فَقَالَ إِنَّكُمْ لاَ تُطِيقُونَهُ فَقُلْنَا أَخْبِرْنَا بِهِ نَأْخُذْ مِنْهُ مَا اسْتَطَعْنَا ‏.‏ قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا صَلَّى الْفَجْرَ يُمْهِلُ حَتَّى إِذَا كَانَتِ الشَّمْسُ مِنْ هَاهُنَا - يَعْنِي مِنْ قِبَلِ الْمَشْرِقِ - بِمِقْدَارِهَا مِنْ صَلاَةِ الْعَصْرِ مِنْ هَا هُنَا - يَعْنِي مِنْ قِبَلِ الْمَغْرِبِ - قَامَ فَصَلَّى رَكْعَتَيْنِ. ثُمَّ يُمْهِلُ حَتَّى إِذَا كَانَتِ الشَّمْسُ مِنْ هَا هُنَا - يَعْنِي مِنْ قِبَلِ الْمَشْرِقِ - مِقْدَارَهَا مِنْ صَلاَةِ الظُّهْرِ مِنْ هَا هُنَا قَامَ فَصَلَّى أَرْبَعًا. وَأَرْبَعًا قَبْلَ الظُّهْرِ إِذَا زَالَتِ الشَّمْسُ. وَرَكْعَتَيْنِ بَعْدَهَا. وَأَرْبَعًا قَبْلَ الْعَصْرِ. يَفْصِلُ بَيْنَ كُلِّ رَكْعَتَيْنِ بِالتَّسْلِيمِ عَلَى الْمَلاَئِكَةِ الْمُقَرَّبِينَ وَالنَّبِيِّينَ. وَمَنْ تَبِعَهُمْ مِنَ الْمُسْلِمِينَ وَالْمُؤْمِنِينَ ‏.‏ قَالَ عَلِيٌّ: فَتِلْكَ سِتَّ عَشْرَةَ رَكْعَةً. تَطَوُّعُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِالنَّهَارِ. وَقَلَّ مَنْ يُدَاوِمُ عَلَيْهَا ‏.‏ قَالَ وَكِيعٌ: زَادَ فِيهِ أَبِي: فَقَالَ حَبِيبُ بْنُ أَبِي ثَابِتٍ: يَا أَبَا إِسْحَاقَ مَا أُحِبُّ أَنَّ لِي بِحَدِيثِكَ هَذَا مِلْءَ مَسْجِدِكَ هَذَا ذَهَبًا ‏.‏\hadithno{1161}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Asim bin Damrah As-Saluli said:“We asked ‘Ali about the voluntary (prayer) of Allah’s Messenger (ﷺ) during the day. He said: ‘You will not be able.’ We said: ‘Inform us of it, we will do what we can of it?’ So he said: ‘When he prayed the Fajr he would delay praying any more. When the sun appeared over there (west) – like it appears here, meaning in the direction of the east, about the amount for the ‘Asr prayer from there, meaning in the direction of the west, meaning before the Maghrib – he would stand and perform two Rak’ah* then he would delay praying until the sun appeared over there (west), meaning in the direction of the east, about the amount of the Zuhr prayer from there, then he would stand and perform four. And, four before the Zuhr when the sun passed the zenith, and two Rak’ah after it, and, four before the ‘Asr, separating between every two Rak’ah with Taslim** upon the angels that are close (to Allah), the Prophets, and those who follow them among the Muslims and the believers.’” 'Ali said: "That is sixteen Rak'ah of voluntary prayer which Allah's Messenger (ﷺ) performed during the day. And there are very few who offer them regularly." Waki` said: “My father added: Habib bin Abu Thabit said: ‘O Abu Ishaq, this mosque filled with gold would not be dearer to me than this Hadith of yours.’” * Meaning, when the sun was low above the eastern horizon. That is the time of the Duha. ** Meaning the Tashah-hud}}
\hadithdefcmd{ibnmajah}{1162}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَوَكِيعٌ، عَنْ كَهْمَسٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ نَبِيُّ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ بَيْنَ كُلِّ أَذَانَيْنِ صَلاَةٌ ‏"‏ ‏.‏ قَالَهَا ثَلاَثًا قَالَ فِي الثَّالِثَةِ ‏"‏ لِمَنْ شَاءَ ‏"‏ ‏.‏\hadithno{1162}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdullah bin Mughaffal said:“The Prophet of Allah (ﷺ) said: ‘Between every two Adhans there is a prayer.’ He said it three times, and on the third time he said, ‘For those who wish.’”}}
\hadithdefcmd{ibnmajah}{1163}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَلِيَّ بْنَ زَيْدِ بْنِ جُدْعَانَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنْ كَانَ الْمُؤَذِّنُ لَيُؤَذِّنُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَيُرَى أَنَّهَا الإِقَامَةُ مِنْ كَثْرَةِ مَنْ يَقُومُ فَيُصَلِّي الرَّكْعَتَيْنِ قَبْلَ الْمَغْرِبِ ‏.‏\hadithno{1163}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Ali bin Zaid bin Jud’an said:“I heard Anas bin Malik say: ‘The Mu ’adh-dhin would call the Adhan during the time of the Messenger of Allah (ﷺ), and one would think that it was the Iqamah because there were so many people who stood and performed the two Rak’ah before the Maghrib.”}}
\hadithdefcmd{ibnmajah}{1164}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا هُشَيْمٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي الْمَغْرِبَ، ثُمَّ يَرْجِعُ إِلَى بَيْتِي فَيُصَلِّي رَكْعَتَيْنِ ‏.‏\hadithno{1164}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) used to pray the Maghrib, then he would come back to my house and pray two Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1165}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ الضَّحَّاكِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ أَتَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي بَنِي عَبْدِ الأَشْهَلِ فَصَلَّى بِنَا الْمَغْرِبَ فِي مَسْجِدِنَا ثُمَّ قَالَ ‏ "‏ ارْكَعُوا هَاتَيْنِ الرَّكْعَتَيْنِ فِي بُيُوتِكُمْ ‏"‏ ‏.‏\hadithno{1165}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi’ bin Khadij said:“We came to the Messenger of Allah (ﷺ) with Banu ‘Abdul-Ashhal, and he led us in praying the Maghrib in our mosque. Then he said: ‘Pray these two Rak’ah in your houses.’”}}
\hadithdefcmd{ibnmajah}{1166}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ وَاقِدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُؤَمَّلِ بْنِ الصَّبَّاحِ، حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، قَالاَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الْوَلِيدِ، حَدَّثَنَا عَاصِمُ بْنُ بَهْدَلَةَ، عَنْ زِرٍّ، وَأَبِي، وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقْرَأُ فِي الرَّكْعَتَيْنِ بَعْدَ صَلاَةِ الْمَغْرِبِ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ‏\}‏ وَ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ \}‏ ‏"‏ ‏.‏\hadithno{1166}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that for the two Rak’ah after Maghrib, the Prophet (ﷺ) used to recite:“Say: O you disbelievers!” [Al-Kafirun (109)] and “Say: He is Allah the One.” [Al- Ikhlas]}}
\hadithdefcmd{ibnmajah}{1167}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو الْحُسَيْنِ الْعُكْلِيُّ، أَخْبَرَنِي عُمَرُ بْنُ أَبِي خَثْعَمٍ الْيَمَامِيُّ، أَنْبَأَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ صَلَّى بَعْدَ الْمَغْرِبِ سِتَّ رَكَعَاتٍ لَمْ يَتَكَلَّمْ بَيْنَهُنَّ بِسُوءٍ عُدِلْنَ لَهُ بِعِبَادَةِ ثِنْتَىْ عَشْرَةَ سَنَةً ‏"‏ ‏.‏\hadithno{1167}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever prays six Rak’ah after the Maghrib and does not say anything bad in between them, will have a reward equal to the worship of twelve years.”}}
\hadithdefcmd{ibnmajah}{1168}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَاشِدٍ الزَّوْفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُرَّةَ الزَّوْفِيِّ، عَنْ خَارِجَةَ بْنِ حُذَافَةَ الْعَدَوِيِّ، قَالَ خَرَجَ عَلَيْنَا النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ إِنَّ اللَّهَ قَدْ أَمَدَّكُمْ بِصَلاَةٍ، لَهِيَ خَيْرٌ لَكُمْ مِنْ حُمُرِ النَّعَمِ. الْوِتْرُ، جَعَلَهُ اللَّهُ لَكُمْ فِيمَا بَيْنَ صَلاَةِ الْعِشَاءِ إِلَى أَنْ يَطْلُعَ الْفَجْرُ ‏"‏ ‏.‏\hadithno{1168}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Kharijah bin Hudhafah Al-‘Adawi said:“The Prophet (ﷺ) came out to us and said: ‘Allah has increased a prayer for you which is better for you than red camels. (It is) Witr, which Allah has enjoined on you between the ‘Isha’ prayer and the onset of dawn.’”}}
\hadithdefcmd{ibnmajah}{1169}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ السَّلُولِيِّ، قَالَ قَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ إِنَّ الْوِتْرَ لَيْسَ بِحَتْمٍ وَلاَ كَصَلاَتِكُمُ الْمَكْتُوبَةِ وَلَكِنْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَوْتَرَ ‏.‏ ثُمَّ قَالَ ‏ "‏ يَا أَهْلَ الْقُرْآنِ أَوْتِرُوا. فَإِنَّ اللَّهَ وِتْرٌ يُحِبُّ الْوِتْرَ ‏"‏ ‏.‏\hadithno{1169}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{‘Ali bin Abu Talib said:“Witr is not definite (obligatory) nor is it like your prescribed prayers. But the Messenger of Allah (ﷺ) prayed Witr, then he said: ‘O people of the Qur’an! Perform Witr, for Allah is Witr* and He loves the odd (numbered).’” * Meaning 'one' which is the first of the odd numbers; He is unique, and there is nothing like Him, similar or equal}}
\hadithdefcmd{ibnmajah}{1170}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو حَفْصٍ الأَبَّارُ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ إِنَّ اللَّهَ وِتْرٌ يُحِبُّ الْوِتْرَ فَأَوْتِرُوا يَا أَهْلَ الْقُرْآنِ ‏"‏ ‏.‏ فَقَالَ أَعْرَابِيٌّ مَا يَقُولُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ لَيْسَ لَكَ وَلاَ لأَصْحَابِكَ ‏"‏ ‏.‏\hadithno{1170}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Prophet (ﷺ) said:“Allah is Witr and He loves the odd (numbered), so perform Witr, O people of the Qur’an.” A Bedouin said: ‘What is the Messenger of Allah (ﷺ) saying?’ He said: ‘That is not for you or your companions.’”}}
\hadithdefcmd{ibnmajah}{1171}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو حَفْصٍ الأَبَّارُ، حَدَّثَنَا الأَعْمَشُ، عَنْ طَلْحَةَ، وَزُبَيْدٍ، عَنْ ذَرٍّ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُوتِرُ بِـ ‏\{سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى\}‏ وَ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ\}‏ وَ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ ‏.‏\hadithno{1171}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ubayy bin Ka’b said:“The Messenger of Allah (ﷺ) used to perform Witr and recite: ‘Glorify the Name of your Lord the Most High.’, [Al-A’la (87)] ‘Say: O you disbelievers!” [Al-Kafirun (109)] and ‘Say: Allah is One.”. [Al-Ikhlas]}}
\hadithdefcmd{ibnmajah}{1172}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُوتِرُ بِـ ‏\{سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ \}‏ وَ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ \}‏ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنْصُورٍ أَبُو بَكْرٍ، قَالَ حَدَّثَنَا شَبَابَةُ، قَالَ حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1172}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) used to perform Witr and recite:“Glorify the Name of your Lord the Most High,” [Al-A’la (87)] “Say: O you disbelievers!” [Al-Kafirun (109)] and ‘Say: Allah is One.”. [Al-Ikhlas (112)] Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{1173}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَأَبُو يُوسُفَ الرَّقِّيُّ مُحَمَّدُ بْنُ أَحْمَدَ الصَّيْدَلاَنِيُّ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ خُصَيْفٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ جُرَيْجٍ، قَالَ سَأَلْنَا عَائِشَةَ بِأَىِّ شَىْءٍ كَانَ يُوتِرُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَتْ كَانَ يَقْرَأُ فِي الرَّكْعَةِ الأُولَى بِـ ‏\{سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى\}‏ وَفِي الثَّانِيَةِ ‏\{قُلْ يَا أَيُّهَا الْكَافِرُونَ\}‏ وَفِي الثَّالِثَةِ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ\}‏ وَالْمُعَوِّذَتَيْنِ ‏.‏\hadithno{1173}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdul-‘Aziz bin Juraij said:“We asked ‘Aishah what the Messenger of Allah (ﷺ) used to recite in Witr. She said: ‘He used to recite: “Glorify the Name of your Lord the Most High,” [Al-A’la (87)] in the first Rak’ah, ‘Say: “O disbelievers!’” [Al- Kafirun (109)] in the second Rak’ah, and ‘Say: Allah is One’ in the third and the Mu’awwidhatain (Chapter 113, 114).’”}}
\hadithdefcmd{ibnmajah}{1174}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي مِنَ اللَّيْلِ مَثْنَى مَثْنَى. وَيُوتِرُ بِرَكْعَةٍ ‏.‏\hadithno{1174}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) used to pray (voluntary prayers) at night two by two, and he would pray one Rak’ah of Witr.”}}
\hadithdefcmd{ibnmajah}{1175}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عَاصِمٌ، عَنْ أَبِي مِجْلَزٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى وَالْوِتْرُ رَكْعَةٌ ‏"‏ قُلْتُ أَرَأَيْتَ إِنْ غَلَبَتْنِي عَيْنِي أَرَأَيْتَ إِنْ نِمْتُ قَالَ اجْعَلْ أَرَأَيْتَ عِنْدَ ذَلِكَ النَّجْمِ ‏.‏ فَرَفَعْتُ رَأْسِي فَإِذَا السِّمَاكُ ثُمَّ أَعَادَ فَقَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى. وَالْوِتْرُ رَكْعَةٌ قَبْلَ الصُّبْحِ ‏"‏ ‏.‏\hadithno{1175}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Mijlaz narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘Night prayers are to be offered two by two, and Witr is one Rak’ah.’ I said: ‘What do you think if I become drowsy and I want to sleep?’ He said: ‘Put “what do you think” up there with that star? (i.e., don’t think about it at all).’ I raised my head and saw As- Simak.* He repeated that the Messenger of Allah (ﷺ) said, ‘Night prayers are to be offered two by two, and Witr is one Rak’ah, before dawn.’” * Here, As-Simak refers to a star or stars, either Arcturus (As-Simak Ar-Ramih) or Spica, also called Alpha Virginis (As-Simak Al-A'zal)}}
\hadithdefcmd{ibnmajah}{1176}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا الْمُطَّلِبُ بْنُ عَبْدِ اللَّهِ، قَالَ سَأَلَ ابْنَ عُمَرَ رَجُلٌ فَقَالَ كَيْفَ أُوتِرُ قَالَ أَوْتِرْ بِوَاحِدَةٍ ‏.‏ قَالَ إِنِّي أَخْشَى أَنْ يَقُولَ النَّاسُ الْبُتَيْرَاءُ فَقَالَ سُنَّةُ اللَّهِ وَرَسُولِهِ ‏.‏ يُرِيدُ هَذِهِ سُنَّةُ اللَّهِ وَرَسُولِهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1176}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A man asked Ibn ‘Umar:“How should I perform Witr?” He said: “Pray Witr with one Rak’ah.” He said: “I am afraid that the people will say that I am cutting the prayer short.” He said: “The Sunnah of Allah and His Messenger.” Meaning “This is the Sunnah of Allah and His Messenger.”}}
\hadithdefcmd{ibnmajah}{1177}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُسَلِّمُ فِي كُلِّ ثِنْتَيْنِ وَيُوتِرُ بِوَاحِدَةٍ ‏.‏\hadithno{1177}\hadithgrade{Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) used to say Taslim after every two Rak’ah, and he would perform Witr with one Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1178}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي الْحَوْرَاءِ، عَنِ الْحَسَنِ بْنِ عَلِيٍّ، قَالَ عَلَّمَنِي جَدِّي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ كَلِمَاتٍ أَقُولُهُنَّ فِي قُنُوتِ الْوِتْرِ ‏ "‏ اللَّهُمَّ عَافِنِي فِيمَنْ عَافَيْتَ وَتَوَلَّنِي فِيمَنْ تَوَلَّيْتَ وَاهْدِنِي فِيمَنْ هَدَيْتَ وَقِنِي شَرَّ مَا قَضَيْتَ وَبَارِكْ لِي فِيمَا أَعْطَيْتَ إِنَّكَ تَقْضِي وَلاَ يُقْضَى عَلَيْكَ إِنَّهُ لاَ يَذِلُّ مَنْ وَالَيْتَ سُبْحَانَكَ رَبَّنَا تَبَارَكْتَ وَتَعَالَيْتَ ‏"‏ ‏.‏\hadithno{1178}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Al-Hasan bin ‘Ali said:“My grandfather, the Messenger of Allah (ﷺ), taught me some words to say in Qunut of Witr: Allahumma ‘afini fiman ‘afait, wa tawallani fiman tawallait, wahdini fiman hadait, wa qini sharra ma qadait, wa barik li fima a’tait. Innaka taqdi wa la yuqda ‘alaik, innahu la yudhillu man walait. Subhanaka rabbana tabarakta wa ta’alait (O Allah, pardon me along with those whom You have pardoned, be an ally to me along with those whom You are an ally to, guide me along with those whom You have guided, protect me from the evil that You have decreed, and bless for me that which You have bestowed. For verily You decree and none can decree over You. He whom You support can never be humiliated. Glory is to You, our Lord, You are Blessed and Exalted).”}}
\hadithdefcmd{ibnmajah}{1179}{حَدَّثَنَا أَبُو عُمَرَ، حَفْصُ بْنُ عَمْرٍو حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنِي هِشَامُ بْنُ عَمْرٍو الْفَزَارِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ الْمَخْزُومِيِّ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، ‏.‏ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ فِي آخِرِ وِتْرِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِرِضَاكَ مِنْ سُخْطِكَ وَأَعُوذُ بِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَأَعُوذُ بِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏\hadithno{1179}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Ali bin Abi Talib that the Prophet (ﷺ) used to say at the end of Witr:“Allahumma inni a’udhu biridaka min sakhatika, wa a’udhu bimu’afatika min ‘uqubatika, wa a’udhu bika minka, la uhsi thana’an ‘alaika, Anta kama athnaita ‘ala nafsika (O Allah, I seek refuge in Your pleasure from Your wrath, and I seek refuge in Your forgiveness from your punishment, and I seek refuge in You from You. I cannot enumerate Your praise, You are as You have praised Yourself).”}}
\hadithdefcmd{ibnmajah}{1180}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ لاَ يَرْفَعُ يَدَيْهِ فِي شَىْءٍ مِنْ دُعَائِهِ إِلاَّ عِنْدَ الاِسْتِسْقَاءِ فَإِنَّهُ كَانَ يَرْفَعُ يَدَيْهِ حَتَّى يُرَى بَيَاضُ إِبْطَيْهِ ‏.‏\hadithno{1180}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) did not raise his hands in any of his supplications except when praying for rain (Istisqa’), when he raised his hands so high that the whiteness of his armpits could be seen}}
\hadithdefcmd{ibnmajah}{1181}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا عَائِذُ بْنُ حَبِيبٍ، عَنْ صَالِحِ بْنِ حَسَّانَ الأَنْصَارِيِّ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا دَعَوْتَ اللَّهَ فَادْعُ بِبَاطِنِ كَفَّيْكَ وَلاَ تَدْعُ بِظُهُورِهِمَا فَإِذَا فَرَغْتَ فَامْسَحْ بِهِمَا وَجْهَكَ ‏"‏ ‏.‏\hadithno{1181}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) said: ‘When you call upon Allah, then do so with the palms of your hands (upwards). Do not do so with the back of your hands (upwards). And when you finish, then wipe your face with them.’”}}
\hadithdefcmd{ibnmajah}{1182}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، عَنْ سُفْيَانَ، عَنْ زُبَيْدٍ الْيَامِيِّ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُوتِرُ فَيَقْنُتُ قَبْلَ الرُّكُوعِ ‏.‏\hadithno{1182}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ubayy bin Ka’b that the Messenger of Allah (ﷺ) used to pray Witr and he would recite Qunut before Ruku’}}
\hadithdefcmd{ibnmajah}{1183}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا سَهْلُ بْنُ يُوسُفَ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سُئِلَ عَنِ الْقُنُوتِ، فِي صَلاَةِ الصُّبْحِ فَقَالَ كُنَّا نَقْنُتُ قَبْلَ الرُّكُوعِ وَبَعْدَهُ ‏.‏\hadithno{1183}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:He was asked about Qunut in the Subh prayer, and he said: “We used to recite Qunut before Ruku’ and afterwards.”}}
\hadithdefcmd{ibnmajah}{1184}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنِ الْقُنُوتِ، فَقَالَ قَنَتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَعْدَ الرُّكُوعِ ‏.‏\hadithno{1184}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Muhammad said:“I asked Anas bin Malik about Qunut, and he said: ‘The Messenger of Allah (ﷺ) recited Qunut after Ruku’.’”}}
\hadithdefcmd{ibnmajah}{1185}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حُصَيْنٍ، عَنْ يَحْيَى بْنِ وَثَّابٍ، عَنْ مَسْرُوقٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ وِتْرِ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ: مِنْ كُلِّ اللَّيْلِ قَدْ أَوْتَرَ. مِنْ أَوَّلِهِ وَأَوْسَطِهِ، وَانْتَهَى وِتْرُهُ، حِينَ مَاتَ، فِي السَّحَرِ ‏.‏\hadithno{1185}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Masruq said:“I asked ‘Aishah about the Witr of the Messenger of Allah (ﷺ). She said: ‘He prayed Witr at every part of the night, at the beginning, in the middle and at the end, when he died (he would perform it) just before dawn.’”}}
\hadithdefcmd{ibnmajah}{1186}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ قَالَ: مِنْ كُلِّ اللَّيْلِ قَدْ أَوْتَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم. مِنْ أَوَّلِهِ وَأَوْسَطِهِ، وَانْتَهَى وِتْرُهُ إِلَى السَّحَرِ ‏.‏\hadithno{1186}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Ali said:“At every part of the night the Messenger of Allah (ﷺ) prayed Witr, at the beginning and in the middle, and finally his Witr was just before dawn.”}}
\hadithdefcmd{ibnmajah}{1187}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي غَنِيَّةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ خَافَ مِنْكُمْ أَنْ لاَ يَسْتَيْقِظَ مِنْ آخِرِ اللَّيْلِ، فَلْيُوتِرْ مِنْ أَوَّلِ اللَّيْلِ ثُمَّ لْيَرْقُدْ. وَمَنْ طَمِعَ مِنْكُمْ أَنْ يَسْتَيْقِظَ مِنْ آخِرِ اللَّيْلِ، فَلْيُوتِرْ مِنْ آخِرِ اللَّيْلِ. فَإِنَّ قِرَاءَةَ آخِرِ اللَّيْلِ مَحْضُورَةٌ. وَذَلِكَ أَفْضَلُ ‏"‏ ‏.‏\hadithno{1187}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“Whoever among you fears that he will not wake up at the end of the night, let him pray Witr at the beginning of the night, then go to sleep. Whoever hopes that he will wake up at the end of the night, let him pray Witr at the end of the night, for recitation (of the Qur’an) at the end of the night is attended (by the angels), and that is better.”}}
\hadithdefcmd{ibnmajah}{1188}{حَدَّثَنَا أَبُو مُصْعَبٍ، أَحْمَدُ بْنُ أَبِي بَكْرٍ الْمَدِينِيُّ وَسُوَيْدُ بْنُ سَعِيدٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ نَامَ عَنِ الْوِتْرِ أَوْ نَسِيَهُ، فَلْيُصَلِّ إِذَا أَصْبَحَ، أَوْ ذَكَرَهُ ‏"‏ ‏.‏\hadithno{1188}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) said: ‘Whoever sleeps and misses Witr, or forgets it, let him pray it when morning comes, or when he remembers.’”}}
\hadithdefcmd{ibnmajah}{1189}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَأَحْمَدُ بْنُ الأَزْهَرِ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَوْتِرُوا قَبْلَ أَنْ تُصْبِحُوا ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى فِي هَذَا الْحَدِيثَ دَلِيلٌ عَلَى أَنَّ حَدِيثَ عَبْدِ الرَّحْمَنِ وَاهٍ ‏.‏\hadithno{1189}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) said: ‘Pray Witr before morning comes.’”}}
\hadithdefcmd{ibnmajah}{1190}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْفِرْيَابِيُّ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْوِتْرُ حَقٌّ. فَمَنْ شَاءَ فَلْيُوتِرْ بِخَمْسٍ. وَمَنْ شَاءَ فَلْيُوتِرْ بِثَلاَثٍ. وَمَنْ شَاءَ فَلْيُوتِرْ بِوَاحِدَةٍ ‏"‏ ‏.‏\hadithno{1190}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Ayyub Al-Ansari that the Messenger of Allah (ﷺ) said:“Witr is Haqq.* Whoever wishes let him pray Witr with five (Rak’ah), and whoever wishes let him pray Witr with three (Rak’ah), and whoever wishes let him pray Witr with one (Rak’ah).”}}
\hadithdefcmd{ibnmajah}{1191}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، قَالَ سَأَلْتُ عَائِشَةَ قُلْتُ يَا أُمَّ الْمُؤْمِنِينَ أَفْتِنِي عَنْ وِتْرِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَتْ كُنَّا نُعِدُّ لَهُ سِوَاكَهُ وَطَهُورَهُ فَيَبْعَثُهُ اللَّهُ فِيمَا شَاءَ أَنْ يَبْعَثَهُ مِنَ اللَّيْلِ فَيَتَسَوَّكُ وَيَتَوَضَّأُ ثُمَّ يُصَلِّي تِسْعَ رَكَعَاتٍ لاَ يَجْلِسُ فِيهَا إِلاَّ عِنْدَ الثَّامِنَةِ فَيَدْعُو رَبَّهُ فَيَذْكُرُ اللَّهَ وَيَحْمَدُهُ وَيَدْعُوهُ ثُمَّ يَنْهَضُ وَلاَ يُسَلِّمُ ثُمَّ يَقُومُ فَيُصَلِّي التَّاسِعَةَ ثُمَّ يَقْعُدُ فَيَذْكُرُ اللَّهَ وَيَحْمَدُهُ وَيَدْعُو رَبَّهُ وَيُصَلِّي عَلَى نَبِيِّهِ ثُمَّ يُسَلِّمُ تَسْلِيمًا يُسْمِعُنَا ثُمَّ يُصَلِّي رَكْعَتَيْنِ بَعْدَ مَا يُسَلِّمُ وَهُوَ قَاعِدٌ فَتِلْكَ إِحْدَى عَشْرَةَ رَكْعَةً فَلَمَّا أَسَنَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَخَذَ اللَّحْمُ أَوْتَرَ بِسَبْعٍ وَصَلَّى رَكْعَتَيْنِ بَعْدَ مَا سَلَّمَ ‏.‏\hadithno{1191}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa’d bin Hisham said:“I asked ‘Aishah: ‘O Mother of the Believers! Tell me about the Witr of the Messenger of Allah (ﷺ).’ She said: ‘We used to keep his tooth stick and water for ablution ready for him. Allah would wake him as He willed to during the night, and he would use the tooth stick and perform ablution, then he would pray nine Rak’ah, during which he would not sit until the eighth Rak’ah. Then he would call upon his Lord and remember Allah and praise Him and supplicate to Him. Then he would get up without saying the Salam. Then he would stand up and pray the ninth Rak’ah. Then he would sit and remember Allah and praise Him, and supplicate to his Lord and send blessing upon His Prophet. Then he would say Salam that we could hear. Then he would pray two Rak’ah after the Salam, while he was sitting down. That was eleven Rak’ah. When the Messenger of Allah (ﷺ) grew older and had gained weight, he would pray Witr with seven Rak’ah and then pray two more Rak’ah after he had said the Salam.’”}}
\hadithdefcmd{ibnmajah}{1192}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ زُهَيْرٍ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُوتِرُ بِسَبْعٍ أَوْ بِخَمْسٍ لاَ يَفْصِلُ بَيْنَهُنَّ بِتَسْلِيمٍ وَلاَ كَلاَمٍ ‏.‏\hadithno{1192}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Salamah said:“The Messenger of Allah (ﷺ) used to pray Witr with seven or five Rak’ah, and he would not say Salam or speak in between them.”}}
\hadithdefcmd{ibnmajah}{1193}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا شُعْبَةُ، عَنْ جَابِرٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ: كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي فِي السَّفَرِ رَكْعَتَيْنِ. لاَ يَزِيدُ عَلَيْهِمَا. وَكَانَ يَتَهَجَّدُ مِنَ اللَّيْلِ ‏.‏ قُلْتُ وَكَانَ يُوتِرُ؟ قَالَ: نَعَمْ ‏.‏\hadithno{1193}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salim that his father said:“The Messenger of Allah (ﷺ) used to pray two Rak’ah while traveling, and he did not do more than that. And he used to pray Tahajjud at night.” I asked: “Did he pray Witr?” He said: “Yes.”}}
\hadithdefcmd{ibnmajah}{1194}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا شَرِيكٌ، عَنْ جَابِرٍ، عَنْ عَامِرٍ، عَنِ ابْنِ عَبَّاسٍ، وَابْنِ، عُمَرَ قَالاَ سَنَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَلاَةَ السَّفَرِ رَكْعَتَيْنِ وَهُمَا تَمَامٌ غَيْرُ قَصْرٍ وَالْوِتْرُ فِي السَّفَرِ سُنَّةٌ ‏.‏\hadithno{1194}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas and Ibn ‘Umar said:“The Messenger of Allah (ﷺ) prescribed two Rak’ah of prayer when traveling; they are complete and are not shortened. And Witr when traveling is Sunnah.”}}
\hadithdefcmd{ibnmajah}{1195}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، حَدَّثَنَا مَيْمُونُ بْنُ مُوسَى الْمَرَئِيُّ، عَنِ الْحَسَنِ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي بَعْدَ الْوِتْرِ رَكْعَتَيْنِ خَفِيفَتَيْنِ، وَهُوَ جَالِسٌ ‏.‏\hadithno{1195}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that the Prophet (ﷺ) used to pray two short Rak’ah after Witr, sitting down}}
\hadithdefcmd{ibnmajah}{1196}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ الْوَاحِدِ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، قَالَ حَدَّثَتْنِي عَائِشَةُ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُوتِرُ بِوَاحِدَةٍ. ثُمَّ يَرْكَعُ رَكْعَتَيْنِ يَقْرَأُ فِيهِمَا وَهُوَ جَالِسٌ. فَإِذَا أَرَادَ أَنْ يَرْكَعَ، قَامَ فَرَكَعَ ‏.‏\hadithno{1196}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Salamah said:“Aishah narrated to me that the Messenger of Allah (ﷺ) prayed Witr with one Rak’ah, then he prayed two Rak’ah in which he recited while sitting, then when he wanted to bow, he stood up and bowed.”}}
\hadithdefcmd{ibnmajah}{1197}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ مَا كُنْتُ أُلْفِي - أَوْ أَلْقَى - النَّبِيَّ ـ صلى الله عليه وسلم ـ مِنْ آخِرِ اللَّيْلِ إِلاَّ وَهُوَ نَائِمٌ عِنْدِي ‏.‏ قَالَ وَكِيعٌ تَعْنِي بَعْدَ الْوِتْرِ ‏.‏\hadithno{1197}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“I never used to see the Prophet (ﷺ) at the end of the night, except that he was sleeping near me.”}}
\hadithdefcmd{ibnmajah}{1198}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا صَلَّى رَكْعَتَىِ الْفَجْرِ اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ ‏.‏\hadithno{1198}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“When the Prophet (ﷺ) prayed the two (Sunnah) Rak’ah of Fajr, he would lie down on his right side.”}}
\hadithdefcmd{ibnmajah}{1199}{حَدَّثَنَا عُمَرُ بْنُ هِشَامٍ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَنْبَأَنَا شُعْبَةُ، حَدَّثَنِي سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا صَلَّى رَكْعَتَىِ الْفَجْرِ اضْطَجَعَ ‏.‏\hadithno{1199}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“When the Messenger of Allah (saw prayed the two (Sunnah) Rak’ah of Fajr, he would lie down.”}}
\hadithdefcmd{ibnmajah}{1200}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي بَكْرِ بْنِ عُمَرَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، عَنْ سَعِيدِ بْنِ يَسَارٍ، قَالَ كُنْتُ مَعَ ابْنِ عُمَرَ فَتَخَلَّفْتُ فَأَوْتَرْتُ فَقَالَ مَا خَلَفَكَ قُلْتُ أَوْتَرْتُ ‏.‏ فَقَالَ أَمَا لَكَ فِي رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أُسْوَةٌ حَسَنَةٌ قُلْتُ بَلَى ‏.‏ قَالَ فَإِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُوتِرُ عَلَى بَعِيرِهِ ‏.‏\hadithno{1200}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Sa’eed bin Yasar said:“I was with Ibn ‘Umar and I lagged behind and prayed Witr. He said: ‘What kept you?’ I said: ‘I was praying Witr.’ He said: ‘Do you not have the best of examples in the Messenger of Allah (ﷺ)?’ I said: ‘Of course.’ He said: ‘The Messenger of Allah (ﷺ) used to pray Witr while riding his camel.’”}}
\hadithdefcmd{ibnmajah}{1201}{حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ الأَسْفَاطِيُّ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُوتِرُ عَلَى رَاحِلَتِهِ ‏.‏\hadithno{1201}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) used to pray Witr while riding his mount}}
\hadithdefcmd{ibnmajah}{1202}{حَدَّثَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ تَوْبَةَ حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زَائِدَةُ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لأَبِي بَكْرٍ ‏"‏ أَىَّ حِينٍ تُوتِرُ ‏"‏ قَالَ أَوَّلَ اللَّيْلِ بَعْدَ الْعَتَمَةِ ‏.‏ قَالَ ‏"‏ فَأَنْتَ يَا عُمَرُ ‏"‏ ‏.‏ فَقَالَ آخِرَ اللَّيْلِ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَمَّا أَنْتَ يَا أَبَا بَكْرٍ فَأَخَذْتَ بِالْوُثْقَى وَأَمَّا أَنْتَ يَا عُمَرُ فَأَخَذْتَ بِالْقُوَّةِ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ تَوْبَةَ أَنْبَأَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ لأَبِي بَكْرٍ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{1202}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) said to Abu Bakr: ‘When do you pray Witr?’ He said: ‘At the beginning of the night, after ‘Isha’.’ He said: ‘And you, O ‘Umar?’ He said: ‘At the end of the night.’ The Prophet (ﷺ) said: ‘As for you, O Abu Bakr, you have seized the trustworthy handhold (i.e., you want to be on the safe side), and as for you, O ‘Umar, you have seized strength (i.e., you are confident that you have the resolve to get up and pray Witr).’” Another chain with similar meaning}}
\hadithdefcmd{ibnmajah}{1203}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَزَادَ أَوْ نَقَصَ - قَالَ إِبْرَاهِيمُ وَالْوَهْمُ مِنِّي - فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ أَزِيدَ فِي الصَّلاَةِ شَىْءٌ قَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ. أَنْسَى كَمَا تَنْسَوْنَ. فَإِذَا نَسِيَ أَحَدُكُمْ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏ ثُمَّ تَحَوَّلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَسَجَدَ سَجْدَتَيْنِ ‏.‏\hadithno{1203}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Abdullah said:“The Messenger of Allah (ﷺ) prayed, and he added or omitted something.” (One of the narrators) Ibrahim said: “The confusion stems from me (i.e., he was not sure which it was).” “It was said to him: ‘O Messenger of Allah! Has something been added to the prayer?’ He said: ‘I am only human, I forget just as you forget. If anyone forgets, let him perform two prostrations when he is sitting (at the end).’ Then the Prophet (ﷺ) turned and prostrated twice.”}}
\hadithdefcmd{ibnmajah}{1204}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ هِشَامٍ، حَدَّثَنِي يَحْيَى، حَدَّثَنِي عِيَاضٌ، أَنَّهُ سَأَلَ أَبَا سَعِيدٍ الْخُدْرِيَّ فَقَالَ أَحَدُنَا يُصَلِّي فَلاَ يَدْرِي كَمْ صَلَّى ‏.‏ فَقَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ فَلَمْ يَدْرِ كَمْ صَلَّى، فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏\hadithno{1204}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Iyad narrated that he asked Abu Sa’eed Al-Khudri:“One of us prays and he does not know how many (Rak’ah) he has prayed.” He said: “The Messenger of Allah (ﷺ) said: ‘When anyone of you prays and does not know how many he has prayed, let him perform two prostrations while he is sitting.’”}}
\hadithdefcmd{ibnmajah}{1205}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، حَدَّثَنِي الْحَكَمُ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ: صَلَّى النَّبِيُّ ـ صلى الله عليه وسلم ـ الظُّهْرَ خَمْسًا. فَقِيلَ لَهُ: أَزِيدَ فِي الصَّلاَةِ؟ قَالَ ‏ "‏ وَمَا ذَاكَ؟ ‏"‏ ‏.‏ فَقِيلَ لَهُ ‏.‏ فَثَنَى رِجْلَهُ، فَسَجَدَ سَجْدَتَيْنِ ‏.‏\hadithno{1205}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdullah said:“(Once) the Prophet (ﷺ) prayed Zuhr with five Rak’ah, and it was said to him: ‘Has something been added to the prayer?’ He said: ‘What is that?’ They told him, and he turned back towards the Qiblah and performed two prostrations.”}}
\hadithdefcmd{ibnmajah}{1206}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ وَهِشَامُ بْنُ عَمَّارٍ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ الأَعْرَجِ، عَنِ ابْنِ بُحَيْنَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى صَلاَةً أَظُنُّ أَنَّهَا الظُّهْرُ (العَصْرُ) فَلَمَّا كَانَ فِي الثَّانِيَةِ قَامَ قَبْلَ أَنْ يَجْلِسَ فَلَمَّا كَانَ قَبْلَ أَنْ يُسَلِّمَ سَجَدَ سَجْدَتَيْنِ ‏.‏\hadithno{1206}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn Buhainah:“The Prophet (ﷺ) offered prayer, I think it was the ‘Asr, and in the second Rak’ah he stood up before he sat. Before he said the Salam, he prostrated twice.”}}
\hadithdefcmd{ibnmajah}{1207}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَابْنُ، فُضَيْلٍ وَيَزِيدُ بْنُ هَارُونَ ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، وَيَزِيدُ بْنُ هَارُونَ، وَأَبُو مُعَاوِيَةَ كُلُّهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، أَنَّ ابْنَ بُحَيْنَةَ، أَخْبَرَهُ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَامَ فِي ثِنْتَيْنِ مِنَ الظُّهْرِ نَسِيَ الْجُلُوسَ حَتَّى إِذَا فَرَغَ مِنْ صَلاَتِهِ إِلاَّ أَنْ يُسَلِّمَ سَجَدَ سَجْدَتَىِ السَّهْوِ وَسَلَّمَ ‏.‏\hadithno{1207}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdur-Rahman Al-A’raj that Ibn Buhainah told him that the Prophet (ﷺ) stood up in the second Rak’ah of Zuhr and forgot to sit. When he had finished his prayer, and before he said the Salam, he performed the two prostrations for forgetfulness (Sahw) and said the Salam}}
\hadithdefcmd{ibnmajah}{1208}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ جَابِرٍ، عَنِ الْمُغِيرَةِ بْنِ شُبَيْلٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا قَامَ أَحَدُكُمْ مِنَ الرَّكْعَتَيْنِ فَلَمْ يَسْتَتِمَّ قَائِمًا فَلْيَجْلِسْ فَإِذَا اسْتَتَمَّ قَائِمًا فَلاَ يَجْلِسْ وَيَسْجُدْ سَجْدَتَىِ السَّهْوِ ‏"‏ ‏.‏\hadithno{1208}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Mughirah bin Shu’bah said:“The Messenger of Allah (ﷺ) said: ‘If anyone of you stands after two Rak’ah, if he has not yet stood up fully, let him sit down again, but if he has stood up fully, then let him not sit down, and let him perform two prostrations for forgetfulness (Sahw).’”}}
\hadithdefcmd{ibnmajah}{1209}{حَدَّثَنَا أَبُو يُوسُفَ الرَّقِّيُّ، مُحَمَّدُ بْنُ أَحْمَدَ الصَّيْدَلاَنِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مَكْحُولٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا شَكَّ أَحَدُكُمْ فِي الثِّنْتَيْنِ وَالْوَاحِدَةِ فَلْيَجْعَلْهَا وَاحِدَةً وَإِذَا شَكَّ فِي الثِّنْتَيْنِ وَالثَّلاَثِ فَلْيَجْعَلْهَا ثِنْتَيْنِ وَإِذَا شَكَّ فِي الثَّلاَثِ وَالأَرْبَعِ فَلْيَجْعَلْهَا ثَلاَثًا ثُمَّ لْيُتِمَّ مَا بَقِيَ مِنْ صَلاَتِهِ حَتَّى يَكُونَ الْوَهْمُ فِي الزِّيَادَةِ ثُمَّ يَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ قَبْلَ أَنْ يُسَلِّمَ ‏"‏ ‏.‏\hadithno{1209}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Abdur-Rahman bin ‘Awf said:“I heard the Messenger of Allah (ﷺ) say: ‘If anyone of you is uncertain as to whether he has prayed one or two Rak’ah, let him assume it is one. If he is uncertain as to whether he has prayed two or three, let him assume it is two. If he is uncertain as to whether he has prayed three or four, let him assume it is three. Then let him complete what is left of his prayer, so that the doubt will be about what is more. Then let him prostrate twice while he is sitting, before the Taslim (saying the Salam).’”}}
\hadithdefcmd{ibnmajah}{1210}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا شَكَّ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيُلْغِ الشَّكَّ وَلْيَبْنِ عَلَى الْيَقِينِ فَإِذَا اسْتَيْقَنَ التَّمَامَ سَجَدَ سَجْدَتَيْنِ فَإِنْ كَانَتْ صَلاَتُهُ تَامَّةً كَانَتِ الرَّكْعَةُ نَافِلَةً وَإِنْ كَانَتْ نَاقِصَةً كَانَتِ الرَّكْعَةُ لِتَمَامِ صَلاَتِهِ وَكَانَتِ السَّجْدَتَانِ رَغْمَ أَنْفِ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{1210}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) said: ‘If anyone of you is uncertain about his prayer, let him put aside uncertainty and act upon that which is certain. When he has made sure his prayer is complete, then let him prostrate twice. Then if his prayer was complete, that (extra) Rak’ah will be counted as voluntary, and if his prayer was lacking, that Rak’ah will complete his prayer, and the two prostrations will rub the Satan’s nose in the dust.’”}}
\hadithdefcmd{ibnmajah}{1211}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ شُعْبَةُ كَتَبَ إِلَىَّ وَقَرَأْتُهُ عَلَيْهِ قَالَ أَخْبَرَنِي إِبْرَاهِيمُ عَنْ عَلْقَمَةَ عَنْ عَبْدِ اللَّهِ قَالَ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَلاَةً لاَ يَدْرِي أَزَادَ أَوْ نَقَصَ ‏.‏ فَسَأَلَ فَحَدَّثْنَاهُ فَثَنَى رِجْلَهُ وَاسْتَقْبَلَ الْقِبْلَةَ وَسَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏ "‏ لَوْ حَدَثَ فِي الصَّلاَةِ شَىْءٌ لأَنْبَأْتُكُمُوهُ وَإِنَّمَا أَنَا بَشَرٌ أَنْسَى كَمَا تَنْسَوْنَ فَإِذَا نَسِيتُ فَذَكِّرُونِي وَأَيُّكُمْ مَا شَكَّ فِي الصَّلاَةِ فَلْيَتَحَرَّ أَقْرَبَ ذَلِكَ مِنَ الصَّوَابِ فَيُتِمَّ عَلَيْهِ وَيُسَلِّمَ وَيَسْجُدَ سَجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{1211}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdullah said:“The Messenger of Allah (ﷺ) offered prayer, and I am not sure whether he did something extra or omitted something. He asked, and we told him, so he turned to face the Qiblah and prostrated twice, then he said the Salam. Then he turned to face us and said: ‘If any new command has been revealed concerning the prayer, I would certainly have told you. But I am only human and I forget and you forget. If I forget, then remind me. And if anyone of you is uncertain about the prayer, let him do what is closest to what is correct, then complete the prayer, say the Salam and prostrate twice.”}}
\hadithdefcmd{ibnmajah}{1212}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا شَكَّ أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَتَحَرَّ الصَّوَابَ ثُمَّ يَسْجُدْ سَجْدَتَيْنِ ‏"‏ ‏.‏ قَالَ الطَّنَافِسِيُّ هَذَا الأَصْلُ وَلاَ يَقْدِرُ أَحَدٌ يَرُدُّهُ ‏.‏\hadithno{1212}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah said:“The Messenger of Allah (ﷺ) said: ‘If anyone of you is uncertain about his prayer, let him try to do what is correct then let him prostrate twice.’” Tanafisi said: "This is the basic rule, and no one is able to reject it}}
\hadithdefcmd{ibnmajah}{1213}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَأَبُو كُرَيْبٍ وَأَحْمَدُ بْنُ سِنَانٍ قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سَهَا فَسَلَّمَ فِي الرَّكْعَتَيْنِ ‏.‏ فَقَالَ لَهُ رَجُلٌ يُقَالُ لَهُ ذُو الْيَدَيْنِ يَا رَسُولَ اللَّهِ أَقَصُرَتِ الصَّلاَةُ أَمْ نَسِيتَ؟ قَالَ ‏"‏ مَا قَصُرَتْ وَمَا نَسِيتُ ‏"‏ ‏.‏ قَالَ إِنَّكَ صَلَّيْتَ رَكْعَتَيْنِ ‏.‏ قَالَ ‏"‏ أَكَمَا يَقُولُ ذُو الْيَدَيْنِ؟ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَتَقَدَّمَ فَصَلَّى رَكْعَتَيْنِ. ثُمَّ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَىِ السَّهْوِ ‏.‏\hadithno{1213}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) forgot and said the Taslim after two Rak’ah. A man who was called Dhul-Yadain said to him:‘O Messenger of Allah, has the prayer been shortened or did you forget?’ He said: ‘It has not been shortened and I did not forget.’ He said: ‘But you prayed two Rak’ah.’ He said: ‘Is what Dhul-Yadain says true?’ They said: ‘Yes.’ So he went forward and performed two Rak’ah and said the Salam, then he prostrated twice for prostrations of forgetfulness}}
\hadithdefcmd{ibnmajah}{1214}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ ابْنِ عَوْنٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِحْدَى صَلاَتَىِ الْعَشِيِّ رَكْعَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ قَامَ إِلَى خَشَبَةٍ كَانَتْ فِي الْمَسْجِدِ يَسْتَنِدُ إِلَيْهَا فَخَرَجَ سَرَعَانُ النَّاسِ يَقُولُونَ قَصُرَتِ الصَّلاَةُ ‏.‏ وَفِي الْقَوْمِ أَبُو بَكْرٍ وَعُمَرُ فَهَابَاهُ أَنْ يَقُولاَ لَهُ شَيْئًا وَفِي الْقَوْمِ رَجُلٌ طَوِيلُ الْيَدَيْنِ يُسَمَّى ذَا الْيَدَيْنِ فَقَالَ يَا رَسُولَ اللَّهِ أَقَصُرَتِ الصَّلاَةُ أَمْ نَسِيتَ؟ فَقَالَ ‏"‏ لَمْ تَقْصُرْ وَلَمْ أَنْسَ ‏"‏ ‏.‏ قَالَ فَإِنَّمَا صَلَّيْتَ رَكْعَتَيْنِ ‏.‏ فَقَالَ ‏"‏ أَكَمَا يَقُولُ ذُو الْيَدَيْنِ؟ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ فَقَامَ فَصَلَّى رَكْعَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1214}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) led us in one of the afternoon prayers, and he prayed two Rak’ah, then he said the Salam. Then he stood up and went to a piece of wood in the mosque, and leaned against it. Those who were in a hurry left the mosque, saying that the prayer had been shortened. Among the people were Abu Bakr and ‘Umar, but they dared not say anything. Among the people there was also a man with long hands who was called Dhul- Yadain. He said: ‘O Messenger of Allah, has the prayer been shortened or did you forget?’ He said: ‘It has not been shortened and I did not forget.’ He said: ‘But you prayed two Rak’ah.’ He said: ‘Is what Dhul- Yadain says true?’ They said: ‘Yes.’ So he went forward and performed two Rak’ah and said the Salam, then he prostrated twice, and then he said the Salam again.”}}
\hadithdefcmd{ibnmajah}{1215}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَأَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، قَالَ سَلَّمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي ثَلاَثِ رَكَعَاتٍ مِنَ الْعَصْرِ ثُمَّ قَامَ فَدَخَلَ الْحُجْرَةَ فَقَامَ الْخِرْبَاقُ رَجُلٌ بَسِيطُ الْيَدَيْنِ فَنَادَى يَا رَسُولَ اللَّهِ أَقَصُرَتِ الصَّلاَةُ؟ فَخَرَجَ مُغْضَبًا يَجُرُّ إِزَارَهُ. فَسَأَلَ، فَأُخْبِرَ. فَصَلَّى تِلْكَ الرَّكْعَةَ الَّتِي كَانَ تَرَكَ. ثُمَّ سَلَّمَ. ثُمَّ سَجَدَ سَجْدَتَيْنِ. ثُمَّ سَلَّمَ ‏.‏\hadithno{1215}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Imran bin Husain said:“The Messenger of Allah (ﷺ) said the Salam after three Rak’ah for ‘Asr, then he stood up and went into the apartment. Khirbaq, a man with big hands, stood up and called out: ‘O Messenger of Allah! Has the prayer been shortened?’ He came out angrily, dragging his lower garment, and asked about it, and was told (what had happened). So he performed the Rak’ah that he had omitted, then he said the Salam, then he prostrated twice and said the Salam again.”}}
\hadithdefcmd{ibnmajah}{1216}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنَا ابْنُ إِسْحَاقَ، حَدَّثَنِي الزُّهْرِيُّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الشَّيْطَانَ يَأْتِي أَحَدَكُمْ فِي صَلاَتِهِ، فَيَدْخُلُ بَيْنَهُ وَبَيْنَ نَفْسِهِ حَتَّى لاَ يَدْرِي زَادَ أَوْ نَقَصَ. فَإِذَا كَانَ ذَلِكَ، فَلْيَسْجُدْ سَجْدَتَيْنِ قَبْلَ أَنْ يُسَلِّمَ. ثُمَّ يُسَلِّمْ ‏"‏ ‏.‏\hadithno{1216}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The Satan comes to any one of you while he is praying and comes between him and his soul, until he does not know whether he as added something or omitted something. If that happens, then he should prostrate twice before the Salam, then he should say the Salam.”}}
\hadithdefcmd{ibnmajah}{1217}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنَا ابْنُ إِسْحَاقَ، أَخْبَرَنِي سَلَمَةُ بْنُ صَفْوَانَ بْنِ سَلَمَةَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الشَّيْطَانَ يَدْخُلُ بَيْنَ ابْنِ آدَمَ وَبَيْنَ نَفْسِهِ فَلاَ يَدْرِي كَمْ صَلَّى فَإِذَا وَجَدَ ذَلِكَ فَلْيَسْجُدْ سَجْدَتَيْنِ قَبْلَ أَنْ يُسَلِّمَ ‏"‏ ‏.‏\hadithno{1217}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The Satan comes between the son of Adam and his soul, and he does not know how many Rak’ah he has prayed. If a person notices that, then let him prostrate twice before he says the Salam.”}}
\hadithdefcmd{ibnmajah}{1218}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، أَنَّ ابْنَ مَسْعُودٍ، سَجَدَ سَجْدَتَىِ السَّهْوِ بَعْدَ السَّلاَمِ وَذَكَرَ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَعَلَ ذَلِكَ ‏.‏\hadithno{1218}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Alqamah that Ibn Mas’ud prostrated twice for the prostrations of forgetfulness after the Salam, and he mentioned that the Prophet (ﷺ) did that.”}}
\hadithdefcmd{ibnmajah}{1219}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَة��، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُبَيْدٍ، عَنْ زُهَيْرِ بْنِ سَالِمٍ الْعَنْسِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ ثَوْبَانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ فِي كُلِّ سَهْوٍ سَجْدَتَانِ بَعْدَ مَا يُسَلِّمُ ‏"‏ ‏.‏\hadithno{1219}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Thawban said:“I heard the Messenger of Allah (ﷺ) say: ‘For every mistake there are two prostrations, after saying the Salam.’”}}
\hadithdefcmd{ibnmajah}{1220}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُوسَى التَّيْمِيُّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِلَى الصَّلاَةِ وَكَبَّرَ ثُمَّ أَشَارَ إِلَيْهِمْ فَمَكَثُوا ثُمَّ انْطَلَقَ فَاغْتَسَلَ وَكَانَ رَأْسُهُ يَقْطُرُ مَاءً فَصَلَّى بِهِمْ فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنِّي خَرَجْتُ إِلَيْكُمْ جُنُبًا. وَإِنِّي نَسِيتُ حَتَّى قُمْتُ فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1220}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) came out to pray and said the Takbir, then he gestured to them to wait. He went and took a bath, and his head was dripping with water while he led them in prayer. When he finished he said: ‘I came out to you in a state of sexual impurity, and I forgot until I had started to pray.’”}}
\hadithdefcmd{ibnmajah}{1221}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْهَيْثَمُ بْنُ خَارِجَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَصَابَهُ قَىْءٌ أَوْ رُعَافٌ أَوْ قَلَسٌ أَوْ مَذْىٌ، فَلْيَنْصَرِفْ، فَلْيَتَوَضَّأْ. ثُمَّ لْيَبْنِ عَلَى صَلاَتِهِ، وَهُوَ فِي ذَلِكَ لاَ يَتَكَلَّمُ ‏"‏ ‏.‏\hadithno{1221}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) said: ‘Whoever vomits, has a nosebleed, belches, or emits prostatic fluid, should stop praying; perform ablution, then resume his prayer, and while he is in that state he should not speak.”}}
\hadithdefcmd{ibnmajah}{1222}{حَدَّثَنَا عُمَرُ بْنُ شَبَّةَ بْنِ عَبِيدَةَ بْنِ زَيْدٍ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ الْمُقَدَّمِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ فَأَحْدَثَ، فَلْيُمْسِكْ عَلَى أَنْفِهِ، ثُمَّ لْيَنْصَرِفْ ‏"‏ ‏.‏ حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا عُمَرُ بْنُ قَيْسٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1222}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said:“When anyone of you performs prayer and commits Hadath, (passing wind) let him take hold of his nose, then leave.” Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{1223}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ كَانَ بِي النَّاصُورُ فَسَأَلْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ عَنِ الصَّلاَةِ فَقَالَ ‏ "‏ صَلِّ قَائِمًا. فَإِنْ لَمْ تَسْتَطِعْ فَقَاعِدًا. فَإِنْ لَمْ تَسْتَطِعْ، فَعَلَى جَنْبٍ ‏"‏ ‏.‏\hadithno{1223}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Imran bin Husain said:“I suffered from Nasur* and I asked the Prophet (ﷺ) about prayer. He said: ‘Perform prayer standing; if you cannot, then sitting; and if you cannot then while lying on your side.’”}}
\hadithdefcmd{ibnmajah}{1224}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، عَنْ سُفْيَانَ، عَنْ جَابِرٍ، عَنْ أَبِي حَرِيزٍ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى جَالِسًا عَلَى يَمِينِهِ وَهُوَ وَجِعٌ ‏.‏\hadithno{1224}\hadithgrade{Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Wa’il bin Hujr said:“I saw the Prophet (ﷺ) performing prayer while sitting on his right side when he was sick.”}}
\hadithdefcmd{ibnmajah}{1225}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ وَالَّذِي ذَهَبَ بِنَفْسِهِ ـ صلى الله عليه وسلم ـ مَا مَاتَ حَتَّى كَانَ أَكْثَرُ صَلاَتِهِ وَهُوَ جَالِسٌ وَكَانَ أَحَبُّ الأَعْمَالِ إِلَيْهِ الْعَمَلَ الصَّالِحَ الَّذِي يَدُومُ عَلَيْهِ الْعَبْدُ وَإِنْ كَانَ يَسِيرًا ‏.‏\hadithno{1225}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Salamah said:‘By the One Who took his soul (i.e., the soul of the Prophet (ﷺ)), he did not die until he offered most of his prayers sitting down. And the dearest of the actions to him was the righteous action that the person does regularly, even if it were a little.”}}
\hadithdefcmd{ibnmajah}{1226}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ الْوَلِيدِ بْنِ أَبِي هِشَامٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَقْرَأُ وَهُوَ قَاعِدٌ فَإِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ قَدْرَ مَا يَقْرَأُ إِنْسَانٌ أَرْبَعِينَ آيَةً ‏.‏\hadithno{1226}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) used to recite Qur’an sitting down, then when he wanted to bow he would stand up for as long as it takes a person to recite forty Verses.”}}
\hadithdefcmd{ibnmajah}{1227}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي فِي شَىْءٍ مِنْ صَلاَةِ اللَّيْلِ إِلاَّ قَائِمًا حَتَّى دَخَلَ فِي السِّنِّ فَجَعَلَ يُصَلِّي جَالِسًا حَتَّى إِذَا بَقِيَ عَلَيْهِ مِنْ قِرَاءَتِهِ أَرْبَعُونَ آيَةً أَوْ ثَلاَثُونَ آيَةً قَامَ فَقَرَأَهَا وَسَجَدَ ‏.‏\hadithno{1227}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“I did not see the Messenger of Allah (ﷺ) offer any of the night prayers in any way other than standing, until he became old. Then he started to pray sitting down until, when there were thirty or forty Verses left of his recitation, he would stand up and recite them, and prostrate.”}}
\hadithdefcmd{ibnmajah}{1228}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنْ حُمَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ الْعُقَيْلِيِّ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِاللَّيْلِ فَقَالَتْ كَانَ يُصَلِّي لَيْلاً طَوِيلاً قَائِمًا وَلَيْلاً طَوِيلاً قَاعِدًا فَإِذَا قَرَأَ قَائِمًا رَكَعَ قَائِمًا وَإِذَا قَرَأَ قَاعِدًا رَكَعَ قَاعِدًا ‏.‏\hadithno{1228}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Abdullah bin Shaqiq Al-‘Uqaili said:“I asked ‘Aishah about the prayer of the Messenger of Allah (ﷺ) at night. She said: ‘He used to pray for a long time at night standing up, and for a long time at night sitting down. If he prayed standing, he would bow standing, and if he prayed sitting, he would bow sitting.’”}}
\hadithdefcmd{ibnmajah}{1229}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا قُطْبَةُ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَاهْ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ مَرَّ بِهِ وَهُوَ يُصَلِّي جَالِسًا فَقَالَ ‏ "‏ صَلاَةُ الْجَالِسِ عَلَى النِّصْفِ مِنْ صَلاَةِ الْقَائِمِ ‏"‏ ‏.‏\hadithno{1229}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Prophet (ﷺ) passed by him when he was praying sitting down. He said:“The prayer of one who sits down is equivalent to half of the prayer of one who stands.”}}
\hadithdefcmd{ibnmajah}{1230}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ خَرَجَ فَرَأَى أُنَاسًا يُصَلُّونَ قُعُودًا فَقَالَ ‏ "‏ صَلاَةُ الْقَاعِدِ عَلَى النِّصْفِ مِنْ صَلاَةِ الْقَائِمِ ‏"‏ ‏.‏\hadithno{1230}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) went out and saw some people praying while sitting down. He said:“The prayer of one who sits down is equivalent to half of the prayer of one who stands.”}}
\hadithdefcmd{ibnmajah}{1231}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الرَّجُلِ يُصَلِّي قَاعِدًا قَالَ ‏ "‏ مَنْ صَلَّى قَائِمًا فَهُوَ أَفْضَلُ. وَمَنْ صَلَّى قَاعِدًا فَلَهُ نِصْفُ أَجْرِ الْقَائِمِ. وَمَنْ صَلَّى نَائِمًا فَلَهُ نِصْفُ أَجْرِ الْقَاعِدِ ‏"‏ ‏.‏\hadithno{1231}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from ‘Imran bin Husain that he asked the Messenger of Allah (ﷺ) about a man who prays sitting down. He said, “Whoever performs prayer standing up, that is better. Whoever performs prayer sitting down will have half the reward of one who prays standing. And whoever performs prayer lying down will have half the reward of one who prays sitting.”}}
\hadithdefcmd{ibnmajah}{1232}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا مَرِضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَضَهُ الَّذِي مَاتَ فِيهِ - وَقَالَ أَبُو مُعَاوِيَةَ لَمَّا ثَقُلَ - جَاءَ بِلاَلٌ يُؤْذِنُهُ بِالصَّلاَةِ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّ أَبَا بَكْرٍ رَجُلٌ أَسِيفٌ - تَعْنِي رَقِيقٌ - وَمَتَى مَا يَقُومُ مُقَامَكَ يَبْكِي فَلاَ يَسْتَطِيعُ فَلَوْ أَمَرْتَ عُمَرَ فَصَلَّى بِالنَّاسِ ‏.‏ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرِ فَلْيُصَلِّ بِالنَّاسِ فَإِنَّكُنَّ صَوَاحِبَاتُ يُوسُفَ ‏"‏ ‏.‏ قَالَتْ فَأَرْسَلْنَا إِلَى أَبِي بَكْرٍ فَصَلَّى بِالنَّاسِ فَوَجَدَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ نَفْسِهِ خِفَّةً فَخَرَجَ إِلَى الصَّلاَةِ يُهَادَى بَيْنَ رَجُلَيْنِ وَرِجْلاَهُ تَخُطَّانِ فِي الأَرْضِ فَلَمَّا أَحَسَّ بِهِ أَبُو بَكْرٍ ذَهَبَ لِيَتَأَخَّرَ فَأَوْمَى إِلَيْهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ مَكَانَكَ ‏.‏ قَالَ فَجَاءَ حَتَّى أَجْلَسَاهُ إِلَى جَنْبِ أَبِي بَكْرٍ فَكَانَ أَبُو بَكْرٍ يَأْتَمُّ بِالنَّبِيِّ ـ صلى الله عليه وسلم ـ وَالنَّاسُ يَأْتَمُّونَ بِأَبِي بَكْرٍ ‏.‏\hadithno{1232}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“When the Messenger of Allah (ﷺ) fell ill with the sickness that would be his last” – (One of the narrators) Abu Mu’awiyah said: “When he was overcome by sickness” – “Bilal came to tell him that it was time for prayer. He said, ‘Tell Abu Bakr to lead the people in prayer.’ We said: ‘O Messenger of Allah! Abu Bakr is a tender-hearted man, and when he takes your place he will weep and not be able to do it. Why do you not tell ‘Umar to lead the people in prayer?’ He said: ‘Tell Abu Bakr to lead the people in prayer; you are (like) the female companions of Yusuf.’” She said: “So we sent word to Abu Bakr, and he led the people in prayer. Then the Messenger of Allah (ﷺ) began to feel a little better, so he came out to the prayer, supported by two men with his feet making lines along the ground. When Abu Bakr realized that he was there, he wanted to step back, but the Prophet (ﷺ) gestured to him to stay where he was. Then (the two men) brought him to sit beside Abu Bakr, and Abu Bakr was following the lead of the Prophet (ﷺ) and the people were following Abu Bakr.”}}
\hadithdefcmd{ibnmajah}{1233}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَبَا بَكْرٍ أَنْ يُصَلِّيَ بِالنَّاسِ فِي مَرَضِهِ فَكَانَ يُصَلِّي بِهِمْ فَوَجَدَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ خِفَّةً فَخَرَجَ وَإِذَا أَبُو بَكْرٍ يَؤُمُّ النَّاسَ فَلَمَّا رَآهُ أَبُو بَكْرٍ اسْتَأْخَرَ فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَىْ كَمَا أَنْتَ فَجَلَسَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حِذَاءَ أَبِي بَكْرٍ إِلَى جَنْبِهِ فَكَانَ أَبُو بَكْرٍ يُصَلِّي بِصَلاَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَالنَّاسُ يُصَلُّونَ بِصَلاَةِ أَبِي بَكْرٍ ‏.‏\hadithno{1233}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) told Abu Bakr to lead the people in prayer when he was sick, and Abu Bakr used to lead them in prayer. Then the Messenger of Allah (ﷺ) began to feel a little better, so he came out, and saw Abu Bakr leading the people in prayer. When Abu Bakr saw him, he stepped back, but the Messenger of Allah (ﷺ) gestured to him to stay where he was. Then the Messenger of Allah (ﷺ) sat beside Abu Bakr. Abu Bakr was following the prayer of the Messenger of Allah (ﷺ), and the people were following the prayer of Abu Bakr.”}}
\hadithdefcmd{ibnmajah}{1234}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، مِنْ كِتَابِهِ فِي بَيْتِهِ قَالَ سَلَمَةُ بْنُ نُبَيْطٍ أَنْبَأَنَا عَنْ نُعَيْمِ بْنِ أَبِي هِنْدٍ عَنْ نُبَيْطِ بْنِ شَرِيطٍ عَنْ سَالِمِ بْنِ عُبَيْدٍ قَالَ أُغْمِيَ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي مَرَضِهِ ثُمَّ أَفَاقَ فَقَالَ ‏"‏ أَحَضَرَتِ الصَّلاَةُ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ مُرُوا بِلاَلاً فَلْيُؤَذِّنْ وَمُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ - أَوْ لِلنَّاسِ - ‏"‏ ‏.‏ ثُمَّ أُغْمِيَ عَلَيْهِ فَأَفَاقَ فَقَالَ ‏"‏ أَحَضَرَتِ الصَّلاَةُ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ مُرُوا بِلاَلاً فَلْيُؤَذِّنْ وَمُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ ثُمَّ أُغْمِيَ عَلَيْهِ فَأَفَاقَ فَقَالَ ‏"‏ أَحَضَرَتِ الصَّلاَةُ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ مُرُوا بِلاَلاً فَلْيُؤَذِّنْ وَمُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ إِنَّ أَبِي رَجُلٌ أَسِيفٌ فَإِذَا قَامَ ذَلِكَ الْمُقَامَ يَبْكِي لاَ يَسْتَطِيعُ فَلَوْ أَمَرْتَ غَيْرَهُ ‏.‏ ثُمَّ أُغْمِيَ عَلَيْهِ فَأَفَاقَ فَقَالَ ‏"‏ مُرُوا بِلاَلاً فَلْيُؤَذِّنْ وَمُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ فَإِنَّكُنَّ صَوَاحِبُ يُوسُفَ أَوْ صَوَاحِبَاتُ يُوسُفَ ‏"‏ ‏.‏ قَالَ فَأُمِرَ بِلاَلٌ فَأَذَّنَ وَأُمِرَ أَبُو بَكْرٍ فَصَلَّى بِالنَّاسِ ثُمَّ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَجَدَ خِفَّةً فَقَالَ ‏"‏ انْظُرُوا لِي مَنْ أَتَّكِئُ عَلَيْهِ ‏"‏ ‏.‏ فَجَاءَتْ بَرِيرَةُ وَرَجُلٌ آخَرُ فَاتَّكَأَ عَلَيْهِمَا فَلَمَّا رَآهُ أَبُو بَكْرٍ ذَهَبَ لِيَنْكُصَ فَأَوْمَأَ إِلَيْهِ أَنِ اثْبُتْ مَكَانَكَ ثُمَّ جَاءَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حَتَّى جَلَسَ إِلَى جَنْبِ أَبِي بَكْرٍ حَتَّى قَضَى أَبُو بَكْرٍ صَلاَتَهُ ثُمَّ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قُبِضَ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ هَذَا حَدِيثٌ غَرِيبٌ لَمْ يُحَدِّثْ بِهِ غَيْرُ نَصْرِ بْنِ عَلِيٍّ ‏.‏\hadithno{1234}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Salim bin ‘Ubaid said:“The Messenger of Allah (ﷺ) fainted when he was sick, then he woke up and said: ‘Has the time for prayer come?’ They said: ‘Yes.’ He said: ‘Tell Bilal to call the Adhan, and tell Abu Bakr to lead the people in prayer.’ Then he fainted, then he woke up and said: ‘Has the time for prayer come?’ They said: ‘Yes.’ He said: ‘Tell Bilal to call the Adhan, and tell Abu Bakr to lead the people in prayer.’ Then he fainted, then he woke up and said: ‘Has the time for prayer come?’ They said: ‘Yes.’ He said: ‘Tell Bilal to call the Adhan, and tell Abu Bakr to lead the people in prayer.’ ‘Aishah said: ‘My father is a tender-hearted man, and if he stands in that place he will weep and will not be able to do it. If you told someone else to do it (that would be better).’ Then he fainted, then woke up and said: ‘Tell Bilal to call the Adhan, and tell Abu Bakr to lead the people in prayer. You are (like) the female companions of Yusuf.’ So Bilal was told to call the Adhan and he did so, and Abu Bakr was told to lead the people in prayer, and he did so. Then the Messenger of Allah (ﷺ) felt a little better, and he said: ‘Find me someone I can lean on.’ Barirah and another man came, and he leaned on them. When Abu Bakr saw him, he started to step back, but (the Prophet (ﷺ)) gestured him to stay where he was. Then the Messenger of Allah (ﷺ) came and sat beside Abu Bakr, until Abu Bakr finished praying. Then the Messenger of Allah (ﷺ) passed away.”}}
\hadithdefcmd{ibnmajah}{1235}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَرْقَمِ بْنِ شُرَحْبِيلَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا مَرِضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَضَهُ الَّذِي مَاتَ فِيهِ كَانَ فِي بَيْتِ عَائِشَةَ ‏.‏ فَقَالَ ‏"‏ ادْعُوا لِي عَلِيًّا ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ نَدْعُو لَكَ أَبَا بَكْرٍ قَالَ ‏"‏ ادْعُوهُ ‏"‏ ‏.‏ قَالَتْ حَفْصَةُ يَا رَسُولَ اللَّهِ نَدْعُو لَكَ عُمَرَ قَالَ ‏"‏ ادْعُوهُ ‏"‏ ‏.‏ قَالَتْ أُمُّ الْفَضْلِ يَا رَسُولَ اللَّهِ نَدْعُو لَكَ الْعَبَّاسَ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَلَمَّا اجْتَمَعُوا رَفَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ رَأْسَهُ فَنَظَرَ فَسَكَتَ فَقَالَ عُمَرُ قُومُوا عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ ثُمَّ جَاءَ بِلاَلٌ يُؤْذِنُهُ بِالصَّلاَةِ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا بَكْرٍ رَجُلٌ رَقِيقٌ حَصِرٌ وَمَتَى لاَ يَرَاكَ يَبْكِي وَالنَّاسُ يَبْكُونَ فَلَوْ أَمَرْتَ عُمَرَ يُصَلِّي بِالنَّاسِ ‏.‏ فَخَرَجَ أَبُو بَكْرٍ فَصَلَّى بِالنَّاسِ فَوَجَدَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ نَفْسِهِ خِفَّةً فَخَرَجَ يُهَادَى بَيْنَ رَجُلَيْنِ وَرِجْلاَهُ تَخُطَّانِ فِي الأَرْضِ فَلَمَّا رَآهُ النَّاسُ سَبَّحُوا بِأَبِي بَكْرٍ فَذَهَبَ لِيَسْتَأْخِرَ فَأَوْمَأَ إِلَيْهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَىْ مَكَانَكَ فَجَاءَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَجَلَسَ عَنْ يَمِينِهِ وَقَامَ أَبُو بَكْرٍ فَكَانَ أَبُو بَكْرٍ يَأْتَمُّ بِالنَّبِيِّ ـ صلى الله عليه وسلم ـ وَالنَّاسُ يَأْتَمُّونَ بِأَبِي بَكْرٍ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَأَخَذَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنَ الْقِرَاءَةِ مِنْ حَيْثُ كَانَ بَلَغَ أَبُو بَكْرٍ ‏.‏ قَالَ وَكِيعٌ وَكَذَا السُّنَّةُ ‏.‏ قَالَ فَمَاتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي مَرَضِهِ ذَلِكَ ‏.‏\hadithno{1235}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“When the Messenger of Allah (ﷺ) fell ill with what would be his final illness, he was in the house of ‘Aishah. He said: ‘Call ‘Ali for me.’ ‘Aishah said: ‘O Messenger of Allah, should we call Abu Bakr for you?’ He said: ‘Call him.’ Hafsah said: ‘O Messenger of Allah, should we call ‘Umar for you?’ He said: ‘Call him.’ Ummul-Fadl said: ‘O Messenger of Allah, should we call Al-‘Abbas for you?’ He said: ‘Yes.’ When they had gathered, the Messenger of Allah (ﷺ) lifted his head, looked and fell silent. ‘Umar said: ‘Get up and leave the Messenger of Allah (ﷺ).’ Then Bilal came to tell him that the time for prayer had come, and he said: ‘Tell Abu Bakr to lead the people in prayer.’ ‘Aishah said: ‘O Messenger of Allah, Abu Bakr is a soft and tender-hearted man, and if he does not see you, he will weep and the people will weep with him. If you tell ‘Umar to lead the people in prayer (that would be better).’ Abu Bakr went out and led the people in prayer, then the Messenger of Allah (ﷺ) felt a little better, so he came out, supported by two men, with his feet making lines along the ground. When the people saw him, they said: ‘Subhan-Allah,’ to alert Abu Bakr. He wanted to step back, but the Prophet (ﷺ) gestured him to stay where he was. Then the Messenger of Allah (ﷺ) came and sat on his right. Abu Bakr stood up and he was following the lead of the Prophet (ﷺ), and the people were following the lead of Abu Bakr. Ibn ‘Abbas said; ‘And the Messenger of Allah (ﷺ) started to recite from where Abu Bakr had reached.’”}}
\hadithdefcmd{ibnmajah}{1236}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حُمَيْدٍ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ حَمْزَةَ بْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أَبِيهِ، قَالَ تَخَلَّفَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَانْتَهَيْنَا إِلَى الْقَوْمِ وَقَدْ صَلَّى بِهِمْ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ رَكْعَةً فَلَمَّا أَحَسَّ بِالنَّبِيِّ ـ صلى الله عليه وسلم ـ ذَهَبَ يَتَأَخَّرُ فَأَوْمَأَ إِلَيْهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ يُتِمَّ الصَّلاَةَ قَالَ ‏ "‏ وَقَدْ أَحْسَنْتَ كَذَلِكَ فَافْعَلْ ‏"‏ ‏.‏\hadithno{1236}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Hamzah bin Mughirah bin Shu’bah narrated that his father said:“The Messenger of Allah (ﷺ) lagged behind (on a journey) and we reached the people when ‘Abdur Rahman bin ‘Awf had already led them in one Rak’ah of the prayer. When he realized that the Prophet (ﷺ) was there, he wanted to step back, but the Prophet (ﷺ) gestured to him that he should complete the prayer. He said: ‘You have done well, do the same in the future.’”}}
\hadithdefcmd{ibnmajah}{1237}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتِ اشْتَكَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَدَخَلَ عَلَيْهِ نَاسٌ مِنْ أَصْحَابِهِ يَعُودُونَهُ فَصَلَّى النَّبِيُّ ـ صلى الله عليه وسلم ـ جَالِسًا فَصَلَّوْا بِصَلاَتِهِ قِيَامًا فَأَشَارَ إِلَيْهِمْ أَنِ اجْلِسُوا فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ. فَإِذَا رَكَعَ فَارْكَعُوا. وَإِذَا رَفَعَ فَارْفَعُوا. وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا ‏"‏ ‏.‏\hadithno{1237}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) fell ill and some of his Companions came to visit him. The Messenger of Allah (ﷺ) performed prayer while sitting down, and they prayed behind him standing up. He gestured them to sit down, and when he finished he said: ‘The Imam is appointed to be followed. When he bows, then bow; when he stands up again, then stand up, and if he prays sitting down then pray sitting down.’”}}
\hadithdefcmd{ibnmajah}{1238}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صُرِعَ عَنْ فَرَسٍ فَجُحِشَ شِقُّهُ الأَيْمَنُ فَدَخَلْنَا نَعُودُهُ وَحَضَرَتِ الصَّلاَةُ فَصَلَّى بِنَا قَاعِدًا وَصَلَّيْنَا وَرَاءَهُ قُعُودًا فَلَمَّا قَضَى الصَّلاَةَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ وَإِذَا سَجَدَ فَاسْجُدُوا وَإِذَا صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا أَجْمَعِينَ ‏"‏ ‏.‏\hadithno{1238}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) fell from his horse and he suffered some lacerations on his right side. We went to visit him and the time for prayer came. He led us in prayer sitting down, and we prayed behind him sitting down. When he finished the prayer he said:“The Imam is appointed to be followed. When he says Allahu Akbar, then say Allahu Akbar; when he bows, then bow; when he says Sami’ Allahu liman hamidah, then say Rabbana wa lakal-hamd; when he prostrates then prostrate; and if he prays sitting down then pray sitting down.”}}
\hadithdefcmd{ibnmajah}{1239}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمُ بْنُ بَشِيرٍ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ وَإِنْ صَلَّى قَائِمًا فَصَلُّوا قِيَامًا وَإِنْ صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا ‏"‏ ‏.‏\hadithno{1239}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘The Imam is appointed to be followed. When he says Allahu Akbar, then say Allahu Akbar; when he bows, then bow; when he says Sami’ Allahu liman hamidah, then say Rabbana wa lakal-hamd; when he prostrates then prostrate; if he prays standing, then pray standing, and if he prays sitting down then pray sitting down.”}}
\hadithdefcmd{ibnmajah}{1240}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ اشْتَكَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَصَلَّيْنَا وَرَاءَهُ وَهُوَ قَاعِدٌ وَأَبُو بَكْرٍ يُكَبِّرُ يُسْمِعُ النَّاسَ تَكْبِيرَهُ فَالْتَفَتَ إِلَيْنَا فَرَآنَا قِيَامًا فَأَشَارَ إِلَيْنَا فَقَعَدْنَا فَصَلَّيْنَا بِصَلاَتِهِ قُعُودًا فَلَمَّا سَلَّمَ قَالَ ‏ "‏ إِنْ كِدْتُمْ أَنْ تَفْعَلُوا فِعْلَ فَارِسَ وَالرُّومِ يَقُومُونَ عَلَى مُلُوكِهِمْ وَهُمْ قُعُودٌ فَلاَ تَفْعَلُوا ائْتَمُّوا بِأَئِمَّتِكُمْ إِنْ صَلَّى قَائِمًا فَصَلُّوا قِيَامًا وَإِنْ صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا ‏"‏ ‏.‏\hadithno{1240}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) fell ill, and we prayed behind him while he was sitting down, and Abu Bakr was saying the Takbir so that the people could hear them. He turned to us and saw us standing, so he gestured to us to sit down. When he had said the Salam, he said: ‘You were about to do the action of the Persians and Romans, who remain standing while their kings are seated. Do not do that. Follow the lead of your Imam; if he prays standing, then pray standing, and if he prays sitting down, then pray sitting down.’”}}
\hadithdefcmd{ibnmajah}{1241}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَحَفْصُ بْنُ غِيَاثٍ، وَيَزِيدُ بْنُ هَارُونَ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، سَعْدِ بْنِ طَارِقٍ قَالَ قُلْتُ لأَبِي يَا أَبَتِ إِنَّكَ قَدْ صَلَّيْتَ خَلْفَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ وَعَلِيٍّ هَا هُنَا بِالْكُوفَةِ، نَحْوًا مِنْ خَمْسِ سِنِينَ. فَكَانُوا يَقْنُتُونَ فِي الْفَجْرِ؟ فَقَالَ: أَىْ بُنَىَّ مُحْدَثٌ ‏.‏\hadithno{1241}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sa’d bin Tariq said:“I said to my father: ‘O my father! You prayed behind the Messenger of Allah (ﷺ) and behind Abu Bakr, ‘Umar and ‘Uthman, and behind ‘Ali here in Kufah for about five years. Did they recite Qunut in Fajr?’ He said: ‘O my son! That is an innovation.’”}}
\hadithdefcmd{ibnmajah}{1242}{حَدَّثَنَا حَاتِمُ بْنُ بَكْرٍ الضَّبِّيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ يَعْلَى، زُنْبُورٌ حَدَّثَنَا عَنْبَسَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ: نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْقُنُوتِ فِي الْفَجْرِ ‏.‏\hadithno{1242}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Salamah said:“The Messenger of Allah (ﷺ) was forbidden to recite Qunut in Fajr.”}}
\hadithdefcmd{ibnmajah}{1243}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَقْنُتُ فِي صَلاَةِ الصُّبْحِ. يَدْعُو عَلَى حَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ، شَهْرًا. ثُمَّ تَرَكَ ‏.‏\hadithno{1243}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) used to recite Qunut in the Subh prayer, and he used to supplicate in it against one of the Arab tribes for a month, then he stopped doing so}}
\hadithdefcmd{ibnmajah}{1244}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا رَفَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ رَأْسَهُ مِنْ صَلاَةِ الصُّبْحِ قَالَ ‏ "‏ اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ، وَسَلَمَةَ بْنَ هِشَامٍ، وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ، وَالْمُسْتَضْعَفِينَ بِمَكَّةَ. اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ، وَاجْعَلْهَا عَلَيْهِمْ سِنِينَ كَسِنِي يُوسُفَ ‏"‏ ‏.‏\hadithno{1244}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“When the Messenger of Allah (ﷺ) raised his head from Ruku’ in the Subh prayer, he said: ‘O Allah, save Al-Walid bin Walid, Salamah bin Hisham and ‘Ayyash bin Abu Rabi’ah, and the oppressed in Makkah. O Allah, tighten Your grip on Mudar, and send them years of famine like the famine of Yusuf.”}}
\hadithdefcmd{ibnmajah}{1245}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَعْمَرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ ضَمْضَمِ بْنِ جَوْسٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَمَرَ بِقَتْلِ الأَسْوَدَيْنِ فِي الصَّلاَةِ الْعَقْرَبِ وَالْحَيَّةِ ‏.‏\hadithno{1245}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) commanded killing the two black ones during prayer; the scorpion and the snake}}
\hadithdefcmd{ibnmajah}{1246}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ الأَوْدِيُّ، وَالْعَبَّاسُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا عَلِيُّ بْنُ ثَابِتٍ الدَّهَّانُ، حَدَّثَنَا الْحَكَمُ بْنُ عَبْدِ الْمَلِكِ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، قَالَتْ لَدَغَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ عَقْرَبٌ وَهُوَ فِي الصَّلاَةِ فَقَالَ ‏ "‏ لَعَنَ اللَّهُ الْعَقْرَبَ مَا تَدَعُ الْمُصَلِّيَ وَغَيْرَ الْمُصَلِّي اقْتُلُوهَا فِي الْحِلِّ وَالْحَرَمِ ‏"‏ ‏.‏\hadithno{1246}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) was stung by a scorpion while he was performing prayer, and he said: ‘May Allah curse the scorpion, for it does not spare anyone, whether he is praying or not. Kill them whether you are in Ihram or not.’” In Al-Hill (outside the sacred precincts of Makkah) or Al-Haram (the sacred precincts or Makkah)}}
\hadithdefcmd{ibnmajah}{1247}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْهَيْثَمُ بْنُ جَمِيلٍ، حَدَّثَنَا مَنْدَلٌ، عَنِ ابْنِ أَبِي رَافِعٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَتَلَ عَقْرَبًا وَهُوَ فِي الصَّلاَةِ ‏.‏\hadithno{1247}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Abu Rafi’, from his father, from his grandfather, that the Prophet (ﷺ) killed a scorpion while he was praying}}
\hadithdefcmd{ibnmajah}{1248}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْ صَلاَتَيْنِ عَنِ الصَّلاَةِ بَعْدَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ وَبَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ ‏.‏\hadithno{1248}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) forbade two prayers:prayer after the Fajr until the sun has risen, and prayer after ‘Asr until the sun has set}}
\hadithdefcmd{ibnmajah}{1249}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى التَّيْمِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ صَلاَةَ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَلاَ صَلاَةَ بَعْدَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{1249}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) said:“There is no prayer after the ‘Asr until the sun has set, and there is no prayer after the Fajr until the sun has risen.”}}
\hadithdefcmd{ibnmajah}{1250}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ شَهِدَ عِنْدِي رِجَالٌ مَرْضِيُّونَ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ وَأَرْضَاهُمْ عِنْدِي عُمَرُ أَنَّ رَ سُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ صَلاَةَ بَعْدَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ وَلاَ صَلاَةَ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{1250}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Good men among whom was ‘Umar bin Khattab, and the best of them in my view is ‘Umar, testified before me that the Messenger of Allah (ﷺ) said: ‘There is no prayer after Fajr until the sun has risen, and there is no prayer after the ‘Asr until the sun has set.’”}}
\hadithdefcmd{ibnmajah}{1251}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ يَزِيدَ بْنِ طَلْقٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ عَمْرِو بْنِ عَبَسَةَ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقُلْتُ هَلْ مِنْ سَاعَةٍ أَحَبُّ إِلَى اللَّهِ مِنْ أُخْرَى قَالَ ‏ "‏ نَعَمْ. جَوْفُ اللَّيْلِ الأَوْسَطُ. فَصَلِّ مَا بَدَا لَكَ حَتَّى يَطْلُعَ الصُّبْحُ. ثُمَّ انْتَهِ حَتَّى تَطْلُعَ الشَّمْسُ، وَمَا دَامَتْ كَأَنَّهَا حَجَفَةٌ حَتَّى تَنْتَشِرَ. ثُمَّ صَلِّ مَا بَدَا لَكَ حَتَّى يَقُومَ الْعَمُودُ عَلَى ظِلِّهِ. ثُمَّ انْتَهِ حَتَّى تَزُولَ الشَّمْسُ فَإِنَّ جَهَنَّمَ تُسْجَرُ نِصْفَ النَّهَارِ. ثُمَّ صَلِّ مَا بَدَا لَكَ حَتَّى تُصَلِّيَ الْعَصْرَ. ثُمَّ انْتَهِ حَتَّى تَغْرُبَ الشَّمْسُ، فَإِنَّهَا تَغْرُبُ بَيْنَ قَرْنَىِ الشَّيْطَانِ وَتَطْلُعُ بَيْنَ قَرْنَىِ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{1251}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Amr bin ‘Abasah said:“I came to the Messenger of Allah (ﷺ) and said: ‘Is there any time that is more beloved to Allah than another?’ He said: ‘Yes, the middle of the night, so pray as much as you want until dawn comes. Then refrain from praying until the sun has risen, and as long as it looks like a shield until it becomes apparent. Then pray as much as you want until a pole stands on its shadow (i.e., noon), then refrain from praying until it has crossed the zenith, for Hell is heated up at midday. Then pray as much as you want until you pray ‘Asr, then refrain from praying until the sun has set, for it sets between the two horns of Satan and it rises between the two horns of Satan.’”}}
\hadithdefcmd{ibnmajah}{1252}{حَدَّثَنَا الْحَسَنُ بْنُ دَاوُدَ الْمُنْكَدِرِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَأَلَ صَفْوَانُ بْنُ الْمُعَطَّلِ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي سَائِلُكَ عَنْ أَمْرٍ أَنْتَ بِهِ عَالِمٌ وَأَنَا بِهِ جَاهِلٌ ‏.‏ قَالَ ‏"‏ وَمَا هُوَ ‏"‏ ‏.‏ قَالَ هَلْ مِنْ سَاعَاتِ اللَّيْلِ وَالنَّهَارِ سَاعَةٌ تُكْرَهُ فِيهَا الصَّلاَةُ قَالَ ‏"‏ نَعَمْ. إِذَا صَلَّيْتَ الصُّبْحَ، فَدَعِ الصَّلاَةَ حَتَّى تَطْلُعَ الشَّمْسُ. فَإِنَّهَا تَطْلُعُ بِقَرْنَىِ الشَّيْطَانِ. ثُمَّ صَلِّ فَالصَّلاَةُ مَحْضُورَةٌ مُتَقَبَّلَةٌ حَتَّى تَسْتَوِيَ الشَّمْسُ عَلَى رَأْسِكَ كَالرُّمْحِ. فَإِذَا كَانَتْ عَلَى رَأْسِكَ كَالرُّمْحِ فَدَعِ الصَّلاَةَ. فَإِنَّ تِلْكَ السَّاعَةَ تُسْجَرُ فِيهَا جَهَنَّمُ وَتُفْتَحُ فِيهَا أَبْوَابُهَا. حَتَّى تَزِيغَ الشَّمْسُ عَنْ حَاجِبِكَ الأَيْمَنِ. فَإِذَا زَالَتْ فَالصَّلاَةُ مَحْضُورَةٌ مُتَقَبَّلَةٌ حَتَّى تُصَلِّيَ الْعَصْرَ. ثُمَّ دَعِ الصَّلاَةَ حَتَّى تَغِيبَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{1252}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“Safwan bin Mu’attal asked the Messenger of Allah (ﷺ): ‘O Messenger of Allah, I want to ask you about something of which you have knowledge and I know nothing.’ He said: ‘What is it?’ He said: ‘Is there any time of the night or day when it is disliked to perform prayer? He said: ‘Yes, when you have prayed the Subh, then do not pray until the sun has risen, for it rises between the two horns of Satan. Then pray, for the prayer is attended (by the angels) and is acceptable (to Allah) until the sun is right overhead like a spear. For at that time Hell is heated up and its gates are opened. (Then refrain from prayer) until the sun passes the zenith. Then when it has passed the zenith, the prayer is attended (by the angels) and is acceptable (to Allah) until you pray the ‘Asr. Then stop praying until the sun has set.’”}}
\hadithdefcmd{ibnmajah}{1253}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي عَبْدِ اللَّهِ الصُّنَابِحِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الشَّمْسَ تَطْلُعُ بَيْنَ قَرْنَىِ الشَّيْطَانِ أَوْ قَالَ: يَطْلُعُ مَعَهَا قَرْنَا الشَّيْطَانِ فَإِذَا ارْتَفَعَتْ فَارَقَهَا. فَإِذَا كَانَتْ فِي وَسَطِ السَّمَاءِ قَارَنَهَا. فَإِذَا دَلَكَتْ أَوْ قَالَ: زَالَتْ فَارَقَهَا. فَإِذَا دَنَتْ لِلْغُرُوبِ قَارَنَهَا. فَإِذَا غَرَبَتْ فَارَقَهَا. فَلاَ تُصَلُّوا هَذِهِ السَّاعَاتِ الثَّلاَثَ ‏"‏ ‏.‏\hadithno{1253}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu ‘Abdullah As-Sunabihi that the Messenger of Allah (ﷺ) said:“The sun rises between the two horns of Satan” or he said “The two horns of Satan rise with it, and when it has risen, Satan parts from it. When it is in the middle of the sky he accompanies it, then when it has crossed the zenith he parts from it. When it is about to set, he accompanies it, and when it has set he parts from it. So do no pray at these three times.”}}
\hadithdefcmd{ibnmajah}{1254}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَيْهِ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا بَنِي عَبْدِ مَنَافٍ لاَ تَمْنَعُوا أَحَدًا طَافَ بِهَذَا الْبَيْتِ وَصَلَّى أَيَّةَ سَاعَةٍ شَاءَ مِنَ اللَّيْلِ وَالنَّهَارِ ‏"‏ ‏.‏\hadithno{1254}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jubair bin Mut’im said:“The Messenger of Allah (ﷺ) said: ‘O Banu ‘Abd Manaf! Do not prevent anyone from circumambulating this House or praying at any time he wants of the day or night.”}}
\hadithdefcmd{ibnmajah}{1255}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَعَلَّكُمْ سَتُدْرِكُونَ أَقْوَامًا يُصَلُّونَ الصَّلاَةَ لِغَيْرِ وَقْتِهَا. فَإِنْ أَدْرَكْتُمُوهُمْ فَصَلُّوا فِي بُيُوتِكُمْ لِلْوَقْتِ الَّذِي تَعْرِفُونَ. ثُمَّ صَلُّوا مَعَهُمْ وَاجْعَلُوهَا سُبْحَةً ‏"‏ ‏.‏\hadithno{1255}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin Mas’ud said:“The Messenger of Allah (ﷺ) said: ‘You may come across people who offer a prayer at the wrong time. If you meet them, then perform prayer in your houses at the time that you know, then pray with them and make that voluntary.”}}
\hadithdefcmd{ibnmajah}{1256}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ صَلِّ الصَّلاَةَ لِوَقْتِهَا. فَإِنْ أَدْرَكْتَ الإِمَامَ يُصَلِّي بِهِمْ فَصَلِّ مَعَهُمْ، وَقَدْ أَحْرَزْتَ صَلاَتَكَ. وَإِلاَّ فَهِيَ نَافِلَةٌ لَكَ ‏"‏ ‏.‏\hadithno{1256}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Dharr that the Prophet (ﷺ) said:“Offer prayer on time, and if you reached the Imam leading them in prayers (on time), then perform it with them, and you will be safe with your prayer, otherwise it will be voluntary for you.”}}
\hadithdefcmd{ibnmajah}{1257}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ أَبِي الْمُثَنَّى، عَنْ أَبِي أُبَىٍّ ابْنِ امْرَأَةِ، عُبَادَةَ بْنِ الصَّامِتِ يَعْنِي عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ سَيَكُونُ أُمَرَاءُ تَشْغَلُهُمْ أَشْيَاءُ يُؤَخِّرُونَ الصَّلاَةَ عَنْ وَقْتِهَا فَاجْعَلُوا صَلاَتَكُمْ مَعَهُمْ تَطَوُّعًا ‏"‏ ‏.‏\hadithno{1257}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Ubadah bin Samit that the Prophet (ﷺ) said:“There will be leaders who will be distracted by matters and they will delay the prayer until after its proper time. So make your prayer with them voluntary.”}}
\hadithdefcmd{ibnmajah}{1258}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا جَرِيرٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي صَلاَةِ الْخَوْفِ ‏ "‏ أَنْ يَكُونَ الإِمَامُ يُصَلِّي بِطَائِفَةٍ مَعَهُ فَيَسْجُدُونَ سَجْدَةً وَاحِدَةً وَتَكُونُ طَائِفَةٌ مِنْهُمْ بَيْنَهُمْ وَبَيْنَ الْعَدُوِّ ثُمَّ يَنْصَرِفُ الَّذِينَ سَجَدُوا السَّجْدَةَ مَعَ أَمِيرِهِمْ ثُمَّ يَكُونُونَ مَكَانَ الَّذِينَ لَمْ يُصَلُّوا وَيَتَقَدَّمُ الَّذِينَ لَمْ يُصَلُّوا فَيُصَلُّوا مَعَ أَمِيرِهِمْ سَجْدَةً وَاحِدَةً ثُمَّ يَنْصَرِفُ أَمِيرُهُمْ وَقَدْ صَلَّى صَلاَتَهُ وَيُصَلِّي كُلُّ وَاحِدَةٍ مِنَ الطَّائِفَتَيْنِ بِصَلاَتِهِ سَجْدَةً لِنَفْسِهِ فَإِنْ كَانَ خَوْفٌ أَشَدَّ مِنْ ذَلِكَ فَرِجَالاً أَوْ رُكْبَانًا ‏"‏ ‏.‏ قَالَ يَعْنِي بِالسَّجْدَةِ الرَّكْعَةَ ‏.‏\hadithno{1258}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said concerning the fear prayer: “The Imam should lead one group in prayer, and they should perform one prostration, and there should be another group between them and the enemy (guarding them). Then those who did the prostration with their leader should move away, and take the place of those who have not yet prayed. Then those who have not yet prayed should come forward and perform one prostration with their leader. Then their leader should move away, and his prayer will be complete. Then each group should perform one prostration by itself. If the fear is too great, then (they should pray) on foot or riding.’” He said: What is meant by prostration here is a Rak’ah}}
\hadithdefcmd{ibnmajah}{1259}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّهُ قَالَ فِي صَلاَةِ الْخَوْفِ قَالَ يَقُومُ الإِمَامُ مُسْتَقْبِلَ الْقِبْلَةِ وَتَقُومُ طَائِفَةٌ مِنْهُمْ مَعَهُ وَطَائِفَةٌ مِنْ قِبَلِ الْعَدُوِّ وَوُجُوهُهُمْ إِلَى الصَّفِّ فَيَرْكَعُ بِهِمْ رَكْعَةً وَيَرْكَعُونَ لأَنْفُسِهِمْ وَيَسْجُدُونَ لأَنْفُسِهِمْ سَجْدَتَيْنِ فِي مَكَانِهِمْ ثُمَّ يَذْهَبُونَ إِلَى مُقَامِ أُولَئِكَ وَيَجِيءُ أُولَئِكَ فَيَرْكَعُ بِهِمْ رَكْعَةً وَيَسْجُدُ بِهِمْ سَجْدَتَيْنِ فَهِيَ لَهُ ثِنْتَانِ وَلَهُمْ وَاحِدَةٌ ثُمَّ يَرْكَعُونَ رَكْعَةً وَاحِدَةً وَيَسْجُدُونَ سَجْدَتَيْنِ ‏.‏ قَالَ مُحَمَّدُ بْنُ بَشَّارٍ فَسَأَلْتُ يَحْيَى بْنَ سَعِيدٍ الْقَطَّانَ عَنْ هَذَا الْحَدِيثِ فَحَدَّثَنِي عَنْ شُعْبَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ عَنْ أَبِيهِ عَنْ صَالِحِ بْنِ خَوَّاتٍ عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِمِثْلِ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ ‏.‏ قَالَ قَالَ لِي يَحْيَى اكْتُبْهُ إِلَى جَنْبِهِ وَلَسْتُ أَحْفَظُ الْحَدِيثَ وَلَكِنْ مِثْلُ حَدِيثِ يَحْيَى ‏.‏\hadithno{1259}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Sahl bin Abu Hathmah that he said concerning the fear prayer:“The Imam should stand facing the Qiblah, and a group of them should stand with him, and another group should stand in the direction of the enemy, facing towards the row (of worshippers). He should lead them in one Rak’ah, then they should bow and do two prostrations by themselves where they are. Then they should go and take the place of the others, and the others should come and pray one Rak’ah, bowing and prostrating with the leader. Then he will have prayed two Rak’ah and they will have prayed one; then they should perform another Rak’ah, bowing and performing two prostrations.”}}
\hadithdefcmd{ibnmajah}{1260}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى بِأَصْحَابِهِ صَلاَةَ الْخَوْفِ فَرَكَعَ بِهِمْ جَمِيعًا ثُمَّ سَجَدَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَالصَّفُّ الَّذِينَ يَلُونَهُ وَالآخَرُونَ قِيَامٌ حَتَّى إِذَا نَهَضَ سَجَدَ أُولَئِكَ بِأَنْفُسِهِمْ سَجْدَتَيْنِ ثُمَّ تَأَخَّرَ الصَّفُّ الْمُقَدَّمُ حَتَّى قَامُوا مُقَامَ أُولَئِكَ وَتَخَلَّلَ أُولَئِكَ حَتَّى قَامُوا مُقَامَ الصَّفِّ الْمُقَدَّمِ فَرَكَعَ بِهِمُ النَّبِيُّ ـ صلى الله عليه وسلم ـ جَمِيعًا ثُمَّ سَجَدَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَالصَّفُّ الَّذِي يَلُونَهُ فَلَمَّا رَفَعُوا رُءُوسَهُمْ سَجَدَ أُولَئِكَ سَجْدَتَيْنِ فَكُلُّهُمْ قَدْ رَكَعَ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَسَجَدَتْ طَائِفَةٌ بِأَنْفُسِهِمْ سَجْدَتَيْنِ وَكَانَ الْعَدُوُّ مِمَّا يَلِي الْقِبْلَةَ ‏.‏\hadithno{1260}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Prophet (ﷺ) led his Companions in the fear prayer. He led them all in bowing, then the Messenger of Allah (ﷺ) and the row nearest him prostrated, and the others stood up, then when he stood up, they prostrated twice by themselves. Then the front row moved back and took their place, and they moved forward until they formed the front row. Then the Prophet (ﷺ) led them all in bowing, then the Messenger of Allah (ﷺ) and the row nearest to him prostrated, and when they raised their heads, the others prostrated twice. So all of them bowed with the Prophet (ﷺ) and some of them prostrated by themselves, and the enemy was in the direction of the Qiblah}}
\hadithdefcmd{ibnmajah}{1261}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ مِنَ النَّاسِ. فَإِذَا رَأَيْتُمُوهُ فَقُومُوا فَصَلُّوا ‏"‏ ‏.‏\hadithno{1261}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Mas’ud said:The Messenger of Allah (ﷺ) said: “The sun and the moon do not become eclipsed for the death of anyone among mankind. If you see that, then stand and perform prayer.”}}
\hadithdefcmd{ibnmajah}{1262}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَأَحْمَدُ بْنُ ثَابِتٍ، وَجَمِيلُ بْنُ الْحَسَنِ، قَالُوا حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَخَرَجَ فَزِعًا يَجُرُّ ثَوْبَهُ حَتَّى أَتَى الْمَسْجِدَ فَلَمْ يَزَلْ يُصَلِّي حَتَّى انْجَلَتْ ثُمَّ قَالَ ‏ "‏ إِنَّ أُنَاسًا يَزْعُمُونَ أَنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ إِلاَّ لِمَوْتِ عَظِيمٍ مِنَ الْعُظَمَاءِ وَلَيْسَ كَذَلِكَ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا تَجَلَّى اللَّهُ لِشَىْءٍ مِنْ خَلْقِهِ خَشَعَ لَهُ ‏"‏ ‏.‏\hadithno{1262}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Nu’man bin Bashir said:“The sun was eclipsed at the time of the Messenger of Allah (ﷺ), and he came out alarmed, dragging his lower garment, until he reached the mosque. He continued to perform prayer until the eclipse was over, then he said: ‘Some people claim that the sun and moon only become eclipsed because of the death of a great leader. That is not so. The sun and the moon do not become eclipsed for the death or birth of anyone. When Allah manifests Himself to anything in His creation, it humbles itself before Him.’”}}
\hadithdefcmd{ibnmajah}{1263}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ كَسَفَتِ الشَّمْسُ فِي حَيَاةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَخَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى الْمَسْجِدِ فَقَامَ فَكَبَّرَ فَصَفَّ النَّاسُ وَرَاءَهُ فَقَرَأَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قِرَاءَةً طَوِيلَةً ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ قَامَ فَقَرَأَ قِرَاءَةً طَوِيلَةً هِيَ أَدْنَى مِنَ الْقِرَاءَةِ الأُولَى ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً هُوَ أَدْنَى مِنَ الرُّكُوعِ الأَوَّلِ ثُمَّ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ فَعَلَ فِي الرَّكْعَةِ الأُخْرَى مِثْلَ ذَلِكَ فَاسْتَكْمَلَ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ وَانْجَلَتِ الشَّمْسُ قَبْلَ أَنْ يَنْصَرِفَ ثُمَّ قَامَ فَخَطَبَ النَّاسَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ. لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ. فَإِذَا رَأَيْتُمُوهُمَا فَافْزَعُوا إِلَى الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1263}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The sun was eclipsed during the life of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) went out to the mosque and stood and said the Takbir, and the people formed rows behind him. The Messenger of Allah (ﷺ) recited for a long time, then he said the Takbir and bowed for a long time. Then he raised his head and said: ‘Sami’ Allahu liman hamidah, Rabban was lakal-hamd.’ Then he stood and recited for a long time, but shorter than the first recitation. Then he said the Takbir and bowed for a long time, but less than the first bowing. Then he said: ‘Sami’ Allahu liman hamidah, Rabbana wa lakal-hamd.’ Then he did the same in the next Rak’ah, and he completed four Rak’ah and four sets of prostration, and the eclipse ended before he finished. Then he stood and addressed the people. He praised Allah as He deserves to be praised, then he said: ‘The sun and the moon are two of the signs of Allah. They do not become eclipsed for the death or birth of anyone. If you see that then seek help in prayer.’”}}
\hadithdefcmd{ibnmajah}{1264}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ ثَعْلَبَةَ بْنِ عِبَادٍ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْكُسُوفِ فَلاَ نَسْمَعُ لَهُ صَوْتًا ‏.‏\hadithno{1264}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Samurah bin Jundab said:“The Messenger of Allah (ﷺ) led us in the eclipse prayer, and we did not hear his voice.”}}
\hadithdefcmd{ibnmajah}{1265}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَلاَةَ الْكُسُوفِ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ انْصَرَفَ فَقَالَ ‏"‏ لَقَدْ دَنَتْ مِنِّي الْجَنَّةُ حَتَّى لَوِ اجْتَرَأْتُ عَلَيْهَا لَجِئْتُكُمْ بِقِطَافٍ مِنْ قِطَافِهَا وَدَنَتْ مِنِّي النَّارُ حَتَّى قُلْتُ أَىْ رَبِّ وَأَنَا فِيهِمْ ‏"‏ ‏.‏ قَالَ نَافِعٌ حَسِبْتُ أَنَّهُ قَالَ ‏"‏ وَرَأَيْتُ امْرَأَةً تَخْدِشُهَا هِرَّةٌ لَهَا فَقُلْتُ مَا شَأْنُ هَذِهِ قَالُوا حَبَسَتْهَا حَتَّى مَاتَتْ جُوعًا لاَ هِيَ أَطْعَمَتْهَا وَلاَ هِيَ أَرْسَلَتْهَا تَأْكُلُ مِنْ خِشَاشِ الأَرْضِ ‏"‏ ‏.‏\hadithno{1265}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Asma’ bint Abu Bakr said:“The Messenger of Allah (ﷺ) performed the eclipse prayer. He stood for a long time, then he bowed for a long time, then he stood up for a long time, then he bowed for a long time, then he stood up, then he prostrated for a long time, then he sat up, then he prostrated for a long time. He stood for a long time, then he bowed for a long time, then he stood up for a long time, then he bowed for a long time, then he stood up, then he prostrated for a long time, then he sat up, then he prostrated for a long time. Then he finished and said: ‘Paradise was brought close to me, so that if I had dared, I could have brought you some of its fruits. And Hell was brought near to me, until I said: “O Lord, am I one of them?” Nafi’ said: “I think that he said: ‘And I saw a woman being scratched by a cat that belonged to her. I said: “What is wrong with this woman?” They said: “She detained it until it died of hunger; she did not feed it and she did not let it loose to eat of the vermin of the earth.”}}
\hadithdefcmd{ibnmajah}{1266}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ هِشَامِ بْنِ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ كِنَانَةَ، عَنْ أَبِيهِ، قَالَ أَرْسَلَنِي أَمِيرٌ مِنَ الأُمَرَاءِ إِلَى ابْنِ عَبَّاسٍ أَسْأَلُهُ عَنِ الصَّلاَةِ، فِي الاِسْتِسْقَاءِ فَقَالَ ابْنُ عَبَّاسٍ مَا مَنَعَهُ أَنْ يَسْأَلَنِي، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مُتَوَاضِعًا مُتَبَذِّلاً مُتَخَشِّعًا مُتَرَسِّلاً مُتَضَرِّعًا فَصَلَّى رَكْعَتَيْنِ كَمَا يُصَلِّي فِي الْعِيدِ وَلَمْ يَخْطُبْ خُطْبَتَكُمْ هَذِهِ ‏.‏\hadithno{1266}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Hisham bin Ishaq bin ‘Abdullah bin Kinanah that his father said:“One of the chiefs* sent me to Ibn ‘Abbas to ask him about the prayer for rain. Ibn ‘Abbas said: ‘What kept him from asking me?’ He said: ‘The Messenger of Allah (ﷺ) went out humbly, walking with a humble and moderate gait, imploring, and he performed two Rak’ah as he used to pray for ‘Eid, but he did not give a sermon like this sermon of yours.’”}}
\hadithdefcmd{ibnmajah}{1267}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، قَالَ سَمِعْتُ عَبَّادَ بْنَ تَمِيمٍ، يُحَدِّثُ أَبِي عَنْ عَمِّهِ، أَنَّهُ شَهِدَ النَّبِيَّ ـ صلى الله عليه وسلم ـ خَرَجَ إِلَى الْمُصَلَّى لِيَسْتَسْقِيَ فَاسْتَقْبَلَ الْقِبْلَةَ وَقَلَبَ رِدَاءَهُ وَصَلَّى رَكْعَتَيْنِ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِمِثْلِهِ ‏.‏ قَالَ سُفْيَانُ عَنِ الْمَسْعُودِيِّ قَالَ سَأَلْتُ أَبَا بَكْرِ بْنَ مُحَمَّدِ بْنِ عَمْرٍو أَجَعَلَ أَعْلاَهُ أَسْفَلَهُ أَوِ الْيَمِينَ عَلَى الشِّمَالِ قَالَ لاَ بَلِ الْيَمِينَ عَلَى الشِّمَالِ ‏.‏\hadithno{1267}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdullah bin Abu Bakr said:“I heard ‘Abbad bin Tamim narrating to my father that his paternal uncle had seen the Prophet (ﷺ) going out to the prayer place to pray for rain. He faced the Qiblah and turned his cloak around, and prayed two Rak’ah.” (One of the narrators) Muhammad bin Sabbah said: “Sufyan told us something similar, narrating from Yahya bin Sa`eed, from Abu Bakr bin Muhammad bin `Amr bin Hazm. from `Abbad bin Tamim, from his paternal uncle, from the Prophet (ﷺ).” Sufyan narrated that Al-Mas`udi said: “I asked Abu Bakr bin Muhammad bin `Amr: 'Did he turn it upside down or right to left?' He said: 'No, it was right to left.'”}}
\hadithdefcmd{ibnmajah}{1268}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، وَالْحَسَنُ بْنُ أَبِي الرَّبِيعِ، قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ النُّعْمَانَ، يُحَدِّثُ عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمًا يَسْتَسْقِي فَصَلَّى بِنَا رَكْعَتَيْنِ بِلاَ أَذَانٍ وَلاَ إِقَامَةٍ ثُمَّ خَطَبَنَا وَدَعَا اللَّهَ وَحَوَّلَ وَجْهَهُ نَحْوَ الْقِبْلَةِ رَافِعًا يَدَيْهِ ثُمَّ قَلَبَ رِدَاءَهُ فَجَعَلَ الأَيْمَنَ عَلَى الأَيْسَرِ وَالأَيْسَرَ عَلَى الأَيْمَنِ ‏.‏\hadithno{1268}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) went out one day to pray for rain. He led us in praying two Rak’ah without any Adhan or Iqamah, then he addressed us and supplicated to Allah. He turned to face the Qiblah, raising his hands, then he turned his cloak around, putting its right on the left and its left on the right.”}}
\hadithdefcmd{ibnmajah}{1269}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، أَنَّهُ قَالَ لِكَعْبٍ يَا كَعْبُ بْنَ مُرَّةَ حَدِّثْنَا عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَاحْذَرْ ‏.‏ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ اسْتَسْقِ اللَّهَ فَرَفَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَدَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ اسْقِنَا غَيْثًا مَرِيئًا مَرِيعًا طَبَقًا عَاجِلاً غَيْرَ رَائِثٍ نَافِعًا غَيْرَ ضَارٍّ ‏"‏ ‏.‏ قَالَ فَمَا جَمَّعُوا حَتَّى أُجِيبُوا ‏.‏ قَالَ فَأَتَوْهُ فَشَكَوْا إِلَيْهِ الْمَطَرَ فَقَالُوا يَا رَسُولَ اللَّهِ تَهَدَّمَتِ الْبُيُوتُ ‏.‏ فَقَالَ ‏"‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏ ‏.‏ قَالَ فَجَعَلَ السَّحَابُ يَنْقَطِعُ يَمِينًا وَشِمَالاً ‏.‏\hadithno{1269}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Shurahbil bin Simt that he said to Ka’b:“O Ka’b bin Murrah, narrate to us a Hadith from the Messenger of Allah (ﷺ), but be careful.” He said: “A man came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, ask Allah for rain!’ So the Messenger of Allah (ﷺ) raised his hands and said: ‘O Allah! Send wholesome, productive rain upon all of us, sooner rather than later, beneficial and not harmful.’ No sooner had they finished performing Friday (prayer) but they were revived. Then they came to him and complained to him about the rain, saying: ‘O Allah, around us and not upon us.’ Then the clouds began to disperse right and left.”}}
\hadithdefcmd{ibnmajah}{1270}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي الْقَاسِمِ أَبُو الأَحْوَصِ، حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، حَدَّثَنَا حُصَيْنٌ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ لَقَدْ جِئْتُكَ مِنْ عِنْدِ قَوْمٍ مَا يَتَزَوَّدُ لَهُمْ رَاعٍ وَلاَ يَخْطِرُ لَهُمْ فَحْلٌ ‏.‏ فَصَعِدَ الْمِنْبَرَ فَحَمِدَ اللَّهَ ثُمَّ قَالَ ‏ "‏ اللَّهُمَّ اسْقِنَا غَيْثًا مُغِيثًا مَرِيئًا طَبَقًا مَرِيعًا غَدَقًا عَاجِلاً غَيْرَ رَائِثٍ ‏"‏ ‏.‏ ثُمَّ نَزَلَ فَمَا يَأْتِيهِ أَحَدٌ مِنْ وَجْهٍ مِنَ الْوُجُوهِ إِلاَّ قَالُوا قَدْ أُحْيِينَا ‏.‏\hadithno{1270}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A Bedouin came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, I have come to you from people who have no place to graze their flocks and even their male camels have become weak. He mounted the pulpit and praised Allah, then he said: ‘O Allah, send upon us all abundant, wholesome rain, productive and plentiful, sooner rather than later.’ Then the rain came down, and no one came to him from any direction but they said: ‘We have been revived.’”}}
\hadithdefcmd{ibnmajah}{1271}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، عَنْ بَرَكَةَ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ اسْتَسْقَى حَتَّى رَأَيْتُ - أَوْ رُؤِيَ - بَيَاضُ إِبْطَيْهِ ‏.‏ قَالَ مُعْتَمِرٌ أُرَاهُ فِي الاِسْتِسْقَاءِ ‏.‏\hadithno{1271}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Mu’tamir narrated from his father, from Barakah, from Bashir bin Nahik, from Abu Hurairah:“The Prophet (ﷺ) supplicated for rain (raising his hands) until I saw or one could see the whiteness of his armpits.”}}
\hadithdefcmd{ibnmajah}{1272}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا أَبُو عَقِيلٍ، عَنْ عُمَرَ بْنِ حَمْزَةَ، حَدَّثَنَا سَالِمٌ، عَنْ أَبِيهِ، قَالَ رُبَّمَا ذَكَرْتُ قَوْلَ الشَّاعِرِ وَأَنَا أَنْظُرُ، إِلَى وَجْهِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى الْمِنْبَرِ فَمَا نَزَلَ حَتَّى جَيَّشَ كُلُّ مِيزَابٍ بِالْمَدِينَةِ فَأَذْكُرُ قَوْلَ الشَّاعِرِ وَأَبْيَضَ يُسْتَسْقَى الْغَمَامُ بِوَجْهِهِ ثِمَالُ الْيَتَامَى عِصْمَةٌ لِلأَرَامِلِ وَهُوَ قَوْلُ أَبِي طَالِبٍ ‏.‏\hadithno{1272}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Salim narrated that his father said:“Sometimes I remember the words of the poet when I was looking at the face of the Messenger of Allah (ﷺ) on the pulpit. He did not come down until all the waterspouts in Al-Madinah were filled with rain. And I remember what the poet said: ‘He has a white complexion and rain is sought by virtue of his countenance, He cares for the orphans, and protects the widows, These are the words of Abu Talib.”}}
\hadithdefcmd{ibnmajah}{1273}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ عَطَاءٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَشْهَدُ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ صَلَّى قَبْلَ الْخُطْبَةِ ثُمَّ خَطَبَ فَرَأَى أَنَّهُ لَمْ يُسْمِعِ النِّسَاءَ فَأَتَاهُنَّ فَذَكَّرَهُنَّ وَوَعَظَهُنَّ وَأَمَرَهُنَّ بِالصَّدَقَةِ وَبِلاَلٌ قَائِلٌ بِيَدَيْهِ هَكَذَا فَجَعَلَتِ الْمَرْأَةُ تُلْقِي الْخُرْصَ وَالْخَاتَمَ وَالشَّىْءَ ‏.‏\hadithno{1273}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Ata’ said:“I heard Ibn ‘Abbas say: ‘I bear witness that the Messenger of Allah (ﷺ) prayed before the sermon, then he delivered the sermon. And he thought that the women had not heard, so he went over to them and reminded them (of Allah) and preached to them and enjoined them to give in charity, and Bilal was spreading his hands like this, and the women started giving their earrings, rings and things.’”}}
\hadithdefcmd{ibnmajah}{1274}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى يَوْمَ الْعِيدِ بِغَيْرِ أَذَانٍ وَلاَ إِقَامَةٍ ‏.‏\hadithno{1274}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) prayed on the day of ‘Eid with no Adhan and no Iqamah}}
\hadithdefcmd{ibnmajah}{1275}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، وَعَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي سَعِيدٍ، قَالَ أَخْرَجَ مَرْوَانُ الْمِنْبَرَ يَوْمَ الْعِيدِ فَبَدَأَ بِالْخُطْبَةِ قَبْلَ الصَّلاَةِ فَقَامَ رَجُلٌ فَقَالَ يَا مَرْوَانُ خَالَفْتَ السُّنَّةَ أَخْرَجْتَ الْمِنْبَرَ يَوْمَ عِيدٍ وَلَمْ يَكُنْ يُخْرَجُ بِهِ وَبَدَأْتَ بِالْخُطْبَةِ قَبْلَ الصَّلاَةِ وَلَمْ يَكُنْ يُبْدَأُ بِهَا ‏.‏ فَقَالَ أَبُو سَعِيدٍ أَمَّا هَذَا فَقَدْ قَضَى مَا عَلَيْهِ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ رَأَى مُنْكَرًا فَاسْتَطَاعَ أَنْ يُغَيِّرَهُ بِيَدِهِ فَلْيُغَيِّرْهُ بِيَدِهِ. فَإِنْ لَمْ يَسْتَطِعْ فَبِلِسَانِهِ. فَإِنْ لَمْ يَسْتَطِعْ بِلِسَانِهِ، فَبِقَلْبِهِ. وَذَلِكَ أَضْعَفُ الإِيمَانِ ‏"‏ ‏.‏\hadithno{1275}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa’eed said:“Marwan brought the pulpit out one ‘Eid day and started to deliver the sermon before the prayer. A man stood up and said: ‘O Commander of the Believers, you have gone against the Sunnah. You have brought the pulpit out on the day of ‘Eid and it was not brought out before, and you started with the sermon before the prayer, when this was not done before.’ Abu Sa’eed said: ‘As for this man, he has done his duty. I heard the Messenger of Allah (ﷺ) say: “Whoever among you sees an evil action, and he is able to change it with his hand, then change it with his hand (by taking action); if he cannot, (do so) with his tongue then with his tongue (by speaking out); and if he cannot then with his heart (by hating it and feeling that it is wrong), and that is the weakest of faith.”}}
\hadithdefcmd{ibnmajah}{1276}{حَدَّثَنَا حَوْثَرَةُ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ثُمَّ أَبُو بَكْرٍ ثُمَّ عُمَرُ يُصَلُّونَ الْعِيدَ قَبْلَ الْخُطْبَةِ ‏.‏\hadithno{1276}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Prophet (ﷺ), then Abu Bakr, then ‘Umar, used to pray the ‘Eid prayer before delivering the sermon.”}}
\hadithdefcmd{ibnmajah}{1277}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ عَمَّارِ بْنِ سَعْدٍ، مُؤَذِّنِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَدَّثَنِي أَبِي عَنْ أَبِيهِ عَنْ جَدِّهِ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُكَبِّرُ فِي الْعِيدَيْنِ فِي الأُولَى سَبْعًا قَبْلَ الْقِرَاءَةِ وَفِي الآخِرَةِ خَمْسًا قَبْلَ الْقِرَاءَةِ ‏.‏\hadithno{1277}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{‘Abdur-Rahman bin Sa’d bin ‘Ammar bin Sa’d, the Mu’adhdhin of the Messenger of Allah (ﷺ), narrated from his father, from his father, from his grandfather, that the Messenger of Allah (ﷺ) used to say the Takbir in the ‘Eid prayer, seven times in the first (Rak’ah) before reciting Qur’an, and five times in the second before reciting Qur’an}}
\hadithdefcmd{ibnmajah}{1278}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْلَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَبَّرَ فِي صَلاَةِ الْعِيدِ سَبْعًا وَخَمْسًا ‏.‏\hadithno{1278}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, from his grandfather, that the Prophet (ﷺ) said the Takbir seven times and five times in the ‘Eid prayer}}
\hadithdefcmd{ibnmajah}{1279}{حَدَّثَنَا أَبُو مَسْعُودٍ، مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عَقِيلٍ حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ عَثْمَةَ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَبَّرَ فِي الْعِيدَيْنِ سَبْعًا فِي الأُولَى وَخَمْسًا فِي الآخِرَةِ ‏.‏\hadithno{1279}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Kathir bin ‘Abdullah bin ‘Amr bin ‘Awf narrated, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said the Takbir in the ‘Eid prayers, seven times in the first Rak’ah and five times in the second}}
\hadithdefcmd{ibnmajah}{1280}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، عَنْ خَالِدِ بْنِ يَزِيدَ، وَعُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَبَّرَ فِي الْفِطْرِ وَالأَضْحَى سَبْعًا وَخَمْسًا سِوَى تَكْبِيرَتَىِ الرُّكُوعِ ‏.‏\hadithno{1280}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said the Takbir seven and five times in (the prayer for ‘Eid) Fitr and Adha, apart from the Takbir for Ruku’ (bowing)}}
\hadithdefcmd{ibnmajah}{1281}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَقْرَأُ فِي الْعِيدَيْنِ بِـ ‏\{سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى\}‏ وَ ‏\{هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ\}‏ ‏.‏\hadithno{1281}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Nu’man bin Bashir that the Messenger of Allah (ﷺ) used to recite “Glorify the Name of your Lord, the Most High,” [Al-A’la (87)] and “Has there come to you the narration of the overwhelming?” [Al-Ghashiyah (88)] in the ‘Eid prayer}}
\hadithdefcmd{ibnmajah}{1282}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ خَرَجَ عُمَرُ يَوْمَ عِيدٍ فَأَرْسَلَ إِلَى أَبِي وَاقِدٍ اللَّيْثِيِّ بِأَىِّ شَىْءٍ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَقْرَأُ فِي مِثْلِ هَذَا الْيَوْمِ؟ قَالَ بِـ ‏\{ق\}‏ وَاقْتَرَبَتْ ‏.‏\hadithno{1282}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Ubaidullah bin ‘Abdullah said:“Umar went out on the day of ‘Eid and sent word to Abu Waqid Al-Laithi asking what the Prophet (ﷺ) used to recite on this day. He said: ‘Qaf [Qaf (50)] and ‘Iqtarabat’.” [Al-Qamar]}}
\hadithdefcmd{ibnmajah}{1283}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، حَدَّثَنَا مُوسَى بْنُ عُبَيْدَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقْرَأُ فِي الْعِيدَيْنِ بِـ ‏\{سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى \}‏ وَ ‏\{هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ \}‏ ‏.‏\hadithno{1283}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) used to recite in the ‘Eid prayer “Glorify the Name of your Lord, the Most High.” [Al-A’la (87)] and “Has there come to you the narration of the overwhelming?” [Al-Ghashiyah]}}
\hadithdefcmd{ibnmajah}{1284}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، قَالَ رَأَيْتُ أَبَا كَاهِلٍ وَكَانَتْ لَهُ صُحْبَةٌ فَحَدَّثَنِي أَخِي، عَنْهُ قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَخْطُبُ عَلَى نَاقَةٍ وَحَبَشِيٌّ آخِذٌ بِخِطَامِهَا ‏.‏\hadithno{1284}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Isma’il bin Abu Khalid said:“I saw Abu Kahil, and he was a Companions, and my brother narrated to me that he said: ‘I saw the Prophet (ﷺ) delivering the sermon atop his she-camel, and an Ethiopian was holding onto its reins.’”}}
\hadithdefcmd{ibnmajah}{1285}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ عَائِذٍ، - هُوَ أَبُو كَاهِلٍ - قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَخْطُبُ عَلَى نَاقَةٍ حَسْنَاءَ وَحَبَشِيٌّ آخِذٌ بِخِطَامِهَا ‏.‏\hadithno{1285}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qais bin ‘Aidh, who was Abu Kahil, said:“I saw the Prophet (ﷺ) delivering the sermon atop a beautiful she-camel, and an Ethiopian was holding onto its reins.”}}
\hadithdefcmd{ibnmajah}{1286}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سَلَمَةَ بْنِ نُبَيْطٍ، عَنْ أَبِيهِ، أَنَّهُ حَجَّ فَقَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَخْطُبُ عَلَى بَعِيرِهِ ‏.‏\hadithno{1286}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salamah bin Nubait that his father performed Hajj and said:“I saw the Prophet (ﷺ) delivering the sermon atop his camel.”}}
\hadithdefcmd{ibnmajah}{1287}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ عَمَّارِ بْنِ سَعْدٍ الْمُؤَذِّنِ، حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُكَبِّرُ بَيْنَ أَضْعَافِ الْخُطْبَةِ يُكْثِرُ التَّكْبِيرَ فِي خُطْبَةِ الْعِيدَيْنِ ‏.‏\hadithno{1287}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Sa’d bin ‘Ammar bin Sa’d, the Mu’adhdhin, that his father narrated, from his father, that his grandfather said:“The Prophet (ﷺ) used to say the Takbir between the two sermons and he used to say the Takbir a great deal in the sermon of ‘Eid.”}}
\hadithdefcmd{ibnmajah}{1288}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، أَخْبَرَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَخْرُجُ يَوْمَ الْعِيدِ فَيُصَلِّي بِالنَّاسِ رَكْعَتَيْنِ ثُمَّ يُسَلِّمُ فَيَقِفُ عَلَى رِجْلَيْهِ فَيَسْتَقْبِلُ النَّاسَ وَهُمْ جُلُوسٌ فَيَقُولُ ‏ "‏ تَصَدَّقُوا تَصَدَّقُوا ‏"‏ ‏.‏ فَأَكْثَرُ مَنْ يَتَصَدَّقُ النِّسَاءُ بِالْقُرْطِ وَالْخَاتَمِ وَالشَّىْءِ فَإِنْ كَانَتْ حَاجَةٌ يُرِيدُ أَنْ يَبْعَثَ بَعْثًا ذَكَرَهُ لَهُمْ وَإِلاَّ انْصَرَفَ ‏.‏\hadithno{1288}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) used to go out on the day of ‘Eid and lead the people in praying two Rak’ah, then he would say the Salam and stand on his two feet facing the people while they were sitting down. He would say: ‘Give in charity. Give in charity.’ Those who gave most in charity were the women, (they would give) earrings and rings and things. If he wanted to send out an expedition he would mention it, otherwise he would leave.”}}
\hadithdefcmd{ibnmajah}{1289}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو بَحْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ فِطْرٍ أَوْ أَضْحًى فَخَطَبَ قَائِمًا ثُمَّ قَعَدَ قَعْدَةً ثُمَّ قَامَ ‏.‏\hadithno{1289}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) went out on the Day of Al-Fitr or Al-Adha, and delivered a sermon standing up. Then he sat down briefly, then stood up again.”}}
\hadithdefcmd{ibnmajah}{1290}{حَدَّثَنَا هَدِيَّةُ بْنُ عَبْدِ الْوَهَّابِ، وَعَمْرُو بْنُ رَافِعٍ الْبَجَلِيُّ، قَالاَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، قَالَ حَضَرْتُ الْعِيدَ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَصَلَّى بِنَا الْعِيدَ ثُمَّ قَالَ ‏ "‏ قَدْ قَضَيْنَا الصَّلاَةَ. فَمَنْ أَحَبَّ أَنْ يَجْلِسَ لِلْخُطْبَةِ فَلْيَجْلِسْ. وَمَنْ أَحَبَّ أَنْ يَذْهَبَ فَلْيَذْهَبْ ‏"‏ ‏.‏\hadithno{1290}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin Sa’ib said:“I attended the ‘Eid prayer with the Messenger of Allah (ﷺ). He led us in offering the ‘Eid prayer, then he said: ‘I have finished the prayer. Whoever wants to sit (and listen to) the sermon, then let him sit, and whoever wants to leave, then let him leave.’”}}
\hadithdefcmd{ibnmajah}{1291}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي عَدِيُّ بْنُ ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ خَرَجَ فَصَلَّى بِهِمُ الْعِيدَ لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا ‏.‏\hadithno{1291}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) went out and led them in the ‘Eid prayer, and he did not pray before it or after it}}
\hadithdefcmd{ibnmajah}{1292}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الطَّائِفِيُّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا فِي عِيدٍ ‏.‏\hadithno{1292}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, from his grandfather, that the Prophet (ﷺ) did not pray before or after the ‘Eid prayer}}
\hadithdefcmd{ibnmajah}{1293}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْهَيْثَمُ بْنُ جَمِيلٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَمْرٍو الرَّقِّيِّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لاَ يُصَلِّي قَبْلَ الْعِيدِ شَيْئًا فَإِذَا رَجَعَ إِلَى مَنْزِلِهِ صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{1293}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) did not pray before the ‘Eid prayer, but when he went back to his house he would pray two Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1294}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ عَمَّارِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَخْرُجُ إِلَى الْعِيدِ مَاشِيًا وَيَرْجِعُ مَاشِيًا ‏.‏\hadithno{1294}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{‘Abdur-Rahman bin Sa’d bin ‘Ammar bin Sa’d said:“My father told me, from his father, from his grandfather, that the Prophet (ﷺ) used to go out to the ‘Eid prayers walking, and he would come back walking.”}}
\hadithdefcmd{ibnmajah}{1295}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ الْعُمَرِيُّ، عَنْ أَبِيهِ، وَعُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَخْرُجُ إِلَى الْعِيدِ مَاشِيًا وَيَرْجِعُ مَاشِيًا ‏.‏\hadithno{1295}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) used to go out to the ‘Eid prayers walking, and come back walking.”}}
\hadithdefcmd{ibnmajah}{1296}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ إِنَّ مِنَ السُّنَّةِ أَنْ يَمْشِيَ إِلَى الْعِيدِ ‏.‏\hadithno{1296}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“It is part of the Sunnah to walk to ‘Eid (prayers).”}}
\hadithdefcmd{ibnmajah}{1297}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْخَطَّابِ، حَدَّثَنَا مِنْدَلٌ، عَنْ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَأْتِي الْعِيدَ مَاشِيًا ‏.‏\hadithno{1297}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muhammad bin ‘Ubaidullah bin Abu Rafi’, from his father, from his grandfather, that the Messenger of Allah (ﷺ) used to come to ‘Eid prayers walking}}
\hadithdefcmd{ibnmajah}{1298}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ عَمَّارِ بْنِ سَعْدٍ، أَخْبَرَنِي أَبِي، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا خَرَجَ إِلَى الْعِيدَيْنِ سَلَكَ عَلَى دَارَىْ سَعِيدِ بْنِ أَبِي الْعَاصِ ثُمَّ عَلَى أَصْحَابِ الْفَسَاطِيطِ ثُمَّ انْصَرَفَ فِي الطَّرِيقِ الأُخْرَى طَرِيقِ بَنِي زُرَيْقٍ ثُمَّ يَخْرُجُ عَلَى دَارِ عَمَّارِ بْنِ يَاسِرٍ وَدَارِ أَبِي هُرَيْرَةَ إِلَى الْبَلاَطِ ‏.‏\hadithno{1298}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abdur-Rahman bin Sa’d bin ‘Ammar bin Sa’d said:“My father told me, from his father, from his grandfather, that when the Prophet (ﷺ) went out on the two ‘Eid, he would pass by the house of Sa’eed bin Abul-‘As, then by the people of the tent, then he would leave by a different route, via Banu Zuraiq, then he would go out by the house of ‘Ammar bin Yasir and the house of Abu Hurairah to Balat.”}}
\hadithdefcmd{ibnmajah}{1299}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو قُتَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يَخْرُجُ إِلَى الْعِيدِ فِي طَرِيقٍ وَيَرْجِعُ فِي أُخْرَى وَيَزْعُمُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{1299}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that he used to go out to the ‘Eid prayers via one route, and return via another, and he said that the Messenger of Allah (ﷺ) used to do that}}
\hadithdefcmd{ibnmajah}{1300}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْخَطَّابِ، حَدَّثَنَا مِنْدَلٌ، عَنْ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَأْتِي الْعِيدَ مَاشِيًا وَيَرْجِعُ مَاشِيًا فِي غَيْرِ الطَّرِيقِ الَّذِي ابْتَدَأَ فِيهِ ‏.‏\hadithno{1300}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muhammad bin ‘Ubaidullah bin Abu Rafi’, from his father, from his grandfather, that the Messenger of Allah (ﷺ) used to come to ‘Eid prayers walking, and that he would go back via a different route than the one he began with}}
\hadithdefcmd{ibnmajah}{1301}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، حَدَّثَنَا أَبُو تُمَيْلَةَ، عَنْ فُلَيْحِ بْنِ سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ الْحَارِثِ الزُّرَقِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا خَرَجَ إِلَى الْعِيدِ رَجَعَ فِي غَيْرِ الطَّرِيقِ الَّذِي أَخَذَ فِيهِ ‏.‏\hadithno{1301}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that when the Prophet (ﷺ) went out to ‘Eid (prayers), he would return via another route than the first one he took}}
\hadithdefcmd{ibnmajah}{1302}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا شَرِيكٌ، عَنْ مُغِيرَةَ، عَنْ عَامِرٍ، قَالَ شَهِدَ عِيَاضٌ الأَشْعَرِيُّ عِيدًا بِالأَنْبَارِ فَقَالَ مَالِي لاَ أَرَاكُمْ تُقَلِّسُونَ كَمَا كَانَ يُقَلَّسُ عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1302}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Amir said:“Iyad Al-Ash’ari was in Anbar at the time of ‘Eid, and he said: ‘Why is it that I do not see you engaged in Taqlis* as was done in the presence of the Messenger of Allah (ﷺ)?’” *Taqlis means to indulge in celebrations on a festive occasion}}
\hadithdefcmd{ibnmajah}{1303}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَامِرٍ، عَنْ قَيْسِ بْنِ سَعْدٍ، قَالَ مَا كَانَ شَىْءٌ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِلاَّ وَقَدْ رَأَيْتُهُ إِلاَّ شَىْءٌ وَاحِدٌ فَإِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُقَلَّسُ لَهُ يَوْمَ الْفِطْرِ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ الْقَطَّانُ حَدَّثَنَا ابْنُ دِيزِيلَ، حَدَّثَنَا آدَمُ، حَدَّثَنَا شَيْبَانُ، عَنْ جَابِرٍ، عَنْ عَامِرٍ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ نَصْرٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ جَابِرٍ، عَنْ عَامِرٍ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ نَصْرٍ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَامِرٍ، نَحْوَهُ ‏.‏\hadithno{1303}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Amir that Qais bin Sa’d said:“There is nothing that happened during the time of the Messenger of Allah (ﷺ) except that I have seen it, except for one thing, which is that Taqlis* was performed for the Messenger of Allah (ﷺ) on the Day of Fitr. (Three other chains of narration) with similar wording. *Taqlis means to indulge in celebrations on a festive occasion}}
\hadithdefcmd{ibnmajah}{1304}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالاَ حَدَّثَنَا الأَوْزَاعِيُّ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَغْدُو إِلَى الْمُصَلَّى فِي يَوْمِ الْعِيدِ وَالْعَنَزَةُ تُحْمَلُ بَيْنَ يَدَيْهِ فَإِذَا بَلَغَ الْمُصَلَّى نُصِبَتْ بَيْنَ يَدَيْهِ فَيُصَلِّي إِلَيْهَا وَذَلِكَ أَنَّ الْمُصَلَّى كَانَ فَضَاءً لَيْسَ فِيهِ شَىْءٌ يُسْتَتَرُ بِهِ ‏.‏\hadithno{1304}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) used to set out for the praying place in the morning of the day of ‘Eid, and a small spear would be carried before him. When he reached the praying place, it would be set up in front of him, then he would pray facing it, and that was because the praying place was an open space in which there was nothing that could serve as a Sutrah*. *Sutrah (screen), meaning a barrier of some type}}
\hadithdefcmd{ibnmajah}{1305}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا صَلَّى يَوْمَ عِيدٍ أَوْ غَيْرَهُ نُصِبَتِ الْحَرْبَةُ بَيْنَ يَدَيْهِ فَيُصَلِّي إِلَيْهَا وَالنَّاسُ مِنْ خَلْفِهِ ‏.‏ قَالَ نَافِعٌ فَمِنْ ثَمَّ اتَّخَذَهَا الأُمَرَاءُ ‏.‏\hadithno{1305}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“When the Prophet (ﷺ) prayed on the day of ‘Eid or on another occasion, a small spear was set up in front of him, and he prayed facing it, and the people were behind him.” Nafi` said: It is from here that the leaders have taken this practice}}
\hadithdefcmd{ibnmajah}{1306}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى الْعِيدَ بِالْمُصَلَّى مُسْتَتِرًا بِحَرْبَةٍ ‏.‏\hadithno{1306}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) prayed ‘Eid at the prayer place, using a small spear as a Sutrah}}
\hadithdefcmd{ibnmajah}{1307}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ حَسَّانٍ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نُخْرِجَهُنَّ فِي يَوْمِ الْفِطْرِ وَالنَّحْرِ ‏.‏ قَالَ قَالَتْ أُمُّ عَطِيَّةَ فَقُلْنَا أَرَأَيْتَ إِحْدَاهُنَّ لاَ يَكُونُ لَهَا جِلْبَابٌ قَالَ ‏ "‏ فَلْتُلْبِسْهَا أُخْتُهَا مِنْ جِلْبَابِهَا ‏"‏ ‏.‏\hadithno{1307}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Umm ‘Atiyyah said:“The Messenger of Allah (ﷺ) commanded us to bring them (the women) out on the day of Fitr and the day of Nahr.” Umm ‘Atiyyah said: “We said: ‘What if one of them does not have an outer covering?’ He said: ‘Let her sister share her own outer covering with her.’”}}
\hadithdefcmd{ibnmajah}{1308}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَخْرِجُوا الْعَوَاتِقَ وَذَوَاتِ الْخُدُورِ لِيَشْهَدْنَ الْعِيدَ وَدَعْوَةَ الْمُسْلِمِينَ ‏.‏ وَلِيَجْتَنِبَنَّ الْحُيَّضُ مُصَلَّى النَّاسِ ‏"‏ ‏.‏\hadithno{1308}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Umm ‘Atiyyah said:“The Messenger of Allah (ﷺ) said: ‘Bring out the women who have attained puberty and those who are in seclusion so that they may attend the ‘Eid prayer and (join in) the supplication of the Muslims. But let the women who are menstruating avoid the prayer place.”}}
\hadithdefcmd{ibnmajah}{1309}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، حَدَّثَنَا حَجَّاجُ بْنُ أَرْطَاةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُخْرِجُ بَنَاتِهِ وَنِسَاءَهُ فِي الْعِيدَيْنِ ‏.‏\hadithno{1309}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) used to bring his daughters and his wives out on the two ‘Eid}}
\hadithdefcmd{ibnmajah}{1310}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ عُثْمَانَ بْنِ الْمُغِيرَةِ، عَنْ إِيَاسِ بْنِ أَبِي رَمْلَةَ الشَّامِيِّ، قَالَ سَمِعْتُ رَجُلاً، سَأَلَ زَيْدَ بْنَ أَرْقَمَ هَلْ شَهِدْتَ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عِيدَيْنِ فِي يَوْمٍ قَالَ نَعَمْ ‏.‏ قَالَ فَكَيْفَ كَانَ يَصْنَعُ قَالَ صَلَّى الْعِيدَ ثُمَّ رَخَّصَ فِي الْجُمُعَةِ ثُمَّ قَالَ ‏ "‏ مَنْ شَاءَ أَنْ يُصَلِّيَ فَلْيُصَلِّ ‏"‏ ‏.‏\hadithno{1310}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Iyas bin Abi Ramlah Ash-Shami said:“I heard a man asking Zaid bin Arqam: ‘Were you present with the Messenger of Allah (ﷺ) when there were two ‘Eid on one day?’ He said: ‘Yes.’ He said: ‘What did he do?’ He said: ‘He prayed the ‘Eid prayer, then he granted a concession not to pray the Friday, then he said: “Whoever wants to pray (Friday), let him do so.”’”}}
\hadithdefcmd{ibnmajah}{1311}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي مُغِيرَةُ الضَّبِّيُّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ أَبِي صَالِحٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ اجْتَمَعَ عِيدَانِ فِي يَوْمِكُمْ هَذَا فَمَنْ شَاءَ أَجْزَأَهُ مِنَ الْجُمُعَةِ وَإِنَّا مُجَمِّعُونَ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ رَبِّهِ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا شُعْبَةُ، عَنْ مُغِيرَةَ الضَّبِّيِّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1311}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Two ‘Eid have come together on this day of yours. So whoever wants, that (the ‘Eid prayer) will suffice him, and he will not have to pray Friday, but we will pray Friday if Allah wills.” Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{1312}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا مِنْدَلُ بْنُ عَلِيٍّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اجْتَمَعَ عِيدَانِ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَصَلَّى بِالنَّاسِ ثُمَّ قَالَ ‏ "‏ مَنْ شَاءَ أَنْ يَأْتِيَ الْجُمُعَةَ فَلْيَأْتِهَا وَمَنْ شَاءَ أَنْ يَتَخَلَّفَ فَلْيَتَخَلَّفْ ‏"‏ ‏.‏\hadithno{1312}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“Two ‘Eid came together at the time of the Messenger of Allah (ﷺ), so he led the people in prayer, then he said: ‘Whoever wishes to come to Friday (prayer), let him come, and whoever wishes to stay behind, let him stay behind.’”}}
\hadithdefcmd{ibnmajah}{1313}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عِيسَى بْنُ عَبْدِ الأَعْلَى بْنِ أَبِي فَرْوَةَ، قَالَ سَمِعْتُ أَبَا يَحْيَى، عُبَيْدَ اللَّهِ التَّيْمِيَّ يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، قَالَ أَصَابَ النَّاسَ مَطَرٌ فِي يَوْمِ عِيدٍ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَصَلَّى بِهِمْ فِي الْمَسْجِدِ ‏.‏\hadithno{1313}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“Rain fell on the day of ‘Eid at the time of the Messenger of Allah (ﷺ), so he led them in prayer in the mosque}}
\hadithdefcmd{ibnmajah}{1314}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ، حَدَّثَنَا نَائِلُ بْنُ نَجِيحٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زِيَادٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُلْبَسَ السِّلاَحُ فِي بِلاَدِ الإِسْلاَمِ فِي الْعِيدَيْنِ إِلاَّ أَنْ يَكُونُوا بِحَضْرَةِ الْعَدُوِّ ‏.‏\hadithno{1314}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) forbade wearing weapons in the Muslim lands on the two ‘Eid, except if the enemy was present}}
\hadithdefcmd{ibnmajah}{1315}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا حَجَّاجُ بْنُ تَمِيمٍ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَغْتَسِلُ يَوْمَ الْفِطْرِ وَيَوْمَ الأَضْحَى ‏.‏\hadithno{1315}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) used to have a bath on the day of Fitr and the day of Adha.”}}
\hadithdefcmd{ibnmajah}{1316}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يُوسُفُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو جَعْفَرٍ الْخَطْمِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عُقْبَةَ بْنِ الْفَاكِهِ بْنِ سَعْدٍ، عَنْ جَدِّهِ الْفَاكِهِ بْنِ سَعْدٍ، - وَكَانَتْ لَهُ صُحْبَةٌ - أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَغْتَسِلُ يَوْمَ الْفِطْرِ وَيَوْمَ النَّحْرِ وَيَوْمَ عَرَفَةَ وَكَانَ الْفَاكِهُ يَأْمُرُ أَهْلَهُ بِالْغُسْلِ فِي هَذِهِ الأَيَّامِ ‏.‏\hadithno{1316}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdur-Rahman bin ‘Uqbah bin Fakih bin Sa’d, from his grandfather Fakih bin Sa’d, who was a Companion of the Prophet (ﷺ) that the Messenger of Allah (ﷺ) used to take a bath on the Day of Fitr, the Day of Nahr, and the day of ‘Arafah, and Fakih used to tell his family to have a bath on these days}}
\hadithdefcmd{ibnmajah}{1317}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ الضَّحَّاكِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا صَفْوَانُ بْنُ عَمْرٍو، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، أَنَّهُ خَرَجَ مَعَ النَّاسِ يَوْمَ فِطْرٍ أَوْ أَضْحًى فَأَنْكَرَ إِبْطَاءَ الإِمَامِ وَقَالَ إِنْ كُنَّا لَقَدْ فَرَغْنَا سَاعَتَنَا هَذِهِ وَذَلِكَ حِينَ التَّسْبِيحِ ‏.‏\hadithno{1317}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Yazid bin Khumair narrated that ‘Abdullah bin Busr went out with the people on the Day of Fitr or Adha, and he objected to the Imam’s delay. He said:“We would have finished by this time.” And that was the time of Tasbih}}
\hadithdefcmd{ibnmajah}{1318}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي مِنَ اللَّيْلِ مَثْنَى مَثْنَى ‏.‏\hadithno{1318}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) used to offer the night prayers two by two.”}}
\hadithdefcmd{ibnmajah}{1319}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى ‏"‏ ‏.‏\hadithno{1319}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“The night prayer is (to be offered) two by two.”}}
\hadithdefcmd{ibnmajah}{1320}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، وَعَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، وَعَنِ ابْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، وَعَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، قَالَ سُئِلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَنْ صَلاَةِ اللَّيْلِ فَقَالَ ‏ "‏ يُصَلِّي مَثْنَى مَثْنَى. فَإِذَا خَافَ الصُّبْحَ أَوْتَرَ بِرَكْعَةٍ ‏"‏ ‏.‏\hadithno{1320}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Prophet (ﷺ) was asked about the night prayer. He said: ‘Pray two by two, and if you fear that dawn is coming, then perform Witr with one Rak’ah.’”}}
\hadithdefcmd{ibnmajah}{1321}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَثَّامُ بْنُ عَلِيٍّ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي بِاللَّيْلِ رَكْعَتَيْنِ رَكْعَتَيْنِ ‏.‏\hadithno{1321}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) used to pray the night prayer two Rak’ah by two Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1322}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، أَنَّهُ سَمِعَ عَلِيًّا الأَزْدِيَّ، يُحَدِّثُ أَنَّهُ سَمِعَ ابْنَ عُمَرَ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ صَلاَةُ اللَّيْلِ وَالنَّهَارِ مَثْنَى مَثْنَى ‏"‏ ‏.‏\hadithno{1322}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn ‘Umar narrated that the Messenger of Allah (ﷺ) said:“Prayers at night and during the day are to be offered two by two.”}}
\hadithdefcmd{ibnmajah}{1323}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ رُمْحٍ، أَنْبَأَنَا ابْنُ وَهْبٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ الْفَتْحِ صَلَّى سُبْحَةَ الضُّحَى ثَمَانِيَ رَكَعَاتٍ سَلَّمَ مِنْ كُلِّ رَكْعَتَيْنِ ‏.‏\hadithno{1323}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Umm Hani’ bint Abu Talib that on the day of the Conquest (of Makkah) the Messenger of Allah (ﷺ) prayed voluntary Duha with eight Rak’ah, saying the Salam after each two Rak’ah}}
\hadithdefcmd{ibnmajah}{1324}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِي سُفْيَانَ السَّعْدِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ فِي كُلِّ رَكْعَتَيْنِ تَسْلِيمَةٌ ‏"‏ ‏.‏\hadithno{1324}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed that the Prophet (ﷺ) said:“After each two Rak’ah there should be the Taslim.”}}
\hadithdefcmd{ibnmajah}{1325}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي عَبْدُ رَبِّهِ بْنُ سَعِيدٍ، عَنْ أَنَسِ بْنِ أَبِي أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ نَافِعِ بْنِ الْعَمْيَاءِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنِ الْمُطَّلِبِ، - يَعْنِي ابْنَ أَبِي وَدَاعَةَ - قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى. وَتَشَهَّدُ فِي كُلِّ رَكْعَتَيْنِ. وَتَبَاءَسُ وَتَمَسْكَنُ وَتُقْنِعُ. وَتَقُولُ: اللَّهُمَّ اغْفِرْ لِي. فَمَنْ لَمْ يَفْعَلْ ذَلِكَ، فَهِيَ خِدَاجٌ ‏"‏ ‏.‏\hadithno{1325}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Muttalib that is, Ibn Abu Wada’ah said:“The Messenger of Allah (ﷺ) said: ‘The night prayers are (to be offered) two by two. Say the Tashah-hud after each two Rak`ah, and raise your hands in all humility like one who is poor and needy and say: ‘Allāhummaghfir lī (O Allah, forgive me).’ And whoever does not do that, it is imperfect.’”}}
\hadithdefcmd{ibnmajah}{1326}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَامَ رَمَضَانَ وَقَامَهُ إِيمَانًا وَاحْتِسَابًا، غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{1326}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever fasts Ramadan and spends its nights in prayer, out of faith and in hope of reward, his previous sins will be forgiven.’”}}
\hadithdefcmd{ibnmajah}{1327}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا مَسْلَمَةُ بْنُ عَلْقَمَةَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ الْجُرَشِيِّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ الْحَضْرَمِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ صُمْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ رَمَضَانَ فَلَمْ يَقُمْ بِنَا شَيْئًا مِنْهُ حَتَّى بَقِيَ سَبْعُ لَيَالٍ فَقَامَ بِنَا لَيْلَةَ السَّابِعَةِ حَتَّى مَضَى نَحْوٌ مِنْ ثُلُثِ اللَّيْلِ ثُمَّ كَانَتِ اللَّيْلَةُ السَّادِسَةُ الَّتِي تَلِيهَا فَلَمْ يَقُمْهَا حَتَّى كَانَتِ الْخَامِسَةُ الَّتِي تَلِيهَا ثُمَّ قَامَ بِنَا حَتَّى مَضَى نَحْوٌ مِنْ شَطْرِ اللَّيْلِ فَقُلْتُ يَا رَسُولَ اللَّهِ لَوْ نَفَّلْتَنَا بَقِيَّةَ لَيْلَتِنَا هَذِهِ ‏.‏ فَقَالَ ‏ "‏ إِنَّهُ مَنْ قَامَ مَعَ الإِمَامِ حَتَّى يَنْصَرِفَ فَإِنَّهُ يَعْدِلُ قِيَامَ لَيْلَةٍ ‏"‏ ‏.‏ ثُمَّ كَانَتِ الرَّابِعَةُ الَّتِي تَلِيهَا فَلَمْ يَقُمْهَا حَتَّى كَانَتِ الثَّالِثَةُ الَّتِي تَلِيهَا ‏.‏ قَالَ فَجَمَعَ نِسَاءَهُ وَأَهْلَهُ وَاجْتَمَعَ النَّاسُ ‏.‏ قَالَ فَقَامَ بِنَا حَتَّى خَشِينَا أَنْ يَفُوتَنَا الْفَلاَحُ ‏.‏ قِيلَ وَمَا الْفَلاَحُ قَالَ السُّحُورُ ‏.‏ قَالَ ثُمَّ لَمْ يَقُمْ بِنَا شَيْئًا مِنْ بَقِيَّةِ الشَّهْرِ ‏.‏\hadithno{1327}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Dharr said:“We fasted Ramadan with the Messenger of Allah (ﷺ) and he did not lead us in praying Qiyam (prayers at night) during any part of it, until there were seven nights left. He led us in praying Qiyam on the seventh night until approximately one third of the night had passed. Then on the sixth night which followed it he did not lead us in prayer. Then he led us in praying Qiyam on the fifth night which followed it until almost half the night had passed. I said: ‘O Messenger of Allah, would that we had offered voluntary prayers throughout the whole night.’ He said: ‘Whoever stands with the Imam until he finishes, it is equivalent to spending the whole night in prayer.’ Then on the fourth night which followed it, he did not lead us in prayer, until the third night that followed it, when he gathered his wives and family, and the people gathered, and he led us in prayer until we feared that we would miss the Falah.” It was asked: “What is the Falah?” He said: “Suhur.” He said: “Then he did not lead us in prayer at night for the rest of the month.”}}
\hadithdefcmd{ibnmajah}{1328}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، وَعُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ نَصْرِ بْنِ عَلِيٍّ الْجَهْضَمِيِّ، عَنِ النَّضْرِ بْنِ شَيْبَانَ، ح وَحَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَالْقَاسِمُ بْنُ الْفَضْلِ الْحُدَّانِيُّ، كِلاَهُمَا عَنِ النَّضْرِ بْنِ شَيْبَانَ، قَالَ لَقِيتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ فَقُلْتُ حَدِّثْنِي بِحَدِيثٍ، سَمِعْتَهُ مِنْ، أَبِيكَ يَذْكُرُهُ فِي شَهْرِ رَمَضَانَ ‏.‏ قَالَ نَعَمْ ‏.‏ حَدَّثَنِي أَبِي أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ذَكَرَ شَهْرَ رَمَضَانَ فَقَالَ ‏ "‏ شَهْرٌ كَتَبَ اللَّهُ عَلَيْكُمْ صِيَامَهُ وَسَنَنْتُ لَكُمْ قِيَامَهُ فَمَنْ صَامَهُ وَقَامَهُ إِيمَانًا وَاحْتِسَابًا خَرَجَ مِنْ ذُنُوبِهِ كَيَوْمَ وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏\hadithno{1328}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Nadr bin Shaiban said:“I met Abu Salamah bin ‘Abdur-Rahman and said: ‘Tell me a Hadith that you heard from your father, in which mention is made of the month of Ramadan.’ He said: ‘Yes, my father narrated to me that the Messenger of Allah (ﷺ) mentioned the month of Ramadan and said: “A month which Allah has enjoined upon you to fast, and in which I have established Qiyam (prayers at night) as Sunnah for you. So whoever fasts it and spends its nights in prayer out of faith and in hope of reward; he will emerge from his sins as on the day his mother bore him.”}}
\hadithdefcmd{ibnmajah}{1329}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَعْقِدُ الشَّيْطَانُ عَلَى قَافِيَةِ رَأْسِ أَحَدِكُمْ بِاللَّيْلِ بِحَبْلٍ فِيهِ ثَلاَثُ عُقَدٍ فَإِنِ اسْتَيْقَظَ فَذَكَرَ اللَّهَ انْحَلَّتْ عُقْدَةٌ فَإِذَا قَامَ فَتَوَضَّأَ انْحَلَّتْ عُقْدَةٌ فَإِذَا قَامَ إِلَى الصَّلاَةِ انْحَلَّتْ عُقَدُهُ كُلُّهَا فَيُصْبِحُ نَشِيطًا طَيِّبَ النَّفْسِ قَدْ أَصَابَ خَيْرًا وَإِنْ لَمْ يَفْعَلْ أَصْبَحَ كَسِلاً خَبِيثَ النَّفْسِ لَمْ يُصِبْ خَيْرًا ‏"‏ ‏.‏\hadithno{1329}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘At night Satan ties a rope in which there are three knots to the nape of the neck of anyone of you. If he wakes up and remembers Allah, one knot is untied. If he performs ablution, another knot is untied, and if he gets up to pray, all the knots are untied, so he wakes up energetic and cheerful, he has already earned something good. But if he does not do that, he wakes up bad-tempered, having earned nothing good.”}}
\hadithdefcmd{ibnmajah}{1330}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ ذُكِرَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ رَجُلٌ نَامَ لَيْلَةً حَتَّى أَصْبَحَ قَالَ ‏ "‏ ذَلِكَ الشَّيْطَانُ بَالَ فِي أُذُنَيْهِ ‏"‏ ‏.‏\hadithno{1330}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdullah said:“Mention was made to the Messenger of Allah (ﷺ) of a man who slept until morning came. He said: ‘That is because Satan urinated in his ears.’”}}
\hadithdefcmd{ibnmajah}{1331}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَكُنْ مِثْلَ فُلاَنٍ كَانَ يَقُومُ اللَّيْلَ فَتَرَكَ قِيَامَ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1331}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“The Messenger of Allah (ﷺ) said: ‘Do not be like so-and-so, who used to pray voluntary night prayers then stopped praying voluntary night prayers.”}}
\hadithdefcmd{ibnmajah}{1332}{حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، وَالْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ، وَالْعَبَّاسُ بْنُ جَعْفَرٍ، وَمُحَمَّدُ بْنُ عَمْرٍو الْحَدَثَانِيُّ، قَالُوا حَدَّثَنَا سُنَيْدُ بْنُ دَاوُدَ، حَدَّثَنَا يُوسُفُ بْنُ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ قَالَتْ أُمُّ سُلَيْمَانَ بْنِ دَاوُدَ لِسُلَيْمَانَ يَا بُنَىَّ لاَ تُكْثِرِ النَّوْمَ بِاللَّيْلِ فَإِنَّ كَثْرَةَ النَّوْمِ بِاللَّيْلِ تَتْرُكُ الرَّجُلَ فَقِيرًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1332}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) said: ‘The mother of Sulaiman bin Dawud said to Sulaiman: “O my son, do not sleep too much at night, for sleeping too much at night will leave a man poor on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{1333}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُحَمَّدٍ الطَّلْحِيُّ، حَدَّثَنَا ثَابِتُ بْنُ مُوسَى أَبُو يَزِيدَ، عَنْ شَرِيكٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَثُرَتْ صَلاَتُهُ بِاللَّيْلِ حَسُنَ وَجْهُهُ بِالنَّهَارِ ‏"‏ ‏.‏\hadithno{1333}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) said: ‘Whoever prays a great deal at night, his face will be handsome during the day.’”}}
\hadithdefcmd{ibnmajah}{1334}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَابْنُ أَبِي عَدِيٍّ، وَعَبْدُ الْوَهَّابِ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ عَوْفِ بْنِ أَبِي جَمِيلَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْمَدِينَةَ انْجَفَلَ النَّاسُ إِلَيْهِ ‏.‏ وَقِيلَ قَدِمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَجِئْتُ فِي النَّاسِ لأَنْظُرَ إِلَيْهِ فَلَمَّا اسْتَبَنْتُ وَجْهَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عَرَفْتُ أَنَّ وَجْهَهُ لَيْسَ بِوَجْهِ كَذَّابٍ فَكَانَ أَوَّلَ شَىْءٍ تَكَلَّمَ بِهِ أَنْ قَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ أَفْشُوا السَّلاَمَ وَأَطْعِمُوا الطَّعَامَ وَصَلُّوا بِاللَّيْلِ وَالنَّاسُ نِيَامٌ تَدْخُلُوا الْجَنَّةَ بِسَلاَمٍ ‏"‏ ‏.‏\hadithno{1334}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin Salam said:“When the Messenger of Allah (ﷺ) came to Al-Madinah, the people rushed towards him and it was said: ‘The Messenger of Allah (ﷺ) has come!’ I came along with the people to see him, and when I looked at the face of the Messenger of Allah (ﷺ), I realized that his face was not the face of a liar. The first thing he said was: “O people, spread (the greeting of) Salam, offer food to people and pray at night when people are sleeping, you will enter Paradise in peace.”}}
\hadithdefcmd{ibnmajah}{1335}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا شَيْبَانُ أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنِ الأَغَرِّ، عَنْ أَبِي سَعِيدٍ، وَأَبِي، هُرَيْرَةَ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ الرَّجُلُ مِنَ اللَّيْلِ وَأَيْقَظَ امْرَأَتَهُ فَصَلَّيَا رَكْعَتَيْنِ كُتِبَا مِنَ الذَّاكِرِينَ اللَّهَ كَثِيرًا وَالذَّاكِرَاتِ ‏"‏ ‏.‏\hadithno{1335}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed and Abu Hurairah said that the Prophet (ﷺ) said:‘When a man wakes up at night and wakes his wife, and they pray two Rak’ah, they will be recorded among the men and women who remember Allah much.”}}
\hadithdefcmd{ibnmajah}{1336}{حَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ رَحِمَ اللَّهُ رَجُلاً قَامَ مِنَ اللَّيْلِ فَصَلَّى وَأَيْقَظَ امْرَأَتَهُ فَصَلَّتْ فَإِنْ أَبَتْ رَشَّ فِي وَجْهِهَا الْمَاءَ رَحِمَ اللَّهُ امْرَأَةً قَامَتْ مِنَ اللَّيْلِ فَصَلَّتْ وَأَيْقَظَتْ زَوْجَهَا فَصَلَّى فَإِنْ أَبَى رَشَّتْ فِي وَجْهِهِ الْمَاءَ ‏"‏ ‏.‏\hadithno{1336}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘May Allah have mercy on a man who gets up at night and prays, and wakes his wife, and she prays; and if she refuses he sprinkles water in her face. And May Allah have mercy on a woman who gets up at night and prays, and wakes her husband and he prays; and if he refuses, she sprinkles water in his face.’”}}
\hadithdefcmd{ibnmajah}{1337}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ بَشِيرِ بْنِ ذَكْوَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو رَافِعٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ السَّائِبِ، قَالَ قَدِمَ عَلَيْنَا سَعْدُ بْنُ أَبِي وَقَّاصٍ وَقَدْ كُفَّ بَصَرُهُ فَسَلَّمْتُ عَلَيْهِ فَقَالَ مَنْ أَنْتَ فَأَخْبَرْتُهُ ‏.‏ فَقَالَ مَرْحَبًا بِابْنِ أَخِي بَلَغَنِي أَنَّكَ حَسَنُ الصَّوْتِ بِالْقُرْآنِ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ هَذَا الْقُرْآنَ نَزَلَ بِحُزْنٍ فَإِذَا قَرَأْتُمُوهُ فَابْكُوا فَإِنْ لَمْ تَبْكُوا فَتَبَاكَوْا وَتَغَنَّوْا بِهِ فَمَنْ لَمْ يَتَغَنَّ بِهِ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{1337}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdur-Rahman bin Sa’ib said:“Sa’d bin Abu Waqqas came to us when he had become blind. I greeted him with Salam and he said: ‘Who are you?’ So I told him, and he said: ‘Welcome, O son of my brother. I have heard that you recite Qur’an in a beautiful voice. I heard the Messenger of Allah (ﷺ) say: “This Qur’an was revealed with sorrow, so when you recite it, then weep. If you cannot weep then pretend to weep, and make your voice melodious in reciting it. Whoever does not make his voice melodious, he is not one of us.”}}
\hadithdefcmd{ibnmajah}{1338}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَنْظَلَةُ بْنُ أَبِي سُفْيَانَ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ سَابِطٍ الْجُمَحِيَّ، يُحَدِّثُ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ أَبْطَأْتُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لَيْلَةً بَعْدَ الْعِشَاءِ ثُمَّ جِئْتُ فَقَالَ ‏"‏ أَيْنَ كُنْتِ ‏"‏ ‏.‏ قُلْتُ كُنْتُ أَسْتَمِعُ قِرَاءَةَ رَجُلٍ مِنْ أَصْحَابِكَ لَمْ أَسْمَعْ مِثْلَ قِرَاءَتِهِ وَصَوْتِهِ مِنْ أَحَدٍ ‏.‏ قَالَتْ فَقَامَ وَقُمْتُ مَعَهُ حَتَّى اسْتَمَعَ لَهُ ثُمَّ الْتَفَتَ إِلَىَّ فَقَالَ ‏"‏ هَذَا سَالِمٌ، مَوْلَى أَبِي حُذَيْفَةَ. الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي أُمَّتِي مِثْلَ هَذَا ‏"‏ ‏.‏\hadithno{1338}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah the wife of the Prophet (ﷺ) said:“One night at the time of the Messenger of Allah (ﷺ) I was late returning from the ‘Isha’, then I came and he said: ‘Where were you?’ I said: ‘I was listening to the recitation of a man among your Companions, for I have never heard a recitation or a voice like his from anyone.’ He got up and I got up with him, to go and listen to him. Then he turned to me and said: ‘This is Salim, the freed slave of Abu Hudhaifah. Praise is to Allah Who has created such men among my Ummah.’”}}
\hadithdefcmd{ibnmajah}{1339}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الضَّرِيرُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمَدَنِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ بْنِ مُجَمِّعٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِنْ أَحْسَنِ النَّاسِ صَوْتًا بِالْقُرْآنِ، الَّذِي إِذَا سَمِعْتُمُوهُ يَقْرَأُ، حَسِبْتُمُوهُ يَخْشَى اللَّهَ ‏"‏ ‏.‏\hadithno{1339}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) said: ‘Among the people who recite the Qur’an with the most beautiful voices is the man who, when you hear him, you think that he fears Allah.’”}}
\hadithdefcmd{ibnmajah}{1340}{حَدَّثَنَا رَاشِدُ بْنُ سَعِيدِ بْنِ رَاشِدٍ الرَّمْلِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عُبَيْدِ اللَّهِ، عَنْ مَيْسَرَةَ، مَوْلَى فَضَالَةَ عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَلَّهُ أَشَدُّ أَذَنًا إِلَى الرَّجُلِ الْحَسَنِ الصَّوْتِ بِالْقُرْآنِ يَجْهَرُ بِهِ مِنْ صَاحِبِ الْقَيْنَةِ إِلَى قَيْنَتِهِ ‏"‏ ‏.‏\hadithno{1340}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Fadalah bin ‘Ubaid said:“The Messenger of Allah (ﷺ) said: ‘Allah listens more attentively to a man with a beautiful voice who recites Qur’an out loud than the master of a singing slave listens to his slave.’”}}
\hadithdefcmd{ibnmajah}{1341}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ دَخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْمَسْجِدَ فَسَمِعَ قِرَاءَةَ رَجُلٍ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ فَقِيلَ هَذَا عَبْدُ اللَّهِ بْنُ قَيْسٍ ‏.‏ فَقَالَ ‏"‏ لَقَدْ أُوتِيَ هَذَا مِنْ مَزَامِيرِ آلِ دَاوُدَ ‏"‏ ‏.‏\hadithno{1341}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) entered the mosque and heard a man reciting Qur’an. He asked: ‘Who is this?’ It was said: ‘(He is) ‘Abdullah bin Qais.’ He said: ‘He has been given (sweet melodious voice) from the Mazamir of the family of Dawud.’”}}
\hadithdefcmd{ibnmajah}{1342}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ طَلْحَةَ الْيَامِيَّ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ عَوْسَجَةَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يُحَدِّثُ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ زَيِّنُوا الْقُرْآنَ بِأَصْوَاتِكُمْ ‏"‏ ‏.‏\hadithno{1342}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Bara’ (bin ‘Azib) that the Messenger of Allah (ﷺ) said:“Beautify the Qur’an with your voices.”}}
\hadithdefcmd{ibnmajah}{1343}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، أَنَّ السَّائِبَ بْنَ يَزِيدَ، وَعُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَاهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ نَامَ عَنْ جُزْئِهِ، أَوْ عَنْ شَىْءٍ مِنْهُ، فَقَرَأَهُ فِيمَا بَيْنَ صَلاَةِ الْفَجْرِ وَصَلاَةِ الظُّهْرِ - كُتِبَ لَهُ كَأَنَّمَا قَرَأَهُ مِنَ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1343}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Abdur-Rahman bin ‘Abdin Al-Qari said:“I heard ‘Umar bin Khattab say: ‘The Messenger of Allah (ﷺ) said: ‘Whoever sleeps and misses his daily portion of Qur’an, or any part of it, let him read it between the Fajr prayer and the Zuhr prayer, and it will be recorded as if he had read it during the night.”}}
\hadithdefcmd{ibnmajah}{1344}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللّ��هِ الْحَمَّالُ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَبْدَةَ بْنِ أَبِي لُبَابَةَ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، عَنْ أَبِي الدَّرْدَاءِ، يَبْلُغُ بِهِ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَتَى فِرَاشَهُ وَهُوَ يَنْوِي أَنْ يَقُومَ فَيُصَلِّيَ مِنَ اللَّيْلِ فَغَلَبَتْهُ عَيْنُهُ حَتَّى يُصْبِحَ - كُتِبَ لَهُ مَا نَوَى وَكَانَ نَوْمُهُ صَدَقَةً عَلَيْهِ مِنْ رَبِّهِ ‏"‏ ‏.‏\hadithno{1344}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih}\hadithtrans{It was narrated that Abu Darda’ conveyed that the Prophet (ﷺ) said:“Whoever goes to bed intending to wake up and pray during the night, but is overwhelmed by sleep until morning comes, what he intended will be recorded for him, and his sleep is a charity given to him by his Lord.”}}
\hadithdefcmd{ibnmajah}{1345}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْلَى الطَّائِفِيِّ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ أَوْسٍ، عَنْ جَدِّهِ، أَوْسِ بْنِ حُذَيْفَةَ قَالَ قَدِمْنَا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي وَفْدِ ثَقِيفٍ فَنَزَّلُوا الأَحْلاَفَ عَلَى الْمُغِيرَةِ بْنِ شُعْبَةَ وَأَنْزَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَنِي مَالِكٍ فِي قُبَّةٍ لَهُ فَكَانَ يَأْتِينَا كُلَّ لَيْلَةٍ بَعْدَ الْعِشَاءِ فَيُحَدِّثُنَا قَائِمًا عَلَى رِجْلَيْهِ حَتَّى يُرَاوِحَ بَيْنَ رِجْلَيْهِ وَأَكْثَرُ مَا يُحَدِّثُنَا مَا لَقِيَ مِنْ قَوْمِهِ مِنْ قُرَيْشٍ وَيَقُولُ ‏"‏ وَلاَ سَوَاءَ كُنَّا مُسْتَضْعَفِينَ مُسْتَذَلِّينَ فَلَمَّا خَرَجْنَا إِلَى الْمَدِينَةِ كَانَتْ سِجَالُ الْحَرْبِ بَيْنَنَا وَبَيْنَهُمْ نُدَالُ عَلَيْهِمْ وَيُدَالُونَ عَلَيْنَا ‏"‏ ‏.‏ فَلَمَّا كَانَ ذَاتَ لَيْلَةٍ أَبْطَأَ عَنِ الْوَقْتِ الَّذِي كَانَ يَأْتِينَا فِيهِ فَقُلْتُ يَا رَسُولَ اللَّهِ لَقَدْ أَبْطَأْتَ عَلَيْنَا اللَّيْلَةَ ‏.‏ قَالَ ‏"‏ إِنَّهُ طَرَأَ عَلَىَّ حِزْبِي مِنَ الْقُرْآنِ فَكَرِهْتُ أَنْ أَخْرُجَ حَتَّى أُتِمَّهُ ‏"‏ ‏.‏ قَالَ أَوْسٌ فَسَأَلْتُ أَصْحَابَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ كَيْفَ تُحَزِّبُونَ الْقُرْآنَ قَالُوا ثَلاَثٌ وَخَمْسٌ وَسَبْعٌ وَتِسْعٌ وَإِحْدَى عَشْرَةَ وَثَلاَثَ عَشْرَةَ وَحِزْبُ الْمُفَصَّلِ ‏.‏\hadithno{1345}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Uthman bin ‘Abdullah bin Aws that his grandfather Aws bin Hudhaifah said:“We came to the Messenger of Allah (ﷺ) in the delegation of Thaqif. The allies of Quraish stayed at the house of Mughirah bin Shu’bah, and the Messenger of Allah (ﷺ) camped Bani Malik in a tent belonging to him. He used to come to us every night after the ‘Isha’ and speak to us standing on his two feet, until he started to shift his weight from one foot to the other. Most of what he told us was what he had suffered from his people, the Quraish. He said: ‘(The two sides) were not equal. We were weak and oppressed and humiliated, and when we went out to Al-Madinah, the outcome of the battles between us varied; sometimes we would defeat them and sometimes they would defeat us.’ One night he was later than he usually was, and I said: ‘O Messenger of Allah, you have come to us late tonight.’ He said: ‘It occurred to me that I had not read my daily portion of Qur’an and I did not want to come out until I had completed it.’” Aws said: “I asked the Companions of the Messenger of Allah (ﷺ): ‘How did you used to divide up the Qur’an?’ They said: ‘A third, a fifth, a seventh, a ninth, an eleventh, a thirteenth, and Hizbul-Mufassal.’”}}
\hadithdefcmd{ibnmajah}{1346}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ يَحْيَى بْنِ حَكِيمِ بْنِ صَفْوَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ جَمَعْتُ الْقُرْآنَ فَقَرَأْتُهُ كُلَّهُ فِي لَيْلَةٍ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنِّي أَخْشَى أَنْ يَطُولَ عَلَيْكَ الزَّمَانُ وَأَنْ تَمَلَّ فَاقْرَأْهُ فِي شَهْرٍ ‏"‏ ‏.‏ فَقُلْتُ دَعْنِي أَسْتَمْتِعْ مِنْ قُوَّتِي وَشَبَابِي ‏.‏ قَالَ ‏"‏ فَاقْرَأْهُ فِي عَشْرَةٍ ‏"‏ ‏.‏ قُلْتُ دَعْنِي أَسْتَمْتِعْ مِنْ قُوَّتِي وَشَبَابِي ‏.‏ قَالَ ‏"‏ فَاقْرَأْهُ فِي سَبْعٍ ‏"‏ ‏.‏ قُلْتُ دَعْنِي أَسْتَمْتِعْ مِنْ قُوَّتِي وَشَبَابِي ‏.‏ فَأَبَى ‏.‏\hadithno{1346}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“I memorized the Qur’an and recited it all in one night. The Messenger of Allah (ﷺ) said: ‘I am afraid that you may live a long life and that you may get bored. Recite it over the period of a month.’ I said: ‘Let me benefit from my strength in my youth.’ He said: ‘Recite it in ten days.’ I said: ‘Let me benefit from my strength and my youth.’ He said: ‘Recite it in seven days.’ I said: ‘Let me benefit from my strength and my youth,’ but he refused (to alter it any further).”}}
\hadithdefcmd{ibnmajah}{1347}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَمْ يَفْقَهْ مَنْ قَرَأَ الْقُرْآنَ فِي أَقَلَّ مِنْ ثَلاَثٍ ‏"‏ ‏.‏\hadithno{1347}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) said:“No one properly understands who reads the Qur’an in less than three days.”}}
\hadithdefcmd{ibnmajah}{1348}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، حَدَّثَنَا قَتَادَةُ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ لاَ أَعْلَمُ نَبِيَّ اللَّهِ ـ صلى الله عليه وسلم ـ قَرَأَ الْقُرْآنَ كُلَّهُ حَتَّى الصَّبَاحِ ‏.‏\hadithno{1348}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“I did not know of the Prophet of Allah (ﷺ) reciting the entire Qur’an until morning.”}}
\hadithdefcmd{ibnmajah}{1349}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مِسْعَرٌ، عَنْ أَبِي الْعَلاَءِ، عَنْ يَحْيَى بْنِ جَعْدَةَ، عَنْ أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ، قَالَتْ كُنْتُ أَسْمَعُ قِرَاءَةَ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِاللَّيْلِ وَأَنَا عَلَى عَرِيشِي ‏.‏\hadithno{1349}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Hani’ bint Abi Talib said:“I used to hear the Prophet (ﷺ) reciting at night when I was on the roof of my house.”}}
\hadithdefcmd{ibnmajah}{1350}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ قُدَامَةَ بْنِ عَبْدِ اللَّهِ، عَنْ جَسْرَةَ بِنْتِ دَجَاجَةَ، قَالَتْ سَمِعْتُ أَبَا ذَرٍّ، يَقُولُ قَامَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِآيَةٍ حَتَّى أَصْبَحَ يُرَدِّدُهَا وَالآيَةُ ‏\{إِنْ تُعَذِّبْهُمْ فَإِنَّهُمْ عِبَادُكَ وَإِنْ تَغْفِرْ لَهُمْ فَإِنَّكَ أَنْتَ الْعَزِيزُ الْحَكِيمُ\}‏ ‏.‏\hadithno{1350}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jasrah bint Dijajah said:“I heard Abu Dharr say: ‘The Prophet (ﷺ) stood reciting a Verse and repeating it until morning came. That Verse was: “If you punish them, they are Your slaves, and if You forgive them, verily You, only You, are the All- Mighty, the All-Wise.’”” [5:]}}
\hadithdefcmd{ibnmajah}{1351}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْمُسْتَوْرِدِ بْنِ الأَحْنَفِ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى فَكَانَ إِذَا مَرَّ بِآيَةِ رَحْمَةٍ سَأَلَ وَإِذَا مَرَّ بِآيَةِ عَذَابٍ اسْتَجَارَ وَإِذَا مَرَّ بِآيَةٍ فِيهَا تَنْزِيهٌ لِلَّهِ سَبَّحَ ‏.‏\hadithno{1351}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hudhaifah that the Prophet (ﷺ) prayed, and when he recited a Verse which mentioned mercy, he would ask for mercy; when he recited a Verse that mentioned punishment he would pray for deliverance from it; and when he recited a Verse that mentioned the Tanzih of Allah, he would glorify Him}}
\hadithdefcmd{ibnmajah}{1352}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ هَاشِمٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ ثَابِتٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أَبِي لَيْلَى، قَالَ صَلَّيْتُ إِلَى جَنْبِ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَهُوَ يُصَلِّي مِنَ اللَّيْلِ تَطَوُّعًا فَمَرَّ بِآيَةِ عَذَابٍ فَقَالَ ‏ "‏ أَعُوذُ بِاللَّهِ مِنَ النَّارِ وَوَيْلٌ لأَهْلِ النَّارِ ‏"‏ ‏.‏\hadithno{1352}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Laila said:“I prayed beside the Prophet (ﷺ) when he was praying voluntary prayers at night. He recited a Verse which mentioned punishment and said: ‘I seek refuge with Allah from the Fire, woe to the people of the Fire.’”}}
\hadithdefcmd{ibnmajah}{1353}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ قَتَادَةَ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنْ قِرَاءَةِ النَّبِيِّ، ـ صلى الله عليه وسلم ـ فَقَالَ كَانَ يَمُدُّ صَوْتَهُ مَدًّا ‏.‏\hadithno{1353}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qatadah said; “I asked Anas bin Malik about the recitation of the Prophet (ﷺ) and he said:‘He used to elongate his voice.’”}}
\hadithdefcmd{ibnmajah}{1354}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ بُرْدِ بْنِ سِنَانٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ غُضَيْفِ بْنِ الْحَارِثِ، قَالَ أَتَيْتُ عَائِشَةَ فَقُلْتُ أَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَجْهَرُ بِالْقُرْآنِ أَوْ يُخَافِتُ بِهِ قَالَتْ رُبَّمَا جَهَرَ وَرُبَّمَا خَافَتَ ‏.‏ قُلْتُ اللَّهُ أَكْبَرُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي هَذَا الأَمْرِ سَعَةً ‏.‏\hadithno{1354}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ghudaif bin Harith said:“I came to ‘Aishah and asked: ‘Did the Messenger of Allah (ﷺ) recite Qur’an loudly or softly?’ She said: ‘Sometimes he would recite loud and sometimes softly.’ I said, ‘Allahu Akbar! Praise is to Allah Who has made this matter one of broad scope.’”}}
\hadithdefcmd{ibnmajah}{1355}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا تَهَجَّدَ مِنَ اللَّيْلِ قَالَ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ وَلَكَ الْحَمْدُ أَنْتَ قَيَّامُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ وَلَكَ الْحَمْدُ أَنْتَ مَالِكُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ وَلَكَ الْحَمْدُ أَنْتَ الْحَقُّ وَوَعْدُكَ حَقٌّ وَلِقَاؤُكَ حَقٌّ وَقَوْلُكَ حَقٌّ وَالْجَنَّةُ حَقٌّ وَالنَّارُ حَقٌّ وَالسَّاعَةُ حَقٌّ وَالنَّبِيُّونَ حَقٌّ وَمُحَمَّدٌ حَقٌّ اللَّهُمَّ لَكَ أَسْلَمْتُ وَبِكَ آمَنْتُ وَعَلَيْكَ تَوَكَّلْتُ وَإِلَيْكَ أَنَبْتُ وَبِكَ خَاصَمْتُ وَإِلَيْكَ حَاكَمْتُ فَاغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ أَنْتَ الْمُقَدِّمُ وَأَنْتَ الْمُؤَخِّرُ لاَ إِلَهَ إِلاَّ أَنْتَ وَلاَ إِلَهَ غَيْرُكَ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِكَ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا سُلَيْمَانُ بْنُ أَبِي مُسْلِمٍ الأَحْوَلُ، خَالُ ابْنِ أَبِي نَجِيحٍ سَمِعَ طَاوُسًا، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا قَامَ مِنَ اللَّيْلِ لِلتَّهَجُّدِ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{1355}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn `Abbas said:“When the Messenger of Allah (ﷺ) prayed Tahajjud at night, he would say: “Allahumma lakal-hamd, Anta nurus-samawati wal-ard wa man fihinna. Wa lakal-hamd, Anta qayyamus-samawati wal-ard wa man fihinna. Wa lakal-hamd, Anta malikus- samawati wal-ard wa man fihinna. Wa lakal-hamd, Antal-haqq, wa wa`duka haqq, wa liqa’uka haqq, wa qawluka haqq, wal-jannatu haqq, wan-naru haqq, was-sa`atu haqq, wan-nabiyyuna haqq, wa Muhammadun haqq. Allahumma laka aslamtu, wa bika amantu, wa `alaika tawakkaltu wa ilaika anabtu, wa bika khasamtu, wa ilaika hakamtu, faghfirli ma qaddamtu wa ma akhkhartu, wa ma asrartu wa ma a`lantu. Antal-muqaddimu wa Antal-muakhkhiru. La ilaha illa anta wa la ilaha ghairuka, wa la hawla wa la quwwata illa bika (O Allah, to you is praise, You are the Light of the heavens and the earth, and everyone therein. To You is praise, You are the Sustainer of the heavens and the earth, and everyone therein. To You is praise, You are the Sovereign of the heavens and the earth, and everyone therein. To You is praise, You are the Truth; Your promise is true, the meeting with You is true, Your saying is true, Paradise is true, the Fire is true, the Hour is true, the Prophets are true, and Muhammad (ﷺ) is true. O Allah, to You have I submitted, in You I believe, in You have I put my trust, to You I turn in repentance, by Your help I argue, to You I refer my case, so forgive me for my past and future sins, what I have done in secret and what I have done openly. You are the One Who brings forward and puts back. None has the right to be worshipped but You, and there is none who has the right to be worshipped other than You. And there is no power and no strength except with You.” Another chain that Ibn `Abbas narrated: “When the Messenger of Allah (ﷺ) stood during the night for Tahajjud,” and he mentioned something similar}}
\hadithdefcmd{ibnmajah}{1356}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، حَدَّثَنِي أَزْهَرُ بْنُ سَعِيدٍ، عَنْ عَاصِمِ بْنِ حُمَيْدٍ، قَالَ سَأَلْتُ عَائِشَةَ مَاذَا كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَفْتَتِحُ بِهِ قِيَامَ اللَّيْلِ قَالَتْ لَقَدْ سَأَلْتَنِي عَنْ شَىْءٍ مَا سَأَلَنِي عَنْهُ أَحَدٌ قَبْلَكَ كَانَ يُكَبِّرُ عَشْرًا وَيَحْمَدُ عَشْرًا وَيُسَبِّحُ عَشْرًا وَيَسْتَغْفِرُ عَشْرًا وَيَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَاهْدِنِي وَارْزُقْنِي وَعَافِنِي ‏"‏ ‏.‏ وَيَتَعَوَّذُ مِنْ ضِيقِ الْمُقَامِ يَوْمَ الْقِيَامَةِ ‏.‏\hadithno{1356}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Asim bin Humaid said:“I asked ‘Aishah: ‘With what did the Prophet (ﷺ) start voluntary prayers?’ She said: ‘You have asked me about something which no one has asked before. He used to say Allahu Akbar ten times, and Al-Hamdu Lillah ten times and Subhan Allah ten times, and he would say Allahumma aghfirli wahdini, warzuqni, wa ‘afini (O Allah, forgive me, guide me, grant me provision and give me good health),” and he would seek refuge from the difficulty of the standing on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{1357}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُمَرَ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ الْيَمَامِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَأَلْتُ عَائِشَةَ بِمَا كَانَ يَسْتَفْتِحُ النَّبِيُّ ـ صلى الله عليه وسلم ـ صَلاَتَهُ إِذَا قَامَ مِنَ اللَّيْلِ قَالَتْ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ رَبَّ جِبْرَئِيلَ وَمِيكَائِيلَ وَإِسْرَافِيلَ فَاطِرَ السَّمَوَاتِ وَالأَرْضِ عَالِمَ الْغَيْبِ وَالشَّهَادَةِ أَنْتَ تَحْكُمُ بَيْنَ عِبَادِكَ فِيمَا كَانُوا فِيهِ يَخْتَلِفُونَ اهْدِنِي لِمَا اخْتُلِفَ فِيهِ مِنَ الْحَقِّ بِإِذْنِكَ إِنَّكَ لَتَهْدِي إِلَى صِرَاطٍ مُسْتَقِيمٍ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ بْنُ عُمَرَ احْفَظُوهُ جِبْرَئِيلُ مَهْمُوزَةً فَإِنَّهُ كَذَا عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1357}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Salamah bin `Abdur-Rahman said:“I asked `Aishah: ‘With what did the Prophet (ﷺ) start his voluntary prayers?’ She said: ‘He would say: “Allahumma Rabba Jibra’il wa Mika’il wa Israfil, Fatiras-samawati wal-ard, `alimal-ghaybi wash- shahadah, Anta tahkumu baina `ibadika fima kanu fihi yakhtalifun, ihdini lima-khtulifa fihi minal-haqqi bi idhnika, innaka latahdi ila siratin mustaqim (O Allah, Lord of Jibra’il, Mika’il and Israfil, Creator of the heavens and the earth, Knower of the unseen and the seen, You judge between Your slaves concerning that wherein they differ. Guide me to the disputed matters of truth by Your Leave, for You are the One Who guides to the straight Path).” (One of the narrators) `Abdur-Rahman bin `Umar said: “Bear in mind the word Jibra’il with a Hamzah - this is how it was narrated from the Prophet (ﷺ).”}}
\hadithdefcmd{ibnmajah}{1358}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - وَهَذَا حَدِيثُ أَبِي بَكْرٍ - قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي مَا بَيْنَ أَنْ يَفْرُغَ مِنْ صَلاَةِ الْعِشَاءِ إِلَى الْفَجْرِ إِحْدَى عَشْرَةَ رَكْعَةً يُسَلِّمُ فِي كُلِّ اثْنَتَيْنِ وَيُوتِرُ بِوَاحِدَةٍ وَيَسْجُدُ فِيهِنَّ سَجْدَةً بِقَدْرِ مَا يَقْرَأُ أَحَدُكُمْ خَمْسِينَ آيَةً قَبْلَ أَنْ يَرْفَعَ رَأْسَهُ فَإِذَا سَكَتَ الْمُؤَذِّنُ مِنَ الأَذَانِ الأَوَّلِ مِنْ صَلاَةِ الصُّبْحِ قَامَ فَرَكَعَ رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏\hadithno{1358}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said, and this is the Hadith of Abu Bakr. “During the period after he finished the ‘Isha’ prayer until the Fajr, the Prophet (ﷺ) used to pray eleven Rak’ah, saying the Salam after each two Rak’ah and praying Witr with one Rak’ah. He would prostrate for as long as it takes anyone of you to recite fifty Verses before he would raise his head. When the Mu’adh-dhin fell silent after the first Adhan for the Subh prayer, he would get up and pray two brief Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1359}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{1359}\hadithgrade{Al-Albani: Shadh; Muhammad Fouad Abd al-Baqi: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) used to pray thirteen Rak’ah at night.”}}
\hadithdefcmd{ibnmajah}{1360}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي مِنَ اللَّيْلِ تِسْعَ رَكَعَاتٍ\hadithno{1360}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) used to pray nine Rak’ah at night}}
\hadithdefcmd{ibnmajah}{1361}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ أَبُو عُبَيْدٍ الْمَدِينِيُّ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَامِرٍ الشَّعْبِيِّ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ وَعَبْدَ اللَّهِ بْنَ عُمَرَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِاللَّيْلِ فَقَالاَ ثَلاَثَ عَشْرَةَ رَكْعَةً مِنْهَا ثَمَانٍ وَيُوتِرُ بِثَلاَثٍ وَرَكْعَتَيْنِ بَعْدَ الْفَجْرِ ‏.‏\hadithno{1361}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Amir Ash-Sha’bi said:“I asked ‘Abdullah bin ‘Abbas and ‘Abdullah bin ‘Umar about the Prophet’s prayer at night. They said: ‘(He prayed) thirteen Rak’ah, including eight, and three for Witr, and two Rak’ah after the Fajr.’”}}
\hadithdefcmd{ibnmajah}{1362}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ عَاصِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعِ بْنِ ثَابِتٍ الزُّبَيْرِيُّ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ قَيْسِ بْنِ مَخْرَمَةَ، أَخْبَرَهُ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قُلْتُ لأَرْمُقَنَّ صَلاَةَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ اللَّيْلَةَ ‏.‏ قَالَ فَتَوَسَّدْتُ عَتَبَتَهُ أَوْ فُسْطَاطَهُ فَقَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ ثُمَّ رَكْعَتَيْنِ طَوِيلَتَيْنِ طَوِيلَتَيْنِ طَوِيلَتَيْنِ ثُمَّ رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ رَكْعَتَيْنِ ثُمَّ أَوْتَرَ فَتِلْكَ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{1362}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Zaid bin Khalid Al-Juhani said:“I said, I must observe how the Messenger of Allah (ﷺ) prays tonight. So I lay down at his door. The Messenger of Allah (ﷺ) got up and prayed two brief Rak’ah, then two long ones, which were very, very long, then two Rak’ah which were shorter than the ones preceding them, then two Rak’ah which were shorter than the ones preceding them, then two Rak’ah which were shorter than the ones preceding them, then two Rak’ah, then Witr. That was thirteen Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1363}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، أَخْبَرَهُ أَنَّهُ، نَامَ عِنْدَ مَيْمُونَةَ زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ - وَهِيَ خَالَتُهُ - قَالَ فَاضْطَجَعْتُ فِي عَرْضِ الْوِسَادَةِ وَاضْطَجَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَهْلُهُ فِي طُولِهَا فَنَامَ النَّبِيُّ ـ صلى الله عليه وسلم ـ حَتَّى إِذَا انْتَصَفَ اللَّيْلُ أَوْ قَبْلَهُ بِقَلِيلٍ أَوْ بَعْدَهُ بِقَلِيلٍ اسْتَيْقَظَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَجَعَلَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ بِيَدِهِ ثُمَّ قَرَأَ الْعَشْرَ آيَاتٍ مِنْ آخِرِ سُورَةِ آلِ عِمْرَانَ ثُمَّ قَامَ إِلَى شَنٍّ مُعَلَّقَةٍ فَتَوَضَّأَ مِنْهَا فَأَحْسَنَ وُضُوءَهُ ثُمَّ قَامَ يُصَلِّي ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ ثُمَّ ذَهَبْتُ فَقُمْتُ إِلَى جَنْبِهِ فَوَضَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَدَهُ الْيُمْنَى عَلَى رَأْسِي وَأَخَذَ أُذُنِي الْيُمْنَى يَفْتِلُهَا فَصَلَّى رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ أَوْتَرَ ‏.‏ ثُمَّ اضْطَجَعَ حَتَّى جَاءَهُ الْمُؤَذِّنُ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ ‏.‏\hadithno{1363}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Kuraib, the freed slave of Ibn ‘Abbas, that Ibn ‘Abbas told him that he slept at the house of Maimunah, the wife of the Prophet (ﷺ), who was his maternal aunt. He said:“I lay down across the pillow and the Messenger of Allah (ﷺ) and his wife were laying along it. The Prophet (ﷺ) slept until midnight, or a little before, or a little after. The Prophet (ﷺ) woke up and began to rub the sleep from his face with his hand. Then he recited the last ten Verses of Surah Al ‘Imran. Then he got up and went to a water skin that was hanging up and performed ablution from it, and he performed ablution well, then he stood up and prayed.” ‘Abdullah bin ‘Abbas said: “I stood up and did what he had done, then I went and stood beside him. The Messenger of Allah (ﷺ) put his right hand on my head, took hold of my right ear and tweaked it. Then he prayed two Rak’ah, then two Rak’ah, then two Rak’ah, then two Rak’ah, then two Rak’ah, then two Rak’ah, then he prayed Witr. Then he lay down until the Mu’adh-dhin came to him and he prayed two brief Rak’ah, then he went out to pray.”}}
\hadithdefcmd{ibnmajah}{1364}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ يَزِيدَ بْنِ طَلْقٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ عَمْرِو بْنِ عَبَسَةَ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ مَنْ أَسْلَمَ مَعَكَ قَالَ ‏"‏ حُرٌّ وَعَبْدٌ ‏"‏ ‏.‏ قُلْتُ هَلْ مِنْ سَاعَةٍ أَقْرَبُ إِلَى اللَّهِ مِنْ أُخْرَى قَالَ ‏"‏ نَعَمْ جَوْفُ اللَّيْلِ الأَوْسَطُ ‏"‏ ‏.‏\hadithno{1364}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Amr bin ‘Abasah said:“I came to the Messenger of Allah (ﷺ) and said: ‘O Messenger of Allah, who became a Muslim with you?’ He said: ‘A free man and a slave.’ I said: ‘Is there any hour of the night that is closer to Allah than another?’ He said: ‘Yes, the last half of the night.’”}}
\hadithdefcmd{ibnmajah}{1365}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَنَامُ أَوَّلَ اللَّيْلِ وَيُحْيِي آخِرَهُ ‏.‏\hadithno{1365}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) used to sleep during the first part of the night and stay awake during the latter part.”}}
\hadithdefcmd{ibnmajah}{1366}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ قَالاَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَأَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يَنْزِلُ رَبُّنَا تَبَارَكَ وَتَعَالَى، حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ، كُلَّ لَيْلَةٍ، فَيَقُولُ: مَنْ يَسْأَلُنِي فَأُعْطِيَهُ؟ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ؟ مَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ؟ حَتَّى يَطْلُعَ الْفَجْرُ ‏"‏ ‏.‏ فَلِذَلِكَ كَانُوا يَسْتَحِبُّونَ صَلاَةَ آخِرِ اللَّيْلِ عَلَى أَوَّلِهِ ‏.‏\hadithno{1366}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Our Lord, the Blessed and Exalted, descends when one third of the night remains, every night and He says: ‘Who will ask of Me, that I may give him? Who will call upon Me, that I may answer him? Who will ask My forgiveness, that I may forgive him?’ until dawn comes.” Hence they used to prefer voluntary prayers at the end of the night rather than at the beginning}}
\hadithdefcmd{ibnmajah}{1367}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رِفَاعَةَ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ يُمْهِلُ حَتَّى إِذَا ذَهَبَ مِنَ اللَّيْلِ نِصْفُهُ أَوْ ثُلُثَاهُ قَالَ لاَ يَسْأَلَنَّ عِبَادِي غَيْرِي مَنْ يَدْعُنِي أَسْتَجِبْ لَهُ مَنْ يَسْأَلْنِي أُعْطِهِ مَنْ يَسْتَغْفِرْنِي أَغْفِرْ لَهُ حَتَّى يَطْلُعَ الْفَجْرُ ‏"‏ ‏.‏\hadithno{1367}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Rifa’ah Al-Juhani said:“The Messenger of Allah (ﷺ) said: ‘Allah provides respite until, when half or two thirds of the night had passed, He says: “My slave does not ask of anyone other than Me. Whoever calls upon Me, I will answer him; whoever asks of Me, I will give him; whoever asks My forgiveness, I will forgive him,” until dawn comes.’”}}
\hadithdefcmd{ibnmajah}{1368}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، وَأَسْبَاطُ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَلْقَمَةَ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الآيَتَانِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ مَنْ قَرَأَهُمَا فِي لَيْلَةٍ كَفَتَاهُ ‏"‏ ‏.‏ قَالَ حَفْصٌ فِي حَدِيثِهِ قَالَ عَبْدُ الرَّحْمَنِ فَلَقِيتُ أَبَا مَسْعُودٍ وَهُوَ يَطُوفُ فَحَدَّثَنِي بِهِ ‏.‏\hadithno{1368}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Mas`ud said:The Messenger of Allah (ﷺ) said: “Whoever recites the last two Verses of Surat Al-Baqarah at night, that will be sufficient for him.” In his narration (one of the narrators) Hafs said: “`Abdur-Rahman said: ‘I met Abu Mas`ud when he was performing Tawaf, and he narrated this to me.’”}}
\hadithdefcmd{ibnmajah}{1369}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِي مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ قَرَأَ الآيَتَيْنِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي لَيْلَةٍ كَفَتَاهُ ‏"‏ ‏.‏\hadithno{1369}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Mas’ud that the Messenger of Allah (ﷺ) said:“Whoever recites the last two Verses of Surat Al-Baqarah at night, that will be sufficient for him.”}}
\hadithdefcmd{ibnmajah}{1370}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ فَلْيَرْقُدْ حَتَّى يَذْهَبَ عَنْهُ النَّوْمُ فَإِنَّهُ لاَ يَدْرِي إِذَا صَلَّى وَهُوَ نَاعِسٌ لَعَلَّهُ يَذْهَبُ يَسْتَغْفِرُ فَيَسُبُّ نَفْسَهُ ‏"‏ ‏.‏\hadithno{1370}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) said: ‘If anyone of you becomes drowsy, let him sleep until he feels refreshed, for he does not know, if he prays when he feels drowsy, he may want to say words seeking forgiveness but (instead) he ends up cursing himself.’”}}
\hadithdefcmd{ibnmajah}{1371}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ دَخَلَ الْمَسْجِدَ فَرَأَى حَبْلاً مَمْدُودًا بَيْنَ سَارِيَتَيْنِ فَقَالَ ‏"‏ مَا هَذَا الْحَبْلُ؟‏ "‏ ‏.‏ قَالُوا لِزَيْنَبَ تُصَلِّي فِيهِ فَإِذَا فَتَرَتْ تَعَلَّقَتْ بِهِ ‏.‏ فَقَالَ ‏"‏ حُلُّوهُ. حُلُّوهُ. لِيُصَلِّ أَحَدُكُمْ نَشَاطَهُ. فَإِذَا فَتَرَ فَلْيَقْعُدْ ‏"‏ ‏.‏\hadithno{1371}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) entered the mosque and saw a rope tied between two pillars. He said, “What is this rope?” They said:“It belongs to Zainab. She prays here and when she gets tired she holds on to it.” He said: “Untie it, untie it; let any one of you pray when he has energy, if he gets tired let him sit down.”}}
\hadithdefcmd{ibnmajah}{1372}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي بَكْرِ بْنِ يَحْيَى بْنِ النَّضْرِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا قَامَ أَحَدُكُمْ مِنَ اللَّيْلِ، فَاسْتَعْجَمَ الْقُرْآنُ عَلَى لِسَانِهِ، فَلَمْ يَدْرِ مَا يَقُولُ، اضْطَجَعَ ‏"‏ ‏.‏\hadithno{1372}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“When anyone of you gets up to pray at night, and his tongue stumbles over the words of the Qur’an, and he does not know what he is saying, let him lie down.”}}
\hadithdefcmd{ibnmajah}{1373}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَعْقُوبُ بْنُ الْوَلِيدِ الْمَدِينِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَلَّى بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ عِشْرِينَ رَكْعَةً بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1373}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) said: ‘Whoever prays twenty Rak’ah between Maghrib and ‘Isha’, Allah will build for him a house in Paradise.’”}}
\hadithdefcmd{ibnmajah}{1374}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَأَبُو عُمَرَ حَفْصُ بْنُ عُمَرَ قَالاَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنِي عُمَرُ بْنُ أَبِي خَثْعَمٍ الْيَمَامِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَلَّى سِتَّ رَكَعَاتٍ بَعْدَ الْمَغْرِبِ لَمْ يَتَكَلَّمْ بَيْنَهُنَّ بِسُوءٍ عُدِلَتْ لَهُ عِبَادَةَ اثْنَتَىْ عَشْرَةَ سَنَةً ‏"‏ ‏.‏\hadithno{1374}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever prays six Rak’ah after the Maghrib and does not speak evil between them, they will be made equivalent to twelve years’ worship.’”}}
\hadithdefcmd{ibnmajah}{1375}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ طَارِقٍ، عَنْ عَاصِمِ بْنِ عَمْرٍو، قَالَ خَرَجَ نَفَرٌ مِنْ أَهْلِ الْعِرَاقِ إِلَى عُمَرَ فَلَمَّا قَدِمُوا عَلَيْهِ قَالَ لَهُمْ مِمَّنْ أَنْتُمْ قَالُوا مِنْ أَهْلِ الْعِرَاقِ ‏.‏ قَالَ فَبِإِذْنٍ جِئْتُمْ قَالُوا نَعَمْ ‏.‏ قَالَ فَسَأَلُوهُ عَنْ صَلاَةِ الرَّجُلِ فِي بَيْتِهِ ‏.‏ فَقَالَ عُمَرُ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ أَمَّا صَلاَةُ الرَّجُلِ فِي بَيْتِهِ فَنُورٌ فَنَوِّرُوا بُيُوتَكُمْ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي الْحُسَيْنِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ عَمْرٍو، عَنْ عُمَيْرٍ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1375}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Asim bin ‘Amr said:“A group from the people of ‘Iraq came to ‘Umar and when they came to him, he said to them: ‘Where are you from?’ They said: ‘From the inhabitants of ‘Iraq.’ He said: ‘Have you come with permission?’ They said: ‘Yes.’ Then they asked him about a man’s prayer in his house. ‘Umar said: ‘I asked the Messenger of Allah (ﷺ) and he said: “As for a man’s prayer in his house, it is light, so illuminate your houses.’”” Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{1376}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا قَضَى أَحَدُكُمْ صَلاَتَهُ فَلْيَجْعَلْ لِبَيْتِهِ مِنْهَا نَصِيبًا فَإِنَّ اللَّهَ جَاعِلٌ فِي بَيْتِهِ مِنْ صَلاَتِهِ خَيْرًا ‏"‏ ‏.‏\hadithno{1376}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) said:“When anyone of you has finished his prayer, let him give his house a share of that, for Allah will put something good in his house because of that prayer.”}}
\hadithdefcmd{ibnmajah}{1377}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ، وَعَبْدُ الرَّحْمَنِ بْنُ عُمَرَ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَتَّخِذُوا بُيُوتَكُمْ قُبُورًا ‏"‏ ‏.‏\hadithno{1377}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘Do not make your houses into graves.’”}}
\hadithdefcmd{ibnmajah}{1378}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ حَرَامِ بْنِ مُعَاوِيَةَ، عَنْ عَمِّهِ عَبْدِ اللَّهِ بْنِ سَعْدٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَيُّمَا أَفْضَلُ الصَّلاَةُ فِي بَيْتِي أَوِ الصَّلاَةُ فِي الْمَسْجِدِ قَالَ ‏ "‏ أَلاَ تَرَى إِلَى بَيْتِي مَا أَقْرَبَهُ مِنَ الْمَسْجِدِ فَلأَنْ أُصَلِّيَ فِي بَيْتِي أَحَبُّ إِلَىَّ مِنْ أَنْ أُصَلِّيَ فِي الْمَسْجِدِ إِلاَّ أَنْ تَكُونَ صَلاَةً مَكْتُوبَةً ‏"‏ ‏.‏\hadithno{1378}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Abdullah bin Sa’d said:“I asked the Messenger of Allah (ﷺ): ‘Which is better prayer in my house or prayer in the mosque?’ He said: ‘Do you not see how close my house is to the mosque?’ But praying in my house is dearer to me than praying in the mosque, apart from the prescribed prayers.’”}}
\hadithdefcmd{ibnmajah}{1379}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، قَالَ سَأَلْتُ فِي زَمَنِ عُثْمَانَ بْنِ عَفَّانَ وَالنَّاسُ مُتَوَافِرُونَ - أَوْ مُتَوَافُونَ - عَنْ صَلاَةِ الضُّحَى، فَلَمْ أَجِدْ أَحَدًا يُخْبِرُنِي أَنَّهُ صَلاَّهَا - يَعْنِي النَّبِيَّ ـ صلى الله عليه وسلم ـ - غَيْرَ أُمِّ هَانِئٍ فَأَخْبَرَتْنِي أَنَّهُ صَلاَّهَا ثَمَانِيَ رَكَعَاتٍ ‏.‏\hadithno{1379}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin Harith said:“During the caliphate of ‘Uthman, when the people were present in large numbers, I asked about Duha prayer, and I could not find anyone who could tell me that he, meaning the Prophet (ﷺ), had prayed it, apart from Umm Hani’. She told me that he had prayed it with eight Rak’ah.”}}
\hadithdefcmd{ibnmajah}{1380}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ ثُمَامَةَ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ صَلَّى الضُّحَى ثِنْتَىْ عَشْرَةَ رَكْعَةً بَنَى اللَّهُ لَهُ قَصْرًا مِنْ ذَهَبٍ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1380}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“I heard the Messenger of Allah (ﷺ) say: ‘Whoever prays Duha with twelve Rak’ah, Allah will build for him a palace of gold in Paradise.’”}}
\hadithdefcmd{ibnmajah}{1381}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ الرِّشْكِ، عَنْ مُعَاذَةَ الْعَدَوِيَّةِ، قَالَتْ سَأَلْتُ عَائِشَةَ أَكَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي الضُّحَى قَالَتْ نَعَمْ أَرْبَعًا وَيَزِيدُ مَا شَاءَ اللَّهُ ‏.‏\hadithno{1381}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Mu’adhah Al-‘Adawiyyah said:“I asked ‘Aishah: ‘Did the Prophet (ﷺ) pray Duha?’ She said: ‘Yes; four (Rak’ah) and he would add whatever Allah willed.’”}}
\hadithdefcmd{ibnmajah}{1382}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنِ النَّهَّاسِ بْنِ قَهْمٍ، عَنْ شَدَّادٍ أَبِي عَمَّارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ حَافَظَ عَلَى شُفْعَةِ الضُّحَى غُفِرَتْ لَهُ ذُنُوبُهُ وَإِنْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{1382}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever regularly prays two Rak’ah of Duha, his sins will be forgiven even if they are like the foam of the sea.’”}}
\hadithdefcmd{ibnmajah}{1383}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ الْمُنْكَدِرِ، يُحَدِّثُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُعَلِّمُنَا الاِسْتِخَارَةَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ ‏ "‏ إِذَا هَمَّ أَحَدُكُمْ بِالأَمْرِ فَلْيَرْكَعْ رَكْعَتَيْنِ مِنْ غَيْرِ الْفَرِيضَةِ ثُمَّ لْيَقُلِ اللَّهُمَّ إِنِّي أَسْتَخِيرُكَ بِعِلْمِكَ وَأَسْتَقْدِرُكَ بِقُدْرَتِكَ وَأَسْأَلُكَ مِنْ فَضْلِكَ الْعَظِيمِ فَإِنَّكَ تَقْدِرُ وَلاَ أَقْدِرُ وَتَعْلَمُ وَلاَ أَعْلَمُ وَأَنْتَ عَلاَّمُ الْغُيُوبِ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ هَذَا الأَمْرَ - فَيُسَمِّيهِ مَا كَانَ مِنْ شَىْءٍ - خَيْرًا لِي فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي - أَوْ خَيْرًا لِي فِي عَاجِلِ أَمْرِي وَآجِلِهِ - فَاقْدُرْهُ لِي وَيَسِّرْهُ لِي وَبَارِكْ لِي فِيهِ وَإِنْ كُنْتَ تَعْلَمُ - يَقُولُ مِثْلَ مَا قَالَ فِي الْمَرَّةِ الأُولَى - وَإِنْ كَانَ شَرًّا لِي فَاصْرِفْهُ عَنِّي وَاصْرِفْنِي عَنْهُ وَاقْدُرْ لِيَ الْخَيْرَ حَيْثُمَا كَانَ ثُمَّ رَضِّنِي بِهِ ‏"‏ ‏.‏\hadithno{1383}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) used to teach us Istikharah, just as he used to teach us a Surah of the Qur’an. He said: ‘If anyone of you is deliberating about a decision he has to make, then let him pray two Rak’ah of non- obligatory prayer, then say: Allahumma inni astakhiruka bi ‘ilmika wa astaqdiruka bi qudratika wa as’aluka min fadlikal-‘azim, fa innaka taqdiru wa la aqdir, wa ta’lamu wa la a’lam, wa Anta ‘allamul-ghuyub. Allahumma in kunta ta’lamu hadhal-amra (then the matter should be mentioned by name) ma kan min shay’in khairan li fi dini wa ma’ashi wa ‘aqibati amri, aw khairanli fi ‘ajili amri wa ajilihi, faqdurhu li wa yassirhu li wa barik li fihi. Wa in kunta ta’lamu [O Allah, I seek Your guidance (in making a choice) by virtue of Your knowledge, and I seek ability by virtue of Your power, and I ask You of Your great bounty. You have power, I have none. And You know, I know not. You are the Knower of hidden things. O Allah, if in Your knowledge, this matter (then it should be mentioned by name) is good for me in my religion, my livelihood and my affairs, or both in this world and in the Hereafter then ordain it for me, make it easy for me, and bless it for me. And if in Your knowledge]. Then saying similar to what he said the first time, except: Wa in kana sharran li fasrifhu ‘anni wasrifni ‘anhu waqdur li al-khair haithuma kana thumma raddini bihi (If it is bad for me then turn it away from me and turn me away from it, and ordain for me the good wherever it may be and make me pleased with it).’”}}
\hadithdefcmd{ibnmajah}{1384}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَاصِمٍ الْعَبَّادَانِيُّ، عَنْ فَائِدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى الأَسْلَمِيِّ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ مَنْ كَانَتْ لَهُ حَاجَةٌ إِلَى اللَّهِ أَوْ إِلَى أَحَدٍ مِنْ خَلْقِهِ فَلْيَتَوَضَّأْ وَلْيُصَلِّ رَكْعَتَيْنِ ثُمَّ لْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ الْحَلِيمُ الْكَرِيمُ سُبْحَانَ اللَّهِ رَبِّ الْعَرْشِ الْعَظِيمِ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ اللَّهُمَّ إِنِّي أَسْأَلُكَ مُوجِبَاتِ رَحْمَتِكَ وَعَزَائِمَ مَغْفِرَتِكَ وَالْغَنِيمَةَ مِنْ كُلِّ بِرٍّ وَالسَّلاَمَةَ مِنْ كُلِّ إِثْمٍ أَسْأَلُكَ أَلاَّ تَدَعَ لِي ذَنْبًا إِلاَّ غَفَرْتَهُ وَلاَ هَمًّا إِلاَّ فَرَّجْتَهُ وَلاَ حَاجَةً هِيَ لَكَ رِضًا إِلاَّ قَضَيْتَهَا لِي ثُمَّ يَسْأَلُ اللَّهَ مِنْ أَمْرِ الدُّنْيَا وَالآخِرَةِ مَا شَاءَ فَإِنَّهُ يُقَدَّرُ ‏"‏ ‏.‏\hadithno{1384}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin Abi Awfa Al-Aslami said:“The Messenger of Allah (ﷺ) came out to us and said: ‘Whoever has some need from Allah or from any of His creation, let him perform ablution and pray two Rak’ah, then let him say: La ilaha illallahul-Halimul- Karim. Subhan-Allahi Rabbil-‘arshil-‘azim. Al-hamdu Lillahi Rabbil-‘Alamin. Allahumma inni as’aluka mujibat rahmatika, wa ‘aza’ima maghfiratika, wal-ghanimata min kulli birrin, was-salamata min kulli ithmnin. As’aluka alla tada’a li dhanban illa ghafartahu, wa la hamman illa farrajtahu, wa la hajah hiya laka ridan illa qadaitaha li (None has the right to be worshipped but Allah, the Forbearing, the Most Generous. Glory is to Allah, the Lord of the Mighty Throne. Praise is to Allah, the Lord of the worlds. O Allah, I ask You for the means of Your mercy and forgiveness, the benefit of every good deed and safety from all sins. I ask You not to leave any sin of mine but You forgive it, or any distress but You relieve it, or any need that is pleasing to You but You meet it). Then he should ask Allah for whatever he wants in this world and in the Hereafter, for it is decreed.”}}
\hadithdefcmd{ibnmajah}{1385}{حَدَّثَنَا أَحْمَدُ بْنُ مَنْصُورِ بْنِ سَيَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي جَعْفَرٍ الْمَدَنِيِّ، عَنْ عُمَارَةَ بْنِ خُزَيْمَةَ بْنِ ثَابِتٍ، عَنْ عُثْمَانَ بْنِ حُنَيْفٍ، أَنَّ رَجُلاً، ضَرِيرَ الْبَصَرِ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ادْعُ اللَّهَ لِي أَنْ يُعَافِيَنِي ‏.‏ فَقَالَ ‏"‏ إِنْ شِئْتَ أَخَّرْتُ لَكَ وَهُوَ خَيْرٌ وَإِنْ شِئْتَ دَعَوْتُ ‏"‏ ‏.‏ فَقَالَ ادْعُهْ ‏.‏ فَأَمَرَهُ أَنْ يَتَوَضَّأَ فَيُحْسِنَ وُضُوءَهُ وَيُصَلِّيَ رَكْعَتَيْنِ وَيَدْعُوَ بِهَذَا الدُّعَاءِ ‏"‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ وَأَتَوَجَّهُ إِلَيْكَ بِمُحَمَّدٍ نَبِيِّ الرَّحْمَةِ يَا مُحَمَّدُ إِنِّي قَدْ تَوَجَّهْتُ بِكَ إِلَى رَبِّي فِي حَاجَتِي هَذِهِ لِتُقْضَى اللَّهُمَّ فَشَفِّعْهُ فِيَّ ‏"‏ ‏.‏\hadithno{1385}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Uthman bin Hunaif that a blind man came to the Prophet (ﷺ) and said:“Pray to Allah to heal me.” He said: “If you wish to store your reward for the Hereafter, that is better, or if you wish, I will supplicate for you.” He said: “Supplicate.” So he told him to perform ablution and do it well, and to pray two Rak’ah, and to say this supplication: “Allahumma inni as’aluka wa atawajjahu ilaika bimuhammadin nabiyyir-rahmah. Ya Muhammadu inni qad tawajjahtu bika ila rabbi fi hajati hadhihi lituqda. Allahumma fashaffi’hu fiya (O Allah, I ask of You and I turn my face towards You by virtue of the intercession of Muhammad the Prophet of mercy. O Muhammad, I have turned to my Lord by virtue of your intercession concerning this need of mine so that it may be met. O Allah, accept his intercession concerning me)”}}
\hadithdefcmd{ibnmajah}{1386}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ أَبُو عِيسَى الْمَسْرُوقِيُّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا مُوسَى بْنُ عُبَيْدَةَ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، مَوْلَى أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ عَنْ أَبِي رَافِعٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِلْعَبَّاسِ ‏"‏ يَا عَمِّ أَلاَ أَحْبُوكَ أَلاَ أَنْفَعُكَ أَلاَ أَصِلُكَ ‏"‏ قَالَ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ تُصَلِّي أَرْبَعَ رَكَعَاتٍ تَقْرَأُ فِي كُلِّ رَكْعَةٍ بِفَاتِحَةِ الْكِتَابِ وَسُورَةٍ فَإِذَا انْقَضَتِ الْقِرَاءَةُ فَقُلْ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ خَمْسَ عَشْرَةَ مَرَّةً قَبْلَ أَنْ تَرْكَعَ ثُمَّ ارْكَعْ فَقُلْهَا عَشْرًا ثُمَّ ارْفَعْ رَأْسَكَ فَقُلْهَا عَشْرًا ثُمَّ اسْجُدْ فَقُلْهَا عَشْرًا ثُمَّ ارْفَعْ رَأْسَكَ فَقُلْهَا عَشْرًا ثُمَّ اسْجُدْ فَقُلْهَا عَشْرًا ثُمَّ ارْفَعْ رَأْسَكَ فَقُلْهَا عَشْرًا قَبْلَ أَنْ تَقُومَ فَتِلْكَ خَمْسٌ وَسَبْعُونَ فِي كُلِّ رَكْعَةٍ وَهِيَ ثَلاَثُمِائَةٍ فِي أَرْبَعِ رَكَعَاتٍ فَلَوْ كَانَتْ ذُنُوبُكَ مِثْلَ رَمْلِ عَالِجٍ غَفَرَهَا اللَّهُ لَكَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ وَمَنْ لَمْ يَسْتَطِعْ يَقُولُهَا فِي يَوْمٍ قَالَ ‏"‏ قُلْهَا فِي جُمُعَةٍ فَإِنْ لَمْ تَسْتَطِعْ فَقُلْهَا فِي شَهْرٍ ‏"‏ ‏.‏ حَتَّى قَالَ ‏"‏ فَقُلْهَا فِي سَنَةٍ ‏"‏ ‏.‏\hadithno{1386}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Rafi’ said:“The Messenger of Allah (ﷺ) said to ‘Abbas: ‘O uncle, shall I not give you a gift, shall I not benefit you, shall I not uphold my ties of kinship with you?’ He said: ‘Of course, O Messenger of Allah.’ He said: ‘Pray four Rak’ah, and recite in each Rak’ah the Opening of the Book (Al-Fatihah) and a Surah. When you have finished reciting, say: Subhan-Allah wal-hamdu Lillah wa la ilaha illallah wa Allahu Akbar (Glory is to Allah, praise is to Allah, none has the right to be worshipped but Allah and Allah is the Most Great) fifteen times before you bow in Ruku’. Then bow and say it ten times; then raise your head and say it ten times; then prostrate and say it ten times; then raise your head and say it ten times; then prostrate and say it ten times; then raise your head and say it ten times before you stand up. That wil be seventy-five times in each Rak’ah and three hundred times in the four Rak’ah, and even if your sins are like the grains of sand, Allah will forgive you for them.’ He said: ‘O Messenger of Allah, what if someone cannot say it in one day?’ He said: ‘Then say it once in a week; if you cannot, then say it once in a month’ until he said: ‘Once in a year.’”}}
\hadithdefcmd{ibnmajah}{1387}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرِ بْنِ الْحَكَمِ النَّيْسَابُورِيُّ، حَدَّثَنَا مُوسَى بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا الْحَكَمُ بْنُ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِلْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ ‏ "‏ يَا عَبَّاسُ يَا عَمَّاهُ أَلاَ أُعْطِيكَ أَلاَ أَمْنَحُكَ أَلاَ أَحْبُوكَ أَلاَ أَفْعَلُ لَكَ عَشْرَ خِصَالٍ إِذَا أَنْتَ فَعَلْتَ ذَلِكَ غَفَرَ اللَّهُ لَكَ ذَنْبَكَ أَوَّلَهُ وَآخِرَهُ وَقَدِيمَهُ وَحَدِيثَهُ وَخَطَأَهُ وَعَمْدَهُ وَصَغِيرَهُ وَكَبِيرَهُ وَسِرَّهُ وَعَلاَنِيَتَهُ عَشْرُ خِصَالٍ أَنْ تُصَلِّيَ أَرْبَعَ رَكَعَاتٍ تَقْرَأُ فِي كُلِّ رَكْعَةٍ بِفَاتِحَةِ الْكِتَابِ وَسُورَةٍ فَإِذَا فَرَغْتَ مِنَ الْقِرَاءَةِ فِي أَوَّلِ رَكْعَةٍ قُلْتَ وَأَنْتَ قَائِمٌ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ خَمْسَ عَشْرَةَ مَرَّةً ثُمَّ تَرْكَعُ فَتَقُولُ وَأَنْتَ رَاكِعٌ عَشْرًا ثُمَّ تَرْفَعُ رَأْسَكَ مِنَ الرُّكُوعِ فَتَقُولُهَا عَشْرًا ثُمَّ تَهْوِي سَاجِدًا فَتَقُولُهَا وَأَنْتَ سَاجِدٌ عَشْرًا ثُمَّ تَرْفَعُ رَأْسَكَ مِنَ السُّجُودِ فَتَقُولُهَا عَشْرًا ثُمَّ تَسْجُدُ فَتَقُولُهَا عَشْرًا ثُمَّ تَرْفَعُ رَأْسَكَ مِنَ السُّجُودِ فَتَقُولُهَا عَشْرًا فَذَلِكَ خَمْسَةٌ وَسَبْعُونَ فِي كُلِّ رَكْعَةٍ تَفْعَلُ فِي أَرْبَعِ رَكَعَاتٍ إِنِ اسْتَطَعْتَ أَنْ تُصَلِّيَهَا فِي كُلِّ يَوْمٍ مَرَّةً فَافْعَلْ فَإِنْ لَمْ تَسْتَطِعْ فَفِي كُلِّ جُمُعَةٍ مَرَّةً فَإِنْ لَمْ تَفْعَلْ فَفِي كُلِّ شَهْرٍ مَرَّةً فَإِنْ لَمْ تَفْعَلْ فَفِي عُمُرِكَ مَرَّةً ‏"‏ ‏.‏\hadithno{1387}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) said to ‘Abbas bin ‘Abdul-Muttalib: ‘O ‘Abbas, O my uncle, shall I not give you a gift, shall I not give you something, shall I not tell you of something which, if you do it, will expiate for ten types of sins? If you do them, Allah will forgive you your sins, the first and the last of them, the old and the new, the unintentional and the deliberate, the minor and the major, the secret and the open, ten types of sin. Pray four Rak’ah, and recite in each Rak’ah the Opening of the Book (Al-Fatihah) and a Surah. When you have finished reciting in the first Rak’ah, while you are standing, say: Subhan-Allah wal- hamdu Lillah wa la ilaha illallah wa Allahu Akbar (Glory if to Allah, praise is to Allah, none has the right to be worshipped but Allah and Allah is the Most Great) fifteen times. Then bow and say it ten times while you are bowing. Then raise your head from Ruku’ and say it ten times. Then go into prostration and say it ten times while you are prostrating. Then raise your head from prostration and say it ten times. Then prostrate and say it ten times. Then raise your head from prostration and say it ten times. That will be seventy-five times in each Rak’ah. Do that in all four Rak’ah. If you can pray it once each day then do so. If you cannot, then once each week; if you cannot, then once each month. If you cannot, then once in your lifetime.’”}}
\hadithdefcmd{ibnmajah}{1388}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا ابْنُ أَبِي سَبْرَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدٍ، عَنْ مُعَاوِيَةَ بْنِ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا كَانَتْ لَيْلَةُ النِّصْفِ مِنْ شَعْبَانَ فَقُومُوا لَيْلَهَا وَصُومُوا يَوْمَهَا ‏.‏ فَإِنَّ اللَّهَ يَنْزِلُ فِيهَا لِغُرُوبِ الشَّمْسِ إِلَى سَمَاءِ الدُّنْيَا فَيَقُولُ أَلاَ مِنْ مُسْتَغْفِرٍ فَأَغْفِرَ لَهُ أَلاَ مُسْتَرْزِقٌ فَأَرْزُقَهُ أَلاَ مُبْتَلًى فَأُعَافِيَهُ أَلاَ كَذَا أَلاَ كَذَا حَتَّى يَطْلُعَ الْفَجْرُ ‏"‏ ‏.‏\hadithno{1388}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali bin Abu Talib said:“The Messenger of Allah (ﷺ) said: ‘When it is the night of the middle of Sha’ban, spend its night in prayer and observe a fast on that day. For Allah descends at sunset on that night to the lowest heaven and says: ‘Is there no one who will ask Me for forgiveness, that I may forgive him? Is there no one who will ask Me for provision, that I may provide for him? Is there no one who is afflicted by trouble, that I may relieve him?’ And so on, until dawn comes.’”}}
\hadithdefcmd{ibnmajah}{1389}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ، وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ أَبُو بَكْرٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَجَّاجٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ فَقَدْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ ذَاتَ لَيْلَةٍ فَخَرَجْتُ أَطْلُبُهُ فَإِذَا هُوَ بِالْبَقِيعِ رَافِعٌ رَأْسَهُ إِلَى السَّمَاءِ فَقَالَ ‏"‏ يَا عَائِشَةُ أَكُنْتِ تَخَافِينَ أَنْ يَحِيفَ اللَّهُ عَلَيْكِ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَتْ قَدْ قُلْتُ وَمَا بِي ذَلِكَ وَلَكِنِّي ظَنَنْتُ أَنَّكَ أَتَيْتَ بَعْضَ نِسَائِكَ ‏.‏ فَقَالَ ‏"‏ إِنَّ اللَّهَ تَعَالَى يَنْزِلُ لَيْلَةَ النِّصْفِ مِنْ شَعْبَانَ إِلَى السَّمَاءِ الدُّنْيَا فَيَغْفِرُ لأَكْثَرَ مِنْ عَدَدِ شَعَرِ غَنَمِ كَلْبٍ ‏"‏ ‏.‏\hadithno{1389}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“I missed the Prophet (ﷺ) one night, so I went out looking for him. I found him at Al-Baqi’, raising his head towards the sky. He said: ‘O ‘Aishah, were you afraid that Allah and His Messenger would wrong you?’” She said: “I said: ‘No, it is not that, but I thought that you had gone to one of your other wives.’ He said: ‘Allah descends on the night of the middle of Sha’ban to the lowest heaven, and He forgives more than the numbers of hairs on the sheep of Banu Kalb.’”}}
\hadithdefcmd{ibnmajah}{1390}{حَدَّثَنَا رَاشِدُ بْنُ سَعِيدِ بْنِ رَاشِدٍ الرَّمْلِيُّ، حَدَّثَنَا الْوَلِيدُ، عَنِ ابْنِ لَهِيعَةَ، عَنِ الضَّحَّاكِ بْنِ أَيْمَنَ، عَنِ الضَّحَّاكِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَرْزَبٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ لَيَطَّلِعُ فِي لَيْلَةِ النِّصْفِ مِنْ شَعْبَانَ فَيَغْفِرُ لِجَمِيعِ خَلْقِهِ إِلاَّ لِمُشْرِكٍ أَوْ مُشَاحِنٍ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو الأَسْوَدِ النَّضْرُ بْنُ عَبْدِ الْجَبَّارِ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنِ الزُّبَيْرِ بْنِ سُلَيْمٍ، عَنِ الضَّحَّاكِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبَا مُوسَى، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1390}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Musa Al-Ash’ari that the Messenger of Allah (ﷺ) said:“Allah looks down on the night of the middle of Sha’ban and forgives all His creation, apart from the idolater and the Mushahin.” Another chain from Abu Musa, from the Prophet (ﷺ) with similar wording}}
\hadithdefcmd{ibnmajah}{1391}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا سَلَمَةُ بْنُ رَجَاءٍ، حَدَّثَتْنِي شَعْثَاءُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى يَوْمَ بُشِّرَ بِرَأْسِ أَبِي جَهْلٍ رَكْعَتَيْنِ ‏.‏\hadithno{1391}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin Abu Awfa that the Messenger of Allah (ﷺ) prayed two Rak’ah on the day when he was given the glad tidings of the head (death) of Abu Jahl}}
\hadithdefcmd{ibnmajah}{1392}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ صَالِحٍ الْمِصْرِيُّ، أَنْبَأَنَا أَبِي، أَنْبَأَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَمْرِو بْنِ الْوَلِيدِ بْنِ عَبْدَةَ السَّهْمِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ بُشِّرَ بِحَاجَةٍ فَخَرَّ سَاجِدًا ‏.‏\hadithno{1392}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) was given glad tidings that a need of his had been met, and he fell down prostrate}}
\hadithdefcmd{ibnmajah}{1393}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ لَمَّا تَابَ اللَّهُ عَلَيْهِ خَرَّ سَاجِدًا ‏.‏\hadithno{1393}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Ka’b bin Malik that his father said that when Allah accepted his repentance, he fell down prostrate}}
\hadithdefcmd{ibnmajah}{1394}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ، وَأَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ بَكَّارِ بْنِ عَبْدِ الْعَزِيزِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أَتَاهُ أَمْرٌ يَسُرُّهُ أَوْ يُسَرُّ بِهِ خَرَّ سَاجِدًا شُكْرًا لِلَّهِ تَبَارَكَ وَتَعَالَى ‏.‏\hadithno{1394}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Bakrah that when the Prophet (ﷺ) heard news that made him happy, or for which one should be happy, he would fall down prostrate in gratitude to Allah, the Blessed and Exalted}}
\hadithdefcmd{ibnmajah}{1395}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَنَصْرُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مِسْعَرٌ، وَسُفْيَانُ، عَنْ عُثْمَانَ بْنِ الْمُغِيرَةِ الثَّقَفِيِّ، عَنْ عَلِيِّ بْنِ رَبِيعَةَ الْوَالِبِيِّ، عَنْ أَسْمَاءَ بْنِ الْحَكَمِ الْفَزَارِيِّ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كُنْتُ إِذَا سَمِعْتُ مِنْ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَدِيثًا يَنْفَعُنِي اللَّهُ بِمَا شَاءَ مِنْهُ وَإِذَا حَدَّثَنِي عَنْهُ غَيْرُهُ اسْتَحْلَفْتُهُ فَإِذَا حَلَفَ صَدَّقْتُهُ وَإِنَّ أَبَا بَكْرٍ حَدَّثَنِي وَصَدَقَ أَبُو بَكْرٍ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ رَجُلٍ يُذْنِبُ ذَنْبًا فَيَتَوَضَّأُ فَيُحْسِنُ الْوُضُوءَ ثُمَّ يُصَلِّي رَكْعَتَيْنِ - وَقَالَ مِسْعَرٌ ثُمَّ يُصَلِّي - وَيَسْتَغْفِرُ اللَّهَ إِلاَّ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏\hadithno{1395}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Ali bin Abu Talib said:“If I heard a Hadith from the Messenger of Allah (ﷺ), Allah benefitted me with it as much as He willed, and if I heard it from anyone else, I would ask him to swear me an oath, then if he swore an oath I would believe him. Abu Bakr told me and Abu Bakr spoke the truth that the Messenger of Allah (ﷺ) said: ‘There is no man who commits a sin then he performs ablution and does it well, then he prays two Rak’ah,’ (one of the narrators) Mis’ar said: ‘then performs prayer and seeks the forgiveness of Allah, but Allah will forgive him.’}}
\hadithdefcmd{ibnmajah}{1396}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ سُفْيَانَ بْنِ عَبْدِ اللَّهِ، - أَظُنُّهُ - عَنْ عَاصِمِ بْنِ سُفْيَانَ الثَّقَفِيِّ، أَنَّهُمْ غَزَوْا غَزْوَةَ السَّلاَسِلِ فَفَاتَهُمُ الْغَزْوُ فَرَابَطُوا ثُمَّ رَجَعُوا إِلَى مُعَاوِيَةَ وَعِنْدَهُ أَبُو أَيُّوبَ وَعُقْبَةُ بْنُ عَامِرٍ فَقَالَ عَاصِمٌ يَا أَبَا أَيُّوبَ فَاتَنَا الْغَزْوُ الْعَامَ وَقَدْ أُخْبِرْنَا أَنَّهُ مَنْ صَلَّى فِي الْمَسَاجِدِ الأَرْبَعَةِ غُفِرَ لَهُ ذَنْبُهُ ‏.‏ فَقَالَ يَا ابْنَ أَخِي أَدُلُّكَ عَلَى أَيْسَرَ مِنْ ذَلِكَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ تَوَضَّأَ كَمَا أُمِرَ وَصَلَّى كَمَا أُمِرَ غُفِرَ لَهُ مَا قَدَّمَ مِنْ عَمَلٍ ‏"‏ ‏.‏ أَكَذَلِكَ يَا عُقْبَةُ قَالَ نَعَمْ ‏.‏\hadithno{1396}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Asim bin Sufyan Thaqafi that they went on the campaign of Salasil, but no battle took place; they only took up their positions. Then they came back to Mu’awiyah, and Abu Ayyub and ‘Uqbah bin ‘Amir were with him. ‘Asim said:“O Abu Ayyub, we have missed out on Jihad this year, and we were told that whoever prays in the four mosques will be forgiven his sins.” He said: “O son of my brother, shall I not tell you of something easier than that? I heard the Messenger of Allah (ﷺ) say: ‘Whoever performs ablution as he has been commanded, and prays as he has been commanded, will be forgiven his previous (bad) deeds.’” He said: “(Did he not say it) like that, O ‘Uqbah?” He said: “Yes.”}}
\hadithdefcmd{ibnmajah}{1397}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنِي ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، حَدَّثَنِي صَالِحُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي فَرْوَةَ، أَنَّ عَامِرَ بْنَ سَعْدٍ، أَخْبَرَهُ قَالَ سَمِعْتُ أَبَانَ بْنَ عُثْمَانَ، يَقُولُ قَالَ عُثْمَانُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ أَرَأَيْتَ لَوْ كَانَ بِفِنَاءِ أَحَدِكُمْ نَهْرٌ يَجْرِي يَغْتَسِلُ فِيهِ كُلَّ يَوْمٍ خَمْسَ مَرَّاتٍ مَا كَانَ يَبْقَى مِنْ دَرَنِهِ ‏"‏ قَالَ لاَ شَىْءَ ‏.‏ قَالَ ‏"‏ فَإِنَّ الصَّلاَةَ تُذْهِبُ الذُّنُوبَ كَمَا يُذْهِبُ الْمَاءُ الدَّرَنَ ‏"‏ ‏.‏\hadithno{1397}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Uthman said:“I heard the Messenger of Allah (ﷺ) say: ‘Do you think that if there was a river in the courtyard of anyone of you, and he bathed in it five times each day, would there be any dirt left on him?’ They said: ‘(There would be) nothing.’ He said: ‘Prayer takes away sins like water takes away dirt.’”}}
\hadithdefcmd{ibnmajah}{1398}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَجُلاً، أَصَابَ مِنِ امْرَأَةٍ يَعْنِي مَا دُونَ الْفَاحِشَةِ فَلاَ أَدْرِي مَا بَلَغَ غَيْرَ أَنَّهُ دُونَ الزِّنَا فَأَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَذَكَرَ ذَلِكَ لَهُ فَأَنْزَلَ اللَّهُ سُبْحَانَهُ ‏\{أَقِمِ الصَّلاَةَ طَرَفَىِ النَّهَارِ وَزُلَفًا مِنَ اللَّيْلِ إِنَّ الْحَسَنَاتِ يُذْهِبْنَ السَّيِّئَاتِ ذَلِكَ ذِكْرَى لِلذَّاكِرِينَ\}‏ فَقَالَ يَا رَسُولَ اللَّهِ أَلِي هَذِهِ قَالَ ‏ "‏ لِمَنْ أَخَذَ بِهَا ‏"‏ ‏.‏\hadithno{1398}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that a man did something with a woman that was less than adultery; I do not know how far it went, but it was less than adultery. He went to the Prophet (ﷺ) and told him about that. Then Allah revealed the words:“And perform the prayer, at the two ends of the day and in some hours of the night. Verily, the good deeds remove the evil deeds. That is a reminder for the mindful.” [11:114] He said: “O Messenger of Allah, is this only for me?” He said: “It is for everyone who acts upon it.”}}
\hadithdefcmd{ibnmajah}{1399}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ فَرَضَ اللَّهُ عَلَى أُمَّتِي خَمْسِينَ صَلاَةً فَرَجَعْتُ بِذَلِكَ ‏.‏ حَتَّى آتِيَ عَلَى مُوسَى فَقَالَ مُوسَى مَاذَا افْتَرَضَ رَبُّكَ عَلَى أُمَّتِكَ قُلْتُ فَرَضَ عَلَىَّ خَمْسِينَ صَلاَةً ‏.‏ قَالَ فَارْجِعْ إِلَى رَبِّكَ فَإِنَّ أُمَّتَكَ لاَ تُطِيقُ ذَلِكَ ‏.‏ فَرَاجَعْتُ رَبِّي فَوَضَعَ عَنِّي شَطْرَهَا فَرَجَعْتُ إِلَى مُوسَى فَأَخْبَرْتُهُ فَقَالَ ارْجِعْ إِلَى رَبِّكَ فَإِنَّ أُمَّتَكَ لاَ تُطِيقُ ذَلِكَ ‏.‏ فَرَاجَعْتُ رَبِّي فَقَالَ هِيَ خَمْسٌ وَهِيَ خَمْسُونَ لاَ يُبَدَّلُ الْقَوْلُ لَدَىَّ ‏.‏ فَرَجَعْتُ إِلَى مُوسَى فَقَالَ ارْجِعْ إِلَى رَبِّكَ ‏.‏ فَقُلْتُ قَدِ اسْتَحْيَيْتُ مِنْ رَبِّي ‏"‏ ‏.‏\hadithno{1399}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) said: ‘Allah enjoined fifty prayers upon my nation, and I came back with that until I came to Musa. Musa said: ‘What has your Lord enjoined upon your nation?’ I said: ‘He has enjoined fifty prayers on me.’ He said: ‘Go back to your Lord, for your nation will not be able to do that.’ So I went back to my Lord, and He reduced it by half. I went back to Musa and told him, and he said: ‘Go back to your Lord, for your nation will not be able to do that.’ So I went back to my Lord, and He said: ‘They are five and they are fifty; My Word does not change.’ So I went back to Musa and he said: ‘Go back to your Lord.’ I said: ‘I feel shy before my Lord.’”}}
\hadithdefcmd{ibnmajah}{1400}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شَرِيكٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُصْمٍ أَبِي عُلْوَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُمِرَ نَبِيُّكُمْ ـ صلى الله عليه وسلم ـ بِخَمْسِينَ صَلاَةً فَنَازَلَ رَبَّكُمْ أَنْ يَجْعَلَهَا خَمْسَ صَلَوَاتٍ ‏.‏\hadithno{1400}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Your Prophet (ﷺ) was enjoined to do fifty prayers but he returned to your Lord to make (i.e., reduce) them to five prayers.”}}
\hadithdefcmd{ibnmajah}{1401}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، عَنِ الْمُخْدِجِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ خَمْسُ صَلَوَاتٍ افْتَرَضَهُنَّ اللَّهُ عَلَى عِبَادِهِ فَمَنْ جَاءَ بِهِنَّ لَمْ يَنْتَقِصْ مِنْهُنَّ شَيْئًا اسْتِخْفَافًا بِحَقِّهِنَّ فَإِنَّ اللَّهَ جَاعِلٌ لَهُ يَوْمَ الْقِيَامَةِ عَهْدًا أَنْ يُدْخِلَهُ الْجَنَّةَ وَمَنْ جَاءَ بِهِنَّ قَدِ انْتَقَصَ مِنْهُنَّ شَيْئًا اسْتِخْفَافًا بِحَقِّهِنَّ لَمْ يَكُنْ لَهُ عِنْدَ اللَّهِ عَهْدٌ إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ غَفَرَ لَهُ ‏"‏ ‏.‏\hadithno{1401}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Ubadah bin Samit said:“I heard the Messenger of Allah (ﷺ) say: ‘Five prayers that Allah has enjoined upon His slaves, so whoever does them, and does not omit anything out of negligence, on the Day of Resurrection Allah will make a covenant with him that He will admit him to Paradise. But whoever does them but omits something from them out of negligence, will not have such a covenant with Allah; if He wills He will punish him, and if He wills, He will forgive him.’”}}
\hadithdefcmd{ibnmajah}{1402}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ بَيْنَمَا نَحْنُ جُلُوسٌ فِي الْمَسْجِدِ دَخَلَ رَجُلٌ عَلَى رَحْلٍ فَأَنَاخَهُ فِي الْمَسْجِدِ ثُمَّ عَقَلَهُ ثُمَّ قَالَ لَهُمْ أَيُّكُمْ مُحَمَّدٌ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مُتَّكِئٌ بَيْنَ ظَهْرَانَيْهِمْ ‏.‏ قَالَ فَقَالُوا هَذَا الرَّجُلُ الأَبْيَضُ الْمُتَّكِئُ ‏.‏ فَقَالَ لَهُ الرَّجُلُ يَا ابْنَ عَبْدِ الْمُطَّلِبِ ‏.‏ فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ قَدْ أَجَبْتُكَ ‏"‏ ‏.‏ فَقَالَ لَهُ الرَّجُلُ يَا مُحَمَّدُ إِنِّي سَائِلُكَ وَمُشَدِّدٌ عَلَيْكَ فِي الْمَسْأَلَةِ فَلاَ تَجِدَنَّ عَلَىَّ فِي نَفْسِكَ ‏.‏ فَقَالَ ‏"‏ سَلْ مَا بَدَا لَكَ ‏"‏ ‏.‏ قَالَ لَهُ الرَّجُلُ نَشَدْتُكَ بِرَبِّكَ وَرَبِّ مَنْ قَبْلَكَ آللَّهُ أَرْسَلَكَ إِلَى النَّاسِ كُلِّهِمْ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ بِاللَّهِ آللَّهُ أَمَرَكَ أَنْ تُصَلِّيَ الصَّلَوَاتِ الْخَمْسَ فِي الْيَوْمِ وَاللَّيْلَةِ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ بِاللَّهِ آللَّهُ أَمَرَكَ أَنْ تَصُومَ هَذَا الشَّهْرَ مِنَ السَّنَةِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأَنْشُدُكَ بِاللَّهِ آللَّهُ أَمَرَكَ أَنْ تَأْخُذَ هَذِهِ الصَّدَقَةَ مِنْ أَغْنِيَائِنَا فَتَقْسِمَهَا عَلَى فُقَرَائِنَا فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ آمَنْتُ بِمَا جِئْتَ بِهِ وَأَنَا رَسُولُ مَنْ وَرَائِي مِنْ قَوْمِي ‏.‏ وَأَنَا ضِمَامُ بْنُ ثَعْلَبَةَ أَخُو بَنِي سَعْدِ بْنِ بَكْرٍ ‏.‏\hadithno{1402}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sharik bin ‘Abdullah bin Abu Namir that he heard Anas bin Malik say:“While we were sitting in the mosque, a man entered riding a camel; he made it kneel in the mosque, then he hobbled it and said to them: ‘Which of you is Muhammad?’ The Messenger of Allah (ﷺ) was reclining among them, so they said: ‘This fair- skinned man who is reclining.’ The man said to him: ‘O son of ‘Abdul- Muttalib!’ The Prophet (ﷺ) said: ‘I am listening to you.’ The man said: O Muhammad! I am asking you and will be stern in asking, so do not bear any ill-feelings towards me.’ He said: ‘Ask whatever you think.’ The man said: ‘I adjure you by your Lord and the Lord of those who came before you, has Allah sent you to all of mankind?’ The Messenger of Allah (ﷺ) said: ‘By Allah, yes.; He said: ‘I adjure you by Allah, has Allah commanded you to pray the five prayers each day and night?’ The Messenger of Allah (ﷺ) said: ‘By Allah, yes.’ He said: ‘I adjure you by Allah, has Allah commanded you to fast this month of each year?’ The Messenger of Allah (ﷺ) said: ‘By Allah, yes.’ He said: ‘I adjure you by Allah, has Allah commanded you to take this charity from our rich and distribute it among our poor?’ The Messenger of Allah (ﷺ) said: ‘By Allah, yes.’ The man said: ‘I believe in what you have brought, and I am the envoy of my people who are behind me. I am Dimam bin Tha’labah, the brother of Banu Sa’d bin Bakr.’”}}
\hadithdefcmd{ibnmajah}{1403}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، حَدَّثَنَا ضُبَارَةُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي السَّلِيلِ، أَخْبَرَنِي دُوَيْدُ بْنُ نَافِعٍ، عَنِ الزُّهْرِيِّ، قَالَ قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ إِنَّ أَبَا قَتَادَةَ بْنَ رِبْعِيٍّ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ افْتَرَضْتُ عَلَى أُمَّتِكَ خَمْسَ صَلَوَاتٍ وَعَهِدْتُ عِنْدِي عَهْدًا أَنَّهُ مَنْ حَافَظَ عَلَيْهِنَّ لِوَقْتِهِنَّ أَدْخَلْتُهُ الْجَنَّةَ وَمَنْ لَمْ يُحَافِظْ عَلَيْهِنَّ فَلاَ عَهْدَ لَهُ عِنْدِي ‏"‏ ‏.‏\hadithno{1403}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sa’eed bin Musayyab said that Abu Qatadah bin Rib’i told him that the Messenger of Allah (ﷺ) said:“Allah said: ‘I have enjoined on your nation five prayers, and I have made a covenant with Myself that whoever maintains them, I will admit them to Paradise, and whoever does not maintain them, has no such covenant with Me.’”}}
\hadithdefcmd{ibnmajah}{1404}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدِينِيُّ، أَحْمَدُ بْنُ أَبِي بَكْرٍ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ رَبَاحٍ، وَعُبَيْدِ اللَّهِ بْنِ أَبِي عَبْدِ اللَّهِ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ. إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏.‏ حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1404}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“One prayer in this mosque of mine is better than a thousand prayers anywhere else, except The Sacred Mosque (Al-Masjid Al-Haram).” (Another chain) from Abu Hurairah from the Prophet (ﷺ) with similar wording}}
\hadithdefcmd{ibnmajah}{1405}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏.‏\hadithno{1405}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) said:“One prayer in this mosque of mine is better than one thousand prayers in any other mosque except the Sacred Mosque.”}}
\hadithdefcmd{ibnmajah}{1406}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَسَدٍ، حَدَّثَنَا زَكَرِيَّا بْنُ عَدِيٍّ، أَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ. إِلاَّ الْمَسْجِدَ الْحَرَامَ. وَصَلاَةٌ فِي الْمَسْجِدِ الْحَرَامِ أَفْضَلُ مِنْ مِائَةِ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ ‏"‏ ‏.‏\hadithno{1406}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“One prayer in my mosque is better than one thousand prayers elsewhere, except the Sacred Mosque, and one prayer in the Sacred Mosque is better than one hundred thousand prayers elsewhere.”}}
\hadithdefcmd{ibnmajah}{1407}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، عَنْ زِيَادِ بْنِ أَبِي سَوْدَةَ، عَنْ أَخِيهِ، عُثْمَانَ بْنِ أَبِي سَوْدَةَ عَنْ مَيْمُونَةَ، مَوْلاَةِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَفْتِنَا فِي بَيْتِ الْمَقْدِسِ ‏.‏ قَالَ ‏"‏ أَرْضُ الْمَحْشَرِ وَالْمَنْشَرِ ائْتُوهُ فَصَلُّوا فِيهِ فَإِنَّ صَلاَةً فِيهِ كَأَلْفِ صَلاَةٍ فِي غَيْرِهِ ‏"‏ ‏.‏ قُلْتُ أَرَأَيْتَ إِنْ لَمْ أَسْتَطِعْ أَنْ أَتَحَمَّلَ إِلَيْهِ قَالَ ‏"‏ فَتُهْدِي لَهُ زَيْتًا يُسْرَجُ فِيهِ فَمَنْ فَعَلَ ذَلِكَ فَهُوَ كَمَنْ أَتَاهُ ‏"‏ ‏.‏\hadithno{1407}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Maimunah the freed (female) slave of the Prophet (ﷺ) said:I said: “O Messenger of Allah, tell us about Baitil- Maqdis.” He said: “It is the land of the Resurrection and the Gathering. Go and pray there, for one prayer there is like one thousand prayers elsewhere.” I said: “What if I cannot travel and go there?” He said: “Then send a gift of oil to light its lamps, for whoever does that is like one who goes there.”}}
\hadithdefcmd{ibnmajah}{1408}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ الْجَهْمِ الأَنْمَاطِيُّ، حَدَّثَنَا أَيُّوبُ بْنُ سُوَيْدٍ، عَنْ أَبِي زُرْعَةَ السَّيْبَانِيِّ، يَحْيَى بْنِ أَبِي عَمْرٍو حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الدَّيْلَمِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ لَمَّا فَرَغَ سُلَيْمَانُ بْنُ دَاوُدَ مِنْ بِنَاءِ بَيْتِ الْمَقْدِسِ سَأَلَ اللَّهَ ثَلاَثًا حُكْمًا يُصَادِفُ حُكْمَهُ وَمُلْكًا لاَ يَنْبَغِي لأَحَدٍ مِنْ بَعْدِهِ وَأَلاَّ يَأْتِيَ هَذَا الْمَسْجِدَ أَحَدٌ لاَ يُرِيدُ إِلاَّ الصَّلاَةَ فِيهِ إِلاَّ خَرَجَ مِنْ ذُنُوبِهِ كَيَوْمَ وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَمَّا اثْنَتَانِ فَقَدْ أُعْطِيَهُمَا وَأَرْجُو أَنْ يَكُونَ قَدْ أُعْطِيَ الثَّالِثَةَ ‏"‏ ‏.‏\hadithno{1408}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Prophet (ﷺ) said:“When Sulaiman bin Dawud finished building Baitil-Maqdis, he asked Allah for three things: judgment that was in harmony with His judgment, a dominion that no one after him would have, and that no one should come to this mosque, intending only to pray there, but he would emerge free of sin as the day his mother bore him.” The Prophet (ﷺ) said: “Two prayers were granted, and I hope that the third was also granted.”}}
\hadithdefcmd{ibnmajah}{1409}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِ الْحَرَامِ وَمَسْجِدِي هَذَا وَالْمَسْجِدِ الأَقْصَى ‏"‏ ‏.‏\hadithno{1409}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“No one should prepare a mount (travel) to visit any mosque except three: the Sacred Mosque, this mosque of mine, and Aqsa Mosque.”}}
\hadithdefcmd{ibnmajah}{1410}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي مَرْيَمَ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ، وَعَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ إِلَى الْمَسْجِدِ الْحَرَامِ وَإِلَى الْمَسْجِدِ الأَقْصَى وَإِلَى مَسْجِدِي هَذَا ‏"‏ ‏.‏\hadithno{1410}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Sa’eed and ‘Abdullah bin ‘Amr bin ‘As that the Messenger of Allah (ﷺ) said:“Do not prepare a mount (travel) to visit any mosque except three: the Sacred Mosque, Aqsa Mosque, and this mosque of mine.”}}
\hadithdefcmd{ibnmajah}{1411}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، حَدَّثَنَا أَبُو الأَبْرَدِ، مَوْلَى بَنِي خَطْمَةَ أَنَّهُ سَمِعَ أُسَيْدَ بْنَ ظُهَيْرٍ الأَنْصَارِيَّ، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ ـ صلى الله عليه وسلم ـ يُحَدِّثُ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِ قُبَاءٍ كَعُمْرَةٍ ‏"‏ ‏.‏\hadithno{1411}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Abul-Abrad, the freed slave of Banu Khatmah, said that he heard Usaid bin Zuhair Ansari who was one of the Companions of the Prophet (ﷺ) narrating that the Prophet (ﷺ) said:“One prayer in the Quba’ Mosque is like ‘Umrah.”}}
\hadithdefcmd{ibnmajah}{1412}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، وَعِيسَى بْنُ يُونُسَ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الْكِرْمَانِيُّ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ بْنَ سَهْلِ بْنِ حُنَيْفٍ، يَقُولُ قَالَ سَهْلُ بْنُ حُنَيْفٍ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَطَهَّرَ فِي بَيْتِهِ، ثُمَّ أَتَى مَسْجِدَ قُبَاءٍ، فَصَلَّى فِيهِ صَلاَةً، كَانَ لَهُ كَأَجْرِ عُمْرَةٍ ‏"‏ ‏.‏\hadithno{1412}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{(Sahl) bin Hunaif said:“The Messenger of Allah (ﷺ) said: ‘Whoever purifies himself in his house, then comes to the Quba’ Mosque and offers one prayer therein, will have a reward like that for ‘Umrah.”}}
\hadithdefcmd{ibnmajah}{1413}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا أَبُو الْخَطَّابِ الدِّمَشْقِيُّ، حَدَّثَنَا رُزَيْقٌ أَبُو عَبْدِ اللَّهِ الأَلْهَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلاَةُ الرَّجُلِ فِي بَيْتِهِ بِصَلاَةٍ وَصَلاَتُهُ فِي مَسْجِدِ الْقَبَائِلِ بِخَمْسٍ وَعِشْرِينَ صَلاَةً وَصَلاَتُهُ فِي الْمَسْجِدِ الَّذِي يُجَمَّعُ فِيهِ بِخَمْسِمِائَةِ صَلاَةٍ وَصَلاَةٌ فِي الْمَسْجِدِ الأَقْصَى بِخَمْسِينَ أَلْفِ صَلاَةٍ وَصَلاَةٌ فِي مَسْجِدِي بِخَمْسِينَ أَلْفِ صَلاَةٍ وَصَلاَةٌ فِي الْمَسْجِدِ الْحَرَامِ بِمِائَةِ أَلْفِ صَلاَةٍ ‏"‏ ‏.‏\hadithno{1413}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) said: ‘A man’s prayer in his house is equal (in reward) to one prayer; his prayer in the mosque of the tribes is equal to twenty-five prayers; his prayer in the mosque in which Friday prayer is offered is equal to five-hundred prayers; his prayer in Aqsa Mosque is equal to fifty thousand prayers; his prayer in my mosque is equal to fifty thousand prayers; and his prayer in the Sacred Mosque is equal to one hundred thousand prayers.”}}
\hadithdefcmd{ibnmajah}{1414}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو الرَّقِّيُّ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الطُّفَيْلِ بْنِ أُبَىِّ بْنِ كَعْبٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي إِلَى جِذْعٍ إِذْ كَانَ الْمَسْجِدُ عَرِيشًا وَكَانَ يَخْطُبُ إِلَى ذَلِكَ الْجِذْعِ فَقَالَ رَجُلٌ مِنْ أَصْحَابِهِ هَلْ لَكَ أَنْ نَجْعَلَ لَكَ شَيْئًا تَقُومُ عَلَيْهِ يَوْمَ الْجُمُعَةِ حَتَّى يَرَاكَ النَّاسُ وَتُسْمِعَهُمْ خُطْبَتَكَ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ فَصَنَعَ لَهُ ثَلاَثَ دَرَجَاتٍ فَهِيَ الَّتِي عَلَى الْمِنْبَرِ فَلَمَّا وُضِعَ الْمِنْبَرُ وَضَعُوهُ فِي مَوْضِعِهِ الَّذِي هُوَ فِيهِ فَلَمَّا أَرَادَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَقُومَ إِلَى الْمِنْبَرِ مَرَّ إِلَى الْجِذْعِ الَّذِي كَانَ يَخْطُبُ إِلَيْهِ فَلَمَّا جَاوَزَ الْجِذْعَ خَارَ حَتَّى تَصَدَّعَ وَانْشَقَّ فَنَزَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لَمَّا سَمِعَ صَوْتَ الْجِذْعِ فَمَسَحَهُ بِيَدِهِ حَتَّى سَكَنَ ثُمَّ رَجَعَ إِلَى الْمِنْبَرِ فَكَانَ إِذَا صَلَّى صَلَّى إِلَيْهِ فَلَمَّا هُدِمَ الْمَسْجِدُ وَغُيِّرَ أَخَذَ ذَلِكَ الْجِذْعَ أُبَىُّ بْنُ كَعْبٍ وَكَانَ عِنْدَهُ فِي بَيْتِهِ حَتَّى بَلِيَ فَأَكَلَتْهُ الأَرَضَةُ وَعَادَ رُفَاتًا ‏.‏\hadithno{1414}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Tufail bin Ubayy bin Ka’b that his father said:“The Messenger of Allah (ﷺ) used to pray facing the trunk of a date- palm tree when the mosque was still a hut, and he used to deliver the sermon leaning on that trunk. A man from among his Companions said: ‘Would you like us to make you something upon which you can stand on Fridays so that the people will be able to see you and hear your sermon?’ He said: ‘Yes.’ So he made three steps for him, as a pulpit. When they put the pulpit in place, they put it in the place where it stands now. When the Messenger of Allah (ﷺ) wanted to stand on the pulpit, he passed by the tree trunk from which he used to deliver the sermon, and when he went beyond the trunk, it moaned and split and cracked. The Messenger of Allah (ﷺ) came down when he heard the voice of the trunk, and rubbed it with his hand until it fell silent. Then he went back to the pulpit and when he prayed, he prayed facing it. When the mosque was knocked down (for renovation) and (the pillars, etc.) were changed, Ubayy bin Ka’b took that trunk and kept it in his house until it became very old and the termites consumed it and it became grains of dust.”}}
\hadithdefcmd{ibnmajah}{1415}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَمَّارِ بْنِ أَبِي عَمَّارٍ، عَنِ ابْنِ عَبَّاسٍ، ‏.‏ وَعَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَخْطُبُ إِلَى جِذْعٍ فَلَمَّا اتَّخَذَ الْمِنْبَرَ ذَهَبَ إِلَى الْمِنْبَرِ فَحَنَّ الْجِذْعُ فَأَتَاهُ فَاحْتَضَنَهُ فَسَكَنَ ‏.‏ فَقَالَ ‏ "‏ لَوْ لَمْ أَحْتَضِنْهُ لَحَنَّ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1415}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) used to deliver the sermon leaning on a tree trunk. When he started to use the pulpit, he went to the pulpit, and the trunk made a sorrowful sound. So he came to it and embraced it, and it calmed down. He said:“If I had not embraced it, it would have continued to grieve until the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{1416}{حَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي حَازِمٍ، قَالَ اخْتَلَفَ النَّاسُ فِي مِنْبَرِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ أَىِّ شَىْءٍ هُوَ فَأَتَوْا سَهْلَ بْنَ سَعْدٍ فَسَأَلُوهُ فَقَالَ مَا بَقِيَ أَحَدٌ مِنَ النَّاسِ أَعْلَمَ بِهِ مِنِّي هُوَ مِنْ أَثْلِ الْغَابَةِ عَمِلَهُ فُلاَنٌ مَوْلَى فُلاَنَةَ نَجَّارٌ فَجَاءَ بِهِ فَقَامَ عَلَيْهِ حِينَ وُضِعَ فَاسْتَقْبَلَ الْقِبْلَةَ وَقَامَ النَّاسُ خَلْفَهُ فَقَرَأَ ثُمَّ رَكَعَ ثُمَّ رَفَعَ رَأْسَهُ فَرَجَعَ الْقَهْقَرَى حَتَّى سَجَدَ بِالأَرْضِ ثُمَّ عَادَ إِلَى الْمِنْبَرِ فَقَرَأَ ثُمَّ رَكَعَ فَقَامَ ثُمَّ رَجَعَ الْقَهْقَرَى حَتَّى سَجَدَ بِالأَرْضِ ‏.‏\hadithno{1416}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hazim said:“The people differed concerning the pulpit of the Messenger of Allah (ﷺ) and what it was made of. So they came to Sahl bin Sa’d and asked him. He said: ‘There is no one left who knows more about that than I. It is made of tamarisk (a type of tree) from Ghabah. It was made by so-and-so, the freed slave of so- and-so (a woman), (who was) a carpenter. He brought it and he (the Prophet (ﷺ)) stood on it when it was put in position. He faced the Qiblah and the people stood behind him. He recited Qur’an, then bowed and raised his head, then he moved backwards until he prostrated on the ground, then he went back to the pulpit and recited Qur’an, then bowed and raised his head, then he moved backwards until he prostrated on the ground.”}}
\hadithdefcmd{ibnmajah}{1417}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُومُ فِي أَصْلِ شَجَرَةٍ - أَوْ قَالَ إِلَى جِذْعٍ - ثُمَّ اتَّخَذَ مِنْبَرًا ‏.‏ قَالَ فَحَنَّ الْجِذْعُ - قَالَ جَابِرٌ - حَتَّى سَمِعَهُ أَهْلُ الْمَسْجِدِ حَتَّى أَتَاهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَمَسَحَهُ فَسَكَنَ ‏.‏ فَقَالَ بَعْضُهُمْ لَوْ لَمْ يَأْتِهِ لَحَنَّ إِلَى يَوْمِ الْقِيَامَةِ ‏.‏\hadithno{1417}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) used to stand by the root of a tree, or by a tree trunk, then he started to use a pulpit. The tree trunk made a grieving sound.” Jabir said: “So that the people in the mosque could hear it. Until the Messenger of Allah (ﷺ) came to it and rubbed it, and it calmed down. Some of them said: ‘If he had not come to it, it would have grieved until the Day of Resurrection.’”}}
\hadithdefcmd{ibnmajah}{1418}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّيْتُ ذَاتَ لَيْلَةٍ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمْ يَزَلْ قَائِمًا حَتَّى هَمَمْتُ بِأَمْرِ سَوْءٍ ‏.‏ قُلْتُ وَمَا ذَاكَ الأَمْرُ قَالَ هَمَمْتُ أَنْ أَجْلِسَ وَأَتْرُكَهُ ‏.‏\hadithno{1418}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Wa’il that ‘Abdullah said:“I prayed one night with the Messenger of Allah (ﷺ) and he kept standing until I thought of doing something bad.” I said: “What was that?”He said: “I thought of sitting down and leaving him.”}}
\hadithdefcmd{ibnmajah}{1419}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، سَمِعَ الْمُغِيرَةَ، يَقُولُ قَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حَتَّى تَوَرَّمَتْ قَدَمَاهُ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ قَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ ‏.‏ قَالَ ‏ "‏ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏ ‏.‏\hadithno{1419}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ziyad bin ‘Ilaqah that he heard Mughirah say:“The Messenger of Allah (ﷺ) stood (in prayer) until his feet became swollen. It was said: ‘O Messenger of Allah, Allah has forgiven you your past and future sins.’ He said: ‘Should I not be a thankful slave?’”}}
\hadithdefcmd{ibnmajah}{1420}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، مُحَمَّدُ بْنُ يَزِيدَ حَدَّثَنَا يَحْيَى بْنُ يَمَانٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي حَتَّى تَوَرَّمَتْ قَدَمَاهُ فَقِيلَ لَهُ إِنَّ اللَّهَ قَدْ غَفَرَ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ ‏.‏ قَالَ ‏ "‏ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏ ‏.‏\hadithno{1420}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) used to pray until his feet became swollen. It was said: ‘O Messenger of Allah, Allah has forgiven you your past and future sins.’ He said: ‘Should I not be a thankful slave?’”}}
\hadithdefcmd{ibnmajah}{1421}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سُئِلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَىُّ الصَّلاَةِ أَفْضَلُ قَالَ ‏ "‏ طُولُ الْقُنُوتِ ‏"‏ ‏.‏\hadithno{1421}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Prophet (ﷺ) was asked: ‘Which prayer is best?’ He said: ‘That with the longer Qunut.’”}}
\hadithdefcmd{ibnmajah}{1422}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَعَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيَّانِ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ ثَابِتِ بْنِ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ مَكْحُولٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ، أَنَّ أَبَا فَاطِمَةَ، حَدَّثَهُ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَخْبِرْنِي بِعَمَلٍ، أَسْتَقِيمُ عَلَيْهِ وَأَعْمَلُهُ ‏.‏ قَالَ ‏ "‏ عَلَيْكَ بِالسُّجُودِ فَإِنَّكَ لاَ تَسْجُدُ لِلَّهِ سَجْدَةً إِلاَّ رَفَعَكَ اللَّهُ بِهَا دَرَجَةً وَحَطَّ بِهَا عَنْكَ خَطِيئَةً ‏"‏ ‏.‏\hadithno{1422}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Kathir bin Murrah that Abu Fatimah told him:“I said: ‘O Messenger of Allah! Tell me of a deed that I can adhere to and act upon.’ He said: “You should prostrate, for you will not prostrate to Allah but He will raise you in status one degree thereby and erase from you one sin.”}}
\hadithdefcmd{ibnmajah}{1423}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو أَبُو عَمْرٍو الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي الْوَلِيدُ بْنُ هِشَامٍ الْمُعَيْطِيُّ، حَدَّثَهُ مَعْدَانُ بْنُ أَبِي طَلْحَةَ الْيَعْمَرِيُّ، قَالَ لَقِيتُ ثَوْبَانَ فَقُلْتُ لَهُ حَدِّثْنِي حَدِيثًا عَسَى اللَّهُ أَنْ يَنْفَعَنِي بِهِ ‏.‏ قَالَ فَسَكَتَ ثُمَّ عُدْتُ فَقُلْتُ مِثْلَهَا فَسَكَتَ ثَلاَثَ مَرَّاتٍ فَقَالَ لِي عَلَيْكَ بِالسُّجُودِ لِلَّهِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ يَسْجُدُ لِلَّهِ سَجْدَةً إِلاَّ رَفَعَهُ اللَّهُ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏ قَالَ مَعْدَانُ ثُمَّ لَقِيتُ أَبَا الدَّرْدَاءِ فَسَأَلْتُهُ فَقَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{1423}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ma’dan bin Abu Talhah Al-Ya’muri said:“I met Thawban and said to him: ‘Tell me a Hadith that Allah may benefit me thereby.’ But he remained silent. Then I said the same and he remained silent. That happened three times. Then he said to me: ‘You should prostrate to Allah; for I heard the Messenger of Allah (ﷺ) say: “No one prostrates to Allah but Allah will raise him one degree in status thereby and will erase one of his sins.” Ma’dan said: “Then I met Abu Darda’ and asked him the same question, and he gave a similar answer.”}}
\hadithdefcmd{ibnmajah}{1424}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ خَالِدِ بْنِ يَزِيدَ الْمُرِّيِّ، عَنْ يُونُسَ بْنِ مَيْسَرَةَ بْنِ حَلْبَسٍ، عَنِ الصُّنَابِحِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ يَسْجُدُ لِلَّهِ سَجْدَةً إِلاَّ كَتَبَ اللَّهُ لَهُ بِهَا حَسَنَةً وَمَحَا عَنْهُ بِهَا سَيِّئَةً وَرَفَعَ لَهُ بِهَا دَرَجَةً فَاسْتَكْثِرُوا مِنَ السُّجُودِ ‏"‏ ‏.‏\hadithno{1424}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Ubadah bin Samit that he heard the Messenger of Allah (ﷺ) say:“No one prostrates to Allah but Allah will record one Hasanah (good reward) for him, and will erase thereby one bad deed and raise him in status one degree. So prostrate a great deal.”}}
\hadithdefcmd{ibnmajah}{1425}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ حَكِيمٍ الضَّبِّيِّ، قَالَ قَالَ لِي أَبُو هُرَيْرَةَ إِذَا أَتَيْتَ أَهْلَ مِصْرِكَ فَأَخْبِرْهُمْ أَنِّي، سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ أَوَّلَ مَا يُحَاسَبُ بِهِ الْعَبْدُ الْمُسْلِمُ يَوْمَ الْقِيَامَةِ، الصَّلاَةُ الْمَكْتُوبَةُ فَإِنْ أَتَمَّهَا، وَإِلاَّ قِيلَ: انْظُرُوا هَلْ لَهُ مِنْ تَطَوُّعٍ؟ فَإِنْ كَانَ لَهُ تَطَوُّعٌ أُكْمِلَتِ الْفَرِيضَةُ مِنْ تَطَوُّعِهِ. ثُمَّ يُفْعَلُ بِسَائِرِ الأَعْمَالِ الْمَفْرُوضَةِ مِثْلُ ذَلِكَ ‏"‏ ‏.‏\hadithno{1425}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Hakim Dabbi said:“Abu Hurairah said to me: ‘When you go to your country, tell them that I heard the Messenger of Allah (ﷺ) say: “The first thing for which the Muslim will be brought to account on the Day of Resurrection will be the prescribed prayers. If they are complete, all well and good, otherwise it will be said: ‘Look and see whether he has any voluntary prayers.’ If he has any voluntary prayers, his prescribed prayers will be completed from his voluntary prayers. Then the same will be done with regard to all his obligatory deeds.”}}
\hadithdefcmd{ibnmajah}{1426}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ تَمِيمٍ الدَّارِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ح وَحَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، أَنْبَأَنَا حُمَيْدٌ، عَنِ الْحَسَنِ، عَنْ رَجُلٍ، عَنْ أَبِي هُرَيْرَةَ، وَدَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ تَمِيمٍ الدَّارِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَوَّلُ مَا يُحَاسَبُ بِهِ الْعَبْدُ يَوْمَ الْقِيَامَةِ صَلاَتُهُ. فَإِنْ أَكْمَلَهَا كُتِبَتْ لَهُ نَافِلَةً. فَإِنْ لَمْ يَكُنْ أَكْمَلَهَا، قَالَ اللَّهُ سُبْحَانَهُ لِمَلاَئِكَتِهِ: انْظُرُوا، هَلْ تَجِدُونَ لِعَبْدِي مِنْ تَطَوُّعٍ؟ فَأَكْمِلُوا بِهَا مَا ضَيَّعَ مِنْ فَرِيضَتِهِ ‏.‏ ثُمَّ تُؤْخَذُ الأَعْمَالُ عَلَى حَسَبِ ذَلِكَ ‏"‏ ‏.‏\hadithno{1426}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Tamim Dari that the Prophet (ﷺ) said:“The first thing for which a person will be brought to account on the Day of Resurrection will be his prayer. If it is complete, then the voluntary (prayers) will also be recorded for him (as an increase). If it is not complete then Allah will say to His angels: ‘Look and see whether you find any voluntary prayers for My slave, and take them to make up what is lacking from his obligatory prayers.’ Then all his deeds will be reckoned in like manner.”}}
\hadithdefcmd{ibnmajah}{1427}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ لَيْثٍ، عَنْ حَجَّاجِ بْنِ عُبَيْدٍ، عَنْ إِبْرَاهِيمَ بْنِ إِسْمَاعِيلَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَيَعْجِزُ أَحَدُكُمْ إِذَا صَلَّى أَنْ يَتَقَدَّمَ أَوْ يَتَأَخَّرَ أَوْ عَنْ يَمِينِهِ أَوْ عَنْ شِمَالِهِ ‏"‏ يَعْنِي السُّبْحَةَ ‏.‏\hadithno{1427}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Is anyone of you incapable, when he prays, of stepping forwards or backwards, or to his right or left?” meaning in order to offer a voluntary prayer}}
\hadithdefcmd{ibnmajah}{1428}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عُثْمَانَ بْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يُصَلِّي الإِمَامُ فِي مُقَامِهِ الَّذِي صَلَّى فِيهِ الْمَكْتُوبَةَ حَتَّى يَتَنَحَّى عَنْهُ ‏"‏ ‏.‏ حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ التَّمِيمِيِّ، عَنْ عُثْمَانَ بْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1428}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Mughirah bin Shu’bah that the Messenger of Allah (ﷺ) said:“The Imam should not pray in the place where he offered the obligatory prayer, until he moves aside.” Another chain from Mughirah, from the Prophet (ﷺ) with similar wording}}
\hadithdefcmd{ibnmajah}{1429}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ تَمِيمِ بْنِ مَحْمُودٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شِبْلٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ ثَلاَثٍ عَنْ نَقْرَةِ الْغُرَابِ وَعَنْ فِرْشَةِ السَّبُعِ وَأَنْ يُوطِنَ الرَّجُلُ الْمَكَانَ الَّذِي يُصَلِّي فِيهِ كَمَا يُوطِنُ الْبَعِيرُ ‏.‏\hadithno{1429}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdur-Rahman bin Shibl said:“The Messenger of Allah (ﷺ) forbade three things: Pecking like a crow, spreading (the forearms) like a beast of prey, and a man having a place in the mosque in which he usually offers the prayer, like a camel has a place to which it usually goes.”}}
\hadithdefcmd{ibnmajah}{1430}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، أَنَّهُ كَانَ يَأْتِي إِلَى سُبْحَةِ الضُّحَى فَيَعْمِدُ إِلَى الأُسْطُوَانَةِ دُونَ الْمُصْحَفِ فَيُصَلِّي قَرِيبًا مِنْهَا فَأَقُولُ لَهُ أَلاَ تُصَلِّي هَا هُنَا وَأُشِيرُ إِلَى بَعْضِ نَوَاحِي الْمَسْجِدِ فَيَقُولُ إِنِّي رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَتَحَرَّى هَذَا الْمُقَامَ ‏.‏\hadithno{1430}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Yazid bin Abu ‘Ubaid that Salamah bin Al-Akwa’ used to offer the Duha prayer, and he would come to the pillar that was near the Mushaf. I said to him:“Why do you not pray over there?” And I pointed to some corner of the mosque. He said: “I saw the Messenger of Allah (ﷺ) seeking out this place.”}}
\hadithdefcmd{ibnmajah}{1431}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ مُحَمَّدِ بْنِ عَبَّادٍ، عَنْ عَبْدِ اللَّهِ بْنِ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى يَوْمَ الْفَتْحِ فَجَعَلَ نَعْلَيْهِ عَنْ يَسَارِهِ ‏.‏\hadithno{1431}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Abdullah bin Sa’ib said:“I saw the Messenger of Allah (ﷺ) praying on the Day of the Conquest, and he put his shoes on his left.”}}
\hadithdefcmd{ibnmajah}{1432}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَلْزِمْ نَعْلَيْكَ قَدَمَيْكَ. فَإِنْ خَلَعْتَهُمَا فَاجْعَلْهُمَا بَيْنَ رِجْلَيْكَ. وَلاَ تَجْعَلْهُمَا عَنْ يَمِينِكَ، وَلاَ عَنْ يَمِينِ صَاحِبِكَ، وَلاَ وَرَاءَكَ، فَتُؤْذِيَ مَنْ خَلْفَكَ ‏"‏ ‏.‏\hadithno{1432}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Keep your shoes on your feet. If you take them off then place them between your two feet; do not place them to your right, or to the right of your companions, or behind you, for they may annoy whoever is behind you.’”}}
