% Auto-generated chapter 9 for ibnmajah
% Hadiths in this chapter: 171

\hadithdefcmd{ibnmajah}{1845}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ قَيْسٍ، قَالَ كُنْتُ مَعَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ بِمِنًى فَخَلاَ بِهِ عُثْمَانُ فَجَلَسْتُ قَرِيبًا مِنْهُ فَقَالَ لَهُ عُثْمَانُ هَلْ لَكَ أَنْ أُزَوِّجَكَ جَارِيَةً بِكْرًا تُذَكِّرُكَ مِنْ نَفْسِكَ بَعْضَ مَا قَدْ مَضَى فَلَمَّا رَأَى عَبْدُ اللَّهِ أَنَّهُ لَيْسَ لَهُ حَاجَةٌ سِوَى هَذَا أَشَارَ إِلَىَّ بِيَدِهِ فَجِئْتُ وَهُوَ يَقُولُ لَئِنْ قُلْتَ ذَلِكَ لَقَدْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لَمْ يَسْتَطِعْ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{1845}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that:Alqamah bin Qais said: “I was with Abdullah bin Masud in Mina, and Uthman took him aside. I was sitting near him. Uthman said to him: 'Would you like that I marry you to a young virgin who will remind you of how you were in the past?' When Abdullah saw that he did not say anything to him apart from that, he gestured to me, so I came and he said: 'As you say that the Messenger of Allah said “O young men, whoever among you can afford it, let him get married, for it is more effective in lowering the gaze and guarding one's chastity. Whoever cannot afford it, let him fast, for it will diminish his desire.” ' ”}}
\hadithdefcmd{ibnmajah}{1846}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا آدَمُ، حَدَّثَنَا عِيسَى بْنُ مَيْمُونٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ النِّكَاحُ مِنْ سُنَّتِي فَمَنْ لَمْ يَعْمَلْ بِسُنَّتِي فَلَيْسَ مِنِّي وَتَزَوَّجُوا فَإِنِّي مُكَاثِرٌ بِكُمُ الأُمَمَ وَمَنْ كَانَ ذَا طَوْلٍ فَلْيَنْكِحْ وَمَنْ لَمْ يَجِدْ فَعَلَيْهِ بِالصِّيَامِ فَإِنَّ الصَّوْمَ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{1846}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aishah that:the Messenger of Allah said: “Marriage is part of my sunnah, and whoever does not follow my sunnah has nothing to do with me. Get married, for I will boast of your great numbers before the nations. Whoever has the means, let him get married, and whoever does not, then he should fast for it will diminish his desire.”}}
\hadithdefcmd{ibnmajah}{1847}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مَيْسَرَةَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَمْ نَرَ لِلْمُتَحَابَّيْنِ مِثْلَ النِّكَاحِ ‏"‏ ‏.‏\hadithno{1847}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Abbas that:the Messenger of Allah said: “There is nothing like marriage, for two who love one another.”}}
\hadithdefcmd{ibnmajah}{1848}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدٍ، قَالَ لَقَدْ رَدَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى عُثْمَانَ بْنِ مَظْعُونٍ التَّبَتُّلَ وَلَوْ أَذِنَ لَهُ لاَخْتَصَيْنَا ‏.‏\hadithno{1848}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that:Sa'd said: “The Messenger of Allah disapproved of Uthman bin Maz'un's desire to remain celibate; if he had given him permission, we would have gotten ourselves castrated.”}}
\hadithdefcmd{ibnmajah}{1849}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، وَزَيْدُ بْنُ أَخْزَمَ، قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنِ التَّبَتُّلِ ‏.‏ زَادَ زَيْدُ بْنُ أَخْزَمَ وَقَرَأَ قَتَادَةُ ‏\{وَلَقَدْ أَرْسَلْنَا رُسُلاً مِنْ قَبْلِكَ وَجَعَلْنَا لَهُمْ أَزْوَاجًا وَذُرِّيَّةً\}‏ ‏.‏\hadithno{1849}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Samurah that:the Messenger of Allah(ﷺ) forbade celibacy. Zaid bin Akhzam added: “And Qatadah recited: 'And indeed We sent Messengers before you (O Muhammad (ﷺ)), and made for them wives and offspring.'”}}
\hadithdefcmd{ibnmajah}{1850}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ شُعْبَةَ، عَنْ أَبِي قَزَعَةَ، عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ مَا حَقُّ الْمَرْأَةِ عَلَى الزَّوْجِ قَالَ ‏ "‏ أَنْ يُطْعِمَهَا إِذَا طَعِمَ وَأَنْ يَكْسُوَهَا إِذَا اكْتَسَى وَلاَ يَضْرِبِ الْوَجْهَ وَلاَ يُقَبِّحْ وَلاَ يَهْجُرْ إِلاَّ فِي الْبَيْتِ ‏"‏ ‏.‏\hadithno{1850}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Hakim bin Muawiyah, from his father, that:a man asked the Prophet(ﷺ): “What are the right of the woman over her husband?” He said: “That he should feed her as he feeds himself and clothe her as he clothes himself; he should not strike her on the face nor disfigure her, and he should not abandon her except in the house (as a form of discipline).” (Hassan)}}
\hadithdefcmd{ibnmajah}{1851}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ الْبَارِقِيِّ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، حَدَّثَنِي أَبِي أَنَّهُ، شَهِدَ حِجَّةَ الْوَدَاعِ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَذَكَّرَ وَوَعَظَ ثُمَّ قَالَ ‏ "‏ اسْتَوْصُوا بِالنِّسَاءِ خَيْرًا فَإِنَّمَا هُنَّ عِنْدَكُمْ عَوَانٍ ‏.‏ لَيْسَ تَمْلِكُونَ مِنْهُنَّ شَيْئًا غَيْرَ ذَلِكَ إِلاَّ أَنْ يَأْتِينَ بِفَاحِشَةٍ مُبَيِّنَةٍ فَإِنْ فَعَلْنَ فَاهْجُرُوهُنَّ فِي الْمَضَاجِعِ وَاضْرِبُوهُنَّ ضَرْبًا غَيْرَ مُبَرِّحٍ فَإِنْ أَطَعْنَكُمْ فَلاَ تَبْغُوا عَلَيْهِنَّ سَبِيلاً إِنَّ لَكُمْ مِنْ نِسَائِكُمْ حَقًّا وَلِنِسَائِكُمْ عَلَيْكُمْ حَقًّا فَأَمَّا حَقُّكُمْ عَلَى نِسَائِكُمْ فَلاَ يُوطِئْنَ فُرُشَكُمْ مَنْ تَكْرَهُونَ وَلاَ يَأْذَنَّ فِي بُيُوتِكُمُ لِمَنْ تَكْرَهُونَ أَلاَ وَحَقُّهُنَّ عَلَيْكُمْ أَنْ تُحْسِنُوا إِلَيْهِنَّ فِي كِسْوَتِهِنَّ وَطَعَامِهِنَّ ‏"‏ ‏.‏\hadithno{1851}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that:Sulaiman bin Amr bin Ahwas said: “My father told me that he was present at the Farewell Pilgrimage with the Messenger of Allah. He praised and glorified Allah, and reminded and exhorted (the people). Then he said: 'I enjoin good treatment of women, for they are prisoners with you, and you have no right to treat them otherwise, unless they commit clear indecency. If they do that, then forsake them in their beds and hit them, but without causing injury or leaving a mark. If they obey you, then do not seek means of annoyance against them. You have rights over your women and your women have rights over you. Your rights over your women are that they are not to allow anyone whom you dislike to tread on your bedding (furniture), nor allow anyone whom you dislike to enter your houses. And their right over you are that you should treat them kindly with regard to their clothing and food.' ”}}
\hadithdefcmd{ibnmajah}{1852}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدِ بْنِ جُدْعَانَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَوْ أَمَرْتُ أَحَدًا أَنْ يَسْجُدَ لأَحَدٍ لأَمَرْتُ الْمَرْأَةَ أَنْ تَسْجُدَ لِزَوْجِهَا وَلَوْ أَنَّ رَجُلاً أَمَرَ امْرَأَةً أَنْ تَنْقُلَ مِنْ جَبَلٍ أَحْمَرَ إِلَى جَبَلٍ أَسْوَدَ وَمِنْ جَبَلٍ أَسْوَدَ إِلَى جَبَلٍ أَحْمَرَ - لَكَانَ نَوْلُهَا أَنْ تَفْعَلَ ‏"‏ ‏.‏\hadithno{1852}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aishah:that the messenger of Allah of said: “If I were to command anyone to prostrate to anyone else, I would have commanded women to prostrate to their husbands. If a man were to command his wife to move (something) from a red mountain to a black mountain, and from a black mountain to a red mountain, her duty is to obey to him.”}}
\hadithdefcmd{ibnmajah}{1853}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنِ الْقَاسِمِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ لَمَّا قَدِمَ مُعَاذٌ مِنَ الشَّامِ سَجَدَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ مَا هَذَا يَا مُعَاذُ ‏"‏ ‏.‏ قَالَ أَتَيْتُ الشَّامَ فَوَافَقْتُهُمْ يَسْجُدُونَ لأَسَاقِفَتِهِمْ وَبَطَارِقَتِهِمْ فَوَدِدْتُ فِي نَفْسِي أَنْ نَفْعَلَ ذَلِكَ بِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَلاَ تَفْعَلُوا فَإِنِّي لَوْ كُنْتُ آمِرًا أَحَدًا أَنْ يَسْجُدَ لِغَيْرِ اللَّهِ لأَمَرْتُ الْمَرْأَةَ أَنْ تَسْجُدَ لِزَوْجِهَا وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لاَ تُؤَدِّي الْمَرْأَةُ حَقَّ رَبِّهَا حَتَّى تُؤَدِّيَ حَقَّ زَوْجِهَا وَلَوْ سَأَلَهَا نَفْسَهَا وَهِيَ عَلَى قَتَبٍ لَمْ تَمْنَعْهُ ‏"‏ ‏.‏\hadithno{1853}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that:Abdullah bin Abu Awfa said “When Muadh bin Jabal came from Sham, he prostrated to the Prophet who said: 'What is this, O Muadh?' He said: 'I went to Sham and saw them prostrating to their bishops and patricians and I wanted to do that for you.' The messenger of Allah said: 'Do not do that. If I were to command anyone to prostrate to anyone other than Allah, I would have commanded women to prostrate to their husbands. By the One in Whose Hand is the soul of Muhammad! No woman can fulfill her duty towards Allah until she fulfills her duty towards her husband. If he asks her (for intimacy) even if she is on her camel saddle, she should not refuse.' ”}}
\hadithdefcmd{ibnmajah}{1854}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِي نَصْرٍ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مُسَاوِرٍ الْحِمْيَرِيِّ، عَنْ أُمِّهِ، قَالَتْ سَمِعْتُ أُمَّ سَلَمَةَ، تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ أَيُّمَا امْرَأَةٍ مَاتَتْ وَزَوْجُهَا عَنْهَا رَاضٍ دَخَلَتِ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{1854}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that from Musawir Al Himyari from his mother that:she heard Umm Salamah say: “I heard the Messenger of Allah say: 'Any woman who dies when her husband is pleased with her, will enter Paradise.' ”}}
\hadithdefcmd{ibnmajah}{1855}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زِيَادِ بْنِ أَنْعُمٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّمَا الدُّنْيَا مَتَاعٌ وَلَيْسَ مِنْ مَتَاعِ الدُّنْيَا شَىْءٌ أَفْضَلَ مِنَ الْمَرْأَةِ الصَّالِحَةِ ‏"‏ ‏.‏\hadithno{1855}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that from Abdullah bin Amr that :the Messenger of Allah said: “This world is but provisions, and there is no provision in this world better than a righteous wife.”}}
\hadithdefcmd{ibnmajah}{1856}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِيهِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ ثَوْبَانَ، قَالَ لَمَّا نَزَلَ فِي الْفِضَّةِ وَالذَّهَبِ مَا نَزَلَ قَالُوا فَأَىَّ الْمَالِ نَتَّخِذُ قَالَ عُمَرُ فَأَنَا أَعْلَمُ لَكُمْ ذَلِكَ ‏.‏ فَأَوْضَعَ عَلَى بَعِيرِهِ فَأَدْرَكَ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَأَنَا فِي أَثَرِهِ فَقَالَ يَا رَسُولَ اللَّهِ أَىَّ الْمَالِ نَتَّخِذُ فَقَالَ ‏ "‏ لِيَتَّخِذْ أَحَدُكُمْ قَلْبًا شَاكِرًا وَلِسَانًا ذَاكِرًا وَزَوْجَةً مُؤْمِنَةً تُعِينُ أَحَدَكُمْ عَلَى أَمْرِ الآخِرَةِ ‏"‏ ‏.‏\hadithno{1856}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:Thawban said: “When the Verse concerning silver and gold was revealed, they said: 'What kind of wealth should we acquire?' Umar said: 'I will tell you about that.' So he rode on his camel and caught up with the Prophet, and I followed him. He said: 'O Messenger of Allah what kind of wealth should we acquire?' He said: 'Let one of you acquire a thankful heart, a tongue that remembers Allah and a believing wife who will help him with regard to the Hereafter.' ”}}
\hadithdefcmd{ibnmajah}{1857}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا عُثْمَانُ بْنُ أَبِي الْعَاتِكَةِ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ كَانَ يَقُولُ ‏ "‏ مَا اسْتَفَادَ الْمُؤْمِنُ بَعْدَ تَقْوَى اللَّهِ خَيْرًا لَهُ مِنْ زَوْجَةٍ صَالِحَةٍ إِنْ أَمَرَهَا أَطَاعَتْهُ وَإِنْ نَظَرَ إِلَيْهَا سَرَّتْهُ وَإِنْ أَقْسَمَ عَلَيْهَا أَبَرَّتْهُ وَإِنْ غَابَ عَنْهَا نَصَحَتْهُ فِي نَفْسِهَا وَمَالِهِ ‏"‏ ‏.‏\hadithno{1857}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that:the Prophet used to say: “Nothing is of more benefit to the believer after Taqwa of Allah than a righteous wife whom, if he commands her she obeys him, if he looks at her he is pleased, if he swears an oath concerning her she fulfills it, and when he is away from her she is sincere towards him with regard to herself and his wealth.”}}
\hadithdefcmd{ibnmajah}{1858}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ تُنْكَحُ النِّسَاءُ لأَرْبَعٍ لِمَالِهَا وَلِحَسَبِهَا وَلِجَمَالِهَا وَلِدِينِهَا ‏.‏ فَاظْفَرْ بِذَاتِ الدِّينِ تَرِبَتْ يَدَاكَ ‏"‏ ‏.‏\hadithno{1858}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that:the Prophet said: “A woman may be married for four things: Her wealth, her lineage, her beauty or for her religion. Choose the religious, may your hands be rubbed with dust (i.e., may you prosper).”}}
\hadithdefcmd{ibnmajah}{1859}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، وَجَعْفَرُ بْنُ عَوْنٍ، عَنِ الإِفْرِيقِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَزَوَّجُوا النِّسَاءَ لِحُسْنِهِنَّ فَعَسَى حُسْنُهُنَّ أَنْ يُرْدِيَهُنَّ وَلاَ تَزَوَّجُوهُنَّ لأَمْوَالِهِنَّ فَعَسَى أَمْوَالُهُنَّ أَنْ تُطْغِيَهُنَّ وَلَكِنْ تَزَوَّجُوهُنَّ عَلَى الدِّينِ وَلأَمَةٌ خَرْمَاءُ سَوْدَاءُ ذَاتُ دِينٍ أَفْضَلُ ‏"‏ ‏.‏\hadithno{1859}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdullah bin Amr that:the Prophet said: “Do not marry women for their beauty for it may lead to their doom. Do not marry them for their wealth, for it may lead them to fall into sin. Rather, marry them for their religion. A black slave woman with piercings who is religious is better.”}}
\hadithdefcmd{ibnmajah}{1860}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ تَزَوَّجْتُ امْرَأَةً عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَقِيتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ أَتَزَوَّجْتَ يَا جَابِرُ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ أَبِكْرًا أَوْ ثَيِّبًا ‏"‏ ‏.‏ قُلْتُ ثَيِّبًا ‏.‏ قَالَ ‏"‏ فَهَلاَّ بِكْرًا تُلاَعِبُهَا ‏"‏ ‏.‏ قُلْتُ كُنَّ لِي أَخَوَاتٌ فَخَشِيتُ أَنْ تَدْخُلَ بَيْنِي وَبَيْنَهُنَّ ‏.‏ قَالَ ‏"‏ فَذَاكَ إِذًا ‏"‏ ‏.‏\hadithno{1860}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that:Jabir bin Abdullah said: “I married a woman during the time of the Prophet and he said: 'Have you got married, O Jabir?' I said: 'Yes'. He said: 'To a virgin or to a previously-married woman?' I said: 'A previously married woman.' He said: 'Why not a virgin so you could play with her?' I said: 'I have sisters and did not want her to create trouble between them and me.' He said: 'That is better then.' ”}}
\hadithdefcmd{ibnmajah}{1861}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ التَّيْمِيُّ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ سَالِمِ بْنِ عُتْبَةَ بْنِ عُوَيْمِ بْنِ سَاعِدَةَ الأَنْصَارِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عَلَيْكُمْ بِالأَبْكَارِ فَإِنَّهُنَّ أَعْذَبُ أَفْوَاهًا وَأَنْتَقُ أَرْحَامًا وَأَرْضَى بِالْيَسِيرِ ‏"‏ ‏.‏\hadithno{1861}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdur-Rahman bin Salim bin Utbah bin Salim bin Uwaim bin Sa'idah Al-Ansari, from his father that:his grandfather said: “The Messenger of Allah said: 'You should marry virgins, for their mouths are sweeter, their wombs are more prolific and they are satisfied with less.'”}}
\hadithdefcmd{ibnmajah}{1862}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سَلاَّمُ بْنُ سَوَّارٍ، حَدَّثَنَا كَثِيرُ بْنُ سَلِيمٍ، عَنِ الضَّحَّاكِ بْنِ مُزَاحِمٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ أَرَادَ أَنْ يَلْقَى اللَّهَ طَاهِرًا مُطَهَّرًا فَلْيَتَزَوَّجِ الْحَرَائِرَ ‏"‏ ‏.‏\hadithno{1862}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:Anas bin Malik said: “I heard the Messenger of Allah say: 'Whoever wants to meet Allah pure and purified, let him marry free women.' ”}}
\hadithdefcmd{ibnmajah}{1863}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ الْمَخْزُومِيُّ، عَنْ طَلْحَةَ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ انْكِحُوا فَإِنِّي مُكَاثِرٌ بِكُمْ ‏"‏ ‏.‏\hadithno{1863}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah said: “Marry, for I will boast of your great numbers.”}}
\hadithdefcmd{ibnmajah}{1864}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ حَجَّاجٍ، عَنْ مُحَمَّدِ بْنِ سُلَيْمَانَ، عَنْ عَمِّهِ، سَهْلِ بْنِ أَبِي حَثْمَةَ عَنْ مُحَمَّدِ بْنِ مَسْلَمَةَ، قَالَ خَطَبْتُ امْرَأَةً فَجَعَلْتُ أَتَخَبَّأُ لَهَا حَتَّى نَظَرْتُ إِلَيْهَا فِي نَخْلٍ لَهَا فَقِيلَ لَهُ أَتَفْعَلُ هَذَا وَأَنْتَ صَاحِبُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا أَلْقَى اللَّهُ فِي قَلْبِ امْرِئٍ خِطْبَةَ امْرَأَةٍ فَلاَ بَأْسَ أَنْ يَنْظُرَ إِلَيْهَا ‏"‏ ‏.‏\hadithno{1864}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:Muhammad bin Salamah said: “I proposed marriage to a woman, then I hid and waited to see her until I saw her among some date palm trees that belonged to her.” It was said to him: “Do you do such a thing when you are a companion of the Messenger of Allah?” He said: “I heard the Messenger of Allah saying: 'When Allah causes a man to propose to a woman, there is nothing wrong with him looking at her.' ”}}
\hadithdefcmd{ibnmajah}{1865}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَزُهَيْرُ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ الْمُغِيرَةَ بْنَ شُعْبَةَ، أَرَادَ أَنْ يَتَزَوَّجَ، امْرَأَةً فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ اذْهَبْ فَانْظُرْ إِلَيْهَا فَإِنَّهُ أَحْرَى أَنْ يُؤْدَمَ بَيْنَكُمَا ‏"‏ ‏.‏ فَفَعَلَ فَتَزَوَّجَهَا فَذَكَرَ مِنْ مُوَافَقَتِهَا ‏.‏\hadithno{1865}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that:Mughirah bin Shubah wanted to marry a woman. The Prophet (ﷺ) said to him: “Go and look at her, for that is more likely to create love between you.” So he did that, and married her, and mentioned how well he got along with her}}
\hadithdefcmd{ibnmajah}{1866}{حَدَّثَنَا الْحَسَنُ بْنُ أَبِي الرَّبِيعِ، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَذَكَرْتُ لَهُ امْرَأَةً أَخْطُبُهَا فَقَالَ ‏ "‏ اذْهَبْ فَانْظُرْ إِلَيْهَا فَإِنَّهُ أَجْدَرُ أَنْ يُؤْدَمَ بَيْنَكُمَا ‏"‏ ‏.‏ فَأَتَيْتُ امْرَأَةً مِنَ الأَنْصَارِ فَخَطَبْتُهَا إِلَى أَبَوَيْهَا وَأَخْبَرْتُهُمَا بِقَوْلِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏ فَكَأَنَّهُمَا كَرِهَا ذَلِكَ ‏.‏ قَالَ فَسَمِعَتْ ذَلِكَ الْمَرْأَةُ وَهِيَ فِي خِدْرِهَا فَقَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَكَ أَنْ تَنْظُرَ فَانْظُرْ ‏.‏ وَإِلاَّ فَإِنِّي أَنْشُدُكَ كَأَنَّهَا أَعْظَمَتْ ذَلِكَ ‏.‏ قَالَ فَنَظَرْتُ إِلَيْهَا فَتَزَوَّجْتُهَا ‏.‏ فَذَكَرَ مِنْ مُوَافَقَتِهَا ‏.‏\hadithno{1866}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that:Mughirah bin Shubah said: “I came to the Prophet and told him of a woman to whom I had to propose marriage. He said: 'Go and look at her, for that is more likely to create love between you.' So I went to a woman among the Ansar and proposed marriage through her parents. I told them what the Prophet had said, and it was as if they did not like that. Then I heard that woman, behind her curtain, say: 'If the Messenger of Allah has told you to do that, then do it, otherwise I adjure you by Allah (not to do so)'. And it was as if she regarded that as a serious matter. So I looked at her and married her.” And he mentioned how well he got along with her}}
\hadithdefcmd{ibnmajah}{1867}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَخْطُبِ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{1867}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah said: “A man should not propose to a woman to whom his brother has already proposed.”}}
\hadithdefcmd{ibnmajah}{1868}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَخْطُبِ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{1868}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Umar that:the Messenger of Allah said: “A man should not propose to a woman to whom his brother has already proposed.”}}
\hadithdefcmd{ibnmajah}{1869}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي بَكْرِ بْنِ أَبِي الْجَهْمِ بْنِ صُخَيْرٍ الْعَدَوِيِّ، قَالَ سَمِعْتُ فَاطِمَةَ بِنْتَ قَيْسٍ، تَقُولُ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِذَا حَلَلْتِ فَآذِنِينِي ‏"‏ ‏.‏ فَآذَنَتْهُ فَخَطَبَهَا مُعَاوِيَةُ وَأَبُو الْجَهْمِ بْنُ صُخَيْرٍ وَأُسَامَةُ بْنُ زَيْدٍ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَمَّا مُعَاوِيَةُ فَرَجُلٌ تَرِبٌ لاَ مَالَ لَهُ وَأَمَّا أَبُو الْجَهْمِ فَرَجُلٌ ضَرَّابٌ لِلنِّسَاءِ وَلَكِنْ أُسَامَةُ ‏"‏ ‏.‏ فَقَالَتْ بِيَدِهَا هَكَذَا أُسَامَةُ أُسَامَةُ ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ طَاعَةُ اللَّهِ وَطَاعَةُ رَسُولِهِ خَيْرٌ لَكِ ‏"‏ ‏.‏ قَالَتْ فَتَزَوَّجْتُهُ فَاغْتَبَطْتُ بِهِ ‏.‏\hadithno{1869}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that:Abu Bakr bin Abu Jahm bin Sukhair Al-Adawi said: “I heard Fathima bint Qais say: 'The Messenger of Allah said to me: “When you become lawful, tell me.” So I told him.' Then Muawiyah, Abu Jahm bin Sukhair and Usamah bin Zaid proposed marriage to her. The Messenger of Allah said: 'As for Muawiyah, he is a poor man who has no money. As from Abu Jahm he is a man who habitually beats woman. But Usamah (is good).' She gestured with her hand, saying: 'Usamah, Usamah!?' The Messenger of Allah said to her: 'Obedience to Allah and obedience to His Messenger is better for you.' She said: 'So I married him and I was pleased with him.' ”}}
\hadithdefcmd{ibnmajah}{1870}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى السُّدِّيُّ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ الْهَاشِمِيِّ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ الأَيِّمُ أَوْلَى بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ تُسْتَأْمَرُ فِي نَفْسِهَا ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ إِنَّ الْبِكْرَ تَسْتَحْيِي أَنْ تَتَكَلَّمَ ‏.‏ قَالَ ‏"‏ إِذْنُهَا سُكُوتُهَا ‏"‏ ‏.‏\hadithno{1870}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Abbas that:the Messenger of Allah said: “A widow has more right (to decide) concerning herself than her guardian, and a virgin should be consulted”. It was said: “O Messenger of Allah, a virgin may be too shy to speak.” He said: “Her consent is her silence.”}}
\hadithdefcmd{ibnmajah}{1871}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تُنْكَحُ الثَّيِّبُ حَتَّى تُسْتَأْمَرَ وَلاَ الْبِكْرُ حَتَّى تُسْتَأْذَنَ وَإِذْنُهَا الصُّمُوتُ ‏"‏ ‏.‏\hadithno{1871}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah said: “A previously-married woman should not be married until she is consulted, and a virgin should not be married until her consent is sought, and her consent is her silence.”}}
\hadithdefcmd{ibnmajah}{1872}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي حُسَيْنٍ، عَنْ عَدِيِّ بْنِ عَدِيٍّ الْكِنْدِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الثَّيِّبُ تُعْرِبُ عَنْ نَفْسِهَا وَالْبِكْرُ رِضَاهَا صَمْتُهَا ‏"‏ ‏.‏\hadithno{1872}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Adi bin Adi Al-Kindi that:his father said: “The Messenger of Allah said: 'A previously-married woman can speak for herself, and the consent of a virgin is her silence.' ”}}
\hadithdefcmd{ibnmajah}{1873}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، أَخْبَرَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ وَمُجَمِّعَ بْنَ يَزِيدَ الأَنْصَارِيَّيْنِ أَخْبَرَاهُ أَنَّ رَجُلاً مِنْهُمْ يُدْعَى خِذَامًا أَنْكَحَ ابْنَةً لَهُ فَكَرِهَتْ نِكَاحَ أَبِيهَا فَأَتَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَكَرَتْ لَهُ فَرَدَّ عَلَيْهَا نِكَاحَ أَبِيهَا فَنَكَحَتْ أَبَا لُبَابَةَ بْنَ عَبْدِ الْمُنْذِرِ ‏.‏ وَذَكَرَ يَحْيَى أَنَّهَا كَانَتْ ثَيِّبًا ‏.‏\hadithno{1873}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdur Rahman bin Yazid Al-Ansari and Mujamma bin Yazid Al-Ansari said:that a man among them who was called Khidam arranged a marriage for his daughter, and she did not like the marriage arranged by her father. She went to the Messenger of Allah and told him about that, and he annulled the marriage arranged by her father. Then she married Abu Lubabah bin Abdul-Mundhir}}
\hadithdefcmd{ibnmajah}{1874}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا وَكِيعٌ، عَنْ كَهْمَسِ بْنِ الْحَسَنِ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ جَاءَتْ فَتَاةٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَتْ إِنَّ أَبِي زَوَّجَنِي ابْنَ أَخِيهِ لِيَرْفَعَ بِي خَسِيسَتَهُ ‏.‏ قَالَ فَجَعَلَ الأَمْرَ إِلَيْهَا ‏.‏ فَقَالَتْ قَدْ أَجَزْتُ مَا صَنَعَ أَبِي وَلَكِنْ أَرَدْتُ أَنْ تَعْلَمَ النِّسَاءُ أَنْ لَيْسَ إِلَى الآبَاءِ مِنَ الأَمْرِ شَىْءٌ ‏.‏\hadithno{1874}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Buraidah that:his father said: “A girl came to the Prophet and said: 'My father married me to his brother's son so that he might raise his status thereby.' The Prophet gave her the choice, and she said: 'I approve of what my father did, but I wanted women to know that their fathers have no right to do that.' ”}}
\hadithdefcmd{ibnmajah}{1875}{حَدَّثَنَا أَبُو السَّقْرِ، يَحْيَى بْنُ يَزْدَادَ الْعَسْكَرِيُّ حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ الْمَرُّوذِيُّ، حَدَّثَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏.‏ أَنَّ جَارِيَةً، بِكْرًا أَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَذَكَرَتْ لَهُ أَنَّ أَبَاهَا زَوَّجَهَا وَهِيَ كَارِهَةٌ ‏.‏ فَخَيَّرَهَا النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا مُعَمَّرُ بْنُ سُلَيْمَانَ الرَّقِّيُّ، عَنْ زَيْدِ بْنِ حِبَّانَ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ مِثْلَهُ ‏.‏\hadithno{1875}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abbas that:a virgin girl came to the Prophet and told him that her father arranged a marriage that she did not like, and the Prophet gave her the choice}}
\hadithdefcmd{ibnmajah}{1876}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَنَا بِنْتُ سِتِّ سِنِينَ فَقَدِمْنَا الْمَدِينَةَ فَنَزَلْنَا فِي بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ فَوُعِكْتُ فَتَمَرَّقَ شَعَرِي حَتَّى وَفَى لَهُ جُمَيْمَةٌ فَأَتَتْنِي أُمِّي أُمُّ رُومَانَ وَإِنِّي لَفِي أُرْجُوحَةٍ وَمَعِي صَوَاحِبَاتٌ لِي فَصَرَخَتْ بِي فَأَتَيْتُهَا وَمَا أَدْرِي مَا تُرِيدُ فَأَخَذَتْ بِيَدِي فَأَوْقَفَتْنِي عَلَى بَابِ الدَّارِ وَإِنِّي لأَنْهَجُ حَتَّى سَكَنَ بَعْضُ نَفَسِي ثُمَّ أَخَذَتْ شَيْئًا مِنْ مَاءٍ فَمَسَحَتْ بِهِ عَلَى وَجْهِي وَرَأْسِي ثُمَّ أَدْخَلَتْنِي الدَّارَ فَإِذَا نِسْوَةٌ مِنَ الأَنْصَارِ فِي بَيْتٍ فَقُلْنَ عَلَى الْخَيْرِ وَالْبَرَكَةِ وَعَلَى خَيْرِ طَائِرٍ ‏.‏ فَأَسْلَمَتْنِي إِلَيْهِنَّ فَأَصْلَحْنَ مِنْ شَأْنِي فَلَمْ يَرُعْنِي إِلاَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ضُحًى ‏.‏ فَأَسْلَمَتْنِي إِلَيْهِ وَأَنَا يَوْمَئِذٍ بِنْتُ تِسْعِ سِنِينَ ‏.‏\hadithno{1876}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that:Aishah said: “The Messenger of Allah married me when I was six years old. Then we came to Al-Madinah and settled among Banu Harith bin Khazraj. I became ill and my hair fell out, then it grew back and became abundant. My mother Umm Ruman came to me while I was on an Urjuhah with some of my friends, and called for me. I went to her, and I did not know what she wanted. She took me by the hand and made me stand at the door of the house, and I was panting. When I got my breath back, she took some water and wiped my face and head, and led me into the house. There were some woman of the Ansar inside the house, and they said: 'With blessings and good fortune (from Allah).' (My mother) handed me over to them and they tidied me up. And suddenly I saw the Messenger of Allah in the morning. And she handed me over to him and I was at that time, nine years old.”}}
\hadithdefcmd{ibnmajah}{1877}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ تَزَوَّجَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَائِشَةَ وَهِيَ بِنْتُ سَبْعٍ وَبَنَى بِهَا وَهِيَ بِنْتُ تِسْعٍ وَتُوُفِّيَ عَنْهَا وَهِيَ بِنْتُ ثَمَانِي عَشْرَةَ سَنَةً ‏.‏\hadithno{1877}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that:Abdullah said: “The Prophet married Aishah when she was seven years old, and consummated the marriage with her when she was nine, and he passed away when she was eighteen.”}}
\hadithdefcmd{ibnmajah}{1878}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، ‏.‏ أَنَّهُ حِينَ هَلَكَ عُثْمَانُ بْنُ مَظْعُونٍ تَرَكَ ابْنَةً لَهُ ‏.‏ قَالَ ابْنُ عُمَرَ فَزَوَّجَنِيهَا خَالِي قُدَامَةُ وَهُوَ عَمُّهَا وَلَمْ يُشَاوِرْهَا وَذَلِكَ بَعْدَ مَا هَلَكَ أَبُوهَا فَكَرِهَتْ نِكَاحَهُ وَأَحَبَّتِ الْجَارِيَةُ أَنْ يُزَوِّجَهَا الْمُغِيرَةَ بْنَ شُعْبَةَ فَزَوَّجَهَا إِيَّاهُ ‏.‏\hadithno{1878}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Umar that:when Uthman bin Mazun died, he left behind a daughter. Ibn Umar said: “My maternal uncle Qudamah, who was her paternal uncle, married me to her, but he did not consult her. That was after her father had died. She did not like this marriage, and the girl wanted to marry Mughirah bin Shubah, so she married him.”}}
\hadithdefcmd{ibnmajah}{1879}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَيُّمَا امْرَأَةٍ لَمْ يُنْكِحْهَا الْوَلِيُّ فَنِكَاحُهَا بَاطِلٌ فَنِكَاحُهَا بَاطِلٌ فَنِكَاحُهَا بَاطِلٌ فَإِنْ أَصَابَهَا فَلَهَا مَهْرُهَا بِمَا أَصَابَ مِنْهَا فَإِنِ اشْتَجَرُوا فَالسُّلْطَانُ وَلِيُّ مَنْ لاَ وَلِيَّ لَهُ ‏"‏ ‏.‏\hadithno{1879}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Aishah that :the Messenger of Allah said: “Any woman whose marriage is not arranged by her guardian, her marriage is invalid, her marriage is invalid, her marriage is invalid. If (the man) has had intercourse with her, then the Mahr belongs to her in return for his intimacy with her. And if there is any dispute then the ruler is the guardian of the one who does not have a guardian.”}}
\hadithdefcmd{ibnmajah}{1880}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَجَّاجٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَعَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏.‏ قَالاَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ ‏.‏ وَفِي حَدِيثِ عَائِشَةَ ‏"‏ وَالسُّلْطَانُ وَلِيُّ مَنْ لاَ وَلِيَّ لَهُ ‏"‏ ‏.‏\hadithno{1880}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that:Aisha and Ibn Abbas said: “The Messenger of Allah said: 'There is no marriage except with a guardian.' ”According to the Hadith of Aishah: “And the ruler is the guardian of the one who does not have a guardian. ”}}
\hadithdefcmd{ibnmajah}{1881}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا أَبُو إِسْحَاقَ الْهَمْدَانِيُّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ ‏.‏\hadithno{1881}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Musa that:the Messenger of Allah said: “There is no marriage except with a guardian.”}}
\hadithdefcmd{ibnmajah}{1882}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ الْعَتَكِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ مَرْوَانَ الْعُقَيْلِيُّ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُزَوِّجُ الْمَرْأَةُ الْمَرْأَةَ وَلاَ تُزَوِّجُ الْمَرْأَةُ نَفْسَهَا فَإِنَّ الزَّانِيَةَ هِيَ الَّتِي تُزَوِّجُ نَفْسَهَا ‏"‏ ‏.‏\hadithno{1882}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah said: “No woman should arrange the marriage of another woman, and no woman should arrange her own marriage. The adulteress is the one who arranges her own marriage.”}}
\hadithdefcmd{ibnmajah}{1883}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الشِّغَارِ وَالشِّغَارُ أَنْ يَقُولَ الرَّجُلُ لِلرَّجُلِ زَوِّجْنِي ابْنَتَكَ أَوْ أُخْتَكَ عَلَى أَنْ أُزَوِّجَكَ ابْنَتِي أَوْ أُخْتِي ‏.‏ وَلَيْسَ بَيْنَهُمَا صَدَاقٌ ‏.‏\hadithno{1883}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that:Ibn Umar said: “The Messenger of Allah forbade Shighar. Shighar is when a man says to another man: 'Marry your daughter or sister to me, on condition that I will marry my daughter or sister to you,' and they do not give any dower (i.e. neither of them give other the dower).”}}
\hadithdefcmd{ibnmajah}{1884}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الشِّغَارِ ‏.‏\hadithno{1884}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that:Abu Hurairah said: “The Messenger of Allah forbade Shighar.”}}
\hadithdefcmd{ibnmajah}{1885}{حَدَّثَنَا الْحُسَيْنُ بْنُ مَهْدِيٍّ، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَاَ مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ شِغَارَ فِي الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{1885}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that:the Messenger of Allah said: “There is no Shighar in Islam.”}}
\hadithdefcmd{ibnmajah}{1886}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عَبْدُ الْعَزِيزِ الدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ كَمْ كَانَ صَدَاقُ نِسَاءِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ كَانَ صَدَاقُهُ فِي أَزْوَاجِهِ اثْنَتَىْ عَشْرَةَ أُوقِيَّةً وَنَشًّا هَلْ تَدْرِي مَا النَّشُّ هُوَ نِصْفُ أُوقِيَّةٍ وَذَلِكَ خَمْسُمِائَةِ دِرْهَمٍ ‏.‏\hadithno{1886}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that:Abu Salamah said: “I asked Aishah: 'How much was the dowry of the wives of the Prophet?' She said: 'The dowry he gave to his wives was twelve Uqiyyah and a Nash (of silver). Do you know what a Nash is? It is one half of an Uqiyyah. And that is equal to to five hundred Dirham.' ”}}
\hadithdefcmd{ibnmajah}{1887}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ ابْنِ عَوْنٍ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي الْعَجْفَاءِ السُّلَمِيِّ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ لاَ تُغَالُوا صَدَاقَ النِّسَاءِ فَإِنَّهَا لَوْ كَانَتْ مَكْرُمَةً فِي الدُّنْيَا أَوْ تَقْوًى عِنْدَ اللَّهِ كَانَ أَوْلاَكُمْ وَأَحَقَّكُمْ بِهَا مُحَمَّدٌ ـ صلى الله عليه وسلم ـ مَا أَصْدَقَ امْرَأَةً مِنْ نِسَائِهِ وَلاَ أُصْدِقَتِ امْرَأَةٌ مِنْ بَنَاتِهِ أَكْثَرَ مِنِ اثْنَتَىْ عَشْرَةَ أُوقِيَّةً وَإِنَّ الرَّجُلَ لَيُثَقِّلُ صَدَقَةَ امْرَأَتِهِ حَتَّى يَكُونَ لَهَا عَدَاوَةٌ فِي نَفْسِهِ وَيَقُولُ قَدْ كَلِفْتُ إِلَيْكِ عَلَقَ الْقِرْبَةِ أَوْ عَرَقَ الْقِرْبَةِ ‏.‏ وَكُنْتُ رَجُلاً عَرَبِيًّا مُوَلَّدًا مَا أَدْرِي مَا عَلَقُ الْقِرْبَةِ أَوْ عَرَقُ الْقِرْبَةِ ‏.‏\hadithno{1887}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that:Abu Ajfa As-Sulami said: “Umar bin Khattab said: 'Do not go to extremes with regard to the dowries of women, for if that were a sign of honor and dignity in this world or a sign of Taqwa before Allah, then Muhammad (ﷺ) would have done that before you. But he did not give any of his wives and none of his daughters were given more than twelve uqiyyah. A man may increase dowry until he feels resentment against her and says: “You cost me everything I own,” or, “You caused me a great deal of hardship.”'” (Hassan)}}
\hadithdefcmd{ibnmajah}{1888}{حَدَّثَنَا أَبُو عُمَرَ الضَّرِيرُ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، مِنْ بَنِي فَزَارَةَ تَزَوَّجَ عَلَى نَعْلَيْنِ فَأَجَازَ النَّبِيُّ ـ صلى الله عليه وسلم ـ نِكَاحَهُ ‏.‏\hadithno{1888}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdullah bin Amir bin Rabiah from his father, that:A man among Banu Fazarah got married for a pair of sandals, and the Prophet permitted his marriage}}
\hadithdefcmd{ibnmajah}{1889}{حَدَّثَنَا حَفْصُ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ مَنْ يَتَزَوَّجُهَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَنَا ‏.‏ فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَعْطِهَا وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ فَقَالَ لَيْسَ مَعِي ‏.‏ قَالَ ‏"‏ قَدْ زَوَّجْتُكَهَا عَلَى مَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{1889}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that:Sahl bin Sa'd said: “A woman came to the Prophet and he said: 'Who will marry her ?' A man said: 'I will.' The Prophet said: 'Give her something, even if it is an iron ring.' He said: 'I do not have one.' He said: 'I marry her to you for what you know of the Quran.'”}}
\hadithdefcmd{ibnmajah}{1890}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، مُحَمَّدُ بْنُ يَزِيدَ حَدَّثَنَا يَحْيَى بْنُ يَمَانٍ، حَدَّثَنَا الأَغَرُّ الرَّقَاشِيُّ، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ تَزَوَّجَ عَائِشَةَ عَلَى مَتَاعِ بَيْتٍ قِيمَتُهُ خَمْسُونَ دِرْهَمًا ‏.‏\hadithno{1890}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Saeed Al-Khudri that:the Prophet (ﷺ) married Aishah with the household goods the value of which was fifty Dirham}}
\hadithdefcmd{ibnmajah}{1891}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ فِرَاسٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ سُئِلَ عَنْ رَجُلٍ، تَزَوَّجَ امْرَأَةً فَمَاتَ عَنْهَا وَلَمْ يَدْخُلْ بِهَا وَلَمْ يَفْرِضْ لَهَا ‏.‏ قَالَ فَقَالَ عَبْدُ اللَّهِ لَهَا الصَّدَاقُ وَلَهَا الْمِيرَاثُ وَعَلَيْهَا الْعِدَّةُ ‏.‏ فَقَالَ مَعْقِلُ بْنُ سِنَانٍ الأَشْجَعِيُّ شَهِدْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَضَى فِي بَرْوَعَ بِنْتِ وَاشِقٍ بِمِثْلِ ذَلِكَ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، مِثْلَهُ ‏.‏\hadithno{1891}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Masruq that:Abdullah was asked about a man who married a woman and died without having consummated the marriage with her, nor stipulating the dowry. Abdullah said: “The dowry is hers, and the inheritance is hers and she has to observe the waiting period.” Ma'qil bin Sinan Al-Ashja'i said: “I saw the Messenger of Allah (ﷺ) pass a similar ruling concerning Birwa' bint Washiq.” (Sahih) Another chain from 'Alqamah, from Abdullah, with similar wording. It was narrated from Masruq that: Abdullah was asked about a man who married a woman and died without having consummated the marriage with her, nor stipulating the dowry. Abdullah said: “The dowry is hers, and the inheritance is hers and she has to observe the waiting period.” Ma'qil bin Sinan Al-Ashja'i said: “I saw the Messenger of Allah pass a similar ruling concerning Birwa' bint Washiq.” (Sahih) Another chain from 'Alqamah, from Abdullah, with similar wording}}
\hadithdefcmd{ibnmajah}{1892}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنِي أَبِي، عَنْ جَدِّي أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ أُوتِيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ جَوَامِعَ الْخَيْرِ وَخَوَاتِمَهُ - أَوْ قَالَ فَوَاتِحَ الْخَيْرِ - فَعَلَّمَنَا خُطْبَةَ الصَّلاَةِ وَخُطْبَةَ الْحَاجَةِ خُطْبَةُ الصَّلاَةِ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏ وَخُطْبَةُ الْحَاجَةِ إِنَّ الْحَمْدَ لِلَّهِ نَحْمَدُهُ وَنَسْتَعِينُهُ وَنَسْتَغْفِرُهُ وَنَعُوذُ بِاللَّهِ مِنْ شُرُورِ أَنْفُسِنَا وَمِنْ سَيِّئَاتِ أَعْمَالِنَا مَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلْ فَلاَ هَادِيَ لَهُ وَأَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏ ثُمَّ تَصِلُ خُطْبَتَكَ بِثَلاَثِ آيَاتٍ مِنْ كِتَابِ اللَّهِ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ حَقَّ تُقَاتِهِ‏\}‏ إِلَى آخِرِ الآيَةِ ‏\{‏ وَاتَّقُوا اللَّهَ الَّذِي تَسَاءَلُونَ بِهِ وَالأَرْحَامَ ‏\}‏ إِلَى آخِرِ الآيَةِ ‏\{‏اتَّقُوا اللَّهَ وَقُولُوا قَوْلاً سَدِيدًا يُصْلِحْ لَكُمْ أَعْمَالَكُمْ وَيَغْفِرْ لَكُمْ ذُنُوبَكُمْ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{1892}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that:`Abdullah bin Mas`ud said: “The Messenger of Allah (ﷺ) was granted a combination of all manner of goodness, as well as its seal,” or he said: “The opening (of the way to) all good. He (ﷺ) taught us the Khutbah of prayer and Khutbah of need. 'The Khutbah of prayer is: At-tahiyyatu lillahi was-salawatu wat-tayyibat. As-salamu `alaika ayyuhan-Nabiyyu was rahmat-ullahi was barakatuhu. As-salamu `alaina wa `ala `ibadillahis-salihin. Ashhadu an la ilaha illallah. Wa ashhadu anna Muhammadan `abduhu wa rasuluh (All compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah and His blessings. Peace be upon us and upon the righteous slaves of Allah. I bear witness that none has the right to be worshiped but Allah. And I bear witness that Muhammad (ﷺ) is His slave and Messenger). The Khutbah of need is: Al-hamdu lillahi nahmadhu wa nasta`inuhu wa nastaghfiruhu, wa na`udhu billahi min shururi anfusina wa min sayi'ati a`malina, man yahdihillahu fala mudilla lahu, wa man yudlil fala hadiya lahu. Wa ashadu an la ilaha illallahu wahduhu la sharika lahu, wa anna Muhammadan `abduhu wa rasuluhu. (Praise is to Allah, we praise Him and we seek His help and His forgiveness. We seek refuge with Allah from the evil of our own souls and from our bad deeds, Whomsoever Allah guides will never be led astray; and whomsoever is led astray, no one can guide. I bear witness that none has the right to be worshiped but Allah, alone with no partner or associate, and that Muhammad (ﷺ) is His slave and His Messenger). Then add to your Khutbah the following three verses: 'O you who believe! Fear Allah as He should be feared, and die not except in the state of Islam (as Muslims) with complete submission to Allah.' And: 'O mankind! Be dutiful to your Lord, Who created you from a single person, and from him He created his wife, and from them both He created many men and women, and fear Allah through Whom you demand your mutual (rights), and (do not cut the relations of) the wombs (kinship). Surely, Allah is Ever an All-Watcher over you.' And: 'O you who believe! Keep your duty to Allah and fear Him, and speak (always) the truth. He will direct you to do righteous good deeds and will forgive you your sins...' until the end of the verse.”}}
\hadithdefcmd{ibnmajah}{1893}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، حَدَّثَنِي عَمْرُو بْنُ سَعِيدٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ نَحْمَدُهُ وَنَسْتَعِينُهُ وَنَعُوذُ بِاللَّهِ مِنْ شُرُورِ أَنْفُسِنَا وَمِنْ سَيِّئَاتِ أَعْمَالِنَا مَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلْ فَلاَ هَادِيَ لَهُ وَأَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏ أَمَّا بَعْدُ ‏"‏ ‏.‏\hadithno{1893}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn `Abbas that:The Prophet (ﷺ) said: “Al-hamdu lillahi nahmadhu wa nasta`inuhu wa na`udhu billahi min shururi anfusina wa min sayi'ati a`malina, man yahdihillahu fala mudilla lahu, wa man yudlil fala hadiya lahu. Wa ashadu an la ilaha illallahu wahduhu la sharika lahu, wa anna Muhammadan `abduhu wa rasuluhu. Amma ba`d. (Praise is to Allah, we praise Him and we seek His help. We seek refuge with Allah from the evil of our own souls and from our bad deeds, Whomsoever Allah guides will never be led astray; and whomsoever is led astray, no one can guide. I bear witness that none has the right to be worshiped but Allah, alone with no partner or associate, and that Muhammad is His slave and His Messenger. To proceed).”}}
\hadithdefcmd{ibnmajah}{1894}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، قَالُوا حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنِ الأَوْزَاعِيِّ، عَنْ قُرَّةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُّ أَمْرٍ ذِي بَالٍ لاَ يُبْدَأُ فِيهِ بِالْحَمْدِ أَقْطَعُ ‏"‏ ‏.‏\hadithno{1894}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah said: “Every important matter that does not start with praise of Allah, is devoid (of blessings).”}}
\hadithdefcmd{ibnmajah}{1895}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَالْخَلِيلُ بْنُ عَمْرٍو، قَالاَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ خَالِدِ بْنِ إِلْيَاسَ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَعْلِنُوا هَذَا النِّكَاحَ وَاضْرِبُوا عَلَيْهِ بِالْغِرْبَالِ ‏"‏ ‏.‏\hadithno{1895}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah:that the Prophet said: “Announce this marriage, and beat the sieve for it.”}}
\hadithdefcmd{ibnmajah}{1896}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بَلْجٍ، عَنْ مُحَمَّدِ بْنِ حَاطِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ فَصْلُ مَا بَيْنَ الْحَلاَلِ وَالْحَرَامِ الدُّفُّ وَالصَّوْتُ فِي النِّكَاحِ ‏"‏ ‏.‏\hadithno{1896}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muhammad bin Hatib that the Messenger of Allah said:“What differentiates between the lawful and the unlawful is (beating) the Daff and raising the voices (in song) at the time of marriage.”}}
\hadithdefcmd{ibnmajah}{1897}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الْحُسَيْنِ، - اسْمُهُ خَالِدٌ الْمَدَنِيُّ - قَالَ كُنَّا بِالْمَدِينَةِ يَوْمَ عَاشُورَاءَ وَالْجَوَارِي يَضْرِبْنَ بِالدُّفِّ وَيَتَغَنَّيْنَ فَدَخَلْنَا عَلَى الرُّبَيِّعِ بِنْتِ مُعَوِّذٍ فَذَكَرْنَا ذَلِكَ لَهَا ‏.‏ فَقَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَبِيحَةَ عُرْسِي وَعِنْدِي جَارِيَتَانِ تُغَنِّيَانِ وَتَنْدُبَانِ آبَائِي الَّذِينَ قُتِلُوا يَوْمَ بَدْرٍ وَتَقُولاَنِ فِيمَا تَقُولاَنِ وَفِينَا نَبِيٌّ يَعْلَمُ مَا فِي غَدٍ ‏.‏ فَقَالَ ‏ "‏ أَمَّا هَذَا فَلاَ تَقُولُوهُ مَا يَعْلَمُ مَا فِي غَدٍ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{1897}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Husain, whose name was Khalid Al-Madani, said:“We were in Al-Madinah on the Say of 'Ashura and the girls were beating the Daff and singing. We entered upon Rubai' bint Mu'awwidh and mentioned that to her. She said: 'The Messenger of Allah entered upon me on the morning of my wedding, and there were two girls with me who were singing and mentioning the qualities of my forefathers who were killed on the Day of Badr. One of the things they were saying was: “Among us there is a Prophet who knows what will happen tomorrow.” He said: “Do not say this, for no one knows what will happen tomorrow except Allah.”}}
\hadithdefcmd{ibnmajah}{1898}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ أَبُو بَكْرٍ وَعِنْدِي جَارِيَتَانِ مِنْ جَوَارِي الأَنْصَارِ تُغَنِّيَانِ بِمَا تَقَاوَلَتْ بِهِ الأَنْصَارُ فِي يَوْمِ بُعَاثٍ ‏.‏ قَالَتْ وَلَيْسَتَا بِمُغَنِّيَتَيْنِ ‏.‏ فَقَالَ أَبُو بَكْرٍ أَبِمَزْمُورِ الشَّيْطَانِ فِي بَيْتِ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَذَلِكَ فِي يَوْمِ عِيدِ الْفِطْرِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا أَبَا بَكْرٍ إِنَّ لِكُلِّ قَوْمٍ عِيدًا وَهَذَا عِيدُنَا ‏"‏ ‏.‏\hadithno{1898}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Aishah said:“Abu Bakr entered upon me, and there were two girls from the Ansar with me, singing about the Day of Bu'ath.” She said: “And they were not really singers. Abu Bakr said: 'The wind instruments of Satan in the house of the Prophet ?' That was on the day of 'Eid(Al-Fitr). But the Prophet said: 'O Abu Bakr, every people has its festival and this is our festival.' ”}}
\hadithdefcmd{ibnmajah}{1899}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عَوْفٌ، عَنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ مَرَّ بِبَعْضِ الْمَدِينَةِ فَإِذَا هُوَ بِجَوَارٍ يَضْرِبْنَ بِدُفِّهِنَّ وَيَتَغَنَّيْنَ وَيَقُلْنَ نَحْنُ جَوَارٍ مِنْ بَنِي النَّجَّارِ يَا حَبَّذَا مُحَمَّدٌ مِنْ جَارِ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ يَعْلَمُ اللَّهُ إِنِّي لأُحِبُّكُنَّ ‏"‏ ‏.‏\hadithno{1899}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik:that the Prophet passed by some part of Al-Madinah and saw some girls beating their Daff And singing, saying: “We are girls from Banu Najjar what an excellent neighbor is Muhammad.” The Prophet said: “Allah knows that you are dear to me.”}}
\hadithdefcmd{ibnmajah}{1900}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا جَعْفَرُ بْنُ عَوْنٍ، أَنْبَأَنَا الأَجْلَحُ، عَنْ أَبِي الزُّبَيْرِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَنْكَحَتْ عَائِشَةُ ذَاتَ قَرَابَةٍ لَهَا مِنَ الأَنْصَارِ فَجَاءَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ أَهْدَيْتُمُ الْفَتَاةَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ أَرْسَلْتُمْ مَعَهَا مَنْ يُغَنِّي قَالَتْ لاَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ الأَنْصَارَ قَوْمٌ فِيهِمْ غَزَلٌ فَلَوْ بَعَثْتُمْ مَعَهَا مَنْ يَقُولُ أَتَيْنَاكُمْ أَتَيْنَاكُمْ فَحَيَّانَا وَحَيَّاكُمْ ‏"‏ ‏.‏\hadithno{1900}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn'Abbas said:'Aisha arranged a marriage for a female relative of hers among the Ansar. The Messenger of Allah came and said: Have you taken the girl (to her husbands house)?” They said: “Yes.” He said: “Have you sent someone with her to sing?” She said: “No.” The Messenger of Allah said: “The Ansar are People with romantic feelings. Why don't you send someone with her to say: 'We have come to you, we have come to you, may Allah bless you and us?'”}}
\hadithdefcmd{ibnmajah}{1901}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْفِرْيَابِيُّ، عَنْ ثَعْلَبَةَ بْنِ أَبِي مَالِكٍ التَّمِيمِيِّ، عَنْ لَيْثٍ، عَنْ مُجَاهِدٍ، قَالَ كُنْتُ مَعَ ابْنِ عُمَرَ فَسَمِعَ صَوْتَ، طَبْلٍ فَأَدْخَلَ إِصْبَعَيْهِ فِي أُذُنَيْهِ ثُمَّ تَنَحَّى حَتَّى فَعَلَ ذَلِكَ ثَلاَثَ مَرَّاتٍ ‏.‏ ثُمَّ قَالَ هَكَذَا فَعَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1901}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mujahid said:“I was with Ibn Umar, and he heard the sound of a drum, so he put his fingers in his ears and turned away. He did that three times, then he said: “This is what I saw the Messenger of Allah do.' ”}}
\hadithdefcmd{ibnmajah}{1902}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ دَخَلَ عَلَيْهَا فَسَمِعَ مُخَنَّثًا وَهُوَ يَقُولُ لِعَبْدِ اللَّهِ بْنِ أَبِي أُمَيَّةَ إِنْ يَفْتَحِ اللَّهُ الطَّائِفَ غَدًا دَلَلْتُكَ عَلَى امْرَأَةٍ تُقْبِلُ بِأَرْبَعٍ وَتُدْبِرُ بِثَمَانٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَخْرِجُوهُ مِنْ بُيُوتِكُمْ ‏"‏ ‏.‏\hadithno{1902}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Umm Salamah:that the Prophet Mohammad entered upon her, and he heard an effeminate man say to 'Abdullah bin Abu Umayyah: “If Allah enables you to conquer Ta'if tommorrow, I will show you a woman who comes in on four (rolls of fat) and goes out on eight.” The Messenger of Allah said: “Throw them out of your houses.”}}
\hadithdefcmd{ibnmajah}{1903}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ لَعَنَ الْمَرْأَةَ تَتَشَبَّهُ بِالرِّجَالِ وَالرَّجُلَ يَتَشَبَّهُ بِالنِّسَاءِ ‏.‏\hadithno{1903}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah:that the Messenger of Allah cursed women who imitate men and men who imitate women}}
\hadithdefcmd{ibnmajah}{1904}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ لَعَنَ الْمُتَشَبِّهِينَ مِنَ الرِّجَالِ بِالنِّسَاءِ وَلَعَنَ الْمُتَشَبِّهَاتِ مِنَ النِّسَاءِ بِالرِّجَالِ ‏.‏\hadithno{1904}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas:that the Prophet cursed men who imitate women and woman who imitate men}}
\hadithdefcmd{ibnmajah}{1905}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا رَفَّأَ قَالَ ‏ "‏ بَارَكَ اللَّهُ لَكُمْ وَبَارَكَ عَلَيْكُمْ وَجَمَعَ بَيْنَكُمَا فِي خَيْرٍ ‏"‏ ‏.‏\hadithno{1905}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah:that the Prophet used to say, when offering congratulations of the occasion of marriage: “Barak Allahu lakum, wa barak 'alaikum, wa jama'a bainakuma fi khair (May Allah bless you and bestow blessings upon you, and bring you together in harmony).”}}
\hadithdefcmd{ibnmajah}{1906}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ عَقِيلِ بْنِ أَبِي طَالِبٍ، أَنَّهُ تَزَوَّجَ امْرَأَةً مِنْ بَنِي جُشَمٍ فَقَالُوا بِالرِّفَاءِ وَالْبَنِينَ فَقَالَ لاَ تَقُولُوا هَكَذَا وَلَكِنْ قُولُوا كَمَا قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُمَّ بَارِكْ لَهُمْ وَبَارِكْ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{1906}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from `Aqil bin Abu Talib:that he married a woman from Banu Jusham, and they said: “May you live in harmony and have many sons.” He said: “Do not say that, rather say what the Messenger of Allah said: 'Allahumma barik lahum wa barik `alaihim (O Allah, bless them and bestow blessings upon them).' ”}}
\hadithdefcmd{ibnmajah}{1907}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَأَى عَلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَثَرَ صُفْرَةٍ فَقَالَ ‏"‏ مَا هَذَا أَوْ مَهْ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي تَزَوَّجْتُ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ فَقَالَ ‏"‏ بَارَكَ اللَّهُ لَكَ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{1907}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik:the Prophet saw traces of yellow perfume on 'Abdur-Rahmaan bin 'Awf, and he asked him “What is this?” He said: “O Messenger of Allah, I married a women for the weight of a Nawah (Stone) of gold. He said: “May Allah bless you. Give a feast even if it is only with one sheep.”}}
\hadithdefcmd{ibnmajah}{1908}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَوْلَمَ عَلَى شَىْءٍ مِنْ نِسَائِهِ مَا أَوْلَمَ عَلَى زَيْنَبَ فَإِنَّهُ ذَبَحَ شَاةً ‏.‏\hadithno{1908}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“I never saw the Messenger of Allah give a wedding feast for any of his wives like the feast he gave for Zainab, for which he slaughtered a sheep.”}}
\hadithdefcmd{ibnmajah}{1909}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، وَغِيَاثُ بْنُ جَعْفَرٍ الرَّحَبِيُّ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا وَائِلُ بْنُ دَاوُدَ، عَنِ ابْنِهِ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَوْلَمَ عَلَى صَفِيَّةَ بِسَوِيقٍ وَتَمْرٍ ‏.‏\hadithno{1909}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas bin Malik:that the Prophet offered Sawiq and dates as a wedding feast for Safiyyah}}
\hadithdefcmd{ibnmajah}{1910}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ أَبُو خَيْثَمَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلِيِّ بْنِ زَيْدِ بْنِ جُدْعَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ شَهِدْتُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ وَلِيمَةً مَا فِيهَا لَحْمٌ وَلاَ خُبْزٌ ‏.‏ قَالَ ابْنُ مَاجَهْ لَمْ يُحَدِّثْ بِهِ إِلاَّ ابْنُ عُيَيْنَةَ ‏.‏\hadithno{1910}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sufyan (Ibn 'Uyainah) from `Ali bin Zaid bin Ju`dan from Anas bin Malik who said:“I attended a wedding feast for the Prophet in which there was no meat and no bread.” Ibn Majah said: It was not narrated except by Ibn `Uyainah}}
\hadithdefcmd{ibnmajah}{1911}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُفَضَّلُ بْنُ عَبْدِ اللَّهِ، عَنْ جَابِرٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، وَأُمِّ سَلَمَةَ قَالَتَا أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نُجَهِّزَ فَاطِمَةَ حَتَّى نُدْخِلَهَا عَلَى عَلِيٍّ فَعَمَدْنَا إِلَى الْبَيْتِ فَفَرَشْنَاهُ تُرَابًا لَيِّنًا مِنْ أَعْرَاضِ الْبَطْحَاءِ ثُمَّ حَشَوْنَا مِرْفَقَتَيْنِ لِيفًا فَنَفَشْنَاهُ بِأَيْدِينَا ثُمَّ أَطْعَمْنَا تَمْرًا وَزَبِيبًا وَسَقَيْنَا مَاءً عَذْبًا وَعَمَدْنَا إِلَى عُودٍ فَعَرَضْنَاهُ فِي جَانِبِ الْبَيْتِ لِيُلْقَى عَلَيْهِ الثَّوْبُ وَيُعَلَّقَ عَلَيْهِ السِّقَاءُ فَمَا رَأَيْنَا عُرْسًا أَحْسَنَ مِنْ عُرْسِ فَاطِمَةَ ‏.‏\hadithno{1911}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah and Umm Salamah said:“The Messenger of Allah commanded us to prepare Fatimah (for her wedding) and take her in to 'Ali. We went to the house and sprinkled it with soft earth from the land of Batha'. Then we stuffed two pillows with (date - palm) fiber which we picked with our own hands. Then we offered dates and raisins to eat, and sweet water to drink. We went and got some wood and set it up at the side of the room, to hang the clothes and water skins on. And we never saw any wedding better than the wedding of Fatimah.”}}
\hadithdefcmd{ibnmajah}{1912}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ دَعَا أَبُو أُسَيْدٍ السَّاعِدِيُّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى عُرْسِهِ فَكَانَتْ خَادِمَهُمُ الْعَرُوسُ ‏.‏ قَالَتْ تَدْرِي مَا سَقَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَتْ أَنْقَعْتُ تَمَرَاتٍ مِنَ اللَّيْلِ فَلَمَّا أَصْبَحْتُ صَفَّيْتُهُنَّ فَأَسْقَيْتُهُنَّ إِيَّاهُ ‏.‏\hadithno{1912}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Sahl bin Sa'd As-Sa'idi said:“Abu Usaid As-Sa'idi invited the Messenger of Allah to his wedding, and the bride herself served them. She said: 'Do you know what I gave the Messenger of Allah to drink? I had soaked some dates the night before, then in the morning I strained them and gave him that water to drink.' ”}}
\hadithdefcmd{ibnmajah}{1913}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ شَرُّ الطَّعَامِ طَعَامُ الْوَلِيمَةِ يُدْعَى لَهَا الأَغْنِيَاءُ وَيُتْرَكُ الْفُقَرَاءُ وَمَنْ لَمْ يُجِبْ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{1913}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The worst of food is food of a wedding feast to which the rich are invited and the poor are not. Whoever does not accept an invitation has disobeyed Allah and His Messenger.' ”}}
\hadithdefcmd{ibnmajah}{1914}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى وَلِيمَةِ عُرْسٍ فَلْيُجِبْ ‏"‏ ‏.‏\hadithno{1914}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar:that the Messenger of Allah said: “If anyone of you is invited to a wedding feast, let him accept.”}}
\hadithdefcmd{ibnmajah}{1915}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَادَةَ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ حُسَيْنٍ أَبُو مَالِكٍ النَّخَعِيُّ، عَنْ مَنْصُورٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْوَلِيمَةُ أَوَّلَ يَوْمٍ حَقٌّ وَالثَّانِي مَعْرُوفٌ وَالثَّالِثُ رِيَاءٌ وَسُمْعَةٌ ‏"‏ ‏.‏\hadithno{1915}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah:that the Messenger of Allah said: 'The wedding feast on the first day is an obligation, on the second day is a custom and on the third day is showing off.”}}
\hadithdefcmd{ibnmajah}{1916}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لِلثَّيِّبِ ثَلاَثًا وَلِلْبِكْرِ سَبْعًا ‏"‏ ‏.‏\hadithno{1916}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas:that the Messenger of Allah said: “Three days for a previously-married woman and seven days for a virgin.”}}
\hadithdefcmd{ibnmajah}{1917}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، عَنْ عَبْدِ الْمَلِكِ، - يَعْنِي ابْنَ أَبِي بَكْرِ بْنِ الْحَارِثِ بْنِ هِشَامٍ - عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ لَمَّا تَزَوَّجَ أُمَّ سَلَمَةَ أَقَامَ عِنْدَهَا ثَلاَثًا وَقَالَ ‏ "‏ لَيْسَ بِكِ عَلَى أَهْلِكِ هَوَانٌ إِنْ شِئْتِ سَبَّعْتُ لَكِ وَإِنْ سَبَّعْتُ لَكِ سَبَّعْتُ لِنِسَائِي ‏"‏ ‏.‏\hadithno{1917}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Al-Harith from his father that when when the Messenger of Allah (ﷺ) married Umm Salamah, he stayed with her for three days, then he said:“You are not insignificant in your husband's eyes. If you wish, I will stay with you for seven days, but then I will stay with my other wives for seven days too.”}}
\hadithdefcmd{ibnmajah}{1918}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَصَالِحُ بْنُ مُحَمَّدِ بْنِ يَحْيَى الْقَطَّانُ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا أَفَادَ أَحَدُكُمُ امْرَأَةً أَوْ خَادِمًا أَوْ دَابَّةً فَلْيَأْخُذْ بِنَاصِيَتِهَا وَلْيَقُلِ اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنْ خَيْرِهَا وَخَيْرِ مَا جُبِلَتْ عَلَيْهِ وَأَعُوذُ بِكَ مِنْ شَرِّهَا وَشَرِّ مَا جُبِلَتْ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1918}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr:that the Prophet said: “When anyone of you gets a new wife, a servant, or an animal, let him take hold of the forelock and say: Allahumma inni as`aluka min khayriha wa khayri ma jubilat 'alaihi, wa 'audhu bika min sharriha wa sharri ma jubilat `alaih (O Allah, I ask You for the goodness within her and the goodness that she is inclined towards, and I seek refuge with you from the evil to which she is inclined).' ”}}
\hadithdefcmd{ibnmajah}{1919}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَوْ أَنَّ أَحَدَكُمْ إِذَا أَتَى امْرَأَتَهُ قَالَ اللَّهُمَّ جَنِّبْنِي الشَّيْطَانَ وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنِي ثُمَّ كَانَ بَيْنَهُمَا وَلَدٌ لَمْ يُسَلِّطِ اللَّهُ عَلَيْهِ الشَّيْطَانَ - أَوْ لَمْ يَضُرَّهُ - ‏"‏ ‏.‏\hadithno{1919}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn `Abbas:that the Prophet said: “When anyone of you has intercourse with his wife, let him say: Allahumma jannibnish-Shaitana wa jannibish-Shaitana ma razaqtani (O Allah, keep Satan away from me and keep Satan away from that with which You bless me).' Then if they have a child, Allah will never allow Satan to gain control over him or he will never harm him.”}}
\hadithdefcmd{ibnmajah}{1920}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، وَأَبُو أُسَامَةَ قَالاَ حَدَّثَنَا بَهْزُ بْنُ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ عَوْرَاتُنَا مَا نَأْتِي مِنْهَا وَمَا نَذَرُ قَالَ ‏"‏ احْفَظْ عَوْرَتَكَ إِلاَّ مِنْ زَوْجَتِكَ أَوْ مَا مَلَكَتْ يَمِينُكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ كَانَ الْقَوْمُ بَعْضُهُمْ فِي بَعْضٍ قَالَ ‏"‏ إِنِ اسْتَطَعْتَ أَنْ لاَ تُرِيَهَا أَحَدًا فَلاَ تُرِيَنَّهَا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ فَإِنْ كَانَ أَحَدُنَا خَالِيًا قَالَ ‏"‏ فَاللَّهُ أَحَقُّ أَنْ يُسْتَحْيَى مِنْهُ مِنَ النَّاسِ ‏"‏ ‏.‏\hadithno{1920}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father that his grandfather said:“I said: 'O Messenger of Allah, with regard to our 'Awrah, what may we uncover of it and what must we conceal?' He said: 'Cover your 'Awrah, except from your wife and those whom your right hand possesses.' I said: 'O Messenger of Allah, what if the people live close together?' He said: 'If you can make sure that no one sees it, then do not let anyone see it.' I said: 'O Messenger of Allah, what if one of us is alone?' He said: 'Allah is more deserving that you should feel shy before Him than People.' ”}}
\hadithdefcmd{ibnmajah}{1921}{حَدَّثَنَا إِسْحَاقُ بْنُ وَهْبٍ الْوَاسِطِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ الْقَاسِمِ الْهَمْدَانِيُّ، حَدَّثَنَا الأَحْوَصُ بْنُ حَكِيمٍ، عَنْ أَبِيهِ، وَرَاشِدِ بْنِ سَعْدٍ، وَعَبْدِ الأَعْلَى بْنِ عَدِيٍّ، عَنْ عُتْبَةَ بْنِ عَبْدٍ السُّلَمِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَتَى أَحَدُكُمْ أَهْلَهُ فَلْيَسْتَتِرْ وَلاَ يَتَجَرَّدْ تَجَرُّدَ الْعَيْرَيْنِ ‏"‏ ‏.‏\hadithno{1921}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Utbah bin 'Abd Sulamain:that the Messenger of Allah said: “When anyone of you has intercourse with his wife, let him cover himself and not be naked liked donkeys.”}}
\hadithdefcmd{ibnmajah}{1922}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ مُوسَى بْنِ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ مَوْلًى، لِعَائِشَةَ عَنْ عَائِشَةَ، قَالَتْ مَا نَظَرْتُ - أَوْ مَا رَأَيْتُ - فَرْجَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَطُّ ‏.‏ قَالَ أَبُو بَكْرٍ قَالَ أَبُو نُعَيْمٍ عَنْ مَوْلاَةٍ لِعَائِشَةَ ‏.‏\hadithno{1922}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from a freed slave of 'Aishah that 'Aishah said:“I never looked at or I never saw the private part of the Messenger of Allah.' ”}}
\hadithdefcmd{ibnmajah}{1923}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنِ الْحَارِثِ بْنِ مُخَلَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَنْظُرُ اللَّهُ إِلَى رَجُلٍ جَامَعَ امْرَأَتَهُ فِي دُبُرِهَا ‏"‏ ‏.‏\hadithno{1923}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah:that the Prophet said: “Allah will not look at a man who has intercourse with his wife in her buttocks.”}}
\hadithdefcmd{ibnmajah}{1924}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنْ حَجَّاجِ بْنِ أَرْطَاةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ عَبْدِ اللَّهِ بْنِ هَرَمِيٍّ، عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ لاَ تَأْتُوا النِّسَاءَ فِي أَدْبَارِهِنَّ ‏"‏ ‏.‏\hadithno{1924}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Khuzaimah bin Thabit:That the Messenger of Allah (ﷺ) said: “Allah is not too shy to tell the truth,” three times. “Do not have intercourse with women in their buttocks.”}}
\hadithdefcmd{ibnmajah}{1925}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، وَجَمِيلُ بْنُ الْحَسَنِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَتْ يَهُودُ تَقُولُ مَنْ أَتَى امْرَأَةً فِي قُبُلِهَا مِنْ دُبُرِهَا كَانَ الْوَلَدُ أَحْوَلَ فَأَنْزَلَ اللَّهُ سُبْحَانَهُ ‏\{نِسَاؤُكُمْ حَرْثٌ لَكُمْ فَأْتُوا حَرْثَكُمْ أَنَّى شِئْتُمْ\}‏ ‏.‏\hadithno{1925}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Muhammad bin Munkadir:that he heard Jabir bin 'Abdullah say: “The Jews used to say that if a man has intercourse with a woman in her vagina from the back, the child would have a squint. Then Allah, Glorious is He, revealed: 'Your wives are a tilth for you, so go to your tilth, when or how you will.' ”}}
\hadithdefcmd{ibnmajah}{1926}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْعَزْلِ فَقَالَ ‏ "‏ أَوَتَفْعَلُونَ لاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا فَإِنَّهُ لَيْسَ مِنْ نَسَمَةٍ قَضَى اللَّهُ لَهَا أَنْ تَكُونَ إِلاَّ هِيَ كَائِنَةٌ ‏"‏ ‏.‏\hadithno{1926}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Kudri said:“A man asked the Messenger of about coitus interruptus. He said: 'Do you do that? If you do not do so, it will not harm; for there is no soul that (SWT) has decreed will exist but it will come into being.' “}}
\hadithdefcmd{ibnmajah}{1927}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَعْزِلُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَالْقُرْآنُ يَنْزِلُ ‏.‏\hadithno{1927}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Jabir said:'We used to practice coitus interruptus during the time of the Messenger of Allah when the Qur'an was being revealed.”}}
\hadithdefcmd{ibnmajah}{1928}{\hadithno{1928}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif}\hadithtrans{It was narrated that 'Umar bin Khattab said: “The Messenger of Allah forbade practicing coitus interruptus with a free woman except with her consent.”}}
\hadithdefcmd{ibnmajah}{1929}{\hadithno{1929}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{It was narrated from Abu Hurairah: that the Prophet said: “A woman should not be married to a man who is married to her paternal aunt of maternal aunt (at the same time).”}}
\hadithdefcmd{ibnmajah}{1930}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَعْقُوبَ بْنِ عُتْبَةَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَنْهَى عَنْ نِكَاحَيْنِ أَنْ يَجْمَعَ الرَّجُلُ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا وَبَيْنَ الْمَرْأَةِ وَخَالَتِهَا ‏.‏\hadithno{1930}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:“I heard the Messenger of Allah forbid two types of marriage: For a man to be married to a woman and her paternal aunt (at the same time), and to a woman and her maternal aunt( at the same time).”}}
\hadithdefcmd{ibnmajah}{1931}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا أَبُو بَكْرٍ النَّهْشَلِيُّ، حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي مُوسَى، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُنْكَحُ الْمَرْأَةُ عَلَى عَمَّتِهَا وَلاَ عَلَى خَالَتِهَا ‏"‏ ‏.‏\hadithno{1931}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Abu Bakr bin Abu Musa narrated that his father said:“The Messenger of Allah said: “A man should not be married to a woman and her paternal aunt or maternal aunt at the same time.”}}
\hadithdefcmd{ibnmajah}{1932}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةَ، رِفَاعَةَ الْقُرَظِيِّ جَاءَتْ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ إِنِّي كُنْتُ عِنْدَ رِفَاعَةَ فَطَلَّقَنِي فَبَتَّ طَلاَقِي فَتَزَوَّجْتُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ وَإِنَّ مَا مَعَهُ مِثْلُ هُدْبَةِ الثَّوْبِ ‏.‏ فَتَبَسَّمَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ أَتُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى تَذُوقِي عُسَيْلَتَهُ وَيَذُوقَ عُسَيْلَتَكِ ‏"‏ ‏.‏\hadithno{1932}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Aishah:that the wife of Rifa'ah Al-Qurazi came to the Messenger of Allah and said: “I was married to Rifa'ah, and he divorced me and made it irrevocable. Then I married ' Abdur-Rahman bin Zubair, and what he has is like the fringe of a garment.” The Prophet smiled and said: “Do you want to go back to Rifa'ah? No, not until you taste his ('Abdur-Rahman's) sweetness and he tastes your sweetness.”}}
\hadithdefcmd{ibnmajah}{1933}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، قَالَ سَمِعْتُ سَالِمَ بْنَ رَزِينٍ، يُحَدِّثُ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي الرَّجُلِ تَكُونُ لَهُ الْمَرْأَةُ فَيُطَلِّقُهَا فَيَتَزَوَّجُهَا رَجُلٌ فَيُطَلِّقُهَا قَبْلَ أَنْ يَدْخُلَ بِهَا أَتَرْجِعُ إِلَى الأَوَّلِ قَالَ ‏ "‏ لاَ ‏.‏ حَتَّى يَذُوقَ الْعُسَيْلَةَ ‏"‏ ‏.‏\hadithno{1933}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar,:from the Prophet, concerning a man who had a wife then divorced her, then another man married her but divorced her before consummating the marriage. Could she go back to the first man? He said: “No, not until he tastes her sweetness.”}}
\hadithdefcmd{ibnmajah}{1934}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، عَنْ زَمْعَةَ بْنِ صَالِحٍ، عَنْ سَلَمَةَ بْنِ وَهْرَامَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْمُحَلِّلَ وَالْمُحَلَّلَ لَهُ ‏.‏\hadithno{1934}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:“The Messenger of Allah cursed the Muhallil and the Muhallal lahu.”}}
\hadithdefcmd{ibnmajah}{1935}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ الْبَخْتَرِيِّ الْوَاسِطِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ ابْنِ عَوْنٍ، وَمُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْمُحَلِّلَ وَالْمُحَلَّلَ لَهُ ‏.‏\hadithno{1935}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:“The Massenger of Allah cursed the Muhallil and the Muhallal lahu.”}}
\hadithdefcmd{ibnmajah}{1936}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ صَالِحٍ الْمِصْرِيُّ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ اللَّيْثَ بْنَ سَعْدٍ، يَقُولُ قَالَ لِي أَبُو مُصْعَبٍ مِشْرَحُ بْنُ هَاعَانَ قَالَ عُقْبَةُ بْنُ عَامِرٍ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَلاَ أُخْبِرُكُمْ بِالتَّيْسِ الْمُسْتَعَارِ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هُوَ الْمُحَلِّلُ لَعَنَ اللَّهُ الْمُحَلِّلَ وَالْمُحَلَّلَ لَهُ ‏"‏ ‏.‏\hadithno{1936}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Uqbah bin 'Amir narrated:that the Messenger of said: 'Shall I not tell you of a borrowed billy goat.” They said: “Yes, O Messenger of!” He said: “He is Muhallil. May curse the Muhallil and the Muhallal lahu.”}}
\hadithdefcmd{ibnmajah}{1937}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنِ الْحَجَّاجِ، عَنِ الْحَكَمِ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَحْرُمُ مِنَ الرَّضَاعِ مَا يَحْرُمُ مِنَ النَّسَبِ ‏"‏ ‏.‏\hadithno{1937}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah:that the Messenger of Allah said: 'Breast-feeding makes unlawful (for marriages) the same things that blood tie make unlawful.”}}
\hadithdefcmd{ibnmajah}{1938}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالاَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أُرِيدَ عَلَى بِنْتِ حَمْزَةَ بْنِ عَبْدِ الْمُطَّلِبِ فَقَالَ ‏ "‏ إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ وَإِنَّهُ يَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ النَّسَبِ ‏"‏ ‏.‏\hadithno{1938}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn 'Abbas:that the Messenger of was offered the daughter of Hamzah bin 'Abdul-Muttalib in marriage, and he said: “She is the daughter of my brother through breastfeeding, and breastfeeding makes unlawful (for marriage) the same things that blood ties make unlawful.”}}
\hadithdefcmd{ibnmajah}{1939}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، حَدَّثَتْهُ أَنَّ أُمَّ حَبِيبَةَ حَدَّثَتْهَا أَنَّهَا، قَالَتْ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ انْكِحْ أُخْتِي عَزَّةَ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَتُحِبِّينَ ذَلِكَ ‏"‏ ‏.‏ قَالَتْ نَعَمْ يَا رَسُولَ اللَّهِ فَلَسْتُ لَكَ بِمُخْلِيَةٍ وَأَحَقُّ مَنْ شَرِكَنِي فِي خَيْرٍ أُخْتِي ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَإِنَّ ذَلِكَ لاَ يَحِلُّ لِي ‏"‏ ‏.‏ قَالَتْ فَإِنَّا نَتَحَدَّثُ أَنَّكَ تُرِيدُ أَنْ تَنْكِحَ دُرَّةَ بِنْتَ أَبِي سَلَمَةَ ‏.‏ فَقَالَ ‏"‏ بِنْتَ أُمِّ سَلَمَةَ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَإِنَّهَا لَوْ لَمْ تَكُنْ رَبِيبَتِي فِي حِجْرِي مَا حَلَّتْ لِي إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ أَرْضَعَتْنِي وَأَبَاهَا ثُوَيْبَةُ فَلاَ تَعْرِضْنَ عَلَىَّ أَخَوَاتِكُنَّ وَلاَ بَنَاتِكُنَّ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ حَبِيبَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{1939}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Urwah bin Zubair that Zainab bint Abi Salmah told him that Umm Habibah told her that she said to Messenger of Allah:“Marry my sister 'Azzah.” The Messenger of Allah said: 'Would you like that? “She said: “Yes, O Messenger of Allah. I am not the only one living with you and the one who most deserves to share good thingswith me is my sister.” The Messenger of Allah said: “But that is not permissible for me.” She said: “But we throught that you wanted to marry Durrah bint Abi Salmah.” The Messenger of Allah said: The daughter of Umm Salamah?” She said: “Yes” The Messenger of Allah said: “Even if she were not my step-daughter who is under my care, she would not be permissible for me, because she is the daughter of my brother through breastfeeding. Tuwaibah breastfed both her father and I. So do not offer your sisters and daughters to me for marriage.”}}
\hadithdefcmd{ibnmajah}{1940}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا ابْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، أَنَّ أُمَّ الْفَضْلِ، حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تُحَرِّمُ الرَّضْعَةُ وَلاَ الرَّضْعَتَانِ أَوِ الْمَصَّةُ وَالْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{1940}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Umm Fadl said:that the Messenger of Allah said: “Breastfeeding once or twice, or suckling once or twice, does not make (marriage) unlawful.”}}
\hadithdefcmd{ibnmajah}{1941}{حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خِدَاشٍ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تُحَرِّمُ الْمَصَّةُ وَالْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{1941}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah:that the Prophet Allah said: “Suckling once or twice does not make (marriage) unlawful.”}}
\hadithdefcmd{ibnmajah}{1942}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، حَدَّثَنَا أَبِي، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ فِيمَا أَنْزَلَ اللَّهُ مِنَ الْقُرْآنِ ثُمَّ سَقَطَ لاَ يُحَرِّمُ إِلاَّ عَشْرُ رَضَعَاتٍ أَوْ خَمْسٌ مَعْلُومَاتٌ ‏.‏\hadithno{1942}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:“Once of the things that Allah revealed in the the Qur'an and then abrogated was that nothing makes marriage prohibited except ten breastfeedings or five well-known (breastfeedings).”}}
\hadithdefcmd{ibnmajah}{1943}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ سَهْلَةُ بِنْتُ سُهَيْلٍ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أَرَى فِي وَجْهِ أَبِي حُذَيْفَةَ الْكَرَاهِيَةَ مِنْ دُخُولِ سَالِمٍ عَلَىَّ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَرْضِعِيهِ ‏"‏ ‏.‏ قَالَتْ كَيْفَ أُرْضِعُهُ وَهُوَ رَجُلٌ كَبِيرٌ فَتَبَسَّمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَالَ ‏"‏ قَدْ عَلِمْتُ أَنَّهُ رَجُلٌ كَبِيرٌ ‏"‏ ‏.‏ فَفَعَلَتْ فَأَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَتْ مَا رَأَيْتُ فِي وَجْهِ أَبِي حُذَيْفَةَ شَيْئًا أَكْرَهُهُ بَعْدُ ‏.‏ وَكَانَ شَهِدَ بَدْرًا ‏.‏\hadithno{1943}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:“Sahlah bint Suhail came to the Prophet and said: 'O Messenger of Allah, I see signs of displeasure on the face of Abu Hudhaifah when Salim enters upon me.” The Prophet said: “Breastfeed him.” She said: “How can I breastfeed him when he is a grown man? The Messenger of Allah smiled and said: “I know that he is a grown man.” So she did that, then she came to the Prophet and said: “I have never seen any signs of displeasure on the face of Abu Hudhayfah after that.” And he was present at (the battle of) Badr}}
\hadithdefcmd{ibnmajah}{1944}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، ‏.‏ وَعَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ نَزَلَتْ آيَةُ الرَّجْمِ وَرَضَاعَةُ الْكَبِيرِ عَشْرًا وَلَقَدْ كَانَ فِي صَحِيفَةٍ تَحْتَ سَرِيرِي فَلَمَّا مَاتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَتَشَاغَلْنَا بِمَوْتِهِ دَخَلَ دَاجِنٌ فَأَكَلَهَا ‏.‏\hadithno{1944}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said:“The Verse of stoning and of breastfeeding an adult ten times was revealed1, and the paper was with me under my pillow. When the Messenger of Allah died, we were preoccupied with his death, and a tame sheep came in and ate it.” 1: These verses were abrogated in recitation but not ruling. Other ahadith establish the number for fosterage to be}}
\hadithdefcmd{ibnmajah}{1945}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ دَخَلَ عَلَيْهَا وَعِنْدَهَا رَجُلٌ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ قَالَتْ هَذَا أَخِي ‏.‏ قَالَ ‏"‏ انْظُرُوا مَنْ تُدْخِلْنَ عَلَيْكُنَّ فَإِنَّ الرَّضَاعَةَ مِنَ الْمَجَاعَةِ ‏"‏ ‏.‏\hadithno{1945}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Aishah:that the Prophet entered upon her and there was a man with her. He said: “Who is this? She said: “This is my brother.” He said: “Look at whom you allow to enter upon you, because the breastfeeding (that makes a person Mahram) is that which satisfies hunger.”}}
\hadithdefcmd{ibnmajah}{1946}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ رَضَاعَ إِلاَّ مَا فَتَقَ الأَمْعَاءَ ‏"‏ ‏.‏\hadithno{1946}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin Zubair:that the Messenger of Allah said: “There is no breastfeeding except that which fills the stomach.”}}
\hadithdefcmd{ibnmajah}{1947}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، وَعُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو عَبِيدَةَ بْنُ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، عَنْ أُمِّهِ، زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ أَنَّهَا أَخْبَرَتْهُ أَنَّ أَزْوَاجَ النَّبِيِّ ـ صلى الله عليه وسلم ـ كُلَّهُنَّ خَالَفْنَ عَائِشَةَ وَأَبَيْنَ أَنْ يَدْخُلَ عَلَيْهِنَّ أَحَدٌ بِمِثْلِ رَضَاعَةِ سَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ وَقُلْنَ وَمَا يُدْرِينَا لَعَلَّ ذَلِكَ كَانَتْ رُخْصَةً لِسَالِمٍ وَحْدَهُ ‏.‏\hadithno{1947}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Zainab bint Abi Salamah:that the wives of the Prophet all differed with 'Aishah and refused to allow anyone with ties of breastfeeding like Salim, the freed salve of Abu Hudhaifah, to enter upon them. They said: “How do we know? That may be a concession granted only to Salim.”}}
\hadithdefcmd{ibnmajah}{1948}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ أَتَانِي عَمِّي مِنَ الرَّضَاعَةِ أَفْلَحُ بْنُ أَبِي قُعَيْسٍ يَسْتَأْذِنُ عَلَىَّ بَعْدَ مَا ضُرِبَ الْحِجَابُ فَأَبَيْتُ أَنْ آذَنَ لَهُ حَتَّى دَخَلَ عَلَىَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ إِنَّهُ عَمُّكِ فَأْذَنِي لَهُ ‏"‏ ‏.‏ فَقُلْتُ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ قَالَ ‏"‏ تَرِبَتْ يَدَاكِ أَوْ يَمِينُكِ ‏"‏ ‏.‏\hadithno{1948}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:“My paternal uncle through breastfeeding, Aflah bin Abu Qu'ais, came and asked permission to visit me, after the ruling on veiling had been enjoined, and I refused to let him in, until the Prophet came in and said: 'He is your paternal uncle; let him in.' I said: 'But it is the woman who breastfed me; the man did not breastfeed me.' He said: 'May your hands be rubbed with dust', or: 'May your right hand be rubbed with dust!”}}
\hadithdefcmd{ibnmajah}{1949}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَ عَمِّي مِنَ الرَّضَاعَةِ يَسْتَأْذِنُ عَلَىَّ فَأَبَيْتُ أَنْ آذَنَ لَهُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَلْيَلِجْ عَلَيْكِ عَمُّكِ ‏"‏ ‏.‏ فَقُلْتُ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ ‏.‏ قَالَ ‏"‏ إِنَّهُ عَمُّكِ فَلْيَلِجْ عَلَيْكِ ‏"‏ ‏.‏\hadithno{1949}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:X“My paternal uncle through breastfeeding came to visit me and I refused to let him in. The Messenger of Allah said: 'Let your paternal uncle visit you.' I said: 'But it is the woman who breastfed me; the man did not breastfeed me.' He said: 'He is your paternal uncle; let him visit you.”}}
\hadithdefcmd{ibnmajah}{1950}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي فَرْوَةَ، عَنْ أَبِي وَهْبٍ الْجَيْشَانِيِّ، عَنْ أَبِي خِرَاشٍ الرُّعَيْنِيِّ، عَنِ الدَّيْلَمِيِّ، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَعِنْدِي أُخْتَانِ تَزَوَّجْتُهُمَا فِي الْجَاهِلِيَّةِ ‏.‏ فَقَالَ ‏ "‏ إِذَا رَجَعْتَ فَطَلِّقْ إِحْدَاهُمَا ‏"‏ ‏.‏\hadithno{1950}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Dailami said:“I came to the Messenger of Allah, and I was married to two sisters whom I had married during the Ignorance period. He said: 'When you go back, divorce one of them.' ”}}
\hadithdefcmd{ibnmajah}{1951}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، عَنْ أَبِي وَهْبٍ الْجَيْشَانِيِّ، حَدَّثَهُ أَنَّهُ، سَمِعَ الضَّحَّاكَ بْنَ فَيْرُوزَ الدَّيْلَمِيَّ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَسْلَمْتُ وَتَحْتِي أُخْتَانِ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِي ‏ "‏ طَلِّقْ أَيَّتَهُمَا شِئْتَ ‏"‏ ‏.‏\hadithno{1951}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Dahhak bin Fairuz Dailami narrated that his father said:'I came to the Prophet and said: 'O Messenger of Allah! I have become Muslim and I am married to two sisters.' The Messenger of Allah said: 'Divorce whichever of them you want.' ”}}
\hadithdefcmd{ibnmajah}{1952}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا هُشَيْمٌ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ حُمَيْضَةَ بِنْتِ الشَّمَرْدَلِ، عَنْ قَيْسِ بْنِ الْحَارِثِ، قَالَ أَسْلَمْتُ وَعِنْدِي ثَمَانِ نِسْوَةٍ فَأَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ اخْتَرْ مِنْهُنَّ أَرْبَعًا ‏"‏ ‏.‏\hadithno{1952}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qais bin Harith said:“I became Muslim and I had eight wives. I went to the Prophet and told him about that. He said: 'Choose four of them.' ”}}
\hadithdefcmd{ibnmajah}{1953}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَسْلَمَ غَيْلاَنُ بْنُ سَلَمَةَ وَتَحْتَهُ عَشْرُ نِسْوَةٍ فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ خُذْ مِنْهُنَّ أَرْبَعًا ‏"‏ ‏.‏\hadithno{1953}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:“Ghailan bin Salamah became Muslim and he had ten wives. The Prophet said to him: 'Choose four of them.' ”}}
\hadithdefcmd{ibnmajah}{1954}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدِ بْنِ عَبْدِ اللَّهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ أَحَقَّ الشَّرْطِ أَنْ يُوفَى بِهِ مَا اسْتَحْلَلْتُمْ بِهِ الْفُرُوجَ ‏"‏ ‏.‏\hadithno{1954}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Uqbah bin 'Amir:that the Prophet said: “The conditions most deserving to be fulfilled are those by means of which the private parts become permissible for you.”}}
\hadithdefcmd{ibnmajah}{1955}{\hadithno{1955}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif}\hadithtrans{}}
\hadithdefcmd{ibnmajah}{1956}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ صَالِحِ بْنِ صَالِحِ بْنِ حَىٍّ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَانَتْ لَهُ جَارِيَةٌ فَأَدَّبَهَا فَأَحْسَنَ أَدَبَهَا وَعَلَّمَهَا فَأَحْسَنَ تَعْلِيمَهَا ثُمَّ أَعْتَقَهَا وَتَزَوَّجَهَا فَلَهُ أَجْرَانِ وَأَيُّمَا رَجُلٍ مِنْ أَهْلِ الْكِتَابِ آمَنَ بِنَبِيِّهِ وَآمَنَ بِمُحَمَّدٍ فَلَهُ أَجْرَانِ وَأَيُّمَا عَبْدٍ مَمْلُوكٍ أَدَّى حَقَّ اللَّهِ عَلَيْهِ وَحَقَّ مَوَالِيهِ فَلَهُ أَجْرَانِ ‏"‏ ‏.‏ قَالَ صَالِحٌ قَالَ الشَّعْبِيُّ قَدْ أَعْطَيْتُكَهَا بِغَيْرِ شَىْءٍ ‏.‏ إِنْ كَانَ الرَّاكِبُ لَيَرْكَبُ فِيمَا دُونَهَا إِلَى الْمَدِينَةِ ‏.‏\hadithno{1956}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Musa that the Messenger of Allah said:'Whoever has a slave woman and teaches her good manners and educates her, then sets her free and marries her, will have two rewards. Any man from among the People of the Book who believed in his Prophet and believed in Muhammad will have two rewards. Any slave who does his duty towards Allah and towards his masters will have two rewards.” (Sahih)(one of the narrators) Salih said: “Sha'bi said: 'I have given this (Hadith) to you for little effort on your part. A rider would travel to Al-Madinah for less than this.' ”}}
\hadithdefcmd{ibnmajah}{1957}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا ثَابِتٌ، وَعَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ صَارَتْ صَفِيَّةُ لِدِحْيَةَ الْكَلْبِيِّ ثُمَّ صَارَتْ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بَعْدُ فَتَزَوَّجَهَا وَجَعَلَ عِتْقَهَا صَدَاقَهَا ‏.‏ قَالَ حَمَّادٌ فَقَالَ عَبْدُ الْعَزِيزِ لِثَابِتٍ يَا أَبَا مُحَمَّدٍ أَنْتَ سَأَلْتَ أَنَسًا مَا أَمْهَرَهَا قَالَ أَمْهَرَهَا نَفْسَهَا ‏.‏\hadithno{1957}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Anas said:“Safiyyah was given to Dihyah Al-Kalbi (as his share of the war booty), then she was given to the Messenger of Allah after that. He married her, and made her ransom (i.e., freedom from slavery) her dowry.” (Sahih)Hammad said: “Abdul-'Aziz said to Thabit: 'O Abu Muhammad! Did you ask Anas what her bridal-money was?' He said: 'Her bridal-money was her freedom.' ”}}
\hadithdefcmd{ibnmajah}{1958}{حَدَّثَنَا حُبَيْشُ بْنُ مُبَشِّرٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنْ عَائِشَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَعْتَقَ صَفِيَّةَ وَجَعَلَ عِتْقَهَا صَدَاقَهَا وَتَزَوَّجَهَا ‏.‏\hadithno{1958}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah:that the Messenger of Allah (ﷺ) set Safiyyah free, and made her ransom her dowry, and he married her}}
\hadithdefcmd{ibnmajah}{1959}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا الْقَاسِمُ بْنُ عَبْدِ الْوَاحِدِ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا تَزَوَّجَ الْعَبْدُ بِغَيْرِ إِذْنِ سَيِّدِهِ كَانَ عَاهِرًا ‏"‏ ‏.‏\hadithno{1959}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar:that the Messenger of Allah said : "If a slave gets married without his master's permission, he is a fornicator}}
\hadithdefcmd{ibnmajah}{1960}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَصَالِحُ بْنُ مُحَمَّدِ بْنِ يَحْيَى بْنِ سَعِيدٍ، قَالاَ حَدَّثَنَا أَبُو غَسَّانَ، مَالِكُ بْنُ إِسْمَاعِيلَ حَدَّثَنَا مِنْدَلٌ، عَنِ ابْنِ جُرَيْجٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَيُّمَا عَبْدٍ تَزَوَّجَ بِغَيْرِ إِذْنِ مَوَالِيهِ فَهُوَ زَانٍ ‏"‏ ‏.‏\hadithno{1960}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar:that the Messenger of Allah said : "Any slave who gets married without his master's permission, is a fornicator}}
\hadithdefcmd{ibnmajah}{1961}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ، وَالْحَسَنِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْ مُتْعَةِ النِّسَاءِ يَوْمَ خَيْبَرَ وَعَنْ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{1961}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Ali bin Abu Talib that:The Messenger of Allah forbade on the Day of Khaibar, the temporary marriage of women and (he forbade) the flesh of domestic donkeys}}
\hadithdefcmd{ibnmajah}{1962}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ، عَنِ الرَّبِيعِ بْنِ سَبْرَةَ، عَنْ أَبِيهِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي حَجَّةِ الْوَدَاعِ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّ الْعُزْبَةَ قَدِ اشْتَدَّتْ عَلَيْنَا ‏.‏ قَالَ ‏"‏ فَاسْتَمْتِعُوا مِنْ هَذِهِ النِّسَاءِ ‏"‏ ‏.‏ فَأَتَيْنَاهُنَّ فَأَبَيْنَ أَنْ يَنْكِحْنَنَا إِلاَّ أَنْ نَجْعَلَ بَيْنَنَا وَبَيْنَهُنَّ أَجَلاً فَذَكَرُوا ذَلِكَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ اجْعَلُوا بَيْنَكُمْ وَبَيْنَهُنَّ أَجَلاً ‏"‏ ‏.‏ فَخَرَجْتُ أَنَا وَابْنُ عَمٍّ لِي مَعَهُ بُرْدٌ وَمَعِي بُرْدٌ وَبُرْدُهُ أَجْوَدُ مِنْ بُرْدِي وَأَنَا أَشَبُّ مِنْهُ فَأَتَيْنَا عَلَى امْرَأَةٍ فَقَالَتْ بُرْدٌ كَبُرْدٍ ‏.‏ فَتَزَوَّجْتُهَا فَمَكَثْتُ عِنْدَهَا تِلْكَ اللَّيْلَةَ ثُمَّ غَدَوْتُ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَائِمٌ بَيْنَ الرُّكْنِ وَالْبَابِ وَهُوَ يَقُولُ ‏"‏ أَيُّهَا النَّاسُ إِنِّي قَدْ كُنْتُ أَذِنْتُ لَكُمْ فِي الاِسْتِمْتَاعِ أَلاَ وَإِنَّ اللَّهَ قَدْ حَرَّمَهَا إِلَى يَوْمِ الْقِيَامَةِ فَمَنْ كَانَ عِنْدَهُ مِنْهُنَّ شَىْءٌ فَلْيُخَلِّ سَبِيلَهَا وَلاَ تَأْخُذُوا مِمَّا آتَيْتُمُوهُنَّ شَيْئًا ‏"‏ ‏.‏\hadithno{1962}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Rabi'bin Sabrah that his father said :"We went out with the Messenger of Allah on the Farewell pilgrimage, and they said : 'O Messenger of Allah, (ﷺ) celibacy has become too difficult for us'. He said : 'Then make temporary marriages with these women'. So we went to them, but they insisted on setting a fixed time between us and them. They mentioned that to the Prophet and he said : 'Set a fixed time between you and them.' So I went out with a cousin of mine. He had a cloak and I had a cloak, but his cloak was finer than mine, and I was younger than him. We came to a women and she said: 'One cloak is like another.' So I married her and stayed with her that night. Then the next day I saw the Messenger of Allah standing between the Rukn (corner) and the door (of the Ka'bah), saying : 'O people, I had permitted temporary marriage for you, but Allah has forbidden it until the Day of Resurrection. however had any temporary wives, he should let them go, and do not take back anything that you had given to them}}
\hadithdefcmd{ibnmajah}{1963}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا الْفِرْيَابِيُّ، عَنْ أَبَانَ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَمَّا وَلِيَ عُمَرُ بْنُ الْخَطَّابِ خَطَبَ النَّاسَ فَقَالَ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَذِنَ لَنَا فِي الْمُتْعَةِ ثَلاَثًا ثُمَّ حَرَّمَهَا وَاللَّهِ لاَ أَعْلَمُ أَحَدًا تَمَتَّعَ وَهُوَ مُحْصَنٌ إِلاَّ رَجَمْتُهُ بِالْحِجَارَةِ إِلاَّ أَنْ يَأْتِيَنِي بِأَرْبَعَةٍ يَشْهَدُونَ أَنَّ رَسُولَ اللَّهِ أَحَلَّهَا بَعْدَ إِذْ حَرَّمَهَا ‏.‏\hadithno{1963}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"When 'Umar bin Khattab was appointed caliph, he addressed the people and said: 'The Messenger of Allah permitted temporary marriage for us three times, then he forbade it. By Allah, If I hear of any married person entering a temporary marriage, I will stone him to death, unless he can bring me four witnesses who will testify that the Messenger of Allah, allowed it after he forbade it}}
\hadithdefcmd{ibnmajah}{1964}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا أَبُو فَزَارَةَ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، حَدَّثَتْنِي مَيْمُونَةُ بِنْتُ الْحَارِثِ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَزَوَّجَهَا وَهُوَ حَلاَلٌ ‏.‏ قَالَ وَكَانَتْ خَالَتِي وَخَالَةَ ابْنِ عَبَّاسٍ ‏.‏\hadithno{1964}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Maimunah bint Harith narrated:that the Messenger of Allah married her when he was Halal (not in Ihram). (Sahih).He (one of the narrators-Yazid) said: "And she was my maternal aunt and the maternal aunt of Idn 'Abbas also}}
\hadithdefcmd{ibnmajah}{1965}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَكَحَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{1965}\hadithgrade{Al-Albani: Shadh; Muhammad Fouad Abd al-Baqi: Shadh; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet got married while he was a Muhrim (in Ihram)}}
\hadithdefcmd{ibnmajah}{1966}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، عَنْ أَبَانَ بْنِ عُثْمَانَ بْنِ عَفَّانَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُحْرِمُ لاَ يَنْكِحُ وَلاَ يُنْكِحُ وَلاَ يَخْطُبُ ‏"‏ ‏.‏\hadithno{1966}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Aban bin 'Uthman bin 'Affan' that his father said:"The Messenger of Allah said: 'The one in lhram should not get married, nor arrange a marriage for anyone else, nor Propose marriage}}
\hadithdefcmd{ibnmajah}{1967}{حَدَّثَنَا مُحَمَّدُ بْنُ سَابُورَ الرَّقِّيُّ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ سُلَيْمَانَ الأَنْصَارِيُّ، أَخُو فُلَيْحٍ عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنِ ابْنِ وَثِيمَةَ الْمِصْرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَتَاكُمْ مَنْ تَرْضَوْنَ خُلُقَهُ وَدِينَهُ فَزَوِّجُوهُ إِلاَّ تَفْعَلُوا تَكُنْ فِتْنَةٌ فِي الأَرْضِ وَفَسَادٌ عَرِيضٌ ‏"‏ ‏.‏\hadithno{1967}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah:that the Messenger of Allah said: "If there comes to you one with whose character and religious commitment you are pleased, then marry (your daughter or female relative under your care) to him, for if you do not do that there will be Fitnah in the land and widespread corruption}}
\hadithdefcmd{ibnmajah}{1968}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا الْحَارِثُ بْنُ عِمْرَانَ الْجَعْفَرِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَخَيَّرُوا لِنُطَفِكُمْ وَانْكِحُوا الأَكْفَاءَ وَأَنْكِحُوا إِلَيْهِمْ ‏"‏ ‏.‏\hadithno{1968}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah:that the Messenger of Allah said: "Choose the best for your sperm, and marry compatible women and propose marriage to them}}
\hadithdefcmd{ibnmajah}{1969}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هَمَّامٍ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَانَتْ لَهُ امْرَأَتَانِ يَمِيلُ مَعَ إِحْدَاهُمَا عَلَى الأُخْرَى جَاءَ يَوْمَ الْقِيَامَةِ وَأَحَدُ شِقَّيْهِ سَاقِطٌ ‏"‏ ‏.‏\hadithno{1969}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah:that the Messenger of Allah said: "Whoever has two wives and favors one of them over the other, he will come on the Day of Resurrection with one of his sides leaning}}
\hadithdefcmd{ibnmajah}{1970}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ يَمَانٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا سَافَرَ أَقْرَعَ بَيْنَ نِسَائِهِ ‏.‏\hadithno{1970}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{It was narrated from 'Aishah:that whenever the Messenger of Allah was to travel, he would cast lots among his wives}}
\hadithdefcmd{ibnmajah}{1971}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْسِمُ بَيْنَ نِسَائِهِ فَيَعْدِلُ ثُمَّ يَقُولُ ‏ "‏ اللَّهُمَّ هَذَا فِعْلِي فِيمَا أَمْلِكُ فَلاَ تَلُمْنِي فِيمَا تَمْلِكُ وَلاَ أَمْلِكُ ‏"‏ ‏.‏\hadithno{1971}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to divide his time equally among his wives, then he would say 'O Allah, this is what I am doing with regard to that which is within my control, so do not hold me accountable for that which is under Your control and is beyond my control}}
\hadithdefcmd{ibnmajah}{1972}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا أَنْ كَبِرَتْ، سَوْدَةُ بِنْتُ زَمْعَةَ وَهَبَتْ يَوْمَهَا لِعَائِشَةَ فَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْسِمُ لِعَائِشَةَ بِيَوْمِ سَوْدَةَ ‏.‏\hadithno{1972}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Urwah narrated from 'Aishah:that when Saudah bint Zam'ah grew old, she gave her day to 'Aishah, and the Messenger of Allah went to 'Aishah on Saudah's day}}
\hadithdefcmd{ibnmajah}{1973}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ سُمَيَّةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَجَدَ عَلَى صَفِيَّةَ بِنْتِ حُيَىٍّ فِي شَىْءٍ ‏.‏ فَقَالَتْ صَفِيَّةُ يَا عَائِشَةُ هَلْ لَكِ أَنْ تُرْضِي رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِّي وَلَكِ يَوْمِي قَالَتْ نَعَمْ ‏.‏ فَأَخَذَتْ خِمَارًا لَهَا مَصْبُوغًا بِزَعْفَرَانٍ فَرَشَّتْهُ بِالْمَاءِ لِيَفُوحَ رِيحُهُ ثُمَّ قَعَدَتْ إِلَى جَنْبِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا عَائِشَةُ إِلَيْكِ عَنِّي إِنَّهُ لَيْسَ يَوْمَكِ ‏"‏ ‏.‏ فَقَالَتْ ذَلِكَ فَضْلُ اللَّهِ يُؤْتِيهِ مَنْ يَشَاءُ ‏.‏ فَأَخْبَرَتْهُ بِالأَمْرِ فَرَضِيَ عَنْهَا ‏.‏\hadithno{1973}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah:that the Messenger of Allah became angry with Safiyyah bint Huyai for something, and Safiyyah said: "O 'Aishah, can you make the Messenger of Allah be pleased with me, and I will give you my day?" She said: "Yes." So she took a headcover of hers that was dyed with saffron and sprinkled it with water so that its fragrance would become stronger, then she sat beside the Messenger of Allah. The Prophet said: "O 'Aishah, go away, because it is not your day!" She said: "That is the Grace of Allah which He bestows on whom He pleases." Then she told him about that matter and he was pleased with her}}
\hadithdefcmd{ibnmajah}{1974}{حَدَّثَنَا حَفْصُ بْنُ عَمْرٍو، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ‏.‏ أَنَّهَا قَالَتْ نَزَلَتْ هَذِهِ الآيَةُ ‏\{وَالصُّلْحُ خَيْرٌ\}‏ فِي رَجُلٍ كَانَتْ تَحْتَهُ امْرَأَةٌ قَدْ طَالَتْ صُحْبَتُهَا وَوَلَدَتْ مِنْهُ أَوْلاَدًا فَأَرَادَ أَنْ يَسْتَبْدِلَ بِهَا فَرَاضَتْهُ عَلَى أَنْ تُقِيمَ عِنْدَهُ وَلاَ يَقْسِمَ لَهَا ‏.‏\hadithno{1974}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"This Verse 'And making peace is better.' was revealed concerning a man who had been married to a woman for a long time, and she had given birth to his children and he wanted to exchange her (for a new wife). She agreed that he would stay with her (the new wife) and would not give her (the first wife) a share of his time. (i.e.) not spend the nights with her}}
\hadithdefcmd{ibnmajah}{1975}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ يَحْيَى، حَدَّثَنَا مُعَاوِيَةُ بْنُ يَزِيدَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ أَبِي رُهْمٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مِنْ أَفْضَلِ الشَّفَاعَةِ أَنْ يُشَفَّعَ بَيْنَ الاِثْنَيْنِ فِي النِّكَاحِ ‏"‏ ‏.‏\hadithno{1975}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Ruhm said:"The Messenger of Allah said: 'One of the best kinds of intercession is interceding between two people concerning marriage}}
\hadithdefcmd{ibnmajah}{1976}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنِ الْعَبَّاسِ بْنِ ذَرِيحٍ، عَنِ الْبَهِيِّ، عَنْ عَائِشَةَ، قَالَتْ عَثَرَ أُسَامَةُ بِعَتَبَةِ الْبَابِ فَشُجَّ فِي وَجْهِهِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَمِيطِي عَنْهُ الأَذَى ‏"‏ ‏.‏ فَتَقَذَّرْتُهُ فَجَعَلَ يَمَصُّ عَنْهُ الدَّمَ وَيَمُجُّهُ عَنْ وَجْهِهِ ثُمَّ قَالَ ‏"‏ لَوْ كَانَ أُسَامَةُ جَارِيَةً لَحَلَّيْتُهُ وَكَسَوْتُهُ حَتَّى أُنَفِّقَهُ ‏"‏ ‏.‏\hadithno{1976}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"Usamah stumbled at the threshold of the door and cut his face. The Messenger of Allah said: 'Remove the harm (the blood) from him,' but I was repulsed by that. He started to suck the blood and remove it from his face, then he said: 'If Usamah were a girl, I would have adorned him and dressed him until I married him off}}
\hadithdefcmd{ibnmajah}{1977}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ وَمُحَمَّدُ بْنُ يَحْيَى قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ جَعْفَرِ بْنِ يَحْيَى بْنِ ثَوْبَانَ، عَنْ عَمِّهِ، عُمَارَةَ بْنِ ثَوْبَانَ عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ خَيْرُكُمْ خَيْرُكُمْ لأَهْلِهِ وَأَنَا خَيْرُكُمْ لأَهْلِي ‏"‏ ‏.‏\hadithno{1977}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:the Prophet said: "The best of you is the one who is best to his wife, and I am the best of you to my wives}}
\hadithdefcmd{ibnmajah}{1978}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خِيَارُكُمْ خِيَارُكُمْ لِنِسَائِهِمْ ‏"‏ ‏.‏\hadithno{1978}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that:the Messenger of Allah said: "The best of you are those who are best to their womenfolk}}
\hadithdefcmd{ibnmajah}{1979}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سَابَقَنِي النَّبِيُّ ـ صلى الله عليه وسلم ـ فَسَبَقْتُهُ ‏.‏\hadithno{1979}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Prophet raced with me and I beat him}}
\hadithdefcmd{ibnmajah}{1980}{حَدَّثَنَا أَبُو بَدْرٍ، عَبَّادُ بْنُ الْوَلِيدِ حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا مُبَارَكُ بْنُ فَضَالَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أُمِّ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا قَدِمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْمَدِينَةَ وَهُوَ عَرُوسٌ بِصَفِيَّةَ بِنْتِ حُ��َىٍّ جِئْنَ نِسَاءُ الأَنْصَارِ فَأَخْبَرْنَ عَنْهَا ‏.‏ قَالَتْ فَتَنَكَّرْتُ وَتَنَقَّبْتُ فَذَهَبْتُ فَنَظَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى عَيْنِي فَعَرَفَنِي ‏.‏ قَالَتْ فَالْتَفَتَ فَأَسْرَعْتُ الْمَشْىَ فَأَدْرَكَنِي فَاحْتَضَنَنِي فَقَالَ ‏ "‏ كَيْفَ رَأَيْتِ ‏"‏ ‏.‏ قَالَتْ قُلْتُ أَرْسِلْ يَهُودِيَّةٌ وَسْطَ يَهُودِيَّاتٍ ‏.‏\hadithno{1980}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:When the Messenger of Allah came to Al-Madinah, he had just married Safiyyah bint Huyai, and the women of the Ansar came and told us about that. My expression changed and I covered my face and went away. The Messenger of Allah looked at my eyes and recognized me. I turned away and walked quickly, but he caught up with me and put his arm around me and said: 'What did you see?' I said: 'Let me go, (I saw) a Jewish woman among other Jewish women}}
\hadithdefcmd{ibnmajah}{1981}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ زَكَرِيَّا، عَنْ خَالِدِ بْنِ سَلَمَةَ، عَنِ الْبَهِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ قَالَتْ عَائِشَةُ مَا عَلِمْتُ حَتَّى دَخَلَتْ عَلَىَّ زَيْنَبُ بِغَيْرِ إِذْنٍ وَهِيَ غَضْبَى ‏.‏ ثُمَّ قَالَتْ يَا رَسُولَ اللَّهِ أَحَسْبُكَ إِذَا قَلَبَتْ لَكَ بُنَيَّةُ أَبِي بَكْرٍ ذُرَيْعَتَيْهَا ‏.‏ ثُمَّ أَقْبَلَتْ عَلَىَّ فَأَعْرَضْتُ عَنْهَا حَتَّى قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ دُونَكِ فَانْتَصِرِي ‏"‏ ‏.‏ فَأَقْبَلْتُ عَلَيْهَا حَتَّى رَأَيْتُهَا وَقَدْ يَبِسَ رِيقُهَا فِي فِيهَا مَا تَرُدُّ عَلَىَّ شَيْئًا فَرَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَتَهَلَّلُ وَجْهُهُ ‏.‏\hadithno{1981}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Urwah bin Zubair narrated that 'Aishah said:"I did not know until Zainab burst in on me without permission and she was angry. Then she said: 'O Messenger of Allah, is it enough for you that the young daughter of Abu Bakr waves her hands in front of you?' Then she turned to me, but I ignored her until the Prophet said: 'You should say something to defend yourself.' So I turned on her, (and replied to her) until I saw that her mouth had become dry, and she did not say anything back to me. And I saw the Prophet with his face shining." (Hasan)}}
\hadithdefcmd{ibnmajah}{1982}{حَدَّثَنَا حَفْصُ بْنُ عَمْرٍو، حَدَّثَنَا عُمَرُ بْنُ حَبِيبٍ الْقَاضِي، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَلْعَبُ بِالْبَنَاتِ وَأَنَا عِنْدَ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَكَانَ يُسَرِّبُ إِلَىَّ صَوَاحِبَاتِي يُلاَعِبْنَنِي ‏.‏\hadithno{1982}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Aishah said:"I used to play with dolls when I was with the Messenger of Allah, and he used to bring my friends to me to play with me}}
\hadithdefcmd{ibnmajah}{1983}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، قَالَ خَطَبَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ثُمَّ ذَكَرَ النِّسَاءَ فَوَعَظَهُمْ فِيهِنَّ ثُمَّ قَالَ ‏ "‏ إِلاَمَ يَجْلِدُ أَحَدُكُمُ امْرَأَتَهُ جَلْدَ الأَمَةِ وَلَعَلَّهُ أَنْ يُضَاجِعَهَا مِنْ آخِرِ يَوْمِهِ ‏"‏ ‏.‏\hadithno{1983}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Abduleh bin Zam'ah said:'The Prophet delivered a sermon then he made mention of women, and exhorted (the men) concerning them. Then he said: 'How long will one of you whip his wife like a slave, then lie with her at the end of the day?}}
\hadithdefcmd{ibnmajah}{1984}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا ضَرَبَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ خَادِمًا لَهُ وَلاَ امْرَأَةً وَلاَ ضَرَبَ بِيَدِهِ شَيْئًا ‏.‏\hadithno{1984}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah never beat any of his servants, or wives, and his hand never hit anything}}
\hadithdefcmd{ibnmajah}{1985}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ إِيَاسِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي ذُبَابٍ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ تَضْرِبُوا إِمَاءَ اللَّهِ ‏"‏ ‏.‏ فَجَاءَ عُمَرُ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ ذَئِرَ النِّسَاءُ عَلَى أَزْوَاجِهِنَّ فَأْمُرْ بِضَرْبِهِنَّ ‏.‏ فَضُرِبْنَ فَطَافَ بِآلِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ طَائِفُ نِسَاءٍ كَثِيرٍ فَلَمَّا أَصْبَحَ قَالَ ‏"‏ لَقَدْ طَافَ اللَّيْلَةَ بِآلِ مُحَمَّدٍ سَبْعُونَ امْرَأَةً كُلُّ امْرَأَةٍ تَشْتَكِي زَوْجَهَا فَلاَ تَجِدُونَ أُولَئِكَ خِيَارَكُمْ ‏"‏ ‏.‏\hadithno{1985}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Iyas bin 'Abdullah bin Abu Dhubab said:"The Prophet said: 'Do not beat the female slaves of Allah.' Then 'Umar came to the Prophet and said: 'O Messenger of Allah, the woman have become bold towards their husbands? So order the beatin g of them,' and they were beaten. Then many women went around to the family of Muhammad,. The next day he said: 'Last night seventy women came to the family of Muhammad, each woman complaining about her husband. You will not find that those are the best of you}}
\hadithdefcmd{ibnmajah}{1986}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَالْحَسَنُ بْنُ مُدْرِكٍ الطَّحَّانُ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ دَاوُدَ بْنِ عَبْدِ اللَّهِ الأَوْدِيِّ، عَنْ عَبْدِ الرَّحْمَنِ الْمُسْلِيِّ، عَنِ الأَشْعَثِ بْنِ قَيْسٍ، قَالَ ضِفْتُ عُمَرَ لَيْلَةً فَلَمَّا كَانَ فِي جَوْفِ اللَّيْلِ قَامَ إِلَى امْرَأَتِهِ يَضْرِبُهَا فَحَجَزْتُ بَيْنَهُمَا فَلَمَّا أَوَى إِلَى فِرَاشِهِ قَالَ لِي يَا أَشْعَثُ احْفَظْ عَنِّي شَيْئًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يُسْأَلُ الرَّجُلُ فِيمَ يَضْرِبُ امْرَأَتَهُ وَلاَ تَنَمْ إِلاَّ عَلَى وِتْرٍ ‏"‏ ‏.‏ وَنَسِيتُ الثَّالِثَةَ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خِدَاشٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا أَبُو عَوَانَةَ، بِإِسْنَادِهِ نَحْوَهُ ‏.‏\hadithno{1986}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ash'ath bin Qais said:"I was a guest (at the home) of 'Umar one night, and in the middle of the night he went and hit his wife, and I separated them. When he went to bed he said to me: 'O Ash'ath, learn from me something that I heard from the Messenger of Allah" A man should not be asked why he beats his wife, and do not go to sleep until you have prayed the Witr."' And I forgot the third thing}}
\hadithdefcmd{ibnmajah}{1987}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ لَعَنَ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏.‏\hadithno{1987}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:the Prophet cursed the woman who does hair extensions and the one who has that done, and the woman who does tattoos and the one who has that done}}
\hadithdefcmd{ibnmajah}{1988}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَتْ إِنَّ ابْنَتِي عُرَيِّسٌ وَقَدْ أَصَابَتْهَا الْحَصْبَةُ فَتَمَرَّقَ شَعْرُهَا ‏.‏ فَأَصِلُ لَهَا فِيهِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ ‏"‏ ‏.‏\hadithno{1988}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Asma' said:"A woman came to the Prophet and said:, My daughter is going to get married, and she had the measles and her hair has fallen out. Can I put extensions in her hair?, The Messenger of Allah said: ‘Allah has cursed the one who does hair extensions and the one who has that done}}
\hadithdefcmd{ibnmajah}{1989}{حَدَّثَنَا أَبُو عُمَرَ، حَفْصُ بْنُ عَمْرٍو وَعَبْدُ الرَّحْمَنِ بْنُ عُمَرَ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْوَاشِمَاتِ وَالْمُسْتَوْشِمَاتِ وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ الْمُغَيِّرَاتِ لِخَلْقِ اللَّهِ ‏.‏ فَبَلَغَ ذَلِكَ امْرَأَةً مِنْ بَنِي أَسَدٍ يُقَالُ لَهَا أُمُّ يَعْقُوبَ فَجَاءَتْ إِلَيْهِ فَقَالَتْ بَلَغَنِي عَنْكَ أَنَّكَ قُلْتَ كَيْتَ وَكَيْتَ ‏.‏ قَالَ وَمَالِي لاَ أَلْعَنُ مَنْ لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ فِي كِتَابِ اللَّهِ قَالَتْ إِنِّي لأَقْرَأُ مَا بَيْنَ لَوْحَيْهِ فَمَا وَجَدْتُهُ ‏.‏ قَالَ إِنْ كُنْتِ قَرَأْتِهِ فَقَدْ وَجَدْتِهِ أَمَا قَرَأْتِ ‏\{وَمَا آتَاكُمُ الرَّسُولُ فَخُذُوهُ وَمَا نَهَاكُمْ عَنْهُ فَانْتَهُوا\}‏ قَالَتْ بَلَى ‏.‏ قَالَ فَإِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَدْ نَهَى عَنْهُ ‏.‏ قَالَتْ فَإِنِّي لأَظُنُّ أَهْلَكَ يَفْعَلُونَ ‏.‏ قَالَ اذْهَبِي فَانْظُرِي ‏.‏ فَذَهَبَتْ فَنَظَرَتْ فَلَمْ تَرَ مِنْ حَاجَتِهَا شَيْئًا ‏.‏ قَالَتْ مَا رَأَيْتُ شَيْئًا ‏.‏ قَالَ عَبْدُ اللَّهِ لَوْ كَانَتْ كَمَا تَقُولِينَ مَا جَامَعَتْنَا ‏.‏\hadithno{1989}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Abdulleh said:"The Messenger of Allah cursed the woman who does tattoos and the one who has them done, and those who pluck their eyebrows and file their teeth for the purpose of beautification, and those who change the creation of Allah." News of that reached a woman of Banu Asad who was called Umm Ya'qub. She came to him and said: "I have heard that you said such and such." He said: 'Why should I not curse those whom the Messenger of Allah cursed ? And it is in the Book of Allah.'' She said: "I read what is between its two covers 'and I have not found that." He said: "If you read it properly you would have found it. Have you not read the words: 'And whatsoever the Messenger (Muhammad) gives you, take it; and whatsoever he forbids you, abstain (from it).'?" She said: "Of course." He said: 'The Messenger of Allah forbade that." She said: 'I think that your wife does it.' He said: " Go and look." So she went and looked and she did not see what she wanted. She said: "I have not seen anything!’ 'Abdullah said: "If she was as you say, I would not have kept her with me}}
\hadithdefcmd{ibnmajah}{1990}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، ح وَحَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، جَمِيعًا عَنْ سُفْيَانَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي النَّبِيُّ ـ صلى الله عليه وسلم ـ فِي شَوَّالٍ وَبَنَى بِي فِي شَوَّالٍ ‏.‏ فَأَىُّ نِسَائِهِ كَانَ أَحْظَى عِنْدَهُ مِنِّي ‏.‏ وَكَانَتْ عَائِشَةُ تَسْتَحِبُّ أَنْ تُدْخِلَ نِسَاءَهَا فِي شَوَّالٍ ‏.‏\hadithno{1990}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Prophet, married me in Shawwal, and he consummated the marriage with me in Shawwal, and which of his wives was more favored to him than I." 'Airhuh used to like marriage to be consummated with her female relatives in Shawwal}}
\hadithdefcmd{ibnmajah}{1991}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا زُهَيْرٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ الْمَلِكِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِيهِ ـ رضي الله عنه ـ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ تَزَوَّجَ أُمَّ سَلَمَةَ فِي شَوَّالٍ وَجَمَعَهَا إِلَيْهِ فِي شَوَّالٍ ‏.‏\hadithno{1991}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Mursal; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdul-Malik bin Harith bin Hisham, from his father, that:the Prophet married Umm Salamah in Shawwal, and consummated the marriage with her in Shawwal}}
\hadithdefcmd{ibnmajah}{1992}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْهَيْثَمُ بْنُ جَمِيلٍ، حَدَّثَنَا شَرِيكٌ، عَنْ مَنْصُورٍ، - أَظُنُّهُ - عَنْ طَلْحَةَ، عَنْ خَيْثَمَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَهَا أَنْ تُدْخِلَ عَلَى رَجُلٍ امْرَأَتَهُ قَبْلَ أَنْ يُعْطِيَهَا شَيْئًا ‏.‏\hadithno{1992}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:the Messenger of Allah told her to take a woman to her husband before he had given her anything (i.e. bridal-money). (Da' if)}}
\hadithdefcmd{ibnmajah}{1993}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ سُلَيْمٍ الْكَلْبِيُّ، عَنْ يَحْيَى بْنِ جَابِرٍ، عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ، عَنْ عَمِّهِ، مِخْمَرِ بْنِ مُعَاوِيَةَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ شُؤْمَ وَقَدْ يَكُونُ الْيُمْنُ فِي ثَلاَثَةٍ فِي الْمَرْأَةِ وَالْفَرَسِ وَالدَّارِ ‏"‏ ‏.‏\hadithno{1993}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hakim bin Mu'awiyah that his paternal uncle Mikhmar bin Mu'awiyah said:"I heard the Messenger of Allah say: 'Do not believe in omens, and good fortune is only to be found in three things: A woman, a horse and a house}}
\hadithdefcmd{ibnmajah}{1994}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ عَاصِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنْ كَانَ فَفِي الْفَرَسِ وَالْمَرْأَةِ وَالْمَسْكَنِ ‏"‏ ‏.‏ يَعْنِي الشُّؤْمَ ‏.‏\hadithno{1994}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Sahl bin Sa'd that:the Messenger of Allah said: "If it exists, it is in three things: a horse, and woman and a house," meaning omens}}
\hadithdefcmd{ibnmajah}{1995}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ أَبُو سَلَمَةَ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الشُّؤْمُ فِي ثَلاَثَةٍ فِي الْفَرَسِ وَالْمَرْأَةِ وَالدَّارِ ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ فَحَدَّثَنِي أَبُو عُبَيْدَةَ بْنُ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، أَنَّ جَدَّتَهُ، زَيْنَبَ حَدَّثَتْهُ عَنْ أُمِّ سَلَمَةَ، أَنَّهَا كَانَتْ تَعُدُّ هَؤُلاَءِ الثَّلاَثَةَ وَتَزِيدُ مَعَهُنَّ السَّيْفَ ‏.‏\hadithno{1995}\hadithgrade{Al-Albani: Shadh; Muhammad Fouad Abd al-Baqi: Shadh; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Salim, from his father, that:the Messenger of Allah said: "Omens are only to be found in three things: a horse, a woman and a house." (Sahih)(One of the narrators) Az-Zuhri said: " Abu 'Ubaidah bin 'Abdullah bin Zam'ah said that his mother, Zainab, narrated to him, from Umm Salamah, that she used to list these three, and add to them "the sword}}
\hadithdefcmd{ibnmajah}{1996}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وَكِيعٌ، عَنْ شَيْبَانَ أَبِي مُعَاوِيَةَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَهْمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مِنَ الْغَيْرَةِ مَا يُحِبُّ اللَّهُ وَمِنْهَا مَا يَكْرَهُ اللَّهُ فَأَمَّا مَا يُحِبُّ فَالْغَيْرَةُ فِي الرِّيبَةِ وَأَمَّا مَا يَكْرَهُ فَالْغَيْرَةُ فِي غَيْرِ رِيبَةٍ ‏"‏ ‏.‏\hadithno{1996}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah said: "There is a kind of protective jealousy that Allah loves and a kind that Allah hates. As for that which Allah loves, it is protective jealousy when there are grounds for suspicion. And as for that which He hates, it is protective jealousy when there are no grounds for suspicion}}
\hadithdefcmd{ibnmajah}{1997}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا غِرْتُ عَلَى امْرَأَةٍ قَطُّ مَا غِرْتُ عَلَى خَدِيجَةَ مِمَّا رَأَيْتُ مِنْ ذِكْرِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لَهَا وَلَقَدْ أَمَرَهُ رَبُّهُ أَنْ يُبَشِّرَهَا بِبَيْتٍ فِي الْجَنَّةِ مِنْ قَصَبٍ ‏.‏ يَعْنِي مِنْ ذَهَبٍ قَالَهُ ابْنُ مَاجَهْ ‏.‏\hadithno{1997}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Aishah said:"I never felt as jealous of any woman as I did of Khadijah, because I saw how the Messenger of Allah remembered her, and his Lord had told him to give her the glad tidings of a house in Paradise made of Qasab}}
\hadithdefcmd{ibnmajah}{1998}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ إِنَّ بَنِي هِشَامِ بْنِ الْمُغِيرَةِ اسْتَأْذَنُونِي أَنْ يُنْكِحُوا ابْنَتَهُمْ عَلِيَّ بْنَ أَبِي طَالِبٍ فَلاَ آذَنُ لَهُمْ ثُمَّ لاَ آذَنُ لَهُمْ ثُمَّ لاَ آذَنُ لَهُمْ إِلاَّ أَنْ يُرِيدَ عَلِيُّ بْنُ أَبِي طَالِبٍ أَنْ يُطَلِّقَ ابْنَتِي وَيَنْكِحَ ابْنَتَهُمْ فَإِنَّمَا هِيَ بَضْعَةٌ مِنِّي يَرِيبُنِي مَا رَابَهَا وَيُؤْذِينِي مَا آذَاهَا ‏"‏ ‏.‏\hadithno{1998}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Mishwar bin Makhramah said:"I heard the Messenger of Allah when he was on the pulpit, say: 'Banu Hisham bin Mughirah asked me for permission to marry their daughter to 'Ali bin Abu Talib, but I will not give them permission, and I will not give them permission, and I will not give them permission, unless 'Ali bin Abu Talib wants to divorce my daughter and marry their daughter, for she is a part of me, and what bothers her bothers me, and what upsets her upsets me}}
\hadithdefcmd{ibnmajah}{1999}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو الْيَمَانِ، أَنْبَأَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَلِيُّ بْنُ الْحُسَيْنِ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ خَطَبَ بِنْتَ أَبِي جَهْلٍ وَعِنْدَهُ فَاطِمَةُ بِنْتُ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَلَمَّا سَمِعَتْ بِذَلِكَ، فَاطِمَةُ أَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَتْ إِنَّ قَوْمَكَ يَتَحَدَّثُونَ أَنَّكَ لاَ تَغْضَبُ لِبَنَاتِكَ وَهَذَا عَلِيٌّ نَاكِحًا ابْنَةَ أَبِي جَهْلٍ ‏.‏ قَالَ الْمِسْوَرُ فَقَامَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَسَمِعْتُهُ حِينَ تَشَهَّدَ ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ فَإِنِّي قَدْ أَنْكَحْتُ أَبَا الْعَاصِ بْنَ الرَّبِيعِ فَحَدَّثَنِي فَصَدَقَنِي وَإِنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ بَضْعَةٌ مِنِّي وَأَنَا أَكْرَهُ أَنْ تَفْتِنُوهَا وَإِنَّهَا وَاللَّهِ لاَ تَجْتَمِعُ بِنْتُ رَسُولِ اللَّهِ وَبِنْتُ عَدُوِّ اللَّهِ عِنْدَ رَجُلٍ وَاحِدٍ أَبَدًا ‏"‏ ‏.‏ قَالَ فَنَزَلَ عَلِيٌّ عَنِ الْخِطْبَةِ ‏.‏\hadithno{1999}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ali bin Husain said that Miswar bin Makhramah told him that:'Ali bin Abu Talib proposed to the daughter of Abu Jahl, when he was married to Fatimah the daughter of the Prophet. When Fatimah heard of that she went to the Prophet, and said: "Your people are saying that you do not feel angry for your daughters. This 'Ali is going to marry the daughter of Abu Jahl." Miswar said: "The Prophet stood up, and I heard him when he bore witness (i.e., said the Shahadah), then he said: 'I married my daughter (Zainab) to Abul-As bin Rabi', and he spoke to me and was speaking the truth. Fatimah bint Muhammad is a part of me, and I hate to see her faced with troubles. By Allah, the daughter of the Messenger of Allah and the daughter of the enemy of Allah will never be joined together in marriage to one man." He said: So, 'Ali abandoned the marriage proposal}}
\hadithdefcmd{ibnmajah}{2000}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تَقُولُ أَمَا تَسْتَحِي الْمَرْأَةُ أَنْ تَهَبَ نَفْسَهَا لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ حَتَّى أَنْزَلَ اللَّهُ ‏\{تُرْجِي مَنْ تَشَاءُ مِنْهُنَّ وَتُؤْوِي إِلَيْكَ مَنْ تَشَاءُ\}‏ ‏.‏ قَالَتْ فَقُلْتُ إِنَّ رَبَّكَ لَيُسَارِعُ فِي هَوَاكَ ‏.‏\hadithno{2000}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It 'was narrated from Hisham bin 'Urwah, from his father that 'Aishah used to say:"Wouldn't a woman feel too shy to offer herself to the Prophet?" Until Aileh revealed; "You (O Muhammad) can postpone (the turn of) whom you will of them (your wives), and you may receive whom you will.” She said: "Then I said: 'Your Lord is quick to make things easy for you}}
\hadithdefcmd{ibnmajah}{2001}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ وَمُحَمَّدُ بْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا ثَابِتٌ، قَالَ كُنَّا جُلُوسًا مَعَ أَنَسِ بْنِ مَالِكٍ وَعِنْدَهُ ابْنَةٌ لَهُ فَقَالَ أَنَسٌ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَعَرَضَتْ نَفْسَهَا عَلَيْهِ ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ هَلْ لَكَ فِيَّ حَاجَةٌ فَقَالَتِ ابْنَتُهُ مَا أَقَلَّ حَيَاءَهَا ‏.‏ فَقَالَ هِيَ خَيْرٌ مِنْكِ رَغِبَتْ فِي رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَعَرَضَتْ نَفْسَهَا عَلَيْهِ ‏.‏\hadithno{2001}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Thabit said:“We were sitting with Anas bin Mahk, and a daughter of his was with him. Anas said: 'A woman came to the Prophet and offered herself to him. She said: " O Messenger of Allah, do you have any need of me?"' His daughter said: 'How little modesty she had!' He said: 'She was better than you, because she wanted (to marry) the Messenger of Allah, and she offered herself to him}}
\hadithdefcmd{ibnmajah}{2002}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ مِنْ بَنِي فَزَارَةَ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَمَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ ‏.‏ قَالَ ‏"‏ هَلْ فِيهَا مِنْ أَوْرَقَ ‏"‏ ‏.‏ قَالَ إِنَّ فِيهَا لَوُرْقًا ‏.‏ قَالَ ‏"‏ فَأَنَّى أَتَاهَا ذَلِكَ ‏"‏ ‏.‏ قَالَ عَسَى عِرْقٌ نَزَعَهَا ‏.‏ قَالَ ‏"‏ وَهَذَا لَعَلَّ عِرْقًا نَزَعَهُ ‏"‏ ‏.‏ وَاللَّفْظُ لاِبْنِ الصَّبَّاحِ ‏.‏\hadithno{2002}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"A man from Banu Fazdrah came to the Messenger of Allah, and said: 'O Messenger of Allah, my wife has given birth to a black boy! The Messenger of Allah said: 'Do you have camels?' He said: 'Yes.' He said: 'What color are they?' He said: 'Red.' He said: 'Are there any grey ones among them?' He said: 'Yes, there are some grey ones among them.' He said: 'Where does that come from?' He said: 'Perhaps it is hereditary.' He said: 'Likewise, perhaps this is hereditary}}
\hadithdefcmd{ibnmajah}{2003}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبَاءَةُ بْنُ كُلَيْبٍ اللَّيْثِيُّ أَبُو غَسَّانَ، عَنْ جُوَيْرِيَةَ بْنِ أَسْمَاءَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ‏.‏ أَنَّ رَجُلاً، مِنْ أَهْلِ الْبَادِيَةِ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ امْرَأَتِي وَلَدَتْ عَلَى فِرَاشِي غُلاَمًا أَسْوَدَ وَإِنَّا أَهْلُ بَيْتٍ لَمْ يَكُنْ فِينَا أَسْوَدُ قَطُّ ‏.‏ قَالَ ‏"‏ هَلْ لَكَ مِنَ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَمَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ ‏.‏ قَالَ ‏"‏ هَلْ فِيهَا أَسْوَدُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ فِيهَا أَوْرَقُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَأَنَّى كَانَ ذَلِكَ ‏"‏ ‏.‏ قَالَ عَسَى أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏.‏ قَالَ ‏"‏ فَلَعَلَّ ابْنَكَ هَذَا نَزَعَهُ عِرْقٌ ‏"‏ ‏.‏\hadithno{2003}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:a man frorn the desert people came to the Prophet and said: "O Messenger of Allah, my wife has given birth on my bed to a black boy, and there are no black people among my family." He said: "Do you have camels?" He said: "Yes." He said: "What color are they?" He said: "Red." He said: are there any black ones among them?" He said, "No." He said: "Are there any grey ones among them?" He said- "Yes." He said "How is that?" He said: "Perhaps it is hereditary." He said: "Perhaps (the color of) this son of yours is also hereditary}}
\hadithdefcmd{ibnmajah}{2004}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ عَبْدَ بْنَ زَمْعَةَ وَسَعْدًا اخْتَصَمَا إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي ابْنِ أَمَةِ زَمْعَةَ ‏.‏ فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ أَوْصَانِي أَخِي إِذَا قَدِمْتُ مَكَّةَ أَنْ أَنْظُرَ إِلَى ابْنِ أَمَةِ زَمْعَةَ فَأَقْبِضَهُ ‏.‏ وَقَالَ عَبْدُ بْنُ زَمْعَةَ أَخِي وَابْنُ أَمَةِ أَبِي وُلِدَ عَلَى فِرَاشِ أَبِي ‏.‏ فَرَأَى النَّبِيُّ ـ صلى الله عليه وسلم ـ شَبَهَهُ بِعُتْبَةَ فَقَالَ ‏ "‏ هُوَ لَكَ يَا عَبْدُ بْنُ زَمْعَةَ ‏.‏ الْوَلَدُ لِلْفِرَاشِ وَاحْتَجِبِي عَنْهُ يَا سَوْدَةُ ‏"‏ ‏.‏\hadithno{2004}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:Ibn Zam'ah and Sa'd (Ibn Abu Waqqas) referred a dispute to the Prophet concerning the son of Zam'ah's slave woman. Sa'd said : " O Messenger of Allah my brother (Utbah bin Abu Waqqas) left instructions in his will that when I come to Makkah, I should look for the son of the slave woman of Zam'ah and take him into my care." 'Abd bin Zam’ah said: "He is my brother and the son of the slave woman of my father; he was born on my father's bed." The Prophet ffi saw that he resembled 'Utbah, and said: "He belongs to you, O 'Abd bin Zam'ah. The child is for the bed. Observe Hijab before him, O Saudah." (sahih)}}
\hadithdefcmd{ibnmajah}{2005}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ أَبِيهِ، عَنْ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَضَى بِالْوَلَدِ لِلْفِرَاشِ ‏.‏\hadithno{2005}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Umar that:the Messenger of Allah ruled that the child belonged to the bed}}
\hadithdefcmd{ibnmajah}{2006}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْوَلَدُ لِلْفِرَاشِ ‏.‏ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏\hadithno{2006}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:the Prophet said: "The child is for the bed (i.e., belongs to the husband) and the fornicator gets nothing}}
\hadithdefcmd{ibnmajah}{2007}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا شُرَحْبِيلُ بْنُ مُسْلِمٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ الْبَاهِلِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏\hadithno{2007}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shurahbil bin Muslim said:"I heard Abu Um Amah Al-Bahili say: 'I heard the Messenger of Allah say: "The child is for the bed and the fornicator gets nothing}}
\hadithdefcmd{ibnmajah}{2008}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَفْصُ بْنُ جُمَيْعٍ، حَدَّثَنَا سِمَاكٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، جَاءَتْ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَسْلَمَتْ ‏.‏ فَتَزَوَّجَهَا رَجُلٌ ‏.‏ قَالَ فَجَاءَ زَوْجُهَا الأَوَّلُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ كُنْتُ أَسْلَمْتُ مَعَهَا وَعَلِمَتْ بِإِسْلاَمِي ‏.‏ قَالَ فَانْتَزَعَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ زَوْجِهَا الآخَرِ وَرَدَّهَا إِلَى زَوْجِهَا الأَوَّلِ ‏.‏\hadithno{2008}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that:a woman came to the Prophet and became Muslim, and a man married her. Then her first husband came and said: "O Messenger of Allah, I became Muslim with her, and she knew that I was Muslim." So the Messenger of Allah took her away from her second husband and returned her to her first husband}}
\hadithdefcmd{ibnmajah}{2009}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ، وَيَحْيَى بْنُ حَكِيمٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَدَّ ابْنَتَهُ عَلَى أَبِي الْعَاصِ بْنِ الرَّبِيعِ بَعْدَ سَنَتَيْنِ بِنِكَاحِهَا الأَوَّلِ ‏.‏\hadithno{2009}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that:the Messenger of Allah returned his daughter to Abul-'As bin Rabi' after two years, on the basis of the first marriage contract}}
\hadithdefcmd{ibnmajah}{2010}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ حَجَّاجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَدَّ ابْنَتَهُ زَيْنَبَ عَلَى أَبِي الْعَاصِ بْنِ الرَّبِيعِ بِنِكَاحٍ جَدِيدٍ ‏.‏\hadithno{2010}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grand father, that:the Messenger of Allah, returned his daughter Zainab to Abul-As bin Rabi', with a new marriage contract}}
\hadithdefcmd{ibnmajah}{2011}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ الْقُرَشِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنْ جُدَامَةَ بِنْتِ وَهْبٍ الأَسَدِيَّةِ، أَنَّهَا قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ قَدْ أَرَدْتُ أَنْ أَنْهَى عَنِ الْغِيَالِ فَإِذَا فَارِسُ وَالرُّومُ يُغِيلُونَ فَلاَ يَقْتُلُونَ أَوْلاَدَهُمْ ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ وَسُئِلَ عَنِ الْعَزْلِ فَقَالَ ‏"‏ هُوَ الْوَأْدُ الْخَفِيُّ ‏"‏ ‏.‏\hadithno{2011}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Judamah bint Wahb Al-Asadiyyah said:"I heard the Messenger of Allah say: 'I wanted to forbid intercourse with a nursing mother, but then (I saw that) the Persians and the Romans do this, and it does not kill their children.' And I heard him say/when he was asked about coitus interruptus: 'It is the disguised form of b.rryirg children alive}}
\hadithdefcmd{ibnmajah}{2012}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ عَمْرِو بْنِ مُهَاجِرٍ، أَنَّهُ سَمِعَ أَبَاهُ الْمُهَاجِرَ بْنَ أَبِي مُسْلِمٍ، يُحَدِّثُ عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ بْنِ السَّكَنِ، وَكَانَتْ، مَوْلاَتَهُ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ تَقْتُلُوا أَوْلاَدَكُمْ سِرًّا فَوَالَّذِي نَفْسِي بِيَدِهِ إِنَّ الْغَيْلَ لَيُدْرِكُ الْفَارِسَ عَلَى ظَهْرِ فَرَسِهِ حَتَّى يَصْرَعَهُ ‏"‏ ‏.‏\hadithno{2012}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muhajir bin Abu Muslim, from Asma' bint Yazid bin Sakary who was his freed slave womary that:she heard the Messenger of Allah say: "Do not kill your children secretly, for by the One in Whose Hand is my soul, intercourse with a breastfeeding woman catches up with people when they are riding their horses (in battle) and wrestles them to the ground}}
\hadithdefcmd{ibnmajah}{2013}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُؤَمَّلٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِي أُمَامَةَ، قَالَ أَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ امْرَأَةٌ مَعَهَا صَبِيَّانِ لَهَا قَدْ حَمَلَتْ أَحَدَهُمَا وَهِيَ تَقُودُ الآخَرَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ حَامِلاَتٌ وَالِدَاتٌ رَحِيمَاتٌ لَوْلاَ مَا يَأْتِينَ إِلَى أَزْوَاجِهِنَّ دَخَلَ مُصَلِّيَاتُهُنَّ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{2013}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah said:"A woman came to the Prophet with two of her children, carrying one and leading the other. The Messenger of Allah said: 'They carry children and give birth to them and are compassionate. If they do not annoy their husbands, those among them who perform prayer will enter Paradise}}
\hadithdefcmd{ibnmajah}{2014}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ الضَّحَّاكِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ كَثِيرِ بْنِ مُرَّةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُؤْذِي امْرَأَةٌ زَوْجَهَا إِلاَّ قَالَتْ زَوْجَتُهُ مِنَ الْحُورِ الْعِينِ لاَ تُؤْذِيهِ قَاتَلَكِ اللَّهُ فَإِنَّمَا هُوَ عِنْدَكِ دَخِيلٌ أَوْشَكَ أَنْ يُفَارِقَكِ إِلَيْنَا ‏"‏ ‏.‏\hadithno{2014}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Mu'adh bin Jabal that:the Messenger of Allah said: "No woman annoys her husband but his wife among houris (of Paradise) safs: 'Do not annoy him, may Allah destroy you, for he is just a temporary guest with you and soon he will leave you and join us}}
\hadithdefcmd{ibnmajah}{2015}{حَدَّثَنَا يَحْيَى بْنُ مُعَلَّى بْنِ مَنْصُورٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مُحَمَّدٍ الْفَرْوِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يُحَرِّمُ الْحَرَامُ الْحَلاَلَ ‏"‏ ‏.‏\hadithno{2015}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that:the Prophet, said: "What is Haram does not make what is Halal into what is Haram.”}}
