% Auto-generated chapter 33 for tirmidhi
% Hadiths in this chapter: 112

\hadithdefcmd{tirmidhi}{2158}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، أَشْرَفَ يَوْمَ الدَّارِ فَقَالَ أَنْشُدُكُمُ اللَّهَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ إِلاَّ بِإِحْدَى ثَلاَثٍ زِنًا بَعْدَ إِحْصَانٍ أَوِ ارْتِدَادٍ بَعْدَ إِسْلاَمٍ أَوْ قَتْلِ نَفْسٍ بِغَيْرِ حَقٍّ فَقُتِلَ بِهِ ‏"‏ ‏.‏ فَوَاللَّهِ مَا زَنَيْتُ فِي جَاهِلِيَّةٍ وَلاَ فِي إِسْلاَمٍ وَلاَ ارْتَدَدْتُ مُنْذُ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَلاَ قَتَلْتُ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ فَبِمَ تَقْتُلُونَنِي قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَعَائِشَةَ وَابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ يَحْيَى بْنِ سَعِيدٍ فَرَفَعَهُ ‏.‏ وَرَوَى يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَغَيْرُ وَاحِدٍ عَنْ يَحْيَى بْنِ سَعِيدٍ هَذَا الْحَدِيثَ فَأَوْقَفُوهُ وَلَمْ يَرْفَعُوهُ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ عُثْمَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم مَرْفُوعًا ‏\hadithno{2158}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Umamah bin Sahl bin Hunaif narrated that on the day of siege, 'Uthman bin 'Affan stood overlooking the people, and he said:"I swear to you by Allah! You know that the Messenger of Allah (s.a.w) said: 'The blood of a Muslim man is not lawful, except for one of three (cases):Illegitimate sexual relations after Ihsan (having been married), or apostasy after Islam, or taking a life without right, for which he is killed.'	By Allah! I have never committed illegitimate sexual relations, not during Jahiliyyah nor during Islam, and I have not committed apostasy since I gave my pledge to the Messenger of Allah (s.a.w), and I have not taken a life that Allah had made unlawful. So for what do you fight me?}}
\hadithdefcmd{tirmidhi}{2159}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي حِجَّةِ الْوَدَاعِ لِلنَّاسِ ‏"‏ أَىُّ يَوْمٍ هَذَا ‏"‏ ‏.‏ قَالُوا يَوْمُ الْحَجِّ الأَكْبَرِ ‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ وَأَعْرَاضَكُمْ بَيْنَكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا أَلاَ لاَ يَجْنِي جَانٍ إِلاَّ عَلَى نَفْسِهِ أَلاَ لاَ يَجْنِي جَانٍ عَلَى وَلَدِهِ وَلاَ مَوْلُودٌ عَلَى وَالِدِهِ أَلاَ وَإِنَّ الشَّيْطَانَ قَدْ أَيِسَ مِنْ أَنْ يُعْبَدَ فِي بِلاَدِكُمْ هَذِهِ أَبَدًا وَلَكِنْ سَتَكُونُ لَهُ طَاعَةٌ فِيمَا تَحْتَقِرُونَ مِنْ أَعْمَالِكُمْ فَسَيَرْضَى بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي بَكْرَةَ وَابْنِ عَبَّاسٍ وَجَابِرٍ وَحُذَيْمِ بْنِ عَمْرٍو السَّعْدِيِّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى زَائِدَةُ عَنْ شَبِيبِ بْنِ غَرْقَدَةَ نَحْوَهُ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شَبِيبِ بْنِ غَرْقَدَةَ ‏.‏\hadithno{2159}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sulaiman bin 'Amr bin Al-Ahwas narrated from his father who said:"During the Farewell Pilgrimage, I heard the Messenger of Allah(s.a.w) saying: 'Which day is this?' They said:'The day of Al-Hajj Al-Akbar.'He said:'Indeed your blood, your wealth, your honour is sacred to each other, just as this day of yours is sacred in this city of yours. Indeed, no one commits a crime except against himself. Indeed none commits a crime for which his son is accountable, nor does a child commit a crime for which his father is held accountable. Indeed Ash-Shaitan has lost hope of ever being worshipped in this city of yours, but he will have compliance in what deeds of yours you consider insignificant, which he will be content with}}
\hadithdefcmd{tirmidhi}{2160}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ السَّائِبِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَأْخُذْ أَحَدُكُمْ عَصَا أَخِيهِ لاَعِبًا أَوْ جَادًّا فَمَنْ أَخَذَ عَصَا أَخِيهِ فَلْيَرُدَّهَا إِلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَسُلَيْمَانَ بْنِ صُرَدَ وَجَعْدَةَ وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ أَبِي ذِئْبٍ ‏.‏ وَالسَّائِبُ بْنُ يَزِيدَ لَهُ صُحْبَةٌ قَدْ سَمِعَ مِنَ النَّبِيِّ صلى الله عليه وسلم أَحَادِيثَ وَهُوَ غُلاَمٌ وَقُبِضَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ ابْنُ سَبْعِ سِنِينَ وَوَالِدُهُ يَزِيدُ بْنُ السَّائِبِ لَهُ أَحَادِيثُ هُوَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَقَدْ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم وَالسَّائِبُ بْنُ يَزِيدَ هُوَ ابْنُ أُخْتِ نَمِرٍ\hadithno{2160}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin As-Sa'ib bin Yazid narrated from his father, from his grandfather who said:"The Messenger of Allah (s.a.w) said: 'Let one of you not take his brother's staff, neither in play nor seriousness. Whoever took his brother's staff, then let him return it to him}}
\hadithdefcmd{tirmidhi}{2161}{‏ حَدَّثَنَا قُتَيْبَةُ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ عَنْ مُحَمَّدِ بْنِ يُوسُفَ عَنِ السَّائِبِ بْنِ يَزِيدَ قَالَ حَجَّ يَزِيدُ مَعَ النَّبِيِّ صلى الله عليه وسلم حَجَّةَ الْوَدَاعِ وَأَنَا ابْنُ سَبْعِ سِنِينَ ‏.‏ فَقَالَ عَلِيُّ بْنُ الْمَدِينِيِّ عَنْ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ كَانَ مُحَمَّدُ بْنُ يُوسُفَ ثَبْتًا صَاحِبَ حَدِيثٍ وَكَانَ السَّائِبُ بْنُ يَزِيدَ جَدَّهُ وَكَانَ مُحَمَّدُ بْنُ يُوسُفَ يَقُولُ حَدَّثَنِي السَّائِبُ بْنُ يَزِيدَ وَهُوَ جَدِّي مِنْ قِبَلِ أُمِّي ‏.‏\hadithno{2161}\hadithgrade{Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Muhammad bin Yusuf narrated that As-Sa'ib bin Yazid said:"Yazid performed Hajj in the Farewell Pilgrimage with the Prophet (s.a.w) when I was seven years old." So 'Ali bin Al-Madini narrated from Yahya bin Sa'eed Al-Qattan: "Muhammad bin Yusuf was a very reliable narrator of Hadith, and As-Sa'ib bin Yazid was his grandfather, and Muhammad bin Yusuf would say: 'As-Sa'ib bin Yazid narrated to me- and he is my grandfather from my mother's side}}
\hadithdefcmd{tirmidhi}{2162}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْعَطَّارُ الْهَاشِمِيُّ، حَدَّثَنَا مَحْبُوبُ بْنُ الْحَسَنِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَشَارَ عَلَى أَخِيهِ بِحَدِيدَةٍ لَعَنَتْهُ الْمَلاَئِكَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي بَكْرَةَ وَعَائِشَةَ وَجَابِرٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ يُسْتَغْرَبُ مِنْ حَدِيثِ خَالِدٍ الْحَذَّاءِ ‏.‏ وَرَوَاهُ أَيُّوبُ عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، نَحْوَهُ وَلَمْ يَرْفَعْهُ وَزَادَ فِيهِ ‏"‏ وَإِنْ كَانَ أَخَاهُ لأَبِيهِ وَأُمِّهِ ‏"‏ ‏.‏ قَالَ وَأَخْبَرَنَا بِذَلِكَ قُتَيْبَةُ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ عَنْ أَيُّوبَ بِهَذَا ‏.‏\hadithno{2162}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"Whoever points a piece of iron at his brother, the angels curse him}}
\hadithdefcmd{tirmidhi}{2163}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ الْبَصْرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتَعَاطَى السَّيْفُ مَسْلُولاً ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي بَكْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏ وَرَوَى ابْنُ لَهِيعَةَ هَذَا الْحَدِيثَ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنْ بَنَّةَ الْجُهَنِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَحَدِيثُ حَمَّادِ بْنِ سَلَمَةَ عِنْدِي أَصَحُّ ‏.‏\hadithno{2163}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated :"The Messenger of Allah(s.a.w) prohibited passing an unsheathed sword}}
\hadithdefcmd{tirmidhi}{2164}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا مَعْدِيُّ بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَلَّى الصُّبْحَ فَهُوَ فِي ذِمَّةِ اللَّهِ فَلاَ يُتْبِعَنَّكُمُ اللَّهُ بِشَيْءٍ مِنْ ذِمَّتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ جُنْدَبٍ وَابْنِ عُمَرَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2164}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"Whoever prays Subh, then he is under the protection of Allah's covenant, so do not infringe at all upon Allah's covenant}}
\hadithdefcmd{tirmidhi}{2165}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا النَّضْرُ بْنُ إِسْمَاعِيلَ أَبُو الْمُغِيرَةِ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ خَطَبَنَا عُمَرُ بِالْجَابِيَةِ فَقَالَ يَا أَيُّهَا النَّاسُ إِنِّي قُمْتُ فِيكُمْ كَمَقَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِينَا فَقَالَ ‏ "‏ أُوصِيكُمْ بِأَصْحَابِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ يَفْشُو الْكَذِبُ حَتَّى يَحْلِفَ الرَّجُلُ وَلاَ يُسْتَحْلَفُ وَيَشْهَدَ الشَّاهِدُ وَلاَ يُسْتَشْهَدُ أَلاَ لاَ يَخْلُوَنَّ رَجُلٌ بِامْرَأَةٍ إِلاَّ كَانَ ثَالِثَهُمَا الشَّيْطَانُ عَلَيْكُمْ بِالْجَمَاعَةِ وَإِيَّاكُمْ وَالْفُرْقَةَ فَإِنَّ الشَّيْطَانَ مَعَ الْوَاحِدِ وَهُوَ مِنَ الاِثْنَيْنِ أَبْعَدُ مَنْ أَرَادَ بُحْبُوحَةَ الْجَنَّةِ فَلْيَلْزَمِ الْجَمَاعَةَ مَنْ سَرَّتْهُ حَسَنَتُهُ وَسَاءَتْهُ سَيِّئَتُهُ فَذَلِكَ الْمُؤْمِنُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رَوَاهُ ابْنُ الْمُبَارَكِ عَنْ مُحَمَّدِ بْنِ سُوقَةَ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2165}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Umar narrated:" 'Umar delivered a Khutbah to us at Al-Jabiyah. He said: 'O you people! Indeed I have stood among you as the Messenger of Allah(s.a.w) stood among us, and he said: "I order you (to stick to) my Companions, then those who come after them, then those who come after them. Then lying will spread until a man will take an oath when no oath was sought from him, and a witness will testify when his testimony was not sought. Behold! A man is not alone with a woman but the third of them is Ash-Shaitan. Adhere to the Jama'ah, beware of separation, for indeed Ash-Shaitan is with one, and he is further away from two. Whoever wants the best place in Paradise, then let him stick to the Jama'ah. Whoever rejoices with his good deeds and grieves over his evil deeds, then that is the believer among you}}
\hadithdefcmd{tirmidhi}{2166}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ مَيْمُونٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَدُ اللَّهِ مَعَ الْجَمَاعَةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ ابْنِ عَبَّاسٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2166}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (s.a.w) said:"Allah's Hand is with the Jama'ah}}
\hadithdefcmd{tirmidhi}{2167}{حَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ الْبَصْرِيُّ، حَدَّثَنِي الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا سُلَيْمَانُ الْمَدَنِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ لاَ يَجْمَعُ أُمَّتِي - أَوْ قَالَ أُمَّةَ مُحَمَّدٍ صلى الله عليه وسلم - عَلَى ضَلاَلَةٍ وَيَدُ اللَّهِ مَعَ الْجَمَاعَةِ وَمَنْ شَذَّ شَذَّ إِلَى النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَسُلَيْمَانُ الْمَدَنِيُّ هُوَ عِنْدِي سُلَيْمَانُ بْنُ سُفْيَانَ وَقَدْ رَوَى عَنْهُ أَبُو دَاوُدَ الطَّيَالِسِيُّ وَأَبُو عَامِرٍ الْعَقَدِيُّ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ ‏.‏ قَالَ أَبُو عِيسَى وَتَفْسِيرُ الْجَمَاعَةِ عِنْدَ أَهْلِ الْعِلْمِ هُمْ أَهْلُ الْفِقْهِ وَالْعِلْمِ وَالْحَدِيثِ ‏.‏ قَالَ وَسَمِعْتُ الْجَارُودَ بْنَ مُعَاذٍ يَقُولُ سَمِعْتُ عَلِيَّ بْنَ الْحَسَنِ يَقُولُ سَأَلْتُ عَبْدَ اللَّهِ بْنَ الْمُبَارَكِ مَنِ الْجَمَاعَةُ فَقَالَ أَبُو بَكْرٍ وَعُمَرُ ‏.‏ قِيلَ لَهُ قَدْ مَاتَ أَبُو بَكْرٍ وَعُمَرُ ‏.‏ قَالَ فُلاَنٌ وَفُلاَنٌ ‏.‏ قِيلَ لَهُ قَدْ مَاتَ فُلاَنٌ وَفُلاَنٌ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ أَبُو حَمْزَةَ السُّكَّرِيُّ جَمَاعَةٌ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو حَمْزَةَ هُوَ مُحَمَّدُ بْنُ مَيْمُونٍ وَكَانَ شَيْخًا صَالِحًا وَإِنَّمَا قَالَ هَذَا فِي حَيَاتِهِ عِنْدَنَا ‏.‏\hadithno{2167}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah(s.a.w) said:'Indeed Allah will not gather my Ummah " - or he said: "[Muhammad's]Ummah upon deviation, and Allah's Hand is over the Jama'ah, and whoever deviates, he deviates to the Fire}}
\hadithdefcmd{tirmidhi}{2168}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، أَنَّهُ قَالَ أَيُّهَا النَّاسُ إِنَّكُمْ تَقْرَءُونَ هَذِهِ الآيَةَ ‏:‏ ‏(‏يَا أَيُّهَا الَّذِينَ آمَنُوا عَلَيْكُمْ أَنْفُسَكُمْ لاَ يَضُرُّكُمْ مَنْ ضَلَّ إِذَا اهْتَدَيْتُمْ ‏)‏ وَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ النَّاسَ إِذَا رَأَوُا الظَّالِمَ فَلَمْ يَأْخُذُوا عَلَى يَدَيْهِ أَوْشَكَ أَنْ يَعُمَّهُمُ اللَّهُ بِعِقَابٍ مِنْهُ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ، وَأُمِّ سَلَمَةَ وَالنُّعْمَانِ بْنِ بَشِيرٍ وَعَبْدِ اللَّهِ بْنِ عُمَرَ وَحُذَيْفَةَ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى غَيْرُ، وَاحِدٍ، عَنْ إِسْمَاعِيلَ، نَحْوَ حَدِيثِ يَزِيدَ وَرَفَعَهُ بَعْضُهُمْ عَنْ إِسْمَاعِيلَ، وَأَوْقَفَهُ، بَعْضُهُمْ ‏.‏\hadithno{2168}\hadithgrade{Al-Albani: Sahih}\hadithtrans{Abu Bakr As-Siddiq said:"O you people! You recite this Ayah: Take care of yourselves! If you follow the guidance no harm shall come to you. I indeed heard the Messenger of Allah (s.a.w) saying: 'When the people see the wrongdoer and they do not take him by the hand, then soon Allah shall envelope you in a punishment from him}}
\hadithdefcmd{tirmidhi}{2169}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عَبْدِ اللَّهِ الأَنْصَارِيِّ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَتَأْمُرُنَّ بِالْمَعْرُوفِ وَلَتَنْهَوُنَّ عَنِ الْمُنْكَرِ أَوْ لَيُوشِكَنَّ اللَّهُ أَنْ يَبْعَثَ عَلَيْكُمْ عِقَابًا مِنْهُ ثُمَّ تَدْعُونَهُ فَلاَ يُسْتَجَابُ لَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2169}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Hudhaifah bin Al-Yaman narrated that the Prophet (s.a.w) said:"By the One in Whose Hand is my soul! Either you command good and forbid evil, or Allah will soon send upon you a punishment from Him, then you will call upon Him, but He will not respond to you}}
\hadithdefcmd{tirmidhi}{2170}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عَبْدِ اللَّهِ، وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الأَنْصَارِيُّ الأَشْهَلِيُّ عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَقُومُ السَّاعَةُ حَتَّى تَقْتُلُوا إِمَامَكُمْ وَتَجْتَلِدُوا بِأَسْيَافِكُمْ وَيَرِثَ دُنْيَاكُمْ شِرَارُكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ عَمْرِو بْنِ أَبِي عَمْرٍو ‏.‏\hadithno{2170}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Hudhaifah bin Al-Yaman narrated that the Messenger of Allah (s.a.w) said:"By the One in Whose Hand is my soul! The Hour will not be established until you fight your A'immah, and you strike each other with your swords, and your world will be inherited by the evilest among you}}
\hadithdefcmd{tirmidhi}{2171}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ ذَكَرَ الْجَيْشَ الَّذِي يُخْسَفُ بِهِمْ فَقَالَتْ أُمُّ سَلَمَةَ لَعَلَّ فِيهِمُ الْمُكْرَهَ ‏.‏ قَالَ ‏ "‏ إِنَّهُمْ يُبْعَثُونَ عَلَى نِيَّاتِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ نَافِعِ بْنِ جُبَيْرٍ عَنْ عَائِشَةَ أَيْضًا عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2171}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Salamah narrated that the Prophet (s.a.w) mentioned the army that the earth would swallow, so Umm Salamah said:'Perhaps there are those among them who are averse to it." He said: "They will be resurrected on their intentions}}
\hadithdefcmd{tirmidhi}{2172}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، قَالَ أَوَّلُ مَنْ قَدَّمَ الْخُطْبَةَ قَبْلَ الصَّلاَةِ مَرْوَانُ فَقَامَ رَجُلٌ فَقَالَ لِمَرْوَانَ خَالَفْتَ السُّنَّةَ ‏.‏ فَقَالَ يَا فُلاَنُ تُرِكَ مَا هُنَالِكَ ‏.‏ فَقَالَ أَبُو سَعِيدٍ أَمَّا هَذَا فَقَدْ قَضَى مَا عَلَيْهِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ رَأَى مُنْكَرًا فَلْيُنْكِرْهُ بِيَدِهِ وَمَنْ لَمْ يَسْتَطِعْ فَبِلِسَانِهِ وَمَنْ لَمْ يَسْتَطِعْ فَبِقَلْبِهِ وَذَلِكَ أَضْعَفُ الإِيمَانِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2172}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Tariq bin Shihab said:"The first to advance the Khutbah before the Salat was Marwan. A man stood to say to Marwan: 'You have contradicted the Sunnah.' So he said: 'O so-and-so! What was there it has been left.' So Abu Sa'eed said: 'As for this, he has fulfilled what is upon him. I heard the Messenger of Allah (s.a.w) saying: 'Whomever among you sees an evil, then let him stop it with his hand. Whomever is not able,then with his tongue, and whomever is not able, then with his heart. That is the weakest of faith}}
\hadithdefcmd{tirmidhi}{2173}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْقَائِمِ عَلَى حُدُودِ اللَّهِ وَالْمُدْهِنِ فِيهَا كَمَثَلِ قَوْمٍ اسْتَهَمُوا عَلَى سَفِينَةٍ فِي الْبَحْرِ فَأَصَابَ بَعْضُهُمْ أَعْلاَهَا وَأَصَابَ بَعْضُهُمْ أَسْفَلَهَا فَكَانَ الَّذِينَ فِي أَسْفَلِهَا يَصْعَدُونَ فَيَسْتَقُونَ الْمَاءَ فَيَصُبُّونَ عَلَى الَّذِينَ فِي أَعْلاَهَا فَقَالَ الَّذِينَ فِي أَعْلاَهَا لاَ نَدَعُكُمْ تَصْعَدُونَ فَتُؤْذُونَنَا فَقَالَ الَّذِينَ فِي أَسْفَلِهَا فَإِنَّا نَنْقُبُهَا مِنْ أَسْفَلِهَا فَنَسْتَقِي فَإِنْ أَخَذُوا عَلَى أَيْدِيهِمْ فَمَنَعُوهُمْ نَجَوْا جَمِيعًا وَإِنْ تَرَكُوهُمْ غَرِقُوا جَمِيعًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2173}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{An-Nu'man bin Bashir narrated that the Messenger of Allah (s.a.w) said:"The parable of the one who upholds Allah's laws and the one who breaches them, is that of a people who drew lots on a ship at sea. Some of them got the upper part, and some of them the lower part. Those on the lower part ascended to get water, spilling it upon those upper part. So those in the upper part say: 'We will not leave you to come up here and bother us.' Then those on the lower part say: 'We should make a hole in the lower part, so we can get water.' If they take them by the hand and stop them, then they will save all of them, and if they leave them, they will all drown}}
\hadithdefcmd{tirmidhi}{2174}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مُصْعَبٍ أَبُو يَزِيدَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مِنْ أَعْظَمِ الْجِهَادِ كَلِمَةَ عَدْلٍ عِنْدَ سُلْطَانٍ جَائِرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي أُمَامَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2174}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Prophet (s.a.w) said:"Indeed, among the greatest types of Jihad is a just statement before a tyrannical ruler}}
\hadithdefcmd{tirmidhi}{2175}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ النُّعْمَانَ بْنَ رَاشِدٍ، يُحَدِّثُ عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابِ بْنِ الأَرَتِّ، عَنْ أَبِيهِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةً فَأَطَالَهَا قَالُوا يَا رَسُولَ اللَّهِ صَلَّيْتَ صَلاَةً لَمْ تَكُنْ تُصَلِّيهَا قَالَ ‏ "‏ أَجَلْ إِنَّهَا صَلاَةُ رَغْبَةٍ وَرَهْبَةٍ إِنِّي سَأَلْتُ اللَّهَ فِيهَا ثَلاَثًا فَأَعْطَانِي اثْنَتَيْنِ وَمَنَعَنِي وَاحِدَةً سَأَلْتُهُ أَنْ لاَ يُهْلِكَ أُمَّتِي بِسَنَةٍ فَأَعْطَانِيهَا وَسَأَلْتُهُ أَنْ لاَ يُسَلِّطَ عَلَيْهِمْ عَدُوًّا مِنْ غَيْرِهِمْ فَأَعْطَانِيهَا وَسَأَلْتُهُ أَنْ لاَ يُذِيقَ بَعْضَهُمْ بَأْسَ بَعْضٍ فَمَنَعَنِيهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ سَعْدٍ وَابْنِ عُمَرَ ‏.‏\hadithno{2175}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Khabbab bin Al-Aratt narrated from his father:"The Messenger of Allah (s.a.w) performed Salat, making it long. They said: 'O Messenger of Allah! You have performed Salat (in a manner) which you do not ordinarily perform it.' He said: 'Yes, It was a prayer of hope and fear. In it I asked Allah for three things. He granted me two, and withheld one from me. I asked him that my Ummah not be destroyed by drought. He granted that. I asked him that they not be overcome by enemies from other then them. He granted that. And I asked him that some of them not suffer from the harm of others, and He withheld that}}
\hadithdefcmd{tirmidhi}{2176}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ زَوَى لِيَ الأَرْضَ فَرَأَيْتُ مَشَارِقَهَا وَمَغَارِبَهَا وَإِنَّ أُمَّتِي سَيَبْلُغُ مُلْكُهَا مَا زُوِيَ لِي مِنْهَا وَأُعْطِيتُ الْكَنْزَيْنِ الأَحْمَرَ وَالأَصْفَرَ وَإِنِّي سَأَلْتُ رَبِّي لأُمَّتِي أَنْ لاَ يُهْلِكَهَا بِسَنَةٍ عَامَّةٍ وَأَنَّ لاَ يُسَلِّطَ عَلَيْهِمْ عَدُوًّا مِنْ سِوَى أَنْفُسِهِمْ فَيَسْتَبِيحَ بَيْضَتَهُمْ وَإِنَّ رَبِّي قَالَ يَا مُحَمَّدُ إِنِّي إِذَا قَضَيْتُ قَضَاءً فَإِنَّهُ لاَ يُرَدُّ وَإِنِّي أَعْطَيْتُكَ لأُمَّتِكَ أَنْ لاَ أُهْلِكَهُمْ بِسَنَةٍ عَامَّةٍ وَأَنْ لاَ أُسَلِّطَ عَلَيْهِمْ عَدُوًّا مِنْ سِوَى أَنْفُسِهِمْ فَيَسْتَبِيحَ بَيْضَتَهُمْ وَلَوِ اجْتَمَعَ عَلَيْهِمْ مَنْ بِأَقْطَارِهَا أَوْ قَالَ مَنْ بَيْنَ أَقْطَارِهَا حَتَّى يَكُونَ بَعْضُهُمْ يُهْلِكُ بَعْضًا وَيَسْبِي بَعْضُهُمْ بَعْضًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2176}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thawban narrated that the Messenger of Allah (s.a.w) said:"Indeed Allah gathered the earth for me so that I saw its east and its west. And surely my Ummah's authority shall reach over all that was shown to me of it. And I have been granted the two treasures; the red and the white. I asked my Lord that my Ummah is not to be destroyed by a universal drought, and that He does not overcome them by enemies outside of them, reaching to their heart of power. My Lord said: 'O Muhammad! When I issue a decree it is not reversed. I have granted for your Ummah that they shall not be destroyed by universal drought. And that they not be overcome by enemies outside of themselves reaching to their heart of power- even if they gather against them from all the regions."' Or he said: "Among the regions. But some of them will destroy others, and some will capture others}}
\hadithdefcmd{tirmidhi}{2177}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى الْقَزَّازُ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، عَنْ رَجُلٍ، عَنْ طَاوُسٍ، عَنْ أُمِّ مَالِكٍ الْبَهْزِيَّةِ، قَالَتْ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِتْنَةً فَقَرَّبَهَا قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَنْ خَيْرُ النَّاسِ فِيهَا قَالَ ‏ "‏ رَجُلٌ فِي مَاشِيَتِهِ يُؤَدِّي حَقَّهَا وَيَعْبُدُ رَبَّهُ وَرَجُلٌ آخِذٌ بِرَأْسِ فَرَسِهِ يُخِيفُ الْعَدُوَّ وَيُخِيفُونَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أُمِّ مُبَشِّرٍ وَأَبِي سَعِيدٍ الْخُدْرِيِّ وَابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رَوَاهُ اللَّيْثُ بْنُ أَبِي سُلَيْمٍ عَنْ طَاوُسٍ عَنْ أُمِّ مَالِكٍ الْبَهْزِيَّةِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2177}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Umm Malik Al-Bahziyyah narrated that the Messenger of Allah (s.a.w) mentioned Fitnah, such that it was drawing near. She said:"I said: 'O Messenger of Allah! Who is the best of people during it?' He said: 'A man among his livestock, who pays what is due on them, and worships his Lord. And a man clutching a head of his horse, terrified of his enemy, and they terrified oh him}}
\hadithdefcmd{tirmidhi}{2178}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ لَيْثٍ، عَنْ طَاوُسٍ، عَنْ زِيَادِ بْنِ سِيمِينْ، كُوشْ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَكُونُ فِتْنَةٌ تَسْتَنْظِفُ الْعَرَبَ قَتْلاَهَا فِي النَّارِ اللِّسَانُ فِيهَا أَشَدُّ مِنَ السَّيْفِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ سَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ لاَ يُعْرَفُ لِزِيَادِ بْنِ سِيمِينَ كُوشْ غَيْرُ هَذَا الْحَدِيثِ رَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ لَيْثٍ فَرَفَعَهُ وَرَوَاهُ حَمَّادُ بْنُ زَيْدٍ عَنْ لَيْثٍ فَوَقَفَهُ ‏.‏\hadithno{2178}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin 'Amr narrated that the Messenger of Allah (s.a.w) said:"There shall be a Fitnah of extermination of the 'Arabs. Its fighters are in the Fire. During it, the tongue is stronger then the sword}}
\hadithdefcmd{tirmidhi}{2179}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَدِيثَيْنِ قَدْ رَأَيْتُ أَحَدَهُمَا وَأَنَا أَنْتَظِرُ الآخَرَ حَدَّثَنَا ‏"‏ أَنَّ الأَمَانَةَ نَزَلَتْ فِي جَذْرِ قُلُوبِ الرِّجَالِ ثُمَّ نَزَلَ الْقُرْآنُ فَعَلِمُوا مِنَ الْقُرْآنِ وَعَلِمُوا مِنَ السُّنَّةِ ‏"‏ ‏.‏ ثُمَّ حَدَّثَنَا عَنْ رَفْعِ الأَمَانَةِ فَقَالَ ‏"‏ يَنَامُ الرَّجُلُ النَّوْمَةَ فَتُقْبَضُ الأَمَانَةُ مِنْ قَلْبِهِ فَيَظَلُّ أَثَرُهَا مِثْلَ الْوَكْتِ ثُمَّ يَنَامُ نَوْمَةً فَتُقْبَضُ الأَمَانَةُ مِنْ قَلْبِهِ فَيَظَلُّ أَثَرُهَا مِثْلَ الْمَجْلِ كَجَمْرٍ دَحْرَجْتَهُ عَلَى رِجْلِكَ فَنَفِطَتْ فَتَرَاهُ مُنْتَبِرًا وَلَيْسَ فِيهِ شَيْءٌ ‏"‏ ‏.‏ ثُمَّ أَخَذَ حَصَاةً فَدَحْرَجَهَا عَلَى رِجْلِهِ قَالَ ‏"‏ فَيُصْبِحُ النَّاسُ يَتَبَايَعُونَ لاَ يَكَادُ أَحَدُهُمْ يُؤَدِّي الأَمَانَةَ حَتَّى يُقَالَ إِنَّ فِي بَنِي فُلاَنٍ رَجُلاً أَمِينًا وَحَتَّى يُقَالَ لِلرَّجُلِ مَا أَجْلَدَهُ وَأَظْرَفَهُ وَأَعْقَلَهُ وَمَا فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏ قَالَ وَلَقَدْ أَتَى عَلَىَّ زَمَانٌ وَمَا أُبَالِي أَيُّكُمْ بَايَعْتُ فِيهِ لَئِنْ كَانَ مُسْلِمًا لَيَرُدَّنَّهُ عَلَىَّ دِينُهُ وَلَئِنْ كَانَ يَهُودِيًّا أَوْ نَصْرَانِيًّا لَيَرُدَّنَّهُ عَلَىَّ سَاعِيهِ فَأَمَّا الْيَوْمَ فَمَا كُنْتُ لأُبَايِعَ مِنْكُمْ إِلاَّ فُلاَنًا وَفُلاَنًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2179}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Hudhaifah [bin Al-Yaman] said:"The Messenger of Allah \{s.a.w\} narrated two narrations to us, one of which I have seen \{happening\} and I am waiting for the other. He narrated that (in the beginning) trust was preserved in the roots of the hearts of men, then the Qur'an was revealed, and they learned it from the Qur'an, and then they learned it from the Sunnah. Then he narrated to us about the disappearance of trust, saying, 'A man will go to sleep whereupon trust will be taken away from his heart, and only its trace will remain, like speckles. He then will sleep, whereupon the remainder of the trust will also be taken away and trace will remain like a blister, like an ember that you roll on your feet, it causes pain and you see it swollen while it contains nothing.' Then he took a pebble and rolled it over his leg. He said: 'So there will come a day when people will deal in business with each other, but there will hardly be any trustworthy persons among them, such that it would be said that in such and such a tribe, there is such and such person, who is honest, and until a man will be admired for his strength, intelligence, and good manners, although indeed he will not have faith equal to a mustard seed in his heart."' He (Hudhaifah) added: "There came upon me a time when I did not mind dealing with anyone of you, for if he was a Muslim, his religion would prevent him from cheating me, and if was a Jew or a Christian, his Muslim ruler would prevent him from cheating me; but today I cannot deal except with so-and-so and so-and-so}}
\hadithdefcmd{tirmidhi}{2180}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سِنَانِ بْنِ أَبِي سِنَانٍ، عَنْ أَبِي وَاقِدٍ اللَّيْثِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا خَرَجَ إِلَى خَيْبَرَ مَرَّ بِشَجَرَةٍ لِلْمُشْرِكِينَ يُقَالُ لَهَا ذَاتُ أَنْوَاطٍ يُعَلِّقُونَ عَلَيْهَا أَسْلِحَتَهُمْ فَقَالُوا يَا رَسُولَ اللَّهِ اجْعَلْ لَنَا ذَاتَ أَنْوَاطٍ كَمَا لَهُمْ ذَاتُ أَنْوَاطٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ سُبْحَانَ اللَّهِ هَذَا كَمَا قَالَ قَوْمُ مُوسَى ‏:‏ ‏(‏اجْعَلْ لَنَا إِلَهًا كَمَا لَهُمْ آلِهَةٌ ‏)‏ وَالَّذِي نَفْسِي بِيَدِهِ لَتَرْكَبُنَّ سُنَّةَ مَنْ كَانَ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو وَاقِدٍ اللَّيْثِيُّ اسْمُهُ الْحَارِثُ بْنُ عَوْفٍ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{2180}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Waqid Al-Laithi narrated that when the Messenger of Allah (s.a.w) went out to Hunain he passed a tree that the idolaters called Dhat Anwat upon which they hung their weapons. They(the Companions) said:"O Messenger of Allah! Make a Dhat Anwat for us as they have a Dhat Anwat.' The Prophet (s.a.w) said: "Subhan Allah! This is like what Musa's people said: Make for us a god like their gods. By the One in Whose is my soul! You shall follow the way of those who were before you}}
\hadithdefcmd{tirmidhi}{2181}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنِ الْقَاسِمِ بْنِ الْفَضْلِ، حَدَّثَنَا أَبُو نَضْرَةَ الْعَبْدِيُّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَقُومُ السَّاعَةُ حَتَّى تُكَلِّمَ السِّبَاعُ الإِنْسَ وَحَتَّى تُكَلِّمَ الرَّجُلَ عَذَبَةُ سَوْطِهِ وَشِرَاكُ نَعْلِهِ وَتُخْبِرَهُ فَخِذُهُ بِمَا أَحْدَثَ أَهْلُهُ مِنْ بَعْدِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْقَاسِمِ بْنِ الْفَضْلِ ‏.‏ وَالْقَاسِمُ بْنُ الْفَضْلِ ثِقَةٌ مَأْمُونٌ عِنْدَ أَهْلِ الْحَدِيثِ وَثَّقَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ ‏.‏\hadithno{2181}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah (s.a.w) said:"By the One in Whose Hand is my soul! The Hour will not be established until predators speak to people and until the tip of a man's whip and the straps on his sandal speak to him, and his thigh informs him of what occurred with his family after him}}
\hadithdefcmd{tirmidhi}{2182}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ انْفَلَقَ الْقَمَرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْهَدُوا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَنَسٍ وَجُبَيْرِ بْنِ مُطْعِمٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2182}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Umar said:"The moon split during the time of the Messenger of Allah(s.a.w), so the Messenger of Allah(s.a.w) said: 'Bear witness}}
\hadithdefcmd{tirmidhi}{2183}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ فُرَاتٍ الْقَزَّازِ، عَنْ أَبِي الطُّفَيْلِ، عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ، قَالَ أَشْرَفَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ غُرْفَةٍ وَنَحْنُ نَتَذَاكَرُ السَّاعَةَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَرَوْا عَشْرَ آيَاتٍ طُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا وَيَأْجُوجُ وَمَأْجُوجُ وَالدَّابَّةُ وَثَلاَثَةُ خُسُوفٍ خَسْفٍ بِالْمَشْرِقِ وَخَسْفٍ بِالْمَغْرِبِ وَخَسْفٍ بِجَزِيرَةِ الْعَرَبِ وَنَارٌ تَخْرُجُ مِنْ قَعْرِ عَدَنَ تَسُوقُ النَّاسَ أَوْ تَحْشُرُ النَّاسَ فَتَبِيتُ مَعَهُمْ حَيْثُ بَاتُوا وَتَقِيلُ مَعَهُمْ حَيْثُ قَالُوا ‏"‏ ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ فُرَاتٍ، نَحْوَهُ وَزَادَ فِيهِ ‏"‏ الدُّخَانَ ‏"‏ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ فُرَاتٍ الْقَزَّازِ، نَحْوَ حَدِيثِ وَكِيعٍ عَنْ سُفْيَانَ، ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، عَنْ شُعْبَةَ، وَالْمَسْعُودِيِّ، سَمِعَا مِنْ، فُرَاتٍ الْقَزَّازِ نَحْوَ حَدِيثِ عَبْدِ الرَّحْمَنِ عَنْ سُفْيَانَ عَنْ فُرَاتٍ وَزَادَ فِيهِ ‏"‏ الدَّجَّالَ أَوِ الدُّخَانَ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا أَبُو النُّعْمَانِ الْحَكَمُ بْنُ عَبْدِ اللَّهِ الْعِجْلِيُّ، عَنْ شُعْبَةَ، عَنْ فُرَاتٍ، نَحْوَ حَدِيثِ أَبِي دَاوُدَ عَنْ شُعْبَةَ، وَزَادَ، فِيهِ قَالَ ‏"‏ وَالْعَاشِرَةُ إِمَّا رِيحٌ تَطْرَحُهُمْ فِي الْبَحْرِ وَإِمَّا نُزُولُ عِيسَى ابْنِ مَرْيَمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي هُرَيْرَةَ وَأُمِّ سَلَمَةَ وَصَفِيَّةَ بِنْتِ حُيَىٍّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2183}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Hudhaifah bin Asid said:"The Messenger of Allah (s.a.w) stood over us on a balcony, and we were discussing the Hour. So the Messenger of Allah(s.a.w) said: 'The Hour shall not be established until you see ten signs. The sun rising from its setting place, Ya'juj and Ma'juj, the beast of the earth, and three collapses of the earth: A collapse in the east, a collapse in the west and a collapse in the 'Arabian peninsula. And a fire that comes out of a place within 'Adan, driving the people, or gathering the people, camping where they camp, and resting where they rest}}
\hadithdefcmd{tirmidhi}{2184}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي إِدْرِيسَ الْمَرْهَبِيِّ، عَنْ مُسْلِمِ بْنِ صَفْوَانَ، عَنْ صَفِيَّةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَنْتَهِي النَّاسُ عَنْ غَزْوِ هَذَا الْبَيْتِ حَتَّى يَغْزُوَ جَيْشٌ حَتَّى إِذَا كَانُوا بِالْبَيْدَاءِ أَوْ بِبَيْدَاءَ مِنَ الأَرْضِ خُسِفَ بِأَوَّلِهِمْ وَآخِرِهِمْ وَلَمْ يَنْجُ أَوْسَطُهُمْ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ فَمَنْ كَرِهَ مِنْهُمْ قَالَ ‏"‏ يَبْعَثُهُمُ اللَّهُ عَلَى مَا فِي أَنْفُسِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2184}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Safiyyah narrated "The Messenger of Allah (s.a.w) said:'The people will not finish attacking this House until it is attacked by an army which, when they are at Al-Baida', or a Baida' in the land, it will swallow from the first of them to the last of them, and the middle of them shall not be saved.' I said: 'O Messenger of Allah(s.a.w)! What about those among them who are averse to it?' He said: 'Allah will resurrect them upon what was in their souls(intentions)}}
\hadithdefcmd{tirmidhi}{2185}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا صَيْفِيُّ بْنُ رِبْعِيٍّ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَكُونُ فِي آخِرِ هَذِهِ الأُمَّةِ خَسْفٌ وَمَسْخٌ وَقَذْفٌ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَنَهْلِكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ نَعَمْ إِذَا ظَهَرَ الْخَبَثُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ عَائِشَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَعَبْدُ اللَّهِ بْنُ عُمَرَ تَكَلَّمَ فِيهِ يَحْيَى بْنُ سَعِيدٍ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{2185}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated "The Messenger of Allah(s.a.w) said:'In the end of this Ummah there will be a collapse, transformation, and Qadhf."' She said :"I said: 'O Messenger of Allah! Will they be destroyed while they are righteous among them?' He said: 'Yes, when evil is dominant}}
\hadithdefcmd{tirmidhi}{2186}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ دَخَلْتُ الْمَسْجِدَ حِينَ غَابَتِ الشَّمْسُ وَالنَّبِيُّ صلى الله عليه وسلم جَالِسٌ فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ أَتَدْرِي أَيْنَ تَذْهَبُ هَذِهِ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ فَإِنَّهَا تَذْهَبُ تَسْتَأْذِنُ فِي السُّجُودِ فَيُؤْذَنُ لَهَا وَكَأَنَّهَا قَدْ قِيلَ لَهَا اطْلُعِي مِنْ حَيْثُ جِئْتِ فَتَطْلُعُ مِنْ مَغْرِبِهَا ‏"‏ ‏.‏ قَالَ ثُمَّ قَرَأَ ‏"‏ وَذَلِكَ مُسْتَقَرٌ لَهَا ‏"‏ ‏.‏ قَالَ وَذَلِكَ قِرَاءَةُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ صَفْوَانَ بْنِ عَسَّالٍ وَحُذَيْفَةَ بْنِ أَسِيدٍ وَأَنَسٍ وَأَبِي مُوسَى ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2186}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Dharr said:"I entered the Masjid at sunset, and the Prophet(s.a.w) was sitting. He said: 'O Abu Dharr! Do you know where this(sun) goes?' I said:'Allah and His Messenger know better.' He said: 'Indeed it goes to seek permission to prostrate, so it is permitted. And it is as if it has been said to it: "Rise from whence you came." So it shall rise from its setting place.' Then he recited: 'That is its fixed course."' He said: "That is the recitation of 'Abdulla bim Mas'ud}}
\hadithdefcmd{tirmidhi}{2187}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، وَأَبُو بَكْرِ بْنُ نَافِعٍ وَغَيْرُ وَاحِدٍ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ حَبِيبَةَ، عَنْ أُمِّ حَبِيبَةَ، عَنْ زَيْنَبَ بِنْتِ جَحْشٍ، قَالَتِ اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نَوْمٍ مُحْمَرًّا وَجْهُهُ وَهُوَ يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ يُرَدِّدُهَا ثَلاَثَ مَرَّاتٍ وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلُ هَذِهِ ‏"‏ وَعَقَدَ عَشْرًا ‏.‏ قَالَتْ زَيْنَبُ قُلْتُ يَا رَسُولَ اللَّهِ أَفَنُهْلَكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ نَعَمْ إِذَا كَثُرَ الْخَبَثُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ جَوَّدَ سُفْيَانُ هَذَا الْحَدِيثَ ‏.‏ هَكَذَا رَوَى الْحُمَيْدِيُّ وَعَلِيُّ بْنُ الْمَدِينِيِّ وَغَيْرُ وَاحِدٍ مِنَ الْحُفَّاظِ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ نَحْوَ هَذَا ‏.‏ وَقَالَ الْحُمَيْدِيُّ قَالَ سُفْيَانُ بْنُ عُيَيْنَةَ حَفِظْتُ مِنَ الزُّهْرِيِّ فِي هَذَا الْحَدِيثِ أَرْبَعَ نِسْوَةٍ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ عَنْ حَبِيبَةَ وَهُمَا رَبِيبَتَا النَّبِيِّ صلى الله عليه وسلم عَنْ أُمِّ حَبِيبَةَ عَنْ زَيْنَبَ بِنْتِ جَحْشٍ زَوْجَىِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى مَعْمَرٌ وَغَيْرُهُ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ وَلَمْ يَذْكُرُوا فِيهِ عَنْ حَبِيبَةَ وَقَدْ رَوَى بَعْضُ أَصْحَابِ ابْنِ عُيَيْنَةَ هَذَا الْحَدِيثَ عَنِ ابْنِ عُيَيْنَةَ وَلَمْ يَذْكُرُوا فِيهِ عَنْ أُمِّ حَبِيبَةَ ‏.‏\hadithno{2187}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Zainab bint Jahsh said:"One day the Messenger of Allah(s.a.w) awoke from sleep with a flushed red face, and said: 'La Ilahaillallah. He repeated it thrice. 'Woe to the Arabs from the evil drawn near. Today a gap has been made in the wall of Ya'juj and Ma'juj like this.' And he formed ten(with his fingers)." Zainab said: "I said: 'O Messenger of Allah! Shall we be destroyed while they are righteous among us?' He said: 'Yes, when the evil abounds}}
\hadithdefcmd{tirmidhi}{2188}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَخْرُجُ فِي آخِرِ الزَّمَانِ قَوْمٌ أَحْدَاثُ الأَسْنَانِ سُفَهَاءُ الأَحْلاَمِ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ يَقُولُونَ مِنْ قَوْلِ خَيْرِ الْبَرِيَّةِ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي سَعِيدٍ وَأَبِي ذَرٍّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ فِي غَيْرِ هَذَا الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم حَيْثُ وَصَفَ هَؤُلاَءِ الْقَوْمَ الَّذِينَ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ إِنَّمَا هُمُ الْخَوَارِجُ وَالْحَرُورِيَّةُ وَغَيْرُهُمْ مِنَ الْخَوَارِجِ ‏.‏\hadithno{2188}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah [bin Mas'ud] narrated that the Messenger of Allah (s.a.w) said:"In the end of time there will come a people young in years, foolish in minds, reciting the Qur'an which will not go beyond their throats, uttering sayings from the best of creatures, going through the religion as an arrow goes through the target}}
\hadithdefcmd{tirmidhi}{2189}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ قَالَ يَا رَسُولَ اللَّهِ اسْتَعْمَلْتَ فُلاَنًا وَلَمْ تَسْتَعْمِلْنِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ سَتَرَوْنَ بَعْدِي أَثَرَةً فَاصْبِرُوا حَتَّى تَلْقَوْنِي عَلَى الْحَوْضِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2189}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Usaid bin Hudair said:"A man from Ansar said, 'O Messenger of Allah! You appointed so-and-so and did not appoint me. So, the Prophet(s.a.w) said, 'After me you will see preferential treatment, so be patient till you meet me at Al-Hawd}}
\hadithdefcmd{tirmidhi}{2190}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّكُمْ سَتَرَوْنَ بَعْدِي أَثَرَةً وَأُمُورًا تُنْكِرُونَهَا ‏"‏ ‏.‏ قَالُوا فَمَا تَأْمُرُنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَدُّوا إِلَيْهِمْ حَقَّهُمْ وَسَلُوا اللَّهَ الَّذِي لَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2190}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah narrated that the Prophet(s.a.w) said:"Indeed, after me you will see preferential treatment, and matters that you dislike." They said: "Then what do you command us[O Messenger of Allah!]" He said: "Give them their rights, and ask Allah for yours}}
\hadithdefcmd{tirmidhi}{2191}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى الْقَزَّازُ الْبَصْرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ الْقُرَشِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا صَلاَةَ الْعَصْرِ بِنَهَارٍ ثُمَّ قَامَ خَطِيبًا فَلَمْ يَدَعْ شَيْئًا يَكُونُ إِلَى قِيَامِ السَّاعَةِ إِلاَّ أَخْبَرَنَا بِهِ حَفِظَهُ مَنْ حَفِظَهُ وَنَسِيَهُ مَنْ نَسِيَهُ وَكَانَ فِيمَا قَالَ ‏"‏ إِنَّ الدُّنْيَا حُلْوَةٌ خَضِرَةٌ وَإِنَّ اللَّهَ مُسْتَخْلِفُكُمْ فِيهَا فَنَاظِرٌ كَيْفَ تَعْمَلُونَ أَلاَ فَاتَّقُوا الدُّنْيَا وَاتَّقُوا النِّسَاءَ ‏"‏ ‏.‏ وَكَانَ فِيمَا قَالَ ‏"‏ أَلاَ لاَ يَمْنَعَنَّ رَجُلاً هَيْبَةُ النَّاسِ أَنْ يَقُولَ بِحَقٍّ إِذَا عَلِمَهُ ‏"‏ ‏.‏ قَالَ فَبَكَى أَبُو سَعِيدٍ فَقَالَ قَدْ وَاللَّهِ رَأَيْنَا أَشْيَاءَ فَهِبْنَا ‏.‏ وَكَانَ فِيمَا قَالَ ‏"‏ أَلاَ إِنَّهُ يُنْصَبُ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ بِقَدْرِ غَدْرَتِهِ وَلاَ غَدْرَةَ أَعْظَمَ مِنْ غَدْرَةِ إِمَامِ عَامَّةٍ يُرْكَزُ لِوَاؤُهُ عِنْدَ اسْتِهِ ‏"‏ ‏.‏ وَكَانَ فِيمَا حَفِظْنَا يَوْمَئِذٍ ‏"‏ أَلاَ إِنَّ بَنِي آدَمَ خُلِقُوا عَلَى طَبَقَاتٍ شَتَّى فَمِنْهُمْ مَنْ يُولَدُ مُؤْمِنًا وَيَحْيَا مُؤْمِنًا وَيَمُوتُ مُؤْمِنًا وَمِنْهُمْ مَنْ يُولَدُ كَافِرًا وَيَحْيَا كَافِرًا وَيَمُوتُ كَافِرًا وَمِنْهُمْ مَنْ يُولَدُ مُؤْمِنًا وَيَحْيَا مُؤْمِنًا وَيَمُوتُ كَافِرًا وَمِنْهُمْ مَنْ يُولَدُ كَافِرًا وَيَحْيَا كَافِرًا وَيَمُوتُ مُؤْمِنًا أَلاَ وَإِنَّ مِنْهُمُ الْبَطِيءَ الْغَضَبِ سَرِيعَ الْفَىْءِ وَمِنْهُمْ سَرِيعُ الْغَضَبِ سَرِيعُ الْفَىْءِ فَتِلْكَ بِتِلْكَ أَلاَ وَإِنَّ مِنْهُمْ سَرِيعَ الْغَضَبِ بَطِيءَ الْفَىْءِ أَلاَ وَخَيْرُهُمْ بَطِيءُ الْغَضَبِ سَرِيعُ الْفَىْءِ أَلاَ وَشَرُّهُمْ سَرِيعُ الْغَضَبِ بَطِيءُ الْفَىْءِ أَلاَ وَإِنَّ مِنْهُمْ حَسَنَ الْقَضَاءِ حَسَنَ الطَّلَبِ وَمِنْهُمْ سَيِّئُ الْقَضَاءِ حَسَنُ الطَّلَبِ وَمِنْهُمْ حَسَنُ الْقَضَاءِ سَيِّئُ الطَّلَبِ فَتِلْكَ بِتِلْكَ أَلاَ وَإِنَّ مِنْهُمُ السَّيِّئَ الْقَضَاءِ السَّيِّئَ الطَّلَبِ أَلاَ وَخَيْرُهُمُ الْحَسَنُ الْقَضَاءِ الْحَسَنُ الطَّلَبِ أَلاَ وَشَرُّهُمْ سَيِّئُ الْقَضَاءِ سَيِّئُ الطَّلَبِ أَلاَ وَإِنَّ الْغَضَبَ جَمْرَةٌ فِي قَلْبِ ابْنِ آدَمَ أَمَا رَأَيْتُمْ إِلَى حُمْرَةِ عَيْنَيْهِ وَانْتِفَاخِ أَوْدَاجِهِ فَمَنْ أَحَسَّ بِشَيْءٍ مِنْ ذَلِكَ فَلْيَلْصَقْ بِالأَرْضِ ‏"‏ ‏.‏ قَالَ وَجَعَلْنَا نَلْتَفِتُ إِلَى الشَّمْسِ هَلْ بَقِيَ مِنْهَا شَيْءٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ إِنَّهُ لَمْ يَبْقَ مِنَ الدُّنْيَا فِيمَا مَضَى مِنْهَا إِلاَّ كَمَا بَقِيَ مِنْ يَوْمِكُمْ هَذَا فِيمَا مَضَى مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ حُذَيْفَةَ وَأَبِي مَرْيَمَ وَأَبِي زَيْدِ بْنِ أَخْطَبَ وَالْمُغِيرَةِ بْنِ شُعْبَةَ وَذَكَرُوا أَنَّ النَّبِيَّ صلى الله عليه وسلم حَدَّثَهُمَ بِمَا هُوَ كَائِنٌ إِلَى أَنْ تَقُومَ السَّاعَةُ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2191}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri said:"One day, the Messenger of Allah(s.a.w) led us in Salat Al-Asr while it was still daytime. Then he stood to give us a Khutbah. He did not leave anything that would happen until the Hour of Judgement except that he informed us about it. Whoever remembered it remembered it, and whoever forgot it forgot it. Among what he said was: 'Indeed the world is green and sweet, and indeed Allah has left you to remain to see how you behave. So beware of the world, and beware of the women.' And among what he said was: 'The awe(status) of people should not prevent a man from saying the truth when he knows it."'He(one of the narrators) said: "Abu Sa'eed wept, then he said: 'By Allah! We have seen things and we feared."' "And among what he said in it, was : 'Indeed, for every treacherous person there shall be a banner erected on The Day Of Resurrection in proportion to his treachery. And there is no treachery greater than the treachery of a leader to the masses' whose banner shall be positioned at his buttocks.' And among what we remember from that day is: 'Behold! Indeed the children of Adam were created in various classes. Among them is he who was born a believer, lives as a believer, and dies a believer. Among them, is he who was born a disbeliever, lives as a disbeliever, and dies a disbeliever. Among them, is he who was born a believer, lives as a believer, and dies a disbeliever. Among them, is he who was born a disbeliever, lives as a disbeliever, and dies a believer. Behold! Among them is the slow to get angry, the quick to calm. Among them is the quick anger and the quick to calm, so this is with that. Behold! Among them is the quick get angry and the slow to calm, and indeed the best of them is the slow to get angry and the quick to calm, and the worst of them is the quick get angry and the slow to calm. Behold! Among them is he who pays back well and collects well. Among them is he who is bad with paying back and good when collecting. Among them is he who pays back well and is bad with collecting, so this is with that. Behold! Among them is he who is bad with paying back and bad with collecting. Indeed the best of them is the one who is good in paying back and good in collecting. And the worst of them is the one who is bad with paying back and bad with collecting. Behold! Anger is an ember in the heart of the son of Adam, as you see it in the redness of his eyes and the bulge of his jugular veins. So whoever senses something from that, then let him cling to the ground."' He said: "So we began turning towards the sun to see if anything of it remained(meaning whether it has set or not). So the Messenger of Allah(s.a.w) said: 'Behold! The world, in relation to what has passed of it, shall not remain except as what remains of this day of yours, in relation to what has passed of it}}
\hadithdefcmd{tirmidhi}{2192}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا فَسَدَ أَهْلُ الشَّامِ فَلاَ خَيْرَ فِيكُمْ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي مَنْصُورِينَ لاَ يَضُرُّهُمْ مَنْ خَذَلَهُمْ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ هُمْ أَصْحَابُ الْحَدِيثِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ حَوَالَةَ وَابْنِ عُمَرَ وَزَيْدِ بْنِ ثَابِتٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا بَهْزُ بْنُ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَيْنَ تَأْمُرُنِي قَالَ ‏"‏ هَا هُنَا ‏"‏ ‏.‏ وَنَحَا بِيَدِهِ نَحْوَ الشَّامِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2192}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu'awiyah bin Qurrah narrated from his father that the Messenger of Allah(s.a.w) said:"When the inhabitants of Ash-Sham become corrupt, then there is no good in it for you. There will never cease to be a group in my Ummah who will be helped(by Allah), they will not be harmed by those who forsake them until the Hour is established." Muhammad bin Isma'il said: "Ali bin Al-Madini said: 'They are the people of Hadith}}
\hadithdefcmd{tirmidhi}{2193}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا فُضَيْلُ بْنُ غَزْوَانَ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَجَرِيرٍ وَابْنِ عُمَرَ وَكُرْزِ بْنِ عَلْقَمَةَ وَوَاثِلَةَ بْنِ الأَسْقَعِ وَالصُّنَابِحِيِّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2193}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah(s.a.w) said:"Do not revert to disbelief after me, some of you striking the necks of others}}
\hadithdefcmd{tirmidhi}{2194}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ عَيَّاشِ بْنِ عَبَّاسٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ سَعْدَ بْنَ أَبِي وَقَّاصٍ، قَالَ عِنْدَ فِتْنَةِ عُثْمَانَ بْنِ عَفَّانَ أَشْهَدُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّهَا سَتَكُونُ فِتْنَةٌ الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ وَالْقَائِمُ خَيْرٌ مِنَ الْمَاشِي وَالْمَاشِي خَيْرٌ مِنَ السَّاعِي ‏"‏ ‏.‏ قَالَ أَفَرَأَيْتَ إِنْ دَخَلَ عَلَىَّ بَيْتِي وَبَسَطَ يَدَهُ إِلَىَّ لِيَقْتُلَنِي ‏.‏ قَالَ ‏"‏ كُنْ كَابْنِ آدَمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَخَبَّابِ بْنِ الأَرَتِّ وَأَبِي بَكْرَةَ وَابْنِ مَسْعُودٍ وَأَبِي وَاقِدٍ وَأَبِي مُوسَى وَخَرَشَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنِ اللَّيْثِ بْنِ سَعْدٍ وَزَادَ فِي الإِسْنَادِ رَجُلاً ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ سَعْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{2194}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Busr bin Sa'eed said:During the Fitnah(in the time) of 'Uthman bin 'Affan, Sa'd bin Abi Waqqas said: "I testify that the Messenger of Allah(s.a.w) said: 'There will be a Fitnah during which the sitting person is better than the standing(person) is better than the walking, and the walking(person) is better than the running."' He said: "What do you see(I should do) if he entered upon me in my homeand extended hos hand to kill me? He said: 'Be as Adam's son}}
\hadithdefcmd{tirmidhi}{2195}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَادِرُوا بِالأَعْمَالِ فِتَنًا كَقِطَعِ اللَّيْلِ الْمُظْلِمِ يُصْبِحُ الرَّجُلُ مُؤْمِنًا وَيُمْسِي كَافِرًا وَيُمْسِي مُؤْمِنًا وَيُصْبِحُ كَافِرًا يَبِيعُ أَحَدُهُمْ دِينَهُ بِعَرَضٍ مِنَ الدُّنْيَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2195}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"Rush to do good deeds. A Fitnah will occur that is like a portion of the dark night, morning will come upon a man as a believer, who will be a disbeliever in the evening, and evening will come upon a believer, who will be a disbeliever in the morning. One of them will sell his religion for goods of the world}}
\hadithdefcmd{tirmidhi}{2196}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ هِنْدِ بِنْتِ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَيْقَظَ لَيْلَةً فَقَالَ ‏ "‏ سُبْحَانَ اللَّهِ مَاذَا أُنْزِلَ اللَّيْلَةَ مِنَ الْفِتْنَةِ مَاذَا أُنْزِلَ مِنَ الْخَزَائِنِ مَنْ يُوقِظُ صَوَاحِبَ الْحُجُرَاتِ يَا رُبَّ كَاسِيَةٍ فِي الدُّنْيَا عَارِيَةٍ فِي الآخِرَةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2196}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Umm Salamah narrated:"One night the Prophet (ﷺ) awoke and said, 'Subhan Allah! How many Fitan (trials and afflictions) have descended tonight. And how many treasures have been disclosed? Who will awaken the women sleeping in these dwellings? O! How many are clothed in this world, yet naked in the Hereafter}}
\hadithdefcmd{tirmidhi}{2197}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَكُونُ بَيْنَ يَدَىِ السَّاعَةِ فِتَنٌ كَقِطَعِ اللَّيْلِ الْمُظْلِمِ يُصْبِحُ الرَّجُلُ فِيهَا مُؤْمِنًا وَيُمْسِي كَافِرًا وَيُمْسِي مُؤْمِنًا وَيُصْبِحُ كَافِرًا يَبِيعُ أَقْوَامٌ دِينَهُمْ بِعَرَضٍ مِنَ الدُّنْيَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَجُنْدَبٍ وَالنُّعْمَانِ بْنِ بَشِيرٍ وَأَبِي مُوسَى ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2197}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah(s.a.w) said:"Before the Hour there shall be Fitan like a portion of the dark night. Morning will come upon a man as a believer, who will be a disbeliever in the evening, and evening will come upon a believer, who will be a disbeliever in the morning, people will sell their religion for goods of the world}}
\hadithdefcmd{tirmidhi}{2198}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنِ الْحَسَنِ، قَالَ كَانَ يَقُولُ فِي هَذَا الْحَدِيثِ ‏ "‏ يُصْبِحُ الرَّجُلُ مُؤْمِنًا وَيُمْسِي كَافِرًا وَيُمْسِي مُؤْمِنًا وَيُصْبِحُ كَافِرًا ‏"‏ ‏.‏ قَالَ يُصْبِحُ الرَّجُلُ مُحَرِّمًا لِدَمِ أَخِيهِ وَعِرْضِهِ وَمَالِهِ وَيُمْسِي مُسْتَحِلاًّ لَهُ وَيُمْسِي مُحَرِّمًا لِدَمِ أَخِيهِ وَعِرْضِهِ وَمَالِهِ وَيُصْبِحُ مُسْتَحِلاًّ لَهُ ‏.‏\hadithno{2198}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Hisham narrated that Al-Hasan would say about the Hadith:" Morning will come upon a man as a believer, who will be a disbeliever in the evening, and evening will come upon a believer, who will be a disbeliever in the morning" - he said: "Morning would come[upon a man] while his brother's blood, honor and wealth was sacred, and when evening would come, he would consider it lawful for him. And evening would come while his brother's blood, honor and wealth was sacred, and when morning would come, he would consider it lawful for him}}
\hadithdefcmd{tirmidhi}{2199}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلِ بْنِ حُجْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَرَجُلٌ سَأَلَهُ فَقَالَ أَرَأَيْتَ إِنْ كَانَ عَلَيْنَا أُمَرَاءُ يَمْنَعُونَا حَقَّنَا وَيَسْأَلُونَا حَقَّهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْمَعُوا وَأَطِيعُوا فَإِنَّمَا عَلَيْهِمْ مَا حُمِّلُوا وَعَلَيْكُمْ مَا حُمِّلْتُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2199}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Alqamah bin Wa'il bin Hujr narrated from his father:"I heard the Messenger of Allah(s.a.w) while a man was asking him: 'What do you see that we should do if there are leaders over us who deny our rights, while they seek their rights?' So the Messenger of Allah(s.a.w) said: 'Listen and obey, for only they are responsible for their burdens, and only you are responsible for your burdens}}
\hadithdefcmd{tirmidhi}{2200}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ وَرَائِكُمْ أَيَّامًا يُرْفَعُ فِيهَا الْعِلْمُ وَيَكْثُرُ فِيهَا الْهَرْجُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا الْهَرْجُ قَالَ ‏"‏ الْقَتْلُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَخَالِدِ بْنِ الْوَلِيدِ وَمَعْقِلِ بْنِ يَسَارٍ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2200}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Musa narrated that the Messenger of Allah(s.a.w) said:"Indeed after you there will be days in which knowledge shall be raised up and Al-Harj shall abound." They said: "O Messenger of Allah(s.a.w)! What is Al-Harj?" He said: "Killing}}
\hadithdefcmd{tirmidhi}{2201}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ الْمُعَلَّى بْنِ زِيَادٍ، رَدَّهُ إِلَى مُعَاوِيَةَ بْنِ قُرَّةَ رَدَّهُ إِلَى مَعْقِلِ بْنِ يَسَارٍ رَدَّهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعِبَادَةُ فِي الْهَرْجِ كَالْهِجْرَةِ إِلَىَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ حَمَّادِ بْنِ زَيْدٍ عَنِ الْمُعَلَّى ‏.‏\hadithno{2201}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ma'qil bin Yasar narrated that the Prophet(s.a.w) said:"Worship during Al-Harj is like Hijrah to me}}
\hadithdefcmd{tirmidhi}{2202}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وُضِعَ السَّيْفُ فِي أُمَّتِي لَمْ يُرْفَعْ عَنْهَا إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2202}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Thawban narrated that the Messenger of Allah(s.a.w) said:"When the sword is imposed on my Ummah, it shall not be removed from it until the Day of Resurrection}}
\hadithdefcmd{tirmidhi}{2203}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدٍ، عَنْ عُدَيْسَةَ بِنْتِ أُهْبَانَ بْنِ صَيْفِيٍّ الْغِفَارِيِّ، قَالَتْ جَاءَ عَلِيُّ بْنُ أَبِي طَالِبٍ إِلَى أَبِي فَدَعَاهُ إِلَى الْخُرُوجِ مَعَهُ فَقَالَ لَهُ أَبِي إِنَّ خَلِيلِي وَابْنَ عَمِّكَ عَهِدَ إِلَىَّ إِذَا اخْتَلَفَ النَّاسُ أَنْ أَتَّخِذَ سَيْفًا مِنْ خَشَبٍ فَقَدِ اتَّخَذْتُهُ فَإِنْ شِئْتَ خَرَجْتُ بِهِ مَعَكَ ‏.‏ قَالَتْ فَتَرَكَهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ مُحَمَّدِ بْنِ مَسْلَمَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ عُبَيْدٍ ‏.‏\hadithno{2203}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Udaisah bint Uhban bin Safi Al-Ghifari said:"Ali bin Abi Talib came to my father to call him to go out(to fight) with him. My father said to him: 'Indeed my beloved, the son of your paternal uncle, made a covenant with me, that when the people differ, to take a sword of wood. So I have resigned it, if you wish I will take it out with you.' She said: 'So he left him}}
\hadithdefcmd{tirmidhi}{2204}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا سَهْلُ بْنُ حَمَّادٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ ثَرْوَانَ، عَنْ هُزَيْلِ بْنِ شُرَحْبِيلَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ فِي الْفِتْنَةِ ‏ "‏ كَسِّرُوا فِيهَا قِسِيَّكُمْ وَقَطِّعُوا فِيهَا أَوْتَارَكُمْ وَالْزَمُوا فِيهَا أَجْوَافَ بُيُوتِكُمْ وَكُونُوا كَابْنِ آدَمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ ثَرْوَانَ هُوَ أَبُو قَيْسٍ الأَوْدِيُّ ‏.‏\hadithno{2204}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Musa narrated that the Prophet(s.a.w) said, about the Fitnah:"Break your bows during it, cut their strings and stick to the depths of your homes, and be like Adam's son}}
\hadithdefcmd{tirmidhi}{2205}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ أُحَدِّثُكُمْ حَدِيثًا سَمِعْتُهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ يُحَدِّثُكُمْ أَحَدٌ بَعْدِي أَنَّهُ سَمِعَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ يُرْفَعَ الْعِلْمُ وَيَظْهَرَ الْجَهْلُ وَيَفْشُوَ الزِّنَا وَتُشْرَبَ الْخَمْرُ وَيَكْثُرَ النِّسَاءُ وَيَقِلَّ الرِّجَالُ حَتَّى يَكُونَ لِخَمْسِينَ امْرَأَةً قَيِّمٌ وَاحِدٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي مُوسَى وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2205}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik said:"I shall narrate a Hadith to you that I heard from the Messenger of Allah(s.a.w), which none after me shall narrate that he heard it from the Messenger of Allah(s.a.w)." [He said:] "The Messenger of Allah(s.a.w) said: 'Indeed, among the signs of the Hour are that knowledge shall be raised up, ignorance shall be rampant, Zina shall abound, Khamr shall be drunk, women shall increase and men shall decrease such that fifty women will be supported by one man}}
\hadithdefcmd{tirmidhi}{2206}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، قَالَ دَخَلْنَا عَلَى أَنَسِ بْنِ مَالِكٍ قَالَ فَشَكَوْنَا إِلَيْهِ مَا نَلْقَى مِنَ الْحَجَّاجِ فَقَالَ ‏ "‏ مَا مِنْ عَامٍ إِلاَّ الَّذِي بَعْدَهُ شَرٌّ مِنْهُ حَتَّى تَلْقَوْا رَبَّكُمْ ‏"‏ ‏.‏ سَمِعْتُ هَذَا مِنْ نَبِيِّكُمْ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2206}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Az-Zubair bin 'Adi said:"We entered upon Anas bin Malik. We complained to him about what we were experiencing from Al-Hajjaj. So he said: 'There will not be a year, except that the one that is after it will be more evil than it, until you meet your Lord. I heard this from your Prophet(s.a.w)}}
\hadithdefcmd{tirmidhi}{2207}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى لاَ يُقَالَ فِي الأَرْضِ اللَّهُ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، نَحْوَهُ وَلَمْ يَرْفَعْهُ وَهَذَا أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏\hadithno{2207}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated that the Messenger of Allah(s.a.w) said:"The Hour will not be established until 'Allah, Allah is not said on the earth}}
\hadithdefcmd{tirmidhi}{2208}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَقِيءُ الأَرْضُ أَفْلاَذَ كَبِدِهَا أَمْثَالَ الأُسْطُوَانِ مِنَ الذَّهَبِ وَالْفِضَّةِ قَالَ فَيَجِيءُ السَّارِقُ فَيَقُولُ فِي مِثْلِ هَذَا قُطِعَتْ يَدِي وَيَجِيءُ الْقَاتِلُ فَيَقُولُ فِي هَذَا قَتَلْتُ وَيَجِيءُ الْقَاطِعُ فَيَقُولُ فِي هَذَا قَطَعْتُ رَحِمِي ثُمَّ يَدَعُونَهُ فَلاَ يَأْخُذُونَ مِنْهُ شَيْئًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2208}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:" The earth will throw out pieces of its liver(in sides): liver; gold and silver will come out like columns." He said: "A thief will come and say: 'For this my hands were amputated?' A murderer will come and say: 'For this I killed?' One who severed ties of kinship will come and say: 'For this I severed the ties of kinship?' Then they will leave it without taking anything from it}}
\hadithdefcmd{tirmidhi}{2209}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، ح قَالَ وَحَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عَبْدِ اللَّهِ، وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الأَنْصَارِيُّ الأَشْهَلِيُّ عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَكُونَ أَسْعَدَ النَّاسِ بِالدُّنْيَا لُكَعُ ابْنُ لُكَعَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ عَمْرِو بْنِ أَبِي عَمْرٍو ‏.‏\hadithno{2209}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Hudhaifah bin Al-Yaman narrated that the Messenger of Allah(s.a.w) said:"The Hour will not be established until the happiest of people in the world is Luka' bin Luka}}
\hadithdefcmd{tirmidhi}{2210}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ التِّرْمِذِيُّ، حَدَّثَنَا الْفَرَجُ بْنُ فَضَالَةَ أَبُو فَضَالَةَ الشَّامِيُّ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَلِيٍّ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا فَعَلَتْ أُمَّتِي خَمْسَ عَشْرَةَ خَصْلَةً حَلَّ بِهَا الْبَلاَءُ ‏"‏ ‏.‏ فَقِيلَ وَمَا هُنَّ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِذَا كَانَ الْمَغْنَمُ دُوَلاً وَالأَمَانَةُ مَغْنَمًا وَالزَّكَاةُ مَغْرَمًا وَأَطَاعَ الرَّجُلُ زَوْجَتَهُ وَعَقَّ أُمَّهُ وَبَرَّ صَدِيقَهُ وَجَفَا أَبَاهُ وَارْتَفَعَتِ الأَصْوَاتُ فِي الْمَسَاجِدِ وَكَانَ زَعِيمُ الْقَوْمِ أَرْذَلَهُمْ وَأُكْرِمَ الرَّجُلُ مَخَافَةَ شَرِّهِ وَشُرِبَتِ الْخُمُورُ وَلُبِسَ الْحَرِيرُ وَاتُّخِذَتِ الْقَيْنَاتُ وَالْمَعَازِفُ وَلَعَنَ آخِرُ هَذِهِ الأُمَّةِ أَوَّلَهَا فَلْيَرْتَقِبُوا عِنْدَ ذَلِكَ رِيحًا حَمْرَاءَ أَوْ خَسْفًا وَمَسْخًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عَلِيِّ بْنِ أَبِي طَالِبٍ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلاَ نَعْلَمُ أَحَدًا رَوَاهُ عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ غَيْرَ الْفَرَجِ بْنِ فَضَالَةَ ‏.‏ وَالْفَرَجُ بْنُ فَضَالَةَ قَدْ تَكَلَّمَ فِيهِ بَعْضُ أَهْلِ الْحَدِيثِ وَضَعَّفَهُ مِنْ قِبَلِ حِفْظِهِ وَقَدْ رَوَاهُ عَنْهُ وَكِيعٌ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ ‏.‏\hadithno{2210}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Abi Talib narrated that the Messenger of Allah(s.a.w) said:"When my Ummah does fifteen things, the afflictions will occur in it." It was said: "What are they O Messenger of Allah?" He said: "When Al-Maghnam (the spoils of war) are distributed (preferentially), trust is usurped, Zakah is a fine, a man obeys his wife and disobeys his mother, he is kind to his friend and abandons his father, voices are raised in the Masajid, the leader of the people is the most despicable among them, the most honored man is the one whose evil the people are afraid of, intoxicants are drunk, silk is worn (by males), there is a fascination for singing slave-girls and music, and the end of this Ummah curses its beginning. When that occurs, anticipate a red wind, collapsing of the earth, and transformation}}
\hadithdefcmd{tirmidhi}{2211}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ الْوَاسِطِيُّ، عَنِ الْمُسْتَلِمِ بْنِ سَعِيدٍ، عَنْ رُمَيْحٍ الْجُذَامِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اتُّخِذَ الْفَىْءُ دُوَلاً وَالأَمَانَةُ مَغْنَمًا وَالزَّكَاةُ مَغْرَمًا وَتُعُلِّمَ لِغَيْرِ الدِّينِ وَأَطَاعَ الرَّجُلُ امْرَأَتَهُ وَعَقَّ أُمَّهُ وَأَدْنَى صَدِيقَهُ وَأَقْصَى أَبَاهُ وَظَهَرَتِ الأَصْوَاتُ فِي الْمَسَاجِدِ وَسَادَ الْقَبِيلَةَ فَاسِقُهُمْ وَكَانَ زَعِيمُ الْقَوْمِ أَرْذَلَهُمْ وَأُكْرِمَ الرَّجُلُ مَخَافَةَ شَرِّهِ وَظَهَرَتِ الْقَيْنَاتُ وَالْمَعَازِفُ وَشُرِبَتِ الْخُمُورُ وَلَعَنَ آخِرُ هَذِهِ الأُمَّةِ أَوَّلَهَا فَلْيَرْتَقِبُوا عِنْدَ ذَلِكَ رِيحًا حَمْرَاءَ وَزَلْزَلَةً وَخَسْفًا وَمَسْخًا وَقَذْفًا وَآيَاتٍ تَتَابَعُ كَنِظَامٍ بَالٍ قُطِعَ سِلْكُهُ فَتَتَابَعَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2211}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"When Al-Fai' is distributed(preferentially), trust is a spoil of war, Zakat is a fine, knowledge is sought for other than the(sake of the) religion, a man obeys his wife and disobeys his mother, he is close to his friend and far from his father, voices are raised in the Masajid, tribes are led by their wicked, the leader of the people is the most despicable among them, the most honored man is the one whose evil the people are afraid of, singing slave-girls and music spread, intoxicants are drunk, and the end of this Ummah curses its beginning- then anticipate a red wind, earthquake, collapsing of the earth, transformation, Qadhf, and the signs follow in succession like gems of a necklace whose string is cut and so they fall in succession}}
\hadithdefcmd{tirmidhi}{2212}{حَدَّثَنَا عَبَّادُ بْنُ يَعْقُوبَ الْكُوفِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْقُدُّوسِ، عَنِ الأَعْمَشِ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ فِي هَذِهِ الأُمَّةِ خَسْفٌ وَمَسْخٌ وَقَذْفٌ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْمُسْلِمِينَ يَا رَسُولَ اللَّهِ وَمَتَى ذَاكَ قَالَ ‏"‏ إِذَا ظَهَرَتِ الْقَيْنَاتُ وَالْمَعَازِفُ وَشُرِبَتِ الْخُمُورُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ الأَعْمَشِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَابِطٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَهَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2212}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Imran bin Husain narrated that the Messenger of Allah(s.a.w) said:"In this Ummah there shall be collapsing of the earth, transformation and Qadhf." A man among the Muslims said: "O Messenger of Allah! When is that?" He said: "When singing slave-girls, music, and drinking intoxicants spread}}
\hadithdefcmd{tirmidhi}{2213}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ هَيَّاجٍ الأَسَدِيُّ الْكُوفِيُّ، حَدَّثَنَا يَحْيَى بْنُ عَبْدِ الرَّحْمَنِ الأَرْحَبِيُّ، حَدَّثَنَا عُبَيْدَةُ بْنُ الأَسْوَدِ، عَنْ مُجَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنِ الْمُسْتَوْرِدِ بْنِ شَدَّادٍ الْفِهْرِيِّ، رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثْتُ فِي نَفَسِ السَّاعَةِ فَسَبَقْتُهَا كَمَا سَبَقَتْ هَذِهِ هَذِهِ ‏"‏ ‏.‏ لإِصْبُعَيْهِ السَّبَّابَةِ وَالْوُسْطَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ الْمُسْتَوْرِدِ بْنِ شَدَّادٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2213}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Mustawrid bin Shaddad Al-Fihri reported that the Messenger of Allah(s.a.w) said:"I was sent in advance of the Hour, so that I precede it like this precedes this." (Indicating) with his index and middle fingers}}
\hadithdefcmd{tirmidhi}{2214}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةَ كَهَاتَيْنِ ‏"‏ ‏.‏ وَأَشَارَ أَبُو دَاوُدَ بِالسَّبَّابَةِ وَالْوُسْطَى فَمَا فَضْلُ إِحْدَاهُمَا عَلَى الأُخْرَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2214}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas narrated that the Messenger of Allah(s.a.w) said:"The Hour and I were dispatched like these two" - and Abu Dawud(a narrator) indicated with his index and middle fingers- so, how much more(in length) is one then the other}}
\hadithdefcmd{tirmidhi}{2215}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، وَعَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ وَلاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَبُرَيْدَةَ وَأَبِي سَعِيدٍ وَعَمْرِو بْنِ تَغْلِبَ وَمُعَاوِيَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2215}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Prophet(s.a.w) said:"The Hour shall not be established until you fight a people whose sandals are made out of hair, and the Hour shall not be established until you fight a people whose faces will look like shields coated with leather}}
\hadithdefcmd{tirmidhi}{2216}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا هَلَكَ كِسْرَى فَلاَ كِسْرَى بَعْدَهُ وَإِذَا هَلَكَ قَيْصَرُ فَلاَ قَيْصَرَ بَعْدَهُ وَالَّذِي نَفْسِي بِيَدِهِ لَتُنْفَقَنَّ كُنُوزُهُمَا فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2216}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"When Kisra is ruined, there will be no Kisra after him, and when Caesar is ruined, there will be no Caesar after him. By the One in Whose Hand is my soul! You shall spend their treasures in Allah's cause}}
\hadithdefcmd{tirmidhi}{2217}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ الْبَغْدَادِيُّ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَتَخْرُجُ نَارٌ مِنْ حَضْرَمَوْتَ أَوْ مِنْ نَحْوِ حَضْرَمَوْتَ قَبْلَ يَوْمِ الْقِيَامَةِ تَحْشُرُ النَّاسَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ فَمَا تَأْمُرُنَا قَالَ ‏"‏ عَلَيْكُمْ بِالشَّامِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ وَأَنَسٍ وَأَبِي هُرَيْرَةَ وَأَبِي ذَرٍّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ مِنْ حَدِيثِ ابْنِ عُمَرَ ‏.‏\hadithno{2217}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Salim bin 'Abdullas [bin 'Umar] narrated from his father, that the Messenger of Allah(s.a.w) said:"A fire is coming from Hadramawt- before the Day of Judgement- to gather the people." They said: "O Messenger of Allah! What do you order us?" He said: "Stick to Ash-Sham}}
\hadithdefcmd{tirmidhi}{2218}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَنْبَعِثَ دَجَّالُونَ كَذَّابُونَ قَرِيبٌ مِنْ ثَلاَثِينَ كُلُّهُمْ يَزْعُمُ أَنَّهُ رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ جَابِرِ بْنِ سَمُرَةَ وَابْنِ عُمَرَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2218}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"The Hour shall not be established until nearly thirty imposters, Dajjal appear, each of them claiming that he is the Messenger of Allah}}
\hadithdefcmd{tirmidhi}{2219}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَلْحَقَ قَبَائِلُ مِنْ أُمَّتِي بِالْمُشْرِكِينَ وَحَتَّى يَعْبُدُوا الأَوْثَانَ وَإِنَّهُ سَيَكُونُ فِي أُمَّتِي ثَلاَثُونَ كَذَّابُونَ كُلُّهُمْ يَزْعُمُ أَنَّهُ نَبِيٌّ وَأَنَا خَاتَمُ النَّبِيِّينَ لاَ نَبِيَّ بَعْدِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2219}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Thawban narrated that the Messenger of Allah(s.a.w) said:"The Hour shall not be established until tribes of my Ummah unite with the idolaters, and until they worship idols. And indeed there shall be thirty imposters in my Ummah,each of them claiming that he is a Prophet. And I am the last of the Prophets, there is no Prophet after me}}
\hadithdefcmd{tirmidhi}{2220}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُصْمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِي ثَقِيفٍ كَذَّابٌ وَمُبِيرٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى يُقَالُ الْكَذَّابُ الْمُخْتَارُ بْنُ أَبِي عُبَيْدٍ وَالْمُبِيرُ الْحَجَّاجُ بْنُ يُوسُفَ ‏.‏ حَدَّثَنَا أَبُو دَاوُدَ سُلَيْمَانُ بْنُ سَلْمٍ الْبَلْخِيُّ أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ عَنْ هِشَامِ بْنِ حَسَّانَ قَالَ أَحْصَوْا مَا قَتَلَ الْحَجَّاجُ صَبْرًا فَبَلَغَ مِائَةَ أَلْفٍ وَعِشْرِينَ أَلْفَ قَتِيلٍ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ‏.‏ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ وَاقِدٍ، حَدَّثَنَا شَرِيكٌ، نَحْوَهُ بِهَذَا الإِسْنَادِ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شَرِيكٍ ‏.‏ وَشَرِيكٌ يَقُولُ عَبْدُ اللَّهِ بْنُ عُصْمٍ وَإِسْرَائِيلُ يَقُولُ عَبْدُ اللَّهِ بْنُ عَصْمَةَ ‏.‏\hadithno{2220}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah(s.a.w) said:"In Thaqif there will be a great liar and destroyer}}
\hadithdefcmd{tirmidhi}{2221}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنِ الأَعْمَشِ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ النَّاسِ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ يَأْتِي مِنْ بَعْدِهِمْ قَوْمٌ يَتَسَمَّنُونَ وَيُحِبُّونَ السِّمَنَ يُعْطُونَ الشَّهَادَةَ قَبْلَ أَنْ يُسْأَلُوهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى مُحَمَّدُ بْنُ فُضَيْلٍ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ عَنْ عَلِيِّ بْنِ مُدْرِكٍ عَنْ هِلاَلِ بْنِ يِسَافٍ وَرَوَى غَيْرُ وَاحِدٍ مِنَ الْحُفَّاظِ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ عَنْ هِلاَلِ بْنِ يِسَافٍ وَلَمْ يَذْكُرُوا فِيهِ عَلِيَّ بْنَ مُدْرِكٍ ‏.‏ قَالَ وَحَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، حَدَّثَنَا هِلاَلُ بْنُ يِسَافٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏ وَهَذَا أَصَحُّ عِنْدِي مِنْ حَدِيثِ مُحَمَّدِ بْنِ فُضَيْلٍ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2221}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Imran bin Husain narrated that the Messenger of Allah(s.a.w) said:"The best of people are my generation, then those who follow them. Then, after them a people will come who increase in fatness, loving fatness, giving testimony before they are asked for it}}
\hadithdefcmd{tirmidhi}{2222}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ أُمَّتِي الْقَرْنُ الَّذِي بُعِثْتُ فِيهِمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ قَالَ وَلاَ أَعْلَمُ ذَكَرَ الثَّالِثَ أَمْ لاَ ‏"‏ ثُمَّ يَنْشَأُ أَقْوَامٌ يَشْهَدُونَ وَلاَ يُسْتَشْهَدُونَ وَيَخُونُونَ وَلاَ يُؤْتَمَنُونَ وَيَفْشُو فِيهِمُ السِّمَنُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2222}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Imran bin Husain narrated that the Messenger of Allah (ﷺ) said:"The best of my Ummah is the generation among whom I was sent, then those who follow them." He(`Imran) said: I do not know if he mentioned the third or not. "Then there shall appear people who testify while their testimony was not sought, who are treacherous, not trusted, and fatness shall spread among them}}
\hadithdefcmd{tirmidhi}{2223}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَكُونُ مِنْ بَعْدِي اثْنَا عَشَرَ أَمِيرًا ‏"‏ ‏.‏ قَالَ ثُمَّ تَكَلَّمَ بِشَيْءٍ لَمْ أَفْهَمْهُ فَسَأَلْتُ الَّذِي يَلِينِي فَقَالَ قَالَ ‏"‏ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مُوسَى، عَنْ جَابِرِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ هَذَا الْحَدِيثِ وقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرِ بْنِ سَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ يُسْتَغْرَبُ مِنْ حَدِيثِ أَبِي بَكْرِ بْنِ أَبِي مُوسَى عَنْ جَابِرِ بْنِ سَمُرَةَ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{2223}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Simak bin Harb narrated from Jabir bin Samurah who said " The Messenger of Allah(s.a.w) said:'There will be twelve Amir after me."' He said: "Then he said something that I did not understand. So I asked the one who was next to me, who said that he(s.a.w) had said: 'All of them are from Quraish}}
\hadithdefcmd{tirmidhi}{2224}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا حُمَيْدُ بْنُ مِهْرَانَ، عَنْ سَعْدِ بْنِ أَوْسٍ، عَنْ زِيَادِ بْنِ كُسَيْبٍ الْعَدَوِيِّ، قَالَ كُنْتُ مَعَ أَبِي بَكْرَةَ تَحْتَ مِنْبَرِ ابْنِ عَامِرٍ وَهُوَ يَخْطُبُ وَعَلَيْهِ ثِيَابٌ رِقَاقٌ فَقَالَ أَبُو بِلاَلٍ انْظُرُوا إِلَى أَمِيرِنَا يَلْبَسُ ثِيَابَ الْفُسَّاقِ ‏.‏ فَقَالَ أَبُو بَكْرَةَ اسْكُتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَهَانَ سُلْطَانَ اللَّهِ فِي الأَرْضِ أَهَانَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2224}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ziyad bin Kusaib Al-'Adawi said:"I was with Abu Bakrah under the Minbar of Ibn 'Amir while he was giving a Khutbah wearing a fine garment. Abu Bilal said: 'Look at our Amir wearing clothes of wickedness!' So Abu Bakrah said: Be quiet! I heard the Messenger of Allah(s.a.w) saying: "Whoever insults Allah's Sultan on the earth, Allah disgraces him}}
\hadithdefcmd{tirmidhi}{2225}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ قِيلَ لِعُمَرَ بْنِ الْخَطَّابِ لَوِ اسْتَخْلَفْتَ قَالَ إِنْ أَسْتَخْلِفْ فَقَدِ اسْتَخْلَفَ أَبُو بَكْرٍ وَإِنْ لَمْ أَسْتَخْلِفْ لَمْ يَسْتَخْلِفْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْحَدِيثِ قِصَّةٌ طَوِيلَةٌ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{2225}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salim bin 'Abdullah narrated from his father who said:"It was said to 'Umar bin Al-Khattab: 'Perhaps you should endorse your successor.' He said: 'If I appoint a successor, then indeed Abu Bakr appointed a successor. And if I do not appoint a successor, the Messenger of Allah(s.a.w) did not appoint a successor}}
\hadithdefcmd{tirmidhi}{2226}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُرَيْجُ بْنُ النُّعْمَانِ، حَدَّثَنَا حَشْرَجُ بْنُ نُبَاتَةَ، عَنْ سَعِيدِ بْنِ جُمْهَانَ، قَالَ حَدَّثَنِي سَفِينَةُ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخِلاَفَةُ فِي أُمَّتِي ثَلاَثُونَ سَنَةً ثُمَّ مُلْكٌ بَعْدَ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ قَالَ لِي سَفِينَةُ أَمْسِكْ خِلاَفَةَ أَبِي بَكْرٍ وَخِلاَفَةَ عُمَرَ وَخِلاَفَةَ عُثْمَانَ ‏.‏ ثُمَّ قَالَ لِي أَمْسِكْ خِلاَفَةَ عَلِيٍّ ‏.‏ قَالَ فَوَجَدْنَاهَا ثَلاَثِينَ سَنَةً ‏.‏ قَالَ سَعِيدٌ فَقُلْتُ لَهُ إِنَّ بَنِي أُمَيَّةَ يَزْعُمُونَ أَنَّ الْخِلاَفَةَ فِيهِمْ ‏.‏ قَالَ كَذَبُوا بَنُو الزَّرْقَاءِ بَلْ هُمْ مُلُوكٌ مِنْ شَرِّ الْمُلُوكِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ قَالاَ لَمْ يَعْهَدِ النَّبِيُّ صلى الله عليه وسلم فِي الْخِلاَفَةِ شَيْئًا ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ قَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ سَعِيدِ بْنِ جُمْهَانَ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سَعِيدِ بْنِ جُمْهَانَ ‏.‏\hadithno{2226}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sa'eed bin Jumhan narrated:"Safinah narrated to me, he said: 'The Messenger of Allah(s.a.w) said: "Al-Khilafah will be in my Ummah for thirty years, then there will be monarchy after that."' Then Safinah said to me: 'Count the Khilafah of Abu Bakr,' then he said: 'Count the Khilafah of 'Umar and the Khilafah of 'Uthman.' Then he said to me: 'Count the Khilafah of 'Ali."' He said: "So we found that they add up to thirty years." Sa'eed said: "I said to him: 'Banu Umaiyyah claim that the Khilafah is among them.' He said: 'Banu Az-Zarqa' lie, rather they are a monarchy, among the worst of monarchies}}
\hadithdefcmd{tirmidhi}{2227}{حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ الْبَصْرِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبِ بْنِ الزُّبَيْرِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي الْهُذَيْلِ، يَقُولُ كَانَ نَاسٌ مِنْ رَبِيعَةَ عِنْدَ عَمْرِو بْنِ الْعَاصِي فَقَالَ رَجُلٌ مِنْ بَكْرِ بْنِ وَائِلٍ لَتَنْتَهِيَنَّ قُرَيْشٌ أَوْ لَيَجْعَلَنَّ اللَّهُ هَذَا الأَمْرَ فِي جُمْهُورٍ مِنَ الْعَرَبِ غَيْرِهِمْ ‏.‏ فَقَالَ عَمْرُو بْنُ الْعَاصِي كَذَبْتَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قُرَيْشٌ وُلاَةُ النَّاسِ فِي الْخَيْرِ وَالشَّرِّ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَابْنِ عُمَرَ وَجَابِرٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{2227}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Abi Al-Hudhail said:" There were some people from(the tribe of) Rabiah with 'Amr bin Al-'As, so a man from(the tribe of) Bakr bin Wa'il said: "Either the Quraish will stop, or Allah will place this matter among the masses of the Arabs other than them.' So 'Amr bin Al-'As said: 'You have lied, I heard the Messenger of Allah(s.a.w) saying: "The Quraish are the leaders of the people, in the good and the bad, until the Day of Judgement}}
\hadithdefcmd{tirmidhi}{2228}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ الْعَبْدِيُّ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ عُمَرَ بْنِ الْحَكَمِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَذْهَبُ اللَّيْلُ وَالنَّهَارُ حَتَّى يَمْلِكَ رَجُلٌ مِنَ الْمَوَالِي يُقَالُ لَهُ جَهْجَاهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2228}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"The night and the day shall not go away until a man called Jahjah among the Mawali reigns}}
\hadithdefcmd{tirmidhi}{2229}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا أَخَافُ عَلَى أُمَّتِي الأَئِمَّةَ الْمُضِلِّينَ ‏"‏ ‏.‏ قَالَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي عَلَى الْحَقِّ ظَاهِرِينَ لاَ يَضُرُّهُمْ مَنْ يَخْذُلُهُمْ حَتَّى يَأْتِيَ أَمْرُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ سَمِعْتُ عَلِيَّ بْنَ الْمَدِينِيِّ يَقُولُ وَذَكَرَ هَذَا الْحَدِيثَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي ظَاهِرِينَ عَلَى الْحَقِّ ‏"‏ ‏.‏ فَقَالَ عَلِيٌّ هُمْ أَهْلُ الْحَدِيثِ ‏.‏\hadithno{2229}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thawban narrated that the Messenger of Allah(s.a.w) said:"I only fear for my Ummah from the misguiding A'immah." He said that the Messenger of Allah(s.a.w) said: "There will never cease to be a group from my Ummah manifest upon the truth, they will not be harmed by those who forsake them until Allah's Decree comes}}
\hadithdefcmd{tirmidhi}{2230}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ الْكُوفِيُّ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَذْهَبُ الدُّنْيَا حَتَّى يَمْلِكَ الْعَرَبَ رَجُلٌ مِنْ أَهْلِ بَيْتِي يُوَاطِئُ اسْمُهُ اسْمِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي سَعِيدٍ وَأُمِّ سَلَمَةَ وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2230}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah narrated that the Messenger of Allah(s.a.w) said:"The world shall not pass away until a man from the people of my family rules the Arabs whose name agrees with my name}}
\hadithdefcmd{tirmidhi}{2231}{حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ بْنِ عَبْدِ الْجَبَّارِ الْعَطَّارُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَلِي رَجُلٌ مِنْ أَهْلِ بَيْتِي يُوَاطِئُ اسْمُهُ اسْمِي ‏"‏ ‏.‏ قَالَ عَاصِمٌ وَأَخْبَرَنَا أَبُو صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَوْ لَمْ يَبْقَ مِنَ الدُّنْيَا إِلاَّ يَوْمٌ لَطَوَّلَ اللَّهُ ذَلِكَ الْيَوْمَ حَتَّى يَلِيَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2231}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asim narrated from Zirr, from 'Abdullah, from the Prophet(s.a.w) who said:"A man is coming from the people of my family whose name agrees with my name." 'Asim said: "Abu Salih narrated to us from Abu Hurairah, who said: 'If there did not remain in the world but one day, then Allah would extend that day until he comes}}
\hadithdefcmd{tirmidhi}{2232}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ زَيْدًا الْعَمِّيَّ، قَالَ سَمِعْتُ أَبَا الصِّدِّيقِ النَّاجِيَّ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ خَشِينَا أَنْ يَكُونَ، بَعْدَ نَبِيِّنَا حَدَثٌ فَسَأَلْنَا نَبِيَّ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ فِي أُمَّتِي الْمَهْدِيَّ يَخْرُجُ يَعِيشُ خَمْسًا أَوْ سَبْعًا أَوْ تِسْعًا ‏"‏ ‏.‏ زَيْدٌ الشَّاكُّ ‏.‏ قَالَ قُلْنَا وَمَا ذَاكَ قَالَ ‏"‏ سِنِينَ ‏"‏ ‏.‏ قَالَ ‏"‏ فَيَجِيءُ إِلَيْهِ رَجُلٌ فَيَقُولُ يَا مَهْدِيُّ أَعْطِنِي أَعْطِنِي ‏"‏ ‏.‏ قَالَ ‏"‏ فَيَحْثِي لَهُ فِي ثَوْبِهِ مَا اسْتَطَاعَ أَنْ يَحْمِلَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَبُو الصِّدِّيقِ النَّاجِيُّ اسْمُهُ بَكْرُ بْنُ عَمْرٍو وَيُقَالُ بَكْرُ بْنُ قَيْسٍ ‏.‏\hadithno{2232}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Zaid bin Al-'Ammi said:"I heard Abu As-Siddiq An-Naji narrate a Hadith from Abu Sa'eed Al-Khudri who said: 'We feared events to occur after our Prophet, so we asked Allah's Prophet(s.a.w), and he said: "Indeed there will be a Mahdi who comes in my Ummah (ruling) living for five, or seven, or nine."- Zaid was the one in doubt- He said: "We said: What is that?" He said: "Years." He said: "A man will come to him and say: O Mahdi! 'Give to me, give to me! So he will fill in his garment whatever he is able to carry}}
\hadithdefcmd{tirmidhi}{2233}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَيُوشِكَنَّ أَنْ يَنْزِلَ فِيكُمُ ابْنُ مَرْيَمَ حَكَمًا مُقْسِطًا فَيَكْسِرَ الصَّلِيبَ وَيَقْتُلَ الْخِنْزِيرَ وَيَضَعَ الْجِزْيَةَ وَيَفِيضَ الْمَالُ حَتَّى لاَ يَقْبَلَهُ أَحَدٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2233}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Prophet(s.a.w) said:"By the One in Whose Hand is my soul! Ibn Mariam shall soon descend among you, judging justly. He shall break the cross, kill the pig, remove the Jizyah, and wealth will be so bountiful that there will be none to accept it}}
\hadithdefcmd{tirmidhi}{2234}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ سُرَاقَةَ، عَنْ أَبِي عُبَيْدَةَ بْنِ الْجَرَّاحِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّهُ لَمْ يَكُنْ نَبِيٌّ بَعْدَ نُوحٍ إِلاَّ قَدْ أَنْذَرَ الدَّجَّالَ قَوْمَهُ وَإِنِّي أُنْذِرُكُمُوهُ ‏"‏ ‏.‏ فَوَصَفَهُ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ لَعَلَّهُ سَيُدْرِكُهُ بَعْضُ مَنْ رَآنِي أَوْ سَمِعَ كَلاَمِي ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ فَكَيْفَ قُلُوبُنَا يَوْمَئِذٍ قَالَ ‏"‏ مِثْلُهَا يَعْنِي الْيَوْمَ أَوْ خَيْرٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ وَعَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ جُزَىٍّ وَعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي عُبَيْدَةَ بْنِ الْجَرَّاحِ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ خَالِدٍ الْحَذَّاءِ وَقَدْ رَوَاهُ شُعْبَةُ أَيْضًا عَنْ خَالِدٍ الْحَذَّاءِ ‏.‏ وَأَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ اسْمُهُ عَامِرُ بْنُ عَبْدِ اللَّهِ بْنِ الْجَرَّاحِ ‏.‏\hadithno{2234}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu 'Ubaidah bin Al-Jarrah said:"I heard the Messenger of Allah(s.a.w): 'There was never a Prophet after Nuh but that he warned his people about the Dajjal, and indeed I shall warn you of him.' Then the Messenger of Allah(s.a.w) described him for us, and he said: "Perhaps some of you who see me, or hear my words shall live to see him." They said: "O Messenger of Allah! How will our hearts be on that day?" He said: "The same – that is, as today – or better.” (Hasan)}}
\hadithdefcmd{tirmidhi}{2235}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ ذَكَرَ الدَّجَّالَ فَقَالَ ‏"‏ إِنِّي لأُنْذِرُكُمُوهُ وَمَا مِنْ نَبِيٍّ إِلاَّ وَقَدْ أَنْذَرَ قَوْمَهُ وَلَقَدْ أَنْذَرَهُ نُوحٌ قَوْمَهُ وَلَكِنِّي سَأَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ تَعْلَمُونَ أَنَّهُ أَعْوَرُ وَإِنَّ اللَّهَ لَيْسَ بِأَعْوَرَ ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي عُمَرُ بْنُ ثَابِتٍ الأَنْصَارِيُّ، أَنَّهُ أَخْبَرَهُ بَعْضُ، أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ يَوْمَئِذٍ لِلنَّاسِ وَهُوَ يُحَذِّرُهُمْ فِتْنَتَهُ ‏"‏ تَعْلَمُونَ أَنَّهُ لَنْ يَرَى أَحَدٌ مِنْكُمْ رَبَّهُ حَتَّى يَمُوتَ وَإِنَّهُ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ ك ف ر يَقْرَأُهُ مَنْ كَرِهَ عَمَلَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2235}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Az-Zuhri narrated from Salim from Ibn 'Umar who said:"The Messengers of Allah(s.a.w)stood among the people,he praised Allah as is due to Him, then he mentioned the Dajjal and he said: 'Indeed I warn you of him. There has not been a Prophet except that he warned his people, and Nuh indeed warned his people – but I am to say something about him that no Prophet has said to his people: You should know that he is one-eyed, and Allah is certainly not one-eyed.'” Az-Zuhri said: “ `Umar bin Thabit Al-Ansari informed me that some of the Companions of the Prophet(s.a.w) informed him, that one day, the Prophet(s.a.w) was cautioning them against Fitnah and he said: 'You must know that not one of you will ever see his Lord until he dies. And indeed, he(the Dajjal) has “Kafir” written between his eyes; everyone who is averse to his behavior shall read it.'” (Sahih)}}
\hadithdefcmd{tirmidhi}{2236}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تُقَاتِلُكُمُ الْيَهُودُ فَتُسَلَّطُونَ عَلَيْهِمْ حَتَّى يَقُولَ الْحَجَرُ يَا مُسْلِمُ هَذَا يَهُودِيٌّ وَرَائِي فَاقْتُلْهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2236}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah(s.a.w) said:"You shall fight the Jews. You will gain such control over them, that a rock will say: 'O Muslim! This Jew is behind me so kill him}}
\hadithdefcmd{tirmidhi}{2237}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَحْمَدُ بْنُ مَنِيعٍ، قَالاَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ أَبِي التَّيَّاحِ، عَنِ الْمُغِيرَةِ بْنِ سُبَيْعٍ، عَنْ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الدَّجَّالُ يَخْرُجُ مِنْ أَرْضٍ بِالْمَشْرِقِ يُقَالُ لَهَا خُرَاسَانُ يَتْبَعُهُ أَقْوَامٌ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ عَبْدُ اللَّهِ بْنُ شَوْذَبٍ وَغَيْرُ وَاحِدٍ عَنْ أَبِي التَّيَّاحِ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي التَّيَّاحِ ‏.‏\hadithno{2237}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Bakr As-Siddiq said:"The Messenger of Allah(s.a.w) narrated to us, saying: 'The Dajjal shall emerge from a land in the east called Khurasan. He is followed by a people whom appear as if their f aces are shields coated with leather}}
\hadithdefcmd{tirmidhi}{2238}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا الْحَكَمُ بْنُ الْمُبَارَكِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مَرْيَمَ، عَنِ الْوَلِيدِ بْنِ سُفْيَانَ، عَنْ يَزِيدَ بْنِ قُطَيْبٍ السَّكُونِيِّ، عَنْ أَبِي بَحْرِيَّةَ، صَاحِبِ مُعَاذٍ عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَلْحَمَةُ الْعُظْمَى وَفَتْحُ الْقُسْطَنْطِينِيَّةِ وَخُرُوجُ الدَّجَّالِ فِي سَبْعَةِ أَشْهُرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ الصَّعْبِ بْنِ جَثَّامَةَ وَعَبْدِ اللَّهِ بْنِ بُسْرٍ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي سَعِيدٍ الْخُدْرِيِّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2238}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Bahriyyah, a Companion of Mu'adh bin Jabal narrated that the Prophet(s.a.w) said:"The great Malhamah, the conquest of Constantinople, and the coming of the Dajjal occur in (the span of) seven months}}
\hadithdefcmd{tirmidhi}{2239}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ فَتْحُ الْقُسْطُنْطِينِيَّةِ مَعَ قِيَامِ السَّاعَةِ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَالْقُسْطَنْطِينِيَّةُ هِيَ مَدِينَةُ الرُّومِ تُفْتَحُ عِنْدَ خُرُوجِ الدَّجَّالِ وَالْقُسْطَنْطِينِيَّةُ قَدْ فُتِحَتْ فِي زَمَانِ بَعْضِ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2239}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik said:"Constantinople will be conquered with the coming of the Hour}}
\hadithdefcmd{tirmidhi}{2240}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، دَخَلَ حَدِيثُ أَحَدِهِمَا فِي حَدِيثِ الآخَرِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ عَنْ أَبِيهِ جُبَيْرِ بْنِ نُفَيْرٍ عَنِ النَّوَّاسِ بْنِ سَمْعَانَ الْكِلاَبِيِّ قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الدَّجَّالَ ذَاتَ غَدَاةٍ فَخَفَّضَ فِيهِ وَرَفَّعَ حَتَّى ظَنَنَّاهُ فِي طَائِفَةِ النَّخْلِ ‏.‏ قَالَ فَانْصَرَفْنَا مِنْ عِنْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ رَجَعْنَا إِلَيْهِ فَعَرَفَ ذَلِكَ فِينَا فَقَالَ ‏"‏ مَا شَأْنُكُمْ ‏"‏ ‏.‏ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ ذَكَرْتَ الدَّجَّالَ الْغَدَاةَ فَخَفَّضْتَ فِيهِ وَرَفَّعْتَ حَتَّى ظَنَنَّاهُ فِي طَائِفَةِ النَّخْلِ ‏.‏ قَالَ ‏"‏ غَيْرُ الدَّجَّالِ أَخْوَفُ لِي عَلَيْكُمْ إِنْ يَخْرُجْ وَأَنَا فِيكُمْ فَأَنَا حَجِيجُهُ دُونَكُمْ وَإِنْ يَخْرُجْ وَلَسْتُ فِيكُمْ فَامْرُؤٌ حَجِيجُ نَفْسِهِ وَاللَّهُ خَلِيفَتِي عَلَى كُلِّ مُسْلِمٍ إِنَّهُ شَابٌّ قَطَطٌ عَيْنُهُ قَائِمَةٌ شَبِيهٌ بِعَبْدِ الْعُزَّى بْنِ قَطَنٍ فَمَنْ رَآهُ مِنْكُمْ فَلْيَقْرَأْ فَوَاتِحَ سُورَةِ أَصْحَابِ الْكَهْفِ قَالَ يَخْرُجُ مَا بَيْنَ الشَّامِ وَالْعِرَاقِ فَعَاثَ يَمِينًا وَشِمَالاً يَا عِبَادَ اللَّهِ اثْبُتُوا ‏"‏ ‏.‏ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ وَمَا لُبْثُهُ فِي الأَرْضِ قَالَ ‏"‏ أَرْبَعِينَ يَوْمًا يَوْمٌ كَسَنَةٍ وَيَوْمٌ كَشَهْرٍ وَيَوْمٌ كَجُمُعَةٍ وَسَائِرُ أَيَّامِهُ كَأَيَّامِكُمْ ‏"‏ ‏.‏ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ أَرَأَيْتَ الْيَوْمَ الَّذِي كَالسَّنَةِ أَتَكْفِينَا فِيهِ صَلاَةُ يَوْمٍ قَالَ ‏"‏ لاَ وَلَكِنِ اقْدُرُوا لَهُ ‏"‏ ‏.‏ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ فَمَا سُرْعَتُهُ فِي الأَرْضِ قَالَ ‏"‏ كَالْغَيْثِ اسْتَدْبَرَتْهُ الرِّيحُ فَيَأْتِي الْقَوْمَ فَيَدْعُوهُمْ فَيُكَذِّبُونَهُ وَيَرُدُّونَ عَلَيْهِ قَوْلَهُ فَيَنْصَرِفُ عَنْهُمْ فَتَتْبَعُهُ أَمْوَالُهُمْ فَيُصْبِحُونَ لَيْسَ بِأَيْدِيهِمْ شَيْءٌ ثُمَّ يَأْتِي الْقَوْمَ فَيَدْعُوهُمْ فَيَسْتَجِيبُونَ لَهُ وَيُصَدِّقُونَهُ فَيَأْمُرُ السَّمَاءَ أَنْ تُمْطِرَ فَتُمْطِرَ وَيَأْمُرُ الأَرْضَ أَنْ تُنْبِتَ فَتُنْبِتَ فَتَرُوحُ عَلَيْهِمْ سَارِحَتُهُمْ كَأَطْوَلِ مَا كَانَتْ ذُرًى وَأَمَدِّهِ خَوَاصِرَ وَأَدَرِّهِ ضُرُوعًا قَالَ ثُمَّ يَأْتِي الْخَرِبَةَ فَيَقُولُ لَهَا أَخْرِجِي كُنُوزَكِ فَيَنْصَرِفُ مِنْهَا فَتَتْبَعُهُ كَيَعَاسِيبِ النَّحْلِ ثُمَّ يَدْعُو رَجُلاً شَابًّا مُمْتَلِئًا شَبَابًا فَيَضْرِبُهُ بِالسَّيْفِ فَيَقْطَعُهُ جِزْلَتَيْنِ ثُمَّ يَدْعُوهُ فَيُقْبِلُ يَتَهَلَّلُ وَجْهُهُ يَضْحَكُ فَبَيْنَمَا هُوَ كَذَلِكَ إِذْ هَبَطَ عِيسَى ابْنُ مَرْيَمَ عَلَيْهِ السَّلاَمُ بِشَرْقِيِّ دِمَشْقَ عِنْدَ الْمَنَارَةِ الْبَيْضَاءِ بَيْنَ مَهْرُودَتَيْنِ وَاضِعًا يَدَيْهِ عَلَى أَجْنِحَةِ مَلَكَيْنِ إِذَا طَأْطَأَ رَأْسَهُ قَطَرَ وَإِذَا رَفَعَهُ تَحَدَّرَ مِنْهُ جُمَانٌ كَاللُّؤْلُؤِ قَالَ وَلاَ يَجِدُ رِيحَ نَفَسِهِ يَعْنِي أَحَدٌ إِلاَّ مَاتَ وَرِيحُ نَفَسِهِ مُنْتَهَى بَصَرِهِ قَالَ فَيَطْلُبُهُ حَتَّى يُدْرِكَهُ بِبَابِ لُدٍّ فَيَقْتُلَهُ قَالَ فَيَلْبَثُ كَذَلِكَ مَا شَاءَ اللَّهُ ‏.‏ قَالَ ثُمَّ يُوحِي اللَّهُ إِلَيْهِ أَنْ حَرِّزْ عِبَادِي إِلَى الطُّورِ فَإِنِّي قَدْ أَنْزَلْتُ عِبَادًا لِي لاَ يَدَانِ لأَحَدٍ بِقِتَالِهِمْ ‏.‏ قَالَ وَيَبْعَثُ اللَّهُ يَأْجُوجَ وَمَأْجُوجَ وَهُمْ كَمَا قَالَ اللَّهُ‏:‏ ‏(‏ مِنْ كُلِّ حَدَبٍ يَنْسِلُونَ ‏)‏ ‏.‏ قَالَ فَيَمُرُّ أَوَّلُهُمْ بِبُحَيْرَةِ الطَّبَرِيَّةِ فَيَشْرَبُ مَا فِيهَا ثُمَّ يَمُرُّ بِهَا آخِرُهُمْ فَيَقُولُ لَقَدْ كَانَ بِهَذِهِ مَرَّةً مَاءٌ ثُمَّ يَسِيرُونَ حَتَّى يَنْتَهُوا إِلَى جَبَلِ بَيْتِ الْمَقْدِسِ فَيَقُولُونَ لَقَدْ قَتَلْنَا مَنْ فِي الأَرْضِ هَلُمَّ فَلْنَقْتُلْ مَنْ فِي السَّمَاءِ ‏.‏ فَيَرْمُونَ بِنُشَّابِهِمْ إِلَى السَّمَاءِ فَيَرُدُّ اللَّهُ عَلَيْهِمْ نُشَّابَهُمْ مُحْمَرًّا دَمًا وَيُحَاصَرُ عِيسَى ابْنُ مَرْيَمَ وَأَصْحَابُهُ حَتَّى يَكُونَ رَأْسُ الثَّوْرِ يَوْمَئِذٍ خَيْرًا لأَحَدِهِمْ مِنْ مِائَةِ دِينَارٍ لأَحَدِكُمُ الْيَوْمَ ‏.‏ قَالَ فَيَرْغَبُ عِيسَى ابْنُ مَرْيَمَ إِلَى اللَّهِ وَأَصْحَابُهُ قَالَ فَيُرْسِلُ اللَّهُ إِلَيْهِمُ النَّغَفَ فِي رِقَابِهِمْ فَيُصْبِحُونَ فَرْسَى مَوْتَى كَمَوْتِ نَفْسٍ وَاحِدَةٍ قَالَ وَيَهْبِطُ عِيسَى وَأَصْحَابُهُ فَلاَ يَجِدُ مَوْضِعَ شِبْرٍ إِلاَّ وَقَدْ مَلأَتْهُ زَهَمَتُهُمْ وَنَتَنُهُمْ وَدِمَاؤُهُمْ قَالَ فَيَرْغَب�� عِيسَى إِلَى اللَّهِ وَأَصْحَابُهُ قَالَ فَيُرْسِلُ اللَّهُ عَلَيْهِمْ طَيْرًا كَأَعْنَاقِ الْبُخْتِ قَالَ فَتَحْمِلُهُمْ فَتَطْرَحُهُمْ بِالْمَهْبِلِ وَيَسْتَوْقِدُ الْمُسْلِمُونَ مِنْ قِسِيِّهِمْ وَنُشَّابِهِمْ وَجِعَابِهِمْ سَبْعَ سِنِينَ قَالَ وَيُرْسِلُ اللَّهُ عَلَيْهِمْ مَطَرًا لاَ يَكُنُّ مِنْهُ بَيْتُ وَبَرٍ وَلاَ مَدَرٍ قَالَ فَيَغْسِلُ الأَرْضَ فَيَتْرُكُهَا كَالزَّلَفَةِ قَالَ ثُمَّ يُقَالُ لِلأَرْضِ أَخْرِجِي ثَمَرَتَكِ وَرُدِّي بَرَكَتَكِ ‏.‏ فَيَوْمَئِذٍ تَأْكُلُ الْعِصَابَةُ مِنَ الرُّمَّانَةِ وَيَسْتَظِلُّونَ بِقِحْفِهَا وَيُبَارَكُ فِي الرِّسْلِ حَتَّى إِنَّ الْفِئَامَ مِنَ النَّاسِ لَيَكْتَفُونَ بِاللَّقْحَةِ مِنَ الإِبِلِ وَإِنَّ الْقَبِيلَةَ لَيَكْتَفُونَ بِاللَّقْحَةِ مِنَ الْبَقَرِ وَإِنَّ الْفَخِذَ لَيَكْتَفُونَ بِاللَّقْحَةِ مِنَ الْغَنَمِ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ بَعَثَ اللَّهُ رِيحًا فَقَبَضَتْ رُوحَ كُلِّ مُؤْمِنٍ وَيَبْقَى سَائِرُ النَّاسِ يَتَهَارَجُونَ كَمَا تَتَهَارَجُ الْحُمُرُ فَعَلَيْهِمْ تَقُومُ السَّاعَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ ‏.‏\hadithno{2240}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from An-Nawwas bin Sam'an, who said:"The Messenger of Allah(s.a.w) mentioned the Dajjal one morning, he belittled him and mentioned his importance until we thought that he might be amidst a cluster of date-palms." He said: "We departed from the presence of the Messenger of Allah(s.a.w), then we returned to him, and he noticed that(concern) in us. So he said: 'What is wrong with you?'" We said: 'O Messenger of Allah! You mentioned the Dajjal this morning, belittling him, and mentioning his importance until we thought that he might be amidst a cluster of the date-palms.' He said: 'It is not the Dajjal that I fear for you. If he were to appear while I am among you, then I will be his adversary on your behalf. And if he appears and I am not among you, then each man will have to fend for himself. And Allah will take care of every Muslim after me. He is young, with curly hair, his eyes protruding, resembling someone from 'Abdul-Uzza bin Qatan. Whoever among you sees him, then let him recite the beginning of Surah Ashab Al-Kahf.'"He said: 'He will appear from what is between Ash-Sham and Al-'Iraq, causing devastation toward the right and toward the left. O worshippers of Allah! Hold fast!'" We said: 'O Messenger of Allah! How long will he linger on the earth?' He said: 'Forty days, a day like a year, a day like a month, a day like a week, and the remainder of his days are like your days.'" We said: 'O Messenger of Allah! Do you think that during the day that is like a year, the Salat of one day will be sufficient for us?' He said: 'No. You will have to estimate it.' We said: 'O Messenger of Allah! How fast will he move through the earth.' He said: 'Like a rain storm driven by the wind. He will come upon a people and call them, and they will deny him, and reject his claims. Then he will leave them, and their wealth will follow him. They will awaken in the morning with nothing left. Then he will come upon a people and call them, and they will respond to him, believing in him. So he will order the Heavens to bring rain, and it shall rain, and he will order the land to sprout, and it will sprout. Their cattle will return to them with their coats the longest, their udders the fullest and their stomachs the fattest.' He said: 'Then he will come upon some ruins, saying to it: "Bring me your treasures!" He will turn to leave it, and it will follow him, like drone bees. Then he will call a young man, full of youth, and he will strike him with the sword cutting him into two pieces. Then he will call him, and he will come forward with his face beaming and laughing. So while he is doing that, 'Eisa bin Mariam, peace be upon him, will descend in eastern Damascus at the white minaret, between two Mahrud, with his hands on the wings of two angels. When he lowers his head, drops fall, and when raises it, gems like pearls drop from him.' He said: 'His (the Dajjal's) breath does not reach anyone but he dies, and his breath reaches as far as his sight.' He said: 'So he pursues him(the Dajjal) and he catches up with him at the gate of Ludd where he kills him.' He said: 'So he remains there as long as Allah wills.' He said: 'Then Allah reveals to him: "Take my slaves to At-Tur, for I have sent down some creatures of Mine which no one shall be able to kill.'" He said: 'Allah dispatches Ya'juj and Ma'juj, and they are as Allah said: They swoop down from every mount.' "He said: 'The first of them pass by the lake of Tiberias, drinking what is in it. Then the last of them pass by it saying: "There was water here at one time." They travel until they reach a mountain at Bait Al-Maqdis. They will say: "We have killed whoever was in the earth. Come! Let us kill whoever is in the skies." They will shoot their arrows into the Heavens, so Allah will return their arrows to them red with blood. Eisa bin Mariam and his Companions be surrounded, until the head of a bull on that day would be better to them than a hundred Dinar to one of you today.' "He (s.a.w) said: "Eisa will beseech Allah, as will his companions.' He said: 'So Allah will send An-Naghaf down upon their necks. In the morning they will find that they have all died like the death of a single soul.' He said: " 'Eisa and his companions will come down, and no spot nor hand-span can be found, except that it is filled with their stench, decay and blood. So 'Eisa will beseech Allah, as will his companions.' So Allah will send upon them birds like the necks of Bukht(milch)camels.' They will carry them off and cast them into an abyss. The Muslims will burn their bows, arrows and quivers for seventy years.' "He(s.a.w) said: 'Allah will send upon them a rain which no house of hide nor mud will bear. The earth will be washed, leaving it like a mirror. Then it will be said to the earth: "bring forth your fruits and return your blessings." So on that day, a whole troop would eat a pomegranate and seek shade under its skin. Milk will be so blessed that a large group of people will be sufficed by one milking of a camel. And that a tribe will be sufficed by one milking of a cow, and that a group will be sufficed by the milking of sheep. While it is like that, Allah will send a wind which grabs the soul of every believer, leaving the remainder of the people copulating publicly like the copulation of donkeys. Upon them the Hour shall begin}}
\hadithdefcmd{tirmidhi}{2241}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ سُئِلَ عَنِ الدَّجَّالِ فَقَالَ ‏ "‏ أَلاَ إِنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ أَلاَ وَإِنَّهُ أَعْوَرُ عَيْنُهُ الْيُمْنَى كَأَنَّهَا عِنَبَةٌ طَافِيَةٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدٍ وَحُذَيْفَةَ وَأَبِي هُرَيْرَةَ وَأَسْمَاءَ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَأَبِي بَكْرَةَ وَعَائِشَةَ وَأَنَسٍ وَابْنِ عَبَّاسٍ وَالْفَلَتَانِ بْنِ عَاصِمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ عُمَرَ ‏.‏\hadithno{2241}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn 'Umar narrated that the Prophet(s.a.w) was asked about the Dajjal, so he said:"Lo! Indeed your Lord is not blind in one eye, and indeed he is blind in one eye; his right eye is as if it is a floating grape}}
\hadithdefcmd{tirmidhi}{2242}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ الْبَصْرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْتِي الدَّجَّالُ الْمَدِينَةَ فَيَجِدُ الْمَلاَئِكَةَ يَحْرُسُونَهَا فَلاَ يَدْخُلُهَا الطَّاعُونُ وَلاَ الدَّجَّالُ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَفَاطِمَةَ بِنْتِ قَيْسٍ وَأُسَامَةَ بْنِ زَيْدٍ وَسَمُرَةَ بْنِ جُنْدَبٍ وَمِحْجَنٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2242}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Anas narrated that the Messenger of Allah(s.a.w) said:"The Dajjal will come to Al-Madinah to find the angels have surrounded it. Neither the plague nor the Dajjal will enter it, if Allah wills}}
\hadithdefcmd{tirmidhi}{2243}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الإِيمَانُ يَمَانٍ وَالْكُفْرُ مِنْ قِبَلِ الْمَشْرِقِ وَالسَّكِينَةُ لأَهْلِ الْغَنَمِ وَالْفَخْرُ وَالرِّيَاءُ فِي الْفَدَّادِينَ أَهْلِ الْخَيْلِ وَأَهْلِ الْوَبَرِ يَأْتِي الْمَسِيحُ إِذَا جَاءَ دُبُرَ أُحُدٍ صَرَفَتِ الْمَلاَئِكَةُ وَجْهَهُ قِبَلَ الشَّامِ وَهُنَالِكَ يَهْلِكُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2243}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"Faith is Yemeni, and disbelief is from the direction of the east. Tranquility is for the people of sheep, and wickedness and Riya is in those who boast among the people of horses and the people of camels. Al-Masih – that is Ad-Dajjal- will come, and when he reaches behind Uhud, the angels will turn his face to the direction of Ash-Sham, and is there that he will be destroyed.” (Sahih)}}
\hadithdefcmd{tirmidhi}{2244}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ سَمِعَ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ ثَعْلَبَةَ الأَنْصَارِيَّ، يُحَدِّثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ الأَنْصَارِيِّ، مِنْ بَنِي عَمْرِو بْنِ عَوْفٍ يَقُولُ سَمِعْتُ عَمِّي، مُجَمِّعَ بْنَ جَارِيَةَ الأَنْصَارِيَّ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَقْتُلُ ابْنُ مَرْيَمَ الدَّجَّالَ بِبَابِ لُدٍّ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَنَافِعِ بْنِ عُتْبَةَ وَأَبِي بَرْزَةَ وَحُذَيْفَةَ بْنِ أَسِيدٍ وَأَبِي هُرَيْرَةَ وَكَيْسَانَ وَعُثْمَانَ بْنِ أَبِي الْعَاصِي وَجَابِرٍ وَأَبِي أُمَامَةَ وَابْنِ مَسْعُودٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَسَمُرَةَ بْنِ جُنْدَبٍ وَالنَّوَّاسِ بْنِ سَمْعَانَ وَعَمْرِو بْنِ عَوْفٍ وَحُذَيْفَةَ بْنِ الْيَمَانِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2244}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Mujammi' bin Jariyah Al-Ansari said:"I heard the Messenger of Allah(s.a.w) saying: 'Eisa bin Maryam will kill the Dajjal at the gate of Ludd}}
\hadithdefcmd{tirmidhi}{2245}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ نَبِيٍّ إِلاَّ وَقَدْ أَنْذَرَ أُمَّتَهُ الأَعْوَرَ الْكَذَّابَ أَلاَ إِنَّهُ أَعْوَرُ وَإِنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ ك ف ر ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2245}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah(s.a.w) said: 'There was no Prophet except that he warned his Ummah of the liar who is blind in one eye. Lo! He is blind in one eye, and your Lord is not blind in one eye. Written between his eyes is: Kafir}}
\hadithdefcmd{tirmidhi}{2246}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ صَحِبَنِي ابْنُ صَائِدٍ إِمَّا حُجَّاجًا وَإِمَّا مُعْتَمِرِينَ فَانْطَلَقَ النَّاسُ وَتُرِكْتُ أَنَا وَهُوَ فَلَمَّا خَلَصْتُ بِهِ اقْشَعْرَرْتُ مِنْهُ وَاسْتَوْحَشْتُ مِنْهُ مِمَّا يَقُولُ النَّاسُ فِيهِ فَلَمَّا نَزَلْتُ قُلْتُ لَهُ ضَعْ مَتَاعَكَ حَيْثُ تِلْكَ الشَّجَرَةِ ‏.‏ قَالَ فَأَبْصَرَ غَنَمًا فَأَخَذَ الْقَدَحَ فَانْطَلَقَ فَاسْتَحْلَبَ ثُمَّ أَتَانِي بِلَبَنٍ فَقَالَ لِي يَا أَبَا سَعِيدٍ اشْرَبْ ‏.‏ فَكَرِهْتُ أَنْ أَشْرَبَ مِنْ يَدِهِ شَيْئًا لِمَا يَقُولُ النَّاسُ فِيهِ فَقُلْتُ لَهُ هَذَا الْيَوْمُ يَوْمٌ صَائِفٌ وَإِنِّي أَكْرَهُ فِيهِ اللَّبَنَ ‏.‏ قَالَ لِي يَا أَبَا سَعِيدٍ هَمَمْتُ أَنْ آخُذَ حَبْلاً فَأُوثِقَهُ إِلَى شَجَرَةٍ ثُمَّ أَخْتَنِقُ لِمَا يَقُولُ النَّاسُ لِي وَفِيَّ أَرَأَيْتَ مَنْ خَفِيَ عَلَيْهِ حَدِيثِي فَلَنْ يَخْفَى عَلَيْكُمْ أَلَسْتُمْ أَعْلَمَ النَّاسِ بِحَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَا مَعْشَرَ الأَنْصَارِ أَلَمْ يَقُلْ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنَّهُ كَافِرٌ وَأَنَا مُسْلِمٌ أَلَمْ يَقُلْ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنَّهُ عَقِيمٌ لاَ يُولَدُ لَهُ وَقَدْ خَلَّفْتُ وَلَدِي بِالْمَدِينَةِ أَلَمْ يَقُلْ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَدْخُلُ أَوْ لاَ تَحِلُّ لَهُ مَكَّةُ وَالْمَدِينَةُ أَلَسْتُ مِنْ أَهْلِ الْمَدِينَةِ وَهُوَ ذَا أَنْطَلِقُ مَعَكَ إِلَى مَكَّةَ ‏.‏ فَوَاللَّهِ مَا زَالَ يَجِيءُ بِهَذَا حَتَّى قُلْتُ فَلَعَلَّهُ مَكْذُوبٌ عَلَيْهِ ثُمَّ قَالَ يَا أَبَا سَعِيدٍ وَاللَّهِ لأُخْبِرَنَّكَ خَبَرًا حَقًّا وَاللَّهِ إِنِّي لأَعْرِفُهُ وَأَعْرِفُ وَالِدَهُ وَأَعْرِفُ أَيْنَ هُوَ السَّاعَةَ مِنَ الأَرْضِ ‏.‏ فَقُلْتُ تَبًّا لَكَ سَائِرَ الْيَوْمِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏صَحِيحٌ\hadithno{2246}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed said:"I was accompanied by Ibn Sa'eed- either performing Hajj or 'Umrah - the people departed, and he and I were left. When I was alone with him I trembled and felt frightened of him because of what the people were saying about him. When I halted I said to him: 'Put your belongings near that tree.'" "he saw a sheep, took out a cup, and went to milk, it. Then he came to me with some milk and said to me: 'Drink Abu Sa'eed!' But I loathed drinking anything from his hand because of what the people were saying about him. So I said to him: 'It is very hot today, and I would not like to drink milk.' So he said to me: 'O Abu Sa'eed, I think I should take a rope, tie it to the tree, then hang myself because of what the people are saying about me. You see those who may be unaware of some narrations, while you are not unaware of them. You people are the most knowledgeable among the people of the Ahadith of the Messenger of Allah, O people of the Ansar! Did the Messenger of Allah not say: "He is a disbeliever" while I am a Muslim? Did the Messenger of Allah not said: "He is sterile, having no children" while I have left my children behind in Al-Madinah? Did the Messenger of Allah not say: "[He will not enter or] Makkah [and Al-Madinah] are not lawful for him" and am I not from the inhabitants of Al-Madinah, and who is the one who accompanied you to Makkah?'" "By Allah, he continued talking like this until I said: 'Perhaps he has been falsely accused' then he said: 'O Abu Sa'eed! By Allah, I can inform you of some information that is true, by Allah! Verily, I know him, I know his father, [and I know] where he is at this time in the land.' So I said: 'May the rest of your day be but grief}}
\hadithdefcmd{tirmidhi}{2247}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ لَقِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم ابْنَ صَائِدٍ فِي بَعْضِ طُرُقِ الْمَدِينَةِ فَاحْتَبَسَهُ وَهُوَ غُلاَمٌ يَهُودِيٌّ وَلَهُ ذُؤَابَةٌ وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَقَالَ أَتَشْهَدُ أَنْتَ أَنِّي رَسُولُ اللَّهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ آمَنْتُ بِاللَّهِ وَمَلاَئِكَتِهِ وَكُتُبِهِ وَرُسُلِهِ وَالْيَوْمِ الآخِرِ ‏"‏ ‏.‏ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا تَرَى ‏"‏ ‏.‏ قَالَ أَرَى عَرْشًا فَوْقَ الْمَاءِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَرَى عَرْشَ إِبْلِيسَ فَوْقَ الْبَحْرِ ‏.‏ قَالَ ‏"‏ فَمَا تَرَى ‏"‏ ‏.‏ قَالَ أَرَى صَادِقًا وَكَاذِبَيْنِ أَوْ صَادِقَيْنِ وَكَاذِبًا ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لُبِّسَ عَلَيْهِ ‏"‏ ‏.‏ فَدَعَاهُ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَحُسَيْنِ بْنِ عَلِيٍّ وَابْنِ عُمَرَ وَأَبِي ذَرٍّ وَابْنِ مَسْعُودٍ وَجَابِرٍ وَحَفْصَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2247}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah(s.a.w) met Ibn Sa'eed on one of the streets of Al-Madinah, so he stopped him- and he was a Jewish boy with locks- and Abu Bakr and 'Umar were with him. So the Messenger of Allah(s.a.w) said to him: 'Do you testify that I am the Messenger of Allah?' So he replied: 'Do you testify that I am Allah's Messenger?' So the Prophet(s.a.w) said: 'I believe in Allah, His Angels, His Books, His Messengers, and the Last Day.'Then the Prophet(s.a.w) said to him: 'What do you see?' He said: 'I see a throne above the water.' So the Prophet(s.a.w) said: 'He sees the throne of Iblis above the sea.' He said: 'What else do you see?' He said: 'I see a truthful one,and two liars- or two truthful ones and a liar.' So the Prophet (s.a.w)said:"He has been confounded. So leave him}}
\hadithdefcmd{tirmidhi}{2248}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَمْكُثُ أَبُو الدَّجَّالِ وَأُمُّهُ ثَلاَثِينَ عَامًا لاَ يُولَدُ لَهُمَا وَلَدٌ ثُمَّ يُولَدُ لَهُمَا غُلاَمٌ أَعْوَرُ أَضَرُّ شَيْءٍ وَأَقَلُّهُ مَنْفَعَةً تَنَامُ عَيْنَاهُ وَلاَ يَنَامُ قَلْبُهُ ‏"‏ ‏.‏ ثُمَّ نَعَتَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَوَيْهِ فَقَالَ ‏"‏ أَبُوهُ طِوَالٌ ضَرْبُ اللَّحْمِ كَأَنَّ أَنْفَهُ مِنْقَارٌ وَأُمُّهُ امْرَأَةٌ فَرْضَاخِيَّةٌ طَوِيلَةُ الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرَةَ فَسَمِعْنَا بِمَوْلُودٍ فِي الْيَهُودِ بِالْمَدِينَةِ فَذَهَبْتُ أَنَا وَالزُّبَيْرُ بْنُ الْعَوَّامِ حَتَّى دَخَلْنَا عَلَى أَبَوَيْهِ فَإِذَا نَعْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهِمَا فَقُلْنَا هَلْ لَكُمَا وَلَدٌ فَقَالاَ مَكَثْنَا ثَلاَثِينَ عَامًا لاَ يُولَدُ لَنَا وَلَدٌ ثُمَّ وُلِدَ لَنَا غُلاَمٌ أَعْوَرُ أَضَرُّ شَيْءٍ وَأَقَلُّهُ مَنْفَعَةً تَنَامُ عَيْنَاهُ وَلاَ يَنَامُ قَلْبُهُ ‏.‏ قَالَ فَخَرَجْنَا مِنْ عِنْدِهِمَا فَإِذَا هُوَ مُنْجَدِلٌ فِي الشَّمْسِ فِي قَطِيفَةٍ لَهُ وَلَهُ هَمْهَمَةٌ فَكَشَفَ عَنْ رَأْسِهِ فَقَالَ مَا قُلْتُمَا قُلْنَا وَهَلْ سَمِعْتَ مَا قُلْنَا قَالَ نَعَمْ تَنَامُ عَيْنَاىَ وَلاَ يَنَامُ قَلْبِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏\hadithno{2248}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdur-Rahman bin Abi Bakrah from his father who said:"The Messenger of Allah(s.a.w) said: 'The father of the Dajjal and hid mother, will abide for thirty years without bearing a son. Then a boy shall be born to them, having one eye in which there is some defect, providing little use. His eyes sleep but his heart does not sleep.' Then the Messenger of Allah(s.a.w) described his parents for us: 'His father is tall, with little fat, with a nose as if it were a beak. His mother is a bulky woman with long breasts.'" So Abu Bakrah said: "I heard about a child being born to some Jews in Al-Madinah. So Az-Zubair bin Al-'Awwam and I went until we entered upon his parents. They appeared as the Messenger of Allah(s.a.w) had described them. We said: 'Do you have any children?' They said: 'We remained for thirty years without any children being born to us, then we bore a boy, having one eye in which there is some defect, providing little use. His eyes sleep but his heart does not sleep.'" He said: "So we were leaving them, when he appeared, glittering in the sunlight in a velvet garment, murmuring something. He uncovered his head and said: 'What were you saying?' We said: 'Did you hear what we were saying?' He said: 'Yes, that my eyes sleep but my heart does not sleep}}
\hadithdefcmd{tirmidhi}{2249}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِابْنِ صَيَّادٍ فِي نَفَرٍ مِنْ أَصْحَابِهِ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ وَهُوَ يَلْعَبُ مَعَ الْغِلْمَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ وَهُوَ غُلاَمٌ فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ظَهْرَهُ بِيَدِهِ ثُمَّ قَالَ ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَنَظَرَ إِلَيْهِ ابْنُ صَيَّادٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ ‏.‏ ثُمَّ قَالَ ابْنُ صَيَّادٍ لِلنَّبِيِّ صلى الله عليه وسلم أَتَشْهَدُ أَنْتَ أَنِّي رَسُولُ اللَّهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ آمَنْتُ بِاللَّهِ وَبِرُسُلِهِ ‏"‏ ‏.‏ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا يَأْتِيكَ ‏"‏ ‏.‏ قَالَ ابْنُ صَيَّادٍ يَأْتِينِي صَادِقٌ وَكَاذِبٌ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خُلِّطَ عَلَيْكَ الأَمْرُ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي خَبَأْتُ لَكَ خَبِيئًا ‏"‏ ‏.‏ وَخَبَأَ لَهُ ‏:‏ ‏(‏يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ ‏)‏ فَقَالَ ابْنُ صَيَّادٍ هُوَ الدُّخُّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْسَأْ فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏ ‏.‏ قَالَ عُمَرُ يَا رَسُولَ اللَّهِ ائْذَنْ لِي فَأَضْرِبَ عُنُقَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ يَكُ حَقًّا فَلَنْ تُسَلَّطَ عَلَيْهِ وَإِنْ لاَ يَكُنْهُ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ يَعْنِي الدَّجَّالَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2249}\hadithgrade{Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar, that the Messenger of Allah(s.a.w) passed by Ibn Sayyad with a group of his Companions – among them `Umar bin Al-Khattab – while he was playing with two boys at the fort of Banu Maghalah, and he was a boy. He did not realize until the Messenger of Allah(s.a.w) struck him with his hand on his back, then he said:“Do you testify that I am the Messenger of Allah?” So Ibn Sayyad looked at him, and said: 'I testify that you are the Messenger to the illiterates.'” He said: “Then Ibn Sayyad said to the Prophet(s.a.w): 'Do you testify that I am the Messenger of Allah?' So the Prophet(s.a.w) said: 'I believe in Allah and His Messengers.' Then the Prophet(s.a.w) said: 'Who has come to you?' Ibn Sayyad said: 'A truthful one and a liar came to me.' So the Prophet(s.a.w) said: 'The matter has been confused for you.' Then the Messenger of Allah(s.a.w) said: 'I have concealed something from you.' And he had concealed (the verse): The day when the sky will bring forth a visible smoke. Ibn Sayyad said: 'It is, “Ad-Dukh.'” So the Messenger of Allah(s.a.w) said: 'Beat it! You can never surpass your ability.' `Umar said: 'O Messenger of Allah! Permit me to chop off his head!' The Messenger of Allah(s.a.w) said: 'If he is indeed him, then you will never overpower him, and if he is not, then there is no good in you killing him.'” (Sahih)}}
\hadithdefcmd{tirmidhi}{2250}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا عَلَى الأَرْضِ نَفْسٌ مَنْفُوسَةٌ - يَعْنِي الْيَوْمَ تَأْتِي عَلَيْهَا مِائَةُ سَنَةٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي سَعِيدٍ وَبُرَيْدَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2250}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir, that the Prophet(s.a.w) said:"There is no soul born upon the earth – meaning today – upon whom will come one hundred years." (Sahih)}}
\hadithdefcmd{tirmidhi}{2251}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، وَأَبِي، بَكْرِ بْنِ سُلَيْمَانَ وَهُوَ ابْنُ أَبِي حَثْمَةَ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ صَلاَةَ الْعِشَاءِ فِي آخِرِ حَيَاتِهِ فَلَمَّا سَلَّمَ قَالَ ‏"‏ أَرَأَيْتَكُمْ لَيْلَتَكُمْ هَذِهِ عَلَى رَأْسِ مِائَةِ سَنَةٍ مِنْهَا لاَ يَبْقَى مِمَّنْ هُوَ عَلَى ظَهْرِ الأَرْضِ أَحَدٌ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ فَوَهَلَ النَّاسُ فِي مَقَالَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم تِلْكَ فِيمَا يَتَحَدَّثُونَهُ مِنْ هَذِهِ الأَحَادِيثِ عَنْ مِائَةِ سَنَةٍ وَإِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَبْقَى مِمَّنْ هُوَ الْيَوْمَ عَلَى ظَهْرِ الأَرْضِ أَحَدٌ ‏"‏ ‏.‏ يُرِيدُ بِذَلِكَ أَنْ يَنْخَرِمَ ذَلِكَ الْقَرْنُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2251}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar, that he said:"The Messenger of Allah(s.a.w) led us in Salat one night for Salat Al-'Isha' during the end of his life. When he said the Taslim he stood and said: 'Do you see this night of yours, upon the head of one hundred years from it there shall not remain anyone who is upon the surface of the earth today.' Ibn 'Umar said: 'So, people misunderstood the saying of the Messenger of Allah(s.a.w), in what they say based on these Ahadith about one hundred years. The Messenger of Allah(s.a.w) only said: 'There shall not remain anyone who is upon the surface today.' Meaning, that generation would end}}
\hadithdefcmd{tirmidhi}{2252}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبِ بْنِ الشَّهِيدِ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ ذَرٍّ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا الرِّيحَ فَإِذَا رَأَيْتُمْ مَا تَكْرَهُونَ فَقُولُوا اللَّهُمَّ إِنَّا نَسْأَلُكَ مِنْ خَيْرِ هَذِهِ الرِّيحِ وَخَيْرِ مَا فِيهَا وَخَيْرِ مَا أُمِرَتْ بِهِ وَنَعُوذُ بِكَ مِنْ شَرِّ هَذِهِ الرِّيحِ وَشَرِّ مَا فِيهَا وَشَرِّ مَا أُمِرَتْ بِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي هُرَيْرَةَ وَعُثْمَانَ بْنِ أَبِي الْعَاصِي وَأَنَسٍ وَابْنِ عَبَّاسٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2252}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ubayy bin Ka'b that the Messenger of Allah(s.a.w) said:"Do not curse the wind. When you see what you dislike, then say: 'Allahumma inna nas-aluka min khairi hadhihir-rih, wa khairi ma fiha wa khairi ma umirat bihi wa na'udhu bika min sharri hadhihir-rih wa sharri ma fiha wa sharri ma umirat bihi' ('O Allah! Indeed we ask you of the good of this wind, and the good of what is in it, and the good of what it has been commanded. And we seek refuge in You from the evil of this wind, and the evil of what is in it, and the evil of what it has been commanded)}}
\hadithdefcmd{tirmidhi}{2253}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم صَعِدَ الْمِنْبَرَ فَضَحِكَ فَقَالَ ‏ "‏ إِنَّ تَمِيمًا الدَّارِيَّ حَدَّثَنِي بِحَدِيثٍ فَفَرِحْتُ فَأَحْبَبْتُ أَنْ أُحَدِّثَكُمْ حَدَّثَنِي أَنَّ نَاسًا مِنْ أَهْلِ فِلَسْطِينَ رَكِبُوا سَفِينَةً فِي الْبَحْرِ فَجَالَتْ بِهِمْ حَتَّى قَذَفَتْهُمْ فِي جَزِيرَةٍ مِنْ جَزَائِرِ الْبَحْرِ فَإِذَا هُمْ بِدَابَّةٍ لَبَّاسَةٍ نَاشِرَةٍ شَعْرَهَا فَقَالُوا مَا أَنْتِ قَالَتْ أَنَا الْجَسَّاسَةُ ‏.‏ قَالُوا فَأَخْبِرِينَا ‏.‏ قَالَتْ لاَ أُخْبِرُكُمْ وَلاَ أَسْتَخْبِرُكُمْ وَلَكِنِ ائْتُوا أَقْصَى الْقَرْيَةِ فَإِنَّ ثَمَّ مَنْ يُخْبِرُكُمْ وَيَسْتَخْبِرُكُمْ ‏.‏ فَأَتَيْنَا أَقْصَى الْقَرْيَةِ فَإِذَا رَجُلٌ مُوثَقٌ بِسِلْسِلَةٍ فَقَالَ أَخْبِرُونِي عَنْ عَيْنِ زُغَرَ ‏.‏ قُلْنَا مَلأَى تَدْفُقُ ‏.‏ قَالَ أَخْبِرُونِي عَنِ الْبُحَيْرَةِ قُلْنَا مَلأَى تَدْفُقُ ‏.‏ قَالَ أَخْبِرُونِي عَنْ نَخْلِ بَيْسَانَ الَّذِي بَيْنَ الأُرْدُنِّ وَفِلَسْطِينَ هَلْ أَطْعَمَ قُلْنَا نَعَمْ ‏.‏ قَالَ أَخْبِرُونِي عَنِ النَّبِيِّ هَلْ بُعِثَ قُلْنَا نَعَمْ ‏.‏ قَالَ أَخْبِرُونِي كَيْفَ النَّاسُ إِلَيْهِ قُلْنَا سِرَاعٌ ‏.‏ قَالَ فَنَزَّ نَزْوَةً حَتَّى كَادَ ‏.‏ قُلْنَا فَمَا أَنْتَ قَالَ إِنَّهُ الدَّجَّالُ وَإِنَّهُ يَدْخُلُ الأَمْصَارَ كُلَّهَا إِلاَّ طَيْبَةَ ‏.‏ وَطَيْبَةُ الْمَدِينَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ قَتَادَةَ عَنِ الشَّعْبِيِّ وَقَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنِ الشَّعْبِيِّ عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ ‏.‏\hadithno{2253}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Fatimah bint Qais narrated that Allah's Prophet(s.a.w) ascended the Minbar, he laughed, and said:"Verily, Tamim Ad-Dari narrated a story to me, and it made me happy, so I wanted to narrate it to you[what he narrated to me]. Some people among the inhabitants of Palestine traveled by boat in the sea, taking them here and there, until it cast them on an island among the islands at sea. There they found a beast, clothed with its hair flowing out. They said: 'What are you?' It said: 'I am Al-Jassasah.' They said: 'Give us some news.' It said: 'I shall not give you any news, nor do I want any of your news. But go to the furthest village, for there is someone who will give you news and seek your news.' So we went to the furthest village, and there was a man fettered with chains. He said: 'Inform me about the spring of Zughar.' We said: '	It is full and flowing.' He said: 'Inform me about Al-Buhairah.' We said,'It is full and flowing.' He said: 'Inform me about the date groves of Baysan which is between Jordan and Palestine, do they produce food?' We said: 'Yes.' He said: 'Inform me about the Prophet, has he been sent?' We said: 'Yes.' He said: 'Inform me how the people came to him.' We said: 'Quickly.' He leaped up to try and escape.' We said: 'What are you?' He said: 'I am the Dajjal.'" (The Prophet(s.a.w) said) "He will enter all of the lands except At-Taibah, and At-Taibah is Al-Madinah}}
\hadithdefcmd{tirmidhi}{2254}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنِ الْحَسَنِ، عَنْ جُنْدُبٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَنْبَغِي لِلْمُؤْمِنِ أَنْ يُذِلَّ نَفْسَهُ ‏"‏ ‏.‏ قَالُوا وَكَيْفَ يُذِلُّ نَفْسَهُ ‏.‏ قَالَ ‏"‏ يَتَعَرَّضُ مِنَ الْبَلاَءِ لِمَا لاَ يُطِيقُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2254}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hudhaifah, that the Messenger of Allah(s.a.w) said:"It is not for the believer to humiliate himself." They said: "How does he humiliate himself?" He said: "By taking on a trial which he can not bear}}
\hadithdefcmd{tirmidhi}{2255}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُكْتِبُ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ انْصُرْ أَخَاكَ ظَالِمًا أَوْ مَظْلُومًا ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ نَصَرْتُهُ مَظْلُومًا فَكَيْفَ أَنْصُرُهُ ظَالِمًا قَالَ ‏"‏ تَكُفُّهُ عَنِ الظُّلْمِ فَذَاكَ نَصْرُكَ إِيَّاهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2255}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik, that the Prophet(s.a.w) said:"Help your brother whether he is an oppressor or oppressed." It was said: "O Messenger of Allah! I help him when he is oppressed. But how can I help him when he oppresses?" He said: "Prevent him from oppression, that is your help for him}}
\hadithdefcmd{tirmidhi}{2256}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي مُوسَى، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ سَكَنَ الْبَادِيَةَ جَفَا وَمَنِ اتَّبَعَ الصَّيْدَ غَفَلَ وَمَنْ أَتَى أَبْوَابَ السَّلاَطِينِ افْتُتِنَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عَبَّاسٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الثَّوْرِيِّ ‏.‏\hadithno{2256}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas, that the Prophet(s.a.w) said:"Whoever resides in the deserts, he becomes ignorant, whoever follows game, he becomes heedless, and whoever comes to the door of the Sultan, he will suffer a Fitnah}}
\hadithdefcmd{tirmidhi}{2257}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّكُمْ مَنْصُورُونَ وَمُصِيبُونَ وَمَفْتُوحٌ لَكُمْ فَمَنْ أَدْرَكَ ذَلِكَ مِنْكُمْ فَلْيَتَّقِ اللَّهَ وَلْيَأْمُرْ بِالْمَعْرُوفِ وَلْيَنْهَ عَنِ الْمُنْكَرِ وَمَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2257}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdur-Rahman bin 'Abdullah bin Mas'ud narrated from his father, that he heard the Messenger of Allah(s.a.w) said:"Indeed you shall be aided, capturing, and victorious; so whoever among you sees that, then let him have Taqwa of Allah, and let him command the good and forbid the evil, and whoever lies about me on purpose, then let him take his seat in the Fire}}
\hadithdefcmd{tirmidhi}{2258}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، وَحَمَّادٍ، وَعَاصِمِ بْنِ بَهْدَلَةَ، سَمِعُوا أَبَا وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ عُمَرُ أَيُّكُمْ يَحْفَظُ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْفِتْنَةِ فَقَالَ حُذَيْفَةُ أَنَا ‏.‏ قَالَ حُذَيْفَةُ فِتْنَةُ الرَّجُلِ فِي أَهْلِهِ وَمَالِهِ وَوَلَدِهِ وَجَارِهِ يُكَفِّرُهَا الصَّلاَةُ وَالصَّوْمُ وَالصَّدَقَةُ وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏.‏ فَقَالَ عُمَرُ لَسْتُ عَنْ هَذَا أَسْأَلُكَ وَلَكِنْ عَنِ الْفِتْنَةِ الَّتِي تَمُوجُ كَمَوْجِ الْبَحْرِ قَالَ يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّ بَيْنَكَ وَبَيْنَهَا بَابًا مُغْلَقًا ‏.‏ قَالَ عُمَرُ أَيُفْتَحُ أَمْ يُكْسَرُ قَالَ بَلْ يُكْسَرُ ‏.‏ قَالَ إِذًا لاَ يُغْلَقُ إِلَى يَوْمِ الْقِيَامَةِ ‏.‏ قَالَ أَبُو وَائِلٍ فِي حَدِيثِ حَمَّادٍ فَقُلْتُ لِمَسْرُوقٍ سَلْ حُذَيْفَةَ عَنِ الْبَابِ فَسَأَلَهُ فَقَالَ عُمَرُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2258}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Wa'il narrated from Hudhaifah that 'Umar said:"Which of you remembers what the Messenger of Allah(s.a.w) said about the Fitnah?" So Hudhaifah said: "I do." Hudhaifah said: "A man's Fitnah is in his family, his wealth, his children, and his neighbors. It is atoned for by the Salat, fasting, charity, and by commanding good and forbidding evil." 'Umar said: "I am not asking you about this. Rather, about the Fitnah that spreads like the waves of the sea." He said: "O Commander of the Believers! Between you and it is a closed door." 'Umar said: "Will it be opened or broken?" He said: "It will be broken." He said: "Then it will never be closed until the Day of Judgement}}
\hadithdefcmd{tirmidhi}{2259}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الْوَهَّابِ، عَنْ مِسْعَرٍ، عَنْ أَبِي حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عَاصِمٍ الْعَدَوِيِّ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ خَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ تِسْعَةٌ خَمْسَةٌ وَأَرْبَعَةٌ أَحَدُ الْعَدَدَيْنِ مِنَ الْعَرَبِ وَالآخَرُ مِنَ الْعَجَمِ فَقَالَ ‏ "‏ اسْمَعُوا هَلْ سَمِعْتُمْ أَنَّهُ سَيَكُونُ بَعْدِي أُمَرَاءُ فَمَنْ دَخَلَ عَلَيْهِمْ فَصَدَّقَهُمْ بِكَذِبِهِمْ وَأَعَانَهُمْ عَلَى ظُلْمِهِمْ فَلَيْسَ مِنِّي وَلَسْتُ مِنْهُ وَلَيْسَ بِوَارِدٍ عَلَىَّ الْحَوْضَ وَمَنْ لَمْ يَدْخُلْ عَلَيْهِمْ وَلَمْ يُعِنْهُمْ عَلَى ظُلْمِهِمْ وَلَمْ يُصَدِّقْهُمْ بِكَذِبِهِمْ فَهُوَ مِنِّي وَأَنَا مِنْهُ وَهُوَ وَارِدٌ عَلَىَّ الْحَوْضَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ مِسْعَرٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ هَارُونُ فَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الْوَهَّابِ، عَنْ سُفْيَانَ، عَنْ أَبِي حَصِينٍ، عَنِ الشَّعْبِيِّ، عَنْ عَاصِمٍ الْعَدَوِيِّ، عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ هَارُونُ وَحَدَّثَنِي مُحَمَّدٌ، عَنْ سُفْيَانَ، عَنْ زُبَيْدٍ، عَنْ إِبْرَاهِيمَ، وَلَيْسَ، بِالنَّخَعِيِّ عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ مِسْعَرٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ حُذَيْفَةَ ‏.‏\hadithno{2259}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ka'b bin 'Ujrah who said:"The Messenger of Allah(s.a.w) came out to us, we were made up of nine; five and four. The first of the numbers for the Arabs, and the latter for the non-Arabs. He said: 'Listen, have you heard that after me there will leaders, whoever enters upon them and condones to their lies, and supports them in their oppression, then he is not from me and I am not from him, and he shall not drink with me from the Hawd. And whoever does not enter upon them, nor help them in their oppression, nor condones to their lies, then he is from me, and I am from him, and he shall drink with me at the Hawd}}
\hadithdefcmd{tirmidhi}{2260}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ ابْنُ بِنْتِ السُّدِّيِّ الْكُوفِيِّ، حَدَّثَنَا عُمَرُ بْنُ شَاكِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ الصَّابِرُ فِيهِمْ عَلَى دِينِهِ كَالْقَابِضِ عَلَى الْجَمْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَعُمَرُ بْنُ شَاكِرٍ شَيْخٌ بَصْرِيٌّ قَدْ رَوَى عَنْهُ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ ‏.‏\hadithno{2260}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah(s.a.w) said:"There shall come upon the people a time in which the one who is patient upon his religion will be like the one holding onto a burning ember}}
\hadithdefcmd{tirmidhi}{2261}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، أَخْبَرَنِي مُوسَى بْنُ عُبَيْدَةَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَشَتْ أُمَّتِي الْمُطَيْطِيَاءَ وَخَدَمَهَا أَبْنَاءُ الْمُلُوكِ أَبْنَاءُ فَارِسَ وَالرُّومِ سُلِّطَ شِرَارُهَا عَلَى خِيَارِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ أَبُو مُعَاوِيَةَ عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ ‏.‏ حَدَّثَنَا بِذَلِكَ، مُحَمَّدُ بْنُ إِسْمَاعِيلَ الْوَاسِطِيُّ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَلاَ يُعْرَفُ لِحَدِيثِ أَبِي مُعَاوِيَةَ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ أَصْلٌ إِنَّمَا الْمَعْرُوفُ حَدِيثُ مُوسَى بْنِ عُبَيْدَةَ ‏.‏ وَقَدْ رَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنْ يَحْيَى بْنِ سَعِيدٍ مُرْسَلاً وَلَمْ يَذْكُرْ فِيهِ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{2261}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Dinar, that Ibn 'Umar said:"The Messenger of Allah(s.a.w) said: 'When my Ummah walks in a proud march, and its servants are the children of kings, children of Persians and Romans, the evilest of them will be set over the best of them}}
\hadithdefcmd{tirmidhi}{2262}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ عَصَمَنِي اللَّهُ بِشَيْءٍ سَمِعْتُهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم لَمَّا هَلَكَ كِسْرَى قَالَ ‏"‏ مَنِ اسْتَخْلَفُوا ‏"‏ ‏.‏ قَالُوا ابْنَتَهُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَنْ يُفْلِحَ قَوْمٌ وَلَّوْا أَمْرَهُمُ امْرَأَةً ‏"‏ ‏.‏ قَالَ فَلَمَّا قَدِمَتْ عَائِشَةُ يَعْنِي الْبَصْرَةَ ذَكَرْتُ قَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَصَمَنِي اللَّهُ بِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2262}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Bakrah said:"Allah restrained me with something that I heard from the Messenger of Allah(s.a.w). When Kisra was destroyed, he said: 'Who did they have to succeed him?' They said: 'His daughter.' So the Prophet(s.a.w) said: 'A people will never succeed who give their leadership to a woman.'" He said: "So when 'Aishah arrived - meaning in Al-Basrah - I remembered the saying of Messenger of Allah (ﷺ), so Allah restrained me by it." Abu Eisa said: This Hadith is [Hasan] Sahih}}
\hadithdefcmd{tirmidhi}{2263}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَفَ عَلَى أُنَاسٍ جُلُوسٍ فَقَالَ ‏"‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِكُمْ مِنْ شَرِّكُمْ ‏"‏ ‏.‏ قَالَ فَسَكَتُوا فَقَالَ ذَلِكَ ثَلاَثَ مَرَّاتٍ فَقَالَ رَجُلٌ بَلَى يَا رَسُولَ اللَّهِ أَخْبِرْنَا بِخَيْرِنَا مِنْ شَرِّنَا ‏.‏ قَالَ ‏"‏ خَيْرُكُمْ مَنْ يُرْجَى خَيْرُهُ وَيُؤْمَنُ شَرُّهُ وَشَرُّكُمْ مَنْ لاَ يُرْجَى خَيْرُهُ وَلاَ يُؤْمَنُ شَرُّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2263}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) came across some people who were sitting, so he said:'Shall I not inform you of the best of you from your worst?'" He said: "They became silent, so he said that three times, then a man said: 'Of course, O Messenger of Allah! Inform us of the best among us from our worst.' He said: 'The best of you is the one whose goodness is hoped for, and people are safe from his evil. And the worst of you is he whose goodness is not hoped for, and people are not safe from his evil}}
\hadithdefcmd{tirmidhi}{2264}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حُمَيْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِخِيَارِ أُمَرَائِكُمْ وَشِرَارِهِمْ خِيَارُهُمُ الَّذِينَ تُحِبُّونَهُمْ وَيُحِبُّونَكُمْ وَتَدْعُونَ لَهُمْ وَيَدْعُونَ لَكُمْ وَشِرَارُ أُمَرَائِكُمُ الَّذِينَ تُبْغِضُونَهُمْ وَيُبْغِضُونَكُمْ وَتَلْعَنُونَهُمْ وَيَلْعَنُونَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ أَبِي حُمَيْدٍ ‏.‏ وَمُحَمَّدٌ يُضَعَّفُ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{2264}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Umar bin Al-Khattab narrated that the Prophet(s.a.w) said:"Shall I not inform you of the best of your leaders and the worst of them: The best of them are those whom you love and they love you, you supplicate for them, and they supplicate for you. And the evilest of your leaders are those who hate you, and you hate them, and they curse you and you curse them}}
\hadithdefcmd{tirmidhi}{2265}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، عَنِ الْحَسَنِ، عَنْ ضَبَّةَ بْنِ مِحْصَنٍ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّهُ سَيَكُونُ عَلَيْكُمْ أَئِمَّةٌ تَعْرِفُونَ وَتُنْكِرُونَ فَمَنْ أَنْكَرَ فَقَدْ بَرِئَ وَمَنْ كَرِهَ فَقَدْ سَلِمَ وَلَكِنْ مَنْ رَضِيَ وَتَابَعَ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ أَفَلاَ نُقَاتِلُهُمْ قَالَ ‏"‏ لاَ مَا صَلَّوْا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2265}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Umm Salamah narrated that the Prophet(s.a.w) said:"Indeed there shall come upon you A'immah whom you like (what they do) and some (of what they do) you dislike. So whoever rejects, then he is innocent, and whoever loathes, then he is safe. But whoever is pleased and follows." It was said: "O Messenger of Allah! Shall we fight them?" He said: "No, as long as they offer Salat}}
\hadithdefcmd{tirmidhi}{2266}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الأَشْقَرُ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، وَهَاشِمُ بْنُ الْقَاسِمِ، قَالاَ حَدَّثَنَا صَالِحٌ الْمُرِّيُّ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ أُمَرَاؤُكُمْ خِيَارَكُمْ وَأَغْنِيَاؤُكُمْ سُمَحَاءَكُمْ وَأُمُورُكُمْ شُورَى بَيْنَكُمْ فَظَهْرُ الأَرْضِ خَيْرٌ لَكُمْ مِنْ بَطْنِهَا وَإِذَا كَانَ أُمَرَاؤُكُمْ شِرَارَكُمْ وَأَغْنِيَاؤُكُمْ بُخَلاَءَكُمْ وَأُمُورُكُمْ إِلَى نِسَائِكُمْ فَبَطْنُ الأَرْضِ خَيْرٌ لَكُمْ مِنْ ظَهْرِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ صَالِحٍ الْمُرِّيِّ ‏.‏ وَصَالِحٌ الْمُرِّيُّ فِي حَدِيثِهِ غَرَائِبُ يَنْفَرِدُ بِهَا لاَ يُتَابَعُ عَلَيْهَا وَهُوَ رَجُلٌ صَالِحٌ ‏.‏\hadithno{2266}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"When your leaders are the best of you, the richest are the most generous among you, and your affairs are consulted among you, then the surface of the earth is better for you than its belly. And when your leaders are the worst of you, the richest are the stingiest among you, and your affairs are referred to your women, then the belly of the earth is better for you than its surface}}
\hadithdefcmd{tirmidhi}{2267}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ الْجُوزَجَانِيُّ، حَدَّثَنَا نُعَيْمُ بْنُ حَمَّادٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّكُمْ فِي زَمَانٍ مَنْ تَرَكَ مِنْكُمْ عُشْرَ مَا أُمِرَ بِهِ هَلَكَ ثُمَّ يَأْتِي زَمَانٌ مَنْ عَمِلَ مِنْهُمْ بِعُشْرِ مَا أُمِرَ بِهِ نَجَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ نُعَيْمِ بْنِ حَمَّادٍ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي ذَرٍّ وَأَبِي سَعِيدٍ ‏.‏\hadithno{2267}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Prophet(s.a.w) said:"You are in a time when whoever abandons a tenth of what he has been ordered, then he is ruined. Then, there will come a time in which whoever does a tenth of what he has been ordered shall be saved}}
\hadithdefcmd{tirmidhi}{2268}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ هَا هُنَا أَرْضُ الْفِتَنِ وَأَشَارَ إِلَى الْمَشْرِقِ حَيْثُ يَطْلُعُ جِذْلُ الشَّيْطَانِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ قَرْنُ الشَّيْطَانِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2268}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah(s.a.w) stood on the Minbar and said:"The land of Fitan is there" and he pointed to the east, meaning: "Where the sun rises from the horn of Shaitan" or he said: "The horn of the sun}}
\hadithdefcmd{tirmidhi}{2269}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ الزُّهْرِيِّ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَخْرُجُ مِنْ خُرَاسَانَ رَايَاتٌ سُودٌ لاَ يَرُدُّهَا شَيْءٌ حَتَّى تُنْصَبَ بِإِيلِيَاءَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2269}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"Black standards will come from Khurasan, nothing shall turn them back until they are planted in Jerusalem}}
