% Auto-generated chapter 63 for bukhari
% Hadiths in this chapter: 172

\hadithdefcmd{bukhari}{3776}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، قَالَ قُلْتُ لأَنَسٍ أَرَأَيْتَ اسْمَ الأَنْصَارِ كُنْتُمْ تُسَمَّوْنَ بِهِ، أَمْ سَمَّاكُمُ اللَّهُ قَالَ بَلْ سَمَّانَا اللَّهُ، كُنَّا نَدْخُلُ عَلَى أَنَسٍ فَيُحَدِّثُنَا مَنَاقِبَ الأَنْصَارِ وَمَشَاهِدَهُمْ، وَيُقْبِلُ عَلَىَّ أَوْ عَلَى رَجُلٍ مِنَ الأَزْدِ فَيَقُولُ فَعَلَ قَوْمُكَ يَوْمَ كَذَا وَكَذَا كَذَا وَكَذَا‏.‏\hadithno{3776}\hadithtrans{Narrated Ghailan bin Jarir:I asked Anas, "Tell me about the name 'Al-Ansar.; Did you call yourselves by it or did Allah call you by it?" He said, "Allah called us by it." We used to visit Anas (at Basra) and he used to narrate to us the virtues and deeds of the Ansar, and he used to address me or a person from the tribe of Al-Azd and say, "Your tribe did so-and-so on such-and-such a day}}
\hadithdefcmd{bukhari}{3777}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ يَوْمُ بُعَاثَ يَوْمًا قَدَّمَهُ اللَّهُ لِرَسُولِهِ صلى الله عليه وسلم فَقَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدِ افْتَرَقَ مَلَؤُهُمْ، وَقُتِلَتْ سَرَوَاتُهُمْ، وَجُرِّحُوا، فَقَدَّمَهُ اللَّهُ لِرَسُولِهِ صلى الله عليه وسلم فِي دُخُولِهِمْ فِي الإِسْلاَمِ‏.‏\hadithno{3777}\hadithtrans{Narrated `Aisha:The day of Bu'ath (i.e. Day of fighting between the two tribes of the Ansar, the Aus and Khazraj) was brought about by Allah for the good of His Apostle so that when Allah's Messenger (ﷺ) reached (Medina), the tribes of Medina had already divided and their chiefs had been killed and wounded. So Allah had brought about the battle for the good of H is Apostle in order that they (i.e. the Ansar) might embrace Islam}}
\hadithdefcmd{bukhari}{3778}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ قَالَتِ الأَنْصَارُ يَوْمَ فَتْحِ مَكَّةَ ـ وَأَعْطَى قُرَيْشًا ـ وَاللَّهِ إِنَّ هَذَا لَهُوَ الْعَجَبُ، إِنَّ سُيُوفَنَا تَقْطُرُ مِنْ دِمَاءِ قُرَيْشٍ، وَغَنَائِمُنَا تُرَدُّ عَلَيْهِمْ‏.‏ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَدَعَا الأَنْصَارَ قَالَ فَقَالَ ‏"‏ مَا الَّذِي بَلَغَنِي عَنْكُمْ ‏"‏‏.‏ وَكَانُوا لاَ يَكْذِبُونَ‏.‏ فَقَالُوا هُوَ الَّذِي بَلَغَكَ‏.‏ قَالَ ‏"‏ أَوَلاَ تَرْضَوْنَ أَنْ يَرْجِعَ النَّاسُ بِالْغَنَائِمِ إِلَى بُيُوتِهِمْ، وَتَرْجِعُونَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى بُيُوتِكُمْ لَوْ سَلَكَتِ الأَنْصَارُ وَادِيًا أَوْ شِعْبًا، لَسَلَكْتُ وَادِيَ الأَنْصَارِ أَوْ شِعْبَهُمْ ‏"‏‏.‏\hadithno{3778}\hadithtrans{Narrated Anas:On the day of the Conquest of Mecca, when the Prophet (ﷺ) had given (from the booty) to the Quraish, the Ansar said, "By Allah, this is indeed very strange: While our swords are still dribbling with the blood of Quraish, our war booty is distributed amongst them." When this news reached the Prophet (ﷺ) he called the Ansar and said, "What is this news that has reached me from you?" They used not to tell lies, so they replied, "What has reached you is true." He said, "Doesn't it please you that the people take the booty to their homes and you take Allah's Messenger (ﷺ) to your homes? If the Ansar took their way through a valley or a mountain pass, I would take the Ansar's valley or a mountain pass}}
\hadithdefcmd{bukhari}{3779}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَوْ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ الأَنْصَارَ سَلَكُوا وَادِيًا أَوْ شِعْبًا، لَسَلَكْتُ فِي وَادِي الأَنْصَارِ، وَلَوْلاَ الْهِجْرَةُ لَكُنْتُ امْرَأً مِنَ الأَنْصَارِ ‏"‏‏.‏ فَقَالَ أَبُو هُرَيْرَةَ مَا ظَلَمَ بِأَبِي وَأُمِّي، آوَوْهُ وَنَصَرُوهُ‏.‏ أَوْ كَلِمَةً أُخْرَى‏.‏\hadithno{3779}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) or Abul-Qasim said, "If the Ansar took their way through a valley or a mountain pass, I would take Ansar's valley. And but for the migration, I would have been one of the Ansar." Abu Huraira used to say, "The Prophet (ﷺ) is not unjust (by saying so). May my parents be sacrificed for him, for the Ansar sheltered and helped him," or said a similar sentence}}
\hadithdefcmd{bukhari}{3780}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ لَمَّا قَدِمُوا الْمَدِينَةَ آخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ عَبْدِ الرَّحْمَنِ وَسَعْدِ بْنِ الرَّبِيعِ، قَالَ لِعَبْدِ الرَّحْمَنِ إِنِّي أَكْثَرُ الأَنْصَارِ مَالاً فَأَقْسِمُ مَالِي نِصْفَيْنِ، وَلِي امْرَأَتَانِ، فَانْظُرْ أَعْجَبَهُمَا إِلَيْكَ فَسَمِّهَا لِي أُطَلِّقْهَا، فَإِذَا انْقَضَتْ عِدَّتُهَا فَتَزَوَّجْهَا‏.‏ قَالَ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ وَمَالِكَ، أَيْنَ سُوقُكُمْ فَدَلُّوهُ عَلَى سُوقِ بَنِي قَيْنُقَاعَ، فَمَا انْقَلَبَ إِلاَّ وَمَعَهُ فَضْلٌ مِنْ أَقِطٍ وَسَمْنٍ، ثُمَّ تَابَعَ الْغُدُوَّ، ثُمَّ جَاءَ يَوْمًا وَبِهِ أَثَرُ صُفْرَةٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَهْيَمْ ‏"‏‏.‏ قَالَ تَزَوَّجْتُ‏.‏ قَالَ ‏"‏ كَمْ سُقْتَ إِلَيْهَا ‏"‏‏.‏ قَالَ نَوَاةً مِنْ ذَهَبٍ‏.‏ أَوْ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ، شَكَّ إِبْرَاهِيمُ‏.‏\hadithno{3780}\hadithtrans{Narrated Sa`d's father:When the emigrants reached Medina. Allah's Messenger (ﷺ) established the bond of fraternity between `Abdur-Rahman and Sa`d bin Ar-Rabi. Sa`d said to `Abdur-Rahman, "I am the richest of all the Ansar, so I want to divide my property (between us), and I have two wives, so see which of the two you like and tell me, so that I may divorce her, and when she finishes her prescribed period (i.e. 'Idda) of divorce, then marry her." `Abdur-Rahman said, "May Allah bless your family and property for you; where is your market?" So they showed him the Qainuqa' market. (He went there and) returned with a profit in the form of dried yogurt and butter. He continued going (to the market) till one day he came, bearing the traces of yellow scent. The Prophet (ﷺ) asked, "What is this (scent)?" He replied, "I got married." The Prophet (ﷺ) asked, "How much Mahr did you give her?" He replied, "I gave her a datestone of gold or a gold piece equal to the weight of a date-stone." (The narrator, Ibrahim, is in doubt as to which is correct)}}
\hadithdefcmd{bukhari}{3781}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّهُ قَالَ قَدِمَ عَلَيْنَا عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ، وَآخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُ وَبَيْنَ سَعْدِ بْنِ الرَّبِيعِ، وَكَانَ كَثِيرَ الْمَالِ، فَقَالَ سَعْدٌ قَدْ عَلِمَتِ الأَنْصَارُ أَنِّي مِنْ أَكْثَرِهَا مَالاً، سَأَقْسِمُ مَالِي بَيْنِي وَبَيْنَكَ شَطْرَيْنِ، وَلِي امْرَأَتَانِ، فَانْظُرْ أَعْجَبَهُمَا إِلَيْكَ فَأُطَلِّقُهَا، حَتَّى إِذَا حَلَّتْ تَزَوَّجْتَهَا‏.‏ فَقَالَ عَبْدُ الرَّحْمَنِ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ‏.‏ فَلَمْ يَرْجِعْ يَوْمَئِذٍ حَتَّى أَفْضَلَ شَيْئًا مِنْ سَمْنٍ وَأَقِطٍ، فَلَمْ يَلْبَثْ إِلاَّ يَسِيرًا، حَتَّى جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ وَضَرٌ مِنْ صُفْرَةٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَهْيَمْ ‏"‏‏.‏ قَالَ تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ‏.‏ فَقَالَ ‏"‏ مَا سُقْتَ فِيهَا ‏"‏‏.‏ قَالَ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ، أَوْ نَوَاةً مِنْ ذَهَبٍ، فَقَالَ ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{3781}\hadithtrans{Narrated Anas:When `Abdur-Rahman bin `Auf came to us, Allah's Messenger (ﷺ) made a bond of fraternity between him and Sa`d bin Ar-Rabi` who was a rich man, Sa`d said, "The Ansar know that I am the richest of all of them, so I will divide my property into two parts between me and you, and I have two wives; see which of the two you like so that I may divorce her and you can marry her after she becomes lawful to you by her passing the prescribed period (i.e. 'Idda) of divorce. `Abdur Rahman said, "May Allah bless you your family (i.e. wives) for you." (But `Abdur-Rahman went to the market) and did not return on that day except with some gain of dried yogurt and butter. He went on trading just a few days till he came to Allah's Messenger (ﷺ) bearing the traces of yellow scent over his clothes. Allah's Messenger (ﷺ) asked him, "What is this scent?" He replied, "I have married a woman from the Ansar." Allah's Apostle asked, "How much Mahr have you given?" He said, "A date-stone weight of gold or a golden date-stone." The Prophet (ﷺ) said, "Arrange a marriage banquet even with a sheep}}
\hadithdefcmd{bukhari}{3782}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ أَبُو هَمَّامٍ، قَالَ سَمِعْتُ الْمُغِيرَةَ بْنَ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَتِ الأَنْصَارُ اقْسِمْ بَيْنَنَا وَبَيْنَهُمُ النَّخْلَ‏.‏ قَالَ ‏ "‏ لاَ ‏"‏‏.‏ قَالَ يَكْفُونَا الْمَئُونَةَ وَتُشْرِكُونَا فِي التَّمْرِ‏.‏ قَالُوا سَمِعْنَا وَأَطَعْنَا‏.‏\hadithno{3782}\hadithtrans{Narrated Abu Huraira:The Ansar said (to the Prophet (ﷺ) ), "Please divide the date-palm trees between us and them (i.e. emigrants)." The Prophet (ﷺ) said, "No." The Ansar said, "Let them (i.e. the emigrants) do the labor for us in the gardens and share the date-fruits with us." The emigrants said, "We accepted this}}
\hadithdefcmd{bukhari}{3783}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَدِيُّ بْنُ ثَابِتٍ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم أَوْ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الأَنْصَارُ لاَ يُحِبُّهُمْ إِلاَّ مُؤْمِنٌ، وَلاَ يُبْغِضُهُمْ إِلاَّ مُنَافِقٌ، فَمَنْ أَحَبَّهُمْ أَحَبَّهُ اللَّهُ، وَمَنْ أَبْغَضَهُمْ أَبْغَضَهُ اللَّهُ ‏"‏‏.‏\hadithno{3783}\hadithtrans{Narrated Al-Bara:I heard the Prophet (ﷺ) saying (or the Prophet (ﷺ) said), "None loves the Ansar but a believer, and none hates them but a hypocrite. So Allah will love him who loves them, and He will hate him who hates them}}
\hadithdefcmd{bukhari}{3784}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَبْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ آيَةُ الإِيمَانِ حُبُّ الأَنْصَارِ، وَآيَةُ النِّفَاقِ بُغْضُ الأَنْصَارِ ‏"‏‏.‏\hadithno{3784}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "The sign of Belief is to love the Ansar, and the sign of hypocrisy is to hate the Ansar}}
\hadithdefcmd{bukhari}{3785}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ رَأَى النَّبِيُّ صلى الله عليه وسلم النِّسَاءَ وَالصِّبْيَانَ مُقْبِلِينَ ـ قَالَ حَسِبْتُ أَنَّهُ قَالَ مِنْ عُرُسٍ ـ فَقَامَ النَّبِيُّ صلى الله عليه وسلم مُمْثِلاً، فَقَالَ ‏ "‏ اللَّهُمَّ أَنْتُمْ مِنْ أَحَبِّ النَّاسِ إِلَىَّ ‏"‏‏.‏ قَالَهَا ثَلاَثَ مِرَارٍ‏.‏\hadithno{3785}\hadithtrans{Narrated Anas:The Prophet (ﷺ) saw the women and children (of the Ansar) coming forward. (The sub-narrator said, "I think that Anas said, 'They were returning from a wedding party.") The Prophet (ﷺ) stood up and said thrice, "By Allah! You are from the most beloved people to me}}
\hadithdefcmd{bukhari}{3786}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ كَثِيرٍ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي هِشَامُ بْنُ زَيْدٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ جَاءَتِ امْرَأَةٌ مِنَ الأَنْصَارِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَهَا صَبِيٌّ لَهَا، فَكَلَّمَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ، إِنَّكُمْ أَحَبُّ النَّاسِ إِلَىَّ ‏"‏‏.‏ مَرَّتَيْنِ‏.‏\hadithno{3786}\hadithtrans{Narrated Anas bin Malik:Once an Ansari woman, accompanied by a son of hers, came to Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) spoke to her and said twice, "By Him in Whose Hand my life is, you are the most beloved people to me}}
\hadithdefcmd{bukhari}{3787}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، سَمِعْتُ أَبَا حَمْزَةَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَتِ الأَنْصَارُ‏:‏ يَا رَسُولَ اللَّهِ لِكُلِّ نَبِيٍّ أَتْبَاعٌ، وَإِنَّا قَدِ اتَّبَعْنَاكَ، فَادْعُ اللَّهَ أَنْ يَجْعَلَ أَتْبَاعَنَا مِنَّا‏.‏ فَدَعَا بِهِ‏.‏ فَنَمَيْتُ ذَلِكَ إِلَى ابْنِ أَبِي لَيْلَى‏.‏ قَالَ قَدْ زَعَمَ ذَلِكَ زَيْدٌ‏.‏\hadithno{3787}\hadithtrans{Narrated Zaid bin Al-Arqam:The Ansar said, "O Allah's Messenger (ﷺ)! Every prophet has his own followers and we have followed you. So will you invoke Allah to let our followers be considered from us (as Ansar too)?" So he invoked Allah accordingly}}
\hadithdefcmd{bukhari}{3788}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، قَالَ سَمِعْتُ أَبَا حَمْزَةَ ـ رَجُلاً مِنَ الأَنْصَارِ ـ قَالَتِ الأَنْصَارُ إِنَّ لِكُلِّ قَوْمٍ أَتْبَاعًا، وَإِنَّا قَدِ اتَّبَعْنَاكَ، فَادْعُ اللَّهَ أَنْ يَجْعَلَ أَتْبَاعَنَا مِنَّا‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اجْعَلْ أَتْبَاعَهُمْ مِنْهُمْ ‏"‏‏.‏ قَالَ عَمْرٌو فَذَكَرْتُهُ لاِبْنِ أَبِي لَيْلَى‏.‏ قَالَ قَدْ زَعَمَ ذَاكَ زَيْدٌ‏.‏ قَالَ شُعْبَةُ أَظُنُّهُ زَيْدَ بْنَ أَرْقَمَ‏.‏\hadithno{3788}\hadithtrans{Narrated Abu Hamza:(A man from the Ansar) The Ansar said, "Every nation has followers and (O Prophet) we have followed you, so invoke Allah to let our followers be considered from us (as Ansar like ourselves)." So the Prophet (ﷺ) said, "O Allah! Let their followers be considered as Ansar like themselves}}
\hadithdefcmd{bukhari}{3789}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي أُسَيْدٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خَيْرُ دُورِ الأَنْصَارِ بَنُو النَّجَّارِ، ثُمَّ بَنُو عَبْدِ الأَشْهَلِ، ثُمَّ بَنُو الْحَارِثِ بْنِ خَزْرَجٍ، ثُمَّ بَنُو سَاعِدَةَ، وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏‏.‏ فَقَالَ سَعْدٌ مَا أَرَى النَّبِيَّ صلى الله عليه وسلم إِلاَّ قَدْ فَضَّلَ عَلَيْنَا فَقِيلَ قَدْ فَضَّلَكُمْ عَلَى كَثِيرٍ‏.‏ وَقَالَ عَبْدُ الصَّمَدِ حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا قَتَادَةُ، سَمِعْتُ أَنَسًا، قَالَ أَبُو أُسَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا، وَقَالَ سَعْدُ بْنُ عُبَادَةَ‏.‏\hadithno{3789}\hadithtrans{Narrated Abu Usaid:The Prophet (ﷺ) said, "The best of the Ansar's families (homes) are those of Banu An-Najjar and then (those of) Banu `Abdul Ash-hal, then (those of) Banu Al-Harith bin Al-Khazraj and then (those of) Banu Sa`ida; nevertheless, there is good in all the families (houses) of the Ansar." On this, Sa`d (bin Ubada) said, "I see that the Prophet (ﷺ) has preferred some people to us." Somebody said (to him), "No, but he has given you superiority to many." (Hadith similar to above with a different chain)}}
\hadithdefcmd{bukhari}{3790}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، قَالَ أَبُو سَلَمَةَ أَخْبَرَنِي أَبُو أُسَيْدٍ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ الأَنْصَارِ ـ أَوْ قَالَ خَيْرُ دُورِ الأَنْصَارِ ـ بَنُو النَّجَّارِ وَبَنُو عَبْدِ الأَشْهَلِ وَبَنُو الْحَارِثِ وَبَنُو سَاعِدَةَ ‏"‏‏.‏\hadithno{3790}\hadithtrans{Narrated Abu Usaid:That he heard the Prophet (ﷺ) saying, "The best of the Ansar, or the best of the Ansar families (homes) are Banu An-Najjar, Bani `Abdul Ash-hal, Banu Al-Harith and Banu Sai'da}}
\hadithdefcmd{bukhari}{3791}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي عَمْرُو بْنُ يَحْيَى، عَنْ عَبَّاسِ بْنِ سَهْلٍ، عَنْ أَبِي حُمَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ خَيْرَ دُورِ الأَنْصَارِ دَارُ بَنِي النَّجَّارِ، ثُمَّ عَبْدِ الأَشْهَلِ، ثُمَّ دَارُ بَنِي الْحَارِثِ، ثُمَّ بَنِي سَاعِدَةَ، وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏‏.‏ فَلَحِقْنَا سَعْدَ بْنَ عُبَادَةَ فَقَالَ أَبَا أُسَيْدٍ أَلَمْ تَرَ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم خَيَّرَ الأَنْصَارَ فَجَعَلَنَا أَخِيرًا فَأَدْرَكَ سَعْدٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، خُيِّرَ دُورُ الأَنْصَارِ فَجُعِلْنَا آخِرًا‏.‏ فَقَالَ ‏"‏ أَوَلَيْسَ بِحَسْبِكُمْ أَنْ تَكُونُوا مِنَ الْخِيَارِ ‏"‏‏.‏\hadithno{3791}\hadithtrans{Narrated Abu Humaid:The Prophet (ﷺ) said, "The best of the Ansar families (homes) are the families (homes) of Banu An- Najjar, and then that of Banu `Abdul Ash-hal, and then that of Banu Al-Harith, and then that of Banu Saida; and there is good in all the families (homes) of the Ansar." Sa`d bin 'Ubada followed us and said, "O Abu Usaid ! Don't you see that the Prophet (ﷺ) compared the Ansar and made us the last of them in superiority? Then Sa`d met the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! In comparing the Ansar's families (homes) as to the degree of superiority, you have made us the last of them." Allah's Messenger (ﷺ) replied, "Isn't it sufficient that you are regarded amongst the best?}}
\hadithdefcmd{bukhari}{3792}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ قَالَ يَا رَسُولَ اللَّهِ، أَلاَ تَسْتَعْمِلُنِي كَمَا اسْتَعْمَلْتَ فُلاَنًا قَالَ ‏ "‏ سَتَلْقَوْنَ بَعْدِي أَثَرَةً فَاصْبِرُوا حَتَّى تَلْقَوْنِي عَلَى الْحَوْضِ ‏"‏‏.‏\hadithno{3792}\hadithtrans{Narrated Usaid bin Hudair:A man from the Ansar said, "O Allah's Messenger (ﷺ)! Will you appoint me as you have appointed so-and-so?" The Prophet (ﷺ) said, "After me you will see others given preference to you; so be patient till you meet me at the Tank (i.e. Lake of Kauthar). (on the Day of Resurrection)}}
\hadithdefcmd{bukhari}{3793}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم لِلأَنْصَارِ ‏ "‏ إِنَّكُمْ سَتَلْقَوْنَ بَعْدِي أَثَرَةً فَاصْبِرُوا حَتَّى تَلْقَوْنِي، وَمَوْعِدُكُمُ الْحَوْضُ ‏"‏‏.‏\hadithno{3793}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said to the Ansar, "After me you will see others given preference to you; so be patient till you meet me, and your promised place (of meeting) will be the Tank (i.e. Lake of Kauthar)}}
\hadithdefcmd{bukhari}{3794}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ حِينَ خَرَجَ مَعَهُ إِلَى الْوَلِيدِ قَالَ دَعَا النَّبِيُّ صلى الله عليه وسلم الأَنْصَارَ إِلَى أَنْ يُقْطِعَ لَهُمُ الْبَحْرَيْنِ‏.‏ فَقَالُوا لاَ، إِلاَّ أَنْ تُقْطِعَ لإِخْوَانِنَا مِنَ الْمُهَاجِرِينَ مِثْلَهَا‏.‏ قَالَ ‏ "‏ إِمَّا لاَ، فَاصْبِرُوا حَتَّى تَلْقَوْنِي، فَإِنَّهُ سَيُصِيبُكُمْ بَعْدِي أُثْرَةٌ ‏"‏‏.‏\hadithno{3794}\hadithtrans{Narrated Yahya bin Sa`id:That he heard Anas bin Malik when he went with him to Al-Walid, saying, "Once the Prophet (ﷺ) called the Ansar in order to give them the territory of Bahrain they said, 'No, unless you give to our emigrant brethren a similar share.' On that he said 'If you do not agree to it, then be patient till you meet me, for after me others will be given preference to you}}
\hadithdefcmd{bukhari}{3795}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو إِيَاسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَةِ، فَأَصْلِحِ الأَنْصَارَ وَالْمُهَاجِرَةَ ‏"‏‏.‏ وَعَنْ قَتَادَةَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ، وَقَالَ فَاغْفِرْ لِلأَنْصَارِ‏.‏\hadithno{3795}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "There is no life except the life of the Hereafter; so, O Allah! Improve the state of the Ansar and the Muhajirun." And Anas added that the Prophet (ﷺ) also said, "O Allah! Forgive the Ansar}}
\hadithdefcmd{bukhari}{3796}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدٍ الطَّوِيلِ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَتِ الأَنْصَارُ يَوْمَ الْخَنْدَقِ تَقُولُ نَحْنُ الَّذِينَ بَايَعُوا مُحَمَّدَا عَلَى الْجِهَادِ مَا حَيِينَا أَبَدَا فَأَجَابَهُمُ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَهْ فَأَكْرِمِ الأَنْصَارَ وَالْمُهَاجِرَهْ\hadithno{3796}\hadithtrans{Narrated Anas bin Malik:On the day of the battle of the Trench (i.e. Ghazwat-ul-Khandaq) the Ansar used to say, "We are those who have given the pledge of allegiance to Muhammad for Jihad (i.e. holy fighting) as long as we live." The Prophet (ﷺ) , replied to them, "O Allah! There is no life except the life of the Hereafter; so please honor the Ansar and the Emigrants}}
\hadithdefcmd{bukhari}{3797}{حَدَّثَنِي مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، قَالَ جَاءَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَحْفِرُ الْخَنْدَقَ وَنَنْقُلُ التُّرَابَ عَلَى أَكْتَادِنَا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَهْ فَاغْفِرْ لِلْمُهَاجِرِينَ وَالأَنْصَارِ ‏"‏‏.‏\hadithno{3797}\hadithtrans{Narrated Sahl:Allah's Messenger (ﷺ) came to us while we were digging the trench and carrying out the earth on our backs. Allah's Messenger (ﷺ) then said, "O Allah ! There is no life except the life of the Hereafter, so please forgive the Emigrants and the Ansar}}
\hadithdefcmd{bukhari}{3798}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ فُضَيْلِ بْنِ غَزْوَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَبَعَثَ إِلَى نِسَائِهِ فَقُلْنَ مَا مَعَنَا إِلاَّ الْمَاءُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَضُمُّ، أَوْ يُضِيفُ هَذَا ‏"‏‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ أَنَا‏.‏ فَانْطَلَقَ بِهِ إِلَى امْرَأَتِهِ، فَقَالَ أَكْرِمِي ضَيْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ مَا عِنْدَنَا إِلاَّ قُوتُ صِبْيَانِي‏.‏ فَقَالَ هَيِّئِي طَعَامَكِ، وَأَصْبِحِي سِرَاجَكِ، وَنَوِّمِي صِبْيَانَكِ إِذَا أَرَادُوا عَشَاءً‏.‏ فَهَيَّأَتْ طَعَامَهَا وَأَصْبَحَتْ سِرَاجَهَا، وَنَوَّمَتْ صِبْيَانَهَا، ثُمَّ قَامَتْ كَأَنَّهَا تُصْلِحُ سِرَاجَهَا فَأَطْفَأَتْهُ، فَجَعَلاَ يُرِيَانِهِ أَنَّهُمَا يَأْكُلاَنِ، فَبَاتَا طَاوِيَيْنِ، فَلَمَّا أَصْبَحَ، غَدَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ ضَحِكَ اللَّهُ اللَّيْلَةَ ـ أَوْ عَجِبَ ـ مِنْ فَعَالِكُمَا ‏"‏ فَأَنْزَلَ اللَّهُ ‏\{‏وَيُؤْثِرُونَ عَلَى أَنْفُسِهِمْ وَلَوْ كَانَ بِهِمْ خَصَاصَةٌ وَمَنْ يُوقَ شُحَّ نَفْسِهِ فَأُولَئِكَ هُمُ الْمُفْلِحُونَ‏\}‏\hadithno{3798}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet. The Prophet (ﷺ) sent a messenger to his wives (to bring something for that man to eat) but they said that they had nothing except water. Then Allah's Messenger (ﷺ) said, "Who will take this (person) or entertain him as a guest?" An Ansar man said, "I." So he took him to his wife and said to her, "Entertain generously the guest of Allah's Messenger (ﷺ) " She said, "We have got nothing except the meals of my children." He said, "Prepare your meal, light your lamp and let your children sleep if they ask for supper." So she prepared her meal, lighted her lamp and made her children sleep, and then stood up pretending to mend her lamp, but she put it off. Then both of them pretended to be eating, but they really went to bed hungry. In the morning the Ansari went to Allah's Messenger (ﷺ) who said, "Tonight Allah laughed or wondered at your action." Then Allah revealed: "But give them (emigrants) preference over themselves even though they were in need of that And whosoever is saved from the covetousness Such are they who will be successful}}
\hadithdefcmd{bukhari}{3799}{حَدَّثَنِي مُحَمَّدُ بْنُ يَحْيَى أَبُو عَلِيٍّ، حَدَّثَنَا شَاذَانُ، أَخُو عَبْدَانَ حَدَّثَنَا أَبِي، أَخْبَرَنَا شُعْبَةُ بْنُ الْحَجَّاجِ، عَنْ هِشَامِ بْنِ زَيْدٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ مَرَّ أَبُو بَكْرٍ وَالْعَبَّاسُ ـ رضى الله عنهما ـ بِمَجْلِسٍ مِنْ مَجَالِسِ الأَنْصَارِ وَهُمْ يَبْكُونَ، فَقَالَ مَا يُبْكِيكُمْ قَالُوا ذَكَرْنَا مَجْلِسَ النَّبِيِّ صلى الله عليه وسلم مِنَّا‏.‏ فَدَخَلَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ بِذَلِكَ ـ قَالَ ـ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم وَقَدْ عَصَبَ عَلَى رَأْسِهِ حَاشِيَةَ بُرْدٍ ـ قَالَ ـ فَصَعِدَ الْمِنْبَرَ وَلَمْ يَصْعَدْهُ بَعْدَ ذَلِكَ الْيَوْمِ، فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏ "‏ أُوصِيكُمْ بِالأَنْصَارِ، فَإِنَّهُمْ كَرِشِي وَعَيْبَتِي، وَقَدْ قَضَوُا الَّذِي عَلَيْهِمْ، وَبَقِيَ الَّذِي لَهُمْ، فَاقْبَلُوا مِنْ مُحْسِنِهِمْ، وَتَجَاوَزُوا عَنْ مُسِيئِهِمْ ‏"‏‏.‏\hadithno{3799}\hadithtrans{Narrated Anas bin Malik:Abu Bakr and Al-`Abbas passed by one of the gatherings of the Ansar who were weeping then. He (i.e. Abu Bakr or Al-`Abbas) asked, "Why are you weeping?" They replied, "We are weeping because we remember the gathering of the Prophet (ﷺ) with us." So Abu Bakr went to the Prophet (ﷺ) and told him of that. The Prophet (ﷺ) came out, tying his head with a piece of the hem of a sheet. He ascended the pulpit which he never ascended after that day. He glorified and praised Allah and then said, "I request you to take care of the Ansar as they are my near companions to whom I confided my private secrets. They have fulfilled their obligations and rights which were enjoined on them but there remains what is for them. So, accept the good of the good-doers amongst them and excuse the wrongdoers amongst them}}
\hadithdefcmd{bukhari}{3800}{حَدَّثَنَا أَحْمَدُ بْنُ يَعْقُوبَ، حَدَّثَنَا ابْنُ الْغَسِيلِ، سَمِعْتُ عِكْرِمَةَ، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ مِلْحَفَةٌ، مُتَعَطِّفًا بِهَا عَلَى مَنْكِبَيْهِ، وَعَلَيْهِ عِصَابَةٌ دَسْمَاءُ حَتَّى جَلَسَ عَلَى الْمِنْبَرِ، فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ، أَيُّهَا النَّاسُ، فَإِنَّ النَّاسَ يَكْثُرُونَ وَتَقِلُّ الأَنْصَارُ، حَتَّى يَكُونُوا كَالْمِلْحِ فِي الطَّعَامِ، فَمَنْ وَلِيَ مِنْكُمْ أَمْرًا يَضُرُّ فِيهِ أَحَدًا أَوْ يَنْفَعُهُ، فَلْيَقْبَلْ مِنْ مُحْسِنِهِمْ، وَيَتَجَاوَزْ عَنْ مُسِيئِهِمْ ‏"‏‏.‏\hadithno{3800}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) (in his fatal illness) came out wrapped in a sheet covering his shoulders and his head was tied with an oily tape of cloth till he sat on the pulpit, and after praising and glorifying Allah, he said, "Then-after, O people! The people will go on increasing, but the Ansar will go on decreasing till they become just like salt in a meal. So whoever amongst you will be the ruler and has the power to harm or benefit others, should accept the good of the good-doers amongst them and excuse the wrongdoers amongst them}}
\hadithdefcmd{bukhari}{3801}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الأَنْصَارُ كَرِشِي وَعَيْبَتِي، وَالنَّاسُ سَيَكْثُرُونَ وَيَقِلُّونَ، فَاقْبَلُوا مِنْ مُحْسِنِهِمْ، وَتَجَاوَزُوا عَنْ مُسِيئِهِمْ ‏"‏‏.‏\hadithno{3801}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "The Ansar are my near companions to whom I confided my private secrets, People will go on increasing but the Ansar will go on decreasing; so accept the good of the good-doers amongst them and excuse the wrong-doers amongst them}}
\hadithdefcmd{bukhari}{3802}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ يَقُولُ أُهْدِيَتْ لِلنَّبِيِّ صلى الله عليه وسلم حُلَّةُ حَرِيرٍ، فَجَعَلَ أَصْحَابُهُ يَمَسُّونَهَا وَيَعْجَبُونَ مِنْ لِينِهَا فَقَالَ ‏ "‏ أَتَعْجَبُونَ مِنْ لِينِ هَذِهِ لَمَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ خَيْرٌ مِنْهَا ‏"‏‏.‏ أَوْ أَلْيَنُ‏.‏ رَوَاهُ قَتَادَةُ وَالزُّهْرِيُّ سَمِعَا أَنَسًا عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3802}\hadithtrans{Narrated Al-Bara:A silken cloth was given as a present to the Prophet (ﷺ) . His companions started touching it and admiring its softness. The Prophet (ﷺ) said, "Are you admiring its softness? The handkerchiefs of Sa`d bin Mu`adh (in Paradise) are better and softer than it}}
\hadithdefcmd{bukhari}{3803}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا فَضْلُ بْنُ مُسَاوِرٍ، خَتَنُ أَبِي عَوَانَةَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ ـ رضى الله عنه ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ اهْتَزَّ الْعَرْشُ لِمَوْتِ سَعْدِ بْنِ مُعَاذٍ ‏"‏‏.‏ وَعَنِ الأَعْمَشِ حَدَّثَنَا أَبُو صَالِحٍ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ‏.‏ فَقَالَ رَجُلٌ لِجَابِرٍ فَإِنَّ الْبَرَاءَ يَقُولُ اهْتَزَّ السَّرِيرُ‏.‏ فَقَالَ إِنَّهُ كَانَ بَيْنَ هَذَيْنِ الْحَيَّيْنِ ضَغَائِنُ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ اهْتَزَّ عَرْشُ الرَّحْمَنِ لِمَوْتِ سَعْدِ بْنِ مُعَاذٍ ‏"‏‏.‏\hadithno{3803}\hadithtrans{Narrated Jabir:I heard the Prophet (ﷺ) saying, "The Throne (of Allah) shook at the death of Sa`d bin Mu`adh." Through another group of narrators, Jabir added, "I heard the Prophet (ﷺ) : saying, 'The Throne of the Beneficent shook because of the death of Sa`d bin Mu`adh}}
\hadithdefcmd{bukhari}{3804}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ أُنَاسًا نَزَلُوا عَلَى حُكْمِ سَعْدِ بْنِ مُعَاذٍ، فَأَرْسَلَ إِلَيْهِ فَجَاءَ عَلَى حِمَارٍ، فَلَمَّا بَلَغَ قَرِيبًا مِنَ الْمَسْجِدِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قُومُوا إِلَى خَيْرِكُمْ أَوْ سَيِّدِكُمْ ‏"‏‏.‏ فَقَالَ ‏"‏ يَا سَعْدُ، إِنَّ هَؤُلاَءِ نَزَلُوا عَلَى حُكْمِكَ ‏"‏‏.‏ قَالَ فَإِنِّي أَحْكُمُ فِيهِمْ أَنْ تُقْتَلَ مُقَاتِلَتُهُمْ وَتُسْبَى ذَرَارِيُّهُمْ‏.‏ قَالَ ‏"‏ حَكَمْتَ بِحُكْمِ اللَّهِ، أَوْ بِحُكْمِ الْمَلِكِ ‏"‏‏.‏\hadithno{3804}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Some people (i.e. the Jews of Bani Quraiza) agreed to accept the verdict of Sa`d bin Mu`adh so the Prophet (ﷺ) sent for him (i.e. Sa`d bin Mu`adh). He came riding a donkey, and when he approached the Mosque, the Prophet (ﷺ) said, "Get up for the best amongst you." or said, "Get up for your chief." Then the Prophet (ﷺ) said, "O Sa`d! These people have agreed to accept your verdict." Sa`d said, "I judge that their warriors should be killed and their children and women should be taken as captives." The Prophet said, "You have given a judgment similar to Allah's Judgment (or the King's judgment)}}
\hadithdefcmd{bukhari}{3805}{حَدَّثَنَا عَلِيُّ بْنُ مُسْلِمٍ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، أَخْبَرَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ رَجُلَيْنِ، خَرَجَا مِنْ عِنْدِ النَّبِيِّ صلى الله عليه وسلم فِي لَيْلَةٍ مُظْلِمَةٍ، وَإِذَا نُورٌ بَيْنَ أَيْدِيهِمَا حَتَّى تَفَرَّقَا، فَتَفَرَّقَ النُّورُ مَعَهُمَا‏.‏ وَقَالَ مَعْمَرٌ عَنْ ثَابِتٍ عَنْ أَنَسٍ أَنَّ أُسَيْدَ بْنَ حُضَيْرٍ وَرَجُلاً مِنَ الأَنْصَارِ‏.‏ قَالَ حَمَّادٌ أَخْبَرَنَا ثَابِتٌ عَنْ أَنَسٍ كَانَ أُسَيْدُ بْنُ حُضَيْرٍ وَعَبَّادُ بْنُ بِشْرٍ عِنْدَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3805}\hadithtrans{Narrated Anas:Two men left the Prophet (ﷺ) on a very dark night. Suddenly a light came in front of them, and when they separated, the light also separated along with them}}
\hadithdefcmd{bukhari}{3806}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اسْتَقْرِئُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنَ ابْنِ مَسْعُودٍ وَسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ، وَأُبَىٍّ، وَمُعَاذِ بْنِ جَبَلٍ ‏"‏‏.‏\hadithno{3806}\hadithtrans{Narrated `Abdullah bin `Amr:I heard the Prophet (ﷺ) saying, "Learn the recitation of Qur'an from four persons: Ibn Mas`ud, Salim, the freed slave of Abu Hudhaifa, Ubai and Mu`adh bin Jabal}}
\hadithdefcmd{bukhari}{3807}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا قَتَادَةُ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ أَبُو أُسَيْدٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ دُورِ الأَنْصَارِ بَنُو النَّجَّارِ، ثُمَّ بَنُو عَبْدِ الأَشْهَلِ، ثُمَّ بَنُو الْحَارِثِ بْنِ الْخَزْرَجِ، ثُمَّ بَنُو سَاعِدَةَ وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏‏.‏ فَقَالَ سَعْدُ بْنُ عُبَادَةَ ـ وَكَانَ ذَا قِدَمٍ فِي الإِسْلاَمِ ـ أَرَى رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ فَضَّلَ عَلَيْنَا‏.‏ فَقِيلَ لَهُ قَدْ فَضَّلَكُمْ عَلَى نَاسٍ كَثِيرٍ‏.‏\hadithno{3807}\hadithtrans{Narrated Abu Usaid:Allah's Messenger (ﷺ) said, "The best of the Ansar's houses are those of Bani An-Najjar, then those of Bani `Abdul Ash-hal, then those of Bani Al-Harith bin Al-Khazraj, then those of Bani Saida; but there is goodness in all the houses of the Ansar." Sa`d bin Ubada who was one of those who embraced Islam early, said, "I see that Allah's Messenger (ﷺ) is giving others superiority above us." Some people said to him, "But he has given you superiority above many other people}}
\hadithdefcmd{bukhari}{3808}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، قَالَ ذُكِرَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ عِنْدَ عَبْدِ اللَّهِ بْنِ عَمْرٍو فَقَالَ ذَاكَ رَجُلٌ لاَ أَزَالُ أُحِبُّهُ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ خُذُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ فَبَدَأَ بِهِ ـ وَسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ، وَمُعَاذِ بْنِ جَبَلٍ، وَأُبَىِّ بْنِ كَعْبٍ ‏"‏‏.‏\hadithno{3808}\hadithtrans{Narrated Masruq:`Abdullah bin Masud was mentioned before `Abdullah bin `Amr who said, "That is a man I still love, as I heard the Prophet (ﷺ) saying 'Learn the recitation of Qur'an from four from `Abdullah bin Mas`ud -- he started with him--Salim, the freed slave of Abu Hudaifa, Mu`adh bin Jabal and Ubai bin Ka`b}}
\hadithdefcmd{bukhari}{3809}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، قَالَ سَمِعْتُ شُعْبَةَ، سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم لأُبَىٍّ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ ‏\{‏لَمْ يَكُنِ الَّذِينَ كَفَرُوا‏\}‏ ‏"‏‏.‏ قَالَ وَسَمَّانِي قَالَ ‏"‏ نَعَمْ ‏"‏ فَبَكَى‏.‏\hadithno{3809}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said to Ubai, "Allah has ordered me to recite to you: 'Those who disbelieve (Surat-al- Bayina 98).' " Ubai said, "Has He mentioned my name?" The Prophet (ﷺ) said, "Yes." On hearing this, Ubai started weeping}}
\hadithdefcmd{bukhari}{3810}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ جَمَعَ الْقُرْآنَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم أَرْبَعَةٌ، كُلُّهُمْ مِنَ الأَنْصَارِ أُبَىٌّ، وَمُعَاذُ بْنُ جَبَلٍ، وَأَبُو زَيْدٍ، وَزَيْدُ بْنُ ثَابِتٍ‏.‏ قُلْتُ لأَنَسِ مَنْ أَبُو زَيْدٍ قَالَ أَحَدُ عُمُومَتِي‏.‏\hadithno{3810}\hadithtrans{Narrated Qatada:Anas said, "The Qur'an was collected in the lifetime of the Prophet (ﷺ) by four (men), all of whom were from the Ansar: Ubai, Mu`adh bin Jabal, Abu Zaid and Zaid bin Thabit." I asked Anas, "Who is Abu Zaid?" He said, "One of my uncles}}
\hadithdefcmd{bukhari}{3811}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لَمَّا كَانَ يَوْمُ أُحُدٍ انْهَزَمَ النَّاسُ عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَبُو طَلْحَةَ بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم مُجَوِّبٌ بِهِ عَلَيْهِ بِحَجَفَةٍ لَهُ، وَكَانَ أَبُو طَلْحَةَ رَجُلاً رَامِيًا شَدِيدَ الْقِدِّ، يَكْسِرُ يَوْمَئِذٍ قَوْسَيْنِ أَوْ ثَلاَثًا، وَكَانَ الرَّجُلُ يَمُرُّ مَعَهُ الْجَعْبَةُ مِنَ النَّبْلِ فَيَقُولُ انْشُرْهَا لأَبِي طَلْحَةَ‏.‏ فَأَشْرَفَ النَّبِيُّ صلى الله عليه وسلم يَنْظُرُ إِلَى الْقَوْمِ، فَيَقُولُ أَبُو طَلْحَةَ يَا نَبِيَّ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي، لاَ تُشْرِفْ يُصِيبُكَ سَهْمٌ مِنْ سِهَامِ الْقَوْمِ، نَحْرِي دُونَ نَحْرِكَ‏.‏ وَلَقَدْ رَأَيْتُ عَائِشَةَ بِنْتَ أَبِي بَكْرٍ وَأُمَّ سُلَيْمٍ وَإِنَّهُمَا لَمُشَمِّرَتَانِ، أَرَى خَدَمَ سُوقِهِمَا، تُنْقِزَانِ الْقِرَبَ عَلَى مُتُونِهِمَا، تُفْرِغَانِهِ فِي أَفْوَاهِ الْقَوْمِ، ثُمَّ تَرْجِعَانِ فَتَمْلآنِهَا، ثُمَّ تَجِيآنِ فَتُفْرِغَانِهِ فِي أَفْوَاهِ الْقَوْمِ، وَلَقَدْ وَقَعَ السَّيْفُ مِنْ يَدَىْ أَبِي طَلْحَةَ إِمَّا مَرَّتَيْنِ، وَإِمَّا ثَلاَثًا‏.‏\hadithno{3811}\hadithtrans{Narrated Anas:On the day of the battle of Uhud, the people ran away, leaving the Prophet (ﷺ) , but Abu- Talha was shielding the Prophet (ﷺ) with his shield in front of him. Abu Talha was a strong, experienced archer who used to keep his arrow bow strong and well stretched. On that day he broke two or three arrow bows. If any man passed by carrying a quiver full of arrows, the Prophet (ﷺ) would say to him, "Empty it in front of Abu Talha." When the Prophet (ﷺ) started looking at the enemy by raising his head, Abu Talha said, "O Allah's Prophet! Let my parents be sacrificed for your sake! Please don't raise your head and make it visible, lest an arrow of the enemy should hit you. Let my neck and chest be wounded instead of yours." (On that day) I saw `Aisha, the daughter of Abu Bakr and Um Sulaim both lifting their dresses up so that I was able to see the ornaments of their legs, and they were carrying the water skins on their arms to pour the water into the mouths of the thirsty people and then go back and fill them and come to pour the water into the mouths of the people again. (On that day) Abu Talha's sword fell from his hand twice or thrice}}
\hadithdefcmd{bukhari}{3812}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ سَمِعْتُ مَالِكًا، يُحَدِّثُ عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، قَالَ مَا سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ لأَحَدٍ يَمْشِي عَلَى الأَرْضِ إِنَّهُ مِنْ أَهْلِ الْجَنَّةِ‏.‏ إِلاَّ لِعَبْدِ اللَّهِ بْنِ سَلاَمٍ قَالَ وَفِيهِ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَشَهِدَ شَاهِدٌ مِنْ بَنِي إِسْرَائِيلَ‏\}‏ الآيَةَ‏.‏ قَالَ لاَ أَدْرِي قَالَ مَالِكٌ الآيَةَ أَوْ فِي الْحَدِيثِ‏.‏\hadithno{3812}\hadithtrans{Narrated Sa`d bin Abi Waqqas:I have never heard the Prophet (ﷺ) saying about anybody walking on the earth that he is from the people of Paradise except `Abdullah bin Salam. The following Verse was revealed concerning him: "And a witness from the children of Israel testifies that this Qur'an is true}}
\hadithdefcmd{bukhari}{3813}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَزْهَرُ السَّمَّانُ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ قَيْسِ بْنِ عُبَادٍ، قَالَ كُنْتُ جَالِسًا فِي مَسْجِدِ الْمَدِينَةِ، فَدَخَلَ رَجُلٌ عَلَى وَجْهِهِ أَثَرُ الْخُشُوعِ، فَقَالُوا هَذَا رَجُلٌ مِنْ أَهْلِ الْجَنَّةِ‏.‏ فَصَلَّى رَكْعَتَيْنِ تَجَوَّزَ فِيهِمَا ثُمَّ خَرَجَ، وَتَبِعْتُهُ فَقُلْتُ إِنَّكَ حِينَ دَخَلْتَ الْمَسْجِدَ قَالُوا هَذَا رَجُلٌ مِنْ أَهْلِ الْجَنَّةِ‏.‏ قَالَ وَاللَّهِ مَا يَنْبَغِي لأَحَدٍ أَنْ يَقُولَ مَا لاَ يَعْلَمُ وَسَأُحَدِّثُكَ لِمَ ذَاكَ رَأَيْتُ رُؤْيَا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَقَصَصْتُهَا عَلَيْهِ، وَرَأَيْتُ كَأَنِّي فِي رَوْضَةٍ ـ ذَكَرَ مِنْ سَعَتِهَا وَخُضْرَتِهَا ـ وَسْطَهَا عَمُودٌ مِنْ حَدِيدٍ، أَسْفَلُهُ فِي الأَرْضِ وَأَعْلاَهُ فِي السَّمَاءِ، فِي أَعْلاَهُ عُرْوَةٌ فَقِيلَ لَهُ ارْقَهْ‏.‏ قُلْتُ لاَ أَسْتَطِيعُ‏.‏ فَأَتَانِي مِنْصَفٌ فَرَفَعَ ثِيَابِي مِنْ خَلْفِي، فَرَقِيتُ حَتَّى كُنْتُ فِي أَعْلاَهَا، فَأَخَذْتُ بِالْعُرْوَةِ، فَقِيلَ لَهُ اسْتَمْسِكْ‏.‏ فَاسْتَيْقَظْتُ وَإِنَّهَا لَفِي يَدِي، فَقَصَصْتُهَا عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تِلْكَ الرَّوْضَةُ الإِسْلاَمُ، وَذَلِكَ الْعَمُودُ عَمُودُ الإِسْلاَمِ، وَتِلْكَ الْعُرْوَةُ عُرْوَةُ الْوُثْقَى، فَأَنْتَ عَلَى الإِسْلاَمِ حَتَّى تَمُوتَ ‏"‏‏.‏ وَذَاكَ الرَّجُلُ عَبْدُ اللَّهِ بْنُ سَلاَمٍ‏.‏ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا مُعَاذٌ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، حَدَّثَنَا قَيْسُ بْنُ عُبَادٍ، عَنِ ابْنِ سَلاَمٍ، قَالَ وَصِيفٌ مَكَانَ مِنْصَفٌ‏.‏\hadithno{3813}\hadithtrans{Narrated Qais bin Ubad:While I was sitting in the Mosque of Medina, there entered a man (Abdullah bin Salam) with signs of solemnity over his face. The people said, "He is one of the people of Paradise." He prayed two light rak`at and then left. I followed him and said, "When you entered the Mosque, the people said, 'He is one of the people of Paradise.' " He said, "By Allah, one ought not say what he does not know; and I will tell you why. In the lifetime of the Prophet (ﷺ) I had a dream which I narrated to him. I saw as if I were in a garden." He then described its extension and greenery. He added: In its center there was an iron pillar whose lower end was fixed in the earth and the upper end was in the sky, and at its upper end there was a (ring-shaped) hand-hold. I was told to climb it. I said, "I can't." "Then a servant came to me and lifted my clothes from behind and I climbed till I reached the top (of the pillar). Then I got hold of the hand-hold, and I was told to hold it tightly, then I woke up and (the effect of) the handhold was in my hand. I narrated all that to the Prophet (ﷺ) who said, 'The garden is Islam, and the handhold is the Most Truth-worthy Hand-Hold. So you will remain as a Muslim till you die." The narrator added: "The man was `Abdullah bin Salam}}
\hadithdefcmd{bukhari}{3814}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، أَتَيْتُ الْمَدِينَةَ فَلَقِيتُ عَبْدَ اللَّهِ بْنَ سَلاَمٍ ـ رضى الله عنه ـ فَقَالَ أَلاَ تَجِيءُ فَأُطْعِمَكَ سَوِيقًا وَتَمْرًا، وَتَدْخُلَ فِي بَيْتٍ ثُمَّ قَالَ إِنَّكَ بِأَرْضٍ الرِّبَا بِهَا فَاشٍ، إِذَا كَانَ لَكَ عَلَى رَجُلٍ حَقٌّ فَأَهْدَى إِلَيْكَ حِمْلَ تِبْنٍ، أَوْ حِمْلَ شَعِيرٍ أَوْ حِمْلَ قَتٍّ، فَلاَ تَأْخُذْهُ، فَإِنَّهُ رِبًا‏.‏ وَلَمْ يَذْكُرِ النَّضْرُ وَأَبُو دَاوُدَ وَوَهْبٌ عَنْ شُعْبَةَ الْبَيْتَ‏.‏\hadithno{3814}\hadithtrans{Narrated Abu Burda:When I came to Medina. I met `Abdullah bin Salam. He said, "Will you come to me so that I may serve you with Sawiq (i.e. powdered barley) and dates, and let you enter a (blessed) house that in which the Prophet (ﷺ) entered?" Then he added, "You are In a country where the practice of Riba (i.e. usury) is prevalent; so if somebody owes you something and he sends you a present of a load of chopped straw or a load of barley or a load of provender then do not take it, as it is Riba}}
\hadithdefcmd{bukhari}{3815}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ جَعْفَرٍ، قَالَ سَمِعْتُ عَلِيًّا ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ح حَدَّثَنِي صَدَقَةُ أَخْبَرَنَا عَبْدَةُ عَنْ هِشَامٍ عَنْ أَبِيهِ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ جَعْفَرٍ عَنْ عَلِيٍّ ـ رضى الله عنهم ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ نِسَائِهَا مَرْيَمُ، وَخَيْرُ نِسَائِهَا خَدِيجَةُ ‏"‏‏.‏\hadithno{3815}\hadithtrans{Narrated `Ali:I heard Allah's Messenger (ﷺ) saying (as below) Narrated `Ali: The Prophet (ﷺ) said, "The best of the world's women is Mary (at her lifetime), and the best of the world's women is Khadija (at her lifetime)}}
\hadithdefcmd{bukhari}{3816}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنَا اللَّيْثُ، قَالَ كَتَبَ إِلَىَّ هِشَامٌ عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا غِرْتُ عَلَى امْرَأَةٍ لِلنَّبِيِّ صلى الله عليه وسلم مَا غِرْتُ عَلَى خَدِيجَةَ، هَلَكَتْ قَبْلَ أَنْ يَتَزَوَّجَنِي، لِمَا كُنْتُ أَسْمَعُهُ يَذْكُرُهَا، وَأَمَرَهُ اللَّهُ أَنْ يُبَشِّرَهَا بِبَيْتٍ مِنْ قَصَبٍ، وَإِنْ كَانَ لَيَذْبَحُ الشَّاةَ فَيُهْدِي فِي خَلاَئِلِهَا مِنْهَا مَا يَسَعُهُنَّ‏.‏\hadithno{3816}\hadithtrans{Narrated `Aisha:I did not feel jealous of any of the wives of the Prophet (ﷺ) as much as I did of Khadija (although) she died before he married me, for I often heard him mentioning her, and Allah had told him to give her the good tidings that she would have a palace of Qasab (i.e. pipes of precious stones and pearls in Paradise), and whenever he slaughtered a sheep, he would send her women-friends a good share of it}}
\hadithdefcmd{bukhari}{3817}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا غِرْتُ عَلَى امْرَأَةٍ مَا غِرْتُ عَلَى خَدِيجَةَ، مِنْ كَثْرَةِ ذِكْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِيَّاهَا‏.‏ قَالَتْ وَتَزَوَّجَنِي بَعْدَهَا بِثَلاَثِ سِنِينَ، وَأَمَرَهُ رَبُّهُ عَزَّ وَجَلَّ أَوْ جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ أَنْ يُبَشِّرَهَا بِبَيْتٍ فِي الْجَنَّةِ مِنْ قَصَبٍ‏.‏\hadithno{3817}\hadithtrans{Narrated `Aisha:I did not feel jealous of any woman as much as I did of Khadija because Allah's Messenger (ﷺ) used to mention her very often. He married me after three years of her death, and his Lord (or Gabriel) ordered him to give her the good news of having a palace of Qasab in Paradise}}
\hadithdefcmd{bukhari}{3818}{حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدِ بْنِ حَسَنٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا حَفْصٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا غِرْتُ عَلَى أَحَدٍ مِنْ نِسَاءِ النَّبِيِّ صلى الله عليه وسلم مَا غِرْتُ عَلَى خَدِيجَةَ، وَمَا رَأَيْتُهَا، وَلَكِنْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُكْثِرُ ذِكْرَهَا، وَرُبَّمَا ذَبَحَ الشَّاةَ، ثُمَّ يُقَطِّعُهَا أَعْضَاءً، ثُمَّ يَبْعَثُهَا فِي صَدَائِقِ خَدِيجَةَ، فَرُبَّمَا قُلْتُ لَهُ كَأَنَّهُ لَمْ يَكُنْ فِي الدُّنْيَا امْرَأَةٌ إِلاَّ خَدِيجَةُ‏.‏ فَيَقُولُ إِنَّهَا كَانَتْ وَكَانَتْ، وَكَانَ لِي مِنْهَا وَلَدٌ‏.‏\hadithno{3818}\hadithtrans{Narrated `Aisha:I did not feel jealous of any of the wives of the Prophet (ﷺ) as much as I did of Khadija though I did not see her, but the Prophet (ﷺ) used to mention her very often, and when ever he slaughtered a sheep, he would cut its parts and send them to the women friends of Khadija. When I sometimes said to him, "(You treat Khadija in such a way) as if there is no woman on earth except Khadija," he would say, "Khadija was such-and-such, and from her I had children}}
\hadithdefcmd{bukhari}{3819}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ـ رضى الله عنهما ـ بَشَّرَ النَّبِيُّ صلى الله عليه وسلم خَدِيجَةَ قَالَ نَعَمْ بِبَيْتٍ مِنْ قَصَبٍ، لاَ صَخَبَ فِيهِ وَلاَ نَصَبَ‏.‏\hadithno{3819}\hadithtrans{Narrated Isma`il:I asked `Abdullah bin Abi `Aufa, "Did the Prophet (ﷺ) give glad tidings to Khadija?" He said, "Yes, of a palace of Qasab (in Paradise) where there will be neither any noise nor any fatigue}}
\hadithdefcmd{bukhari}{3820}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَتَى جِبْرِيلُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ هَذِهِ خَدِيجَةُ قَدْ أَتَتْ مَعَهَا إِنَاءٌ فِيهِ إِدَامٌ أَوْ طَعَامٌ أَوْ شَرَابٌ، فَإِذَا هِيَ أَتَتْكَ فَاقْرَأْ عَلَيْهَا السَّلاَمَ مِنْ رَبِّهَا وَمِنِّي، وَبَشِّرْهَا بِبَيْتٍ فِي الْجَنَّةِ مِنْ قَصَبٍ، لاَ صَخَبَ فِيهِ وَلاَ نَصَبَ‏.‏\hadithno{3820}\hadithtrans{Narrated Abu Huraira: Gabriel came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! This is Khadija coming to you with a dish having meat soup (or some food or drink). When she reaches you, greet her on behalf of her Lord (i.e. Allah) and on my behalf, and give her the glad tidings of having a Qasab palace in Paradise wherein there will be neither any noise nor any fatigue (trouble)}}
\hadithdefcmd{bukhari}{3821}{وَقَالَ إِسْمَاعِيلُ بْنُ خَلِيلٍ أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اسْتَأْذَنَتْ هَالَةُ بِنْتُ خُوَيْلِدٍ أُخْتُ خَدِيجَةَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم، فَعَرَفَ اسْتِئْذَانَ خَدِيجَةَ فَارْتَاعَ لِذَلِكَ، فَقَالَ ‏ "‏ اللَّهُمَّ هَالَةَ ‏"‏‏.‏ قَالَتْ فَغِرْتُ فَقُلْتُ مَا تَذْكُرُ مِنْ عَجُوزٍ مِنْ عَجَائِزِ قُرَيْشٍ، حَمْرَاءِ الشِّدْقَيْنِ، هَلَكَتْ فِي الدَّهْرِ، قَدْ، أَبْدَلَكَ اللَّهُ خَيْرًا مِنْهَا\hadithno{3821}\hadithtrans{Narrated 'Aisha:Once Hala bint Khuwailid, Khadija's sister, asked the permission of the Prophet (ﷺ) to enter. On that, the Prophet (ﷺ) remembered the way Khadija used to ask permission, and that upset him. He said, "O Allah! Hala!" So I became jealous and said, "What makes you remember an old woman amongst the old women of Quraish an old woman (with a teethless mouth) of red gums who died long ago, and in whose place Allah has given you somebody better than her?}}
\hadithdefcmd{bukhari}{3822}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، عَنْ بَيَانٍ، عَنْ قَيْسٍ، قَالَ سَمِعْتُهُ يَقُولُ قَالَ جَرِيرُ بْنُ عَبْدِ اللَّهِ ـ رضى الله عنه مَا حَجَبَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مُنْذُ أَسْلَمْتُ، وَلاَ رَآنِي إِلاَّ ضَحِكَ‏.‏\hadithno{3822}\hadithtrans{Narrated Jarir bin 'Abdullah: Allah's Messenger (ﷺ) has never refused to admit me since I embraced Islam, and whenever he saw me, he would smile}}
\hadithdefcmd{bukhari}{3823}{وَعَنْ قَيْسٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ فِي الْجَاهِلِيَّةِ بَيْتٌ يُقَالَ لَهُ ذُو الْخَلَصَةِ، وَكَانَ يُقَالُ لَهُ الْكَعْبَةُ الْيَمَانِيَةُ، أَوِ الْكَعْبَةُ الشَّأْمِيَّةُ، فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَلْ أَنْتَ مُرِيحِي مِنْ ذِي الْخَلَصَةِ ‏"‏‏.‏ قَالَ فَنَفَرْتُ إِلَيْهِ فِي خَمْسِينَ وَمِائَةِ فَارِسٍ مِنْ أَحْمَسَ ـ قَالَ ـ فَكَسَرْنَا، وَقَتَلْنَا مَنْ وَجَدْنَا عِنْدَهُ، فَأَتَيْنَاهُ، فَأَخْبَرْنَاهُ، فَدَعَا لَنَا وَلأَحْمَسَ‏.‏\hadithno{3823}\hadithtrans{Jarir bin 'Abdullah narrated:There was a house called Dhul-Khalasa in the Pre-Islamic Period and it was also called Al-Ka'ba Al-Yamaniya or Al-Ka'ba Ash-Shamiya. Allah's Messenger (ﷺ) said to me, "Will you relieve me from Dhul-Khalasa?" So I left for it with 150 cavalrymen from the tribe of Ahmas and then we destroyed it and killed whoever we found there. Then we came to the Prophet (ﷺ) and informed him about it. He invoked good upon us and upon the tribe of Ahmas}}
\hadithdefcmd{bukhari}{3824}{حَدَّثَنِي إِسْمَاعِيلُ بْنُ خَلِيلٍ، أَخْبَرَنَا سَلَمَةُ بْنُ رَجَاءٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ لَمَّا كَانَ يَوْمُ أُحُدٍ هُزِمَ الْمُشْرِكُونَ هَزِيمَةً بَيِّنَةً، فَصَاحَ إِبْلِيسُ أَىْ عِبَادَ اللَّهِ أُخْرَاكُمْ، فَرَجَعَتْ أُولاَهُمْ عَلَى أُخْرَاهُمْ، فَاجْتَلَدَتْ أُخْرَاهُمْ، فَنَظَرَ حُذَيْفَةُ، فَإِذَا هُوَ بِأَبِيهِ فَنَادَى أَىْ عِبَادَ اللَّهِ، أَبِي أَبِي‏.‏ فَقَالَتْ فَوَاللَّهِ مَا احْتَجَزُوا حَتَّى قَتَلُوهُ، فَقَالَ حُذَيْفَةُ غَفَرَ اللَّهُ لَكُمْ‏.‏ قَالَ أَبِي فَوَاللَّهِ مَا زَالَتْ فِي حُذَيْفَةَ مِنْهَا بَقِيَّةُ خَيْرٍ حَتَّى لَقِيَ اللَّهَ عَزَّ وَجَلَّ‏.‏\hadithno{3824}\hadithtrans{Narrated `Aisha:On the day of the battle of Uhud the pagans were defeated completely. Then Satan shouted loudly, "O Allah's slaves! Beware the ones behind you!" So the front files attacked the back ones. Then Hudhaifa looked and saw his father, and said loudly, "O Allah's slaves! My father! My father!" By Allah, they did not stop till they killed him (i.e. Hudaifa's father). Hudhaifa said, "May Allah forgive you!" The sub-narrator said, "By Allah, because of what Hudhaifa said, he remained in a good state till he met Allah (i.e. died)}}
\hadithdefcmd{bukhari}{3825}{وَقَالَ عَبْدَانُ أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ جَاءَتْ هِنْدٌ بِنْتُ عُتْبَةَ قَالَتْ يَا رَسُولَ اللَّهِ، مَا كَانَ عَلَى ظَهْرِ الأَرْضِ مِنْ أَهْلِ خِبَاءٍ أَحَبُّ إِلَىَّ أَنْ يَذِلُّوا مِنْ أَهْلِ خِبَائِكَ، ثُمَّ مَا أَصْبَحَ الْيَوْمَ عَلَى ظَهْرِ الأَرْضِ أَهْلُ خِبَاءٍ أَحَبَّ إِلَىَّ أَنْ يَعِزُّوا مِنْ أَهْلِ خِبَائِكَ‏.‏ قَالَ وَأَيْضًا وَالَّذِي نَفْسِي بِيَدِهِ، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ مِسِّيكٌ، فَهَلْ عَلَىَّ حَرَجٌ أَنْ أُطْعِمَ مِنَ الَّذِي لَهُ عِيَالَنَا قَالَ ‏ "‏ لاَ أُرَاهُ إِلاَّ بِالْمَعْرُوفِ ‏"‏‏.‏\hadithno{3825}\hadithtrans{Narrated 'Aishah (ra):Hind bint 'Utba came and said, "O Allah's Messenger! (Before I embraced Islam) there was no family on the surface of the earth I wished to see in degradation more than I did your family, but today there is no family on the surface of the earth I wish to see honored more than I did yours." The Prophet (ﷺ) said, "I thought similarly, by Him in whose Hand my soul is!" She further said, "O Allah's Messenger ! Abu Sufyan is a miser, so, is it sinful of me to feed my children from his property ?" He said, "I do not allow it unless you take for your needs what is just and reasonable}}
\hadithdefcmd{bukhari}{3826}{حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى، حَدَّثَنَا سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم لَقِيَ زَيْدَ بْنَ عَمْرِو بْنِ نُفَيْلٍ بِأَسْفَلِ بَلْدَحَ، قَبْلَ أَنْ يَنْزِلَ عَلَى النَّبِيِّ صلى الله عليه وسلم الْوَحْىُ فَقُدِّمَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم سُفْرَةٌ، فَأَبَى أَنْ يَأْكُلَ مِنْهَا ثُمَّ قَالَ زَيْدٌ إِنِّي لَسْتُ آكُلُ مِمَّا تَذْبَحُونَ عَلَى أَنْصَابِكُمْ، وَلاَ آكُلُ إِلاَّ مَا ذُكِرَ اسْمُ اللَّهِ عَلَيْهِ‏.‏ وَأَنَّ زَيْدَ بْنَ عَمْرٍو كَانَ يَعِيبُ عَلَى قُرَيْشٍ ذَبَائِحَهُمْ، وَيَقُولُ الشَّاةُ خَلَقَهَا اللَّهُ، وَأَنْزَلَ لَهَا مِنَ السَّمَاءِ الْمَاءَ، وَأَنْبَتَ لَهَا مِنَ الأَرْضِ، ثُمَّ تَذْبَحُونَهَا عَلَى غَيْرِ اسْمِ اللَّهِ إِنْكَارًا لِذَلِكَ وَإِعْظَامًا لَهُ‏.‏\hadithno{3826}\hadithtrans{Narrated 'Abdullah bin 'Umar: The Prophet (ﷺ) met Zaid bin 'Amr bin Nufail in the bottom of (the valley of) Baldah before any Divine Inspiration came to the Prophet. A meal was presented to the Prophet (ﷺ) but he refused to eat from it. (Then it was presented to Zaid) who said, "I do not eat anything which you slaughter in the name of your stone idols. I eat none but those things on which Allah's Name has been mentioned at the time of slaughtering." Zaid bin 'Amr used to criticize the way Quraish used to slaughter their animals, and used to say, "Allah has created the sheep and He has sent the water for it from the sky, and He has grown the grass for it from the earth; yet you slaughter it in other than the Name of Allah. He used to say so, for he rejected that practice and considered it as something abominable}}
\hadithdefcmd{bukhari}{3827}{قَالَ مُوسَى حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، وَلاَ أَعْلَمُهُ إِلاَّ تُحُدِّثَ بِهِ عَنِ ابْنِ عُمَرَ أَنَّ زَيْدَ بْنَ عَمْرِو بْنِ نُفَيْلٍ خَرَجَ إِلَى الشَّأْمِ، يَسْأَلُ عَنِ الدِّينِ وَيَتْبَعُهُ فَلَقِيَ عَالِمًا مِنَ الْيَهُودِ، فَسَأَلَهُ عَنْ دِينِهِمْ، فَقَالَ إِنِّي لَعَلِّي أَنْ أَدِينَ دِينَكُمْ، فَأَخْبِرْنِي‏.‏ فَقَالَ لاَ تَكُونُ عَلَى دِينِنَا حَتَّى تَأْخُذَ بِنَصِيبِكَ مِنْ غَضَبِ اللَّهِ‏.‏ قَالَ زَيْدٌ مَا أَفِرُّ إِلاَّ مِنْ غَضَبِ اللَّهِ، وَلاَ أَحْمِلُ مِنْ غَضَبِ اللَّهِ شَيْئًا أَبَدًا، وَأَنَّى أَسْتَطِيعُهُ فَهَلْ تَدُلُّنِي عَلَى غَيْرِهِ قَالَ مَا أَعْلَمُهُ إِلاَّ أَنْ يَكُونَ حَنِيفًا‏.‏ قَالَ زَيْدٌ وَمَا الْحَنِيفُ قَالَ دِينُ إِبْرَاهِيمَ لَمْ يَكُنْ يَهُودِيًّا وَلاَ نَصْرَانِيًّا وَلاَ يَعْبُدُ إِلاَّ اللَّهَ‏.‏ فَخَرَجَ زَيْدٌ فَلَقِيَ عَالِمًا مِنَ النَّصَارَى، فَذَكَرَ مِثْلَهُ، فَقَالَ لَنْ تَكُونَ عَلَى دِينِنَا حَتَّى تَأْخُذَ بِنَصِيبِكَ مِنْ لَعْنَةِ اللَّهِ‏.‏ قَالَ مَا أَفِرُّ إِلاَّ مِنْ لَعْنَةِ اللَّهِ، وَلاَ أَحْمِلُ مِنْ لَعْنَةِ اللَّهِ وَلاَ مِنْ غَضَبِهِ شَيْئًا أَبَدًا، وَأَنَّى أَسْتَطِيعُ فَهَلْ تَدُلُّنِي عَلَى غَيْرِهِ قَالَ مَا أَعْلَمُهُ إِلاَّ أَنْ يَكُونَ حَنِيفًا‏.‏ قَالَ وَمَا الْحَنِيفُ قَالَ دِينُ إِبْرَاهِيمَ لَمْ يَكُنْ يَهُودِيًّا وَلاَ نَصْرَانِيًّا وَلاَ يَعْبُدُ إِلاَّ اللَّهَ‏.‏ فَلَمَّا رَأَى زَيْدٌ قَوْلَهُمْ فِي إِبْرَاهِيمَ ـ عَلَيْهِ السَّلاَمُ ـ خَرَجَ، فَلَمَّا بَرَزَ رَفَعَ يَدَيْهِ فَقَالَ اللَّهُمَّ إِنِّي أَشْهَدُ أَنِّي عَلَى دِينِ إِبْرَاهِيمَ‏.‏\hadithno{3827}\hadithtrans{Narrated Ibn 'Umar:Zaid bin 'Amr bin Nufail went to Sham, inquiring about a true religion to follow. He met a Jewish religious scholar and asked him about their religion. He said, "I intend to embrace your religion, so tell me something about it." The Jew said, "You will not embrace our religion unless you receive your share of Allah's Anger." Zaid said, "'I do not run except from Allah's Anger, and I will never bear a bit of it if I have the power to avoid it. Can you tell me of some other religion?" He said, "I do not know any other religion except the Hanif." Zaid enquired, "What is Hanif?" He said, "Hanif is the religion of (the prophet) Abraham who was neither a Jew nor a Christian, and he used to worship None but Allah (Alone)" Then Zaid went out and met a Christian religious scholar and told him the same as before. The Christian said, "You will not embrace our religion unless you get a share of Allah's Curse." Zaid replied, "I do not run except from Allah's Curse, and I will never bear any of Allah's Curse and His Anger if I have the power to avoid them. Will you tell me of some other religion?" He replied, "I do not know any other religion except Hanif." Zaid enquired, "What is Hanif?" He replied, Hanif is the religion of (the prophet) Abraham who was neither a Jew nor a Christian and he used to worship None but Allah (Alone)" When Zaid heard their Statement about (the religion of) Abraham, he left that place, and when he came out, he raised both his hands and said, "O Allah! I make You my Witness that I am on the religion of Abraham}}
\hadithdefcmd{bukhari}{3828}{وَقَالَ اللَّيْثُ كَتَبَ إِلَىَّ هِشَامٌ عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ رَأَيْتُ زَيْدَ بْنَ عَمْرِو بْنِ نُفَيْلٍ قَائِمًا مُسْنِدًا ظَهْرَهُ إِلَى الْكَعْبَةِ يَقُولُ يَا مَعَاشِرَ قُرَيْشٍ، وَاللَّهِ مَا مِنْكُمْ عَلَى دِينِ إِبْرَاهِيمَ غَيْرِي، وَكَانَ يُحْيِي الْمَوْءُودَةَ، يَقُولُ لِلرَّجُلِ إِذَا أَرَادَ أَنْ يَقْتُلَ ابْنَتَهُ لاَ تَقْتُلْهَا، أَنَا أَكْفِيكَهَا مَئُونَتَهَا‏.‏ فَيَأْخُذُهَا فَإِذَا تَرَعْرَعَتْ قَالَ لأَبِيهَا إِنْ شِئْتَ دَفَعْتُهَا إِلَيْكَ، وَإِنْ شِئْتَ كَفَيْتُكَ مَئُونَتَهَا‏.‏\hadithno{3828}\hadithtrans{Narrated Asma bint Abi Bakr:I saw Zaid bin Amr bin Nufail standing with his back against the Ka'ba and saying, "O people of Quraish! By Allah, none amongst you is on the religion of Abraham except me." He used to preserve the lives of little girls: If somebody wanted to kill his daughter he would say to him, "Do not kill her for I will feed her on your behalf." So he would take her, and when she grew up nicely, he would say to her father, "Now if you want her, I will give her to you, and if you wish, I will feed her on your behalf}}
\hadithdefcmd{bukhari}{3829}{حَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ لَمَّا بُنِيَتِ الْكَعْبَةُ ذَهَبَ النَّبِيُّ صلى الله عليه وسلم وَعَبَّاسٌ يَنْقُلاَنِ الْحِجَارَةَ، فَقَالَ عَبَّاسٌ لِلنَّبِيِّ صلى الله عليه وسلم اجْعَلْ إِزَارَكَ عَلَى رَقَبَتِكَ يَقِيكَ مِنَ الْحِجَارَةِ، فَخَرَّ إِلَى الأَرْضِ، وَطَمَحَتْ عَيْنَاهُ إِلَى السَّمَاءِ ثُمَّ أَفَاقَ فَقَالَ ‏ "‏ إِزَارِي إِزَارِي ‏"‏‏.‏ فَشَدَّ عَلَيْهِ إِزَارَهُ‏.‏\hadithno{3829}\hadithtrans{Narrated Jabir bin `Abdullah:When the Ka`ba was rebuilt, the Prophet (ﷺ) and `Abbas went to carry stones. `Abbas said to the Prophet (ﷺ) "(Take off and) put your waist sheet over your neck so that the stones may not hurt you." (But as soon as he took off his waist sheet) he fell unconscious on the ground with both his eyes towards the sky. When he came to his senses, he said, "My waist sheet! My waist sheet!" Then he tied his waist sheet (round his waist)}}
\hadithdefcmd{bukhari}{3830}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، وَعُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، قَالاَ لَمْ يَكُنْ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم حَوْلَ الْبَيْتِ حَائِطٌ، كَانُوا يُصَلُّونَ حَوْلَ الْبَيْتِ، حَتَّى كَانَ عُمَرُ، فَبَنَى حَوْلَهُ حَائِطًا ـ قَالَ عُبَيْدُ اللَّهِ ـ جَدْرُهُ قَصِيرٌ، فَبَنَاهُ ابْنُ الزُّبَيْرِ‏.‏\hadithno{3830}\hadithtrans{Narrated `Amr bin Dinar and 'Ubaidullah bin Abi Yazid:In the lifetime of the Prophet (ﷺ) there was no wall around the Ka`ba and the people used to pray around the Ka`ba till `Umar became the Caliph and he built the wall around it. 'Ubaidullah further said, "Its wall was low, so Ibn Az-Zubair built it}}
\hadithdefcmd{bukhari}{3831}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، قَالَ هِشَامٌ حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ عَاشُورَاءُ يَوْمًا تَصُومُهُ قُرَيْشٌ فِي الْجَاهِلِيَّةِ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم يَصُومُهُ، فَلَمَّا قَدِمَ الْمَدِينَةَ صَامَهُ وَأَمَرَ بِصِيَامِهِ، فَلَمَّا نَزَلَ رَمَضَانُ كَانَ مَنْ شَاءَ صَامَهُ، وَمَنْ شَاءَ لاَ يَصُومُهُ‏.‏\hadithno{3831}\hadithtrans{Narrated `Aisha:'Ashura' (i.e. the tenth of Muharram) was a day on which the tribe of Quraish used to fast in the pre-Islamic period of ignorance. The Prophet (ﷺ) also used to fast on this day. So when he migrated to Medina, he fasted on it and ordered (the Muslims) to fast on it. When the fasting of Ramadan was enjoined, it became optional for the people to fast or not to fast on the day of Ashura}}
\hadithdefcmd{bukhari}{3832}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانُوا يَرَوْنَ أَنَّ الْعُمْرَةَ فِي أَشْهُرِ الْحَجِّ مِنَ الْفُجُورِ فِي الأَرْضِ، وَكَانُوا يُسَمُّونَ الْمُحَرَّمَ صَفَرًا وَيَقُولُونَ إِذَا بَرَا الدَّبَرْ، وَعَفَا الأَثَرْ، حَلَّتِ الْعُمْرَةُ لِمَنِ اعْتَمَرْ‏.‏ قَالَ فَقَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ رَابِعَةً مُهِلِّينَ بِالْحَجِّ وَأَمَرَهُمُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَجْعَلُوهَا عُمْرَةً‏.‏ قَالُوا يَا رَسُولَ اللَّهِ، أَىُّ الْحِلِّ قَالَ ‏ "‏ الْحِلُّ كُلُّهُ ‏"‏‏.‏\hadithno{3832}\hadithtrans{Narrated Ibn `Abbas:The people used to consider the performance of `Umra in the months of Hajj an evil deed on the earth, and they used to call the month of Muharram as Safar and used to say, "When (the wounds over) the backs (of the camels) have healed and the foot-marks (of the camels) have vanished (after coming from Hajj), then `Umra becomes legal for the one who wants to perform `Umra." Allah's Messenger (ﷺ) and his companions reached Mecca assuming Ihram for Hajj on the fourth of Dhul-Hijja. The Prophet (ﷺ) ordered his companions to perform `Umra (with that Ihram instead of Hajj). They asked, "O Allah's Apostle! What kind of finishing of Ihram?" The Prophet (ﷺ) said, "Finish the Ihram completely}}
\hadithdefcmd{bukhari}{3833}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ كَانَ عَمْرٌو يَقُولُ حَدَّثَنَا سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ سَيْلٌ فِي الْجَاهِلِيَّةِ فَكَسَا مَا بَيْنَ الْجَبَلَيْنِ‏.‏ قَالَ سُفْيَانُ وَيَقُولُ إِنَّ هَذَا لَحَدِيثٌ لَهُ شَأْنٌ‏.‏\hadithno{3833}\hadithtrans{Narrated Sa`id bin Al-Musaiyab's grand-father:In the pre-Islamic period of ignorance a flood of rain came and filled the valley in between the two mountains (around the Ka`ba)}}
\hadithdefcmd{bukhari}{3834}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ بَيَانٍ أَبِي بِشْرٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، قَالَ دَخَلَ أَبُو بَكْرٍ عَلَى امْرَأَةٍ مِنْ أَحْمَسَ يُقَالُ لَهَا زَيْنَبُ، فَرَآهَا لاَ تَكَلَّمُ، فَقَالَ مَا لَهَا لاَ تَكَلَّمُ قَالُوا حَجَّتْ مُصْمِتَةً‏.‏ قَالَ لَهَا تَكَلَّمِي، فَإِنَّ هَذَا لاَ يَحِلُّ، هَذَا مِنْ عَمَلِ الْجَاهِلِيَّةِ‏.‏ فَتَكَلَّمَتْ، فَقَالَتْ مَنْ أَنْتَ قَالَ امْرُؤٌ مِنَ الْمُهَاجِرِينَ‏.‏ قَالَتْ أَىُّ الْمُهَاجِرِينَ قَالَ مِنْ قُرَيْشٍ‏.‏ قَالَتْ مِنْ أَىِّ قُرَيْشٍ أَنْتَ قَالَ إِنَّكِ لَسَئُولٌ أَنَا أَبُو بَكْرٍ‏.‏ قَالَتْ مَا بَقَاؤُنَا عَلَى هَذَا الأَمْرِ الصَّالِحِ الَّذِي جَاءَ اللَّهُ بِهِ بَعْدَ الْجَاهِلِيَّةِ قَالَ بَقَاؤُكُمْ عَلَيْهِ مَا اسْتَقَامَتْ بِكُمْ أَئِمَّتُكُمْ‏.‏ قَالَتْ وَمَا الأَئِمَّةُ قَالَ أَمَا كَانَ لِقَوْمِكِ رُءُوسٌ وَأَشْرَافٌ يَأْمُرُونَهُمْ فَيُطِيعُونَهُمْ قَالَتْ بَلَى‏.‏ قَالَ فَهُمْ أُولَئِكَ عَلَى النَّاسِ‏.‏\hadithno{3834}\hadithtrans{Narrated Qais bin Abi Hazim:Abu Bakr went to a lady from the Ahmas tribe called Zainab bint Al-Muhajir and found that she refused to speak. He asked, "Why does she not speak." The people said, "She has intended to perform Hajj without speaking." He said to her, "Speak, for it is illegal not to speak, as it is an action of the pre-islamic period of ignorance. So she spoke and said, "Who are you?" He said, "A man from the Emigrants." She asked, "Which Emigrants?" He replied, "From Quraish." She asked, "From what branch of Quraish are you?" He said, "You ask too many questions; I am Abu Bakr." She said, "How long shall we enjoy this good order (i.e. Islamic religion) which Allah has brought after the period of ignorance?" He said, "You will enjoy it as long as your Imams keep on abiding by its rules and regulations." She asked, "What are the Imams?" He said, "Were there not heads and chiefs of your nation who used to order the people and they used to obey them?" She said, "Yes." He said, "So they (i.e. the Imams) are those whom I meant}}
\hadithdefcmd{bukhari}{3835}{حَدَّثَنِي فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَسْلَمَتِ امْرَأَةٌ سَوْدَاءُ لِبَعْضِ الْعَرَبِ، وَكَانَ لَهَا حِفْشٌ فِي الْمَسْجِدِ قَالَتْ فَكَانَتْ تَأْتِينَا فَتَحَدَّثُ عِنْدَنَا فَإِذَا فَرَغَتْ مِنْ حَدِيثِهَا قَالَتْ وَيَوْمُ الْوِشَاحِ مِنْ تَعَاجِيبِ رَبِّنَا أَلاَ إِنَّهُ مِنْ بَلْدَةِ الْكُفْرِ أَنْجَانِي فَلَمَّا أَكْثَرَتْ قَالَتْ لَهَا عَائِشَةُ وَمَا يَوْمُ الْوِشَاحِ قَالَتْ خَرَجَتْ جُوَيْرِيَةٌ لِبَعْضِ أَهْلِي، وَعَلَيْهَا وِشَاحٌ مِنْ أَدَمٍ فَسَقَطَ مِنْهَا، فَانْحَطَّتْ عَلَيْهِ الْحُدَيَّا وَهْىَ تَحْسِبُهُ لَحْمًا، فَأَخَذَتْ فَاتَّهَمُونِي بِهِ فَعَذَّبُونِي، حَتَّى بَلَغَ مِنْ أَمْرِي أَنَّهُمْ طَلَبُوا فِي قُبُلِي، فَبَيْنَا هُمْ حَوْلِي وَأَنَا فِي كَرْبِي إِذْ أَقْبَلَتِ الْحُدَيَّا حَتَّى وَازَتْ بِرُءُوسِنَا ثُمَّ أَلْقَتْهُ، فَأَخَذُوهُ فَقُلْتُ لَهُمْ هَذَا الَّذِي اتَّهَمْتُمُونِي بِهِ وَأَنَا مِنْهُ بَرِيئَةٌ‏.‏\hadithno{3835}\hadithtrans{Narrated `Aisha:A black lady slave of some of the 'Arabs embraced Islam and she had a hut in the mosque. She used to visit us and talk to us, and when she finished her talk, she used to say: "The day of the scarf was one of our Lord's wonders: Verily! He has delivered me from the land of Kufr." When she said the above verse many times, I (i.e. `Aisha) asked her, "What was the day of the scarf?" She replied, "Once the daughter of some of my masters went out and she was wearing a leather scarf (round her neck) and the leather scarf fell from her and a kite descended and picked it up, mistaking it for a piece of meat. They (i.e. my masters) accused me of stealing it and they tortured me to such an extent that they even looked for it in my private parts. So, while they all were around me, and I was in my great distress, suddenly the kite came over our heads and threw the scarf, and they took it. I said to them 'This is what you accused me of stealing, though I was innocent}}
\hadithdefcmd{bukhari}{3836}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَلاَ مَنْ كَانَ حَالِفًا فَلاَ يَحْلِفْ إِلاَّ بِاللَّهِ ‏"‏‏.‏ فَكَانَتْ قُرَيْشٌ تَحْلِفُ بِآبَائِهَا، فَقَالَ ‏"‏ لاَ تَحْلِفُوا بِآبَائِكُمْ ‏"‏‏.‏\hadithno{3836}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "If anybody has to take an oath, he should swear only by Allah." The people of Quraish used to swear by their fathers, but the Prophet (ﷺ) said, "Do not swear by your fathers}}
\hadithdefcmd{bukhari}{3837}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، حَدَّثَهُ أَنَّ الْقَاسِمَ كَانَ يَمْشِي بَيْنَ يَدَىِ الْجَنَازَةِ وَلاَ يَقُومُ لَهَا، وَيُخْبِرُ عَنْ عَائِشَةَ قَالَتْ كَانَ أَهْلُ الْجَاهِلِيَّةِ يَقُومُونَ لَهَا، يَقُولُونَ إِذَا رَأَوْهَا كُنْتِ فِي أَهْلِكِ مَا أَنْتِ‏.‏ مَرَّتَيْنِ‏.‏\hadithno{3837}\hadithtrans{Narrated `Abdur-Rahman bin Al-Qasim:Al-Qasim used to walk in front of the funeral procession. He used not to get up for the funeral procession (in case it passed by him). And he narrated from `Aisha that she said, "The people of the pre-Islamic period of ignorance used to stand up for the funeral procession. When they saw it they used to say twice: 'You were noble in your family. What are you now?}}
\hadithdefcmd{bukhari}{3838}{حَدَّثَنِي عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ قَالَ عُمَرُ ـ رضى الله عنه ـ إِنَّ الْمُشْرِكِينَ كَانُوا لاَ يُفِيضُونَ مِنْ جَمْعٍ حَتَّى تَشْرُقَ الشَّمْسُ عَلَى ثَبِيرٍ، فَخَالَفَهُمُ النَّبِيُّ صلى الله عليه وسلم فَأَفَاضَ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ‏.‏\hadithno{3838}\hadithtrans{Narrated `Umar:The pagans used not to leave Jam' (i.e. Muzdalifa) till the sun had risen on Thabir mountain. The Prophet contradicted them by leaving (Muzdalifa) before the sun rose}}
\hadithdefcmd{bukhari}{3839}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ قُلْتُ لأَبِي أُسَامَةَ حَدَّثَكُمْ يَحْيَى بْنُ الْمُهَلَّبِ، حَدَّثَنَا حُصَيْنٌ، عَنْ عِكْرِمَةَ، ‏\{‏وَكَأْسًا دِهَاقًا‏\}‏ قَالَ مَلأَى مُتَتَابِعَةً‏.‏\hadithno{3839}\hadithtrans{Narrated Husain:That `Ikrima said, "Kasan Dihaqa means glass full (of something) followed successively with other full glasses}}
\hadithdefcmd{bukhari}{3840}{قَالَ وَقَالَ ابْنُ عَبَّاسٍ سَمِعْتُ أَبِي يَقُولُ، فِي الْجَاهِلِيَّةِ اسْقِنَا كَأْسًا دِهَاقًا‏.‏\hadithno{3840}\hadithtrans{Ibn `Abbas said:"In the pre-Islamic period of ignorance I heard my father saying, "Provide us with Kasan Dihaqa}}
\hadithdefcmd{bukhari}{3841}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَصْدَقُ كَلِمَةٍ قَالَهَا الشَّاعِرُ كَلِمَةُ لَبِيدٍ أَلاَ كُلُّ شَىْءٍ مَا خَلاَ اللَّهَ بَاطِلٌ وَكَادَ أُمَيَّةُ بْنُ أَبِي الصَّلْتِ أَنْ يُسْلِمَ ‏"‏‏.‏\hadithno{3841}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The most true words said by a poet was the words of Labid." He said, Verily, Everything except Allah is perishable and Umaiya bin As-Salt was about to be a Muslim (but he did not embrace Islam)}}
\hadithdefcmd{bukhari}{3842}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ لأَبِي بَكْرٍ غُلاَمٌ يُخْرِجُ لَهُ الْخَرَاجَ، وَكَانَ أَبُو بَكْرٍ يَأْكُلُ مِنْ خَرَاجِهِ، فَجَاءَ يَوْمًا بِشَىْءٍ فَأَكَلَ مِنْهُ أَبُو بَكْرٍ فَقَالَ لَهُ الْغُلاَمُ تَدْرِي مَا هَذَا فَقَالَ أَبُو بَكْرٍ وَمَا هُوَ قَالَ كُنْتُ تَكَهَّنْتُ لإِنْسَانٍ فِي الْجَاهِلِيَّةِ وَمَا أُحْسِنُ الْكِهَانَةَ، إِلاَّ أَنِّي خَدَعْتُهُ، فَلَقِيَنِي فَأَعْطَانِي بِذَلِكَ، فَهَذَا الَّذِي أَكَلْتَ مِنْهُ‏.‏ فَأَدْخَلَ أَبُو بَكْرٍ يَدَهُ فَقَاءَ كُلَّ شَىْءٍ فِي بَطْنِهِ‏.‏\hadithno{3842}\hadithtrans{Narrated `Aisha:Abu Bakr had a slave who used to give him some of his earnings. Abu Bakr used to eat from it. One day he brought something and Abu Bakr ate from it. The slave said to him, "Do you know what this is?" Abu Bakr then enquired, "What is it?" The slave said, "Once, in the pre-Islamic period of ignorance I foretold somebody's future though I did not know this knowledge of foretelling but I, cheated him, and when he met me, he gave me something for that service, and that is what you have eaten from." Then Abu Bakr put his hand in his mouth and vomited whatever was present in his stomach}}
\hadithdefcmd{bukhari}{3843}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ أَهْلُ الْجَاهِلِيَّةِ يَتَبَايَعُونَ لُحُومَ الْجَزُورِ إِلَى حَبَلِ الْحَبَلَةِ، قَالَ وَحَبَلُ الْحَبَلَةِ أَنْ تُنْتَجَ النَّاقَةُ مَا فِي بَطْنِهَا، ثُمَّ تَحْمِلَ الَّتِي نُتِجَتْ، فَنَهَاهُمُ النَّبِيُّ صلى الله عليه وسلم عَنْ ذَلِكَ‏.‏\hadithno{3843}\hadithtrans{Narrated Ibn `Umar:In the pre-Islamic period of ignorance the people used to bargain with the meat of camels on the principle of Habal-al-Habala which meant the sale of a she-camel that would be born by a she-camel that had not yet been born. The Prophet (ﷺ) forbade them such a transaction}}
\hadithdefcmd{bukhari}{3844}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا مَهْدِيٌّ، قَالَ غَيْلاَنُ بْنُ جَرِيرٍ كُنَّا نَأْتِي أَنَسَ بْنَ مَالِكٍ فَيُحَدِّثُنَا عَنِ الأَنْصَارِ،، وَكَانَ، يَقُولُ لِي فَعَلَ قَوْمُكَ كَذَا وَكَذَا يَوْمَ كَذَا وَكَذَا، وَفَعَلَ قَوْمُكَ كَذَا وَكَذَا يَوْمَ كَذَا وَكَذَا‏.‏\hadithno{3844}\hadithtrans{Narrated Ghailan bin Jarir:We used to visit Anas bin Malik and he used to talk to us about the Ansar, and used to say to me: "Your people did so-and-so on such-and-such a day, and your people did so-and-so on such-and-such a day}}
\hadithdefcmd{bukhari}{3845}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا قَطَنٌ أَبُو الْهَيْثَمِ، حَدَّثَنَا أَبُو يَزِيدَ الْمَدَنِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ إِنَّ أَوَّلَ قَسَامَةٍ كَانَتْ فِي الْجَاهِلِيَّةِ لَفِينَا بَنِي هَاشِمٍ، كَانَ رَجُلٌ مِنْ بَنِي هَاشِمٍ اسْتَأْجَرَهُ رَجُلٌ مِنْ قُرَيْشٍ مِنْ فَخِذٍ أُخْرَى، فَانْطَلَقَ مَعَهُ فِي إِبِلِهِ، فَمَرَّ رَجُلٌ بِهِ مِنْ بَنِي هَاشِمٍ قَدِ انْقَطَعَتْ عُرْوَةُ جُوَالِقِهِ فَقَالَ أَغِثْنِي بِعِقَالٍ أَشُدُّ بِهِ عُرْوَةَ جُوَالِقِي، لاَ تَنْفِرُ الإِبِلُ‏.‏ فَأَعْطَاهُ عِقَالاً، فَشَدَّ بِهِ عُرْوَةَ جُوَالِقِهِ، فَلَمَّا نَزَلُوا عُقِلَتِ الإِبِلُ إِلاَّ بَعِيرًا وَاحِدًا، فَقَالَ الَّذِي اسْتَأْجَرَهُ مَا شَأْنُ هَذَا الْبَعِيرِ لَمْ يُعْقَلْ مِنْ بَيْنِ الإِبِلِ قَالَ لَيْسَ لَهُ عِقَالٌ‏.‏ قَالَ فَأَيْنَ عِقَالُهُ قَالَ فَحَذَفَهُ بِعَصًا كَانَ فِيهَا أَجَلُهُ، فَمَرَّ بِهِ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ، فَقَالَ أَتَشْهَدُ الْمَوْسِمَ قَالَ مَا أَشْهَدُ، وَرُبَّمَا شَهِدْتُهُ‏.‏ قَالَ هَلْ أَنْتَ مُبْلِغٌ عَنِّي رِسَالَةً مَرَّةً مِنَ الدَّهْرِ قَالَ نَعَمْ‏.‏ قَالَ فَكُنْتَ إِذَا أَنْتَ شَهِدْتَ الْمَوْسِمَ فَنَادِ يَا آلَ قُرَيْشٍ‏.‏ فَإِذَا أَجَابُوكَ، فَنَادِ يَا آلَ بَنِي هَاشِمٍ‏.‏ فَإِنْ أَجَابُوكَ فَسَلْ عَنْ أَبِي طَالِبٍ، فَأَخْبِرْهُ أَنَّ فُلاَنًا قَتَلَنِي فِي عِقَالٍ، وَمَاتَ الْمُسْتَأْجَرُ، فَلَمَّا قَدِمَ الَّذِي اسْتَأْجَرَهُ أَتَاهُ أَبُو طَالِبٍ فَقَالَ مَا فَعَلَ صَاحِبُنَا قَالَ مَرِضَ، فَأَحْسَنْتُ الْقِيَامَ عَلَيْهِ، فَوَلِيتُ دَفْنَهُ‏.‏ قَالَ قَدْ كَانَ أَهْلَ ذَاكَ مِنْكَ‏.‏ فَمَكُثَ حِينًا، ثُمَّ إِنَّ الرَّجُلَ الَّذِي أَوْصَى إِلَيْهِ أَنْ يُبْلِغَ عَنْهُ وَافَى الْمَوْسِمَ فَقَالَ يَا آلَ قُرَيْشٍ‏.‏ قَالُوا هَذِهِ قُرَيْشٌ‏.‏ قَالَ يَا آلَ بَنِي هَاشِمٍ‏.‏ قَالُوا هَذِهِ بَنُو هَاشِمٍ‏.‏ قَالَ أَيْنَ أَبُو طَالِبٍ قَالُوا هَذَا أَبُو طَالِبٍ‏.‏ قَالَ أَمَرَنِي فُلاَنٌ أَنْ أُبْلِغَكَ رِسَالَةً أَنَّ فُلاَنًا قَتَلَهُ فِي عِقَالٍ‏.‏ فَأَتَاهُ أَبُو طَالِبٍ فَقَالَ لَهُ اخْتَرْ مِنَّا إِحْدَى ثَلاَثٍ، إِنْ شِئْتَ أَنْ تُؤَدِّيَ مِائَةً مِنَ الإِبِلِ، فَإِنَّكَ قَتَلْتَ صَاحِبَنَا، وَإِنْ شِئْتَ حَلَفَ خَمْسُونَ مِنْ قَوْمِكَ أَنَّكَ لَمْ تَقْتُلْهُ، فَإِنْ أَبَيْتَ قَتَلْنَاكَ بِهِ فَأَتَى قَوْمَهُ، فَقَالُوا نَحْلِفُ‏.‏ فَأَتَتْهُ امْرَأَةٌ مِنْ بَنِي هَاشِمٍ كَانَتْ تَحْتَ رَجُلٍ مِنْهُمْ قَدْ وَلَدَتْ لَهُ‏.‏ فَقَالَتْ يَا أَبَا طَالِبٍ أُحِبُّ أَنْ تُجِيزَ ابْنِي هَذَا بِرَجُلٍ مِنَ الْخَمْسِينَ وَلاَ تَصْبُرْ يَمِينَهُ حَيْثُ تُصْبَرُ الأَيْمَانُ‏.‏ فَفَعَلَ فَأَتَاهُ رَجُلٌ مِنْهُمْ فَقَالَ يَا أَبَا طَالِبٍ، أَرَدْتَ خَمْسِينَ رَجُلاً أَنْ يَحْلِفُوا مَكَانَ مِائَةٍ مِنَ الإِبِلِ، يُصِيبُ كُلَّ رَجُلٍ بَعِيرَانِ، هَذَانِ بَعِيرَانِ فَاقْبَلْهُمَا عَنِّي وَلاَ تَصْبُرْ يَمِينِي حَيْثُ تُصْبِرُ الأَيْمَانُ‏.‏ فَقَبِلَهُمَا، وَجَاءَ ثَمَانِيةٌ وَأَرْبَعُونَ فَحَلَفُوا‏.‏ قَالَ ابْنُ عَبَّاسٍ فَوَالَّذِي نَفْسِي بِيَدِهِ، مَا حَالَ الْحَوْلُ وَمِنَ الثَّمَانِيَةِ وَأَرْبَعِينَ عَيْنٌ تَطْرِفُ‏.‏\hadithno{3845}\hadithtrans{Narrated Ibn `Abbas:The first event of Qasama in the pre-Islamic period of ignorance was practiced by us (i.e. Banu Hashim). A man from Banu Hashim was employed by a Quraishi man from another branch-family. The (Hashimi) laborer set out with the Quraishi driving his camels. There passed by him another man from Banu Hashim. The leather rope of the latter's bag had broken so he said to the laborer, "Will you help me by giving me a rope in order to tie the handle of my bag lest the camels should run away from me?" The laborer gave him a rope and the latter tied his bag with it. When the caravan halted, all the camels' legs were tied with their fetters except one camel. The employer asked the laborer, "Why, from among all the camels has this camel not been fettered?" He replied, "There is no fetter for it." The Quraishi asked, "Where is its fetter?" and hit the laborer with a stick that caused his death (later on Just before his death) a man from Yemen passed by him. The laborer asked (him), "Will you go for the pilgrimage?" He replied, "I do not think I will attend it, but perhaps I will attend it." The (Hashimi) laborer said, "Will you please convey a message for me once in your life?" The other man said, "yes." The laborer wrote: 'When you attend the pilgrimage, call the family of Quraish, and if they respond to you, call the family of Banu Hashim, and if they respond to you, ask about Abu Talib and tell him that so-and-so has killed me for a fetter." Then the laborer expired. When the employer reached (Mecca), Abu Talib visited him and asked, "What has happened to our companion?" He said, "He became ill and I looked after him nicely (but he died) and I buried him." Then Abu Talib said, "The deceased deserved this from you." After some time, the messenger whom the laborer had asked to convey the message, reached during the pilgrimage season. He called, "O the family of Quraish!" The people replied, "This is Quraish." Then he called, "O the family of Banu Hashim!" Again the people replied, "This is Banu Hashim." He asked, "Who is Abu Talib?" The people replied, "This is Abu Talib." He said, "'So-and-so has asked me to convey a message to you that so-and-so has killed him for a fetter (of a camel)." Then Abu Talib went to the (Quraishi) killer and said to him, "Choose one of three alternatives: (i) If you wish, give us one-hundred camels because you have murdered our companion, (ii) or if you wish, fifty of your men should take an oath that you have not murdered our companion, and if you do not accept this, (iii) we will kill you in Qisas." The killer went to his people and they said, "We will take an oath." Then a woman from Banu Hashim who was married to one of them (i.e.the Quraishis) and had given birth to a child from him, came to Abu Talib and said, "O Abu Talib! I wish that my son from among the fifty men, should be excused from this oath, and that he should not take the oath where the oathtaking is carried on." Abu Talib excused him. Then another man from them came (to Abu Talib) and said, "O Abu Talib! You want fifty persons to take an oath instead of giving a hundred camels, and that means each man has to give two camels (in case he does not take an oath). So there are two camels I would like you to accept from me and excuse me from taking an oath when the oaths are taken. Abu Talib accepted them from him. Then 48 men came and took the oath. Ibn `Abbas further said: By Him in Whose Hand my life is, before the end of that year, none of those 48 persons remained alive}}
\hadithdefcmd{bukhari}{3846}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ يَوْمُ بُعَاثٍ يَوْمًا قَدَّمَهُ اللَّهُ لِرَسُولِهِ صلى الله عليه وسلم، فَقَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدِ افْتَرَقَ مَلَؤُهُمْ، وَقُتِّلَتْ سَرَوَاتُهُمْ وَجُرِّحُوا، قَدَّمَهُ اللَّهُ لِرَسُولِهِ صلى الله عليه وسلم فِي دُخُولِهِمْ فِي الإِسْلاَمِ‏.‏\hadithno{3846}\hadithtrans{Narrated 'Aisha: Allah caused the day of Buath to take place before Allah's Messenger (ﷺ) was sent (as an Apostle) so that when Allah's Messenger (ﷺ) reached Medina, those people had already divided (in different groups) and their chiefs had been killed or wounded. So Allah made that day precede Allah's Messenger (ﷺ) so that they (i.e. the Ansar) might embrace Islam}}
\hadithdefcmd{bukhari}{3847}{وَقَالَ ابْنُ وَهْبٍ أَخْبَرَنَا عَمْرٌو، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، أَنَّ كُرَيْبًا، مَوْلَى ابْنِ عَبَّاسٍ حَدَّثَهُ أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَيْسَ السَّعْىُ بِبَطْنِ الْوَادِي بَيْنَ الصَّفَا وَالْمَرْوَةِ سُنَّةً، إِنَّمَا كَانَ أَهْلُ الْجَاهِلِيَّةِ يَسْعَوْنَهَا وَيَقُولُونَ لاَ نُجِيزُ الْبَطْحَاءَ إِلاَّ شَدًّا\hadithno{3847}\hadithtrans{Narrated Ibn 'Abbas:To run along the valley between two green pillars of Safa and Marwa (mountains) was not Sunna, but the people in the pre-islamic period of ignorance used to run along it, and used to say: "We do not cross this rain stream except running strongly}}
\hadithdefcmd{bukhari}{3848}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْجُعْفِيُّ، حَدَّثَنَا سُفْيَانُ، أَخْبَرَنَا مُطَرِّفٌ، سَمِعْتُ أَبَا السَّفَرِ، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ يَا أَيُّهَا النَّاسُ، اسْمَعُوا مِنِّي مَا أَقُولُ لَكُمْ، وَأَسْمِعُونِي مَا تَقُولُونَ، وَلاَ تَذْهَبُوا فَتَقُولُوا قَالَ ابْنُ عَبَّاسٍ، قَالَ ابْنُ عَبَّاسٍ مَنْ طَافَ بِالْبَيْتِ فَلْيَطُفْ مِنْ وَرَاءِ الْحِجْرِ، وَلاَ تَقُولُوا الْحَطِيمُ، فَإِنَّ الرَّجُلَ فِي الْجَاهِلِيَّةِ كَانَ يَحْلِفُ فَيُلْقِي سَوْطَهُ أَوْ نَعْلَهُ أَوْ قَوْسَهُ‏.‏\hadithno{3848}\hadithtrans{Narrated Abu As-Safar:I heard Ibn `Abbas saying, "O people! Listen to what I say to you, and let me hear whatever you say, and don't go (without understanding), and start saying, 'Ibn `Abbas said so-and-so, Ibn `Abbas said so-and-so, Ibn `Abbas said so-and-so.' He who wants to perform the Tawaf around the Ka`ba should go behind Al-Hijr (i.e. a portion of the Ka`ba left out unroofed) and do not call it Al-Hatim, for in the pre-Islamic period of ignorance if any man took an oath, he used to throw his whip, shoes or bow in it}}
\hadithdefcmd{bukhari}{3849}{حَدَّثَنَا نُعَيْمُ بْنُ حَمَّادٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ حُصَيْنٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ رَأَيْتُ فِي الْجَاهِلِيَّةِ قِرْدَةً اجْتَمَعَ عَلَيْهَا قِرَدَةٌ قَدْ زَنَتْ، فَرَجَمُوهَا فَرَجَمْتُهَا مَعَهُمْ‏.‏\hadithno{3849}\hadithtrans{Narrated `Amr bin Maimun:During the pre-Islamic period of ignorance I saw a she-monkey surrounded by a number of monkeys. They were all stoning it, because it had committed illegal sexual intercourse. I too, stoned it along with them}}
\hadithdefcmd{bukhari}{3850}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خِلاَلٌ مِنْ خِلاَلِ الْجَاهِلِيَّةِ الطَّعْنُ فِي الأَنْسَابِ وَالنِّيَاحَةُ، وَنَسِيَ الثَّالِثَةَ، قَالَ سُفْيَانُ وَيَقُولُونَ إِنَّهَا الاِسْتِسْقَاءُ بِالأَنْوَاءِ‏.‏\hadithno{3850}\hadithtrans{Narrated Sufyan:'Ubaidullah said: "I heard Ibn `Abbas saying, "Following are some traits of the people of the pre- Islamic period of ignorance (i) to defame the ancestry of other families, (ii) and to wail over the dead." 'Ubaidullah forgot the third trait. Sufyan said, "They say it (i.e. the third trait) was to believe that rain was caused by the influence of stars (i.e. if a special star appears it will rain)}}
\hadithdefcmd{bukhari}{3851}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا النَّضْرُ، عَنْ هِشَامٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أُنْزِلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ ابْنُ أَرْبَعِينَ، فَمَكَثَ ثَلاَثَ عَشْرَةَ سَنَةً، ثُمَّ أُمِرَ بِالْهِجْرَةِ، فَهَاجَرَ إِلَى الْمَدِينَةِ، فَمَكَثَ بِهَا عَشْرَ سِنِينَ، ثُمَّ تُوُفِّيَ صلى الله عليه وسلم‏.‏\hadithno{3851}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) was inspired Divinely at the age of forty. Then he stayed in Mecca for thirteen years, and then was ordered to migrate, and he migrated to Medina and stayed there for ten years and then died}}
\hadithdefcmd{bukhari}{3852}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا بَيَانٌ، وَإِسْمَاعِيلُ، قَالاَ سَمِعْنَا قَيْسًا، يَقُولُ سَمِعْتُ خَبَّابًا، يَقُولُ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهْوَ مُتَوَسِّدٌ بُرْدَةً، وَهْوَ فِي ظِلِّ الْكَعْبَةِ، وَقَدْ لَقِينَا مِنَ الْمُشْرِكِينَ شِدَّةً فَقُلْتُ أَلاَ تَدْعُو اللَّهَ فَقَعَدَ وَهْوَ مُحْمَرٌّ وَجْهُهُ فَقَالَ ‏ "‏ لَقَدْ كَانَ مَنْ قَبْلَكُمْ لَيُمْشَطُ بِمِشَاطِ الْحَدِيدِ مَا دُونَ عِظَامِهِ مِنْ لَحْمٍ أَوْ عَصَبٍ مَا يَصْرِفُهُ ذَلِكَ عَنْ دِينِهِ، وَيُوضَعُ الْمِنْشَارُ عَلَى مَفْرِقِ رَأْسِهِ، فَيُشَقُّ بِاثْنَيْنِ، مَا يَصْرِفُهُ ذَلِكَ عَنْ دِينِهِ، وَلَيُتِمَّنَّ اللَّهُ هَذَا الأَمْرَ حَتَّى يَسِيرَ الرَّاكِبُ مِنْ صَنْعَاءَ إِلَى حَضْرَمَوْتَ مَا يَخَافُ إِلاَّ اللَّهَ ‏"‏‏.‏ زَادَ بَيَانٌ وَالذِّئْبَ عَلَى غَنَمِهِ‏.‏\hadithno{3852}\hadithtrans{Narrated Khabbab:I came to the Prophet (ﷺ) while he was leaning against his sheet cloak in the shade of the Ka`ba. We were suffering greatly from the pagans in those days. I said (to him), "Will you invoke Allah (to help us)?" He sat down with a red face and said, "(A believer among) those who were before you used to be combed with iron combs so that nothing of his flesh or nerves would remain on his bones; yet that would never make him desert his religion. A saw might be put over the parting of his head which would be split into two parts, yet all that would never make him abandon his religion. Allah will surely complete this religion (i.e. Islam) so that a traveler from Sana to Hadra-maut will not be afraid of anybody except Allah." (The sub-narrator, Bayan added, "Or the wolf, lest it should harm his sheep)}}
\hadithdefcmd{bukhari}{3853}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه قَالَ قَرَأَ النَّبِيُّ صلى الله عليه وسلم النَّجْمَ، فَسَجَدَ فَمَا بَقِيَ أَحَدٌ إِلاَّ سَجَدَ، إِلاَّ رَجُلٌ رَأَيْتُهُ أَخَذَ كَفًّا مِنْ حَصًا فَرَفَعَهُ فَسَجَدَ عَلَيْهِ وَقَالَ هَذَا يَكْفِينِي‏.‏ فَلَقَدْ رَأَيْتُهُ بَعْدُ قُتِلَ كَافِرًا بِاللَّهِ‏.‏\hadithno{3853}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) recited Surat An-Najm and prostrated, and there was nobody who did not prostrate then except a man whom I saw taking a handful of pebbles, lifting it, and prostrating on it. He then said, "This is sufficient for me." No doubt I saw him killed as a disbeliever afterwards}}
\hadithdefcmd{bukhari}{3854}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم سَاجِدٌ وَحَوْلَهُ نَاسٌ مِنْ قُرَيْشٍ جَاءَ عُقْبَةُ بْنُ أَبِي مُعَيْطٍ بِسَلَى جَزُورٍ، فَقَذَفَهُ عَلَى ظَهْرِ النَّبِيِّ صلى الله عليه وسلم، فَلَمْ يَرْفَعْ رَأْسَهُ فَجَاءَتْ فَاطِمَةُ ـ عَلَيْهَا السَّلاَمُ ـ فَأَخَذَتْهُ مِنْ ظَهْرِهِ، وَدَعَتْ عَلَى مَنْ صَنَعَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ عَلَيْكَ الْمَلأَ مِنْ قُرَيْشٍ أَبَا جَهْلِ بْنَ هِشَامٍ، وَعُتْبَةَ بْنَ رَبِيعَةَ، وَشَيْبَةَ بْنَ رَبِيعَةَ، وَأُمَيَّةَ بْنَ خَلَفٍ ـ أَوْ أُبَىَّ بْنَ خَلَفٍ ‏"‏‏.‏ شُعْبَةُ الشَّاكُّ ـ فَرَأَيْتُهُمْ قُتِلُوا يَوْمَ بَدْرٍ، فَأُلْقُوا فِي بِئْرٍ غَيْرَ أُمَيَّةَ أَوْ أُبَىٍّ تَقَطَّعَتْ أَوْصَالُهُ، فَلَمْ يُلْقَ فِي الْبِئْرِ‏.‏\hadithno{3854}\hadithtrans{Narrated `Abdullah:While the Prophet (ﷺ) was prostrating, surrounded by some of Quraish, `Uqba bin Abi Mu'ait brought the intestines (i.e. Abdominal contents) of a camel and put them over the back of the Prophet. The Prophet (ﷺ) did not raise his head, (till) Fatima, came and took it off his back and cursed the one who had done the harm. The Prophet (ﷺ) said, "O Allah! Destroy the chiefs of Quraish, Abu Jahl bin Hisham, `Utba bin Rabi`a, Shaiba bin Rabi`a, Umaiya bin Khalaf or Ubai bin Khalaf." (The sub-narrator Shu`ba, is not sure of the last name.) I saw these people killed on the day of Badr battle and thrown in the well except Umaiya or Ubai whose body parts were mutilated but he was not thrown in the well}}
\hadithdefcmd{bukhari}{3855}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، حَدَّثَنِي سَعِيدُ بْنُ جُبَيْرٍ، أَوْ قَالَ حَدَّثَنِي الْحَكَمُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ أَمَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبْزَى قَالَ سَلِ ابْنَ عَبَّاسٍ عَنْ هَاتَيْنِ الآيَتَيْنِ، مَا أَمْرُهُمَا ‏\{‏وَلاَ تَقْتُلُوا النَّفْسَ الَّتِي حَرَّمَ اللَّهُ ‏\}‏ ‏\{‏وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا‏\}‏ فَسَأَلْتُ ابْنَ عَبَّاسٍ فَقَالَ لَمَّا أُنْزِلَتِ الَّتِي فِي الْفُرْقَانِ قَالَ مُشْرِكُو أَهْلِ مَكَّةَ فَقَدْ قَتَلْنَا النَّفْسَ الَّتِي حَرَّمَ اللَّهُ، وَدَعَوْنَا مَعَ اللَّهِ إِلَهًا آخَرَ، وَقَدْ أَتَيْنَا الْفَوَاحِشَ‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏إِلاَّ مَنْ تَابَ وَآمَنَ‏\}‏ الآيَةَ فَهَذِهِ لأُولَئِكَ وَأَمَّا الَّتِي فِي النِّسَاءِ الرَّجُلُ إِذَا عَرَفَ الإِسْلاَمَ وَشَرَائِعَهُ، ثُمَّ قَتَلَ فَجَزَاؤُهُ جَهَنَّمُ‏.‏ فَذَكَرْتُهُ لِمُجَاهِدٍ فَقَالَ إِلاَّ مَنْ نَدِمَ‏.‏\hadithno{3855}\hadithtrans{Narrated Sa`id bin Jubair:`AbdurRahman bin Abza said, "Ask Ibn `Abbas about these two Qur'anic Verses: 'Nor kill such life as Allah has made sacred, Except for just cause.' (25.168) "And whoever kills a believer intentionally, his recompense is Hell. (4.93) So I asked Ibn `Abbas who said, "When the Verse that is in Sura-al-Furqan was revealed, the pagans of Mecca said, 'But we have slain such life as Allah has made sacred, and we have invoked other gods along with Allah, and we have also committed fornication.' So Allah revealed:-- 'Except those who repent, believe, and do good-- (25.70) So this Verse was concerned with those people. As for the Verse in Surat-an-Nisa (4-93), it means that if a man, after understanding Islam and its laws and obligations, murders somebody, then his punishment is to dwell in the (Hell) Fire forever." Then I mentioned this to Mujahid who said, "Except the one who regrets (one's crime)}}
\hadithdefcmd{bukhari}{3856}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنِي الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، قَالَ سَأَلْتُ ابْنَ عَمْرِو بْنِ الْعَاصِ أَخْبِرْنِي بِأَشَدِّ، شَىْءٍ صَنَعَهُ الْمُشْرِكُونَ بِالنَّبِيِّ صلى الله عليه وسلم قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يُصَلِّي فِي حِجْرِ الْكَعْبَةِ إِذْ أَقْبَلَ عُقْبَةُ بْنُ أَبِي مُعَيْطٍ، فَوَضَعَ ثَوْبَهُ فِي عُنُقِهِ فَخَنَقَهُ خَنْقًا شَدِيدًا، فَأَقْبَلَ أَبُو بَكْرٍ حَتَّى أَخَذَ بِمَنْكِبِهِ وَدَفَعَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏\{‏أَتَقْتُلُونَ رَجُلاً أَنْ يَقُولَ رَبِّيَ اللَّهُ‏\}‏ الآيَةَ‏.‏ تَابَعَهُ ابْنُ إِسْحَاقَ حَدَّثَنِي يَحْيَى بْنُ عُرْوَةَ عَنْ عُرْوَةَ، قُلْتُ لِعَبْدِ اللَّهِ بْنِ عَمْرٍو‏.‏ وَقَالَ عَبْدَةُ عَنْ هِشَامٍ عَنْ أَبِيهِ قِيلَ لِعَمْرِو بْنِ الْعَاصِ‏.‏ وَقَالَ مُحَمَّدُ بْنُ عَمْرٍو عَنْ أَبِي سَلَمَةَ حَدَّثَنِي عَمْرُو بْنُ الْعَاصِ‏.‏\hadithno{3856}\hadithtrans{Narrated `Urwa bin Az-Zubair:I asked Ibn `Amr bin Al-As, "Tell me of the worst thing which the pagans did to the Prophet." He said, "While the Prophet (ﷺ) was praying in the Hijr of the Ka`ba; `Uqba bin Abi Mu'ait came and put his garment around the Prophet's neck and throttled him violently. Abu Bakr came and caught him by his shoulder and pushed him away from the Prophet (ﷺ) and said, "Do you want to kill a man just because he says, 'My Lord is Allah?}}
\hadithdefcmd{bukhari}{3857}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ حَمَّادٍ الآمُلِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُجَالِدٍ، عَنْ بَيَانٍ، عَنْ وَبَرَةَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، قَالَ قَالَ عَمَّارُ بْنُ يَاسِرٍ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَا مَعَهُ إِلاَّ خَمْسَةُ أَعْبُدٍ وَامْرَأَتَانِ، وَأَبُو بَكْرٍ‏.‏\hadithno{3857}\hadithtrans{Narrated `Ammar bin Yasir:I saw Allah's Messenger (ﷺ) , and the only converts (to Islam) with him, were five slaves, two women and Abu Bakr}}
\hadithdefcmd{bukhari}{3858}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هَاشِمٌ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، سَعْدَ بْنَ أَبِي وَقَّاصٍ يَقُولُ مَا أَسْلَمَ أَحَدٌ إِلاَّ فِي الْيَوْمِ الَّذِي أَسْلَمْتُ فِيهِ، وَلَقَدْ مَكَثْتُ سَبْعَةَ أَيَّامٍ وَإِنِّي لَثُلُثُ الإِسْلاَمِ\hadithno{3858}\hadithtrans{Narrated Abu 'Is-haq: Sa`d bin Abi Waqqas said: None embraced Islam, except on the day I embraced it. And for seven days I was one of the three persons who were Muslims (one-third of Islam)}}
\hadithdefcmd{bukhari}{3859}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا مِسْعَرٌ، عَنْ مَعْنِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ أَبِي قَالَ، سَأَلْتُ مَسْرُوقًا مَنْ آذَنَ النَّبِيَّ صلى الله عليه وسلم بِالْجِنِّ لَيْلَةَ اسْتَمَعُوا الْقُرْآنَ‏.‏ فَقَالَ حَدَّثَنِي أَبُوكَ ـ يَعْنِي عَبْدَ اللَّهِ ـ أَنَّهُ آذَنَتْ بِهِمْ شَجَرَةٌ‏.‏\hadithno{3859}\hadithtrans{Narrated `Abdur-Rahman:"I asked Masruq, 'Who informed the Prophet (ﷺ) about the Jinns at the night when they heard the Qur'an?' He said, 'Your father `Abdullah informed me that a tree informed the Prophet (ﷺ) about them}}
\hadithdefcmd{bukhari}{3860}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي جَدِّي، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّهُ كَانَ يَحْمِلُ مَعَ النَّبِيِّ صلى الله عليه وسلم إِدَاوَةً لِوَضُوئِهِ وَحَاجَتِهِ، فَبَيْنَمَا هُوَ يَتْبَعُهُ بِهَا فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏‏.‏ فَقَالَ أَنَا أَبُو هُرَيْرَةَ‏.‏ فَقَالَ ‏"‏ ابْغِنِي أَحْجَارًا أَسْتَنْفِضْ بِهَا، وَلاَ تَأْتِنِي بِعَظْمٍ وَلاَ بِرَوْثَةٍ ‏"‏‏.‏ فَأَتَيْتُهُ بِأَحْجَارٍ أَحْمِلُهَا فِي طَرَفِ ثَوْبِي حَتَّى وَضَعْتُ إِلَى جَنْبِهِ ثُمَّ انْصَرَفْتُ، حَتَّى إِذَا فَرَغَ مَشَيْتُ، فَقُلْتُ مَا بَالُ الْعَظْمِ وَالرَّوْثَةِ قَالَ ‏"‏ هُمَا مِنْ طَعَامِ الْجِنِّ، وَإِنَّهُ أَتَانِي وَفْدُ جِنِّ نَصِيبِينَ وَنِعْمَ الْجِنُّ، فَسَأَلُونِي الزَّادَ، فَدَعَوْتُ اللَّهَ لَهُمْ أَنْ لاَ يَمُرُّوا بِعَظْمٍ وَلاَ بِرَوْثَةٍ إِلاَّ وَجَدُوا عَلَيْهَا طَعَامًا ‏"‏‏.‏\hadithno{3860}\hadithtrans{Narrated Abu Huraira:That once he was in the company of the Prophet (ﷺ) carrying a water pot for his ablution and for cleaning his private parts. While he was following him carrying it (i.e. the pot), the Prophet (ﷺ) said, "Who is this?" He said, "I am Abu Huraira." The Prophet (ﷺ) said, "Bring me stones in order to clean my private parts, and do not bring any bones or animal dung." Abu Huraira went on narrating: So I brought some stones, carrying them in the corner of my robe till I put them by his side and went away. When he finished, I walked with him and asked, "What about the bone and the animal dung?" He said, "They are of the food of Jinns. The delegate of Jinns of (the city of) Nasibin came to me--and how nice those Jinns were--and asked me for the remains of the human food. I invoked Allah for them that they would never pass by a bone or animal dung but find food on them}}
\hadithdefcmd{bukhari}{3861}{حَدَّثَنِي عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا الْمُثَنَّى، عَنْ أَبِي جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا بَلَغَ أَبَا ذَرٍّ مَبْعَثُ النَّبِيِّ صلى الله عليه وسلم قَالَ لأَخِيهِ ارْكَبْ إِلَى هَذَا الْوَادِي، فَاعْلَمْ لِي عِلْمَ هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ، يَأْتِيهِ الْخَبَرُ مِنَ السَّمَاءِ، وَاسْمَعْ مِنْ قَوْلِهِ، ثُمَّ ائْتِنِي‏.‏ فَانْطَلَقَ الأَخُ حَتَّى قَدِمَهُ وَسَمِعَ مِنْ قَوْلِهِ، ثُمَّ رَجَعَ إِلَى أَبِي ذَرٍّ، فَقَالَ لَهُ رَأَيْتُهُ يَأْمُرُ بِمَكَارِمِ الأَخْلاَقِ، وَكَلاَمًا مَا هُوَ بِالشِّعْرِ‏.‏ فَقَالَ مَا شَفَيْتَنِي مِمَّا أَرَدْتُ، فَتَزَوَّدَ وَحَمَلَ شَنَّةً لَهُ فِيهَا مَاءٌ حَتَّى قَدِمَ مَكَّةَ، فَأَتَى الْمَسْجِدَ، فَالْتَمَسَ النَّبِيَّ صلى الله عليه وسلم وَلاَ يَعْرِفُهُ، وَكَرِهَ أَنْ يَسْأَلَ عَنْهُ حَتَّى أَدْرَكَهُ بَعْضُ اللَّيْلِ، فَرَآهُ عَلِيٌّ فَعَرَفَ أَنَّهُ غَرِيبٌ‏.‏ فَلَمَّا رَآهُ تَبِعَهُ، فَلَمْ يَسْأَلْ وَاحِدٌ مِنْهُمَا صَاحِبَهُ عَنْ شَىْءٍ حَتَّى أَصْبَحَ، ثُمَّ احْتَمَلَ قِرْبَتَهُ وَزَادَهُ إِلَى الْمَسْجِدِ، وَظَلَّ ذَلِكَ الْيَوْمَ وَلاَ يَرَاهُ النَّبِيُّ صلى الله عليه وسلم حَتَّى أَمْسَى، فَعَادَ إِلَى مَضْجَعِهِ، فَمَرَّ بِهِ عَلِيٌّ فَقَالَ أَمَا نَالَ لِلرَّجُلِ أَنْ يَعْلَمَ مَنْزِلَهُ فَأَقَامَهُ، فَذَهَبَ بِهِ مَعَهُ لاَ يَسْأَلُ وَاحِدٌ مِنْهُمَا صَاحِبَهُ عَنْ شَىْءٍ، حَتَّى إِذَا كَانَ يَوْمَ الثَّالِثِ، فَعَادَ عَلِيٌّ مِثْلَ ذَلِكَ، فَأَقَامَ مَعَهُ ثُمَّ قَالَ أَلاَ تُحَدِّثُنِي مَا الَّذِي أَقْدَمَكَ قَالَ إِنْ أَعْطَيْتَنِي عَهْدًا وَمِيثَاقًا لَتُرْشِدَنَّنِي فَعَلْتُ فَفَعَلَ فَأَخْبَرَهُ‏.‏ قَالَ فَإِنَّهُ حَقٌّ وَهُوَ رَسُولُ اللَّهِ صلى الله عليه وسلم، فَإِذَا أَصْبَحْتَ فَاتْبَعْنِي، فَإِنِّي إِنْ رَأَيْتُ شَيْئًا أَخَافُ عَلَيْكَ قُمْتُ كَأَنِّي أُرِيقُ الْمَاءَ، فَإِنْ مَضَيْتُ فَاتْبَعْنِي حَتَّى تَدْخُلَ مَدْخَلِي‏.‏ فَفَعَلَ، فَانْطَلَقَ يَقْفُوهُ حَتَّى دَخَلَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَدَخَلَ مَعَهُ، فَسَمِعَ مِنْ قَوْلِهِ، وَأَسْلَمَ مَكَانَهُ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ارْجِعْ إِلَى قَوْمِكَ، فَأَخْبِرْهُمْ حَتَّى يَأْتِيَكَ أَمْرِي ‏"‏‏.‏ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ لأَصْرُخَنَّ بِهَا بَيْنَ ظَهْرَانَيْهِمْ، فَخَرَجَ حَتَّى أَتَى الْمَسْجِدَ فَنَادَى بِأَعْلَى صَوْتِهِ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ‏.‏ ثُمَّ قَامَ الْقَوْمُ فَضَرَبُوهُ حَتَّى أَضْجَعُوهُ، وَأَتَى الْعَبَّاسُ فَأَكَبَّ عَلَيْهِ قَالَ وَيْلَكُمْ أَلَسْتُمْ تَعْلَمُونَ أَنَّهُ مِنْ غِفَارٍ وَأَنَّ طَرِيقَ تِجَارِكُمْ إِلَى الشَّأْمِ فَأَنْقَذَهُ مِنْهُمْ، ثُمَّ عَادَ مِنَ الْغَدِ لِمِثْلِهَا، فَضَرَبُوهُ وَثَارُوا إِلَيْهِ، فَأَكَبَّ الْعَبَّاسُ عَلَيْهِ‏.‏\hadithno{3861}\hadithtrans{Narrated Ibn `Abbas:When Abu Dhar received the news of the Advent of the Prophet (ﷺ) he said to his brother, "Ride to this valley (of Mecca) and try to find out the truth of the person who claims to be a prophet who is informed of the news of Heaven. Listen to what he says and come back to me." So his brother set out and came to the Prophet (ﷺ) and listened to some of his talks, and returned to Abu Dhar and said to him. "I have seen him enjoining virtuous behavior and saying something that is not poetry." Abu Dhar said, "You have not satisfied me as to what I wanted." He then took his journey-food and carried a waterskin of his, containing some water till he reached Mecca. He went to the Mosque and searched for the Prophet and though he did not know him, he hated to ask anybody about him. When a part of the night had passed away, `Ali saw him and knew that he was a stranger. So when Abu Dhar saw `Ali, he followed him, and none of them asked his companion about anything, and when it was dawn, Abu Dhar took his journey food and his water-skin to the Mosque and stayed there all the day long without being perceived by the Prophet, and when it was evening, he came back to his retiring place. `Ali passed by him and said, "Has the man not known his dwelling place yet?" So `Ali awakened him and took him with him and none of them spoke to the other about anything. When it was the third day. `Ali did the same and Abu Dhar stayed with him. Then `Ali said "Will you tell me what has brought you here?" Abu Dhar said, "If you give me a firm promise that you will guide me, then I will tell you." `Ali promised him, and he informed `Ali about the matter. `Ali said, "It is true, and he is the Messenger of Allah. Next morning when you get up, accompany me, and if I see any danger for you, I will stop as if to pass water, but if I go on, follow me and enter the place which I will enter." Abu Dhar did so, and followed `Ali till he entered the place of the Prophet, and Abu Dhar went in with him, Abu Dhar listened to some of the Prophet's talks and embraced Islam on the spot. The Prophet (ﷺ) said to him, "Go back to your people and inform them (about it) till you receive my order." Abu Dhar said, "By Him in Whose Hand my life is, I will proclaim my conversion loudly amongst them (i.e. the pagans)." So he went out, and when he reached the Mosque, he said as loudly as possible, "I bear witness that None has the right to be worshipped except Allah, and Muhammad is the Messenger of Allah." The People got up and beat him painfully. Then Al-Abbas came and knelt over him ((to protect him) and said (to the people), "Woe to you! Don't you know that this man belongs to the tribe of Ghifar and your trade to Sha'm is through their way?" So he rescued him from them. Abu Dhar again did the same the next day. They beat him and took vengeance on him and again Al-Abbas knelt over him (to protect him)}}
\hadithdefcmd{bukhari}{3862}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، فِي مَسْجِدِ الْكُوفَةِ يَقُولُ وَاللَّهِ لَقَدْ رَأَيْتُنِي وَإِنَّ عُمَرَ لَمُوثِقِي عَلَى الإِسْلاَمِ قَبْلَ أَنْ يُسْلِمَ عُمَرُ، وَلَوْ أَنَّ أُحُدًا ارْفَضَّ لِلَّذِي صَنَعْتُمْ بِعُثْمَانَ لَكَانَ مَحْقُوقًا أَنْ يَرْفَضَّ‏.‏\hadithno{3862}\hadithtrans{Narrated Qais:I heard Sa`id bin Zaid bin `Amr bin Nufail saying in the mosque of Al-Kufa. "By Allah, I have seen myself tied and forced by `Umar to leave Islam before `Umar himself embraced Islam. And if the mountain of Uhud could move from its place for the evil which you people have done to `Uthman, then it would have the right to move from its place}}
\hadithdefcmd{bukhari}{3863}{حَدَّثَنِي مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ مَا زِلْنَا أَعِزَّةً مُنْذُ أَسْلَمَ عُمَرُ‏.‏\hadithno{3863}\hadithtrans{Narrated `Abdullah bin Mas'ud:We have been powerful since `Umar embraced Islam}}
\hadithdefcmd{bukhari}{3864}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدٍ، قَالَ فَأَخْبَرَنِي جَدِّي، زَيْدُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِ، قَالَ بَيْنَمَا هُوَ فِي الدَّارِ خَائِفًا، إِذْ جَاءَهُ الْعَاصِ بْنُ وَائِلٍ السَّهْمِيُّ أَبُو عَمْرٍو، عَلَيْهِ حُلَّةُ حِبَرَةٍ، وَقَمِيصٌ مَكْفُوفٌ بِحَرِيرٍ، وَهُوَ مِنْ بَنِي سَهْمٍ، وَهُمْ حُلَفَاؤُنَا فِي الْجَاهِلِيَّةِ فَقَالَ لَهُ مَا بَالُكَ قَالَ زَعَمَ قَوْمُكَ أَنَّهُمْ سَيَقْتُلُونِي إِنْ أَسْلَمْتُ‏.‏ قَالَ لاَ سَبِيلَ إِلَيْكَ‏.‏ بَعْدَ أَنْ قَالَهَا أَمِنْتُ، فَخَرَجَ الْعَاصِ، فَلَقِيَ النَّاسَ قَدْ سَالَ بِهِمُ الْوَادِي فَقَالَ أَيْنَ تُرِيدُونَ فَقَالُوا نُرِيدُ هَذَا ابْنَ الْخَطَّابِ الَّذِي صَبَا‏.‏ قَالَ لاَ سَبِيلَ إِلَيْهِ‏.‏ فَكَرَّ النَّاسُ‏.‏\hadithno{3864}\hadithtrans{Narrated `Abdullah bin `Umar:While `Umar was at home in a state of fear, there came Al-`As bin Wail As-Sahmi Abu `Amr, wearing an embroidered cloak and a shirt having silk hems. He was from the tribe of Bani Sahm who were our allies during the pre-Islamic period of ignorance. Al-`As said to `Umar "What is wrong with you?" He said, "Your people claim that they would kill me if I become a Muslim." Al-`As said, "Nobody will harm you after I have given protection to you." So Al-`As went out and met the people streaming in the whole valley. He said, "Where are you going?" They said, "We want Ibn Al-Khattab who has embraced Islam." Al-`As said, "There is no way for anybody to touch him." So the people retreated}}
\hadithdefcmd{bukhari}{3865}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرُو بْنُ دِينَارٍ سَمِعْتُهُ قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ لَمَّا أَسْلَمَ عُمَرُ اجْتَمَعَ النَّاسُ عِنْدَ دَارِهِ وَقَالُوا صَبَا عُمَرُ‏.‏ وَأَنَا غُلاَمٌ فَوْقَ ظَهْرِ بَيْتِي، فَجَاءَ رَجُلٌ عَلَيْهِ قَبَاءٌ مِنْ دِيبَاجٍ فَقَالَ قَدْ صَبَا عُمَرُ‏.‏ فَمَا ذَاكَ فَأَنَا لَهُ جَارٌ‏.‏ قَالَ فَرَأَيْتُ النَّاسَ تَصَدَّعُوا عَنْهُ فَقُلْتُ مَنْ هَذَا قَالُوا الْعَاصِ بْنُ وَائِلٍ‏.‏\hadithno{3865}\hadithtrans{Narrated `Abdullah bin `Umar:When `Umar embraced Islam, all The (disbelieving) people gathered around his home and said, "`Umar has embraced Islam." At that time I was still a boy and was on the roof of my house. There came a man wearing a cloak of Dibaj (i.e. a kind of silk), and said, "`Umar has embraced Islam. Nobody can harm him for I am his protector." I then saw the people going away from `Umar and asked who the man was, and they said, "Al-`As bin Wail}}
\hadithdefcmd{bukhari}{3866}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ، أَنَّ سَالِمًا، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ مَا سَمِعْتُ عُمَرَ، لِشَىْءٍ قَطُّ يَقُولُ إِنِّي لأَظُنُّهُ كَذَا‏.‏ إِلاَّ كَانَ كَمَا يَظُنُّ، بَيْنَمَا عُمَرُ جَالِسٌ إِذْ مَرَّ بِهِ رَجُلٌ جَمِيلٌ فَقَالَ لَقَدْ أَخْطَأَ ظَنِّي، أَوْ إِنَّ هَذَا عَلَى دِينِهِ فِي الْجَاهِلِيَّةِ، أَوْ لَقَدْ كَانَ كَاهِنَهُمْ، عَلَىَّ الرَّجُلَ، فَدُعِيَ لَهُ، فَقَالَ لَهُ ذَلِكَ، فَقَالَ مَا رَأَيْتُ كَالْيَوْمِ اسْتُقْبِلَ بِهِ رَجُلٌ مُسْلِمٌ، قَالَ فَإِنِّي أَعْزِمُ عَلَيْكَ إِلاَّ مَا أَخْبَرْتَنِي‏.‏ قَالَ كُنْتُ كَاهِنَهُمْ فِي الْجَاهِلِيَّةِ‏.‏ قَالَ فَمَا أَعْجَبُ مَا جَاءَتْكَ بِهِ جِنِّيَّتُكَ قَالَ بَيْنَمَا أَنَا يَوْمًا فِي السُّوقِ جَاءَتْنِي أَعْرِفُ فِيهَا الْفَزَعَ، فَقَالَتْ أَلَمْ تَرَ الْجِنَّ وَإِبْلاَسَهَا وَيَأْسَهَا مِنْ بَعْدِ إِنْكَاسِهَا وَلُحُوقَهَا بِالْقِلاَصِ وَأَحْلاَسِهَا قَالَ عُمَرُ صَدَقَ، بَيْنَمَا أَنَا عِنْدَ آلِهَتِهِمْ إِذْ جَاءَ رَجُلٌ بِعِجْلٍ فَذَبَحَهُ، فَصَرَخَ بِهِ صَارِخٌ، لَمْ أَسْمَعْ صَارِخًا قَطُّ أَشَدَّ صَوْتًا مِنْهُ يَقُولُ يَا جَلِيحْ، أَمْرٌ نَجِيحْ رَجُلٌ فَصِيحْ يَقُولُ لاَ إِلَهَ إِلاَّ أَنْتَ‏.‏ فَوَثَبَ الْقَوْمُ قُلْتُ لاَ أَبْرَحُ حَتَّى أَعْلَمَ مَا وَرَاءَ هَذَا ثُمَّ نَادَى يَا جَلِيحْ، أَمْرٌ نَجِيحْ، رَجُلٌ فَصِيحْ، يَقُولُ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَقُمْتُ فَمَا نَشِبْنَا أَنْ قِيلَ هَذَا نَبِيٌّ‏.‏\hadithno{3866}\hadithtrans{Narrated `Abdullah bin `Umar:I never heard `Umar saying about something that he thought it would be so-and-so, but he was quite right. Once, while `Umar was sitting, a handsome man passed by him, `Umar said, "If I am not wrong, this person is still on his religion of the pre-Islamic period of ignorance or he was their foreteller. Call the man to me." When the man was called to him, he told him of his thought. The man said, "I have never seen such a day on which a Muslim is faced with such an accusation." `Umar said, "I am determined that you should tell me the truth." He said, "I was a foreteller in the pre-Islamic period of ignorance." Then `Umar said, "Tell me the most astonishing thing your female Jinn has told you of." He said, "One-day while I was in the market, she came to me scared and said, 'Haven't you seen the Jinns and their despair and they were overthrown after their defeat (and prevented from listening to the news of the heaven) so that they (stopped going to the sky and) kept following camel-riders (i.e. 'Arabs)?" `Umar said, "He is right." and added, "One day while I was near their idols, there came a man with a calf and slaughtered it as a sacrifice (for the idols). An (unseen) creature shouted at him, and I have never heard harsher than his voice. He was crying, 'O you bold evil-doer! A matter of success! An eloquent man is saying: None has the right to be worshipped except you (O Allah).' On that the people fled, but I said, 'I shall not go away till I know what is behind this.' Then the cry came again: 'O you bold evil-doer! A matter of success! An eloquent man is saying: None has the right to be worshipped except Allah.' I then went away and a few days later it was said, "A prophet has appeared}}
\hadithdefcmd{bukhari}{3867}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا قَيْسٌ، قَالَ سَمِعْتُ سَعِيدَ بْنَ زَيْدٍ، يَقُولُ لِلْقَوْمِ لَوْ رَأَيْتُنِي مُوثِقِي عُمَرُ عَلَى الإِسْلاَمِ أَنَا وَأُخْتُهُ وَمَا أَسْلَمَ، وَلَوْ أَنَّ أُحُدًا انْقَضَّ لِمَا صَنَعْتُمْ، بِعُثْمَانَ لَكَانَ مَحْقُوقًا أَنْ يَنْقَضَّ‏.‏\hadithno{3867}\hadithtrans{Narrated Qais:I heard Sa`id bin Zaid saying to the people, "If you but saw me and `Umar's sister tied and forced by `Umar to leave Islam while he was not yet a Muslim. And if the mountain of Uhud could move from its place for the evil which you people have done to `Uthman, it would have the right to do that}}
\hadithdefcmd{bukhari}{3868}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه أَنَّ أَهْلَ، مَكَّةَ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يُرِيَهُمْ آيَةً، فَأَرَاهُمُ الْقَمَرَ شِقَّتَيْنِ، حَتَّى رَأَوْا حِرَاءً بَيْنَهُمَا‏.‏\hadithno{3868}\hadithtrans{Narrated Anas bin Malik:The people of Mecca asked Allah's Messenger (ﷺ) to show them a miracle. So he showed them the moon split in two halves between which they saw the Hira' mountain}}
\hadithdefcmd{bukhari}{3869}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ انْشَقَّ الْقَمَرُ وَنَحْنُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِمِنًى فَقَالَ ‏ "‏ اشْهَدُوا ‏"‏‏.‏ وَذَهَبَتْ فِرْقَةٌ نَحْوَ الْجَبَلِ وَقَالَ أَبُو الضُّحَى عَنْ مَسْرُوقٍ عَنْ عَبْدِ اللَّهِ انْشَقَّ بِمَكَّةَ‏.‏ وَتَابَعَهُ مُحَمَّدُ بْنُ مُسْلِمٍ عَنِ ابْنِ أَبِي نَجِيحٍ عَنْ مُجَاهِدٍ عَنْ أَبِي مَعْمَرٍ عَنْ عَبْدِ اللَّهِ‏.‏\hadithno{3869}\hadithtrans{Narrated `Abdullah:The moon was split ( into two pieces ) while we were with the Prophet (ﷺ) in Mina. He said, "Be witnesses." Then a Piece of the moon went towards the mountain}}
\hadithdefcmd{bukhari}{3870}{حَدَّثَنَا عُثْمَانُ بْنُ صَالِحٍ، حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ الْقَمَرَ، انْشَقَّ عَلَى زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3870}\hadithtrans{Narrated `Abdullah bin `Abbas:During the lifetime of Allah's Messenger (ﷺ) the moon was split (into two pieces)}}
\hadithdefcmd{bukhari}{3871}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ انْشَقَّ الْقَمَرُ‏.‏\hadithno{3871}\hadithtrans{Narrated `Abdullah:The moon was split (into two pieces)}}
\hadithdefcmd{bukhari}{3872}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْجُعْفِيُّ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَدِيِّ بْنِ الْخِيَارِ، أَخْبَرَهُ أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ وَعَبْدَ الرَّحْمَنِ بْنَ الأَسْوَدِ بْنِ عَبْدِ يَغُوثَ قَالاَ لَهُ مَا يَمْنَعُكَ أَنْ تُكَلِّمَ خَالَكَ عُثْمَانَ فِي أَخِيهِ الْوَلِيدِ بْنِ عُقْبَةَ وَكَانَ أَكْثَرَ النَّاسُ فِيمَا فَعَلَ بِهِ‏.‏ قَالَ عُبَيْدُ اللَّهِ فَانْتَصَبْتُ لِعُثْمَانَ حِينَ خَرَجَ إِلَى الصَّلاَةِ فَقُلْتُ لَهُ إِنَّ لِي إِلَيْكَ حَاجَةً وَهْىَ نَصِيحَةٌ‏.‏ فَقَالَ أَيُّهَا الْمَرْءُ، أَعُوذُ بِاللَّهِ مِنْكَ، فَانْصَرَفْتُ، فَلَمَّا قَضَيْتُ الصَّلاَةَ جَلَسْتُ إِلَى الْمِسْوَرِ وَإِلَى ابْنِ عَبْدِ يَغُوثَ، فَحَدَّثْتُهُمَا بِالَّذِي قُلْتُ لِعُثْمَانَ وَقَالَ لِي‏.‏ فَقَالاَ قَدْ قَضَيْتَ الَّذِي كَانَ عَلَيْكَ‏.‏ فَبَيْنَمَا أَنَا جَالِسٌ مَعَهُمَا، إِذْ جَاءَنِي رَسُولُ عُثْمَانَ، فَقَالاَ لِي قَدِ ابْتَلاَكَ اللَّهُ‏.‏ فَانْطَلَقْتُ حَتَّى دَخَلْتُ عَلَيْهِ، فَقَالَ مَا نَصِيحَتُكَ الَّتِي ذَكَرْتَ آنِفًا قَالَ فَتَشَهَّدْتُ ثُمَّ قُلْتُ إِنَّ اللَّهَ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم وَأَنْزَلَ عَلَيْهِ الْكِتَابَ، وَكُنْتَ مِمَّنِ اسْتَجَابَ لِلَّهِ وَرَسُولِهِ صلى الله عليه وسلم وَآمَنْتَ بِهِ، وَهَاجَرْتَ الْهِجْرَتَيْنِ الأُولَيَيْنِ، وَصَحِبْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَرَأَيْتَ هَدْيَهُ، وَقَدْ أَكْثَرَ النَّاسُ فِي شَأْنِ الْوَلِيدِ بْنِ عُقْبَةَ، فَحَقٌّ عَلَيْكَ أَنْ تُقِيمَ عَلَيْهِ الْحَدَّ‏.‏ فَقَالَ لِي يَا ابْنَ أَخِي أَدْرَكْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ قُلْتُ لاَ، وَلَكِنْ قَدْ خَلَصَ إِلَىَّ مِنْ عِلْمِهِ مَا خَلَصَ إِلَى الْعَذْرَاءِ فِي سِتْرِهَا‏.‏ قَالَ فَتَشَهَّدَ عُثْمَانُ فَقَالَ إِنَّ اللَّهَ قَدْ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ وَأَنْزَلَ عَلَيْهِ الْكِتَابَ، وَكُنْتُ مِمَّنِ اسْتَجَابَ لِلَّهِ وَرَسُولِهِ صلى الله عليه وسلم وَآمَنْتُ بِمَا بُعِثَ بِهِ مُحَمَّدٌ صلى الله عليه وسلم‏.‏ وَهَاجَرْتُ الْهِجْرَتَيْنِ الأُولَيَيْنِ كَمَا قُلْتَ، وَصَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَبَايَعْتُهُ، وَاللَّهِ مَا عَصَيْتُهُ وَلاَ غَشَشْتُهُ حَتَّى تَوَفَّاهُ اللَّهُ، ثُمَّ اسْتَخْلَفَ اللَّهُ أَبَا بَكْرٍ فَوَاللَّهِ مَا عَصَيْتُهُ وَلاَ غَشَشْتُهُ، ثُمَّ اسْتُخْلِفَ عُمَرُ، فَوَاللَّهِ مَا عَصَيْتُهُ وَلاَ غَشَشْتُهُ، ثُمَّ اسْتُخْلِفْتُ، أَفَلَيْسَ لِي عَلَيْكُمْ مِثْلُ الَّذِي كَانَ لَهُمْ عَلَىَّ قَالَ بَلَى‏.‏ قَالَ فَمَا هَذِهِ الأَحَادِيثُ الَّتِي تَبْلُغُنِي عَنْكُمْ فَأَمَّا مَا ذَكَرْتَ مِنْ شَأْنِ الْوَلِيدِ بْنِ عُقْبَةَ، فَسَنَأْخُذُ فِيهِ إِنْ شَاءَ اللَّهُ بِالْحَقِّ قَالَ فَجَلَدَ الْوَلِيدَ أَرْبَعِينَ جَلْدَةً، وَأَمَرَ عَلِيًّا أَنْ يَجْلِدَهُ، وَكَانَ هُوَ يَجْلِدُهُ‏.‏ وَقَالَ يُونُسُ وَابْنُ أَخِي الزُّهْرِيِّ عَنِ الزُّهْرِيِّ أَفَلَيْسَ لِي عَلَيْكُمْ مِنَ الْحَقِّ مِثْلُ الَّذِي كَانَ لَهُمْ‏.‏ قَالَ أَبُو عَبْد اللَّهِ بَلَاءٌ مِنْ رَبِّكُمْ مَا ابْتُلِيتُمْ بِهِ مِنْ شِدَّةٍ وَفِي مَوْضِعٍ الْبَلَاءُ الِابْتِلَاءُ وَالتَّمْحِيصُ مَنْ بَلَوْتُهُ وَمَحَّصْتُهُ أَيْ اسْتَخْرَجْتُ مَا عِنْدَهُ يَبْلُو يَخْتَبِرُ مُبْتَلِيكُمْ مُخْتَبِرُكُمْ وَأَمَّا قَوْلُهُ بَلَاءٌ عَظِيمٌ النِّعَمُ وَهِيَ مِنْ أَبْلَيْتُهُ وَتِلْكَ مِنْ ابْتَلَيْتُهُ\hadithno{3872}\hadithtrans{Narrated 'Ubaidullah bin `Adi bin Al-Khiyar:That Al-Miswar bin Makhrama and `Abdur-Rahman bin Al-Aswad bin 'Abd Yaghuth had said to him, "What prevents you from speaking to your uncle `Uthman regarding his brother Al-Walid bin `Uqba?" The people were speaking against the latter for what he had done. 'Ubaidullah said, "So I kept waiting for `Uthman, and when he went out for the prayer, I said to him, 'I have got something to say to you as a piece of advice.' `Uthman said, 'O man! I seek Refuge with Allah from you. So I went away. When I finished my prayer, I sat with Al-Miswar and Ibn 'Abd Yaghuth and talked to both of them of what I had said to `Uthman and what he had said to me. They said, 'You have done your duty.' So while I was sitting with them. `Uthman's Messenger came to me. They said, 'Allah has put you to trial." I set out and when I reached `Uthman, he said, 'What is your advice which you mentioned a while ago?' I recited Tashahhud and added, 'Allah has sent Muhammad and has revealed the Holy Book (i.e. Qur'an) to him. You (O `Uthman!) were amongst those who responded to the call of Allah and His Apostle and had faith in him. And you took part in the first two migrations (to Ethiopia and to Medina), and you enjoyed the company of Allah's Messenger (ﷺ) and learned his traditions and advice. Now the people are talking much about Al-Walid bin `Uqba and so it is your duty to impose on him the legal punishment.' `Uthman then said to me, 'O my nephew! Did you ever meet Allah's Messenger (ﷺ) ?' I said, 'No, but his knowledge has reached me as it has reached the virgin in her seclusion.' `Uthman then recited Tashahhud and said, 'No doubt, Allah has sent Muhammad with the Truth and has revealed to him His Holy Book (i.e. Qur'an) and I was amongst those who responded to the call of Allah and His Apostle and I had faith in Muhammad's Mission, and I had performed the first two migrations as you have said, and I enjoyed the company of Allah's Messenger (ﷺ) and gave the pledge of allegiance to him. By Allah, I never disobeyed him and never cheated him till Allah caused him to die. Then Allah made Abu Bakr Caliph, and by Allah, I was never disobedient to him, nor did I cheat him. Then `Umar became Caliph, and by Allah, I was never disobedient to him, nor did I cheat him. Then I became Caliph. Have I not then the same rights over you as they had over me?' I replied in the affirmative. `Uthman further said, 'Then what are these talks which are reaching me from you? As for what you have mentioned about Al-Walid bin 'Uqba, Allah willing, I shall give him the legal punishment justly.' Then `Uthman ordered that Al-Walid be flogged forty lashes. He ordered `Ali to flog him and he himself flogged him as well}}
\hadithdefcmd{bukhari}{3873}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ أُمَّ، حَبِيبَةَ وَأُمَّ سَلَمَةَ ذَكَرَتَا كَنِيسَةً رَأَيْنَهَا بِالْحَبَشَةِ، فِيهَا تَصَاوِيرُ، فَذَكَرَتَا لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ أُولَئِكَ إِذَا كَانَ فِيهِمُ الرَّجُلُ الصَّالِحُ فَمَاتَ بَنَوْا عَلَى قَبْرِهِ مَسْجِدًا، وَصَوَّرُوا فِيهِ تِيكَ الصُّوَرَ، أُولَئِكَ شِرَارُ الْخَلْقِ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{3873}\hadithtrans{Narrated `Aisha:Um Habiba and Um Salama mentioned a church they had seen in Ethiopia and in the church there were pictures. When they told the Prophet (ﷺ) of this, he said, "Those people are such that if a pious man amongst them died, they build a place of worship over his grave and paint these pictures in it. Those people will be Allah's worst creatures on the Day of Resurrection}}
\hadithdefcmd{bukhari}{3874}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدٍ السَّعِيدِيُّ، عَنْ أَبِيهِ، عَنْ أُمِّ خَالِدٍ بِنْتِ خَالِدٍ، قَالَتْ قَدِمْتُ مِنْ أَرْضِ الْحَبَشَةِ وَأَنَا جُوَيْرِيَةٌ، فَكَسَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم خَمِيصَةً لَهَا أَعْلاَمٌ، فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْسَحُ الأَعْلاَمَ بِيَدِهِ وَيَقُولُ ‏ "‏ سَنَاهْ، سَنَاهْ ‏"‏‏.‏ قَالَ الْحُمَيْدِيُّ يَعْنِي حَسَنٌ حَسَنٌ‏.‏\hadithno{3874}\hadithtrans{Narrated Um Khalid bint Khalid:When I came from Ethiopia (to Medina), I was a young girl. Allah's Messenger (ﷺ) made me wear a sheet having marks on it. Allah's Messenger (ﷺ) was rubbing those marks with his hands saying, "Sanah! Sanah!" (i.e. good, good)}}
\hadithdefcmd{bukhari}{3875}{حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كُنَّا نُسَلِّمُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ يُصَلِّي فَيَرُدُّ عَلَيْنَا، فَلَمَّا رَجَعْنَا مِنْ عِنْدِ النَّجَاشِيِّ سَلَّمْنَا عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْنَا، فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نُسَلِّمُ عَلَيْكَ فَتَرُدُّ عَلَيْنَا قَالَ ‏ "‏ إِنَّ فِي الصَّلاَةِ شُغْلاً ‏"‏‏.‏ فَقُلْتُ لإِبْرَاهِيمَ كَيْفَ تَصْنَعُ أَنْتَ قَالَ أَرُدُّ فِي نَفْسِي‏.‏\hadithno{3875}\hadithtrans{Narrated `Abdullah:We used to greet the Prophet (ﷺ) while he used to be in prayers, and he used to reply to our greetings. But when we came back from Najashi (the King of Ethiopia) we greeted him (while he was praying) and he did not reply to us. We said, "O Allah's Messenger (ﷺ)! We used to greet you in the past and you used to reply to us." He said, "Verily The Mind is occupied and busy with more important matter during the prayer." (So one cannot return One's greetings)}}
\hadithdefcmd{bukhari}{3876}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا بُرَيْدُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ بَلَغَنَا مَخْرَجُ النَّبِيِّ صلى الله عليه وسلم وَنَحْنُ بِالْيَمَنِ فَرَكِبْنَا سَفِينَةً فَأَلْقَتْنَا سَفِينَتُنَا إِلَى النَّجَاشِيِّ بِالْحَبَشَةِ، فَوَافَقْنَا جَعْفَرَ بْنَ أَبِي طَالِبٍ، فَأَقَمْنَا مَعَهُ حَتَّى قَدِمْنَا، فَوَافَقْنَا النَّبِيَّ صلى الله عليه وسلم حِينَ افْتَتَحَ خَيْبَرَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَكُمْ أَنْتُمْ يَا أَهْلَ السَّفِينَةِ هِجْرَتَانِ ‏"‏‏.‏\hadithno{3876}\hadithtrans{Narrated Abu Musa:We received the news of the departure of the Prophet (to Medina) while we were in Yemen. So we went on board a ship but our ship took us away to An-Najashi (the Negus) in Ethiopia. There we met Ja`far bin Abi Talib and stayed with him till we came (to Medina) by the time when the Prophet (ﷺ) had conquered Khaibar. The Prophet (ﷺ) said, "O you people of the ship! You will have (the reward of) two migrations}}
\hadithdefcmd{bukhari}{3877}{حَدَّثَنَا أَبُو الرَّبِيعِ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم حِينَ مَاتَ النَّجَاشِيُّ ‏ "‏ مَاتَ الْيَوْمَ رَجُلٌ صَالِحٌ، فَقُومُوا فَصَلُّوا عَلَى أَخِيكُمْ أَصْحَمَةَ ‏"‏‏.‏\hadithno{3877}\hadithtrans{Narrated Jabir:When Negus died, the Prophet (ﷺ) said, "Today a pious man has died. So get up and offer the funeral prayer for your brother Ashama}}
\hadithdefcmd{bukhari}{3878}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، حَدَّثَنَا قَتَادَةُ، أَنَّ عَطَاءً، حَدَّثَهُمْ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ ـ رضى الله عنهما ـ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم صَلَّى عَلَى النَّجَاشِيِّ فَصَفَّنَا وَرَاءَهُ فَكُنْتُ فِي الصَّفِّ الثَّانِي أَوِ الثَّالِثِ‏.‏\hadithno{3878}\hadithtrans{Narrated Jabir bin `Abdullah Al-Ansari:Allah's Messenger (ﷺ) led the funeral prayer for the Negus and made us stand in rows behind him and I was in the second or third row}}
\hadithdefcmd{bukhari}{3879}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ، عَنْ سَلِيمِ بْنِ حَيَّانَ، حَدَّثَنَا سَعِيدُ بْنُ مِينَاءَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى أَصْحَمَةَ النَّجَاشِيِّ، فَكَبَّرَ عَلَيْهِ أَرْبَعًا‏.‏ تَابَعَهُ عَبْدُ الصَّمَدِ‏.‏\hadithno{3879}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) offered the funeral prayer for Ashama, the Negus, with four Takbir}}
\hadithdefcmd{bukhari}{3880}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَابْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَخْبَرَهُمَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى لَهُمُ النَّجَاشِيَّ صَاحِبَ الْحَبَشَةِ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ، وَقَالَ ‏ "‏ اسْتَغْفِرُوا لأَخِيكُمْ ‏"‏‏.‏\hadithno{3880}\hadithtrans{Narrated Abu Huraira:that Allah's Messenger (ﷺ) informed them (i.e. his companions) of the death of Negus, the king of Ethiopia, on the very day on which the latter died, and said, "Ask Allah's Forgiveness for your brother}}
\hadithdefcmd{bukhari}{3881}{وَعَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَخْبَرَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَفَّ بِهِمْ فِي الْمُصَلَّى، فَصَلَّى عَلَيْهِ وَكَبَّرَ أَرْبَعًا‏.‏\hadithno{3881}\hadithtrans{Abu Huraira further said: "Allah's Messenger (ﷺ) made them (i.e. the Muslims) stand in rows at the Musalla (i.e. praying place) and led the funeral prayer for the Negus and said four Takbir}}
\hadithdefcmd{bukhari}{3882}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أَرَادَ حُنَيْنًا ‏ "‏ مَنْزِلُنَا غَدًا إِنْ شَاءَ اللَّهُ بِخَيْفِ بَنِي كِنَانَةَ، حَيْثُ تَقَاسَمُوا عَلَى الْكُفْرِ ‏"‏‏.‏\hadithno{3882}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ), while going out for the battle of Hunain, said, "Tomorrow Allah willing, we will encamp at Khaif Bani Kinana where the pagans(of Quraish) took the oath of Kufr (against the Prophet (ﷺ) i.e. to be loyal to heathenism, by boycotting Banu Hashim, the Prophet's folk. (See Hadith)}}
\hadithdefcmd{bukhari}{3883}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنَا عَبْدُ الْمَلِكِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ، حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ ـ رضى الله عنه ـ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم مَا أَغْنَيْتَ عَنْ عَمِّكَ فَإِنَّهُ كَانَ يَحُوطُكَ وَيَغْضَبُ لَكَ‏.‏ قَالَ ‏ "‏ هُوَ فِي ضَحْضَاحٍ مِنْ نَارٍ، وَلَوْلاَ أَنَا لَكَانَ فِي الدَّرَكِ الأَسْفَلِ مِنَ النَّارِ ‏"‏‏.‏\hadithno{3883}\hadithtrans{Narrated Al-Abbas bin `Abdul Muttalib:That he said to the Prophet (ﷺ) "You have not been of any avail to your uncle (Abu Talib) (though) by Allah, he used to protect you and used to become angry on your behalf." The Prophet (ﷺ) said, "He is in a shallow fire, and had It not been for me, he would have been in the bottom of the (Hell) Fire}}
\hadithdefcmd{bukhari}{3884}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِيهِ، أَنَّ أَبَا طَالِبٍ، لَمَّا حَضَرَتْهُ الْوَفَاةُ دَخَلَ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم وَعِنْدَهُ أَبُو جَهْلٍ فَقَالَ ‏"‏ أَىْ عَمِّ، قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ كَلِمَةً أُحَاجُّ لَكَ بِهَا عِنْدَ اللَّهِ ‏"‏‏.‏ فَقَالَ أَبُو جَهْلٍ وَعَبْدُ اللَّهِ بْنُ أَبِي أُمَيَّةَ يَا أَبَا طَالِبٍ، تَرْغَبُ عَنْ مِلَّةِ عَبْدِ الْمُطَّلِبِ فَلَمْ يَزَالاَ يُكَلِّمَانِهِ حَتَّى قَالَ آخِرَ شَىْءٍ كَلَّمَهُمْ بِهِ عَلَى مِلَّةِ عَبْدِ الْمُطَّلِبِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لأَسْتَغْفِرَنَّ لَكَ مَا لَمْ أُنْهَ عَنْهُ ‏"‏‏.‏ فَنَزَلَتْ ‏\{‏مَا كَانَ لِلنَّبِيِّ وَالَّذِينَ آمَنُوا أَنْ يَسْتَغْفِرُوا لِلْمُشْرِكِينَ وَلَوْ كَانُوا أُولِي قُرْبَى مِنْ بَعْدِ مَا تَبَيَّنَ لَهُمْ أَنَّهُمْ أَصْحَابُ الْجَحِيمِ‏\}‏ وَنَزَلَتْ ‏\{‏إِنَّكَ لاَ تَهْدِي مَنْ أَحْبَبْتَ‏\}‏\hadithno{3884}\hadithtrans{Narrated Al-Musaiyab:When Abu Talib was in his death bed, the Prophet (ﷺ) went to him while Abu Jahl was sitting beside him. The Prophet (ﷺ) said, "O my uncle! Say: None has the right to be worshipped except Allah, an expression I will defend your case with, before Allah." Abu Jahl and `Abdullah bin Umaiya said, "O Abu Talib! Will you leave the religion of `Abdul Muttalib?" So they kept on saying this to him so that the last statement he said to them (before he died) was: "I am on the religion of `Abdul Muttalib." Then the Prophet said, " I will keep on asking for Allah's Forgiveness for you unless I am forbidden to do so." Then the following Verse was revealed:-- "It is not fitting for the Prophet (ﷺ) and the believers to ask Allah's Forgiveness for the pagans, even if they were their near relatives, after it has become clear to them that they are the dwellers of the (Hell) Fire." (9.113) The other Verse was also revealed:-- "(O Prophet!) Verily, you guide not whom you like, but Allah guides whom He will}}
\hadithdefcmd{bukhari}{3885}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا ابْنُ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم وَذُكِرَ عِنْدَهُ عَمُّهُ فَقَالَ ‏ "‏ لَعَلَّهُ تَنْفَعُهُ شَفَاعَتِي يَوْمَ الْقِيَامَةِ، فَيُجْعَلُ فِي ضَحْضَاحٍ مِنَ النَّارِ، يَبْلُغُ كَعْبَيْهِ، يَغْلِي مِنْهُ دِمَاغُهُ ‏"‏‏.‏ حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ حَدَّثَنَا ابْنُ أَبِي حَازِمٍ وَالدَّرَاوَرْدِيُّ عَنْ يَزِيدَ بِهَذَا، وَقَالَ تَغْلِي مِنْهُ أُمُّ دِمَاغِهِ‏.‏\hadithno{3885}\hadithtrans{Narrated Abu Sa`id Al-Khudri:That he heard the Prophet (ﷺ) when somebody mentioned his uncle (i.e. Abu Talib), saying, "Perhaps my intercession will be helpful to him on the Day of Resurrection so that he may be put in a shallow fire reaching only up to his ankles. His brain will boil from it." Narrated Yazid: (as above, Hadith 224) using the words: "will make his brain boil}}
\hadithdefcmd{bukhari}{3886}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَمَّا كَذَّبَنِي قُرَيْشٌ قُمْتُ فِي الْحِجْرِ، فَجَلاَ اللَّهُ لِي بَيْتَ الْمَقْدِسِ، فَطَفِقْتُ أُخْبِرُهُمْ عَنْ آيَاتِهِ وَأَنَا أَنْظُرُ إِلَيْهِ ‏"‏‏.‏\hadithno{3886}\hadithtrans{Narrated Jabir bin `Abdullah:That he heard Allah's Messenger (ﷺ) saying, "When the people of Quraish did not believe me (i.e. the story of my Night Journey), I stood up in Al-Hijr and Allah displayed Jerusalem in front of me, and I began describing it to them while I was looking at it}}
\hadithdefcmd{bukhari}{3887}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ مَالِكِ بْنِ صَعْصَعَةَ ـ رضى الله عنهما ـ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم حَدَّثَهُمْ عَنْ لَيْلَةَ أُسْرِيَ بِهِ ‏"‏ بَيْنَمَا أَنَا فِي الْحَطِيمِ ـ وَرُبَّمَا قَالَ فِي الْحِجْرِ ـ مُضْطَجِعًا، إِذْ أَتَانِي آتٍ فَقَدَّ ـ قَالَ وَسَمِعْتُهُ يَقُولُ فَشَقَّ ـ مَا بَيْنَ هَذِهِ إِلَى هَذِهِ ـ فَقُلْتُ لِلْجَارُودِ وَهْوَ إِلَى جَنْبِي مَا يَعْنِي بِهِ قَالَ مِنْ ثُغْرَةِ نَحْرِهِ إِلَى شِعْرَتِهِ، وَسَمِعْتُهُ يَقُولُ مِنْ قَصِّهِ إِلَى شِعْرَتِهِ ـ فَاسْتَخْرَجَ قَلْبِي، ثُمَّ أُتِيتُ بِطَسْتٍ مِنْ ذَهَبٍ مَمْلُوءَةٍ إِيمَانًا، فَغُسِلَ قَلْبِي ثُمَّ حُشِيَ، ثُمَّ أُوتِيتُ بِدَابَّةٍ دُونَ الْبَغْلِ وَفَوْقَ الْحِمَارِ أَبْيَضَ ‏"‏‏.‏ ـ فَقَالَ لَهُ الْجَارُودُ هُوَ الْبُرَاقُ يَا أَبَا حَمْزَةَ قَالَ أَنَسٌ نَعَمْ، يَضَعُ خَطْوَهُ عِنْدَ أَقْصَى طَرْفِهِ ـ ‏"‏ فَحُمِلْتُ عَلَيْهِ، فَانْطَلَقَ بِي جِبْرِيلُ حَتَّى أَتَى السَّمَاءَ الدُّنْيَا فَاسْتَفْتَحَ، فَقِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ وَمَنْ مَعَكَ قَالَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ، فَنِعْمَ الْمَجِيءُ جَاءَ فَفَتَحَ، فَلَمَّا خَلَصْتُ، فَإِذَا فِيهَا آدَمُ، فَقَالَ هَذَا أَبُوكَ آدَمُ فَسَلِّمْ عَلَيْهِ‏.‏ فَسَلَّمْتُ عَلَيْهِ فَرَدَّ السَّلاَمَ ثُمَّ قَالَ مَرْحَبًا بِالاِبْنِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ‏.‏ ثُمَّ صَعِدَ حَتَّى أَتَى السَّمَاءَ الثَّانِيَةَ فَاسْتَفْتَحَ، قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ وَمَنْ مَعَكَ قَالَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ فَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَفَتَحَ، فَلَمَّا خَلَصْتُ، إِذَا يَحْيَى وَعِيسَى، وَهُمَا ابْنَا الْخَالَةِ قَالَ هَذَا يَحْيَى وَعِيسَى فَسَلِّمْ عَلَيْهِمَا‏.‏ فَسَلَّمْتُ فَرَدَّا، ثُمَّ قَالاَ مَرْحَبًا بِالأَخِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ‏.‏ ثُمَّ صَعِدَ بِي إِلَى السَّمَاءِ الثَّالِثَةِ، فَاسْتَفْتَحَ قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ وَمَنْ مَعَكَ قَالَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ، فَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَفُتِحَ، فَلَمَّا خَلَصْتُ إِذَا يُوسُفُ‏.‏ قَالَ هَذَا يُوسُفُ فَسَلِّمْ عَلَيْهِ‏.‏ فَسَلَّمْتُ عَلَيْهِ فَرَدَّ، ثُمَّ قَالَ مَرْحَبًا بِالأَخِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ، ثُمَّ صَعِدَ بِي حَتَّى أَتَى السَّمَاءَ الرَّابِعَةَ، فَاسْتَفْتَحَ، قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ وَمَنْ مَعَكَ قَالَ مُحَمَّدٌ‏.‏ قِيلَ أَوَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ، فَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَفُتِحَ، فَلَمَّا خَلَصْتُ إِلَى إِدْرِيسَ قَالَ هَذَا إِدْرِيسُ فَسَلِّمْ عَلَيْهِ‏.‏ فَسَلَّمْتُ عَلَيْهِ فَرَدَّ ثُمَّ قَالَ مَرْحَبًا بِالأَخِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ‏.‏ ثُمَّ صَعِدَ بِي حَتَّى أَتَى السَّمَاءَ الْخَامِسَةَ، فَاسْتَفْتَحَ، قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ وَمَنْ مَعَكَ قَالَ مُحَمَّدٌ صلى الله عليه وسلم‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ، فَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَلَمَّا خَلَصْتُ فَإِذَا هَارُونُ قَالَ هَذَا هَارُونُ فَسَلِّمْ عَلَيْهِ‏.‏ فَسَلَّمْتُ عَلَيْهِ فَرَدَّ ثُمَّ قَالَ مَرْحَبًا بِالأَخِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ‏.‏ ثُمَّ صَعِدَ بِي حَتَّى أَتَى السَّمَاءَ السَّادِسَةَ، فَاسْتَفْتَحَ، قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ مَنْ مَعَكَ قَالَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قَالَ مَرْحَبًا بِهِ، فَنِعْمَ الْمَجِيءُ جَاءَ، فَلَمَّا خَلَصْتُ، فَإِذَا مُوسَى قَالَ هَذَا مُوسَى فَسَلِّمْ عَلَيْهِ، فَسَلَّمْتُ عَلَيْهِ فَرَدَّ ثُمَّ قَالَ مَرْحَبًا بِالأَخِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ‏.‏ فَلَمَّا تَجَاوَزْتُ بَكَى، قِيلَ لَهُ مَا يُبْكِيكَ قَالَ أَبْكِي لأَنَّ غُلاَمًا بُعِثَ بَعْدِي، يَدْخُلُ الْجَنَّةَ مِنْ أُمَّتِهِ أَكْثَرُ مَنْ يَدْخُلُهَا مِنْ أُمَّتِي‏.‏ ثُمَّ صَعِدَ بِي إِلَى السَّمَاءِ السَّابِعَةِ، فَاسْتَفْتَحَ جِبْرِيلُ، قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ وَمَنْ مَعَكَ قَالَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ بُعِثَ إِلَيْهِ‏.‏ قَالَ نَعَمْ‏.‏ قَالَ مَرْحَبًا بِهِ، فَنِعْمَ الْمَجِيءُ جَاءَ فَلَمَّا خَلَصْتُ، فَإِذَا إِبْرَاهِيمُ قَالَ هَذَا أَبُوكَ فَسَلِّمْ عَلَيْهِ‏.‏ قَالَ فَسَلَّمْتُ عَلَيْهِ، فَرَدَّ السَّلاَمَ قَالَ مَرْحَبًا بِالاِبْنِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ‏.‏ ثُمَّ رُفِعَتْ لِي سِدْرَةُ الْمُنْتَهَى، فَإِذَا نَبِقُهَا مِثْلُ قِلاَلِ هَجَرَ، وَإِذَا وَرَقُهَا مِثْلُ آذَانِ الْفِيَلَةِ قَالَ هَذِهِ سِدْرَةُ الْمُنْتَهَى، وَإِذَا أَرْبَعَةُ أَنْهَارٍ نَهْرَانِ بَاطِنَانِ، وَنَهْرَانِ ظَاهِرَانِ‏.‏ فَقُلْتُ مَا هَذَانِ يَا جِبْرِيلُ قَالَ أَمَّا الْبَاطِنَانِ، فَنَهَرَانِ فِي الْجَنَّةِ، وَأَمَّا الظَّاهِرَانِ فَالنِّيلُ وَالْفُرَاتُ‏.‏ ثُمَّ رُفِعَ لِي الْبَيْتُ الْمَعْمُورُ، ثُمَّ أُتِيتُ بِإِنَاءٍ مِنْ خَمْرٍ، وَإِنَاءٍ مِنْ لَبَنٍ وَإِنَاءٍ مِنْ عَسَلٍ، فَأَخَذْتُ اللَّبَنَ، فَقَالَ هِيَ الْفِطْرَةُ أَنْتَ عَلَيْهَا وَأُمَّتُكَ‏.‏ ثُمَّ فُرِضَتْ عَلَىَّ الصَّلَوَاتُ خَمْسِينَ صَلاَةً كُلَّ يَوْمٍ‏.‏ فَرَجَعْتُ فَمَرَرْتُ عَلَى مُوسَى، فَقَالَ بِمَا أُمِرْتَ قَالَ أُمِرْتُ بِخَمْسِينَ صَلاَةً كُلَّ يَوْمٍ‏.‏ قَالَ إِنَّ أُمَّتَكَ لاَ تَسْتَطِيعُ خَمْسِينَ صَلاَةً كُلَّ يَوْمٍ، وَإِنِّي وَاللَّهِ قَدْ جَرَّبْتُ النَّاسَ قَبْلَكَ، وَعَالَجْتُ بَنِي إِسْرَائِيلَ أَشَدَّ الْمُعَالَجَةِ، فَارْجِعْ إِلَى رَبِّكَ فَاسْأَلْهُ التَّخْفِيفَ لأُمَّتِكَ‏.‏ فَرَجَعْتُ، فَوَضَعَ عَنِّي عَشْرًا، فَرَجَعْتُ إِلَى مُوسَى فَقَالَ مِثْلَهُ، فَرَجَعْتُ فَوَضَعَ عَنِّي عَشْرًا، فَرَجَعْتُ إِلَى مُوسَى فَقَالَ مِثْلَهُ، فَرَجَعْتُ فَوَضَعَ عَنِّي عَشْرًا، فَرَجَعْتُ إِلَى مُوسَى فَقَالَ مِثْلَهُ، فَرَجَعْتُ فَأُمِرْتُ بِعَشْرِ صَلَوَاتٍ كُلَّ يَوْمٍ، فَرَجَعْتُ فَقَالَ مِثْلَهُ، فَرَجَعْتُ فَأُمِرْتُ بِخَمْسِ صَلَوَاتٍ كُلَّ يَوْمٍ، فَرَجَعْتُ إِلَى مُوسَى، فَقَالَ بِمَا أُمِرْتَ قُلْتُ أُمِرْتُ بِخَمْسِ صَلَوَاتٍ كُلَّ يَوْمٍ‏.‏ قَالَ إِنَّ أُمَّتَكَ لاَ تَسْتَطِيعُ خَمْسَ صَلَوَاتٍ كُلَّ يَوْمٍ، وَإِنِّي قَدْ جَرَّبْتُ النَّاسَ قَبْلَكَ، وَعَالَجْتُ بَنِي إِسْرَائِيلَ أَشَدَّ الْمُعَالَجَةِ، فَارْجِعْ إِلَى رَبِّكَ فَاسْأَلْهُ التَّخْفِيفَ لأُمَّتِكَ‏.‏ قَالَ سَأَلْتُ رَبِّي حَتَّى اسْتَحْيَيْتُ، وَلَكِنْ أَرْضَى وَأُسَلِّمُ ـ قَالَ ـ فَلَمَّا جَاوَزْتُ نَادَى مُنَادٍ أَمْضَيْتُ فَرِيضَتِي وَخَفَّفْتُ عَنْ عِبَادِي ‏"‏‏.‏\hadithno{3887}\hadithtrans{Narrated Anas bin Malik:Malik bin Sasaa said that Allah's Messenger (ﷺ) described to them his Night Journey saying, "While I was lying in Al-Hatim or Al-Hijr, suddenly someone came to me and cut my body open from here to here." I asked Al-Jarud who was by my side, "What does he mean?" He said, "It means from his throat to his pubic area," or said, "From the top of the chest." The Prophet (ﷺ) further said, "He then took out my heart. Then a gold tray of Belief was brought to me and my heart was washed and was filled (with Belief) and then returned to its original place. Then a white animal which was smaller than a mule and bigger than a donkey was brought to me." (On this Al-Jarud asked, "Was it the Buraq, O Abu Hamza?" I (i.e. Anas) replied in the affirmative). The Prophet (ﷺ) said, "The animal's step (was so wide that it) reached the farthest point within the reach of the animal's sight. I was carried on it, and Gabriel set out with me till we reached the nearest heaven. When he asked for the gate to be opened, it was asked, 'Who is it?' Gabriel answered, 'Gabriel.' It was asked, 'Who is accompanying you?' Gabriel replied, 'Muhammad.' It was asked, 'Has Muhammad been called?' Gabriel replied in the affirmative. Then it was said, 'He is welcomed. What an excellent visit his is!' The gate was opened, and when I went over the first heaven, I saw Adam there. Gabriel said (to me). 'This is your father, Adam; pay him your greetings.' So I greeted him and he returned the greeting to me and said, 'You are welcomed, O pious son and pious Prophet.' Then Gabriel ascended with me till we reached the second heaven. Gabriel asked for the gate to be opened. It was asked, 'Who is it?' Gabriel answered, 'Gabriel.' It was asked, 'Who is accompanying you?' Gabriel replied, 'Muhammad.' It was asked, 'Has he been called?' Gabriel answered in the affirmative. Then it was said, 'He is welcomed. What an excellent visit his is!' The gate was opened. When I went over the second heaven, there I saw Yahya (i.e. John) and `Isa (i.e. Jesus) who were cousins of each other. Gabriel said (to me), 'These are John and Jesus; pay them your greetings.' So I greeted them and both of them returned my greetings to me and said, 'You are welcomed, O pious brother and pious Prophet.' Then Gabriel ascended with me to the third heaven and asked for its gate to be opened. It was asked, 'Who is it?' Gabriel replied, 'Gabriel.' It was asked, 'Who is accompanying you?' Gabriel replied, 'Muhammad.' It was asked, 'Has he been called?' Gabriel replied in the affirmative. Then it was said, 'He is welcomed, what an excellent visit his is!' The gate was opened, and when I went over the third heaven there I saw Joseph. Gabriel said (to me), 'This is Joseph; pay him your greetings.' So I greeted him and he returned the greeting to me and said, 'You are welcomed, O pious brother and pious Prophet.' Then Gabriel ascended with me to the fourth heaven and asked for its gate to be opened. It was asked, 'Who is it?' Gabriel replied, 'Gabriel' It was asked, 'Who is accompanying you?' Gabriel replied, 'Muhammad.' It was asked, 'Has he been called?' Gabriel replied in the affirmative. Then it was said, 'He is welcomed, what an excel lent visit his is!' The gate was opened, and when I went over the fourth heaven, there I saw Idris. Gabriel said (to me), 'This is Idris; pay him your greetings.' So I greeted him and he returned the greeting to me and said, 'You are welcomed, O pious brother and pious Prophet.' Then Gabriel ascended with me to the fifth heaven and asked for its gate to be opened. It was asked, 'Who is it?' Gabriel replied, 'Gabriel.' It was asked. 'Who is accompanying you?' Gabriel replied, 'Muhammad.' It was asked, 'Has he been called?' Gabriel replied in the affirmative. Then it was said He is welcomed, what an excellent visit his is! So when I went over the fifth heaven, there I saw Harun (i.e. Aaron), Gabriel said, (to me). This is Aaron; pay him your greetings.' I greeted him and he returned the greeting to me and said, 'You are welcomed, O pious brother and pious Prophet.' Then Gabriel ascended with me to the sixth heaven and asked for its gate to be opened. It was asked. 'Who is it?' Gabriel replied, 'Gabriel.' It was asked, 'Who is accompanying you?' Gabriel replied, 'Muhammad.' It was asked, 'Has he been called?' Gabriel replied in the affirmative. It was said, 'He is welcomed. What an excellent visit his is!' When I went (over the sixth heaven), there I saw Moses. Gabriel said (to me),' This is Moses; pay him your greetings. So I greeted him and he returned the greetings to me and said, 'You are welcomed, O pious brother and pious Prophet.' When I left him (i.e. Moses) he wept. Someone asked him, 'What makes you weep?' Moses said, 'I weep because after me there has been sent (as Prophet) a young man whose followers will enter Paradise in greater numbers than my followers.' Then Gabriel ascended with me to the seventh heaven and asked for its gate to be opened. It was asked, 'Who is it?' Gabriel replied, 'Gabriel.' It was asked,' Who is accompanying you?' Gabriel replied, 'Muhammad.' It was asked, 'Has he been called?' Gabriel replied in the affirmative. Then it was said, 'He is welcomed. What an excellent visit his is!' So when I went (over the seventh heaven), there I saw Abraham. Gabriel said (to me), 'This is your father; pay your greetings to him.' So I greeted him and he returned the greetings to me and said, 'You are welcomed, O pious son and pious Prophet.' Then I was made to ascend to Sidrat-ul-Muntaha (i.e. the Lote Tree of the utmost boundary) Behold! Its fruits were like the jars of Hajr (i.e. a place near Medina) and its leaves were as big as the ears of elephants. Gabriel said, 'This is the Lote Tree of the utmost boundary) . Behold ! There ran four rivers, two were hidden and two were visible, I asked, 'What are these two kinds of rivers, O Gabriel?' He replied,' As for the hidden rivers, they are two rivers in Paradise and the visible rivers are the Nile and the Euphrates.' Then Al-Bait-ul-Ma'mur (i.e. the Sacred House) was shown to me and a container full of wine and another full of milk and a third full of honey were brought to me. I took the milk. Gabriel remarked, 'This is the Islamic religion which you and your followers are following.' Then the prayers were enjoined on me: They were fifty prayers a day. When I returned, I passed by Moses who asked (me), 'What have you been ordered to do?' I replied, 'I have been ordered to offer fifty prayers a day.' Moses said, 'Your followers cannot bear fifty prayers a day, and by Allah, I have tested people before you, and I have tried my level best with Bani Israel (in vain). Go back to your Lord and ask for reduction to lessen your followers' burden.' So I went back, and Allah reduced ten prayers for me. Then again I came to Moses, but he repeated the same as he had said before. Then again I went back to Allah and He reduced ten more prayers. When I came back to Moses he said the same, I went back to Allah and He ordered me to observe ten prayers a day. When I came back to Moses, he repeated the same advice, so I went back to Allah and was ordered to observe five prayers a day. When I came back to Moses, he said, 'What have you been ordered?' I replied, 'I have been ordered to observe five prayers a day.' He said, 'Your followers cannot bear five prayers a day, and no doubt, I have got an experience of the people before you, and I have tried my level best with Bani Israel, so go back to your Lord and ask for reduction to lessen your follower's burden.' I said, 'I have requested so much of my Lord that I feel ashamed, but I am satisfied now and surrender to Allah's Order.' When I left, I heard a voice saying, 'I have passed My Order and have lessened the burden of My Worshipers}}
\hadithdefcmd{bukhari}{3888}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ فِي قَوْلِهِ تَعَالَى ‏\{‏وَمَا جَعَلْنَا الرُّؤْيَا الَّتِي أَرَيْنَاكَ إِلاَّ فِتْنَةً لِلنَّاسِ‏\}‏ قَالَ هِيَ رُؤْيَا عَيْنٍ، أُرِيَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ إِلَى بَيْتِ الْمَقْدِسِ‏.‏ قَالَ وَالشَّجَرَةَ الْمَلْعُونَةَ فِي الْقُرْآنِ قَالَ هِيَ شَجَرَةُ الزَّقُّومِ‏.‏\hadithno{3888}\hadithtrans{Narrated Ibn `Abbas:Regarding the Statement of Allah" "And We granted the vision (Ascension to the heavens) which We made you see (as an actual eye witness) was only made as a trial for the people." (17.60) Ibn `Abbas added: The sights which Allah's Messenger (ﷺ) was shown on the Night Journey when he was taken to Bait-ulMaqdis (i.e. Jerusalem) were actual sights, (not dreams). And the Cursed Tree (mentioned) in the Qur'an is the tree of Zaqqum (itself)}}
\hadithdefcmd{bukhari}{3889}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ ـ وَكَانَ قَائِدَ كَعْبٍ حِينَ عَمِيَ ـ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ يُحَدِّثُ حِينَ تَخَلَّفَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ‏.‏ بِطُولِهِ، قَالَ ابْنُ بُكَيْرٍ فِي حَدِيثِهِ وَلَقَدْ شَهِدْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم لَيْلَةَ الْعَقَبَةِ حِينَ تَوَاثَقْنَا عَلَى الإِسْلاَمِ، وَمَا أُحِبُّ أَنَّ لِي بِهَا مَشْهَدَ بَدْرٍ وَإِنْ كَانَتْ بَدْرٌ، أَذْكَرَ فِي النَّاسِ مِنْهَا‏.‏\hadithno{3889}\hadithtrans{Narrated `Abdullah bin Ka`b:Who was Ka`b's guide when Ka`b turned blind: I heard Ka`b bin Malik narrating: When he remained behind (i.e. did not Join) the Prophet (ﷺ) in the Ghazwa of Tabuk. Ibn Bukair, in his narration stated that Ka`b said, " I witnessed the Al-`Aqaba pledge of allegiance at night with the Prophet (ﷺ) when we jointly agreed to support Islam with all our efforts I would not like to have attended the Badr battle instead of that 'Aqaba pledge although Badr is more well-known than it, amongst the people}}
\hadithdefcmd{bukhari}{3890}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ كَانَ عَمْرٌو يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ شَهِدَ بِي خَالاَىَ الْعَقَبَةَ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ ابْنُ عُيَيْنَةَ أَحَدُهُمَا الْبَرَاءُ بْنُ مَعْرُورٍ‏.‏\hadithno{3890}\hadithtrans{Narrated Jabir bin `Abdullah:I was present with my two maternal uncles at Al-`Aqaba (where the pledge of allegiance was given). (Ibn 'Uyaina said, "One of the two was Al-Bara' bin Marur)}}
\hadithdefcmd{bukhari}{3891}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ عَطَاءٌ قَالَ جَابِرٌ أَنَا وَأَبِي، وَخَالِي، مِنْ أَصْحَابِ الْعَقَبَةِ‏.‏\hadithno{3891}\hadithtrans{Narrated Jabir:My father, my two maternal uncles and I were among those who took part in the 'Aqaba Pledge}}
\hadithdefcmd{bukhari}{3892}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، قَالَ أَخْبَرَنِي أَبُو إِدْرِيسَ، عَائِذُ اللَّهِ أَنَّ عُبَادَةَ بْنَ الصَّامِتِ ـ مِنَ الَّذِينَ شَهِدُوا بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ـ وَمِنْ أَصْحَابِهِ لَيْلَةَ الْعَقَبَةِ ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَحَوْلَهُ عِصَابَةٌ مِنْ أَصْحَابِهِ ‏ "‏ تَعَالَوْا بَايِعُونِي عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا، وَلاَ تَسْرِقُوا، وَلاَ تَزْنُوا، وَلاَ تَقْتُلُوا أَوْلاَدَكُمْ، وَلاَ تَأْتُونَ بِبُهْتَانٍ تَفْتَرُونَهُ بَيْنَ أَيْدِيكُمْ وَأَرْجُلِكُمْ، وَلاَ تَعْصُونِي فِي مَعْرُوفٍ، فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ، وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَعُوقِبَ بِهِ فِي الدُّنْيَا فَهْوَ لَهُ كَفَّارَةٌ، وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَسَتَرَهُ اللَّهُ فَأَمْرُهُ إِلَى اللَّهِ، إِنْ شَاءَ عَاقَبَهُ، وَإِنْ شَاءَ عَفَا عَنْهُ ‏"‏‏.‏ قَالَ فَبَايَعْتُهُ عَلَى ذَلِكَ‏.‏\hadithno{3892}\hadithtrans{Narrated 'Ubada bin As-Samit:Who had taken part in the battle of Badr with Allah's Messenger (ﷺ) and had been amongst his companions on the night of Al-`Aqaba Pledge: Allah's Messenger (ﷺ), surrounded by a group of his companions said, "Come along and give me the pledge of allegiance that you will not worship anything besides Allah, will not steal, will not commit illegal sexual intercourse will not kill your children, will not utter; slander, invented by yourself, and will not disobey me if I order you to do something good. Whoever among you will respect and fulfill this pledge, will be rewarded by Allah. And if one of you commits any of these sins and is punished in this world then that will be his expiation for it, and if one of you commits any of these sins and Allah screens his sin, then his matter, will rest with Allah: If He will, He will punish him and if He will,. He will excuse him." So I gave the pledge of allegiance to him for these conditions}}
\hadithdefcmd{bukhari}{3893}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنِ الصُّنَابِحِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ ـ رضى الله عنه ـ أَنَّهُ قَالَ إِنِّي مِنَ النُّقَبَاءِ الَّذِينَ بَايَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ بَايَعْنَاهُ عَلَى أَنْ لاَ نُشْرِكَ بِاللَّهِ شَيْئًا، وَلاَ نَسْرِقَ، وَلاَ نَزْنِيَ، وَلاَ نَقْتُلَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ، وَلاَ نَنْتَهِبَ، وَلاَ نَعْصِيَ بِالْجَنَّةِ إِنْ فَعَلْنَا ذَلِكَ، فَإِنْ غَشِينَا مِنْ ذَلِكَ شَيْئًا كَانَ قَضَاءُ ذَلِكَ إِلَى اللَّهِ‏.‏\hadithno{3893}\hadithtrans{Narrated 'Ubada bin As Samit:I was one of the Naqibs who gave the ('Aqaba) Pledge of Allegiance to Allah's Messenger (ﷺ). We gave the pledge of allegiance to him that we would not worship anything other than Allah, would not steal, would not commit illegal sexual intercourse, would not kill a person whose killing Allah has made illegal except rightfully, would not rob each other, and we would not be promised Paradise if we did the above sins, then if we committed one of the above sins, Allah will give His Judgment concerning it}}
\hadithdefcmd{bukhari}{3894}{حَدَّثَنِي فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ تَزَوَّجَنِي النَّبِيُّ صلى الله عليه وسلم وَأَنَا بِنْتُ سِتِّ سِنِينَ، فَقَدِمْنَا الْمَدِينَةَ فَنَزَلْنَا فِي بَنِي الْحَارِثِ بْنِ خَزْرَجٍ، فَوُعِكْتُ فَتَمَرَّقَ شَعَرِي فَوَفَى جُمَيْمَةً، فَأَتَتْنِي أُمِّي أُمُّ رُومَانَ وَإِنِّي لَفِي أُرْجُوحَةٍ وَمَعِي صَوَاحِبُ لِي، فَصَرَخَتْ بِي فَأَتَيْتُهَا لاَ أَدْرِي مَا تُرِيدُ بِي فَأَخَذَتْ بِيَدِي حَتَّى أَوْقَفَتْنِي عَلَى باب الدَّارِ، وَإِنِّي لأَنْهَجُ، حَتَّى سَكَنَ بَعْضُ نَفَسِي، ثُمَّ أَخَذَتْ شَيْئًا مِنْ مَاءٍ فَمَسَحَتْ بِهِ وَجْهِي وَرَأْسِي ثُمَّ أَدْخَلَتْنِي الدَّارَ فَإِذَا نِسْوَةٌ مِنَ الأَنْصَارِ فِي الْبَيْتِ فَقُلْنَ عَلَى الْخَيْرِ وَالْبَرَكَةِ، وَعَلَى خَيْرِ طَائِرٍ‏.‏ فَأَسْلَمَتْنِي إِلَيْهِنَّ فَأَصْلَحْنَ مِنْ شَأْنِي، فَلَمْ يَرُعْنِي إِلاَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ضُحًى، فَأَسْلَمَتْنِي إِلَيْهِ، وَأَنَا يَوْمَئِذٍ بِنْتُ تِسْعِ سِنِينَ‏.‏\hadithno{3894}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) engaged me when I was a girl of six (years). We went to Medina and stayed at the home of Bani-al-Harith bin Khazraj. Then I got ill and my hair fell down. Later on my hair grew (again) and my mother, Um Ruman, came to me while I was playing in a swing with some of my girl friends. She called me, and I went to her, not knowing what she wanted to do to me. She caught me by the hand and made me stand at the door of the house. I was breathless then, and when my breathing became alright, she took some water and rubbed my face and head with it. Then she took me into the house. There in the house I saw some Ansari women who said, "Best wishes and Allah's Blessing and a good luck." Then she entrusted me to them and they prepared me (for the marriage). Unexpectedly Allah's Apostle came to me in the forenoon and my mother handed me over to him, and at that time I was a girl of nine years of age}}
\hadithdefcmd{bukhari}{3895}{حَدَّثَنَا مُعَلًّى، حَدَّثَنَا وُهَيْبٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ أُرِيتُكِ فِي الْمَنَامِ مَرَّتَيْنِ، أَرَى أَنَّكِ فِي سَرَقَةٍ مِنْ حَرِيرٍ وَيَقُولُ هَذِهِ امْرَأَتُكَ فَاكْشِفْ عَنْهَا فَإِذَا هِيَ أَنْتِ فَأَقُولُ إِنْ يَكُ هَذَا مِنْ عِنْدِ اللَّهِ يُمْضِهِ ‏"‏‏.‏\hadithno{3895}\hadithtrans{Narrated `Aisha:That the Prophet (ﷺ) said to her, "You have been shown to me twice in my dream. I saw you pictured on a piece of silk and some-one said (to me). 'This is your wife.' When I uncovered the picture, I saw that it was yours. I said, 'If this is from Allah, it will be done}}
\hadithdefcmd{bukhari}{3896}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، قَالَ تُوُفِّيَتْ خَدِيجَةُ قَبْلَ مَخْرَجِ النَّبِيِّ صلى الله عليه وسلم إِلَى الْمَدِينَةِ بِثَلاَثِ سِنِينَ، فَلَبِثَ سَنَتَيْنِ أَوْ قَرِيبًا مِنْ ذَلِكَ، وَنَكَحَ عَائِشَةَ وَهْىَ بِنْتُ سِتِّ سِنِينَ، ثُمَّ بَنَى بِهَا وَهْىَ بِنْتُ تِسْعِ سِنِينَ‏.‏\hadithno{3896}\hadithtrans{Narrated Hisham's father:Khadija died three years before the Prophet (ﷺ) departed to Medina. He stayed there for two years or so and then he married `Aisha when she was a girl of six years of age, and he consummated that marriage when she was nine years old}}
\hadithdefcmd{bukhari}{3897}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يَقُولُ عُدْنَا خَبَّابًا فَقَالَ هَاجَرْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم نُرِيدُ وَجْهَ اللَّهِ، فَوَقَعَ أَجْرُنَا عَلَى اللَّهِ، فَمِنَّا مَنْ مَضَى، لَمْ يَأْخُذْ مِنْ أَجْرِهِ شَيْئًا، مِنْهُمْ مُصْعَبُ بْنُ عُمَيْرٍ قُتِلَ يَوْمَ أُحُدٍ، وَتَرَكَ نَمِرَةً، فَكُنَّا إِذَا غَطَّيْنَا بِهَا رَأْسَهُ بَدَتْ رِجْلاَهُ، وَإِذَا غَطَّيْنَا رِجْلَيْهِ بَدَا رَأْسُهُ، فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُغَطِّيَ رَأْسَهُ، وَنَجْعَلَ عَلَى رِجْلَيْهِ شَيْئًا مِنْ إِذْخِرٍ‏.‏ وَمِنَّا مَنْ أَيْنَعَتْ لَهُ ثَمَرَتُهُ فَهْوَ يَهْدِبُهَا‏.‏\hadithno{3897}\hadithtrans{Narrated Abu Wail:We visited Khabbab who said, "We migrated with the Prophet (ﷺ) for Allah's Sake, so our reward became due and sure with Allah. Some of us passed away without taking anything of their rewards (in this world) and one of them was Mus`ab bin `Umair who was martyred on the day (of the battle) of Uhud leaving a striped woolen cloak. When we covered his head with it, his feet became naked, and when we covered his feet, his head became naked. So Allah's Messenger (ﷺ) ordered us to cover his head and put some Idhkhir (i.e. a special kind of grass) on his feet. (On the other hand) some of us have had their fruits ripened (in this world) and they are collecting them}}
\hadithdefcmd{bukhari}{3898}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ ـ هُوَ ابْنُ زَيْدٍ ـ عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، قَالَ سَمِعْتُ عُمَرَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الأَعْمَالُ بِالنِّيَّةِ، فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى دُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا، فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ، وَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ، فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ صلى الله عليه وسلم ‏"‏‏.‏\hadithno{3898}\hadithtrans{Narrated `Umar:I heard the Prophet (ﷺ) saying, "The reward of deeds depends on the intentions, so whoever emigrated for the worldly benefits or to marry a woman, his emigration was for that for which he emigrated, but whoever emigrated for the Sake of Allah and His Apostle, his emigration is for Allah and His Apostle}}
\hadithdefcmd{bukhari}{3899}{حَدَّثَنِي إِسْحَاقُ بْنُ يَزِيدَ الدِّمَشْقِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، قَالَ حَدَّثَنِي أَبُو عَمْرٍو الأَوْزَاعِيُّ، عَنْ عَبْدَةَ بْنِ أَبِي لُبَابَةَ، عَنْ مُجَاهِدِ بْنِ جَبْرٍ الْمَكِّيِّ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يَقُولُ لاَ هِجْرَةَ بَعْدَ الْفَتْحِ‏.‏\hadithno{3899}\hadithtrans{Narrated Mujahid bin Jabir Al-Makki:`Abdullah bin `Umar used to say, "There is no more Hijrah (i.e. migration) after the Conquest of Mecca}}
\hadithdefcmd{bukhari}{3900}{وَحَدَّثَنِي الأَوْزَاعِيُّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، قَالَ زُرْتُ عَائِشَةَ مَعَ عُبَيْدِ بْنِ عُمَيْرٍ اللَّيْثِيِّ فَسَأَلْنَاهَا عَنِ الْهِجْرَةِ، فَقَالَتْ لاَ هِجْرَةَ الْيَوْمَ، كَانَ الْمُؤْمِنُونَ يَفِرُّ أَحَدُهُمْ بِدِينِهِ إِلَى اللَّهِ تَعَالَى وَإِلَى رَسُولِهِ صلى الله عليه وسلم مَخَافَةَ أَنْ يُفْتَنَ عَلَيْهِ، فَأَمَّا الْيَوْمَ فَقَدْ أَظْهَرَ اللَّهُ الإِسْلاَمَ، وَالْيَوْمَ يَعْبُدُ رَبَّهُ حَيْثُ شَاءَ، وَلَكِنْ جِهَادٌ وَنِيَّةٌ‏.‏\hadithno{3900}\hadithtrans{Narrated 'Ata bin Abi Rabah:`Ubaid bin `Umar Al-Laithi and I visited Aisha and asked her about the Hijra (i.e. migration), and she said, "Today there is no (Hijrah) emigration. A believer used to run away with his religion to Allah and His Apostle lest he should be put to trial because of his religion. Today Allah has made Islam triumphant, and today a believer can worship his Lord wherever he likes. But the deeds that are still rewardable (in place of emigration) are Jihad and good intentions." (See Hadith No. 42 Vol)}}
\hadithdefcmd{bukhari}{3901}{حَدَّثَنِي زَكَرِيَّاءُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ نُمَيْرٍ، قَالَ هِشَامٌ فَأَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ سَعْدًا، قَالَ اللَّهُمَّ إِنَّكَ تَعْلَمُ أَنَّهُ لَيْسَ أَحَدٌ أَحَبَّ إِلَىَّ أَنْ أُجَاهِدَهُمْ فِيكَ مِنْ قَوْمٍ كَذَّبُوا رَسُولَكَ صلى الله عليه وسلم وَأَخْرَجُوهُ، اللَّهُمَّ فَإِنِّي أَظُنُّ أَنَّكَ قَدْ وَضَعْتَ الْحَرْبَ بَيْنَنَا وَبَيْنَهُمْ‏.‏ وَقَالَ أَبَانُ بْنُ يَزِيدَ حَدَّثَنَا هِشَامٌ عَنْ أَبِيهِ أَخْبَرَتْنِي عَائِشَةُ مِنْ قَوْمٍ كَذَّبُوا نَبِيَّكَ وَأَخْرَجُوهُ مِنْ قُرَيْشٍ‏.‏\hadithno{3901}\hadithtrans{Narrated Aisha:Sa`d said, "O Allah! You know that there is none against whom I am eager to fight more willingly for Your Cause than those people who disbelieved Your Apostle and drove him out (of his city). O Allah! I think that You have ended the fight between us and them}}
\hadithdefcmd{bukhari}{3902}{حَدَّثَنَا مَطَرُ بْنُ الْفَضْلِ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بُعِثَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَرْبَعِينَ سَنَةً، فَمَكُثَ بِمَكَّةَ ثَلاَثَ عَشْرَةَ سَنَةً يُوحَى إِلَيْهِ، ثُمَّ أُمِرَ بِالْهِجْرَةِ فَهَاجَرَ عَشْرَ سِنِينَ، وَمَاتَ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ‏.‏\hadithno{3902}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) started receiving the Divine Inspiration at the age of forty. Then he stayed in Mecca for thirteen years, receiving the Divine Revelation. Then he was ordered to migrate and he lived as an Emigrant for ten years and then died at the age of sixty-three (years)}}
\hadithdefcmd{bukhari}{3903}{حَدَّثَنِي مَطَرُ بْنُ الْفَضْلِ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَكَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ ثَلاَثَ عَشْرَةَ، وَتُوُفِّيَ وَهْوَ ابْنُ ثَلاَثٍ وَسِتِّينَ‏.‏\hadithno{3903}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) stayed in Mecca for thirteen years (after receiving the first Divine Inspiration) and died at the age of sixty-three}}
\hadithdefcmd{bukhari}{3904}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عُبَيْدٍ ـ يَعْنِي ابْنَ حُنَيْنٍ ـ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَلَسَ عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ إِنَّ عَبْدًا خَيَّرَهُ اللَّهُ بَيْنَ أَنْ يُؤْتِيَهُ مِنْ زَهْرَةِ الدُّنْيَا مَا شَاءَ، وَبَيْنَ مَا عِنْدَهُ، فَاخْتَارَ مَا عِنْدَهُ ‏"‏‏.‏ فَبَكَى أَبُو بَكْرٍ وَقَالَ فَدَيْنَاكَ بِآبَائِنَا وَأُمَّهَاتِنَا‏.‏ فَعَجِبْنَا لَهُ، وَقَالَ النَّاسُ انْظُرُوا إِلَى هَذَا الشَّيْخِ، يُخْبِرُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ عَبْدٍ خَيَّرَهُ اللَّهُ بَيْنَ أَنْ يُؤْتِيَهُ مِنْ زَهْرَةِ الدُّنْيَا وَبَيْنَ مَا عِنْدَهُ وَهْوَ يَقُولُ فَدَيْنَاكَ بِآبَائِنَا وَأُمَّهَاتِنَا‏.‏ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُوَ الْمُخَيَّرَ، وَكَانَ أَبُو بَكْرٍ هُوَ أَعْلَمَنَا بِهِ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ أَمَنِّ النَّاسِ عَلَىَّ فِي صُحْبَتِهِ وَمَالِهِ أَبَا بَكْرٍ، وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً مِنْ أُمَّتِي لاَتَّخَذْتُ أَبَا بَكْرٍ، إِلاَّ خُلَّةَ الإِسْلاَمِ، لاَ يَبْقَيَنَّ فِي الْمَسْجِدِ خَوْخَةٌ إِلاَّ خَوْخَةُ أَبِي بَكْرٍ ‏"‏‏.‏\hadithno{3904}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) sat on the pulpit and said, "Allah has given one of His Slaves the choice of receiving the splendor and luxury of the worldly life whatever he likes or to accept the good (of the Hereafter) which is with Allah. So he has chosen that good which is with Allah." On that Abu Bakr wept and said, "Our fathers and mothers be sacrificed for you." We became astonished at this. The people said, "Look at this old man! Allah's Messenger (ﷺ) talks about a Slave of Allah to whom He has given the option to choose either the splendor of this worldly life or the good which is with Him, while he says. 'our fathers and mothers be sacrificed for you." But it was Allah's Messenger (ﷺ) who had been given the option, and Abu Bakr knew it better than we. Allah's Messenger (ﷺ) added, "No doubt, I am indebted to Abu Bakr more than to anybody else regarding both his companionship and his wealth. And if I had to take a Khalil from my followers, I would certainly have taken Abu Bakr, but the fraternity of Islam is. sufficient. Let no door (i.e. Khoukha) of the Mosque remain open, except the door of Abu Bakr}}
\hadithdefcmd{bukhari}{3905}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَمْ أَعْقِلْ أَبَوَىَّ قَطُّ إِلاَّ وَهُمَا يَدِينَانِ الدِّينَ، وَلَمْ يَمُرَّ عَلَيْنَا يَوْمٌ إِلاَّ يَأْتِينَا فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم طَرَفَىِ النَّهَارِ بُكْرَةً وَعَشِيَّةً، فَلَمَّا ابْتُلِيَ الْمُسْلِمُونُ خَرَجَ أَبُو بَكْرٍ مُهَاجِرًا نَحْوَ أَرْضِ الْحَبَشَةِ، حَتَّى بَلَغَ بَرْكَ الْغِمَادِ لَقِيَهُ ابْنُ الدَّغِنَةِ وَهْوَ سَيِّدُ الْقَارَةِ‏.‏ فَقَالَ أَيْنَ تُرِيدُ يَا أَبَا بَكْرٍ فَقَالَ أَبُو بَكْرٍ أَخْرَجَنِي قَوْمِي، فَأُرِيدُ أَنْ أَسِيحَ فِي الأَرْضِ وَأَعْبُدَ رَبِّي‏.‏ قَالَ ابْنُ الدَّغِنَةِ فَإِنَّ مِثْلَكَ يَا أَبَا بَكْرٍ لاَ يَخْرُجُ وَلاَ يُخْرَجُ، إِنَّكَ تَكْسِبُ الْمَعْدُومَ، وَتَصِلُ الرَّحِمَ وَتَحْمِلُ الْكَلَّ، وَتَقْرِي الضَّيْفَ، وَتُعِينُ عَلَى نَوَائِبِ الْحَقِّ، فَأَنَا لَكَ جَارٌ، ارْجِعْ وَاعْبُدْ رَبَّكَ بِبَلَدِكَ‏.‏ فَرَجَعَ وَارْتَحَلَ مَعَهُ ابْنُ الدَّغِنَةِ، فَطَافَ ابْنُ الدَّغِنَةِ عَشِيَّةً فِي أَشْرَافِ قُرَيْشٍ، فَقَالَ لَهُمْ إِنَّ أَبَا بَكْرٍ لاَ يَخْرُجُ مِثْلُهُ وَلاَ يُخْرَجُ، أَتُخْرِجُونَ رَجُلاً يَكْسِبُ الْمَعْدُومَ، وَيَصِلُ الرَّحِمَ، وَيَحْمِلُ الْكَلَّ، وَيَقْرِي الضَّيْفَ، وَيُعِينُ عَلَى نَوَائِبِ الْحَقِّ فَلَمْ تُكَذِّبْ قُرَيْشٌ بِجِوَارِ ابْنِ الدَّغِنَةِ، وَقَالُوا لاِبْنِ الدَّغِنَةِ مُرْ أَبَا بَكْرٍ فَلْيَعْبُدْ رَبَّهُ فِي دَارِهِ، فَلْيُصَلِّ فِيهَا وَلْيَقْرَأْ مَا شَاءَ، وَلاَ يُؤْذِينَا بِذَلِكَ، وَلاَ يَسْتَعْلِنْ بِهِ، فَإِنَّا نَخْشَى أَنْ يَفْتِنَ نِسَاءَنَا وَأَبْنَاءَنَا‏.‏ فَقَالَ ذَلِكَ ابْنُ الدَّغِنَةِ لأَبِي بَكْرٍ، فَلَبِثَ أَبُو بَكْرٍ بِذَلِكَ يَعْبُدُ رَبَّهُ فِي دَارِهِ، وَلاَ يَسْتَعْلِنُ بِصَلاَتِهِ، وَلاَ يَقْرَأُ فِي غَيْرِ دَارِهِ، ثُمَّ بَدَا لأَبِي بَكْرٍ فَابْتَنَى مَسْجِدًا بِفِنَاءِ دَارِهِ وَكَانَ يُصَلِّي فِيهِ وَيَقْرَأُ الْقُرْآنَ، فَيَنْقَذِفُ عَلَيْهِ نِسَاءُ الْمُشْرِكِينَ وَأَبْنَاؤُهُمْ، وَهُمْ يَعْجَبُونَ مِنْهُ، وَيَنْظُرُونَ إِلَيْهِ، وَكَانَ أَبُو بَكْرٍ رَجُلاً بَكَّاءً، لاَ يَمْلِكُ عَيْنَيْهِ إِذَا قَرَأَ الْقُرْآنَ، وَأَفْزَعَ ذَلِكَ أَشْرَافَ قُرَيْشٍ مِنَ الْمُشْرِكِينَ، فَأَرْسَلُوا إِلَى ابْنِ الدَّغِنَةِ، فَقَدِمَ عَلَيْهِمْ‏.‏ فَقَالُوا إِنَّا كُنَّا أَجَرْنَا أَبَا بَكْرٍ بِجِوَارِكَ، عَلَى أَنْ يَعْبُدَ رَبَّهُ فِي دَارِهِ، فَقَدْ جَاوَزَ ذَلِكَ، فَابْتَنَى مَسْجِدًا بِفِنَاءِ دَارِهِ، فَأَعْلَنَ بِالصَّلاَةِ وَالْقِرَاءَةِ فِيهِ، وَإِنَّا قَدْ خَشِينَا أَنْ يَفْتِنَ نِسَاءَنَا وَأَبْنَاءَنَا فَانْهَهُ، فَإِنْ أَحَبَّ أَنْ يَقْتَصِرَ عَلَى أَنْ يَعْبُدَ رَبَّهُ فِي دَارِهِ فَعَلَ، وَإِنْ أَبَى إِلاَّ أَنْ يُعْلِنَ بِذَلِكَ فَسَلْهُ أَنْ يَرُدَّ إِلَيْكَ ذِمَّتَكَ، فَإِنَّا قَدْ كَرِهْنَا أَنْ نُخْفِرَكَ، وَلَسْنَا مُقِرِّينَ لأَبِي بَكْرٍ الاِسْتِعْلاَنَ‏.‏ قَالَتْ عَائِشَةُ فَأَتَى ابْنُ الدَّغِنَةِ إِلَى أَبِي بَكْرٍ فَقَالَ قَدْ عَلِمْتَ الَّذِي عَاقَدْتُ لَكَ عَلَيْهِ، فَإِمَّا أَنْ تَقْتَصِرَ عَلَى ذَلِكَ، وَإِمَّا أَنْ تَرْجِعَ إِلَىَّ ذِمَّتِي، فَإِنِّي لاَ أُحِبُّ أَنْ تَسْمَعَ الْعَرَبُ أَنِّي أُخْفِرْتُ فِي رَجُلٍ عَقَدْتُ لَهُ‏.‏ فَقَالَ أَبُو بَكْرٍ فَإِنِّي أَرُدُّ إِلَيْكَ جِوَارَكَ وَأَرْضَى بِجِوَارِ اللَّهِ عَزَّ وَجَلَّ‏.‏ وَالنَّبِيُّ صلى الله عليه وسلم يَوْمَئِذٍ بِمَكَّةَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِلْمُسْلِمِينَ ‏"‏ إِنِّي أُرِيتُ دَارَ هِجْرَتِكُمْ ذَاتَ نَخْلٍ بَيْنَ لاَبَتَيْنِ ‏"‏‏.‏ وَهُمَا الْحَرَّتَانِ، فَهَاجَرَ مَنْ هَاجَرَ قِبَلَ الْمَدِينَةِ، وَرَجَعَ عَامَّةُ مَنْ كَانَ هَاجَرَ بِأَرْضِ الْحَبَشَةِ إِلَى الْمَدِينَةِ، وَتَجَهَّزَ أَبُو بَكْرٍ قِبَلَ الْمَدِينَةِ، فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَلَى رِسْلِكَ، فَإِنِّي أَرْجُو أَنْ يُؤْذَنَ لِي ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ وَهَلْ تَرْجُو ذَلِكَ بِأَبِي أَنْتَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ فَحَبَسَ أَبُو بَكْرٍ نَفْسَهُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لِيَصْحَبَهُ، وَعَلَفَ رَاحِلَتَيْنِ كَانَتَا عِنْدَهُ وَرَقَ السَّمُرِ وَهْوَ الْخَبَطُ أَرْبَعَةَ أَشْهُرٍ‏.‏ قَالَ ابْنُ شِهَابٍ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ فَبَيْنَمَا نَحْنُ يَوْمًا جُلُوسٌ فِي بَيْتِ أَبِي بَكْرٍ فِي نَحْرِ الظَّهِيرَةِ قَالَ قَائِلٌ لأَبِي بَكْرٍ هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُتَقَنِّعًا ـ فِي سَاعَةٍ لَمْ يَكُنْ يَأْتِينَا فِيهَا ـ فَقَالَ أَبُو بَكْرٍ فِدَاءٌ لَهُ أَبِي وَأُمِّي، وَاللَّهِ مَا جَاءَ بِهِ فِي هَذِهِ السَّاعَةِ إِلاَّ أَمْرٌ‏.‏ قَالَتْ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاسْتَأْذَنَ، فَأُذِنَ لَهُ فَدَخَلَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأَبِي بَكْرٍ ‏"‏ أَخْرِجْ مَنْ عِنْدَكَ ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ إِنَّمَا هُمْ أَهْلُكَ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنِّي قَدْ أُذِنَ لِي فِي الْخُرُوجِ ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ الصَّحَابَةُ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ فَخُذْ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ إِحْدَى رَاحِلَتَىَّ هَاتَيْنِ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بِالثَّمَنِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ فَجَهَّزْنَاهُمَا أَحَثَّ الْجَهَازِ، وَصَنَعْنَا لَهُمَا سُفْرَةً فِي جِرَابٍ، فَقَطَعَتْ أَسْمَاءُ بِنْتُ أَبِي بَكْرٍ قِطْعَةً مَنْ نِطَاقِهَا فَرَبَطَتْ بِهِ عَلَى فَمِ الْجِرَابِ، فَبِذَلِكَ سُمِّيَتْ ذَاتَ النِّطَاقِ ـ قَالَتْ ـ ثُمَّ لَحِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ بِغَارٍ فِي جَبَلِ ثَوْرٍ فَكَمَنَا فِيهِ ثَلاَثَ لَيَالٍ، يَبِيتُ عِنْدَهُمَا عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ وَهْوَ غُلاَمٌ شَابٌّ ثَقِفٌ لَقِنٌ، فَيُدْلِجُ مِنْ عِنْدِهِمَا بِسَحَرٍ، فَيُصْبِحُ مَعَ قُرَيْشٍ بِمَكَّةَ كَبَائِتٍ، فَلاَ يَسْمَعُ أَمْرًا يُكْتَادَانِ بِهِ إِلاَّ وَعَاهُ، حَتَّى يَأْتِيَهُمَا بِخَبَرِ ذَلِكَ حِينَ يَخْتَلِطُ الظَّلاَمُ، وَيَرْعَى عَلَيْهِمَا عَامِرُ بْنُ فُهَيْرَةَ مَوْلَى أَبِي بَكْرٍ مِنْحَةً مِنْ غَنَمٍ، فَيُرِيحُهَا عَلَيْهِمَا حِينَ يَذْهَبُ سَاعَةٌ مِنَ الْعِشَاءِ، فَيَبِيتَانِ فِي رِسْلٍ وَهْوَ لَبَنُ مِنْحَتِهِمَا وَرَضِيفِهِمَا، حَتَّى يَنْعِقَ بِهَا عَامِرُ بْنُ فُهَيْرَةَ بِغَلَسٍ، يَفْعَلُ ذَلِكَ فِي كُلِّ لَيْلَةٍ مِنْ تِلْكَ اللَّيَالِي الثَّلاَثِ، وَاسْتَأْجَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ رَجُلاً مِنْ بَنِي الدِّيلِ، وَهْوَ مِنْ بَنِي عَبْدِ بْنِ عَدِيٍّ هَادِيًا خِرِّيتًا ـ وَالْخِرِّيتُ الْمَاهِرُ بِالْهِدَايَةِ ـ قَدْ غَمَسَ حِلْفًا فِي آلِ الْعَاصِ بْنِ وَائِلٍ السَّهْمِيِّ، وَهْوَ عَلَى دِينِ كُفَّارِ قُرَيْشٍ فَأَمِنَاهُ، فَدَفَعَا إِلَيْهِ رَاحِلَتَيْهِمَا، وَوَاعَدَاهُ غَارَ ثَوْرٍ بَعْدَ ثَلاَثِ لَيَالٍ بِرَاحِلَتَيْهِمَا صُبْحَ ثَلاَثٍ، وَانْطَلَقَ مَعَهُمَا عَامِرُ بْنُ فُهَيْرَةَ وَالدَّلِيلُ فَأَخَذَ بِهِمْ طَرِيقَ السَّوَاحِلِ‏.‏\hadithno{3905}\hadithtrans{Narrated 'Aisha: (the wife of the Prophet) I never remembered my parents believing in any religion other than the true religion (i.e. Islam), and (I don't remember) a single day passing without our being visited by Allah's Messenger (ﷺ) in the morning and in the evening. When the Muslims were put to test (i.e. troubled by the pagans), Abu Bakr set out migrating to the land of Ethiopia, and when he reached Bark-al-Ghimad, Ibn Ad-Daghina, the chief of the tribe of Qara, met him and said, "O Abu Bakr! Where are you going?" Abu Bakr replied, "My people have turned me out (of my country), so I want to wander on the earth and worship my Lord." Ibn Ad-Daghina said, "O Abu Bakr! A man like you should not leave his home-land, nor should he be driven out, because you help the destitute earn their livings, and you keep good relations with your Kith and kin, help the weak and poor, entertain guests generously, and help the calamity-stricken persons. Therefore I am your protector. Go back and worship your Lord in your town." So Abu Bakr returned and Ibn Ad-Daghina accompanied him. In the evening Ibn Ad-Daghina visited the nobles of Quraish and said to them. "A man like Abu Bakr should not leave his homeland, nor should he be driven out. Do you (i.e. Quraish) drive out a man who helps the destitute earn their living, keeps good relations with his Kith and kin, helps the weak and poor, entertains guests generously and helps the calamity-stricken persons?" So the people of Quraish could not refuse Ibn Ad-Daghina's protection, and they said to Ibn Ad-Daghina, "Let Abu Bakr worship his Lord in his house. He can pray and recite there whatever he likes, but he should not hurt us with it, and should not do it publicly, because we are afraid that he may affect our women and children." Ibn Ad-Daghina told Abu Bakr of all that. Abu Bakr stayed in that state, worshipping his Lord in his house. He did not pray publicly, nor did he recite Quran outside his house. Then a thought occurred to Abu Bakr to build a mosque in front of his house, and there he used to pray and recite the Quran. The women and children of the pagans began to gather around him in great number. They used to wonder at him and look at him. Abu Bakr was a man who used to weep too much, and he could not help weeping on reciting the Quran. That situation scared the nobles of the pagans of Quraish, so they sent for Ibn Ad-Daghina. When he came to them, they said, "We accepted your protection of Abu Bakr on condition that he should worship his Lord in his house, but he has violated the conditions and he has built a mosque in front of his house where he prays and recites the Quran publicly. We are now afraid that he may affect our women and children unfavorably. So, prevent him from that. If he likes to confine the worship of his Lord to his house, he may do so, but if he insists on doing that openly, ask him to release you from your obligation to protect him, for we dislike to break our pact with you, but we deny Abu Bakr the right to announce his act publicly." Ibn Ad-Daghina went to Abu- Bakr and said, ("O Abu Bakr!) You know well what contract I have made on your behalf; now, you are either to abide by it, or else release me from my obligation of protecting you, because I do not want the 'Arabs hear that my people have dishonored a contract I have made on behalf of another man." Abu Bakr replied, "I release you from your pact to protect me, and am pleased with the protection from Allah." At that time the Prophet (ﷺ) was in Mecca, and he said to the Muslims, "In a dream I have been shown your migration place, a land of date palm trees, between two mountains, the two stony tracts." So, some people migrated to Medina, and most of those people who had previously migrated to the land of Ethiopia, returned to Medina. Abu Bakr also prepared to leave for Medina, but Allah's Messenger (ﷺ) said to him, "Wait for a while, because I hope that I will be allowed to migrate also." Abu Bakr said, "Do you indeed expect this? Let my father be sacrificed for you!" The Prophet (ﷺ) said, "Yes." So Abu Bakr did not migrate for the sake of Allah's Messenger (ﷺ) in order to accompany him. He fed two she-camels he possessed with the leaves of As-Samur tree that fell on being struck by a stick for four months. One day, while we were sitting in Abu Bakr's house at noon, someone said to Abu Bakr, "This is Allah's Messenger (ﷺ) with his head covered coming at a time at which he never used to visit us before." Abu Bakr said, "May my parents be sacrificed for him. By Allah, he has not come at this hour except for a great necessity." So Allah's Messenger (ﷺ) came and asked permission to enter, and he was allowed to enter. When he entered, he said to Abu Bakr. "Tell everyone who is present with you to go away." Abu Bakr replied, "There are none but your family. May my father be sacrificed for you, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said, "I have been given permission to migrate." Abu Bakr said, "Shall I accompany you? May my father be sacrificed for you, O Allah's Messenger (ﷺ)!" Allah's Messenger (ﷺ) said, "Yes." Abu Bakr said, "O Allah's Messenger (ﷺ)! May my father be sacrificed for you, take one of these two she-camels of mine." Allah's Messenger (ﷺ) replied, "(I will accept it) with payment." So we prepared the baggage quickly and put some journey food in a leather bag for them. Asma, Abu Bakr's daughter, cut a piece from her waist belt and tied the mouth of the leather bag with it, and for that reason she was named Dhat-un-Nitaqain (i.e. the owner of two belts). Then Allah's Messenger (ﷺ) and Abu Bakr reached a cave on the mountain of Thaur and stayed there for three nights. 'Abdullah bin Abi Bakr who was intelligent and a sagacious youth, used to stay (with them) overnight. He used to leave them before day break so that in the morning he would be with Quraish as if he had spent the night in Mecca. He would keep in mind any plot made against them, and when it became dark he would (go and) inform them of it. 'Amir bin Fuhaira, the freed slave of Abu Bakr, used to bring the milch sheep (of his master, Abu Bakr) to them a little while after nightfall in order to rest the sheep there. So they always had fresh milk at night, the milk of their sheep, and the milk which they warmed by throwing heated stones in it. 'Amir bin Fuhaira would then call the herd away when it was still dark (before daybreak). He did the same in each of those three nights. Allah's Messenger (ﷺ) and Abu Bakr had hired a man from the tribe of Bani Ad-Dail from the family of Bani Abd bin Adi as an expert guide, and he was in alliance with the family of Al-'As bin Wail As-Sahmi and he was on the religion of the infidels of Quraish. The Prophet (ﷺ) and Abu Bakr trusted him and gave him their two she-camels and took his promise to bring their two she camels to the cave of the mountain of Thaur in the morning after three nights later. And (when they set out), 'Amir bin Fuhaira and the guide went along with them and the guide led them along the sea-shore}}
\hadithdefcmd{bukhari}{3906}{قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ مَالِكٍ الْمُدْلِجِيُّ ـ وَهْوَ ابْنُ أَخِي سُرَاقَةَ بْنِ مَالِكِ بْنِ جُعْشُمٍ ـ أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّهُ، سَمِعَ سُرَاقَةَ بْنَ جُعْشُمٍ، يَقُولُ جَاءَنَا رُسُلُ كُفَّارِ قُرَيْشٍ يَجْعَلُونَ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ دِيَةَ كُلِّ وَاحِدٍ مِنْهُمَا، مَنْ قَتَلَهُ أَوْ أَسَرَهُ، فَبَيْنَمَا أَنَا جَالِسٌ فِي مَجْلِسٍ مِنْ مَجَالِسِ قَوْمِي بَنِي مُدْلِجٍ أَقْبَلَ رَجُلٌ مِنْهُمْ حَتَّى قَامَ عَلَيْنَا وَنَحْنُ جُلُوسٌ، فَقَالَ يَا سُرَاقَةُ، إِنِّي قَدْ رَأَيْتُ آنِفًا أَسْوِدَةً بِالسَّاحِلِ ـ أُرَاهَا مُحَمَّدًا وَأَصْحَابَهُ‏.‏ قَالَ سُرَاقَةُ فَعَرَفْتُ أَنَّهُمْ هُمْ، فَقُلْتُ لَهُ إِنَّهُمْ لَيْسُوا بِهِمْ، وَلَكِنَّكَ رَأَيْتَ فُلاَنًا وَفُلاَنًا انْطَلَقُوا بِأَعْيُنِنَا‏.‏ ثُمَّ لَبِثْتُ فِي الْمَجْلِسِ سَاعَةً، ثُمَّ قُمْتُ فَدَخَلْتُ فَأَمَرْتُ جَارِيَتِي أَنْ تَخْرُجَ بِفَرَسِي وَهْىَ مِنْ وَرَاءِ أَكَمَةٍ فَتَحْبِسَهَا عَلَىَّ، وَأَخَذْتُ رُمْحِي، فَخَرَجْتُ بِهِ مِنْ ظَهْرِ الْبَيْتِ، فَحَطَطْتُ بِزُجِّهِ الأَرْضَ، وَخَفَضْتُ عَالِيَهُ حَتَّى أَتَيْتُ فَرَسِي فَرَكِبْتُهَا، فَرَفَعْتُهَا تُقَرَّبُ بِي حَتَّى دَنَوْتُ مِنْهُمْ، فَعَثَرَتْ بِي فَرَسِي، فَخَرَرْتُ عَنْهَا فَقُمْتُ، فَأَهْوَيْتُ يَدِي إِلَى كِنَانَتِي فَاسْتَخْرَجْتُ مِنْهَا الأَزْلاَمَ، فَاسْتَقْسَمْتُ بِهَا أَضُرُّهُمْ أَمْ لاَ فَخَرَجَ الَّذِي أَكْرَهُ، فَرَكِبْتُ فَرَسِي، وَعَصَيْتُ الأَزْلاَمَ، تُقَرِّبُ بِي حَتَّى إِذَا سَمِعْتُ قِرَاءَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ لاَ يَلْتَفِتُ، وَأَبُو بَكْرٍ يُكْثِرُ الاِلْتِفَاتَ سَاخَتْ يَدَا فَرَسِي فِي الأَرْضِ حَتَّى بَلَغَتَا الرُّكْبَتَيْنِ، فَخَرَرْتُ عَنْهَا ثُمَّ زَجَرْتُهَا فَنَهَضَتْ، فَلَمْ تَكَدْ تُخْرِجُ يَدَيْهَا، فَلَمَّا اسْتَوَتْ قَائِمَةً، إِذَا لأَثَرِ يَدَيْهَا عُثَانٌ سَاطِعٌ فِي السَّمَاءِ مِثْلُ الدُّخَانِ، فَاسْتَقْسَمْتُ بِالأَزْلاَمِ، فَخَرَجَ الَّذِي أَكْرَهُ، فَنَادَيْتُهُمْ بِالأَمَانِ فَوَقَفُوا، فَرَكِبْتُ فَرَسِي حَتَّى جِئْتُهُمْ، وَوَقَعَ فِي نَفْسِي حِينَ لَقِيتُ مَا لَقِيتُ مِنَ الْحَبْسِ عَنْهُمْ أَنْ سَيَظْهَرُ أَمْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ إِنَّ قَوْمَكَ قَدْ جَعَلُوا فِيكَ الدِّيَةَ‏.‏ وَأَخْبَرْتُهُمْ أَخْبَارَ مَا يُرِيدُ النَّاسُ بِهِمْ، وَعَرَضْتُ عَلَيْهِمِ الزَّادَ وَالْمَتَاعَ، فَلَمْ يَرْزَآنِي وَلَمْ يَسْأَلاَنِي إِلاَّ أَنْ قَالَ أَخْفِ عَنَّا‏.‏ فَسَأَلْتُهُ أَنْ يَكْتُبَ لِي كِتَابَ أَمْنٍ، فَأَمَرَ عَامِرَ بْنَ فُهَيْرَةَ، فَكَتَبَ فِي رُقْعَةٍ مِنْ أَدِيمٍ، ثُمَّ مَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَقِيَ الزُّبَيْرَ فِي رَكْبٍ مِنَ الْمُسْلِمِينَ كَانُوا تِجَارًا قَافِلِينَ مِنَ الشَّأْمِ، فَكَسَا الزُّبَيْرُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ ثِيَابَ بَيَاضٍ، وَسَمِعَ الْمُسْلِمُونَ بِالْمَدِينَةِ مَخْرَجَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ مَكَّةَ، فَكَانُوا يَغْدُونَ كُلَّ غَدَاةٍ إِلَى الْحَرَّةِ فَيَنْتَظِرُونَهُ، حَتَّى يَرُدَّهُمْ حَرُّ الظَّهِيرَةِ، فَانْقَلَبُوا يَوْمًا بَعْدَ مَا أَطَالُوا انْتِظَارَهُمْ، فَلَمَّا أَوَوْا إِلَى بُيُوتِهِمْ، أَوْفَى رَجُلٌ مِنْ يَهُودَ عَلَى أُطُمٍ مِنْ آطَامِهِمْ لأَمْرٍ يَنْظُرُ إِلَيْهِ، فَبَصُرَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَأَصْحَابِهِ مُبَيَّضِينَ يَزُولُ بِهِمُ السَّرَابُ، فَلَمْ يَمْلِكِ الْيَهُودِيُّ أَنْ قَالَ بِأَعْلَى صَوْتِهِ يَا مَعَاشِرَ الْعَرَبِ هَذَا جَدُّكُمُ الَّذِي تَنْتَظِرُونَ‏.‏ فَثَارَ الْمُسْلِمُونَ إِلَى السِّلاَحِ، فَتَلَقَّوْا رَسُولَ اللَّهِ صلى الله عليه وسلم بِظَهْرِ الْحَرَّةِ، فَعَدَلَ بِهِمْ ذَاتَ الْيَمِينِ حَتَّى نَزَلَ بِهِمْ فِي بَنِي عَمْرِو بْنِ عَوْفٍ، وَذَلِكَ يَوْمَ الاِثْنَيْنِ مِنْ شَهْرِ رَبِيعٍ الأَوَّلِ، فَقَامَ أَبُو بَكْرٍ لِلنَّاسِ، وَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَامِتًا، فَطَفِقَ مَنْ جَاءَ مِنَ الأَنْصَارِ مِمَّنْ لَمْ يَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُحَيِّي أَبَا بَكْرٍ، حَتَّى أَصَابَتِ الشَّمْسُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَقْبَلَ أَبُو بَكْرٍ حَتَّى ظَلَّلَ عَلَيْهِ بِرِدَائِهِ، فَعَرَفَ النَّاسُ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ، فَلَبِثَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَنِي عَمْرِو بْنِ عَوْفٍ بِضْعَ عَشْرَةَ لَيْلَةً وَأُسِّسَ الْمَسْجِدُ الَّذِي أُسِّسَ عَلَى التَّقْوَى، وَصَلَّى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم، ثُمَّ رَكِبَ رَاحِلَتَهُ فَسَارَ يَمْشِي مَعَهُ النَّاسُ حَتَّى بَرَكَتْ عِنْدَ مَسْجِدِ الرَّسُولِ صلى الله عليه وسلم بِالْمَدِينَةِ، وَهْوَ يُصَلِّي فِيهِ يَوْمَئِذٍ رِجَالٌ مِنَ الْمُسْلِمِينَ، وَكَانَ مِرْبَدًا لِلتَّمْرِ لِسُهَيْلٍ وَسَهْلٍ غُلاَمَيْنِ يَتِيمَيْنِ فِي حَجْرِ أَسْعَدَ بْنِ زُرَارَةَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ بَرَكَتْ بِهِ رَاحِلَتُهُ ‏"‏ هَذَا إِنْ شَاءَ اللَّهُ الْمَنْزِلُ ‏"‏‏.‏ ثُمَّ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْغُلاَمَيْنِ، فَسَاوَمَهُمَا بِالْمِرْبَدِ لِيَتَّخِذَهُ مَسْجِدًا، فَقَالاَ لاَ بَلْ نَهَبُهُ لَكَ يَا رَسُولَ اللَّهِ، ثُمَّ بَنَاهُ مَسْجِدًا، وَطَفِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْقُلُ مَعَهُمُ اللَّبِنَ فِي بُنْيَانِهِ، وَيَقُولُ وَهُوَ يَنْقُلُ اللَّبِنَ ‏"‏ هَذَا الْحِمَالُ لاَ حِمَالَ خَيْبَرْ هَذَا أَبَرُّ رَبَّنَا وَأَطْهَرْ ‏"‏‏.‏ وَيَقُولُ ‏"‏ اللَّهُمَّ إِنَّ الأَجْرَ أَجْرُ الآخِرَهْ فَارْحَمِ الأَنْصَارَ وَالْمُهَاجِرَهْ ‏"‏‏.‏ فَتَمَثَّلَ بِشِعْرِ رَجُلٍ مِنَ الْمُسْلِمِينَ لَمْ يُسَمَّ لِي‏.‏ قَالَ ابْنُ شِهَابٍ وَلَمْ يَبْلُغْنَا فِي الأَحَادِيثِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَمَثَّلَ بِبَيْتِ شِعْرٍ تَامٍّ غَيْرِ هذه الآيات\hadithno{3906}\hadithtrans{The nephew of Suraqa bin Ju'shum said that his father informed him that he heard Suraqa bin Ju'shum saying, "The messengers of the heathens of Quraish came to us declaring that they had assigned for the persons who would kill or arrest Allah's Messenger (ﷺ) and Abu Bakr, a reward equal to their bloodmoney. While I was sitting in one of the gatherings of my tribe, Bani Mudlij, a man from them came to us and stood up while we were sitting, and said, "O Suraqa! No doubt, I have just seen some people far away on the seashore, and I think they are Muhammad and his companions." Suraqa added, "I too realized that it must have been they. But I said 'No, it is not they, but you have seen so-and-so, and so-and-so whom we saw set out.' I stayed in the gathering for a while and then got up and left for my home and ordered my slave-girl to get my horse which was behind a hillock, and keep it ready for me. Then I took my spear and left by the back door of my house dragging the lower end of the spear on the ground and keeping it low. Then I reached my horse, mounted it and made it gallop. When I approached them (i.e. Muhammad and Abu Bakr), my horse stumbled and I fell down from it, Then I stood up, got hold of my quiver and took out the divining arrows and drew lots as to whether I should harm them (i.e. the Prophet (ﷺ) and Abu Bakr) or not, and the lot which I disliked came out. But I remounted my horse and let it gallop, giving no importance to the divining arrows. When I heard the recitation of the Quran by Allah's Messenger (ﷺ) who did not look hither and thither while Abu Bakr was doing it often, suddenly the forelegs of my horse sank into the ground up to the knees, and I fell down from it. Then I rebuked it and it got up but could hardly take out its forelegs from the ground, and when it stood up straight again, its fore-legs caused dust to rise up in the sky like smoke. Then again I drew lots with the divining arrows, and the lot which I disliked, came out. So I called upon them to feel secure. They stopped, and I remounted my horse and went to them. When I saw how I had been hampered from harming them, it came to my mind that the cause of Allah's Messenger (ﷺ) (i.e. Islam) will become victorious. So I said to him, "Your people have assigned a reward equal to the bloodmoney for your head." Then I told them all the plans the people of Mecca had made concerning them. Then I offered them some journey food and goods but they refused to take anything and did not ask for anything, but the Prophet (ﷺ) said, "Do not tell others about us." Then I requested him to write for me a statement of security and peace. He ordered 'Amr bin Fuhaira who wrote it for me on a parchment, and then Allah's Messenger (ﷺ) proceeded on his way. Narrated 'Urwa bin Az-Zubair:Allah's Messenger (ﷺ) met Az-Zubair in a caravan of Muslim merchants who were returning from Sham. Az-Zubair provided Allah's Messenger (ﷺ) and Abu Bakr with white clothes to wear. When the Muslims of Medina heard the news of the departure of Allah's Messenger (ﷺ) from Mecca (towards Medina), they started going to the Harra every morning . They would wait for him till the heat of the noon forced them to return. One day, after waiting for a long while, they returned home, and when they went into their houses, a Jew climbed up the roof of one of the forts of his people to look for something, and he saw Allah's Messenger (ﷺ) and his companions dressed in white clothes, emerging out of the desert mirage. The Jew could not help shouting at the top of his voice, "O you 'Arabs! Here is your great man whom you have been waiting for!" So all the Muslims rushed to their arms and received Allah's Messenger (ﷺ) on the summit of Harra. The Prophet (ﷺ) turned with them to the right and alighted at the quarters of Bani 'Amr bin 'Auf, and this was on Monday in the month of Rabi-ul-Awal. Abu Bakr stood up, receiving the people while Allah's Messenger (ﷺ) sat down and kept silent. Some of the Ansar who came and had not seen Allah's Messenger (ﷺ) before, began greeting Abu Bakr, but when the sunshine fell on Allah's Messenger (ﷺ) and Abu Bakr came forward and shaded him with his sheet only then the people came to know Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) stayed with Bani 'Amr bin 'Auf for ten nights and established the mosque (mosque of Quba) which was founded on piety. Allah's Messenger (ﷺ) prayed in it and then mounted his she-camel and proceeded on, accompanied by the people till his she-camel knelt down at (the place of) the Mosque of Allah's Messenger (ﷺ) at Medina. Some Muslims used to pray there in those days, and that place was a yard for drying dates belonging to Suhail and Sahl, the orphan boys who were under the guardianship of 'Asad bin Zurara. When his she-camel knelt down, Allah's Messenger (ﷺ) said, "This place, Allah willing, will be our abiding place." Allah's Messenger (ﷺ) then called the two boys and told them to suggest a price for that yard so that he might take it as a mosque. The two boys said, "No, but we will give it as a gift, O Allah's Messenger (ﷺ)!" Allah's Messenger (ﷺ) then built a mosque there. The Prophet (ﷺ) himself started carrying unburnt bricks for its building and while doing so, he was saying "This load is better than the load of Khaibar, for it is more pious in the Sight of Allah and purer and better rewardable." He was also saying, "O Allah! The actual reward is the reward in the Hereafter, so bestow Your Mercy on the Ansar and the Emigrants." Thus the Prophet (ﷺ) recited (by way of proverb) the poem of some Muslim poet whose name is unknown to me. (Ibn Shihab said, "In the Hadiths it does not occur that Allah's Apostle recited a complete poetic verse other than this one)}}
\hadithdefcmd{bukhari}{3907}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، وَفَاطِمَةَ، عَنْ أَسْمَاءَ، رضى الله عنها صَنَعْتُ سُفْرَةً لِلنَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ حِينَ أَرَادَا الْمَدِينَةَ، فَقُلْتُ لأَبِي مَا أَجِدُ شَيْئًا أَرْبُطُهُ إِلاَّ نِطَاقِي‏.‏ قَالَ فَشُقِّيهِ‏.‏ فَفَعَلْتُ، فَسُمِّيتُ ذَاتَ النِّطَاقَيْنِ‏.‏\hadithno{3907}\hadithtrans{Narrated Asma:I prepared the journey food for the Prophet (ﷺ) and Abu Bakr when they wanted (to migrate to) Medina. I said to my father (Abu Bakr), "I do not have anything to tie the container of the journey food with except my waist belt." He said, "Divide it lengthwise into two." I did so, and for this reason I was named 'Dhat-un-Nitaqain' (i.e. the owner of two belts). (Ibn `Abbas said, "Asma', Dhat-un-Nitaq)}}
\hadithdefcmd{bukhari}{3908}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ لَمَّا أَقْبَلَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْمَدِينَةِ تَبِعَهُ سُرَاقَةُ بْنُ مَالِكِ بْنِ جُعْشُمٍ، فَدَعَا عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم فَسَاخَتْ بِهِ فَرَسُهُ‏.‏ قَالَ ادْعُ اللَّهَ لِي وَلاَ أَضُرُّكَ‏.‏ فَدَعَا لَهُ‏.‏ قَالَ فَعَطِشَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَمَرَّ بِرَاعٍ، قَالَ أَبُو بَكْرٍ فَأَخَذْتُ قَدَحًا فَحَلَبْتُ فِيهِ كُثْبَةً مِنْ لَبَنٍ، فَأَتَيْتُهُ فَشَرِبَ حَتَّى رَضِيتُ‏.‏\hadithno{3908}\hadithtrans{Narrated Al-Bara:When the Prophet (ﷺ) migrated to Medina, Suraqa bin Malik bin Ju'shum pursued him. The Prophet (ﷺ) invoked evil on him, therefore the forelegs of his horse sank into the ground. Suraqa said (to the Prophet ), "Invoke Allah to rescue me, and I will not harm you. "The Prophet (ﷺ) invoked Allah for him. Then Allah's Messenger (ﷺ) felt thirsty and he passed by a shepherd. Abu Bakr said, "I took a bowl and milked a little milk in it and brought it to the Prophet (ﷺ) and he drank till I was pleased}}
\hadithdefcmd{bukhari}{3909}{حَدَّثَنِي زَكَرِيَّاءُ بْنُ يَحْيَى، عَنْ أَبِي أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ ـ رضى الله عنها ـ أَنَّهَا حَمَلَتْ بِعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَتْ فَخَرَجْتُ وَأَنَا مُتِمٌّ، فَأَتَيْتُ الْمَدِينَةَ، فَنَزَلْتُ بِقُبَاءٍ، فَوَلَدْتُهُ بِقُبَاءٍ، ثُمَّ أَتَيْتُ بِهِ النَّبِيَّ صلى الله عليه وسلم فَوَضَعْتُهُ فِي حَجْرِهِ، ثُمَّ دَعَا بِتَمْرَةٍ، فَمَضَغَهَا، ثُمَّ تَفَلَ فِي فِيهِ، فَكَانَ أَوَّلَ شَىْءٍ دَخَلَ جَوْفَهُ رِيقُ رَسُولِ اللَّهِ صلى الله عليه وسلم، ثُمَّ حَنَّكَهُ بِتَمْرَةٍ ثُمَّ دَعَا لَهُ وَبَرَّكَ عَلَيْهِ، وَكَانَ أَوَّلَ مَوْلُودٍ وُلِدَ فِي الإِسْلاَمِ‏.‏ تَابَعَهُ خَالِدُ بْنُ مَخْلَدٍ عَنْ عَلِيِّ بْنِ مُسْهِرٍ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ أَسْمَاءَ ـ رضى الله عنها ـ أَنَّهَا هَاجَرَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْىَ حُبْلَى‏.‏\hadithno{3909}\hadithtrans{Narrated Asma:That she conceived `Abdullah bin Az-Zubair. She added, "I migrated to Medina while I was at full term of pregnancy and alighted at Quba where I gave birth to him. Then I brought him to the Prophet (ﷺ) and put him in his lap. The Prophet (ﷺ) asked for a date, chewed it, and put some of its juice in the child's mouth. So, the first thing that entered the child's stomach was the saliva of Allah's Messenger (ﷺ). Then the Prophet rubbed the child's palate with a date and invoked for Allah's Blessings on him, and he was the first child born amongst the Emigrants in the Islamic Land (i.e. Medina)}}
\hadithdefcmd{bukhari}{3910}{حَدَّثَنَا قُتَيْبَةُ، عَنْ أَبِي أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَوَّلُ مَوْلُودٍ وُلِدَ فِي الإِسْلاَمِ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ، أَتَوْا بِهِ النَّبِيَّ صلى الله عليه وسلم فَأَخَذَ النَّبِيُّ صلى الله عليه وسلم تَمْرَةً فَلاَكَهَا ثُمَّ أَدْخَلَهَا فِي فِيهِ، فَأَوَّلُ مَا دَخَلَ بَطْنَهُ رِيقُ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3910}\hadithtrans{Narrated Aisha:The first child who was born in the Islamic Land (i.e. Medina) amongst the Emigrants, was `Abdullah bin Az-Zubair. They brought him to the Prophet. The Prophet (ﷺ) took a date, and after chewing it, put its juice in his mouth. So the first thing that went into the child's stomach, was the saliva of the Prophet}}
\hadithdefcmd{bukhari}{3911}{حَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ قَالَ أَقْبَلَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِلَى الْمَدِينَةِ وَهْوَ مُرْدِفٌ أَبَا بَكْرٍ، وَأَبُو بَكْرٍ شَيْخٌ يُعْرَفُ، وَنَبِيُّ اللَّهِ صلى الله عليه وسلم شَابٌّ لاَ يُعْرَفُ، قَالَ فَيَلْقَى الرَّجُلُ أَبَا بَكْرٍ فَيَقُولُ يَا أَبَا بَكْرٍ، مَنْ هَذَا الرَّجُلُ الَّذِي بَيْنَ يَدَيْكَ فَيَقُولُ هَذَا الرَّجُلُ يَهْدِينِي السَّبِيلَ‏.‏ قَالَ فَيَحْسِبُ الْحَاسِبُ أَنَّهُ إِنَّمَا يَعْنِي الطَّرِيقَ، وَإِنَّمَا يَعْنِي سَبِيلَ الْخَيْرِ، فَالْتَفَتَ أَبُو بَكْرٍ، فَإِذَا هُوَ بِفَارِسٍ قَدْ لَحِقَهُمْ، فَقَالَ يَا رَسُولَ اللَّهِ، هَذَا فَارِسٌ قَدْ لَحِقَ بِنَا‏.‏ فَالْتَفَتَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ اللَّهُمَّ اصْرَعْهُ ‏"‏‏.‏ فَصَرَعَهُ الْفَرَسُ، ثُمَّ قَامَتْ تُحَمْحِمُ فَقَالَ يَا نَبِيَّ اللَّهِ مُرْنِي بِمَا شِئْتَ‏.‏ قَالَ ‏"‏ فَقِفْ مَكَانَكَ، لاَ تَتْرُكَنَّ أَحَدًا يَلْحَقُ بِنَا ‏"‏‏.‏ قَالَ فَكَانَ أَوَّلَ النَّهَارِ جَاهِدًا عَلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم، وَكَانَ آخِرَ النَّهَارِ مَسْلَحَةً لَهُ، فَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَانِبَ الْحَرَّةِ، ثُمَّ بَعَثَ إِلَى الأَنْصَارِ، فَجَاءُوا إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم فَسَلَّمُوا عَلَيْهِمَا، وَقَالُوا ارْكَبَا آمِنَيْنِ مُطَاعَيْنِ‏.‏ فَرَكِبَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ، وَحَفُّوا دُونَهُمَا بِالسِّلاَحِ، فَقِيلَ فِي الْمَدِينَةِ جَاءَ نَبِيُّ اللَّهِ، جَاءَ نَبِيُّ اللَّهِ صلى الله عليه وسلم‏.‏ فَأَشْرَفُوا يَنْظُرُونَ وَيَقُولُونَ جَاءَ نَبِيُّ اللَّهِ، جَاءَ نَبِيُّ اللَّهِ‏.‏ فَأَقْبَلَ يَسِيرُ حَتَّى نَزَلَ جَانِبَ دَارِ أَبِي أَيُّوبَ، فَإِنَّهُ لَيُحَدِّثُ أَهْلَهُ، إِذْ سَمِعَ بِهِ عَبْدُ اللَّهِ بْنُ سَلاَمٍ وَهْوَ فِي نَخْلٍ لأَهْلِهِ يَخْتَرِفُ لَهُمْ، فَعَجِلَ أَنْ يَضَعَ الَّذِي يَخْتَرِفُ لَهُمْ فِيهَا، فَجَاءَ وَهْىَ مَعَهُ، فَسَمِعَ مِنْ نَبِيِّ اللَّهِ صلى الله عليه وسلم ثُمَّ رَجَعَ إِلَى أَهْلِهِ، فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ أَىُّ بُيُوتِ أَهْلِنَا أَقْرَبُ ‏"‏‏.‏ فَقَالَ أَبُو أَيُّوبَ أَنَا يَا نَبِيَّ اللَّهِ، هَذِهِ دَارِي، وَهَذَا بَابِي‏.‏ قَالَ ‏"‏ فَانْطَلِقْ فَهَيِّئْ لَنَا مَقِيلاً ‏"‏‏.‏ قَالَ قُومَا عَلَى بَرَكَةِ اللَّهِ‏.‏ فَلَمَّا جَاءَ نَبِيُّ اللَّهِ صلى الله عليه وسلم جَاءَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ اللَّهِ، وَأَنَّكَ جِئْتَ بِحَقٍّ، وَقَدْ عَلِمَتْ يَهُودُ أَنِّي سَيِّدُهُمْ وَابْنُ سَيِّدِهِمْ، وَأَعْلَمُهُمْ وَابْنُ أَعْلَمِهِمْ، فَادْعُهُمْ فَاسْأَلْهُمْ عَنِّي قَبْلَ أَنْ يَعْلَمُوا أَنِّي قَدْ أَسْلَمْتُ، فَإِنَّهُمْ إِنْ يَعْلَمُوا أَنِّي قَدْ أَسْلَمْتُ قَالُوا فِيَّ مَا لَيْسَ فِيَّ‏.‏ فَأَرْسَلَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَأَقْبَلُوا فَدَخَلُوا عَلَيْهِ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا مَعْشَرَ الْيَهُودِ، وَيْلَكُمُ اتَّقُوا اللَّهَ، فَوَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ إِنَّكُمْ لَتَعْلَمُونَ أَنِّي رَسُولُ اللَّهِ حَقًّا، وَأَنِّي جِئْتُكُمْ بِحَقٍّ فَأَسْلِمُوا ‏"‏‏.‏ قَالُوا مَا نَعْلَمُهُ‏.‏ قَالُوا لِلنَّبِيِّ صلى الله عليه وسلم قَالَهَا ثَلاَثَ مِرَارٍ‏.‏ قَالَ ‏"‏ فَأَىُّ رَجُلٍ فِيكُمْ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ‏"‏‏.‏ قَالُوا ذَاكَ سَيِّدُنَا وَابْنُ سَيِّدِنَا، وَأَعْلَمُنَا وَابْنُ أَعْلَمِنَا‏.‏ قَالَ ‏"‏ أَفَرَأَيْتُمْ إِنْ أَسْلَمَ ‏"‏‏.‏ قَالُوا حَاشَا لِلَّهِ، مَا كَانَ لِيُسْلِمَ‏.‏ قَالَ ‏"‏ أَفَرَأَيْتُمْ إِنْ أَسْلَمَ ‏"‏‏.‏ قَالُوا حَاشَا لِلَّهِ، مَا كَانَ لِيُسْلِمَ‏.‏ قَالَ ‏"‏ يَا ابْنَ سَلاَمٍ، اخْرُجْ عَلَيْهِمْ ‏"‏‏.‏ فَخَرَجَ فَقَالَ يَا مَعْشَرَ الْيَهُودِ، اتَّقُوا اللَّهَ، فَوَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ إِنَّكُمْ لَتَعْلَمُونَ أَنَّهُ رَسُولُ اللَّهِ، وَأَنَّهُ جَاءَ بِحَقٍّ‏.‏ فَقَالُوا كَذَبْتَ‏.‏ فَأَخْرَجَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3911}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) arrived at Medina with Abu Bakr, riding behind him on the same camel. Abu Bakr was an elderly man known to the people, while Allah's Messenger (ﷺ) was a youth that was unknown. Thus, if a man met Abu Bakr, he would say, "O Abu Bakr! Who is this man in front of you?" Abu Bakr would say, "This man shows me the Way," One would think that Abu Bakr meant the road, while in fact, Abu Bakr meant the way of virtue and good. Then Abu Bakr looked behind and saw a horse-rider pursuing them. He said, "O Allah's Messenger (ﷺ)! This is a horse-rider pursuing us." The Prophet (ﷺ) looked behind and said, "O Allah! Cause him to fall down." So the horse threw him down and got up neighing. After that the rider, Suraqa said, "O Allah's Prophet! Order me whatever you want." The Prophet said, "Stay where you are and do not allow anybody to reach us." So, in the first part of the day Suraqa was an enemy of Allah's Prophet and in the last part of it, he was a protector. Then Allah's Apostle alighted by the side of the Al-Harra and sent a message to the Ansar, and they came to Allah's Prophet and Abu Bakr, and having greeted them, they said, "Ride (your she-camels) safe and obeyed." Allah's Messenger (ﷺ) and Abu Bakr rode and the Ansar, carrying their arms, surrounded them. The news that Allah's Prophet had come circulated in Medina. The people came out and were eagerly looking and saying "Allah's Prophet has come! Allah's Prophet has come! So the Prophet (ﷺ) went on till he alighted near the house of Abu Ayub. While the Prophet (ﷺ) was speaking with the family members of Abu Ayub, `Abdullah bin Salam heard the news of his arrival while he himself was picking the dates for his family from his family garden. He hurried to the Prophet (ﷺ) carrying the dates which he had collected for his family from the garden. He listened to Allah's Prophet and then went home. Then Allah's Prophet said, "Which is the nearest of the houses of our kith and kin?" Abu Ayub replied, "Mine, O Allah's Prophet! This is my house and this is my gate." The Prophet (ﷺ) said, "Go and prepare a place for our midday rest." Abu Ayub said, "Get up (both of you) with Allah's Blessings." So when Allah's Prophet went into the house, `Abdullah bin Salam came and said "I testify that you (i.e. Muhammad) are Apostle of Allah and that you have come with the Truth. The Jews know well that I am their chief and the son of their chief and the most learned amongst them and the son of the most learned amongst them. So send for them (i.e. Jews) and ask them about me before they know that I have embraced Islam, for if they know that they will say about me things which are not correct." So Allah's Messenger (ﷺ) sent for them, and they came and entered. Allah's Messenger (ﷺ) said to them, "O (the group of) Jews! Woe to you: be afraid of Allah. By Allah except Whom none has the right to be worshipped, you people know for certain, that I am Apostle of Allah and that I have come to you with the Truth, so embrace Islam." The Jews replied, "We do not know this." So they said this to the Prophet and he repeated it thrice. Then he said, "What sort of a man is `Abdullah bin Salam amongst you?" They said, "He is our chief and the son of our chief and the most learned man, and the son of the most learned amongst us." He said, "What would you think if he should embrace Islam?" They said, "Allah forbid! He can not embrace Islam." He said, " What would you think if he should embrace Islam?" They said, "Allah forbid! He can not embrace Islam." He said, "What would you think if he should embrace Islam?" They said, "Allah forbid! He can not embrace Islam." He said, "O Ibn Salam! Come out to them." He came out and said, "O (the group of) Jews! Be afraid of Allah except Whom none has the right to be worshipped. You know for certain that he is Apostle of Allah and that he has brought a True Religion!' They said, "You tell a lie." On that Allah's Messenger (ﷺ) turned them out}}
\hadithdefcmd{bukhari}{3912}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ يَعْنِي، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، رضى الله عنه قَالَ كَانَ فَرَضَ لِلْمُهَاجِرِينَ الأَوَّلِينَ أَرْبَعَةَ آلاَفٍ فِي أَرْبَعَةٍ، وَفَرَضَ لاِبْنِ عُمَرَ ثَلاَثَةَ آلاَفٍ وَخَمْسَمِائَةٍ فَقِيلَ لَهُ هُوَ مِنَ الْمُهَاجِرِينَ، فَلِمَ نَقَصْتَهُ مِنْ أَرْبَعَةِ آلاَفٍ فَقَالَ إِنَّمَا هَاجَرَ بِهِ أَبَوَاهُ‏.‏ يَقُولُ لَيْسَ هُوَ كَمَنْ هَاجَرَ بِنَفْسِهِ‏.‏\hadithno{3912}\hadithtrans{Narrated Ibn `Umar:`Umar bin Al-Khattab fixed a grant of 4000 (Dirhams) for every Early Emigrant (i.e. Muhajir) and fixed a grant of 3500 (Dirhams) only for Ibn `Umar. Somebody said to `Umar, "Ibn `Umar is also one of the Early Emigrants; why do you give him less than four-thousand?" `Umar replied, "His parents took him with them when they migrated, so he was not like the one who had migrated by himself}}
\hadithdefcmd{bukhari}{3913}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ خَبَّابٍ، قَالَ هَاجَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3913}\hadithtrans{Narrated Khabbab:We migrated with Allah's Messenger (ﷺ) (See Hadith No. 253 below)}}
\hadithdefcmd{bukhari}{3914}{وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ شَقِيقَ بْنَ سَلَمَةَ، قَالَ حَدَّثَنَا خَبَّابٌ، قَالَ هَاجَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَبْتَغِي وَجْهَ اللَّهِ، وَوَجَبَ أَجْرُنَا عَلَى اللَّهِ، فَمِنَّا مَنْ مَضَى لَمْ يَأْكُلْ مِنْ أَجْرِهِ شَيْئًا، مِنْهُمْ مُصْعَبُ بْنُ عُمَيْرٍ، قُتِلَ يَوْمَ أُحُدٍ فَلَمْ نَجِدْ شَيْئًا نُكَفِّنُهُ فِيهِ، إِلاَّ نَمِرَةً كُنَّا إِذَا غَطَّيْنَا بِهَا رَأْسَهُ خَرَجَتْ رِجْلاَهُ، فَإِذَا غَطَّيْنَا رِجْلَيْهِ خَرَجَ رَأْسُهُ، فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُغْطِيَ رَأْسَهُ بِهَا، وَنَجْعَلَ عَلَى رِجْلَيْهِ مِنْ إِذْخِرٍ، وَمِنَّا مَنْ أَيْنَعَتْ لَهُ ثَمَرَتُهُ فَهْوَ يَهْدِبُهَا‏.‏\hadithno{3914}\hadithtrans{Narrated Khabbab:We migrated with Allah's Messenger (ﷺ) seeking Allah's Countenance, so our rewards became due and sure with Allah. Some of us passed away without eating anything of their rewards in this world. One of these was Mus`ab bin `Umair who was martyred on the day of the battle of Uhud. We did not find anything to shroud his body with except a striped cloak. When we covered his head with it, his feet remained uncovered, and when we covered his feet with it, his head remained uncovered. So Allah's Apostle ordered us to cover his head with it and put some Idhkhir (i.e. a kind of grass) over his feet. And there are some amongst us whose fruits have ripened and they are collecting them (i.e. they have received their rewards in this world)}}
\hadithdefcmd{bukhari}{3915}{حَدَّثَنَا يَحْيَى بْنُ بِشْرٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا عَوْفٌ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، قَالَ حَدَّثَنِي أَبُو بُرْدَةَ بْنُ أَبِي مُوسَى الأَشْعَرِيُّ، قَالَ قَالَ لِي عَبْدُ اللَّهِ بْنُ عُمَرَ هَلْ تَدْرِي مَا قَالَ أَبِي لأَبِيكَ قَالَ قُلْتُ لاَ‏.‏ قَالَ فَإِنَّ أَبِي قَالَ لأَبِيكَ يَا أَبَا مُوسَى، هَلْ يَسُرُّكَ إِسْلاَمُنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِجْرَتُنَا مَعَهُ، وَجِهَادُنَا مَعَهُ، وَعَمَلُنَا كُلُّهُ مَعَهُ، بَرَدَ لَنَا، وَأَنَّ كُلَّ عَمَلٍ عَمِلْنَاهُ بَعْدَهُ نَجَوْنَا مِنْهُ كَفَافًا رَأْسًا بِرَأْسٍ فَقَالَ أَبِي لاَ وَاللَّهِ، قَدْ جَاهَدْنَا بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَصَلَّيْنَا، وَصُمْنَا، وَعَمِلْنَا خَيْرًا كَثِيرًا، وَأَسْلَمَ عَلَى أَيْدِينَا بَشَرٌ كَثِيرٌ، وَإِنَّا لَنَرْجُو ذَلِكَ‏.‏ فَقَالَ أَبِي لَكِنِّي أَنَا وَالَّذِي نَفْسُ عُمَرَ بِيَدِهِ لَوَدِدْتُ أَنَّ ذَلِكَ بَرَدَ لَنَا، وَأَنَّ كُلَّ شَىْءٍ عَمِلْنَاهُ بَعْدُ نَجَوْنَا مِنْهُ كَفَافًا رَأْسًا بِرَأْسٍ‏.‏ فَقُلْتُ إِنَّ أَبَاكَ وَاللَّهِ خَيْرٌ مِنْ أَبِي‏.‏\hadithno{3915}\hadithtrans{Narrated Abu Burda Bin Abi Musa Al-Ash`ari:`Abdullah bin `Umar said to me, "Do you know what my father said to your father once?" I said, "No." He said, "My father said to your father, 'O Abu Musa, will it please you that we will be rewarded for our conversion to Islam with Allah's Messenger (ﷺ) and our migration with him, and our Jihad with him and all our good deeds which we did, with him, and that all the deeds we did after his death will be disregarded whether good or bad?' Your father (i.e. Abu Musa) said, 'No, by Allah, we took part in Jihad after Allah's Messenger (ﷺ) , prayed and did plenty of good deeds, and many people have embraced Islam at our hands, and no doubt, we expect rewards from Allah for these good deeds.' On that my father (i.e. `Umar) said, 'As for myself, By Him in Whose Hand `Umar's soul is, I wish that the deeds done by us at the time of the Prophet (ﷺ) remain rewardable while whatsoever we did after the death of the Prophet (ﷺ) be enough to save us from Punishment in that the good deeds compensate for the bad ones.' " On that I said (to Ibn `Umar), "By Allah, your father was better than my father}}
\hadithdefcmd{bukhari}{3916}{حَدَّثَنِي مُحَمَّدُ بْنُ صَبَّاحٍ ـ أَوْ بَلَغَنِي عَنْهُ ـ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ إِذَا قِيلَ لَهُ هَاجَرَ قَبْلَ أَبِيهِ يَغْضَبُ، قَالَ وَقَدِمْتُ أَنَا وَعُمَرُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَجَدْنَاهُ قَائِلاً فَرَجَعْنَا إِلَى الْمَنْزِلِ، فَأَرْسَلَنِي عُمَرُ وَقَالَ اذْهَبْ فَانْظُرْ هَلِ اسْتَيْقَظَ فَأَتَيْتُهُ، فَدَخَلْتُ عَلَيْهِ فَبَايَعْتُهُ، ثُمَّ انْطَلَقْتُ إِلَى عُمَرَ، فَأَخْبَرْتُهُ أَنَّهُ قَدِ اسْتَيْقَظَ، فَانْطَلَقْنَا إِلَيْهِ نُهَرْوِلُ هَرْوَلَةً حَتَّى دَخَلَ عَلَيْهِ فَبَايَعَهُ ثُمَّ بَايَعْتُهُ‏.‏\hadithno{3916}\hadithtrans{Narrated Abu `Uthman:I heard that Ibn `Umar used to become angry if someone mentioned that he had migrated before his father (`Umar), and he used to say, " `Umar and I came to Allah's Messenger (ﷺ) and found him having his midday rest, so we returned home. Then `Umar sent me again (to the Prophet (ﷺ) ) and said, 'Go and see whether he is awake.' I went to him and entered his place and gave him the pledge of allegiance. Then I went back to `Umar and informed him that the Prophet (ﷺ) was awake. So we both went, running slowly, and when `Umar entered his place, he gave him the pledge of allegiance and thereafter I too gave him the pledge of allegiance}}
\hadithdefcmd{bukhari}{3917}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ، حَدَّثَنَا شُرَيْحُ بْنُ مَسْلَمَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يُحَدِّثُ قَالَ ابْتَاعَ أَبُو بَكْرٍ مِنْ عَازِبٍ رَحْلاً فَحَمَلْتُهُ مَعَهُ قَالَ فَسَأَلَهُ عَازِبٌ عَنْ مَسِيرِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ أُخِذَ عَلَيْنَا بِالرَّصَدِ، فَخَرَجْنَا لَيْلاً، فَأَحْثَثْنَا لَيْلَتَنَا وَيَوْمَنَا حَتَّى قَامَ قَائِمُ الظَّهِيرَةِ، ثُمَّ رُفِعَتْ لَنَا صَخْرَةٌ، فَأَتَيْنَاهَا وَلَهَا شَىْءٌ مِنْ ظِلٍّ قَالَ فَفَرَشْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَرْوَةً مَعِي، ثُمَّ اضْطَجَعَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم فَانْطَلَقْتُ أَنْفُضُ مَا حَوْلَهُ، فَإِذَا أَنَا بِرَاعٍ قَدْ أَقْبَلَ فِي غُنَيْمَةٍ يُرِيدُ مِنَ الصَّخْرَةِ مِثْلَ الَّذِي أَرَدْنَا فَسَأَلْتُهُ لِمَنْ أَنْتَ يَا غُلاَمُ فَقَالَ أَنَا لِفُلاَنٍ‏.‏ فَقُلْتُ لَهُ هَلْ فِي غَنَمِكَ مِنْ لَبَنٍ قَالَ نَعَمْ‏.‏ قُلْتُ لَهُ هَلْ أَنْتَ حَالِبٌ قَالَ نَعَمْ‏.‏ فَأَخَذَ شَاةً مِنْ غَنَمِهِ فَقُلْتُ لَهُ انْفُضِ الضَّرْعَ‏.‏ قَالَ فَحَلَبَ كُثْبَةً مِنْ لَبَنٍ، وَمَعِي إِدَاوَةٌ مِنْ مَاءٍ عَلَيْهَا خِرْقَةٌ قَدْ رَوَّأْتُهَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَصَبَبْتُ عَلَى اللَّبَنِ حَتَّى بَرَدَ أَسْفَلُهُ، ثُمَّ أَتَيْتُ بِهِ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ اشْرَبْ يَا رَسُولَ اللَّهِ‏.‏ فَشَرِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى رَضِيتُ، ثُمَّ ارْتَحَلْنَا وَالطَّلَبُ فِي إِثْرِنَا‏.‏\hadithno{3917}\hadithtrans{Narrated Al-Bara:Abu Bakr bought a (camel's) saddle from `Azib, and I carried it for him. `Azib (i.e. my father) asked Abu Bakr regarding the journey of the migration of Allah's Messenger (ﷺ). Abu Bakr said, "Close observers were appointed by our enemies to watch us. So we went out at night and travelled throughout the night and the following day till it was noon, then we perceived a rock and went towards it, and there was some shade under it. I spread a cloak I had with me for Allah's Messenger (ﷺ) and then the Prophet (ﷺ) layed on it. I went out to guard him and all of a sudden I saw a shepherd coming with his sheep looking for the same, the shade of the rock as we did, I asked him, 'O boy, to whom do you belong?' He replied, 'I belong to so-and-so.' I asked him, 'Is there some milk in your sheep?' He replied in the affirmative. I asked him, 'Will you milk?' He replied in the affirmative. Then he got hold of one of his sheep. I said to him, 'Remove the dust from its udder.' Then he milked a little milk. I had a water-skin with me which was tied with a piece of cloth. I had prepared the water-skin for Allah's Messenger (ﷺ) . So I poured some water over the milk (container) till its bottom became cold. Then I brought the milk to the Prophet and said, 'Drink, O Allah's Messenger (ﷺ).' Allah's Messenger (ﷺ) drank till I became pleased. Then we departed and the pursuers were following us}}
\hadithdefcmd{bukhari}{3918}{قَالَ الْبَرَاءُ فَدَخَلْتُ مَعَ أَبِي بَكْرٍ عَلَى أَهْلِهِ، فَإِذَا عَائِشَةُ ابْنَتُهُ مُضْطَجِعَةٌ، قَدْ أَصَابَتْهَا حُمَّى، فَرَأَيْتُ أَبَاهَا فَقَبَّلَ خَدَّهَا، وَقَالَ كَيْفَ أَنْتِ يَا بُنَيَّةُ\hadithno{3918}\hadithtrans{Al-Bara added:I then went with Abu Bakr into his home (carrying that saddle) and there I saw his daughter `Aisha Lying in a bed because of heavy fever and I saw her father Abu Bakr kissing her cheek and saying, "How are you, little daughter?}}
\hadithdefcmd{bukhari}{3919}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا مُحَمَّدُ بْنُ حِمْيَرَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي عَبْلَةَ، أَنَّ عُقْبَةَ بْنَ وَسَّاجٍ، حَدَّثَهُ عَنْ أَنَسٍ، خَادِمِ النَّبِيِّ صلى الله عليه وسلم قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم وَلَيْسَ فِي أَصْحَابِهِ أَشْمَطُ غَيْرَ أَبِي بَكْرٍ، فَغَلَفَهَا بِالْحِنَّاءِ وَالْكَتَمِ‏.‏\hadithno{3919}\hadithtrans{Narrated Anas:(the servant of the Prophet) When the Prophet (ﷺ) arrived (at Medina), there was not a single companion of the Prophet (ﷺ) who had grey and black hair except Abu Bakr, and he dyed his hair with Henna' and Katam (i.e. plants used for dying hair)}}
\hadithdefcmd{bukhari}{3920}{وَقَالَ دُحَيْمٌ حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي أَبُو عُبَيْدٍ، عَنْ عُقْبَةَ بْنِ وَسَّاجٍ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ، فَكَانَ أَسَنَّ أَصْحَابِهِ أَبُو بَكْرٍ، فَغَلَفَهَا بِالْحِنَّاءِ وَالْكَتَمِ حَتَّى قَنَأَ لَوْنُهَا‏.‏\hadithno{3920}\hadithtrans{Through another group of narrators, Anas bin Malik said: "When the Prophet (ﷺ) arrived at Medina, the eldest amongst his companions was Abu Bakr. He dyed his hair with Hinna and Katam till it became of dark red color}}
\hadithdefcmd{bukhari}{3921}{حَدَّثَنَا أَصْبَغُ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ تَزَوَّجَ امْرَأَةً مِنْ كَلْبٍ يُقَالُ لَهَا أُمُّ بَكْرٍ، فَلَمَّا هَاجَرَ أَبُو بَكْرٍ طَلَّقَهَا، فَتَزَوَّجَهَا ابْنُ عَمِّهَا، هَذَا الشَّاعِرُ الَّذِي قَالَ هَذِهِ الْقَصِيدَةَ، رَثَى كُفَّارَ قُرَيْشٍ وَمَاذَا بِالْقَلِيبِ قَلِيبِ بَدْرٍ مِنَ الشِّيزَى تُزَيَّنُ بِالسَّنَامِ وَمَاذَا بِالْقَلِيبِ، قَلِيبِ بَدْرٍ مِنَ الْقَيْنَاتِ وَالشَّرْبِ الْكِرَامِ تُحَيِّي بِالسَّلاَمَةِ أُمُّ بَكْرٍ وَهَلْ لِي بَعْدَ قَوْمِي مِنْ سَلاَمِ يُحَدِّثُنَا الرَّسُولُ بِأَنْ سَنَحْيَا وَكَيْفَ حَيَاةُ أَصْدَاءٍ وَهَامِ\hadithno{3921}\hadithtrans{Narrate Aisha:Abu Bakr married a woman from the tribe of Bani Kalb, called Um Bakr. When Abu Bakr migrated to Medina, he divorced her and she was married by her cousin, the poet who said the following poem lamenting the infidels of Quraish: "What is there kept in the well, The well of Badr, (The owners of) the trays of Roasted camel humps? What is there kept in the well, The well of Badr, (The owners of) lady singers And friends of the honorable companions; who used to drink (wine) together, Um Bakr greets us With the greeting of peace, But can I find peace After my people have gone? The Apostle tells us that We shall live again, But what sort of life will owls and skulls live?:}}
\hadithdefcmd{bukhari}{3922}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، عَنْ أَبِي بَكْرٍ ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الْغَارِ فَرَفَعْتُ رَأْسِي، فَإِذَا أَنَا بِأَقْدَامِ الْقَوْمِ، فَقُلْتُ يَا نَبِيَّ اللَّهِ، لَوْ أَنَّ بَعْضَهُمْ طَأْطَأَ بَصَرَهُ رَآنَا‏.‏ قَالَ ‏ "‏ اسْكُتْ يَا أَبَا بَكْرٍ، اثْنَانِ اللَّهُ ثَالِثُهُمَا ‏"‏‏.‏\hadithno{3922}\hadithtrans{Narrated Abu Bakr:I was with the Prophet (ﷺ) in the Cave. When I raised my head, I saw the feet of the people. I said, "O Allah's Messenger (ﷺ)! If some of them should look down, they will see us." The Prophet (ﷺ) said, "O Abu Bakr, be quiet! (For we are) two and Allah is the Third of us}}
\hadithdefcmd{bukhari}{3923}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ،‏.‏ وَقَالَ مُحَمَّدُ بْنُ يُوسُفَ حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا الزُّهْرِيُّ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ يَزِيدَ اللَّيْثِيُّ، قَالَ حَدَّثَنِي أَبُو سَعِيدٍ ـ رضى الله عنه ـ قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَأَلَهُ عَنِ الْهِجْرَةِ فَقَالَ ‏"‏ وَيْحَكَ إِنَّ الْهِجْرَةَ شَأْنُهَا شَدِيدٌ، فَهَلْ لَكَ مِنْ إِبِلٍ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَتُعْطِي صَدَقَتَهَا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَهَلْ تَمْنَحُ مِنْهَا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَتَحْلُبُهَا يَوْمَ وُرُودِهَا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَاعْمَلْ مِنْ وَرَاءِ الْبِحَارِ، فَإِنَّ اللَّهَ لَنْ يَتِرَكَ مِنْ عَمَلِكَ شَيْئًا ‏"‏‏.‏\hadithno{3923}\hadithtrans{Narrated Abu Sa`id:Once a bedouin came to the Prophet (ﷺ) and asked him about the migration. The Prophet (ﷺ) said, "Mercy of Allah be on you! The migration is a quite difficult matter. Have you got some camels?" He replied in the affirmative. Then the Prophet (ﷺ) said, "Do you give their Zakat?" He replied in the affirmative. The Prophet said, "Do you let others benefit by their milk gratis?" He replied in the affirmative. Then the Prophet asked, "Do you milk them on their watering days and give their milk to the poor and needy?" He replied in the affirmative. The Prophet, said, "Go on doing like this from beyond the seas, and there is no doubt that Allah will not overlook any of your good deeds}}
\hadithdefcmd{bukhari}{3924}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، سَمِعَ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ أَوَّلُ مَنْ قَدِمَ عَلَيْنَا مُصْعَبُ بْنُ عُمَيْرٍ وَابْنُ أُمِّ مَكْتُومٍ، ثُمَّ قَدِمَ عَلَيْنَا عَمَّارُ بْنُ يَاسِرٍ وَبِلاَلٌ رضى الله عنهم‏.‏\hadithno{3924}\hadithtrans{Narrated Al-Bara:The first people who came to us (in Medina) were Mus`ab bin `Umair and Ibn Um Maktum. Then came to us `Ammar bin Yasir and Bilal}}
\hadithdefcmd{bukhari}{3925}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ قَالَ أَوَّلُ مَنْ قَدِمَ عَلَيْنَا مُصْعَبُ بْنُ عُمَيْرٍ وَابْنُ أُمِّ مَكْتُومٍ، وَكَانَا يُقْرِئَانِ النَّاسَ، فَقَدِمَ بِلاَلٌ وَسَعْدٌ وَعَمَّارُ بْنُ يَاسِرٍ، ثُمَّ قَدِمَ عُمَرُ بْنُ الْخَطَّابِ فِي عِشْرِينَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَدِمَ النَّبِيُّ صلى الله عليه وسلم، فَمَا رَأَيْتُ أَهْلَ الْمَدِينَةِ فَرِحُوا بِشَىْءٍ فَرَحَهُمْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم، حَتَّى جَعَلَ الإِمَاءُ يَقُلْنَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَمَا قَدِمَ حَتَّى قَرَأْتُ ‏\{‏سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى‏\}‏ فِي سُوَرٍ مِنَ الْمُفَصَّلِ‏.‏\hadithno{3925}\hadithtrans{Narrated Al-Bara bin Azib:The first people who came to us (in Medina) were Mus`ab bin `Umair and Ibn Um Maktum who were teaching Qur'an to the people. Then there came Bilal, Sa`d and `Ammar bin Yasir. After that `Umar bin Al-Khattab came along with twenty other companions of the Prophet. Later on the Prophet (ﷺ) himself came (to Medina) and I had never seen the people of Medina so joyful as they were on the arrival of Allah's Apostle, for even the slave girls were saying, "Allah's Messenger (ﷺ) has arrived!" And before his arrival I had read the Sura starting with:-- "Glorify the Name of your Lord, the Most High" (87.1) together with other Suras of Al-Mufassal}}
\hadithdefcmd{bukhari}{3926}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وُعِكَ أَبُو بَكْرٍ وَبِلاَلٌ ـ قَالَتْ ـ فَدَخَلْتُ عَلَيْهِمَا فَقُلْتُ يَا أَبَتِ كَيْفَ تَجِدُكَ وَيَا بِلاَلُ، كَيْفَ تَجِدُكَ قَالَتْ فَكَانَ أَبُو بَكْرٍ إِذَا أَخَذَتْهُ الْحُمَّى يَقُولُ كُلُّ امْرِئٍ مُصَبَّحٌ فِي أَهْلِهِ وَالْمَوْتُ أَدْنَى مِنْ شِرَاكِ نَعْلِهِ وَكَانَ بِلاَلٌ إِذَا أَقْلَعَ عَنْهُ الْحُمَّى يَرْفَعُ عَقِيرَتَهُ وَيَقُولُ أَلاَ لَيْتَ شِعْرِي هَلْ أَبِيتَنَّ لَيْلَةً بِوَادٍ وَحَوْلِي إِذْخِرٌ وَجَلِيلُ وَهَلْ أَرِدَنْ يَوْمًا مِيَاهَ مَجَنَّةٍ وَهَلْ يَبْدُوَنْ لِي شَامَةٌ وَطَفِيلُ قَالَتْ عَائِشَةُ فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏ "‏ اللَّهُمَّ حَبِّبْ إِلَيْنَا الْمَدِينَةَ كَحُبِّنَا مَكَّةَ أَوْ أَشَدَّ، وَصَحِّحْهَا وَبَارِكْ لَنَا فِي صَاعِهَا وَمُدِّهَا، وَانْقُلْ حُمَّاهَا فَاجْعَلْهَا بِالْجُحْفَةِ ‏"‏‏.‏\hadithno{3926}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) came to Medina, Abu Bakr and Bilal got fever, and I went to both of them and said, "O my father, how do you feel? O Bilal, how do you feel?" Whenever Abu Bakr's fever got worse, he would say, "Every man will meet his death once in one morning while he will be among his family, for death is really nearer to him than his leather shoe laces (to his feet)." And whenever fever deserted Bilal, he would say aloud, "Would that I know whether I shall spend a night in the valley (of Mecca) with Idhkhir and Jalil (i.e. kinds of grass) around me, and whether I shall drink one day the water of Majannah, and whether I shall see once again the hills of Shamah and Tafil?" Then I went to Allah's Messenger (ﷺ) and told him of that. He said, "O Allah, make us love Medina as much as or more than we used to love Mecca, O Allah, make it healthy and bless its Sa' and Mud (i.e. measures), and take away its fever to Al-Juhfa}}
\hadithdefcmd{bukhari}{3927}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُرْوَةُ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَدِيٍّ، أَخْبَرَهُ دَخَلْتُ، عَلَى عُثْمَانَ‏.‏ وَقَالَ بِشْرُ بْنُ شُعَيْبٍ حَدَّثَنِي أَبِي، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَدِيِّ بْنِ خِيَارٍ، أَخْبَرَهُ قَالَ دَخَلْتُ عَلَى عُثْمَانَ فَتَشَهَّدَ ثُمَّ قَالَ أَمَّا بَعْدُ فَإِنَّ اللَّهَ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ، وَكُنْتُ مِمَّنِ اسْتَجَابَ لِلَّهِ وَلِرَسُولِهِ، وَآمَنَ بِمَا بُعِثَ بِهِ مُحَمَّدٌ صلى الله عليه وسلم، ثُمَّ هَاجَرْتُ هِجْرَتَيْنِ، وَنِلْتُ صِهْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَبَايَعْتُهُ، فَوَاللَّهِ مَا عَصَيْتُهُ وَلاَ غَشَشْتُهُ حَتَّى تَوَفَّاهُ اللَّهُ‏.‏ تَابَعَهُ إِسْحَاقُ الْكَلْبِيُّ حَدَّثَنِي الزُّهْرِيُّ مِثْلَهُ‏.‏\hadithno{3927}\hadithtrans{Narrated 'Ubaidullah bin Adi bin Khiyar:I went to `Uthman. After reciting Tashah-hud, he said,. "Then after no doubt, Allah sent Muhammad with the Truth, and I was amongst those who responded to the Call of Allah and His Prophet and believed in the message of Muhammad. Then I took part in the two migrations. I became the son-in-law of Allah's Messenger (ﷺ) and gave the pledge of allegiance to him By Allah, I never disobeyed him, nor did I deceive him till Allah took him unto Him}}
\hadithdefcmd{bukhari}{3928}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنِي ابْنُ وَهْبٍ، حَدَّثَنَا مَالِكٌ،‏.‏ وَأَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ رَجَعَ إِلَى أَهْلِهِ وَهْوَ بِمِنًى، فِي آخِرِ حَجَّةٍ حَجَّهَا عُمَرُ، فَوَجَدَنِي، فَقَالَ عَبْدُ الرَّحْمَنِ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّ الْمَوْسِمَ يَجْمَعُ رَعَاعَ النَّاسِ، وَإِنِّي أَرَى أَنْ تُمْهِلَ حَتَّى تَقْدَمَ الْمَدِينَةَ، فَإِنَّهَا دَارُ الْهِجْرَةِ وَالسُّنَّةِ، وَتَخْلُصَ لأَهْلِ الْفِقْهِ وَأَشْرَافِ النَّاسِ وَذَوِي رَأْيِهِمْ‏.‏ قَالَ عُمَرُ لأَقُومَنَّ فِي أَوَّلِ مَقَامٍ أَقُومُهُ بِالْمَدِينَةِ‏.‏\hadithno{3928}\hadithtrans{Narrated Ibn `Abbas:During the last Hajj led by `Umar, `Abdur-Rahman bin `Auf returned to his family at Mina and met me there. `AbdurRahman said (to `Umar), "O chief of the believers! The season of Hajj is the season when there comes the scum of the people (besides the good amongst them), so I recommend that you should wait till you go back to Medina, for it is the place of Migration and Sunna (i.e. the Prophet's tradition), and there you will be able to refer the matter to the religious scholars and the nobles and the people of wise opinions." `Umar said, "I will speak of it in Medina on my very first sermon I will deliver there}}
\hadithdefcmd{bukhari}{3929}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ خَارِجَةَ بْنِ زَيْدِ بْنِ ثَابِتٍ، أَنَّ أُمَّ الْعَلاَءِ ـ امْرَأَةً مِنْ نِسَائِهِمْ بَايَعَتِ النَّبِيَّ صلى الله عليه وسلم ـ أَخْبَرَتْهُ أَنَّ عُثْمَانَ بْنَ مَظْعُونٍ طَارَ لَهُمْ فِي السُّكْنَى حِينَ اقْتَرَعَتِ الأَنْصَارُ عَلَى سُكْنَى الْمُهَاجِرِينَ، قَالَتْ أُمُّ الْعَلاَءِ فَاشْتَكَى عُثْمَانُ عِنْدَنَا، فَمَرَّضْتُهُ حَتَّى تُوُفِّيَ، وَجَعَلْنَاهُ فِي أَثْوَابِهِ، فَدَخَلَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ رَحْمَةُ اللَّهِ عَلَيْكَ أَبَا السَّائِبِ، شَهَادَتِي عَلَيْكَ لَقَدْ أَكْرَمَكَ اللَّهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَمَا يُدْرِيكِ أَنَّ اللَّهَ أَكْرَمَهُ ‏"‏‏.‏ قَالَتْ قُلْتُ لاَ أَدْرِي بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ فَمَنْ قَالَ ‏"‏ أَمَّا هُوَ فَقَدْ جَاءَهُ وَاللَّهِ الْيَقِينُ، وَاللَّهِ إِنِّي لأَرْجُو لَهُ الْخَيْرَ، وَمَا أَدْرِي وَاللَّهِ وَأَنَا رَسُولُ اللَّهِ مَا يُفْعَلُ بِي ‏"‏‏.‏ قَالَتْ فَوَاللَّهِ لاَ أُزَكِّي أَحَدًا بَعْدَهُ قَالَتْ فَأَحْزَنَنِي ذَلِكَ فَنِمْتُ فَأُرِيتُ لِعُثْمَانَ بْنِ مَظْعُونٍ عَيْنًا تَجْرِي، فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ‏.‏ فَقَالَ ‏"‏ ذَلِكَ عَمَلُهُ ‏"‏‏.‏\hadithno{3929}\hadithtrans{Narrated 'Um Al-`Ala:An Ansari woman who gave the pledge of allegiance to the Prophet (ﷺ) that the Ansar drew lots concerning the dwelling of the Emigrants. `Uthman bin Maz'un was decided to dwell with them (i.e. Um Al-`Ala's family), `Uthman fell ill and I nursed him till he died, and we covered him with his clothes. Then the Prophet (ﷺ) came to us and I (addressing the dead body) said, "O Abu As-Sa'ib, may Allah's Mercy be on you! I bear witness that Allah has honored you." On that the Prophet (ﷺ) said, "How do you know that Allah has honored him?" I replied, "I do not know. May my father and my mother be sacrificed for you, O Allah's Messenger (ﷺ)! But who else is worthy of it (if not `Uthman)?" He said, "As to him, by Allah, death has overtaken him, and I hope the best for him. By Allah, though I am the Apostle of Allah, yet I do not know what Allah will do to me," By Allah, I will never assert the piety of anyone after him. That made me sad, and when I slept I saw in a dream a flowing stream for `Uthman bin Maz'un. I went to Allah's Messenger (ﷺ) and told him of it. He remarked, "That symbolizes his (good) deeds}}
\hadithdefcmd{bukhari}{3930}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ يَوْمُ بُعَاثٍ يَوْمًا قَدَّمَهُ اللَّهُ عَزَّ وَجَلَّ لِرَسُولِهِ صلى الله عليه وسلم، فَقَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وَقَدِ افْتَرَقَ مَلَؤُهُمْ، وَقُتِلَتْ سَرَاتُهُمْ فِي دُخُولِهِمْ فِي الإِسْلاَمِ‏.‏\hadithno{3930}\hadithtrans{Narrated `Aisha:The day of Bu'ath was a day (i.e. battle) which Allah caused to take place just before the mission of His Apostle so that when Allah's Messenger (ﷺ) came to Medina, they (the tribes) had divided (into hostile groups) and their nobles had been killed; and all that facilitated their conversion to Islam}}
\hadithdefcmd{bukhari}{3931}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ، دَخَلَ عَلَيْهَا وَالنَّبِيُّ صلى الله عليه وسلم عِنْدَهَا يَوْمَ فِطْرٍ أَوْ أَضْحًى، وَعِنْدَهَا قَيْنَتَانِ ‏\{‏تُغَنِّيَانِ‏\}‏ بِمَا تَقَاذَفَتِ الأَنْصَارُ يَوْمَ بُعَاثَ‏.‏ فَقَالَ أَبُو بَكْرٍ مِزْمَارُ الشَّيْطَانِ مَرَّتَيْنِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ دَعْهُمَا يَا أَبَا بَكْرٍ، إِنَّ لِكُلِّ قَوْمٍ عِيدًا، وَإِنَّ عِيدَنَا هَذَا الْيَوْمُ ‏"‏‏.‏\hadithno{3931}\hadithtrans{Narrated Aisha:That once Abu Bakr came to her on the day of `Id-ul-Fitr or `Id ul Adha while the Prophet (ﷺ) was with her and there were two girl singers with her, singing songs of the Ansar about the day of Buath. Abu Bakr said twice. "Musical instrument of Satan!" But the Prophet (ﷺ) said, "Leave them Abu Bakr, for every nation has an `Id (i.e. festival) and this day is our `Id}}
\hadithdefcmd{bukhari}{3932}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ،‏.‏ وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، حَدَّثَنَا أَبُو التَّيَّاحِ، يَزِيدُ بْنُ حُمَيْدٍ الضُّبَعِيُّ قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ، نَزَلَ فِي عُلْوِ الْمَدِينَةِ فِي حَىٍّ يُقَالُ لَهُمْ بَنُو عَمْرِو بْنِ عَوْفٍ ـ قَالَ ـ فَأَقَامَ فِيهِمْ أَرْبَعَ عَشْرَةَ لَيْلَةً، ثُمَّ أَرْسَلَ إِلَى مَلإِ بَنِي النَّجَّارِ ـ قَالَ ـ فَجَاءُوا مُتَقَلِّدِي سُيُوفِهِمْ، قَالَ وَكَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى رَاحِلَتِهِ، وَأَبُو بَكْرٍ رِدْفَهُ، وَمَلأُ بَنِي النَّجَّارِ حَوْلَهُ حَتَّى أَلْقَى بِفِنَاءِ أَبِي أَيُّوبَ، قَالَ فَكَانَ يُصَلِّي حَيْثُ أَدْرَكَتْهُ الصَّلاَةُ، وَيُصَلِّي فِي مَرَابِضِ الْغَنَمِ، قَالَ ثُمَّ إِنَّهُ أَمَرَ بِبِنَاءِ الْمَسْجِدِ، فَأَرْسَلَ إِلَى مَلإِ بَنِي النَّجَّارِ، فَجَاءُوا فَقَالَ ‏ "‏ يَا بَنِي النَّجَّارِ، ثَامِنُونِي حَائِطَكُمْ هَذَا ‏"‏‏.‏ فَقَالُوا لاَ، وَاللَّهِ لاَ نَطْلُبُ ثَمَنَهُ إِلاَّ إِلَى اللَّهِ‏.‏ قَالَ فَكَانَ فِيهِ مَا أَقُولُ لَكُمْ كَانَتْ فِيهِ قُبُورُ الْمُشْرِكِينَ، وَكَانَتْ فِيهِ خِرَبٌ، وَكَانَ فِيهِ نَخْلٌ، فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقُبُورِ الْمُشْرِكِينَ فَنُبِشَتْ، وَبِالْخِرَبِ فَسُوِّيَتْ، وَبِالنَّخْلِ فَقُطِعَ، قَالَ فَصَفُّوا النَّخْلَ قِبْلَةَ الْمَسْجِدِ ـ قَالَ ـ وَجَعَلُوا عِضَادَتَيْهِ حِجَارَةً‏.‏ قَالَ قَالَ جَعَلُوا يَنْقُلُونَ ذَاكَ الصَّخْرَ وَهُمْ يَرْتَجِزُونَ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم مَعَهُمْ يَقُولُونَ اللَّهُمَّ إِنَّهُ لاَ خَيْرَ إِلاَّ خَيْرُ الآخِرَهْ فَانْصُرِ الأَنْصَارَ وَالْمُهَاجِرَهْ‏.‏\hadithno{3932}\hadithtrans{Narrated Anas bin Malik:When Allah's Messenger (ﷺ) arrived at Medina, he alighted at the upper part of Medina among the people called Bani `Amr bin `Auf and he stayed with them for fourteen nights. Then he sent for the chiefs of Bani An-Najjar, and they came, carrying their swords. As if I am just now looking at Allah's Messenger (ﷺ) on his she-camel with Abu Bakr riding behind him (on the same camel) and the chiefs of Bani An- Najjar around him till he dismounted in the courtyard of Abu Aiyub's home. The Prophet (ﷺ) used to offer the prayer wherever the prayer was due, and he would pray even in sheepfolds. Then he ordered that the mosque be built. He sent for the chiefs of Banu An-Najjar, and when they came, he said, "O Banu An-Najjar! Suggest to me the price of this garden of yours." They replied "No! By Allah, we do not demand its price except from Allah." In that garden there were the (following) things that I will tell you: Graves of pagans, unleveled land with holes and pits etc., and date-palm trees. Allah's Messenger (ﷺ) ordered that the graves of the pagans be dug up and, the unleveled land be leveled and the date-palm trees be cut down. The trunks of the trees were arranged so as to form the wall facing the Qibla. The Stone pillars were built at the sides of its gate. The companions of the Prophet (ﷺ) were carrying the stones and reciting some lyrics, and Allah's Messenger (ﷺ) . . was with them and they were saying, "O Allah! There is no good except the good of the Hereafter, so bestow victory on the Ansar and the Emigrants}}
\hadithdefcmd{bukhari}{3933}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا حَاتِمٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ الزُّهْرِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَسْأَلُ السَّائِبَ ابْنَ أُخْتِ النَّمِرِ مَا سَمِعْتَ فِي، سُكْنَى مَكَّةَ قَالَ سَمِعْتُ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثٌ لِلْمُهَاجِرِ بَعْدَ الصَّدَرِ ‏"‏‏.‏\hadithno{3933}\hadithtrans{Narrated `Abdur-Rahman bin Humaid Az-Zuhri:I heard `Umar bin `Abdul-Aziz asking As-Sa'ib, the nephew of An-Namir, "What have you heard about residing in Mecca?" The other said, "I heard Al-Ala bin Al-Hadrami saying, Allah's Messenger (ﷺ) said: An Emigrant is allowed to stay in Mecca for three days after departing from Mina (i.e. after performing all the ceremonies of Hajj)}}
\hadithdefcmd{bukhari}{3934}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ مَا عَدُّوا مِنْ مَبْعَثِ النَّبِيِّ صلى الله عليه وسلم وَلاَ مِنْ وَفَاتِهِ، مَا عَدُّوا إِلاَّ مِنْ مَقْدَمِهِ الْمَدِينَةَ‏.‏\hadithno{3934}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet's companions did not take as a starting date for the Muslim calendar, the day, the Prophet (ﷺ) had been sent as an Apostle or the day of his death, but the day of his arrival at Medina}}
\hadithdefcmd{bukhari}{3935}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ فُرِضَتِ الصَّلاَةُ رَكْعَتَيْنِ، ثُمَّ هَاجَرَ النَّبِيُّ صلى الله عليه وسلم فَفُرِضَتْ أَرْبَعًا، وَتُرِكَتْ صَلاَةُ السَّفَرِ عَلَى الأُولَى‏.‏ تَابَعَهُ عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ‏.‏\hadithno{3935}\hadithtrans{Narrated `Aisha:Originally, two rak`at were prescribed in every prayer. When the Prophet (ﷺ) migrated (to Medina) four rak`at were enjoined, while the journey prayer remained unchanged(i.e. two rak`at)}}
\hadithdefcmd{bukhari}{3936}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ عَادَنِي النَّبِيُّ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ مِنْ مَرَضٍ أَشْفَيْتُ مِنْهُ عَلَى الْمَوْتِ، فَقُلْتُ يَا رَسُولَ اللَّهِ، بَلَغَ بِي مِنَ الْوَجَعِ مَا تَرَى، وَأَنَا ذُو مَالٍ وَلاَ يَرِثُنِي إِلاَّ ابْنَةٌ لِي وَاحِدَةٌ، أَفَأَتَصَدَّقُ بِثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَأَتَصَدَّقُ بِشَطْرِهِ قَالَ ‏"‏ الثُّلُثُ يَا سَعْدُ، وَالثُّلُثُ كَثِيرٌ، إِنَّكَ أَنْ تَذَرَ ذُرِّيَّتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَذَرَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ ‏"‏‏.‏ قَالَ أَحْمَدُ بْنُ يُونُسَ عَنْ إِبْرَاهِيمَ ‏"‏ أَنْ تَذَرَ ذُرِّيَّتَكَ، وَلَسْتَ بِنَافِقٍ نَفَقَةً تَبْتَغِي بِهَا وَجْهَ اللَّهِ إِلاَّ آجَرَكَ اللَّهُ بِهَا، حَتَّى اللُّقْمَةَ تَجْعَلُهَا فِي فِي امْرَأَتِكَ ‏"‏‏.‏ قُلْتَ يَا رَسُولَ اللَّهِ، أُخَلَّفُ بَعْدَ أَصْحَابِي قَالَ ‏"‏ إِنَّكَ لَنْ تُخَلَّفَ فَتَعْمَلَ عَمَلاً تَبْتَغِي بِهِ وَجْهَ اللَّهِ إِلاَّ ازْدَدْتَ بِهِ دَرَجَةً وَرِفْعَةً، وَلَعَلَّكَ تُخَلَّفُ حَتَّى يَنْتَفِعَ بِكَ أَقْوَامٌ، وَيُضَرَّ بِكَ آخَرُونَ، اللَّهُمَّ أَمْضِ لأَصْحَابِي هِجْرَتَهُمْ، وَلاَ تَرُدَّهُمْ عَلَى أَعْقَابِهِمْ، لَكِنِ الْبَائِسُ سَعْدُ ابْنُ خَوْلَةَ يَرْثِي لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُوُفِّيَ بِمَكَّةَ ‏"‏‏.‏ وَقَالَ أَحْمَدُ بْنُ يُونُسَ وَمُوسَى عَنْ إِبْرَاهِيمَ ‏"‏ أَنْ تَذَرَ وَرَثَتَكَ ‏"‏‏.‏\hadithno{3936}\hadithtrans{Narrated Sa`d bin Malik:In the year of Hajjat-ul-Wada` the Prophet (ﷺ) visited me when I fell ill and was about to die because of that illness. I said, "O Allah's Messenger (ﷺ)! I am very ill as you see, and I am a rich man and have no heir except my only daughter. Shall I give 2/3 of my property in charity?" He said, "No." I said, "Shall I then give one half of it in charity?" He said, "O Sa`d! Give 1/3 (in charity) and even 1/3 is too much. No doubt, it is better to leave your children rich than to leave them poor, reduced to begging from others. And Allah will reward you for whatever you spend with the intention of gaining Allah's Pleasure even if it were a mouthful of food you put into your wives mouth." I said, "O Allah's Apostle! Am I to be left behind (in Mecca) after my companions have gone?" He said, "If you should be left behind, you will be upgraded and elevated for every deed you will do with a desire to achieve Allah's Pleasure. I hope that you will live long so that some people will benefit by you while others will be harmed. O Allah! Please fulfill the migration of my companions and do not make them turn back on their heels. But (we feel sorry for) the unlucky Sa`d bin Khaulah." Allah's Messenger (ﷺ) lamented his death in Mecca}}
\hadithdefcmd{bukhari}{3937}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَدِمَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ، فَآخَى النَّبِيُّ صلى الله عليه وسلم بَيْنَهُ وَبَيْنَ سَعْدِ بْنِ الرَّبِيعِ الأَنْصَارِيِّ، فَعَرَضَ عَلَيْهِ أَنْ يُنَاصِفَهُ أَهْلَهُ وَمَالَهُ، فَقَالَ عَبْدُ الرَّحْمَنِ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ وَمَالِكَ، دُلَّنِي عَلَى السُّوقِ‏.‏ فَرَبِحَ شَيْئًا مِنْ أَقِطٍ وَسَمْنٍ، فَرَآهُ النَّبِيُّ صلى الله عليه وسلم بَعْدَ أَيَّامٍ وَعَلَيْهِ وَضَرٌ مِنْ صُفْرَةٍ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَهْيَمْ يَا عَبْدَ الرَّحْمَنِ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ‏.‏ قَالَ ‏"‏ فَمَا سُقْتَ فِيهَا ‏"‏‏.‏ فَقَالَ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{3937}\hadithtrans{Narrated Anas:When `Abdur-Rahman bin `Auf came to Medina and the Prophet (ﷺ) established the bond of brotherhood between him and Sa`d bin Ar-Rabi-al-Ansari, Sa`d suggested that `Abdur-Rahman should accept half of his property and family. `Abdur Rahman said, "May Allah bless you in your family and property; guide me to the market." So `Abdur-Rahman (while doing business in the market) made some profit of some condensed dry yoghurt and butter. After a few days the Prophet (ﷺ) saw him wearing clothes stained with yellow perfume. The Prophet (ﷺ) asked, "What is this, O `Abdur-Rahman?" He said, "O Allah's Messenger (ﷺ)! I have married an Ansar' woman." The Prophet (ﷺ) asked, "What have you given her as Mahr?" He (i.e. `Abdur-Rahman) said, "A piece of gold, about the weight of a date stone." Then the Prophet said, Give a banquet, even though of a sheep}}
\hadithdefcmd{bukhari}{3938}{حَدَّثَنِي حَامِدُ بْنُ عُمَرَ، عَنْ بِشْرِ بْنِ الْمُفَضَّلِ، حَدَّثَنَا حُمَيْدٌ، حَدَّثَنَا أَنَسٌ، أَنَّ عَبْدَ اللَّهِ بْنَ سَلاَمٍ، بَلَغَهُ مَقْدَمُ النَّبِيِّ صلى الله عليه وسلم الْمَدِينَةَ، فَأَتَاهُ يَسْأَلُهُ عَنْ أَشْيَاءَ، فَقَالَ إِنِّي سَائِلُكَ عَنْ ثَلاَثٍ لاَ يَعْلَمُهُنَّ إِلاَّ نَبِيٌّ مَا أَوَّلُ أَشْرَاطِ السَّاعَةِ وَمَا أَوَّلُ طَعَامٍ يَأْكُلُهُ أَهْلُ الْجَنَّةِ وَمَا بَالُ الْوَلَدِ يَنْزِعُ إِلَى أَبِيهِ أَوْ إِلَى أُمِّهِ قَالَ ‏"‏ أَخْبَرَنِي بِهِ جِبْرِيلُ آنِفًا ‏"‏‏.‏ قَالَ ابْنُ سَلاَمٍ ذَاكَ عَدُوُّ الْيَهُودِ مِنَ الْمَلاَئِكَةِ‏.‏ قَالَ ‏"‏ أَمَّا أَوَّلُ أَشْرَاطِ السَّاعَةِ فَنَارٌ تَحْشُرُهُمْ مِنَ الْمَشْرِقِ إِلَى الْمَغْرِبِ، وَأَمَّا أَوَّلُ طَعَامٍ يَأْكُلُهُ أَهْلُ الْجَنَّةِ، فَزِيَادَةُ كَبِدِ الْحُوتِ، وَأَمَّا الْوَلَدُ، فَإِذَا سَبَقَ مَاءُ الرَّجُلِ مَاءَ الْمَرْأَةِ نَزَعَ الْوَلَدَ، وَإِذَا سَبَقَ مَاءُ الْمَرْأَةِ مَاءَ الرَّجُلِ نَزَعَتِ الْوَلَدَ ‏"‏‏.‏ قَالَ أَشْهَدُ أَنَّ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّكَ رَسُولُ اللَّهِ‏.‏ قَالَ يَا رَسُولَ اللَّهِ، إِنَّ الْيَهُودَ قَوْمٌ بُهُتٌ، فَاسْأَلْهُمْ عَنِّي قَبْلَ أَنْ يَعْلَمُوا بِإِسْلاَمِي، فَجَاءَتِ الْيَهُودُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَىُّ رَجُلٍ عَبْدُ اللَّهِ بْنُ سَلاَمٍ فِيكُمْ ‏"‏‏.‏ قَالُوا خَيْرُنَا وَابْنُ خَيْرِنَا وَأَفْضَلُنَا وَابْنُ أَفْضَلِنَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرَأَيْتُمْ إِنْ أَسْلَمَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ‏"‏‏.‏ قَالُوا أَعَاذَهُ اللَّهُ مِنْ ذَلِكَ‏.‏ فَأَعَادَ عَلَيْهِمْ، فَقَالُوا مِثْلَ ذَلِكَ، فَخَرَجَ إِلَيْهِمْ عَبْدُ اللَّهِ فَقَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ‏.‏ قَالُوا شَرُّنَا وَابْنُ شَرِّنَا‏.‏ وَتَنَقَّصُوهُ‏.‏ قَالَ هَذَا كُنْتُ أَخَافُ يَا رَسُولَ اللَّهِ‏.‏\hadithno{3938}\hadithtrans{Narrated Anas:When the news of the arrival of the Prophet (ﷺ) at Medina reached `Abdullah bin Salam, he went to him to ask him about certain things, He said, "I am going to ask you about three things which only a Prophet can answer: What is the first sign of The Hour? What is the first food which the people of Paradise will eat? Why does a child attract the similarity to his father or to his mother?" The Prophet (ﷺ) replied, "Gabriel has just now informed me of that." Ibn Salam said, "He (i.e. Gabriel) is the enemy of the Jews amongst the angels. The Prophet (ﷺ) said, "As for the first sign of The Hour, it will be a fire that will collect the people from the East to the West. As for the first meal which the people of Paradise will eat, it will be the caudate (extra) lobe of the fish-liver. As for the child, if the man's discharge proceeds the woman's discharge, the child attracts the similarity to the man, and if the woman's discharge proceeds the man's, then the child attracts the similarity to the woman." On this, `Abdullah bin Salam said, "I testify that None has the right to be worshipped except Allah, and that you are the Messenger of Allah." and added, "O Allah's Messenger (ﷺ)! Jews invent such lies as make one astonished, so please ask them about me before they know about my conversion to Islam. " The Jews came, and the Prophet (ﷺ) said, "What kind of man is `Abdullah bin Salam among you?" They replied, "The best of us and the son of the best of us and the most superior among us, and the son of the most superior among us. "The Prophet (ﷺ) said, "What would you think if `Abdullah bin Salam should embrace Islam?" They said, "May Allah protect him from that." The Prophet (ﷺ) repeated his question and they gave the same answer. Then `Abdullah came out to them and said, "I testify that None has the right to be worshipped except Allah and that Muhammad is the Messenger of Allah!" On this, the Jews said, "He is the most wicked among us and the son of the most wicked among us." So they degraded him. On this, he (i.e. `Abdullah bin Salam) said, "It is this that I was afraid of, O Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{3940}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ أَبَا الْمِنْهَالِ عَبْدَ الرَّحْمَنِ بْنَ مُطْعِمٍ، قَالَ بَاعَ شَرِيكٌ لِي دَرَاهِمَ فِي السُّوقِ نَسِيئَةً فَقُلْتُ سُبْحَانَ اللَّهِ أَيَصْلُحُ هَذَا فَقَالَ سُبْحَانَ اللَّهِ، وَاللَّهِ لَقَدْ بِعْتُهَا فِي السُّوقِ فَمَا عَابَهُ أَحَدٌ، فَسَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ فَقَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ نَتَبَايَعُ هَذَا الْبَيْعَ، فَقَالَ ‏ "‏ مَا كَانَ يَدًا بِيَدٍ فَلَيْسَ بِهِ بَأْسٌ، وَمَا كَانَ نَسِيئَةً فَلاَ يَصْلُحُ ‏"‏‏.‏ وَالْقَ زَيْدَ بْنَ أَرْقَمَ فَاسْأَلْهُ فَإِنَّهُ كَانَ أَعْظَمَنَا تِجَارَةً، فَسَأَلْتُ زَيْدَ بْنَ أَرْقَمَ فَقَالَ مِثْلَهُ‏.‏ وَقَالَ سُفْيَانُ مَرَّةً فَقَالَ قَدِمَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَنَحْنُ نَتَبَايَعُ، وَقَالَ نَسِيئَةً إِلَى الْمَوْسِمِ أَوِ الْحَجِّ‏.‏\hadithno{3940}\hadithtrans{Narrated Abu Al-Minhal `AbdurRahman bin Mut`im:A partner of mine sold some Dirhams on credit in the market. I said, "Glorified be Allah! Is this legal?" He replied, "Glorified be Allah! By Allah, when I sold them in the market, nobody objected to it." Then I asked Al-Bara' bin `Azib (about it) he said, "We used to make such a transaction when the Prophet came to Medina. So he said, 'There is no harm in it if it is done from hand to hand, but it is not allowed on credit.' Go to Zaid bin Al- Arqam and ask him about it for he was the greatest trader of all of us." So I asked Zaid bin Al-Arqam., and he said the same (as Al-Bara) did}}
\hadithdefcmd{bukhari}{3941}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا قُرَّةُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ آمَنَ بِي عَشَرَةٌ مِنَ الْيَهُودِ لآمَنَ بِي الْيَهُودُ ‏"‏‏.‏\hadithno{3941}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Had only ten Jews (amongst their chiefs) believed me, all the Jews would definitely have believed me}}
\hadithdefcmd{bukhari}{3942}{حَدَّثَنِي أَحْمَدُ ـ أَوْ مُحَمَّدُ ـ بْنُ عُبَيْدِ اللَّهِ الْغُدَانِيُّ حَدَّثَنَا حَمَّادُ بْنُ أُسَامَةَ، أَخْبَرَنَا أَبُو عُمَيْسٍ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَإِذَا أُنَاسٌ مِنَ الْيَهُودِ يُعَظِّمُونَ عَاشُورَاءَ وَيَصُومُونَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نَحْنُ أَحَقُّ بِصَوْمِهِ ‏"‏‏.‏ فَأَمَرَ بِصَوْمِهِ‏.‏\hadithno{3942}\hadithtrans{Narrated Abu Musa:When the Prophet (ﷺ) arrived at Medina, he noticed that some people among the Jews used to respect Ashura' (i.e. 10th of Muharram) and fast on it. The Prophet (ﷺ) then said, "We have more right to observe fast on this day." and ordered that fasting should be observed on it}}
\hadithdefcmd{bukhari}{3943}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَجَدَ الْيَهُودَ يَصُومُونَ عَاشُورَاءَ، فَسُئِلُوا عَنْ ذَلِكَ، فَقَالُوا هَذَا الْيَوْمُ الَّذِي أَظْفَرَ اللَّهُ فِيهِ مُوسَى وَبَنِي إِسْرَائِيلَ عَلَى فِرْعَوْنَ، وَنَحْنُ نَصُومُهُ تَعْظِيمًا لَهُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَحْنُ أَوْلَى بِمُوسَى مِنْكُمْ ‏"‏‏.‏ ثُمَّ أَمَرَ بِصَوْمِهِ‏.‏\hadithno{3943}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) arrived at Medina he found that the Jews observed fast on the day of 'Ashura'. They were asked the reason for the fast. They replied, "This is the day when Allah caused Moses and the children of Israel to have victory over Pharaoh, so we fast on this day as a sign of glorifying it." Allah's Messenger (ﷺ) said, "We are closer to Moses than you." Then he ordered that fasting on this day should be observed}}
\hadithdefcmd{bukhari}{3944}{حَدَّثَنَا عَبْدَانُ، حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَسْدِلُ شَعْرَهُ، وَكَانَ الْمُشْرِكُونَ يَفْرُقُونَ رُءُوسَهُمْ، وَكَانَ أَهْلُ الْكِتَابِ يَسْدِلُونَ رُءُوسَهُمْ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم يُحِبُّ مُوَافَقَةَ أَهْلِ الْكِتَابِ فِيمَا لَمْ يُؤْمَرْ فِيهِ بِشَىْءٍ، ثُمَّ فَرَقَ النَّبِيُّ صلى الله عليه وسلم رَأْسَهُ‏.‏\hadithno{3944}\hadithtrans{Narrated `Abdullah bin `Abbas:The Prophet (ﷺ) used to keep his hair falling loose while the pagans used to part their hair, and the People of the Scriptures used to keep their hair falling loose, and the Prophet (ﷺ) liked to follow the People of the Scriptures in matters about which he had not been instructed differently, but later on the Prophet (ﷺ) started parting his hair}}
\hadithdefcmd{bukhari}{3945}{حَدَّثَنِي زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ هُمْ أَهْلُ الْكِتَابِ، جَزَّءُوهُ أَجْزَاءً، فَآمَنُوا بِبَعْضِهِ وَكَفَرُوا بِبَعْضِهِ‏.‏ ‏\{‏يَعْنِي قَوْلَ اللَّهِ تَعَالَى ‏\{‏الَّذِينَ جَعَلُوا الْقُرْآنَ عِضِينَ ‏\}‏\hadithno{3945}\hadithtrans{Narrated Ibn `Abbas:They, the people of the Scriptures, divided this Scripture into parts, believing in some portions of it and disbelieving the others. (See 15:)}}
\hadithdefcmd{bukhari}{3946}{حَدَّثَنِي الْحَسَنُ بْنُ عُمَرَ بْنِ شَقِيقٍ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ أَبِي وَحَدَّثَنَا أَبُو عُثْمَانَ، عَنْ سَلْمَانَ الْفَارِسِيِّ، أَنَّهُ تَدَاوَلَهُ بِضْعَةَ عَشَرَ مِنْ رَبٍّ إِلَى رَبٍّ‏.‏\hadithno{3946}\hadithtrans{Narrated Salman Al-Farisi:That he was sold (as a slave) by one master to another for more than ten times (i.e. between 13 and)}}
\hadithdefcmd{bukhari}{3947}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَوْفٍ، عَنْ أَبِي عُثْمَانَ، قَالَ سَمِعْتُ سَلْمَانَ ـ رضى الله عنه ـ يَقُولُ أَنَا مِنْ، رَامَ هُرْمُزَ‏.‏\hadithno{3947}\hadithtrans{Narrated Salman:I am from Ram-Hurmuz (i.e. a Persian town)}}
\hadithdefcmd{bukhari}{3948}{حَدَّثَنِي الْحَسَنُ بْنُ مُدْرِكٍ، حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ، عَنْ سَلْمَانَ، قَالَ فَتْرَةٌ بَيْنَ عِيسَى وَمُحَمَّدٍ صلى الله عليه وسلم سِتُّمِائَةِ سَنَةٍ‏.‏\hadithno{3948}\hadithtrans{Narrated Salman:The interval between Jesus and Muhammad was six hundred years}}
