% Auto-generated chapter 22 for muslim
% Hadiths in this chapter: 178

\hadithdefcmd{muslim}{3962}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَلَ أَهْلَ خَيْبَرَ بِشَطْرِ مَا يَخْرُجُ مِنْهَا مِنْ ثَمَرٍ أَوْ زَرْعٍ ‏.‏\hadithno{3962}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) contracted with the people of Khaibar the (trees) on the condition that he would have half the produce in fruits and harvest}}
\hadithdefcmd{muslim}{3963}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عَلِيٌّ، - وَهُوَ ابْنُ مُسْهِرٍ - أَخْبَرَنَا عُبَيْدُ، اللَّهِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ بِشَطْرِ مَا يَخْرُجُ مِنْ ثَمَرٍ أَوْ زَرْعٍ فَكَانَ يُعْطِي أَزْوَاجَهُ كَلَّ سَنَةٍ مِائَةَ وَسْقٍ ثَمَانِينَ وَسْقًا مِنْ تَمْرٍ وَعِشْرِينَ وَسْقًا مِنْ شَعِيرٍ فَلَمَّا وَلِيَ عُمَرُ قَسَمَ خَيْبَرَ خَيَّرَ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم أَنْ يُقْطِعَ لَهُنَّ الأَرْضَ وَالْمَاءَ أَوْ يَضْمَنَ لَهُنَّ الأَوْسَاقَ كُلَّ عَامٍ فَاخْتَلَفْنَ فَمِنْهُنَّ مَنِ اخْتَارَ الأَرْضَ وَالْمَاءَ وَمِنْهُنَّ مَنِ اخْتَارَ الأَوْسَاقَ كُلَّ عَامٍ فَكَانَتْ عَائِشَةُ وَحَفْصَةُ مِمَّنِ اخْتَارَتَا الأَرْضَ وَالْمَاءَ ‏.‏\hadithno{3963}\hadithtrans{Ibn Umar (Allah be pleased with them) reported:Allah's Messenger (ﷺ) handed over the land of Khaibar (on the condition) of the share of produce of fruits and harvest, and he also gave to his wives every year one hundred wasqs: eighty wasqs of dates and twenty wasqs of barley. When 'Umar became the caliph he distributed the (lands and trees) of Khaibar, and gave option to the wives of Allah's Apostle (ﷺ) to earmark for themselves the land and water or stick to the wasqs (that they got) every year. They differed in this matter. Some of them opted for land and water, and some of them opted for wasqs every year. 'A'isha and Hafsa were among those who opted for land and water}}
\hadithdefcmd{muslim}{3964}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَلَ أَهْلَ خَيْبَرَ بِشَطْرِ مَا خَرَجَ مِنْهَا مِنْ زَرْعٍ أَوْ ثَمَرٍ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِنَحْوِ حَدِيثِ عَلِيِّ بْنِ مُسْهِرٍ وَلَمْ يَذْكُرْ فَكَانَتْ عَائِشَةُ وَحَفْصَةُ مِمَّنِ اخْتَارَتَا الأَرْضَ وَالْمَاءَ وَقَالَ خَيَّرَ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم أَنْ يُقْطِعَ لَهُنَّ الأَرْضَ وَلَمْ يَذْكُرِ الْمَاءَ ‏.‏\hadithno{3964}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) contracted with the people of Khaibar (land and trees on the condition that they should give) half of the yield from land and trees. The rest of the hadith is the same. In the hadith transmitted on the authority of AIi b. Mushir there is no mention of it, but that A'isha and Hafsa were those who opted for land and water, but he (the narrator) said:He (Hadrat 'Umar, gave option to the wives of Allah's Apostle (ﷺ) that land would be earmarked for them, but he made no mention of water}}
\hadithdefcmd{muslim}{3965}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ اللَّيْثِيُّ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ لَمَّا افْتُتِحَتْ خَيْبَرُ سَأَلَتْ يَهُودُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يُقِرَّهُمْ فِيهَا عَلَى أَنْ يَعْمَلُوا عَلَى نِصْفِ مَا خَرَجَ مِنْهَا مِنَ الثَّمَرِ وَالزَّرْعِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُقِرُّكُمْ فِيهَا عَلَى ذَلِكَ مَا شِئْنَا ‏"‏ ‏.‏ ثُمَّ سَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ ابْنِ نُمَيْرٍ وَابْنِ مُسْهِرٍ عَنْ عُبَيْدِ اللَّهِ وَزَادَ فِيهِ وَكَانَ الثَّمَرُ يُقْسَمُ عَلَى السُّهْمَانِ مِنْ نِصْفِ خَيْبَرَ فَيَأْخُذُ رَسُولُ اللَّهِ صلى الله عليه وسلم الْخُمُسَ ‏.‏\hadithno{3965}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported that when Khaibar had been conquered, the Jews asked Allah's Messenger (ﷺ) to let them continue (cultivation in those lands) on half of the share of yield in fruits and crop, whereupon Allah's Messenger (ﷺ) said:I will allow you to continue here, so long as we would desire. The rest of the hadith is the same, but with this addition:" The fruit would be distributed equal to the half of Khaibar. And out of hall of the produce of the land, Allah's Apostle (may peace be be upon him) got the fifth part}}
\hadithdefcmd{muslim}{3966}{وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ نَافِعٍ، عَنْ عَبْدِ، اللَّهِ بْنِ عُمَرَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ دَفَعَ إِلَى يَهُودِ خَيْبَرَ نَخْلَ خَيْبَرَ وَأَرْضَهَا عَلَى أَنْ يَعْتَمِلُوهَا مِنْ أَمْوَالِهِمْ وَلِرَسُولِ اللَّهِ صلى الله عليه وسلم شَطْرُ ثَمَرِهَا ‏.‏\hadithno{3966}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) returned to the Jews of Khaibar the date-palms of Khaibar and its land on the condition that they should work upon them with their own wealth (seeds, implements), and give half of the yield to Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3967}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، بْنَ الْخَطَّابِ أَجْلَى الْيَهُودَ وَالنَّصَارَى مِنْ أَرْضِ الْحِجَازِ وَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا ظَهَرَ عَلَى خَيْبَرَ أَرَادَ إِخْرَاجَ الْيَهُودِ مِنْهَا وَكَانَتِ الأَرْضُ حِينَ ظُهِرَ عَلَيْهَا لِلَّهِ وَلِرَسُولِهِ وَلِلْمُسْلِمِينَ فَأَرَادَ إِخْرَاجَ الْيَهُودِ مِنْهَا فَسَأَلَتِ الْيَهُودُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يُقِرَّهُمْ بِهَا عَلَى أَنْ يَكْفُوا عَمَلَهَا وَلَهُمْ نِصْفُ الثَّمَرِ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نُقِرُّكُمْ بِهَا عَلَى ذَلِكَ مَا شِئْنَا ‏"‏ ‏.‏ فَقَرُّوا بِهَا حَتَّى أَجْلاَهُمْ عُمَرُ إِلَى تَيْمَاءَ وَأَرِيحَاءَ ‏.‏\hadithno{3967}\hadithtrans{Ibn Umar reported that 'Umar b. al-Khattab (Allah be pleased with him) expelled the Jews and Christians from the land of Hijaz, and that when Allah's Messenger (ﷺ) conquered Khaibar he made up his mind to expel the Jews from it (the territory of Khaibar) because, when that land was conquered, it came under the sway of Allah, that of His Messenger (ﷺ) and that of the Muslims. The jews asked Allah's Messenger (ﷺ) to let them continue there on the condition that they would work on it, and would get in turn half of the fruit (of the trees), whereupon Allah's Messenger (ﷺ) said:We would let you continue there so long as we will desire. So they continued (to cultivate the lands) till 'Umar externed them to Taima' ang Ariha (two villages in Arabia, but out of Hijaz)}}
\hadithdefcmd{muslim}{3968}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمٍ يَغْرِسُ غَرْسًا إِلاَّ كَانَ مَا أُكِلَ مِنْهُ لَهُ صَدَقَةٌ وَمَا سُرِقَ مِنْهُ لَهُ صَدَقَةٌ وَمَا أَكَلَ السَّبُعُ مِنْهُ فَهُوَ لَهُ صَدَقَةٌ وَمَا أَكَلَتِ الطَّيْرُ فَهُوَ لَهُ صَدَقَةً وَلاَ يَرْزَؤُهُ أَحَدٌ إِلاَّ كَانَ لَهُ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{3968}\hadithtrans{Jabir (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Never does a Muslim plants a tree except that he has the reward of charity for him, for what is eaten out of that is charity; what is stolen out of that, what the beasts eat out of that, what the birds eat out of that is charity for him. (In short) none incurs a loss to him but it becomes a charity on his part}}
\hadithdefcmd{muslim}{3969}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَى أُمِّ مُبَشِّرٍ الأَنْصَارِيَّةِ فِي نَخْلٍ لَهَا فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ غَرَسَ هَذَا النَّخْلَ أَمُسْلِمٌ أَمْ كَافِرٌ ‏"‏ ‏.‏ فَقَالَتْ بَلْ مُسْلِمٌ ‏.‏ فَقَالَ ‏"‏ لاَ يَغْرِسُ مُسْلِمٌ غَرْسًا وَلاَ يَزْرَعُ زَرْعًا فَيَأْكُلَ مِنْهُ إِنْسَانٌ وَلاَ دَابَّةٌ وَلاَ شَىْءٌ إِلاَّ كَانَتْ لَهُ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{3969}\hadithtrans{Jabir (Allah be pleased with him) reported that Allah's Apostle (ﷺ) visited Umm Mubashshir al-Ansariya at her orchard of date-palms and said to her:Who has planted these trees of dates-a Muslim or a non-Musim? She said: A Muslim, of course, whereupon he said: Never a Muslim plants, or cultivates a land, and it out of that men eat, or the animals eat, or anything else eats, but that becomes charity on his (planter's) behalf}}
\hadithdefcmd{muslim}{3970}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَابْنُ أَبِي خَلَفٍ، قَالاَ حَدَّثَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَغْرِسُ رَجُلٌ مُسْلِمٌ غَرْسًا وَلاَ زَرْعًا فَيَأْكُلَ مِنْهُ سَبُعٌ أَوْ طَائِرٌ أَوْ شَىْءٌ إِلاَّ كَانَ لَهُ فِيهِ أَجْرٌ ‏"‏ ‏.‏ وَقَالَ ابْنُ أَبِي خَلَفٍ طَائِرٌ شَىْءٌ ‏.‏\hadithno{3970}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:I heard Allah's Messenger (ﷺ) saying: Never does a Muslim plant, or cultivate, but has reward for him for what the beasts eat, or the birds eat or anything else eats out of that}}
\hadithdefcmd{muslim}{3971}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدِ بْنِ إِبْرَاهِيمَ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى أُمِّ مَعْبَدٍ حَائِطًا فَقَالَ ‏"‏ يَا أُمَّ مَعْبَدٍ مَنْ غَرَسَ هَذَا النَّخْلَ أَمُسْلِمٌ أَمْ كَافِرٌ ‏"‏ ‏.‏ فَقَالَتْ بَلْ مُسْلِمٌ ‏.‏ قَالَ ‏"‏ فَلاَ يَغْرِسُ الْمُسْلِمُ غَرْسًا فَيَأْكُلَ مِنْهُ إِنْسَانٌ وَلاَ دَابَّةٌ وَلاَ طَيْرٌ إِلاَّ كَانَ لَهُ صَدَقَةً إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3971}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported:Allah's Apostle (ﷺ) visited the orchard of Umm Ma'sud and said: Umm Ma'bad. he who has planted this tree, is he a Muslim or a non-Muslim? She said: Of course, he is a Muslim, whereupon he (the Holy Prophet) said: No Muslim who plants (trees) and from their fruits the human beings or the beasts or birds eat, but that would be taken as an act of charity on the Day of Resurrection}}
\hadithdefcmd{muslim}{3972}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَإِسْحَاقُ، بْنُ إِبْرَاهِيمَ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا عَمَّارُ بْنُ مُحَمَّدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ فُضَيْلٍ، كُلُّ هَؤُلاَءِ عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، ‏.‏ زَادَ عَمْرٌو فِي رِوَايَتِهِ عَنْ عَمَّارٍ، وَأَبُو كُرَيْبٍ فِي رِوَايَتِهِ عَنْ أَبِي مُعَاوِيَةَ، فَقَالاَ عَنْ أُمِّ مُبَشِّرٍ، وَفَى رِوَايَةِ ابْنِ فُضَيْلٍ عَنِ امْرَأَةِ، زَيْدِ بْنِ حَارِثَةَ وَفِي رِوَايَةِ إِسْحَاقَ عَنْ أَبِي مُعَاوِيَةَ، قَالَ رُبَّمَا قَالَ عَنْ أُمِّ مُبَشِّرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُبَّمَا لَمْ يَقُلْ وَكُلُّهُمْ قَالُوا عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ حَدِيثِ عَطَاءٍ وَأَبِي الزُّبَيْرِ وَعَمْرِو بْنِ دِينَارٍ ‏.‏\hadithno{3972}\hadithtrans{This hadith is transmitted on the authority of Abu Muawiya (but With a slight change of words)}}
\hadithdefcmd{muslim}{3973}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمٍ يَغْرِسُ غَرْسًا أَوْ يَزْرَعُ زَرْعًا فَيَأْكُلُ مِنْهُ طَيْرٌ أَوْ إِنْسَانٌ أَوْ بَهِيمَةٌ إِلاَّ كَانَ لَهُ بِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{3973}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying Never does a Muslim plant trees or cultivate land and birds or a man or a beast eat out of them but that is a charity on his behalf}}
\hadithdefcmd{muslim}{3974}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم دَخَلَ نَخْلاً لأُمِّ مُبَشِّرٍ - امْرَأَةٍ مِنَ الأَنْصَارِ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ غَرَسَ هَذَا النَّخْلَ أَمُسْلِمٌ أَمْ كَافِرٌ ‏"‏ ‏.‏ قَالُوا مُسْلِمٌ ‏.‏ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{3974}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported that Allah's Apostle (ﷺ) visited the date-palms of Umm Mubashshir (Allah be pleased with her), a lady from the Ansar, and said:Who planted this palm-a Muslim or an unbelievers The rest of the hadith is the same}}
\hadithdefcmd{muslim}{3975}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنِ ابْنِ جُرَيْجٍ، أَنَّ أَبَا الزُّبَيْرِ، أَخْبَرَهُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنْ بِعْتَ مِنْ أَخِيكَ ثَمَرًا ‏"‏‏.‏ ح. وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا أَبُو ضَمْرَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ بِعْتَ مِنْ أَخِيكَ ثَمَرًا فَأَصَابَتْهُ جَائِحَةٌ فَلاَ يَحِلُّ لَكَ أَنْ تَأْخُذَ مِنْهُ شَيْئًا بِمَ تَأْخُذُ مَالَ أَخِيكَ بِغَيْرِ حَقٍّ ‏"‏‏.‏\hadithno{3975}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) saying:If You sell fruits to your brother (and Jabir b. Ahduthh reported through another chain of narrators: If you were to sell fruits to your brother) and these is a stricken with Calamity, it is not permissible for you to get anything from him. Why do you get the wealth of your brother, without jutification?}}
\hadithdefcmd{muslim}{3976}{وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3976}\hadithtrans{A hadith like this has been narrated on the authority of Juraij with the same chain of transmitters}}
\hadithdefcmd{muslim}{3977}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ ثَمَرِ النَّخْلِ حَتَّى تَزْهُوَ ‏.‏ فَقُلْنَا لأَنَسٍ مَا زَهْوُهَا قَالَ تَحْمَرُّ وَتَصْفَرُّ ‏.‏ أَرَأَيْتَكَ إِنْ مَنَعَ اللَّهُ الثَّمَرَةَ بِمَ تَسْتَحِلُّ مَالَ أَخِيكَ\hadithno{3977}\hadithtrans{Anas (Allah be pleased with him) reported that Allah's Apostle (ﷺ) forbade the sale of the fruit of date-palms until it becomes mellow. We (some of the other narrators in the chain of transmitters) said:What does the word" mellow" mean? He said: (There the fruit) turns red or yellow. Don't you see if Allah had checked (the growth of) fruits; then what for the wealth of your brother would be permissible for you?}}
\hadithdefcmd{muslim}{3978}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ، بْنِ مَالِكٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرَةِ حَتَّى تُزْهِيَ قَالُوا وَمَا تُزْهِيَ قَالَ تَحْمَرُّ ‏.‏ فَقَالَ إِذَا مَنَعَ اللَّهُ الثَّمَرَةَ فَبِمَ تَسْتَحِلُّ مَالَ أَخِيكَ\hadithno{3978}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade the sale of fruits until these are mellow. They (the companions of Anas) said:What is meant by" mellow"? He said: It implies that these became red. He said: When Allah hinders the growth of fruits, (then) what for the wealth of your brother would become permissible for you?}}
\hadithdefcmd{muslim}{3979}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ لَمْ يُثْمِرْهَا اللَّهُ فَبِمَ يَسْتَحِلُّ أَحَدُكُمْ مَالَ أَخِيهِ ‏"‏ ‏.‏\hadithno{3979}\hadithtrans{Anas (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:If Allah does not fructify them, then what is permissible for one of you to take the wealth of his brother?}}
\hadithdefcmd{muslim}{3980}{حَدَّثَنَا بِشْرُ بْنُ الْحَكَمِ، وَإِبْرَاهِيمُ بْنُ دِينَارٍ، وَعَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، - وَاللَّفْظُ لِبِشْرٍ - قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ سُلَيْمَانَ بْنِ عَتِيقٍ، عَنْ جَابِرٍ، أَنَّوسلم أَمَرَ بِوَضْعِ الْجَوَائِحِ ‏.‏ قَالَ أَبُو إِسْحَاقَ - وَهْوَ صَاحِبُ مُسْلِمٍ - حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ عَنْ سُفْيَانَ بِهَذَا ‏.‏\hadithno{3980}\hadithtrans{Jabir (Allah be pleased with him) reported that Allah's Apostle (ﷺ) commanded to make deductions in the payment of that stricken with a Calamity}}
\hadithdefcmd{muslim}{3981}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ بُكَيْرٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي، سَعِيدٍ الْخُدْرِيِّ قَالَ أُصِيبَ رَجُلٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ثِمَارٍ ابْتَاعَهَا فَكَثُرَ دَيْنُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقُوا عَلَيْهِ ‏"‏ ‏.‏ فَتَصَدَّقَ النَّاسُ عَلَيْهِ فَلَمْ يَبْلُغْ ذَلِكَ وَفَاءَ دَيْنِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِغُرَمَائِهِ ‏"‏ خُذُوا مَا وَجَدْتُمْ وَلَيْسَ لَكُمْ إِلاَّ ذَلِكَ ‏"‏ ‏.‏\hadithno{3981}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleeased with him) reported that in the time of Allah's Messenger (ﷺ) a man suffered loss in fruits he had bought and his debt increased; so Allah's Messenger (ﷺ) told (the people) to give him charity and they gave him charity, but that was not enough to pay the debt in full, whereupon Allah's Messenger (ﷺ) said to his creditors:" Take what you find, you will have nothing but alms}}
\hadithdefcmd{muslim}{3982}{حَدَّثَنِي يُونُسُ بْنُ عَبْدِ الأَعْلَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3982}\hadithtrans{This hadith has been narrated on the authority of Bukair b. al-Ashajj with the same chain of transmitters}}
\hadithdefcmd{muslim}{3983}{وَحَدَّثَنِي غَيْرُ، وَاحِدٍ، مِنْ أَصْحَابِنَا قَالُوا حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، - وَهُوَ ابْنُ بِلاَلٍ - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي الرِّجَالِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ أُمَّهُ، عَمْرَةَ بِنْتَ عَبْدِ الرَّحْمَنِ قَالَتْ سَمِعْتُ عَائِشَةَ، تَقُولُ سَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَوْتَ خُصُومٍ بِالْبَابِ عَالِيَةً أَصْوَاتُهُمَا وَإِذَا أَحَدُهُمَا يَسْتَوْضِعُ الآخَرَ وَيَسْتَرْفِقُهُ فِي شَىْءٍ وَهُوَ يَقُولُ وَاللَّهِ لاَ أَفْعَلُ ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَيْهِمَا فَقَالَ ‏ "‏ أَيْنَ الْمُتَأَلِّي عَلَى اللَّهِ لاَ يَفْعَلُ الْمَعْرُوفَ ‏"‏ ‏.‏ قَالَ أَنَا يَا رَسُولَ اللَّهِ فَلَهُ أَىُّ ذَلِكَ أَحَبَّ ‏.‏\hadithno{3983}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) heard the voices of altercation of two disputants at the door; both the voices were quite loud. The one demanded some remission and desired that the other one should show leniency to him, whereupon the (other one) was saying: By Allah will not do that. Then there came Allah's Messenger (ﷺ) to them and said: Where is he who swears by Allah that he would not do good? He said: Massenger of Allah, it is I. He may do as he desires}}
\hadithdefcmd{muslim}{3984}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ كَعْبِ بْنِ مَالِكٍ، أَخْبَرَهُ عَنْ أَبِيهِ، أَنَّهُ تَقَاضَى ابْنَ أَبِي حَدْرَدٍ دَيْنًا كَانَ لَهُ عَلَيْهِ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ فَارْتَفَعَتْ أَصْوَاتُهُمَا حَتَّى سَمِعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي بَيْتِهِ فَخَرَجَ إِلَيْهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى كَشَفَ سِجْفَ حُجْرَتِهِ وَنَادَى كَعْبَ بْنَ مَالِكٍ فَقَالَ ‏"‏ يَا كَعْبُ ‏"‏ ‏.‏ فَقَالَ لَبَّيْكَ يَا رَسُولَ اللَّهِ ‏.‏ فَأَشَارَ إِلَيْهِ بِيَدِهِ أَنْ ضَعِ الشَّطْرَ مِنْ دَيْنِكَ ‏.‏ قَالَ كَعْبٌ قَدْ فَعَلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُمْ فَاقْضِهِ ‏"‏ ‏.‏\hadithno{3984}\hadithtrans{Abdullah b. Ka'ab b. Malik reported from his father that he pressed in the mosque Ibn Abu Hadrad for the payment of the debt that he owed to him during the lifetime of Allah's Messenger (ﷺ). (In this altercation) their voices became loud, until Allah's Messenger (ﷺ) heard them, while he was in the house, so Allah's Messenger (ﷺ) came out towards them, and he lifted the curtain of his apartment and he called upon Ka'b b. Malik and said:O Ka'b. He said: At thy beck and call, Allah's Messenger. He pointed out with the help of his hand to remit half of the loan due to him. Ka'b said: Allah's Messenger, I am ready to do that, whereupon Allah's Messenger (ﷺ) said (to Ibn Abu Hadrad): Stand up and make him the payment (of the rest)}}
\hadithdefcmd{muslim}{3985}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ،لا عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ كَعْبَ بْنَ مَالِكٍ، أَخْبَرَهُ أَنَّهُ، تَقَاضَى دَيْنًا لَهُ عَلَى ابْنِ أَبِي حَدْرَدٍ بِمِثْلِ حَدِيثِ ابْنِ وَهْبٍ ‏.‏\hadithno{3985}\hadithtrans{The above hadith is narrated through another chain with a slight variation of words at the begining and the rest is of the hadith is the same}}
\hadithdefcmd{muslim}{3986}{قَالَ مُسْلِمٌ وَرَوَى اللَّيْثُ بْنُ سَعْدٍ، حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ، هُرْمُزَ عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ كَعْبِ بْنِ مَالِكٍ، أَنَّهُ كَانَ لَهُ مَالٌ عَلَى عَبْدِ اللَّهِ بْنِ أَبِي حَدْرَدٍ الأَسْلَمِيِّ فَلَقِيَهُ فَلَزِمَهُ فَتَكَلَّمَا حَتَّى ارْتَفَعَتْ أَصْوَاتُهُمَا فَمَرَّ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا كَعْبُ ‏"‏ ‏.‏ فَأَشَارَ بِيَدِهِ كَأَنَّهُ يَقُولُ النِّصْفَ فَأَخَذَ نِصْفًا مِمَّا عَلَيْهِ وَتَرَكَ نِصْفًا ‏.‏\hadithno{3986}\hadithtrans{Ka'b b. Malik reported that he made a demand for the payment of the debt that Ibn Abu Hadrad owed to him. This hadith is narrated through another chain of transmitters and (the words are):" He had to get the loan from Abdullah b. Hadrad al-Aslami. He met him and pressed him for payment. There was an altercation between them, until their voices became loud. There happened to pass by them Allah's Messenger (ﷺ) and he said: O Ka'b, and pointed out with his hand in such a way as he meant half. So he got half of what he (Ibn Abu Hadrad) owed to him and remitted the half}}
\hadithdefcmd{muslim}{3987}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، أَخْبَرَنِي أَبُو بَكْرِ بْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخْبَرَهُ أَنَّ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم - أَوْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ - ‏ "‏ مَنْ أَدْرَكَ مَالَهُ بِعَيْنِهِ عِنْدَ رَجُلٍ قَدْ أَفْلَسَ - أَوْ إِنْسَانٍ قَدْ أَفْلَسَ - فَهُوَ أَحَقُّ بِهِ مِنْ غَيْرِهِ ‏"‏ ‏.‏\hadithno{3987}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who found his property intact with a person (who bought it but who later on) became insolvent (or a person who became insolvent), he (the seller) is entitled to get it more than anyone else}}
\hadithdefcmd{muslim}{3988}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، جَمِيعًا عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَيَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، قَالاَ حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، وَيَحْيَى بْنُ سَعِيدٍ، وَحَفْصُ بْنُ غِيَاثٍ، كُلُّ هَؤُلاَءِ عَنْ يَحْيَى بْنِ سَعِيدٍ، فِي هَذَا الإِسْنَادِ ‏.‏ بِمَعْنَى حَدِيثِ زُهَيْرٍ وَقَالَ ابْنُ رُمْحٍ مِنْ بَيْنِهِمْ فِي رِوَايَتِهِ أَيُّمَا امْرِئٍ فُلِّسَ ‏.‏\hadithno{3988}\hadithtrans{This hadith has been narrated on the authority of Yahya b. Sa'id with the same chain of transmitters (but with a slight variation of words and these are)" Whenever a man becomes poor}}
\hadithdefcmd{muslim}{3989}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا هِشَامُ بْنُ سُلَيْمَانَ، - وَهُوَ ابْنُ عِكْرِمَةَ بْنِ خَالِدٍ الْمَخْزُومِيُّ - عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي ابْنُ أَبِي حُسَيْنٍ، أَنَّ أَبَا بَكْرِ بْنَ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَخْبَرَهُ أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ حَدَّثَهُ عَنْ حَدِيثِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَدِيثِ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرَّجُلِ الَّذِي يُعْدِمُ إِذَا وُجِدَ عِنْدَهُ الْمَتَاعُ وَلَمْ يُفَرِّقْهُ ‏ "‏ أَنَّهُ لِصَاحِبِهِ الَّذِي بَاعَهُ ‏"‏ ‏.‏\hadithno{3989}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) saying about a person who becomes insolvent and (the thing bought by him) is found intact with him, that belongs to one who sold it}}
\hadithdefcmd{muslim}{3990}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَفْلَسَ الرَّجُلُ فَوَجَدَ الرَّجُلُ مَتَاعَهُ بِعَيْنِهِ فَهُوَ أَحَقُّ بِهِ ‏"‏ ‏.‏\hadithno{3990}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:When a man becomes insolvent (and the other) man (the seller) finds his commodity intact with him, he is more entitled to get it (than anyone else)}}
\hadithdefcmd{muslim}{3991}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا سَعِيدٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، أَيْضًا حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي كِلاَهُمَا، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَقَالاَ ‏ "‏ فَهُوَ أَحَقُّ بِهِ مِنَ الْغُرَمَاءِ ‏"‏ ‏.‏\hadithno{3991}\hadithtrans{This hadith has been narrated on the authority of Qatada with the same chain of transmitters (but with a change of these words):" He is more entitled to get it than any other creditor}}
\hadithdefcmd{muslim}{3992}{وَحَدَّثَنِي مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا أَبُو سَلَمَةَ، الْخُزَاعِيُّ - قَالَ حَجَّاجٌ مَنْصُورُ بْنُ سَلَمَةَ - أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ خُثَيْمِ بْنِ عِرَاكٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَفْلَسَ الرَّجُلُ فَوَجَدَ الرَّجُلُ عِنْدَهُ سِلْعَتَهُ بِعَيْنِهَا فَهُوَ أَحَقُّ بِهَا ‏"‏ ‏.‏\hadithno{3992}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:When a inan becomes insolvent, and the other person (seller) finds his goods intact with him, he is more entitled to get them than anyone else}}
\hadithdefcmd{muslim}{3993}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مَنْصُورٌ، عَنْ رِبْعِيِّ بْنِ، حِرَاشٍ أَنَّ حُذَيْفَةَ، حَدَّثَهُمْ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَلَقَّتِ الْمَلاَئِكَةُ رُوحَ رَجُلٍ مِمَّنْ كَانَ قَبْلَكُمْ فَقَالُوا أَعَمِلْتَ مِنَ الْخَيْرِ شَيْئًا قَالَ لاَ ‏.‏ قَالُوا تَذَكَّرْ ‏.‏ قَالَ كُنْتُ أُدَايِنُ النَّاسَ فَآمُرُ فِتْيَانِي أَنْ يُنْظِرُوا الْمُعْسِرَ وَيَتَجَوَّزُوا عَنِ الْمُوسِرِ - قَالَ - قَالَ اللَّهُ عَزَّ وَجَلَّ تَجَوَّزُوا عَنْهُ ‏"‏ ‏.‏\hadithno{3993}\hadithtrans{Hudhaifa reported Allah's Messenger (ﷺ) as saying The angels took away the soul of a person who had lived among people who were before you. They (the angels) said:Did you do anything good? He said: No. they said: Try to recall. He said: I used to lend to people and order my servants to give respite to one in straitened circumstances and give allowance to the solvent, for Allah, the Exalted and Majestic, said (to the angels): You should ignore (his failing)}}
\hadithdefcmd{muslim}{3994}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لاِبْنِ حُجْرٍ - قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الْمُغِيرَةِ، عَنْ نُعَيْمِ بْنِ أَبِي هِنْدٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، قَالَ اجْتَمَعَ حُذَيْفَةُ وَأَبُو مَسْعُودٍ فَقَالَ حُذَيْفَةُ ‏ "‏ رَجُلٌ لَقِيَ رَبَّهُ فَقَالَ مَا عَمِلْتَ قَالَ مَا عَمِلْتُ مِنَ الْخَيْرِ إِلاَّ أَنِّي كُنْتُ رَجُلاً ذَا مَالٍ فَكُنْتُ أُطَالِبُ بِهِ النَّاسَ فَكُنْتُ أَقْبَلُ الْمَيْسُورَ وَأَتَجَاوَزُ عَنِ الْمَعْسُورِ ‏.‏ فَقَالَ تَجَاوَزُوا عَنْ عَبْدِي ‏"‏ ‏.‏ قَالَ أَبُو مَسْعُودٍ هَكَذَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏\hadithno{3994}\hadithtrans{Hudhaifa reported:A person met his Lord (after death) and He said: What (good) did you do? He said: I did no good except this that I was a rich man, and I demanded from the people (the repayment of debt that I advanced to them). I, however, accepted that which the solvent gave and remitted (the debt) of the insolvent, whereupon He (the Lord) said: You should ignore (the faults) of My servant. Abu Mas'ud (Allah be pleased with him) said: This is what I heard Allah's Messenger (ﷺ) as saying}}
\hadithdefcmd{muslim}{3995}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ، عُمَيْرٍ عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ رَجُلاً مَاتَ فَدَخَلَ الْجَنَّةَ فَقِيلَ لَهُ مَا كُنْتَ تَعْمَلُ قَالَ فَإِمَّا ذَكَرَ وَإِمَّا ذُكِّرَ ‏.‏ فَقَالَ إِنِّي كُنْتُ أُبَايِعُ النَّاسَ فَكُنْتُ أُنْظِرُ الْمُعْسِرَ وَأَتَجَوَّزُ فِي السِّكَّةِ أَوْ فِي النَّقْدِ ‏.‏ فَغُفِرَ لَهُ ‏"‏ ‏.‏ فَقَالَ أَبُو مَسْعُودٍ وَأَنَا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3995}\hadithtrans{Hudhaifa (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:A person died and he entered Paradise. It was said to him What (act) did you do? (Either he recalled it himself or he was made to recall), he said I used to enter into transactions with people and I gave respite to the insolvent and did not show any strictness in case of accepting a coin or demanding cash payment. (For these acts of his) he was granted pardon. Abu Mas'ud said: I heard this from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3996}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ سَعْدِ بْنِ طَارِقٍ، عَنْ رِبْعِيِّ، بْنِ حِرَاشٍ عَنْ حُذَيْفَةَ، قَالَ ‏ "‏ أُتِيَ اللَّهُ بِعَبْدٍ مِنْ عِبَادِهِ آتَاهُ اللَّهُ مَالاً فَقَالَ لَهُ مَاذَا عَمِلْتَ فِي الدُّنْيَا - قَالَ وَلاَ يَكْتُمُونَ اللَّهَ حَدِيثًا - قَالَ يَا رَبِّ آتَيْتَنِي مَالَكَ فَكُنْتُ أُبَايِعُ النَّاسَ وَكَانَ مِنْ خُلُقِي الْجَوَازُ فَكُنْتُ أَتَيَسَّرُ عَلَى الْمُوسِرِ وَأُنْظِرُ الْمُعْسِرَ ‏.‏ فَقَالَ اللَّهُ أَنَا أَحَقُّ بِذَا مِنْكَ تَجَاوَزُوا عَنْ عَبْدِي ‏"‏ ‏.‏ فَقَالَ عُقْبَةُ بْنُ عَامِرٍ الْجُهَنِيُّ وَأَبُو مَسْعُودٍ الأَنْصَارِيُّ هَكَذَا سَمِعْنَاهُ مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3996}\hadithtrans{Hudhaifa (Allah be pleased with him) reported:A servant from amongst the servants of Allah was brought to Him whom Allah had endowed with riches. He (Allah) said to him: What (did you do) in the world? (They cannot conceal anything from Allah) He (the person) said: O my Lord, You endowed me with Your riches. I used to enter into transactions with people. It was my nature to be lenient to (my debtors). I showed leniency to the solvent and gave respite to the insolvent, whereupon Allah said: I have more right than you to do this to connive at My servant. 'Uqba b. 'Amir al-Juhani and Abu Mas'ud said: This is what we heard from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3997}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حُوسِبَ رَجُلٌ مِمَّنْ كَانَ قَبْلَكُمْ فَلَمْ يُوجَدْ لَهُ مِنَ الْخَيْرِ شَىْءٌ إِلاَّ أَنَّهُ كَانَ يُخَالِطُ النَّاسَ وَكَانَ مُوسِرًا فَكَانَ يَأْمُرُ غِلْمَانَهُ أَنْ يَتَجَاوَزُوا عَنِ الْمُعْسِرِ قَالَ قَالَ اللَّهُ عَزَّ وَجَلَّ نَحْنُ أَحَقُّ بِذَلِكَ مِنْهُ تَجَاوَزُوا عَنْهُ ‏"‏ ‏.‏\hadithno{3997}\hadithtrans{Abu Mas'ud (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:A person from people who lived before you was called to account (by Allah at the Day of Judgment) and no good was found in his account except this that lie being a rich man had (financial) dealings with people and had commanded his servants to show leniency to the straitened ones. Upon this Allah, the Exalted and Majestic, said: We have more right to this, so overlook (his faults)}}
\hadithdefcmd{muslim}{3998}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، وَمُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ، - قَالَ مَنْصُورٌ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، وَقَالَ ابْنُ جَعْفَرٍ، أَخْبَرَنَا إِبْرَاهِيمُ، وَهُوَ ابْنُ سَعْدٍ عَنِ ابْنِ، شِهَابٍ عَنِ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ رَجُلٌ يُدَايِنُ النَّاسَ فَكَانَ يَقُولُ لِفَتَاهُ إِذَا أَتَيْتَ مُعْسِرًا فَتَجَاوَزْ عَنْهُ لَعَلَّ اللَّهَ يَتَجَاوَزُ عَنَّا ‏.‏ فَلَقِيَ اللَّهَ فَتَجَاوَزَ عَنْهُ ‏"‏ ‏.‏\hadithno{3998}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:There was a person who gave loans to the people and said to his men: When an insolvent comes to you show him leniency that Allah may overlook our (faults). So when he met Allah, He overlooked his faults (forgave him)}}
\hadithdefcmd{muslim}{3999}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{3999}\hadithtrans{A hadith like this is narrated on the authority of Abu Huraira (Allah be pleased with him)}}
\hadithdefcmd{muslim}{4000}{حَدَّثَنَا أَبُو الْهَيْثَمِ، خَالِدُ بْنُ خِدَاشِ بْنِ عَجْلاَنَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، أَنَّ أَبَا قَتَادَةَ، طَلَبَ غَرِيمًا لَهُ فَتَوَارَى عَنْهُ ثُمَّ وَجَدَهُ فَقَالَ إِنِّي مُعْسِرٌ ‏.‏ فَقَالَ آللَّهِ قَالَ آللَّهِ ‏.‏ قَالَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ سَرَّهُ أَنْ يُنْجِيَهُ اللَّهُ مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ فَلْيُنَفِّسْ عَنْ مُعْسِرٍ أَوْ يَضَعْ عَنْهُ ‏"‏ ‏.‏\hadithno{4000}\hadithtrans{Abdullah b. Abu Qatada reported that Abu Qatada (Allah be pleased with him) demanded (the payment of his debt) from his debtor but he disappeared; later on he found him and he said:I am hard up financially, whereupon he said: (Do you state it) by God? He said: By God. Upon this he (Qatada) said: I heard Allah's Messenger (ﷺ) as saying: He who loves that Allah saves him from the torments of the Day of Resurrection should give respite to the insolvent or remit (his debt)}}
\hadithdefcmd{muslim}{4001}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4001}\hadithtrans{This hadith has been narrated on the authority of Ayyob with the same chain of transmitters}}
\hadithdefcmd{muslim}{4002}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَطْلُ الْغَنِيِّ ظُلْمٌ وَإِذَا أُتْبِعَ أَحَدُكُمْ عَلَى مَلِيءٍ فَلْيَتْبَعْ ‏"‏ ‏.‏\hadithno{4002}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Delay (in the payment of debt) on the part of a rich man is injustice, and when one of you is retired to a rich man, he should follow him}}
\hadithdefcmd{muslim}{4003}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالاَ جَمِيعًا حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4003}\hadithtrans{A hadith like this has been transmitted on the authority of Abu Huraira (Allah be pleased with him)}}
\hadithdefcmd{muslim}{4004}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، أَخْبَرَنَا وَكِيعٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ فَضْلِ الْمَاءِ ‏.‏\hadithno{4004}\hadithtrans{Jabir b. 'Abdullah (, Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade the sale of excess water}}
\hadithdefcmd{muslim}{4005}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ ضِرَابِ الْجَمَلِ وَعَنْ بَيْعِ الْمَاءِ وَالأَرْضِ لِتُحْرَثَ ‏.‏ فَعَنْ ذَلِكَ نَهَى النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4005}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade the hiring of a Camel to cover a she-Camel and from selling water and land to be tilled. So from all this the Messenger of Allah (ﷺ) forbade}}
\hadithdefcmd{muslim}{4006}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، كِلاَهُمَا عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُمْنَعُ فَضْلُ الْمَاءِ لِيُمْنَعَ بِهِ الْكَلأُ ‏"‏ ‏.‏\hadithno{4006}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Excess water must not be withheld so that the growth of herbage may be hindered}}
\hadithdefcmd{muslim}{4007}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، - وَاللَّفْظُ لِحَرْمَلَةَ - أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَمْنَعُوا فَضْلَ الْمَاءِ لِتَمْنَعُوا بِهِ الْكَلأَ ‏"‏ ‏.‏\hadithno{4007}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Do not withhold excess of water, so that you may prevent the growth of herbage}}
\hadithdefcmd{muslim}{4008}{وَحَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي زِيَادُ بْنُ سَعْدٍ، أَنَّ هِلاَلَ بْنَ أُسَامَةَ، أَخْبَرَهُ أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُبَاعُ فَضْلُ الْمَاءِ لِيُبَاعَ بِهِ الْكَلأُ ‏"‏ ‏.‏\hadithno{4008}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:The excess of water should not be sold in order to enable the sate of herbage}}
\hadithdefcmd{muslim}{4009}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ، عَبْدِ الرَّحْمَنِ عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏"‏ ‏.‏\hadithno{4009}\hadithtrans{Aba Mas'ud al-Ansari (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade the charging of price of the dog, and earnings of a prostitute and sweets offered to a kahin}}
\hadithdefcmd{muslim}{4010}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ، بْنُ أَبِي شَيْبَةَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏ وَفِي حَدِيثِ اللَّيْثِ مِنْ رِوَايَةِ ابْنِ رُمْحٍ أَنَّهُ سَمِعَ أَبَا مَسْعُودٍ ‏.‏\hadithno{4010}\hadithtrans{A hadith like this is reported on the authority of Abu Mas'ud through another chain of transmitters}}
\hadithdefcmd{muslim}{4011}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ مُحَمَّدِ بْنِ يُوسُفَ، قَالَ سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، يُحَدِّثُ عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ شَرُّ الْكَسْبِ مَهْرُ الْبَغِيِّ وَثَمَنُ الْكَلْبِ وَكَسْبُ الْحَجَّامِ ‏"‏ ‏.‏\hadithno{4011}\hadithtrans{Rafi b. Khadij (Allah be pleased with him) reported:I heard Allah's Apostle (ﷺ) as saying: The worst earning is the earning of a prostitute, the price of a dog and the earning of a cupper}}
\hadithdefcmd{muslim}{4012}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ حَدَّثَنِي إِبْرَاهِيمُ بْنُ قَارِظٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، حَدَّثَنِي رَافِعُ بْنُ خَدِيجٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ثَمَنُ الْكَلْبِ خَبِيثٌ وَمَهْرُ الْبَغِيِّ خَبِيثٌ وَكَسْبُ الْحَجَّامِ خَبِيثٌ ‏"‏ ‏.‏\hadithno{4012}\hadithtrans{Rafi b. Khadij reported Allah'\& Messenger (ﷺ) as saying:The price of a dog is evil, the earning of a prostitute is evil and the earning of a cupper is evil}}
\hadithdefcmd{muslim}{4013}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي، كَثِيرٍ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4013}\hadithtrans{A hadith like this has been narrated on the authority of Rafi' b. Khadij through another chain of transmitters}}
\hadithdefcmd{muslim}{4014}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ حَدَّثَنِي إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ، عَنِ السَّائِبِ بْنِ يَزِيدَ، حَدَّثَنَا رَافِعُ بْنُ خَدِيجٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4014}\hadithtrans{A hadith like this has been narrated on the authority of Rafi' b. Khadij through another chain of transmitters}}
\hadithdefcmd{muslim}{4015}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، قَالَ سَأَلْتُ جَابِرًا عَنْ ثَمَنِ الْكَلْبِ، وَالسِّنَّوْرِ، قَالَ زَجَرَ النَّبِيُّ صلى الله عليه وسلم عَنْ ذَلِكَ ‏.‏\hadithno{4015}\hadithtrans{Abu Zubair said:I asked Jabir about the price of a dog and a cat; he said: Allah's Messenger (ﷺ) disapproved of that}}
\hadithdefcmd{muslim}{4016}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ ‏.‏\hadithno{4016}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) giving command for killing dogs}}
\hadithdefcmd{muslim}{4017}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الْكِلاَبِ فَأَرْسَلَ فِي أَقْطَارِ الْمَدِينَةِ أَنْ تُقْتَلَ ‏.‏\hadithno{4017}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported:Allah's Messenger (ﷺ) ordered to kill dogs, and he sent (men) to the corners of Medina that they should be killed}}
\hadithdefcmd{muslim}{4018}{وَحَدَّثَنِي حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ أُمَيَّةَ - عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِقَتْلِ الْكِلاَبِ فَنَنْبَعِثُ فِي الْمَدِينَةِ وَأَطْرَافِهَا فَلاَ نَدَعُ كَلْبًا إِلاَّ قَتَلْنَاهُ حَتَّى إِنَّا لَنَقْتُلُ كَلْبَ الْمُرَيَّةِ مِنْ أَهْلِ الْبَادِيَةِ يَتْبَعُهَا ‏.‏\hadithno{4018}\hadithtrans{Abdullah (b. Umar) (Allah be pleased with them) reported:Allah's Messenger (ﷺ) ordered the killing of dogs and we would send (men) in Medina and its corners and we did not spare any dog that we did not kill, so much so that we killed the dog that accompanied the wet she-camel belonging to the people of the desert}}
\hadithdefcmd{muslim}{4019}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ إِلاَّ كَلْبَ صَيْدٍ أَوْ كَلْبَ غَنَمٍ أَوْ مَاشِيَةٍ ‏.‏ فَقِيلَ لاِبْنِ عُمَرَ إِنَّ أَبَا هُرَيْرَةَ يَقُولُ أَوْ كَلْبَ زَرْعٍ ‏.‏ فَقَالَ ابْنُ عُمَرَ إِنَّ لأَبِي هُرَيْرَةَ زَرْعًا\hadithno{4019}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that Allah's Messenger (may peace be, upon him) ordered the killing of dogs except the dog tamed for hunting, or watching of the herd of sheep or other domestic animals. It was said to Ibn Umar (Allah be pleased with them) that Abu Huraira (Allah be pleased with him) talks of (exception) about the dog for watching the field, whereupon he said:Since Abu Huraira (Allah be pleased with him) possessed land}}
\hadithdefcmd{muslim}{4020}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا رَوْحٌ، ح وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الْكِلاَبِ حَتَّى إِنَّ الْمَرْأَةَ تَقْدَمُ مِنَ الْبَادِيَةِ بِكَلْبِهَا فَنَقْتُلُهُ ثُمَّ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ قَتْلِهَا وَقَالَ ‏ "‏ عَلَيْكُمْ بِالأَسْوَدِ الْبَهِيمِ ذِي النُّقْطَتَيْنِ فَإِنَّهُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{4020}\hadithtrans{Abu Zubair heard Jabir b. 'Abdullah (Allah be pleased with him) saying:Allah's Messenger (ﷺ) ordered us to kill dogs, and we carried out this order so much so that we also kill the dog coming with a woman from the desert. Then Allah's Apostle (ﷺ) forbade their killing. He (the Prophet further) said: It is your duty the jet-black (dog) having two spots (on the eyes), for it is a devil}}
\hadithdefcmd{muslim}{4021}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، سَمِعَ مُطَرِّفَ، بْنَ عَبْدِ اللَّهِ عَنِ ابْنِ الْمُغَفَّلِ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الْكِلاَبِ ثُمَّ قَالَ ‏ "‏ مَا بَالُهُمْ وَبَالُ الْكِلاَبِ ‏"‏ ‏.‏ ثُمَّ رَخَّصَ فِي كَلْبِ الصَّيْدِ وَكَلْبِ الْغَنَمِ ‏.‏\hadithno{4021}\hadithtrans{Ibn Mughaffal reported:Allah's Messenger (ﷺ) ordered the killing of dogs and then said: what is the trouble with them (the people of Medina)? How dogs are nuisance to them (the citizens of Medina)? He then permitted keehing of dogs for hunting and (the protection of) herds}}
\hadithdefcmd{muslim}{4022}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ، حَاتِمٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَقَالَ ابْنُ حَاتِمٍ فِي حَدِيثِهِ عَنْ يَحْيَى، وَرَخَّصَ، فِي كَلْبِ الْغَنَمِ وَالصَّيْدِ وَالزَّرْعِ ‏.‏\hadithno{4022}\hadithtrans{In the hadith transmitted on the authority of Yahya, he (the Holy Prophet) permitted the keeping of dogs for (the protection of) herds, for hunting and (the protection of) cultivated land}}
\hadithdefcmd{muslim}{4023}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ ضَارِي نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏\hadithno{4023}\hadithtrans{Ibn Umar (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who keeps a dog other than that meant for watching the herd or for hunting loses every day out of his deeds equal to two qirat}}
\hadithdefcmd{muslim}{4024}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبَ صَيْدٍ أَوْ مَاشِيَةٍ نَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏\hadithno{4024}\hadithtrans{Salim reported on the authority of his father that Allah's Apostle (ﷺ) said:He who kept a dog other than one meant for hunting or for watching the herd, lost two qirat of his reward every day}}
\hadithdefcmd{muslim}{4025}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ - قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهْوَ ابْنُ جَعْفَرٍ - عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبَ ضَارِيَةٍ أَوْ مَاشِيَةٍ نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏\hadithno{4025}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying He who kept a dog other than one meant for hunting or for watching the herd lost out of his deeds (equal to) two qirat every day}}
\hadithdefcmd{muslim}{4026}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ أَبِي حَرْمَلَةَ - عَنْ سَالِمِ بْنِ عَبْدِ، اللَّهِ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ كَلْبَ صَيْدٍ نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ وَقَالَ أَبُو هُرَيْرَةَ ‏"‏ أَوْ كَلْبَ حَرْثٍ ‏"‏ ‏.‏\hadithno{4026}\hadithtrans{Salim b. 'Abdullah reported on the authority of his father that Allah's Messenger (ﷺ) said:He who kept a dog other than one meant for watching the herd or for hunting would lose every day two qirat of his good deeds. 'Abdullah and Abu Huraira also said: Or dog meant for watching the field}}
\hadithdefcmd{muslim}{4027}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَكِيعٌ، حَدَّثَنَا حَنْظَلَةُ بْنُ أَبِي سُفْيَانَ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبَ ضَارٍ أَوْ مَاشِيَةٍ نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏ قَالَ سَالِمٌ وَكَانَ أَبُو هُرَيْرَةَ يَقُولُ ‏"‏ أَوْ كَلْبَ حَرْثٍ ‏"‏ ‏.‏ وَكَانَ صَاحِبَ حَرْثٍ ‏.‏\hadithno{4027}\hadithtrans{Salim reported on the authority of his father (Allah be pleased with him) that Allah's Messenger (ﷺ) said:He who kept a dog other than one meant for hunting or for the protection of the herd would lose two qirat of his deeds every day. Salim said: Abu Huraira (Allah be pleased with him) used to say: Or the dog meant for watching the field, and he was the owner of the land}}
\hadithdefcmd{muslim}{4028}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، أَخْبَرَنَا عُمَرُ بْنُ حَمْزَةَ بْنِ عَبْدِ، اللَّهِ بْنِ عُمَرَ حَدَّثَنَا سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا أَهْلِ دَارٍ اتَّخَذُوا كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ كَلْبَ صَائِدٍ نَقَصَ مِنْ عَمَلِهِمْ كُلَّ يَوْمٍ قِيرَاطَانِ‏"‏ ‏.‏\hadithno{4028}\hadithtrans{Salim b. Abdullah reported on the authority of his father that Allah's Messenger (ﷺ) said:Whosover amongst the owners of the house keeps a dog other than one meant for watching the herd or for hunting loses two qirat of his deeds every day}}
\hadithdefcmd{muslim}{4029}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْحَكَمِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اتَّخَذَ كَلْبًا إِلاَّ كَلْبَ زَرْعٍ أَوْ غَنَمٍ أَوْ صَيْدٍ يَنْقُصُ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏\hadithno{4029}\hadithtrans{Ibn Umar (Allah be pleased with them) narrated Allah's Messenger (ﷺ) as saying:He who kept a dog ther than one meant for watching the fields or herds or hunting would lose one qirat every day out of his reward (with God)}}
\hadithdefcmd{muslim}{4030}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اقْتَنَى كَلْبًا لَيْسَ بِكَلْبِ صَيْدٍ وَلاَ مَاشِيَةٍ وَلاَ أَرْضٍ فَإِنَّهُ يَنْقُصُ مِنْ أَجْرِهِ قِيرَاطَانِ كُلَّ يَوْمٍ ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِ أَبِي الطَّاهِرِ ‏"‏ وَلاَ أَرْضٍ ‏"‏ ‏.‏\hadithno{4030}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who kept a dog which is neither meant for hunting nor for watching the anitmals nor for watching the fields would lose two qirat every day out of his reward; and there is no mention of the fields in the hadith transmitted by Abu Tahir}}
\hadithdefcmd{muslim}{4031}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اتَّخَذَ كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ صَيْدٍ أَوْ زَرْعٍ انْتَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ فَذُكِرَ لاِبْنِ عُمَرَ قَوْلُ أَبِي هُرَيْرَةَ فَقَالَ يَرْحَمُ اللَّهُ أَبَا هُرَيْرَةَ كَانَ صَاحِبَ زَرْعٍ ‏.‏\hadithno{4031}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who kept a dog except one meant for watching the herd, or for hunting or for watching the fields. he lost two qirat of reward every day. Zuhri said: The words of Abu Huraira (Allah be pleased with him) were conveyed to Ibn Umar who said: May Allah have mercy upon Abu Huraira; he owned a field}}
\hadithdefcmd{muslim}{4032}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَمْسَكَ كَلْبًا فَإِنَّهُ يَنْقُصُ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ إِلاَّ كَلْبَ حَرْثٍ أَوْ مَاشِيَةٍ‏"‏ ‏.‏\hadithno{4032}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who kept a dog would lose out of his deeds equal to one qirat every day. except (one kept) for watching the field or herd}}
\hadithdefcmd{muslim}{4033}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا شُعَيْبُ بْنُ إِسْحَاقَ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4033}\hadithtrans{A hadith like this has been transmitted on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{4034}{حَدَّثَنَا أَحْمَدُ بْنُ الْمُنْذِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَرْبٌ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4034}\hadithtrans{This hadith has been reported on the authority of Yahya b. Abu Kathir with the same chain of transmitters}}
\hadithdefcmd{muslim}{4035}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - عَنْ إِسْمَاعِيلَ، بْنِ سُمَيْعٍ حَدَّثَنَا أَبُو رَزِينٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اتَّخَذَ كَلْبًا لَيْسَ بِكَلْبِ صَيْدٍ وَلاَ غَنَمٍ نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏\hadithno{4035}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who kept a dog, but not meant for hunting or watching the herd, would lose one qirat of reward every day}}
\hadithdefcmd{muslim}{4036}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، أَنَّ السَّائِبَ، بْنَ يَزِيدَ أَخْبَرَهُ أَنَّهُ، سَمِعَ سُفْيَانَ بْنَ أَبِي زُهَيْرٍ، - وَهُوَ رَجُلٌ مِنْ شَنُوءَةَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اقْتَنَى كَلْبًا لاَ يُغْنِي عَنْهُ زَرْعًا وَلاَ ضَرْعًا نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏ قَالَ آنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ إِي وَرَبِّ هَذَا الْمَسْجِدِ ‏.‏\hadithno{4036}\hadithtrans{Sufyan b. Abu Zuhair (he was a person belonging to the tribe of Shanu'a and was amongst the Conpanions of Allah's Messenger [may peace be upon him ) said:I heard Messenger of Allah (ﷺ) as saying: He who kept a dog (other than that) which is indispensable for watching the field or the animals would lose one qirat out of his deeds every day. As-Sa'ib b Yazid (one of the narrators) said: Did you hear it from Allah's Messenger (ﷺ)? He said: Yes. by the Lord of this mosque}}
\hadithdefcmd{muslim}{4037}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، عَنْ يَزِيدَ بْنِ، خُصَيْفَةَ أَخْبَرَنِي السَّائِبُ بْنُ يَزِيدَ، أَنَّهُ وَفَدَ عَلَيْهِمْ سُفْيَانُ بْنُ أَبِي زُهَيْرٍ الشَّنَئِيُّ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4037}\hadithtrans{This hadith has been narrated on the authority of Sufyan b. Abu Zuhair al-Shana'i}}
\hadithdefcmd{muslim}{4038}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنْ حُمَيْدٍ، قَالَ سُئِلَ أَنَسُ بْنُ مَالِكٍ عَنْ كَسْبِ الْحَجَّامِ، فَقَالَ احْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَجَمَهُ أَبُو طَيْبَةَ فَأَمَرَ لَهُ بِصَاعَيْنِ مِنْ طَعَامٍ وَكَلَّمَ أَهْلَهُ فَوَضَعُوا عَنْهُ مِنْ خَرَاجِهِ وَقَالَ ‏ "‏ إِنَّ أَفْضَلَ مَا تَدَاوَيْتُمْ بِهِ الْحِجَامَةُ أَوْ هُوَ مِنْ أَمْثَلِ دَوَائِكُمْ ‏"‏ ‏.‏\hadithno{4038}\hadithtrans{It is narrated on the authority of Humaid that Anas b. Malik was asked about the earnings of the cupper. He said:Allah's Messenger (ﷺ) got himself cupped. His cupper was Abu Taiba and he (the Holy Prophet) commanded to give him two sa's of corn. He (the Holy Prophet) talked with the members of his family and they lightened the burden of Kharaj (tax) from him (i. e. they made remis- sion in the charges of their own accord). He (Allah's Apostle) said: The best (treat- ment) which you take is cupping, or it is the best of your treatments}}
\hadithdefcmd{muslim}{4039}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي الْفَزَارِيَّ - عَنْ حُمَيْدٍ، قَالَ سُئِلَ أَنَسٌ عَنْ كَسْبِ الْحَجَّامِ، فَذَكَرَ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ إِنَّ أَفْضَلَ مَا تَدَاوَيْتُمْ بِهِ الْحِجَامَةُ وَالْقُسْطُ الْبَحْرِيُّ وَلاَ تُعَذِّبُوا صِبْيَانَكُمْ بِالْغَمْزِ ‏"‏ ‏.‏\hadithno{4039}\hadithtrans{Rumaid reported that Anas b. Malik (Allah be pleased with him) has asked about the earnings of a cupper. Then (the above-mentioned hadith was reported but with this addition) that he said:The best treatment which you get is cupping. or aloeswood and do not torture your children by pressing their uvula}}
\hadithdefcmd{muslim}{4040}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ بْنِ خِرَاشٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ دَعَا النَّبِيُّ صلى الله عليه وسلم غُلاَمًا لَنَا حَجَّامًا فَحَجَمَهُ فَأَمَرَ لَهُ بِصَاعٍ أَوْ مُدٍّ أَوْ مُدَّيْنِ وَكَلَّمَ فِيهِ فَخُفِّفَ عَنْ ضَرِيبَتِهِ ‏.‏\hadithno{4040}\hadithtrans{Humaid reported Anas (Allah be pleased with him) having said this:Allah's Apostle (ﷺ) called for young cupper belonging to us. He capped him and he (the Holy Prophet) commanded that he should be paid one sa' or one mudd or two mudds (of wheat). It was said (that charges were high) and a reduction was made in the charges}}
\hadithdefcmd{muslim}{4041}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمَخْزُومِيُّ، كِلاَهُمَا عَنْ وُهَيْبٍ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَأَعْطَى الْحَجَّامَ أَجْرَهُ وَاسْتَعَطَ ‏.‏\hadithno{4041}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that Allah's Messenger (ﷺ) got himself cupped and he paid the clipper his charges and he put medicine in his nostrils}}
\hadithdefcmd{muslim}{4042}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لِعَبْدٍ - قَالاَ أَخْبَرَنَا عَبْدُ، الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَجَمَ النَّبِيَّ صلى الله عليه وسلم عَبْدٌ لِبَنِي بَيَاضَةَ فَأَعْطَاهُ النَّبِيُّ صلى الله عليه وسلم أَجْرَهُ وَكَلَّمَ سَيِّدَهُ فَخَفَّفَ عَنْهُ مِنْ ضَرِيبَتِهِ وَلَوْ كَانَ سُحْتًا لَمْ يُعْطِهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4042}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported:The slave of Banu Bayada cupped Allah's Apostle (ﷺ) and he gave him his wages, and talked to his master and he reduced the charges, and if this earning was unlawful Allah's Apostle (ﷺ) would not have given it}}
\hadithdefcmd{muslim}{4043}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى أَبُو هَمَّامٍ، حَدَّثَنَا سَعِيدٌ الْجُرَيْرِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ بِالْمَدِينَةِ قَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّ اللَّهَ تَعَالَى يُعَرِّضُ بِالْخَمْرِ وَلَعَلَّ اللَّهَ سَيُنْزِلُ فِيهَا أَمْرًا فَمَنْ كَانَ عِنْدَهُ مِنْهَا شَىْءٌ فَلْيَبِعْهُ وَلْيَنْتَفِعْ بِهِ ‏"‏ ‏.‏ قَالَ فَمَا لَبِثْنَا إِلاَّ يَسِيرًا حَتَّى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ تَعَالَى حَرَّمَ الْخَمْرَ فَمَنْ أَدْرَكَتْهُ هَذِهِ الآيَةُ وَعِنْدَهُ مِنْهَا شَىْءٌ فَلاَ يَشْرَبْ وَلاَ يَبِعْ ‏"‏ ‏.‏ قَالَ فَاسْتَقْبَلَ النَّاسُ بِمَا كَانَ عِنْدَهُ مِنْهَا فِي طَرِيقِ الْمَدِينَةِ فَسَفَكُوهَا ‏.‏\hadithno{4043}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported:I heard Allah's Messenger (ﷺ) addressing in Medina. He said: O people, Allah is giving an indication (of the prohibition) of wine. and He is probably soon going to give an order about it. So he who has anything of it with him should sell that, and derive benefit out of it. He (the narrator) said: We waited for some time that Allah's Apostle (ﷺ) said: Verily Allah, the Exalted, has forbidden wine. So who hears this verse and he has anything of it with him, he should neither drink it nor sell it. He (the narrator) said: The people then brought whatever they had of it with them on the streets of Medina and spilt that}}
\hadithdefcmd{muslim}{4044}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ وَعْلَةَ - رَجُلٌ مِنْ أَهْلِ مِصْرَ - أَنَّهُ جَاءَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ح . وَحَدَّثَنَا أَبُو الطَّاهِرِ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، وَغَيْرُهُ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ وَعْلَةَ السَّبَإِيِّ، - مِنْ أَهْلِ مِصْرَ - أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ عَمَّا يُعْصَرُ مِنْ الْعِنَبِ فَقَالَ ابْنُ عَبَّاسٍ إِنَّ رَجُلًا أَهْدَى لِرَسُولِ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ رَاوِيَةَ خَمْرٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ هَلْ عَلِمْتَ أَنَّ اللَّهَ قَدْ حَرَّمَهَا قَالَ لَا فَسَارَّ إِنْسَانًا فَقَالَ لَهُ رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ بِمَ سَارَرْتَهُ فَقَالَ أَمَرْتُهُ بِبَيْعِهَا فَقَالَ إِنَّ الَّذِي حَرَّمَ شُرْبَهَا حَرَّمَ بَيْعَهَا قَالَ فَفَتَحَ الْمَزَادَةَ حَتَّى ذَهَبَ مَا فِيهَا\hadithno{4044}\hadithtrans{Abd al-Rahman b. Wa'ala as-Saba'i (who was an Egyptian) asked 'Abdullah b. Abbas; (Allah be pleased with them) about that which is extracted from the grapes, whereupon he said:A person presented to Allah's Messenger (ﷺ) a small water-skin of wine. Allah's Messenger (ﷺ) said to him: Do you know that Allah has forbidden it? He said: No. He then whispered to another man. Allah's Messenger (ﷺ) asked him what he had whispered. He said: I advised him to sell that, whereupon he (the Holy Prophet) said: Verily He Who has forbidden its drinking has forbidden its sale also. He (the narrator) said: He opened the waterskin until what was contained in it was spilt}}
\hadithdefcmd{muslim}{4045}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ، سَعِيدٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ وَعْلَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{4045}\hadithtrans{Abd al-Rahman b. Wa'ala narrated this on the authority of 'Abdullah b. Abbas}}
\hadithdefcmd{muslim}{4046}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ زُهَيْرٌ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَتِ الآيَاتُ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاقْتَرَأَهُنَّ عَلَى النَّاسِ ثُمَّ نَهَى عَنِ التِّجَارَةِ فِي الْخَمْرِ ‏.‏\hadithno{4046}\hadithtrans{A'isha (Allah be pleased with her) reported:When the concluding verses of Sura Baqara were revealed, Allah's Messenger (ﷺ) went out and read them out to the people and then forbade them to trade in wine}}
\hadithdefcmd{muslim}{4047}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا أُنْزِلَتِ الآيَاتُ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي الرِّبَا - قَالَتْ - خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمَسْجِدِ فَحَرَّمَ التِّجَارَةَ فِي الْخَمْرِ ‏.‏\hadithno{4047}\hadithtrans{A'isha (Allah be pleased with her) reported:When the concluding verses of Sura Baqara pertaining to Riba were revealed, Allah's Messenger (ﷺ) went out to the mosque and he forbade the trade in wine}}
\hadithdefcmd{muslim}{4048}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي، رَبَاحٍ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَامَ الْفَتْحِ وَهُوَ بِمَكَّةَ ‏"‏ إِنَّ اللَّهَ وَرَسُولَهُ حَرَّمَ بَيْعَ الْخَمْرِ وَالْمَيْتَةِ وَالْخِنْزِيرِ وَالأَصْنَامِ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ شُحُومَ الْمَيْتَةِ فَإِنَّهُ يُطْلَى بِهَا السُّفُنُ وَيُدْهَنُ بِهَا الْجُلُودُ وَيَسْتَصْبِحُ بِهَا النَّاسُ فَقَالَ ‏"‏ لاَ هُوَ حَرَامٌ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ قَاتَلَ اللَّهُ الْيَهُودَ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَمَّا حَرَّمَ عَلَيْهِمْ شُحُومَهَا أَجْمَلُوهُ ثُمَّ بَاعُوهُ فَأَكَلُوا ثَمَنَهُ ‏"‏‏.‏\hadithno{4048}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying in the Year of Victory while he was in Mecca:Verily Allah and His Messenger have forbidden the sale of wine, carcass, swine and idols, It was said: Allah's Messenger, you see that the fat of the carcass is used for coating the boats and varnishing the hides and people use it for lighting purposes, whereupon he said: No, it is forbidden, Then Allah's Messenger (ﷺ) said: May Allah the Exalted and Majestic destroy the Jews; when Allah forbade the use of fat of the carcass for them, they melted it, and then sold it and made use of its price (received from it)}}
\hadithdefcmd{muslim}{4049}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الْحَمِيدِ، بْنِ جَعْفَرٍ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا الضَّحَّاكُ - يَعْنِي أَبَا عَاصِمٍ - عَنْ عَبْدِ الْحَمِيدِ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ قَالَ كَتَبَ إِلَىَّ عَطَاءٌ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ بِمِثْلِ حَدِيثِ اللَّيْثِ ‏.‏\hadithno{4049}\hadithtrans{Yazid b. Abu Habib reported:'Ata' reported to me that he heard Jabir (b. 'Abdullah) saying it that he had heard that from Allah's Messenger (ﷺ) in the Year of Victory}}
\hadithdefcmd{muslim}{4050}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَلَغَ عُمَرَ أَنَّ سَمُرَةَ، بَاعَ خَمْرًا فَقَالَ قَاتَلَ اللَّهُ سَمُرَةَ أَلَمْ يَعْلَمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْيَهُودَ حُرِّمَتْ عَلَيْهِمُ الشُّحُومُ فَجَمَلُوهَا فَبَاعُوهَا ‏"‏ ‏.‏\hadithno{4050}\hadithtrans{Ibn Abbas (Allah be pleased with him) reported:This news reached 'Umar that Samura had sold wine, whereupon he said: May Allah destroy Samura; does he not know that Allah's Messenger (ﷺ) said:" Let there be the curse of Allah upon the Jews that fat was declared forbidden for them, but they melted it and then sold it"?}}
\hadithdefcmd{muslim}{4051}{حَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحٌ، - يَعْنِي ابْنَ الْقَاسِمِ - عَنْ عَمْرِو بْنِ دِينَارٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{4051}\hadithtrans{This hadith has been narrated on the authority of 'Amr b. Dinar with the same chain of transmitters}}
\hadithdefcmd{muslim}{4052}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ حَرَّمَ اللَّهُ عَلَيْهِمُ الشُّحُومَ فَبَاعُوهَا وَأَكَلُوا أَثْمَانَهَا‏"‏ ‏.‏\hadithno{4052}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:May Allah destroy the Jews for Allah forbade the use of fats for them, but they sold them and made use of their price}}
\hadithdefcmd{muslim}{4053}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ حُرِّمَ عَلَيْهِمُ الشَّحْمُ فَبَاعُوهُ وَأَكَلُوا ثَمَنَهُ ‏"‏ ‏.‏\hadithno{4053}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:May Allah destroy the Jews for Allah forbade the use of fat for them, but they sold it and made use of its price}}
\hadithdefcmd{muslim}{4054}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ إِلاَّ مِثْلاً بِمِثْلٍ وَلاَ تُشِفُّوا بَعْضَهَا عَلَى بَعْضٍ وَلاَ تَبِيعُوا الْوَرِقَ بِالْوَرِقِ إِلاَّ مِثْلاً بِمِثْلٍ وَلاَ تُشِفُّوا بَعْضَهَا عَلَى بَعْضٍ وَلاَ تَبِيعُوا مِنْهَا غَائِبًا بِنَاجِزٍ ‏"‏ ‏.‏\hadithno{4054}\hadithtrans{Abu Salid al-Khudri reported Allah's Messenger (ﷺ) as saying:Do not sell gold for gold, except like for like, and don't increase something of it upon something; and don't sell silver unless like for like, and don't increase some thing of it upon something, and do not sell for ready money something to be given later}}
\hadithdefcmd{muslim}{4055}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، قَالَ لَهُ رَجُلٌ مِنْ بَنِي لَيْثٍ إِنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ يَأْثُرُ هَذَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رِوَايَةِ قُتَيْبَةَ فَذَهَبَ عَبْدُ اللَّهِ وَنَافِعٌ مَعَهُ ‏.‏ وَفِي حَدِيثِ ابْنِ رُمْحٍ قَالَ نَافِعٌ فَذَهَبَ عَبْدُ اللَّهِ وَأَنَا مَعَهُ وَاللَّيْثِيُّ حَتَّى دَخَلَ عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ فَقَالَ إِنَّ هَذَا أَخْبَرَنِي أَنَّكَ تُخْبِرُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْوَرِقِ بِالْوَرِقِ إِلاَّ مِثْلاً بِمِثْلٍ وَعَنْ بَيْعِ الذَّهَبِ بِالذَّهَبِ إِلاَّ مِثْلاً بِمِثْلٍ ‏.‏ فَأَشَارَ أَبُو سَعِيدٍ بِإِصْبَعَيْهِ إِلَى عَيْنَيْهِ وَأُذُنَيْهِ فَقَالَ أَبْصَرَتْ عَيْنَاىَ وَسَمِعَتْ أُذُنَاىَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ وَلاَ تَبِيعُوا الْوَرِقَ بِالْوَرِقِ إِلاَّ مِثْلاً بِمِثْلٍ وَلاَ تُشِفُّوا بَعْضَهُ عَلَى بَعْضٍ وَلاَ تَبِيعُوا شَيْئًا غَائِبًا مِنْهُ بِنَاجِزٍ إِلاَّ يَدًا بِيَدٍ ‏"‏ ‏.‏\hadithno{4055}\hadithtrans{Nafi' reported that Ibn 'Umar told him that a person of the tribe of Laith said that Abu Sa'id al-Kludri narrated it (the above-mentioned hadith) from tile Messenger of Allah (ﷺ) in a narration of Qutaiba. So 'Abduliali and Nafi' went along with him, and in the hadith transmitted by Ibn Rumh (the words are) that Nafi' said:'Abdullah (b. 'Umar) went and I along with the person belonging to Banu Laith entered (the house) of Sa'id al-Khudri, and he ('Abdullah b. Umar) said: I have been informed that you say that Allah's Messenger (ﷺ) forbade the sale of silver with silver except in case of like for like, and sale of gold for gold except in case of like for like. Abu Sa'id pointed towards this eyes and his ears with his fingers and said: My eyes saw, and my ears listened to Allah's Messenger (ﷺ) saying: Do not sell gold for gold, and do not sell silver for silver except in case of like for like, and do not increase something of it upon something, and do not sell for ready money something, not present, but hand to hand}}
\hadithdefcmd{muslim}{4056}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرٌ يَعْنِي ابْنَ حَازِمٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ، أَبِي عَدِيٍّ عَنِ ابْنِ عَوْنٍ، كُلُّهُمْ عَنْ نَافِعٍ، ‏.‏ بِنَحْوِ حَدِيثِ اللَّيْثِ عَنْ نَافِعٍ، عَنْ أَبِي سَعِيدٍ، الْخُدْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4056}\hadithtrans{This hadith has been narrated on the authority of Abu Sa'id al-Khudri through another chain of transmitters}}
\hadithdefcmd{muslim}{4057}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ وَلاَ الْوَرِقَ بِالْوَرِقِ إِلاَّ وَزْنًا بِوَزْنٍ مِثْلاً بِمِثْلٍ سَوَاءً بِسَوَاءٍ ‏"‏ ‏.‏\hadithno{4057}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Do not sell gold for gold and silver for silver weight for weight or of the same quality}}
\hadithdefcmd{muslim}{4058}{حَدَّثَنَا أَبُو الطَّاهِرِ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالُوا حَدَّثَنَا ابْنُ، وَهْبٍ أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، يَقُولُ إِنَّهُ سَمِعَ مَالِكَ بْنَ، أَبِي عَامِرٍ يُحَدِّثُ عَنْ عُثْمَانَ بْنِ عَفَّانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبِيعُوا الدِّينَارَ بِالدِّينَارَيْنِ وَلاَ الدِّرْهَمَ بِالدِّرْهَمَيْنِ ‏"‏ ‏.‏\hadithno{4058}\hadithtrans{Uthman b. 'Affan reported Allah's Messenger (ﷺ) as saying:Do not sell a dinar for two dinars and one dirham for two dirhams}}
\hadithdefcmd{muslim}{4059}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، أَنَّهُ قَالَ أَقْبَلْتُ أَقُولُ مَنْ يَصْطَرِفُ الدَّرَاهِمَ فَقَالَ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ وَهُوَ عِنْدَ عُمَرَ بْنِ الْخَطَّابِ أَرِنَا ذَهَبَكَ ثُمَّ ائْتِنَا إِذَا جَاءَ خَادِمُنَا نُعْطِكَ وَرِقَكَ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ كَلاَّ وَاللَّهِ لَتُعْطِيَنَّهُ وَرِقَهُ أَوْ لَتَرُدَّنَّ إِلَيْهِ ذَهَبَهُ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْوَرِقُ بِالذَّهَبِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالْبُرُّ بِالْبُرِّ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالشَّعِيرُ بِالشَّعِيرِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالتَّمْرُ بِالتَّمْرِ رِبًا إِلاَّ هَاءَ وَهَاءَ‏"‏ ‏.‏\hadithno{4059}\hadithtrans{Malik b. Aus b. al-Hadathan reported:I came saying who was prepared toexchange dirhams (for my gold), whereupon Talha b. Ubaidullah (Allah be pleased with him) (as he was sitting with 'Umar b. Khattib) said: Show us your gold and then come to us (at a later time). When our servant would come we would give you your silver (dirhams due to you). Thereupon 'Umar b. al-Khattib (Allah be pleased with him) said: Not at all. By Allah, either give him his silver (coins). or return his gold to him, for Allah's Messenger (ﷺ) said: Exchange of silver for gold (has an element of) interest in it. except when (it is exchanged) on the spot;and wheat for wheat is an interest unless both are handed over on the spot: barley for barley is interest unless both are handed over on the spot; dates for dates is interest unless both are handed over on the Spot}}
\hadithdefcmd{muslim}{4060}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ، عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4060}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{4061}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، قَالَ كُنْتُ بِالشَّامِ فِي حَلْقَةٍ فِيهَا مُسْلِمُ بْنُ يَسَارٍ فَجَاءَ أَبُو الأَشْعَثِ قَالَ قَالُوا أَبُو الأَشْعَثِ أَبُو الأَشْعَثِ ‏.‏ فَجَلَسَ فَقُلْتُ لَهُ حَدِّثْ أَخَانَا حَدِيثَ عُبَادَةَ بْنِ الصَّامِتِ ‏.‏ قَالَ نَعَمْ غَزَوْنَا غَزَاةً وَعَلَى النَّاسِ مُعَاوِيَةُ فَغَنِمْنَا غَنَائِمَ كَثِيرَةً فَكَانَ فِيمَا غَنِمْنَا آنِيَةٌ مِنْ فِضَّةٍ فَأَمَرَ مُعَاوِيَةُ رَجُلاً أَنْ يَبِيعَهَا فِي أَعْطِيَاتِ النَّاسِ فَتَسَارَعَ النَّاسُ فِي ذَلِكَ فَبَلَغَ عُبَادَةَ بْنَ الصَّامِتِ فَقَامَ فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ بَيْعِ الذَّهَبِ بِالذَّهَبِ وَالْفِضَّةِ بِالْفِضَّةِ وَالْبُرِّ بِالْبُرِّ وَالشَّعِيرِ بِالشَّعِيرِ وَالتَّمْرِ بِالتَّمْرِ وَالْمِلْحِ بِالْمِلْحِ إِلاَّ سَوَاءً بِسَوَاءٍ عَيْنًا بِعَيْنٍ فَمَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى ‏.‏ فَرَدَّ النَّاسُ مَا أَخَذُوا فَبَلَغَ ذَلِكَ مُعَاوِيَةَ فَقَامَ خَطِيبًا فَقَالَ أَلاَ مَا بَالُ رِجَالٍ يَتَحَدَّثُونَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَادِيثَ قَدْ كُنَّا نَشْهَدُهُ وَنَصْحَبُهُ فَلَمْ نَسْمَعْهَا مِنْهُ ‏.‏ فَقَامَ عُبَادَةُ بْنُ الصَّامِتِ فَأَعَادَ الْقِصَّةَ ثُمَّ قَالَ لَنُحَدِّثَنَّ بِمَا سَمِعْنَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِنْ كَرِهَ مُعَاوِيَةُ - أَوْ قَالَ وَإِنْ رَغِمَ - مَا أُبَالِي أَنْ لاَ أَصْحَبَهُ فِي جُنْدِهِ لَيْلَةً سَوْدَاءَ ‏.‏ قَالَ حَمَّادٌ هَذَا أَوْ نَحْوَهُ‏.‏\hadithno{4061}\hadithtrans{Abi Qilabah reported:I was in Syria (having) a circle (of friends). in which was Muslim b. Yasir. There came Abu'l-Ash'ath. He (the narrator) said that they (the friends) called him: Abu'l-Ash'ath, Abu'l-Ash'ath, and he sat down. I said to him: Narrate to our brother the hadith of Ubada b. Samit. He said: Yes. We went out on an expedition, Mu'awiya being the leader of the people, and we gained a lot of spoils of war. And there was one silver utensil in what we took as spoils. Mu'awiya ordered a person to sell it for payment to the people (soldiers). The people made haste in getting that. The news of (this state of affairs) reached 'Ubada b. Samit, and he stood up and said: I heard Allah's Messenger (ﷺ) forbidding the sale of gold by gold, and silver by silver, and wheat by wheat, and barley by barley, and dates by dates, and salt by salt, except like for like and equal for equal. So he who made an addition or who accepted an addition (committed the sin of taking) interest. So the people returned what they had got. This reached Mu'awiya. and he stood up to deliver an address. He said: What is the matter with people that they narrate from the Messenger (ﷺ) such tradition which we did not hear though we saw him (the Holy Prophet) and lived in his company? Thereupon, Ubida b. Samit stood up and repeated that narration, and then said: We will definitely narrate what we heard from Allah's Messenger (ﷺ) though it may be unpleasant to Mu'awiya (or he said: Even if it is against his will). I do not mind if I do not remain in his troop in the dark night. Hammad said this or something like this}}
\hadithdefcmd{muslim}{4062}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنْ عَبْدِ الْوَهَّابِ الثَّقَفِيِّ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4062}\hadithtrans{The above hadith is likewise narrated through another chain of transmission on the authority of Abi Qilabah}}
\hadithdefcmd{muslim}{4063}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ خَالِدٍ، الْحَذَّاءِ عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالذَّهَبِ وَالْفِضَّةُ بِالْفِضَّةِ وَالْبُرُّ بِالْبُرِّ وَالشَّعِيرُ بِالشَّعِيرِ وَالتَّمْرُ بِالتَّمْرِ وَالْمِلْحُ بِالْمِلْحِ مِثْلاً بِمِثْلٍ سَوَاءً بِسَوَاءٍ يَدًا بِيَدٍ فَإِذَا اخْتَلَفَتْ هَذِهِ الأَصْنَافُ فَبِيعُوا كَيْفَ شِئْتُمْ إِذَا كَانَ يَدًا بِيَدٍ ‏"‏ ‏.‏\hadithno{4063}\hadithtrans{Ubida b. al-Simit (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Gold is to be paid for by gold, silver by silver, wheat by wheat, barley by barley, dates by dates, and salt by salt, like for like and equal for equal, payment being made hand to hand. If these classes differ, then sell as you wish if payment is made hand to hand}}
\hadithdefcmd{muslim}{4064}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ الْعَبْدِيُّ، حَدَّثَنَا أَبُو الْمُتَوَكِّلِ النَّاجِيُّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالذَّهَبِ وَالْفِضَّةُ بِالْفِضَّةِ وَالْبُرُّ بِالْبُرِّ وَالشَّعِيرُ بِالشَّعِيرِ وَالتَّمْرُ بِالتَّمْرِ وَالْمِلْحُ بِالْمِلْحِ مِثْلاً بِمِثْلٍ يَدًا بِيَدٍ فَمَنْ زَادَ أَوِ اسْتَزَادَ فَقَدْ أَرْبَى الآخِذُ وَالْمُعْطِي فِيهِ سَوَاءٌ ‏"‏ ‏.‏\hadithno{4064}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Gold is to be paid for by gold, silver by silver, wheat by wheat, barley by barley, dates by dates, salt by salt, like by like, payment being made hand to hand. He who made an addition to it, or asked for an addition, in fact dealt in usury. The receiver and the giver are equally guilty}}
\hadithdefcmd{muslim}{4065}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا سُلَيْمَانُ الرَّبَعِيُّ، حَدَّثَنَا أَبُو الْمُتَوَكِّلِ النَّاجِيُّ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالذَّهَبِ مِثْلاً بِمِثْلٍ ‏"‏ ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{4065}\hadithtrans{This hadith has been narrated on the authority of Abu Sa'id al-Khudri (Allah be pleased with him) through another chain of transmitters}}
\hadithdefcmd{muslim}{4066}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَوَاصِلُ بْنُ عَبْدِ الأَعْلَى قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ التَّمْرُ بِالتَّمْرِ وَالْحِنْطَةُ بِالْحِنْطَةِ وَالشَّعِيرُ بِالشَّعِيرِ وَالْمِلْحُ بِالْمِلْحِ مِثْلاً بِمِثْلٍ يَدًا بِيَدٍ فَمَنْ زَادَ أَوِ اسْتَزَادَ فَقَدْ أَرْبَى إِلاَّ مَا اخْتَلَفَتْ أَلْوَانُهُ ‏"‏ ‏.‏\hadithno{4066}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Dates are to be paid for by dates, wheat by wheat, barley by barley, salt by salt, like for like, payment being made on the spot. He who made an addition or demanded an addition, in fact, dealt in usury except in case where their classes differ}}
\hadithdefcmd{muslim}{4067}{وَحَدَّثَنِيهِ أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ فُضَيْلِ بْنِ غَزْوَانَ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَذْكُرْ ‏ "‏ يَدًا بِيَدٍ ‏"‏ ‏.‏\hadithno{4067}\hadithtrans{This hadith has been narrated on the authority of Fudail b. Ghazwan with the same chain of transmitters, but he made no mention of (payment being) made on the spot}}
\hadithdefcmd{muslim}{4068}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَوَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالذَّهَبِ وَزْنًا بِوَزْنٍ مِثْلاً بِمِثْلٍ وَالْفِضَّةُ بِالْفِضَّةِ وَزْنًا بِوَزْنٍ مِثْلاً بِمِثْلٍ فَمَنْ زَادَ أَوِ اسْتَزَادَ فَهُوَ رِبًا‏"‏ ‏.‏\hadithno{4068}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Mess-., nger (ﷺ) as saying:Gold is to be paid for by gold with equal weight, like for like, and silver is to be paid for by silver with equal weight, like for like. He who made an addition to it or demanded an addition dealt in usury}}
\hadithdefcmd{muslim}{4069}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ مُوسَى، بْنِ أَبِي تَمِيمٍ عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الدِّينَارُ بِالدِّينَارِ لاَ فَضْلَ بَيْنَهُمَا وَالدِّرْهَمُ بِالدِّرْهَمِ لاَ فَضْلَ بَيْنَهُمَا ‏"‏ ‏.‏\hadithno{4069}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Let dinar be exchanged for dinar, with no addition on either side and dirham be exchanged for dirham with no addition on either side}}
\hadithdefcmd{muslim}{4070}{حَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ سَمِعْتُ مَالِكَ بْنَ أَنَسٍ، يَقُولُ حَدَّثَنِي مُوسَى بْنُ أَبِي تَمِيمٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4070}\hadithtrans{This hadith has been narrated on the authority of Musa b. Abu Tamim with the same chain of transmitters}}
\hadithdefcmd{muslim}{4071}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ أَبِي، الْمِنْهَالِ قَالَ بَاعَ شَرِيكٌ لِي وَرِقًا بِنَسِيئَةٍ إِلَى الْمَوْسِمِ أَوْ إِلَى الْحَجِّ فَجَاءَ إِلَىَّ فَأَخْبَرَنِي فَقُلْتُ هَذَا أَمْرٌ لاَ يَصْلُحُ ‏.‏ قَالَ قَدْ بِعْتُهُ فِي السُّوقِ فَلَمْ يُنْكِرْ ذَلِكَ عَلَىَّ أَحَدٌ ‏.‏ فَأَتَيْتُ الْبَرَاءَ بْنَ عَازِبٍ فَسَأَلْتُهُ فَقَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَنَحْنُ نَبِيعُ هَذَا الْبَيْعَ فَقَالَ ‏ "‏ مَا كَانَ يَدًا بِيَدٍ فَلاَ بَأْسَ بِهِ وَمَا كَانَ نَسِيئَةً فَهُوَ رِبًا ‏"‏ ‏.‏ وَائْتِ زَيْدَ بْنَ أَرْقَمَ فَإِنَّهُ أَعْظَمُ تِجَارَةً مِنِّي ‏.‏ فَأَتَيْتُهُ فَسَأَلْتُهُ فَقَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{4071}\hadithtrans{Abu Minhal reported:My partner sold silver to be paid in the (Hajj) season or (in the days of) Hajj. He (my partner) came to me and informed me, and I said to him: Such transaction is not desirable. He said: I sold it in the market (on loan) but nobody objected to this. I went to al-Bara' b. 'Azib and asked him, and he said: Allah's Apostle (ﷺ) came to Medina and we made such transaction, whereupon he said: In case the payment is made on the spot, there is no harm in it, and in case (it is 'sold) on loan, it is usury. You better go to Zaid b. Arqam, for he is a greater trader than I; so I went to him and asked him, and he said like it}}
\hadithdefcmd{muslim}{4072}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبٍ، أَنَّهُ سَمِعَ أَبَا الْمِنْهَالِ، يَقُولُ سَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ عَنِ الصَّرْفِ، فَقَالَ سَلْ زَيْدَ بْنَ أَرْقَمَ فَهُوَ أَعْلَمُ ‏.‏ فَسَأَلْتُ زَيْدًا فَقَالَ سَلِ الْبَرَاءَ فَإِنَّهُ أَعْلَمُ ثُمَّ قَالاَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْوَرِقِ بِالذَّهَبِ دَيْنًا\hadithno{4072}\hadithtrans{Habib reported that he heard Abu Minhal as saying:I asked al-Bara' b. Azib about the exchange of (gold for silver or vice versa), whereupon he said: you better ask Zaid b. Arqam for he knows more than I. So I asked Zaid but he said: You better ask al-Bara' for he knows more than I. Then both of them said: Allah's Messenger (ﷺ) forbade the sale of silver for gold when payment is to be made in future}}
\hadithdefcmd{muslim}{4073}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، أَخْبَرَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْفِضَّةِ بِالْفِضَّةِ وَالذَّهَبِ بِالذَّهَبِ إِلاَّ سَوَاءً بِسَوَاءٍ وَأَمَرَنَا أَنْ نَشْتَرِيَ الْفِضَّةَ بِالذَّهَبِ كَيْفَ شِئْنَا وَنَشْتَرِيَ الذَّهَبَ بِالْفِضَّةِ كَيْفَ شِئْنَا ‏.‏ قَالَ فَسَأَلَهُ رَجُلٌ فَقَالَ يَدًا بِيَدٍ فَقَالَ هَكَذَا سَمِعْتُ ‏.‏\hadithno{4073}\hadithtrans{Abd al-Rabman b. Abia Bakra reported on the authority of his father that Allah's Messenger (ﷺ) forbade the sale of gold for gold, and silver for silver except equal for equal, and commanded us to buy silver for gold as we desired and buy gold for silver as we desired. A person asked him (about the nature of payment), whereupon he said:It is to be made on the spot. This is what I heard (from Allah's Messenger (may peace be upon him)}}
\hadithdefcmd{muslim}{4074}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا مُعَاوِيَةُ، عَنْ يَحْيَى، - وَهُوَ ابْنُ أَبِي كَثِيرٍ - عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرَةَ، أَخْبَرَهُ أَنَّ أَبَا بَكْرَةَ قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4074}\hadithtrans{Abd al-Rabman b. Abu Bakra said:Allah's Messenger (ﷺ) prohibited us. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4075}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ أَنَّهُ سَمِعَ عُلَىَّ بْنَ رَبَاحٍ اللَّخْمِيَّ، يَقُولُ سَمِعْتُ فَضَالَةَ بْنَ عُبَيْدٍ الأَنْصَارِيَّ، يَقُولُ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ بِخَيْبَرَ بِقِلاَدَةٍ فِيهَا خَرَزٌ وَذَهَبٌ وَهِيَ مِنَ الْمَغَانِمِ تُبَاعُ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالذَّهَبِ الَّذِي فِي الْقِلاَدَةِ فَنُزِعَ وَحْدَهُ ثُمَّ قَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالذَّهَبِ وَزْنًا بِوَزْنٍ ‏"‏ ‏.‏\hadithno{4075}\hadithtrans{Fadala b. Ubaid al-Ansari reported:A necklace having gold and gems in it was brought to Allah's Messenger (ﷺ) in Khaibar and it was one of the spoils of war and was put to sale. Allah's Messenger (ﷺ) said: The gold used in it should be separated, and then Allah's Messenger (ﷺ) further said: (Sell) gold for gold with equal weight}}
\hadithdefcmd{muslim}{4076}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ أَبِي شُجَاعٍ، سَعِيدِ بْنِ يَزِيدَ عَنْ خَالِدِ بْنِ، أَبِي عِمْرَانَ عَنْ حَنَشٍ الصَّنْعَانِيِّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ اشْتَرَيْتُ يَوْمَ خَيْبَرَ قِلاَدَةً بِاثْنَىْ عَشَرَ دِينَارًا فِيهَا ذَهَبٌ وَخَرَزٌ فَفَصَّلْتُهَا فَوَجَدْتُ فِيهَا أَكْثَرَ مِنِ اثْنَىْ عَشَرَ دِينَارًا فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تُبَاعُ حَتَّى تُفَصَّلَ ‏"‏ ‏.‏\hadithno{4076}\hadithtrans{Fadila b. 'Ubaid (Allah be pleased with him) reported:I bought on the day (of the Victory of Khaibar) a necklace for twelve dinars (gold coins). It was made of gold studded with gems. I separated (gold from gems) in it, and found (gold) of more (worth) than twelve dinars. I made a mention of it to Allah's Apostle (ﷺ), whereupon he said: It should not be sold unless it is separated}}
\hadithdefcmd{muslim}{4077}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ مُبَارَكٍ، عَنْ سَعِيدِ بْنِ، يَزِيدَ بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4077}\hadithtrans{A hadith like this is narrated on the authority of Sa'id b. Yazid with the same chain of transmitters}}
\hadithdefcmd{muslim}{4078}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ أَبِي جَعْفَرٍ، عَنِ الْجُلاَحِ أَبِي كَثِيرٍ، حَدَّثَنِي حَنَشٌ الصَّنْعَانِيُّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ نُبَايِعُ الْيَهُودَ الْوُقِيَّةَ الذَّهَبَ بِالدِّينَارَيْنِ وَالثَّلاَثَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ إِلاَّ وَزْنًا بِوَزْنٍ ‏"‏ ‏.‏\hadithno{4078}\hadithtrans{Fadala b. 'Ubaid reported:We were in the company of Allah's Messenger ( may peace be upon him) on the day (of the Victory of) Khaibar, and made transaction with the Jews for the 'uqiya of gold for the dinars or three (gold coins), whereupon Allah's Messenger (ﷺ) said: Do not sell gold for gold but for equal weight}}
\hadithdefcmd{muslim}{4079}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ قُرَّةَ بْنِ عَبْدِ الرَّحْمَنِ الْمَعَافِرِيِّ، وَعَمْرِو، بْنِ الْحَارِثِ وَغَيْرِهِمَا أَنَّ عَامِرَ بْنَ يَحْيَى الْمَعَافِرِيَّ، أَخْبَرَهُمْ عَنْ حَنَشٍ، أَنَّهُ قَالَ كُنَّا مَعَ فَضَالَةَ بْنِ عُبَيْدٍ فِي غَزْوَةٍ فَطَارَتْ لِي وَلأَصْحَابِي قِلاَدَةٌ فِيهَا ذَهَبٌ وَوَرِقٌ وَجَوْهَرٌ فَأَرَدْتُ أَنْ أَشْتَرِيَهَا فَسَأَلْتُ فَضَالَةَ بْنَ عُبَيْدٍ فَقَالَ انْزِعْ ذَهَبَهَا فَاجْعَلْهُ فِي كِفَّةٍ وَاجْعَلْ ذَهَبَكَ فِي كِفَّةٍ ثُمَّ لاَ تَأْخُذَنَّ إِلاَّ مِثْلاً بِمِثْلٍ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يَأْخُذَنَّ إِلاَّ مِثْلاً بِمِثْلٍ ‏"‏ ‏.‏\hadithno{4079}\hadithtrans{Hanash reported:We were along with Fadala b. Ubaid (Allah be pleased with him) in an expedition. There fell to my and my friend's lot a necklace made of gold, silver and jewels. I decided to buy that. I asked Fadala b. 'Ubaid, whereupon he said: Separate its gold and place it in one pan (of the balance) and place your gold in the other pan, and do not receive but equal for equal, for I heard Allah's Messenger (ﷺ) as saying: He who believes in Allah and the Hereafter should not take but equal for equal}}
\hadithdefcmd{muslim}{4080}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ أَبَا النَّضْرِ، حَدَّثَهُ أَنَّ بُسْرَ بْنَ سَعِيدٍ حَدَّثَهُ عَنْ مَعْمَرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ أَرْسَلَ غُلاَمَهُ بِصَاعِ قَمْحٍ فَقَالَ بِعْهُ ثُمَّ اشْتَرِ بِهِ شَعِيرًا ‏.‏ فَذَهَبَ الْغُلاَمُ فَأَخَذَ صَاعًا وَزِيَادَةَ بَعْضِ صَاعٍ فَلَمَّا جَاءَ مَعْمَرًا أَخْبَرَهُ بِذَلِكَ فَقَالَ لَهُ مَعْمَرٌ لِمَ فَعَلْتَ ذَلِكَ انْطَلِقْ فَرُدَّهُ وَلاَ تَأْخُذَنَّ إِلاَّ مِثْلاً بِمِثْلٍ فَإِنِّي كُنْتُ أَسْمَعُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الطَّعَامُ بِالطَّعَامِ مِثْلاً بِمِثْلٍ ‏"‏ ‏.‏ قَالَ وَكَانَ طَعَامُنَا يَوْمَئِذٍ الشَّعِيرَ ‏.‏ قِيلَ لَهُ فَإِنَّهُ لَيْسَ بِمِثْلِهِ قَالَ إِنِّي أَخَافُ أَنْ يُضَارِعَ ‏.‏\hadithno{4080}\hadithtrans{Ma'mar b. Abdullah reported that he sent his slave with a sa' of wheat and said to him:Sell it, and then buy with it barley. The slave went away and he got a sa' (of barley) and a part of sa' over and above that. When he came to Ma'mar he informed him about that, whereupon Ma'mar said to him: Why did you do that? Go back and return that, and do not accept but weight, for weight, for I used to hear from Allah's Apostle (ﷺ) as saying: Wheat for wheat and like for like. He (one of the narrators) said: Our food in those days consisted of barley. It was said to him (Ma'mar) that (wheat) is not like that (barley). He replied: I am afraid these may not be similar}}
\hadithdefcmd{muslim}{4081}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يُحَدِّثُ أَنَّ أَبَا هُرَيْرَةَ، وَأَبَا سَعِيدٍ حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَخَا بَنِي عَدِيٍّ الأَنْصَارِيَّ فَاسْتَعْمَلَهُ عَلَى خَيْبَرَ فَقَدِمَ بِتَمْرٍ جَنِيبٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏ ‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنَّا لَنَشْتَرِي الصَّاعَ بِالصَّاعَيْنِ مِنَ الْجَمْعِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَفْعَلُوا وَلَكِنْ مِثْلاً بِمِثْلٍ أَوْ بِيعُوا هَذَا وَاشْتَرُوا بِثَمَنِهِ مِنْ هَذَا وَكَذَلِكَ الْمِيزَانُ ‏"‏ ‏.‏\hadithno{4081}\hadithtrans{Abu Huraira and Abu Sa'id al-Khudri (Allah be pleased with them) reported that Allah's Messenger (ﷺ) deputed a person from Banu 'Adi al-Ansari to collect revenue from Khaibar. He came with a fine quality of dates, whereupon Allah's Messenger (ﷺ) said to him:Are all the dates of Khaibar like this? He said: Allah's Messenger, it is not so. We buy one sa' of (fine quality of dates) for two sa's out of total output (including even the inferior quality of dates), whereupon Allah's Messenger (ﷺ) said: Don't do that, but like for like, or sell this (the inferior quality and receive the price) and then buy with the price of that, and that would make up the measure}}
\hadithdefcmd{muslim}{4082}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلِ بْنِ عَبْدِ، الرَّحْمَنِ بْنِ عَوْفٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَعَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً عَلَى خَيْبَرَ فَجَاءَهُ بِتَمْرٍ جَنِيبٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏ ‏.‏ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنَّا لَنَأْخُذُ الصَّاعَ مِنْ هَذَا بِالصَّاعَيْنِ وَالصَّاعَيْنِ بِالثَّلاَثَةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلاَ تَفْعَلْ بِعِ الْجَمْعَ بِالدَّرَاهِمِ ثُمَّ ابْتَعْ بِالدَّرَاهِمِ جَنِيبًا ‏"‏ ‏.‏\hadithno{4082}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) deputed a person to collect revenue from Khaibar. He brought fine quality of dates, whereupon Allah's Messenger (ﷺ) said:Are all the dates of Khaibar like this)? He said: No. We got one sa' (of fine dates) for two sa's (of inferior dates), and (similarly) two sa's for three sa's. Thereupon Allah's Messenger (ﷺ) said: Don't do that rather sell the inferior quality of dates for dirhams (money), and then buy the superior quality with the help of dirhams}}
\hadithdefcmd{muslim}{4083}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَحْيَى بْنُ صَالِحٍ الْوُحَاظِيُّ، حَدَّثَنَا مُعَاوِيَةُ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، - وَاللَّفْظُ لَهُمَا - جَمِيعًا عَنْ يَحْيَى بْنِ حَسَّانَ، حَدَّثَنَا مُعَاوِيَةُ، - وَهُوَ ابْنُ سَلاَّمٍ - أَخْبَرَنِي يَحْيَى، - وَهُوَ ابْنُ أَبِي كَثِيرٍ - قَالَ سَمِعْتُ عُقْبَةَ بْنَ عَبْدِ الْغَافِرِ، يَقُولُ سَمِعْتُ أَبَا سَعِيدٍ، يَقُولُ جَاءَ بِلاَلٌ بِتَمْرٍ بَرْنِيٍّ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مِنْ أَيْنَ هَذَا ‏"‏ ‏.‏ فَقَالَ بِلاَلٌ تَمْرٌ كَانَ عِنْدَنَا رَدِيءٌ فَبِعْتُ مِنْهُ صَاعَيْنِ بِصَاعٍ لِمَطْعَمِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَقَالَ رَسُولُ اللَّهِ عِنْدَ ذَلِكَ ‏"‏ أَوَّهْ عَيْنُ الرِّبَا لاَ تَفْعَلْ وَلَكِنْ إِذَا أَرَدْتَ أَنْ تَشْتَرِيَ التَّمْرَ فَبِعْهُ بِبَيْعٍ آخَرَ ثُمَّ اشْتَرِ بِهِ ‏"‏ ‏.‏ لَمْ يَذْكُرِ ابْنُ سَهْلٍ فِي حَدِيثِهِ عِنْدَ ذَلِكَ ‏.‏\hadithno{4083}\hadithtrans{Abd Sa'id reported:Bilal (Allah be pleased with him) came with fine quality of dates. Allah's Messenger (ﷺ) said to him: From where (you have brought them)? Bilal said: We had inferior quality of dates and I exchanged two sa's (of inferior quality) with one sa (of fine quality) as food for Allah's Apostle (ﷺ), whereupon Allah's Messenger (ﷺ) said: Woe! it is in fact usury; therefore, don't do that. But when you intend to buy dates (of superior quality), sell (the inferior quality) in a separate bargain and then buy (the superior quality). And in the hadith transmitted by Ibn Sahl there is no mention of" whereupon}}
\hadithdefcmd{muslim}{4084}{وَحَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي قَزَعَةَ، الْبَاهِلِيِّ عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِتَمْرٍ فَقَالَ ‏"‏ مَا هَذَا التَّمْرُ مِنْ تَمْرِنَا ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ بِعْنَا تَمْرَنَا صَاعَيْنِ بِصَاعٍ مِنْ هَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا الرِّبَا فَرُدُّوهُ ثُمَّ بِيعُوا تَمْرَنَا وَاشْتَرُوا لَنَا مِنْ هَذَا ‏"‏ ‏.‏\hadithno{4084}\hadithtrans{Abu Sa'id (Allah be pleased with him) reported:Dates were brought to Allah's Messenger (ﷺ), and he said: These dates are not like our dates, whereupon a man said: We sold two sa's of our dates (in order to get) one sa', of these (fine dates), whereupon Allah's Messenger (ﷺ) said: That is interest; so return (these dates of fine quality), and get your (inferior dates) ; then sell our dates (for money) and buy for us (with the help of money) such (fine dates)}}
\hadithdefcmd{muslim}{4085}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ كُنَّا نُرْزَقُ تَمْرَ الْجَمْعِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ الْخِلْطُ مِنَ التَّمْرِ فَكُنَّا نَبِيعُ صَاعَيْنِ بِصَاعٍ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ صَاعَىْ تَمْرٍ بِصَاعٍ وَلاَ صَاعَىْ حِنْطَةٍ بِصَاعٍ وَلاَ دِرْهَمَ بِدِرْهَمَيْنِ ‏"‏ ‏.‏\hadithno{4085}\hadithtrans{Abu Sa'id (Allah be pleased with him) reported:We were given to eat, during the lifetime of Allah's Messenger (ﷺ), dates of different qualities mixed together, and we used to sell two sa's of these for one sa, (of fine quality of dates). This reached Allah's Messenger (ﷺ), whereupon he said: There should be no exchange of two sa's of (inferior) dates for one sa (of fine dates) and two sa's of (inferior) wheat for one sa' of (fine) wheat. and one dirham for two dirharms}}
\hadithdefcmd{muslim}{4086}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي، نَضْرَةَ قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ عَنِ الصَّرْفِ، فَقَالَ أَيَدًا بِيَدٍ قُلْتُ نَعَمْ ‏.‏ قَالَ فَلاَ بَأْسَ بِهِ ‏.‏ فَأَخْبَرْتُ أَبَا سَعِيدٍ فَقُلْتُ إِنِّي سَأَلْتُ ابْنَ عَبَّاسٍ عَنِ الصَّرْفِ فَقَالَ أَيَدًا بِيَدٍ قُلْتُ نَعَمْ ‏.‏ قَالَ فَلاَ بَأْسَ بِهِ ‏.‏ قَالَ أَوَقَالَ ذَلِكَ إِنَّا سَنَكْتُبُ إِلَيْهِ فَلاَ يُفْتِيكُمُوهُ قَالَ فَوَاللَّهِ لَقَدْ جَاءَ بَعْضُ فِتْيَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِتَمْرٍ فَأَنْكَرَهُ فَقَالَ ‏"‏ كَأَنَّ هَذَا لَيْسَ مِنْ تَمْرِ أَرْضِنَا ‏"‏ ‏.‏ قَالَ كَانَ فِي تَمْرِ أَرْضِنَا - أَوْ فِي تَمْرِنَا - الْعَامَ بَعْضُ الشَّىْءِ فَأَخَذْتُ هَذَا وَزِدْتُ بَعْضَ الزِّيَادَةِ ‏.‏ فَقَالَ ‏"‏ أَضْعَفْتَ أَرْبَيْتَ لاَ تَقْرَبَنَّ هَذَا إِذَا رَابَكَ مِنْ تَمْرِكَ شَىْءٌ فَبِعْهُ ثُمَّ اشْتَرِ الَّذِي تُرِيدُ مِنَ التَّمْرِ ‏"‏ ‏.‏\hadithno{4086}\hadithtrans{Abu Nadra reported:I asked Ibn Abbas (Allah be pleased with them) about the conversion (of gold and silver for silver and gold). We said: Is it hand to hand exchange? I said: Yes. whereupon he said: There is no harm in it. I informed Abu Sa'id about it, telling him that I had asked Ibn 'Abbas about it and he said: Is it hand to hand exchange? I said: Yes, whereupon he said: There is no harm in it. He (the narrator) said, or he said like it: We will soon write to him, and he will not give you this fatwa (religious verdict). He said: By Allah, someone of the boy-servants of Allah's Messenger (ﷺ) brought dates, but he refused to accept them (on the plea) that those did not seem to be of the dates of our land. He said: Something had happened to the dates of our land, or our dates. So I got these dates (in exchange by giving) excess (of the dates of our land), whereupon he said: You made an addition for getting the fine dates (in exchange) which tantamounts, to interest; don't do that (in future). Whenever you find some doubt (as regards the deteriorating quality of) your dates, sell them, and then buy the dates that you like}}
\hadithdefcmd{muslim}{4087}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الأَعْلَى، أَخْبَرَنَا دَاوُدُ، عَنْ أَبِي نَضْرَةَ، قَالَ سَأَلْتُ ابْنَ عُمَرَ وَابْنَ عَبَّاسٍ عَنِ الصَّرْفِ، فَلَمْ يَرَيَا بِهِ بَأْسًا فَإِنِّي لَقَاعِدٌ عِنْدَ أَبِي سَعِيدٍ الْخُدْرِيِّ فَسَأَلْتُهُ عَنِ الصَّرْفِ فَقَالَ مَا زَادَ فَهُوَ رِبًا ‏.‏ فَأَنْكَرْتُ ذَلِكَ لِقَوْلِهِمَا فَقَالَ لاَ أُحَدِّثُكَ إِلاَّ مَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم جَاءَهُ صَاحِبُ نَخْلِهِ بِصَاعٍ مِنْ تَمْرٍ طَيِّبٍ وَكَانَ تَمْرُ النَّبِيِّ صلى الله عليه وسلم هَذَا اللَّوْنَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَنَّى لَكَ هَذَا ‏"‏ ‏.‏ قَالَ انْطَلَقْتُ بِصَاعَيْنِ فَاشْتَرَيْتُ بِهِ هَذَا الصَّاعَ فَإِنَّ سِعْرَ هَذَا فِي السُّوقِ كَذَا وَسِعْرَ هَذَا كَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَيْلَكَ أَرْبَيْتَ إِذَا أَرَدْتَ ذَلِكَ فَبِعْ تَمْرَكَ بِسِلْعَةٍ ثُمَّ اشْتَرِ بِسِلْعَتِكَ أَىَّ تَمْرٍ شِئْتَ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ فَالتَّمْرُ بِالتَّمْرِ أَحَقُّ أَنْ يَكُونَ رِبًا أَمِ الْفِ��َّةُ بِالْفِضَّةِ قَالَ فَأَتَيْتُ ابْنَ عُمَرَ بَعْدُ فَنَهَانِي وَلَمْ آتِ ابْنَ عَبَّاسٍ - قَالَ - فَحَدَّثَنِي أَبُو الصَّهْبَاءِ أَنَّهُ سَأَلَ ابْنَ عَبَّاسٍ عَنْهُ بِمَكَّةَ فَكَرِهَهُ ‏.‏\hadithno{4087}\hadithtrans{Abu Nadra reported:I asked Ibn Umar and Ibn Abbas (Allah be pleased with them) about the conversion of gold with gold but they did not find any harm in that. I was sitting in the company of Abd Sa'id al-Khudri (Allah be pleased with him) and asked him about this exchange, and he said: Whatever is addition is an' interest. I refused to accept it on account of their statement (statement of Ibn 'Abbas and Ibn 'Umar). He said: I am not narrating to you except what I heard from Allah's Messenger (ﷺ). There came to him the owner of a date-palm with one sa' of fine dates, and the dates of Allah's Apostle (ﷺ) were of that colour. Allah's Apostle (ﷺ) said to him: Where did you get these dates? I went with two sa's of (inferior dates) and bought one sa' of (these fine dates), for that is the prevailing price (of inferior dates) in the market and that is the price (of the fine quality of dates in the market), whereupon Allah's Messenger (ﷺ) said: Woe be upon you! You have dealt in interest, when you decide to do it (i. e. exchange superior quality of dates for inferior quality) ; so you should sell your dates for another commodity (or currency) and then with the help of that commodity buy the dates you like. Abu Sa'ad said: When dates are exchanged for dates (with different qualities) there is the possibility (of the element of) interest (creeping into that) or when gold is exchanged for gold having different qualities. I subsequently came to Ibn 'Umar and he forbade me (to do it), but I did not come to Ibn 'Abbas; (Allah be pleased with them). He (the narrator) said: Abu as-Sahba' narrated to me: He asked Ibn Abbas (Allah be pleased with them) in Mecca, and he too disapproved of it}}
\hadithdefcmd{muslim}{4088}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبَّادٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنْ سُفْيَانَ بْنِ، عُيَيْنَةَ - وَاللَّفْظُ لاِبْنِ عَبَّادٍ - قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي صَالِحٍ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ الدِّينَارُ بِالدِّينَارِ وَالدِّرْهَمُ بِالدِّرْهَمِ مِثْلاً بِمِثْلٍ مَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى ‏.‏ فَقُلْتُ لَهُ إِنَّ ابْنَ عَبَّاسٍ يَقُولُ غَيْرَ هَذَا ‏.‏ فَقَالَ لَقَدْ لَقِيتُ ابْنَ عَبَّاسٍ فَقُلْتُ أَرَأَيْتَ هَذَا الَّذِي تَقُولُ أَشَىْءٌ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَوْ وَجَدْتَهُ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ فَقَالَ لَمْ أَسْمَعْهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ أَجِدْهُ فِي كِتَابِ اللَّهِ وَلَكِنْ حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الرِّبَا فِي النَّسِيئَةِ ‏"‏ ‏.‏\hadithno{4088}\hadithtrans{Abu Salih reported:I heard Abu Sa'id al-Khudri (Allah be pleased with him) said: Dinar (gold) for gold and dirham for dirham can be (exchanged) with equal for equal; but he who gives more or demands more in fact deals in interest. I sald to him: Ibn 'Abbas (Allah be pleased with them) says otherwise, whereupon he said: I met Ibn 'Abbas (Allah be pleased with them) and said: Do you see what you say; have you heard it from Allah's Messenger (ﷺ), or found it in the Book of Allah, the Glorious and Majestic? He said: I did not hear it from Allah's Messenger (ﷺ). and I did not find it in the Book of Allah (Glorious and Majestic), but Usama b. Zaid narrated it to me that Allah's Apostle (ﷺ) said: There can be an element of interest in credit}}
\hadithdefcmd{muslim}{4089}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لِعَمْرٍو - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ، اللَّهِ بْنِ أَبِي يَزِيدَ أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا الرِّبَا فِي النَّسِيئَةِ ‏"‏ ‏.‏\hadithno{4089}\hadithtrans{Ubaidullah b. Abu Yazid heard Ibn 'Abbas (Allah be pleased with them) as saying:Usama b. Zaid reported Allah's Apostle (ﷺ) as saying: There can be an element of interest in credit (when the payment is not equal)}}
\hadithdefcmd{muslim}{4090}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، قَالاَ حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ رِبًا فِيمَا كَانَ يَدًا بِيَدٍ ‏"‏ ‏.‏\hadithno{4090}\hadithtrans{Ibn 'Abbas; (Allah be pleased with them) reported on the authority of Usama b. Zaid Allah's Messenger (ﷺ) as having said this:There is no element of interest when the money or commodity is exchanged hand to hand}}
\hadithdefcmd{muslim}{4091}{حَدَّثَنَا الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا هِقْلٌ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ أَبِي، رَبَاحٍ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، لَقِيَ ابْنَ عَبَّاسٍ فَقَالَ لَهُ أَرَأَيْتَ قَوْلَكَ فِي الصَّرْفِ أَشَيْئًا سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَمْ شَيْئًا وَجَدْتَهُ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ فَقَالَ ابْنُ عَبَّاسٍ كَلاَّ لاَ أَقُولُ أَمَّا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَنْتُمْ أَعْلَمُ بِهِ وَأَمَّا كِتَابُ اللَّهِ فَلاَ أَعْلَمُهُ وَلَكِنْ حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ إِنَّمَا الرِّبَا فِي النَّسِيئَةِ ‏"‏ ‏.‏\hadithno{4091}\hadithtrans{Ata' b. Abu Rabah reported:Abu Sa'id al-Khudri (Allah be pleased with them) met Ibn 'Abbas (Allah be pleased with them) and said to him: What do you say in regard to the conversion (of commodities or money) did you hear it from Allah's Messenger (ﷺ), or is it something which you found In Allah's Book, Majestic and Glorious? Thereupon Ibn Abbas (Allah be pleated with them) said: I don't say that. So far at Allah's Massenger (ﷺ) is concerned, you know him better, and to far as the Book of Allah to concerned, I do not know it (more than you do), but 'Usama b. Zaid (Allah be pleased with him) narrated to me Allah's Messenger (ﷺ) as having said this: Beware, there can be an element of interest in credit}}
\hadithdefcmd{muslim}{4092}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعُثْمَانَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، قَالَ سَأَلَ شِبَاكٌ إِبْرَاهِيمَ فَحَدَّثَنَا عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم آكِلَ الرِّبَا وَمُؤْكِلَهُ ‏.‏ قَالَ قُلْتُ وَكَاتِبَهُ وَشَاهِدَيْهِ قَالَ إِنَّمَا نُحَدِّثُ بِمَا سَمِعْنَا ‏.‏\hadithno{4092}\hadithtrans{Abdullah (b. Mas'ud) (Allah be pleased with him) said that Allah's Messenger (ﷺ) cursed the one who accepted interest and the one who paid it I asked about the one who recorded it, and two witnesses to it. He (the narrator) said:We narrate what we have heard}}
\hadithdefcmd{muslim}{4093}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَزُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالُوا حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم آكِلَ الرِّبَا وَمُوكِلَهُ وَكَاتِبَهُ وَشَاهِدَيْهِ وَقَالَ هُمْ سَوَاءٌ ‏.‏\hadithno{4093}\hadithtrans{Jabir said that Allah's Messenger (ﷺ) cursed the accepter of interest and its payer, and one who records it, and the two witnesses, and he said:They are all equal}}
\hadithdefcmd{muslim}{4094}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ الْهَمْدَانِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ سَمِعْتُهُ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَأَهْوَى النُّعْمَانُ بِإِصْبَعَيْهِ إِلَى أُذُنَيْهِ ‏ "‏ إِنَّ الْحَلاَلَ بَيِّنٌ وَإِنَّ الْحَرَامَ بَيِّنٌ وَبَيْنَهُمَا مُشْتَبِهَاتٌ لاَ يَعْلَمُهُنَّ كَثِيرٌ مِنَ النَّاسِ فَمَنِ اتَّقَى الشُّبُهَاتِ اسْتَبْرَأَ لِدِينِهِ وَعِرْضِهِ وَمَنْ وَقَعَ فِي الشُّبُهَاتِ وَقَعَ فِي الْحَرَامِ كَالرَّاعِي يَرْعَى حَوْلَ الْحِمَى يُوشِكُ أَنْ يَرْتَعَ فِيهِ أَلاَ وَإِنَّ لِكُلِّ مَلِكٍ حِمًى أَلاَ وَإِنَّ حِمَى اللَّهِ مَحَارِمُهُ أَلاَ وَإِنَّ فِي الْجَسَدِ مُضْغَةً إِذَا صَلَحَتْ صَلَحَ الْجَسَدُ كُلُّهُ وَإِذَا فَسَدَتْ فَسَدَ الْجَسَدُ كُلُّهُ أَلاَ وَهِيَ الْقَلْبُ ‏"‏ ‏.‏\hadithno{4094}\hadithtrans{Nu'man b. Bashir (Allah be pleased with him) reported:I heard Allah's Messenger (may peace be upon himn) as having said this (and Nu'man) pointed towards his ears with his fingers): What is lawful is evident and what is unlawful is evident, and in between them are the things doubtful which many people do not know. So he who guards against doubtful things keeps his religion and honour blameless, and he who indulges in doubtful things indulges in fact in unlawful things, just as a shepherd who pastures his animals round a preserve will soon pasture them in it. Beware, every king has a preserve, and the things God his declaced unlawful are His preserves. Beware, in the body there is a piece of flesh; if it is sound, the whole body is sound and if it is corrupt the whole body is corrupt, and hearken it is the heart}}
\hadithdefcmd{muslim}{4095}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، قَالاَ حَدَّثَنَا زَكَرِيَّاءُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4095}\hadithtrans{This hadith has been narrated on the authority of Zakariya with the same chain of transmitters}}
\hadithdefcmd{muslim}{4096}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مُطَرِّفٍ، وَأَبِي، فَرْوَةَ الْهَمْدَانِيِّ ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنِ ابْنِ عَجْلاَنَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَعِيدٍ، كُلُّهُمْ عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ غَيْرَ أَنَّ حَدِيثَ زَكَرِيَّاءَ أَتَمُّ مِنْ حَدِيثِهِمْ وَأَكْثَرُ ‏.‏\hadithno{4096}\hadithtrans{AI-Nu'man b. Bashir reported it from Allah's Apostle (ﷺ). The hadith narrated by Zakariya is, however, more complete and lengthy than the other ones}}
\hadithdefcmd{muslim}{4097}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي خَالِدُ، بْنُ يَزِيدَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي هِلاَلٍ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنْ عَامِرٍ الشَّعْبِيِّ، أَنَّهُ سَمِعَ نُعْمَانَ بْنَ بَشِيرِ بْنِ سَعْدٍ، صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَخْطُبُ النَّاسَ بِحِمْصَ وَهُوَ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الْحَلاَلُ بَيِّنٌ وَالْحَرَامُ بَيِّنٌ ‏"‏ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ زَكَرِيَّاءَ عَنِ الشَّعْبِيِّ إِلَى قَوْلِهِ ‏"‏ يُوشِكُ أَنْ يَقَعَ فِيهِ ‏"‏ ‏.‏\hadithno{4097}\hadithtrans{Nu'man b. Bashir b. Sa'd, a Companion of Allah's Messenger (ﷺ) was heard delivering a sermon at Hims and was saying:I heard Allah's Messenger (way peace be upon him) as saying: The lawful is evident and the unlawful is evident, the rest of the hadith is the same as related by Zakariya}}
\hadithdefcmd{muslim}{4098}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّهُ كَانَ يَسِيرُ عَلَى جَمَلٍ لَهُ قَدْ أَعْيَا فَأَرَادَ أَنْ يُسَيِّبَهُ قَالَ فَلَحِقَنِي النَّبِيُّ صلى الله عليه وسلم فَدَعَا لِي وَضَرَبَهُ فَسَارَ سَيْرًا لَمْ يَسِرْ مِثْلَهُ قَالَ ‏"‏ بِعْنِيهِ بِوُقِيَّةٍ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ ثُمَّ قَالَ ‏"‏ بِعْنِيهِ ‏"‏ ‏.‏ فَبِعْتُهُ بِوُقِيَّةٍ وَاسْتَثْنَيْتُ عَلَيْهِ حُمْلاَنَهُ إِلَى أَهْلِي فَلَمَّا بَلَغْتُ أَتَيْتُهُ بِالْجَمَلِ فَنَقَدَنِي ثَمَنَهُ ثُمَّ رَجَعْتُ فَأَرْسَلَ فِي أَثَرِي فَقَالَ ‏"‏ أَتُرَانِي مَاكَسْتُكَ لآخُذَ جَمَلَكَ خُذْ جَمَلَكَ وَدَرَاهِمَكَ فَهُوَ لَكَ ‏"‏ ‏.‏\hadithno{4098}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported that he was travelling on his camel which had grown jaded, and he decided to let it off. When Allah's Apostle (ﷺ) met him and prayed for him and struck it, so it trotted as it had never trotted before. He said:Sell it to me for an 'uqaya. I said: No. He again said: Sell it to me. So I sold it to him for an 'uqaya, but made the stipulation that I should be allowed to ride back to my family. Then when I came to (my place) I took the camel to him and he paid me its price in ready money. I then went back and he sent: (someone) behind me (and as I came) he said: Do you see that I asked you to reduce price for buying your camel. Take your camel and your coins; these are yours}}
\hadithdefcmd{muslim}{4099}{وَحَدَّثَنَاهُ عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - عَنْ زَكَرِيَّاءَ، عَنْ عَامِرٍ، حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ ‏.‏\hadithno{4099}\hadithtrans{This hadith has been narrated on the authority of Jabir through another chain of transmitters}}
\hadithdefcmd{muslim}{4100}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعُثْمَانَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَلاَحَقَ بِي وَتَحْتِي نَاضِحٌ لِي قَدْ أَعْيَا وَلاَ يَكَادُ يَسِيرُ قَالَ فَقَالَ لِي ‏"‏ مَا لِبَعِيرِكَ ‏"‏ ‏.‏ قَالَ قُلْتُ عَلِيلٌ - قَالَ - فَتَخَلَّفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَزَجَرَهُ وَدَعَا لَهُ فَمَازَالَ بَيْنَ يَدَىِ الإِبِلِ قُدَّامَهَا يَسِيرُ ‏.‏ قَالَ فَقَالَ لِي ‏"‏ كَيْفَ تَرَى بَعِيرَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ بِخَيْرٍ قَدْ أَصَابَتْهُ بَرَكَتُكَ ‏.‏ قَالَ ‏"‏ أَفَتَبِيعُنِيهِ ‏"‏ ‏.‏ فَاسْتَحْيَيْتُ وَلَمْ يَكُنْ لَنَا نَاضِحٌ غَيْرُهُ قَالَ فَقُلْتُ نَعَمْ ‏.‏ فَبِعْتُهُ إِيَّاهُ عَلَى أَنَّ لِي فَقَارَ ظَهْرِهِ حَتَّى أَبْلُغَ الْمَدِينَةَ - قَالَ - فَقُلْتُ لَهُ يَا رَسُولَ اللَّهِ إِنِّي عَرُوسٌ فَاسْتَأْذَنْتُهُ فَأَذِنَ لِي فَتَقَدَّمْتُ النَّاسَ إِلَى الْمَدِينَةِ حَتَّى انْتَهَيْتُ فَلَقِيَنِي خَالِي فَسَأَلَنِي عَنِ الْبَعِيرِ فَأَخْبَرْتُهُ بِمَا صَنَعْتُ فِيهِ فَلاَمَنِي فِيهِ - قَالَ - وَقَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لِي حِينَ اسْتَأْذَنْتُهُ ‏"‏ مَا تَزَوَّجْتَ أَبِكْرًا أَمْ ثَيِّبًا ‏"‏ ‏.‏ فَقُلْتُ لَهُ تَزَوَّجْتُ ثَيِّبًا ‏.‏ قَالَ ‏"‏ أَفَلاَ تَزَوَّجْتَ بِكْرًا تُلاَعِبُكَ وَتُلاَعِبُهَا ‏"‏ ‏.‏ فَقُلْتُ لَهُ يَا رَسُولَ اللَّهِ تُوُفِّيَ وَالِدِي - أَوِ اسْتُشْهِدَ - وَلِي أَخَوَاتٌ صِغَارٌ فَكَرِهْتُ أَنْ أَتَزَوَّجَ إِلَيْهِنَّ مِثْلَهُنَّ فَلاَ تُؤَدِّبُهُنَّ وَلاَ تَقُومُ عَلَيْهِنَّ فَتَزَوَّجْتُ ثَيِّبًا لِتَقُومَ عَلَيْهِنَّ وَتُؤَدِّبَهُنَّ - قَالَ - فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ غَدَوْتُ إِلَيْهِ بِالْبَعِيرِ فَأَعْطَانِي ثَمَنَهُ وَرَدَّهُ عَلَىَّ ‏.‏\hadithno{4100}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:I went on an expedition with Allah's Messenger (ﷺ). He overtook me and I was on a water-carrying camel who had grown tired and did not walk (trot). He (the Holy Prophet) said to me: What is the matter with your camel? I said: It is sick. He (the Holy Prophet) stepped behind and drove it and prayed for it, and then it always moved ahead of other camels. He (then) said: How do you find your camel? I said: It is, by the grace of your prayer, all right. He said: Would you sell this (camel) to me? I felt shy (to say him," No" ) as we had no other camel for carrying water, but (later on) I said: Yes, and to I sold it to him on the condition that (I would be permitted) to ride it until I reached Madina. I said to him: Allah's Messenger, I am newly married, so I asked his permission (to go ahead of the caravan). He permitted me, and I reached Medina well in advance of other people, until I reached my destination. There my maternal uncle met me and asked me about the camel, and I told him what I had done with regard to it. He reproved me in this connection. He (Jabir) said: When I asked his permission (to go ahead of the caravan) Allah's Messenger (ﷺ) inquired of me whether I had married a virgin or a non-virgin. I said to him: I have married a non-virgin. He said: Why did you not marry a virgin who would have played with you and you would have played with her? I said to him: Allah's Messenger, my father died (or he fell as a martyr), and I have small sisters to (look after), so I did not like the idea that I should marry a woman who is like them and thus be not able to teach them manners and look after them properly. So I have married a non-virgin so that she should be able to look after them and teach them manners, When Allah's Messenger (ﷺ) came to Medina, I went to him in the morning with the camel. He paid me its price and returned that (the camel) to me}}
\hadithdefcmd{muslim}{4101}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرٍ، قَالَ أَقْبَلْنَا مِنْ مَكَّةَ إِلَى الْمَدِينَةِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاعْتَلَّ جَمَلِي ‏.‏ وَسَاقَ الْحَدِيثَ بِقِصَّتِهِ وَفِيهِ ثُمَّ قَالَ لِي ‏"‏ بِعْنِي جَمَلَكَ هَذَا ‏"‏ ‏.‏ قَالَ قُلْتُ لاَ بَلْ هُوَ لَكَ ‏.‏ قَالَ ‏"‏ لاَ بَلْ بِعْنِيهِ ‏"‏ ‏.‏ قَالَ قُلْتُ لاَ بَلْ هُوَ لَكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ لاَ بَلْ بِعْنِيهِ ‏"‏ ‏.‏ قَالَ قُلْتُ فَإِنَّ لِرَجُلٍ عَلَىَّ أُوقِيَّةَ ذَهَبٍ فَهُوَ لَكَ بِهَا ‏.‏ قَالَ ‏"‏ قَدْ أَخَذْتُهُ فَتَبَلَّغْ عَلَيْهِ إِلَى الْمَدِينَةِ ‏"‏ ‏.‏ قَالَ فَلَمَّا قَدِمْتُ الْمَدِينَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِبِلاَلٍ ‏"‏ أَعْطِهِ أُوقِيَّةً مِنْ ذَهَبٍ وَزِدْهُ ‏"‏ ‏.‏ قَالَ فَأَعْطَانِي أُوقِيَّةً مِنْ ذَهَبٍ وَزَادَنِي قِيرَاطًا - قَالَ - فَقُلْتُ لاَ تُفَارِقُنِي زِيَادَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - فَكَانَ فِي كِيسٍ لِي فَأَخَذَهُ أَهْلُ الشَّامِ يَوْمَ الْحَرَّةِ ‏.‏\hadithno{4101}\hadithtrans{Jabir reported:We went from Mecca to Medina with Allah's Messenger (ﷺ) when my camel fell ill, and the rest of the hadith is the same. (But it in also narrated in it: ) He (the Holy Prophet) said to me: Sell your camel to me. I said: No, but it is yours. He said: No. (it can't be), but sell it to me. I said: No, but, Allah's Messenger, it is yours. He said: No, it can't be, but sell it to me. I said: Then give me an 'uqaya of gold for I owe that to a person and then it would be yours. He (the Holy Prophet) said: I take it (for an 'uqiya of gold) and you reach Medina on it. As I reached Medina, Allah's Messenger (ﷺ) said to Bilal: Give him an 'uqiya of gold and make some extra payment too. He (Jabir) said: He gave me an 'uqiya of gold and made an addition of a qirat. He (Jabir) said: The addition made by Allah's Messenger (ﷺ) was with me (as a sacred trust for belssing) and lay with me in a pocket until the people of Syria took it on the Day of Harra}}
\hadithdefcmd{muslim}{4102}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ أَبِي، نَضْرَةَ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَتَخَلَّفَ نَاضِحِي ‏.‏ وَسَاقَ الْحَدِيثَ وَقَالَ فِيهِ فَنَخَسَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ لِي ‏"‏ ارْكَبْ بِاسْمِ اللَّهِ ‏"‏ ‏.‏ وَزَادَ أَيْضًا قَالَ فَمَا زَالَ يَزِيدُنِي وَيَقُولُ ‏"‏ وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏\hadithno{4102}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:We were with Allah's Messenger (ﷺ) in a journey and my camel meant for carrying water lagged behind. The rest of the hadith is the same and it is mentioned also: Allah's Messenger (ﷺ) pricked it and then said to me: Ride in the name of Allah. He constantly made addition (in prayers for me) and went on saying. May Allah forgive you}}
\hadithdefcmd{muslim}{4103}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ لَمَّا أَتَى عَلَىَّ النَّبِيُّ صلى الله عليه وسلم وَقَدْ أَعْيَا بَعِيرِي - قَالَ - فَنَخَسَهُ فَوَثَبَ - فَكُنْتُ بَعْدَ ذَلِكَ أَحْبِسُ خِطَامَهُ لأَسْمَعَ حَدِيثَهُ فَمَا أَقْدِرُ عَلَيْهِ فَلَحِقَنِي النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ بِعْنِيهِ ‏"‏ ‏.‏ فَبِعْتُهُ مِنْهُ بِخَمْسِ أَوَاقٍ - قَالَ - قُلْتُ عَلَى أَنَّ لِي ظَهْرَهُ إِلَى الْمَدِينَةِ ‏.‏ قَالَ ‏"‏ وَلَكَ ظَهْرُهُ إِلَى الْمَدِينَةِ ‏"‏ ‏.‏ قَالَ فَلَمَّا قَدِمْتُ الْمَدِينَةَ أَتَيْتُهُ بِهِ فَزَادَنِي وُقِيَّةً ثُمَّ وَهَبَهُ لِي ‏.‏\hadithno{4103}\hadithtrans{Jabir (Allah be pleased with him) reported:My camel had grown tired as Allah's Messenger (ﷺ) came to me. He goaded it and it began to jump. After that I tried to restrain its rein so that I could listen to his (Prophet's) words, but I could not do that. Allah's Apostle (ﷺ) met me and said: Sell it to me, and I sold it for five 'uqiyas. I said: On the condition that I may use it as a ride (for going back) to Medina. He (the Holy Prophet) said: Well, you may use it as a ride up till Medina. When I came to Medina I handed over that to him and he made an addition of an uqiya (to that amount which had been agreed upon) and then presented that (camel) to me}}
\hadithdefcmd{muslim}{4104}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِسْحَاقَ، حَدَّثَنَا بَشِيرُ بْنُ عُقْبَةَ، عَنْ أَبِي الْمُتَوَكِّلِ النَّاجِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَافَرْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ - أَظُنُّهُ قَالَ غَازِيًا - وَاقْتَصَّ الْحَدِيثَ وَزَادَ فِيهِ قَالَ ‏"‏ يَا جَابِرُ أَتَوَفَّيْتَ الثَّمَنَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ لَكَ الثَّمَنُ وَلَكَ الْجَمَلُ لَكَ الثَّمَنُ وَلَكَ الْجَمَلُ‏"‏ ‏.‏\hadithno{4104}\hadithtrans{Abd Mutawakkil al-Najl reported from Jabir b. 'Abdullah (Allah be pleased with them) who said:I accompanied Allah's Messenger (ﷺ) in one of his journeys (the narrator says, he said in Jihad), and he narrated the rest of the hadith, and made this addition: He (the Holy Prophet) said: Jabir, have you received the price? I said: Yes, whereupon he said: Yours is the price as well as the camel; yours is the price as well as the camel}}
\hadithdefcmd{muslim}{4105}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ اشْتَرَى مِنِّي رَسُولُ اللَّهِ صلى الله عليه وسلم بَعِيرًا بِوُقِيَّتَيْنِ وَدِرْهَمٍ أَوْ دِرْهَمَيْنِ - قَاَلَ - فَلَمَّا قَدِمَ صِرَارًا أَمَرَ بِبَقَرَةٍ فَذُبِحَتْ فَأَكَلُوا مِنْهَا فَلَمَّا قَدِمَ الْمَدِينَةَ أَمَرَنِي أَنْ آتِيَ الْمَسْجِدَ فَأُصَلِّيَ رَكْعَتَيْنِ وَوَزَنَ لِي ثَمَنَ الْبَعِيرِ فَأَرْجَحَ لِي ‏.‏\hadithno{4105}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:Allah's Messenger (ﷺ) bought a camel from me for two 'uqiyas and a dirham or two dirhams. As he reached Sirar (a village near Medina), he commanded a cow to be slaughtered and it was slaughtered, and they ate of that, and as he (the Holy Prophet) reached Medina he ordered me to go to the mosque and offer two rak'ahs of prayer, and he measured for me the price of the camel and even made an excess payment to me}}
\hadithdefcmd{muslim}{4106}{حَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا مُحَارِبٌ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذِهِ الْقِصَّةِ غَيْرَ أَنَّهُ قَالَ فَاشْتَرَاهُ مِنِّي بِثَمَنٍ قَدْ سَمَّاهُ ‏.‏ وَلَمْ يَذْكُرِ الْوُقِيَّتَيْنِ وَالدِّرْهَمَ وَالدِّرْهَمَيْنِ ‏.‏ وَقَالَ أَمَرَ بِبَقَرَةٍ فَنُحِرَتْ ثُمَّ قَسَمَ لَحْمَهَا ‏.‏\hadithno{4106}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported this narration from Allah's Apostle (ﷺ) but with this variation that he said:He (the Holy Prophet) bought the camel from me on a stipulated price. And he did not mention two 'uqiyas and a dirham or two dirhams, and he comanded a cow (to be slaughtered) and it was slaughtered, and he then distributed its flesh}}
\hadithdefcmd{muslim}{4107}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ قَدْ أَخَذْتُ جَمَلَكَ بِأَرْبَعَةِ دَنَانِيرَ وَلَكَ ظَهْرُهُ إِلَى الْمَدِينَةِ ‏"‏ ‏.‏\hadithno{4107}\hadithtrans{Jabir (Allah be pleased with him) reported that Allah's Apostle (ﷺ) said to him:I have taken your camelfor four dinars, and you may ride upon it to Medina}}
\hadithdefcmd{muslim}{4108}{حَدَّثَنَا أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ مَالِكِ بْنِ، أَنَسٍ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي رَافِعٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَسْلَفَ مِنْ رَجُلٍ بَكْرًا فَقَدِمَتْ عَلَيْهِ إِبِلٌ مِنْ إِبِلِ الصَّدَقَةِ فَأَمَرَ أَبَا رَافِعٍ أَنْ يَقْضِيَ الرَّجُلَ بَكْرَهُ فَرَجَعَ إِلَيْهِ أَبُو رَافِعٍ فَقَالَ لَمْ أَجِدْ فِيهَا إِلاَّ خِيَارًا رَبَاعِيًا ‏.‏ فَقَالَ ‏ "‏ أَعْطِهِ إِيَّاهُ إِنَّ خِيَارَ النَّاسِ أَحْسَنُهُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{4108}\hadithtrans{Abu Rafi' reported that Allah's Messenger (ﷺ) took from a man as a loan a young camel (below six years). Then the camels of Sadaqa were brought to him. He ordered Abu Rafi' to return to that person the young camel (as a return of the loan). Abu Rafi' returned to him and said:I did not find among them but better camels above the age of six. He (the Holy Prophet) said: Give that to him for the best men are those who are best in paying off the debt}}
\hadithdefcmd{muslim}{4109}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، سَمِعْتُ زَيْدَ بْنَ أَسْلَمَ، أَخْبَرَنَا عَطَاءُ بْنُ يَسَارٍ، عَنْ أَبِي رَافِعٍ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ اسْتَسْلَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَكْرًا ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَإِنَّ خَيْرَ عِبَادِ اللَّهِ أَحْسَنُهُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{4109}\hadithtrans{Abu Rafi', the freed slave of Allah's Messenger (ﷺ), said:Allah's Messenger (ﷺ) took as a loan (the rest of the hadith is the same), but with this variation that he (the Holy Prophet) said: Good amongst the servants of Allah is he who is best in paying off the debt}}
\hadithdefcmd{muslim}{4110}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارِ بْنِ عُثْمَانَ الْعَبْدِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ لِرَجُلٍ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حَقٌّ فَأَغْلَظَ لَهُ فَهَمَّ بِهِ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ لِصَاحِبِ الْحَقِّ مَقَالاً - فَقَالَ لَهُمُ - اشْتَرُوا لَهُ سِنًّا فَأَعْطُوهُ إِيَّاهُ ‏"‏ ‏.‏ فَقَالُوا إِنَّا لاَ نَجِدُ إِلاَّ سِنًّا هُوَ خَيْرٌ مِنْ سِنِّهِ ‏.‏ قَالَ ‏"‏ فَاشْتَرُوهُ فَأَعْطُوهُ إِيَّاهُ فَإِنَّ مِنْ خَيْرِكُمْ - أَوْ خَيْرَكُمْ - أَحْسَنُكُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{4110}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:Allah's Messenger (ﷺ) owed (something) to a person. He behaved in an uncivil manner with him. This vexed the Companions of the Prophet (ﷺ), whereupon Allah's Apostle (ﷺ) said: He who has a right is entitled to speak, and said to them (his Companions): Buy a camel for him and give that to him. They said: We do not find a camel (of that age) but one with better age than that. He said: Buy that and give that to him, for best of you or best amongst you are those who are best in paying off debt}}
\hadithdefcmd{muslim}{4111}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ صَالِحٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ اسْتَقْرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم سِنًّا فَأَعْطَى سِنًّا فَوْقَهُ وَقَالَ ‏ "‏ خِيَارُكُمْ مَحَاسِنُكُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{4111}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:Allah's Messenger (ﷺ) took a camel on loan, and then returned him (the lender) the camel of a more mature age and said: Good among you are those who are good in clearing off the debt}}
\hadithdefcmd{muslim}{4112}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ يَتَقَاضَى رَسُولَ اللَّهِ صلى الله عليه وسلم بَعِيرًا فَقَالَ ‏ "‏ أَعْطُوهُ سِنًّا فَوْقَ سِنِّهِ - وَقَالَ - خَيْرُكُمْ أَحْسَنُكُمْ قَضَاءً ‏"‏ ‏\hadithno{4112}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:There came a person demanding a camel from Allah's Messenger (ﷺ). He (the Holy Prophet) said: Give him (the camel) of that age or of more mature age, and said: Best among you is one who is best in clearing off the debt}}
\hadithdefcmd{muslim}{4113}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَابْنُ، رُمْحٍ قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنِيهِ قُتَيْبَةُ، بْنُ سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جَاءَ عَبْدٌ فَبَايَعَ النَّبِيَّ صلى الله عليه وسلم عَلَى الْهِجْرَةِ وَلَمْ يَشْعُرْ أَنَّهُ عَبْدٌ فَجَاءَ سَيِّدُهُ يُرِيدُهُ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِعْنِيهِ ‏"‏ ‏.‏ فَاشْتَرَاهُ بِعَبْدَيْنِ أَسْوَدَيْنِ ثُمَّ لَمْ يُبَايِعْ أَحَدًا بَعْدُ حَتَّى يَسْأَلَهُ ‏"‏ أَعَبْدٌ هُوَ ‏"‏ ‏.‏\hadithno{4113}\hadithtrans{Jabir (Allah be pleased with him) reported:There came a slave and pledg- ed allegiance to Allah's Apostle (ﷺ) on migration; he (the Holy Prophet) did not know that he was a slave. Then there came his master and demanded him back, whereupon Allah's Apostle (ﷺ) said: Sell him to me. And he bought him for two black slaves, and he did not afterwards take allegiance from anyone until he had asked him whether he was a slave (or a free man)}}
\hadithdefcmd{muslim}{4114}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَمُحَمَّدُ بْنُ الْعَلاَءِ - وَاللَّفْظُ لِيَحْيَى قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتِ اشْتَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ يَهُودِيٍّ طَعَامًا بِنَسِيئَةٍ فَأَعْطَاهُ دِرْعًا لَهُ رَهْنًا ‏.‏\hadithno{4114}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) bought some grain from a Jew on credit and gave him a coat-of- mail of his as a pledge}}
\hadithdefcmd{muslim}{4115}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ، يُونُسَ عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتِ اشْتَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ يَهُودِيٍّ طَعَامًا وَرَهَنَهُ دِرْعًا مِنْ حَدِيدٍ ‏.‏\hadithno{4115}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) bought from a Jew grain (as loan) and pledged him his iron coat-of-mail}}
\hadithdefcmd{muslim}{4116}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا الْمَخْزُومِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ، زِيَادٍ عَنِ الأَعْمَشِ، قَالَ ذَكَرْنَا الرَّهْنَ فِي السَّلَمِ عِنْدَ إِبْرَاهِيمَ النَّخَعِيِّ فَقَالَ حَدَّثَنَا الأَسْوَدُ بْنُ يَزِيدَ عَنْ عَائِشَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اشْتَرَى مِنْ يَهُودِيٍّ طَعَامًا إِلَى أَجَلٍ وَرَهَنَهُ دِرْعًا لَهُ مِنْ حَدِيدٍ ‏.‏\hadithno{4116}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) bought from a Jew grain for a specified time; and gave him iron coat-of-mail of his as a pledge}}
\hadithdefcmd{muslim}{4117}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي الأَسْوَدُ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ وَلَمْ يَذْكُرْ مِنْ حَدِيدٍ‏.‏\hadithno{4117}\hadithtrans{This hadith has been narrated on the authority of 'A'isha (Allah be pleased with her), through another chain ol transmitters, but no mention was made of (its being made) of iron}}
\hadithdefcmd{muslim}{4118}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَمْرٌو النَّاقِدُ، - وَاللَّفْظُ لِيَحْيَى قَالَ عَمْرٌو حَدَّثَنَا وَقَالَ يَحْيَى - أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ عَنِ ابْنِ أَبِي نَجِيحٍ عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ عَنْ أَبِي الْمِنْهَالِ عَنِ ابْنِ عَبَّاسٍ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَهُمْ يُسْلِفُونَ فِي الثِّمَارِ السَّنَةَ وَالسَّنَتَيْنِ فَقَالَ ‏ "‏ مَنْ أَسْلَفَ فِي تَمْرٍ فَلْيُسْلِفْ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ إِلَى أَجَلٍ مَعْلُومٍ‏"‏ ‏.‏\hadithno{4118}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that when Allah's Prophet (ﷺ) came to Medina, they were paying one and two years in advance for fruits, so he said:Those who pay in advance for anything must do so for a specified weight and for a definite time}}
\hadithdefcmd{muslim}{4119}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنِ ابْنِ أَبِي نَجِيحٍ، حَدَّثَنِي عَبْدُ اللَّهِ، بْنُ كَثِيرٍ عَنْ أَبِي الْمِنْهَالِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ يُسْلِفُونَ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَسْلَفَ فَلاَ يُسْلِفْ إِلاَّ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ ‏"‏ ‏.‏\hadithno{4119}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that when Allah's Messenger (ﷺ) came to (Medina) and the people were paying in advance (for the fruits, etc.), he said to them:He who makes an advance payment should not make advance payment except for a specified measure and weight (and for a specified period)}}
\hadithdefcmd{muslim}{4120}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَإِسْمَاعِيلُ بْنُ سَالِمٍ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ عَبْدِ الْوَارِثِ ‏.‏ وَلَمْ يَذْكُرْ ‏ "‏ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏ ‏.‏\hadithno{4120}\hadithtrans{Ibn Abu Najih has narrated a hadith like this with the same chain of transmitters, but he has not mentioned:" for a definite period}}
\hadithdefcmd{muslim}{4121}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، كِلاَهُمَا عَنْ سُفْيَانَ، عَنِ ابْنِ أَبِي نَجِيحٍ، بِإِسْنَادِهِمْ مِثْلَ حَدِيثِ ابْنِ عُيَيْنَةَ يَذْكُرُ فِيهِ ‏ "‏ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏ ‏.‏\hadithno{4121}\hadithtrans{This hadith has been narrated by Ibn Abu Najih through another chain of transmitters mentioning in it" for a specified period}}
\hadithdefcmd{muslim}{4122}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - قَالَ كَانَ سَعِيدُ بْنُ الْمُسَيَّبِ يُحَدِّثُ أَنَّ مَعْمَرًا، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ احْتَكَرَ فَهُوَ خَاطِئٌ ‏"‏ ‏.‏ فَقِيلَ لِسَعِيدٍ فَإِنَّكَ تَحْتَكِرُ قَالَ سَعِيدٌ إِنَّ مَعْمَرًا الَّذِي كَانَ يُحَدِّثُ هَذَا الْحَدِيثَ كَانَ يَحْتَكِرُ ‏.‏\hadithno{4122}\hadithtrans{Ma`mar (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who hoards is a sinner. It was said to Sa`id (b. al-Musayyib): You also hoard. Sa`id said: Ma`mar who narrated this hadith also hoarded}}
\hadithdefcmd{muslim}{4123}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ مَعْمَرِ بْنِ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحْتَكِرُ إِلاَّ خَاطِئٌ ‏"‏ ‏.‏\hadithno{4123}\hadithtrans{Ma'mar b. Abdullah reported Allah's Messenger (ﷺ) as saying:No one hoards but the sinner}}
\hadithdefcmd{muslim}{4124}{قَالَ إِبْرَاهِيمُ قَالَ مُسْلِمٌ وَحَدَّثَنِي بَعْضُ، أَصْحَابِنَا عَنْ عَمْرِو بْنِ عَوْنٍ، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ مَعْمَرِ، بْنِ أَبِي مَعْمَرٍ أَحَدِ بَنِي عَدِيِّ بْنِ كَعْبٍ قَالَ قَالَ رَسُولُ اللَّهِ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ عَنْ يَحْيَى ‏.‏\hadithno{4124}\hadithtrans{This hadith has been transmitted on the authority of Sulaiman b. Bilal from Yahya}}
\hadithdefcmd{muslim}{4125}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو صَفْوَانَ الأُمَوِيُّ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، بْنُ يَحْيَى قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، كِلاَهُمَا عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، أَنَّسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْحَلِفُ مَنْفَقَةٌ لِلسِّلْعَةِ مَمْحَقَةٌ لِلرِّبْحِ ‏"‏ ‏.‏\hadithno{4125}\hadithtrans{Abu Huraira (Allah be pleased with him) said he heard Allah's Messenger (ﷺ) as saying:Swearing produces a ready sale for a commodity, but blots out the blessing}}
\hadithdefcmd{muslim}{4126}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ مَعْبَدِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِيَّاكُمْ وَكَثْرَةَ الْحَلِفِ فِي الْبَيْعِ فَإِنَّهُ يُنَفِّقُ ثُمَّ يَمْحَقُ ‏"‏ ‏.‏\hadithno{4126}\hadithtrans{Abu Qatada al-Ansari (Allah be pleased with him) reported he heard Allah's Messenger (ﷺ) say:Beware of swearing; it produces a ready sale for a commodity, but blots out the blessing}}
\hadithdefcmd{muslim}{4127}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ لَهُ شَرِيكٌ فِي رَبْعَةٍ أَوْ نَخْلٍ فَلَيْسَ لَهُ أَنْ يَبِيعَ حَتَّى يُؤْذِنَ شَرِيكَهُ فَإِنْ رَضِيَ أَخَذَ وَإِنْ كَرِهَ تَرَكَ ‏"‏ ‏.‏\hadithno{4127}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who has a partner in a dwelling or a garden, it is not lawful for him to sell that until he is permitted by his partner. If he (the partner) agrees, he should go in for that, and if he disapproves of that, he should abandon (the idea of selling it)}}
\hadithdefcmd{muslim}{4128}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لاِبْنِ نُمَيْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالشُّفْعَةِ فِي كُلِّ شِرْكَةٍ لَمْ تُقْسَمْ رَبْعَةٍ أَوْ حَائِطٍ ‏.‏ لاَ يَحِلُّ لَهُ أَنْ يَبِيعَ حَتَّى يُؤْذِنَ شَرِيكَهُ فَإِنْ شَاءَ أَخَذَ وَإِنْ شَاءَ تَرَكَ فَإِذَا بَاعَ وَلَمْ يُؤْذِنْهُ فَهْوَ أَحَقُّ بِهِ ‏.‏\hadithno{4128}\hadithtrans{Jabir bin 'Abdullah (Allah be pleased with them) said that the Messenger of Allah (ﷺ) decreed pre-emption in every joint ownership and not divided-the one-it may be a dwelling or a garden. It is not lawful for him (for the partner) to sell that until his partner gives his consent. He (the partner) is entitled to buy it when he desires and he can abandon it if he so likes. And if he (the one partner) sells it without getting the consent of the (other partner), he has the greatest right to it}}
\hadithdefcmd{muslim}{4129}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنِ ابْنِ جُرَيْجٍ، أَنَّ أَبَا الزُّبَيْرِ، أَخْبَرَهُ أَنَّهُ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشُّفْعَةُ فِي كُلِّ شِرْكٍ فِي أَرْضٍ أَوْ رَبْعٍ أَوْ حَائِطٍ لاَ يَصْلُحُ أَنْ يَبِيعَ حَتَّى يَعْرِضَ عَلَى شَرِيكِهِ فَيَأْخُذَ أَوْ يَدَعَ فَإِنْ أَبَى فَشَرِيكُهُ أَحَقُّ بِهِ حَتَّى يُؤْذِنَهُ ‏"‏ ‏.‏\hadithno{4129}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:There is pre-emption in everything which is shared, be it land, or a dwelling or a garden. It is not proper to sell it until he informs his partner; he may go in for that, or he may abandon it; and it he (the partner intending to sell his share) does not do that, then his partner has the greatest right to it until he permits him}}
\hadithdefcmd{muslim}{4130}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْنَعْ أَحَدُكُمْ جَارَهُ أَنْ يَغْرِزَ خَشَبَةً فِي جِدَارِهِ ‏"‏ ‏.‏ قَالَ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ مَا لِي أَرَاكُمْ عَنْهَا مُعْرِضِينَ وَاللَّهِ لأَرْمِيَنَّ بِهَا بَيْنَ أَكْتَافِكُمْ ‏.‏\hadithno{4130}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:None among you should prevent his neighbour from fixing a beam in his wall. Abu Huraira (Allah be pleased with him) then said: What is this that I see you evading (this injunction of the Holy Prophet)? By Allah, I will certainly throw it between your shoulders (narrate this to you)}}
\hadithdefcmd{muslim}{4131}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، بْنُ يَحْيَى قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ، الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4131}\hadithtrans{This hadith is narrated on the authority of Zuhri with the same chain of transrmitters}}
\hadithdefcmd{muslim}{4132}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، عَنْ سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اقْتَطَعَ شِبْرًا مِنَ الأَرْضِ ظُلْمًا طَوَّقَهُ اللَّهُ إِيَّاهُ يَوْمَ الْقِيَامَةِ مِنْ سَبْعِ أَرَضِينَ ‏"‏ ‏.‏\hadithno{4132}\hadithtrans{Sa'id b. Zaid b. 'Amr b. Nufail (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who wrongly took a span of land, Allah shall make him carry around his neck seven earths}}
\hadithdefcmd{muslim}{4133}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدٍ، أَنَّحَدَّثَهُ عَنْ سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، أَنَّ أَرْوَى، خَاصَمَتْهُ فِي بَعْضِ دَارِهِ فَقَالَ دَعُوهَا وَإِيَّاهَا فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَخَذَ شِبْرًا مِنَ الأَرْضِ بِغَيْرِ حَقِّهِ طُوِّقَهُ فِي سَبْعِ أَرَضِينَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ اللَّهُمَّ إِنْ كَانَتْ كَاذِبَةً فَأَعْمِ بَصَرَهَا وَاجْعَلْ قَبْرَهَا فِي دَارِهَا ‏.‏ قَالَ فَرَأَيْتُهَا عَمْيَاءَ تَلْتَمِسُ الْجُدُرَ تَقُولُ أَصَابَتْنِي دَعْوَةُ سَعِيدِ بْنِ زَيْدٍ ‏.‏ فَبَيْنَمَا هِيَ تَمْشِي فِي الدَّارِ مَرَّتْ عَلَى بِئْرٍ فِي الدَّارِ فَوَقَعَتْ فِيهَا فَكَانَتْ قَبْرَهَا‏.‏\hadithno{4133}\hadithtrans{Sa'id b. Zaid b. 'Amr b. Nufail (Allah be pleased with them) reported that Arwi (bint Uwais) disputed with him (in regard to a part of the land) of his hodse. He said:Leave it and take off your claim from it, for I heard Allah's Messenger (ﷺ) as saying: He who took a span of land without his right would be made to wear around his neck seven earths on the Day of Resurrection. He (Sa'id b. Zaid) said: O Allah, make her blind if she has told a lie and make her grave in her house. He (the narrator) said: I saw her blind groping (her way) by touching the walls and saying: The curse of Sa'id b. Zaid has hit me. And it so happened that as she was walking in her house, she passed by a well in her house and fell therein and that be- came her grave}}
\hadithdefcmd{muslim}{4134}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ أَرْوَى بِنْتَ أُوَيْسٍ، ادَّعَتْ عَلَى سَعِيدِ بْنِ زَيْدٍ أَنَّهُ أَخَذَ شَيْئًا مِنْ أَرْضِهَا فَخَاصَمَتْهُ إِلَى مَرْوَانَ بْنِ الْحَكَمِ ‏.‏ فَقَالَ سَعِيدٌ أَنَا كُنْتُ آخُذُ مِنْ أَرْضِهَا شَيْئًا بَعْدَ الَّذِي سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ وَمَا سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَخَذَ شِبْرًا مِنَ الأَرْضِ ظُلْمًا طُوِّقَهُ إِلَى سَبْعِ أَرَضِينَ ‏"‏ ‏.‏ فَقَالَ لَهُ مَرْوَانُ لاَ أَسْأَلُكَ بَيِّنَةً بَعْدَ هَذَا ‏.‏ فَقَالَ اللَّهُمَّ إِنْ كَانَتْ كَاذِبَةً فَعَمِّ بَصَرَهَا وَاقْتُلْهَا فِي أَرْضِهَا ‏.‏ قَالَ فَمَا مَاتَتْ حَتَّى ذَهَبَ بَصَرُهَا ثُمَّ بَيْنَا هِيَ تَمْشِي فِي أَرْضِهَا إِذْ وَقَعَتْ فِي حُفْرَةٍ فَمَاتَتْ ‏.‏\hadithno{4134}\hadithtrans{Hisham b. Urwa reported on the authority of his father (Allah be pleased with him) that Arwa bint Uwais disputed with Sa'id b. Zaid that he had seized some of the land belonging to her. She brought this dispute before Marwan b. al-Hakam. Sa'id said:How could I take a part of her land, after what I heard from Allah's Messenger (may peace be upon'him)? He (Marwan) said: What did you hear from Allah's Messenger (ﷺ)? He said: I heard Allah's Messenger (ﷺ) say: He who wrongly took a span of land would be made to wear around his neck seven earths. Marwan said: I do not ask any evidence from you after this. He (Sa'id) said: O Allah, make her blind if she has told a lie and kill her in her own land. He (the narrator) said: She did not die until she had lost her eyesight, and (one day) as she was walking in her land, she fell down into a pit and died}}
\hadithdefcmd{muslim}{4135}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ زَيْدٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَخَذَ شِبْرًا مِنَ الأَرْضِ ظُلْمًا فَإِنَّهُ يُطَوَّقُهُ يَوْمَ الْقِيَامَةِ مِنْ سَبْعِ أَرَضِينَ ‏"‏ ‏.‏\hadithno{4135}\hadithtrans{Sa'id b. Zaid reported:I heard Allah's Apostle (ﷺ) say: He who took a span of earth wrongly would be made to wear around his neck seven earths on the Day of Resurrection}}
\hadithdefcmd{muslim}{4136}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَأْخُذُ أَحَدٌ شِبْرًا مِنَ الأَرْضِ بِغَيْرِ حَقِّهِ إِلاَّ طَوَّقَهُ اللَّهُ إِلَى سَبْعِ أَرَضِينَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4136}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (may peace he upon him) as saying:One should not take a span of land without having legitimate right to it, otherwise Allah would make him wear (around his neck) seven earths on the Day of Resurrection}}
\hadithdefcmd{muslim}{4137}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، - يَعْنِي ابْنَ عَبْدِ الْوَارِثِ - حَدَّثَنَا حَرْبٌ، - وَهُوَ ابْنُ شَدَّادٍ - حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ أَبِي كَثِيرٍ - عَنْ مُحَمَّدِ بْنِ، إِبْرَاهِيمَ أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ وَكَانَ، بَيْنَهُ وَبَيْنَ قَوْمِهِ خُصُومَةٌ فِي أَرْضٍ وَأَنَّهُ دَخَلَ عَلَى عَائِشَةَ فَذَكَرَ ذَلِكَ لَهَا فَقَالَتْ يَا أَبَا سَلَمَةَ اجْتَنِبِ الأَرْضَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ ظَلَمَ قِيدَ شِبْرٍ مِنَ الأَرْضِ طُوِّقَهُ مِنْ سَبْعِ أَرَضِينَ ‏"‏ ‏.‏\hadithno{4137}\hadithtrans{Muhammad b. Ibrahim said that Abu Salama reported to him that there was between him and his people dispute over a piece of land, and he came to 'A'isha and mentioned that to her, whereupon she said:Abu Salama, abstain from getting this land, for Allah's Messenger (ﷺ) said: He who usurps even a span of land would be made to wear around his neck seven earths}}
\hadithdefcmd{muslim}{4138}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا حَبَّانُ بْنُ هِلاَلٍ، أَخْبَرَنَا أَبَانٌ، حَدَّثَنَا يَحْيَى، أَنَّ مُحَمَّدَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُ أَنَّ أَبَا سَلَمَةَ حَدَّثَهُ أَنَّهُ، دَخَلَ عَلَى عَائِشَةَ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{4138}\hadithtrans{This hadith has been narrated on the authority of Abu Salama with another chain of transmitters}}
\hadithdefcmd{muslim}{4139}{حَدَّثَنِي أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اخْتَلَفْتُمْ فِي الطَّرِيقِ جُعِلَ عَرْضُهُ سَبْعَ أَذْرُعٍ ‏"‏ ‏.‏\hadithno{4139}\hadithtrans{Abu Haraira reported Allah's Apostle (ﷺ) as saying:When you disagree about a path, its breadth should be made seven cubits}}
