% Auto-generated chapter 1 for abudawud
% Hadiths in this chapter: 390

\hadithdefcmd{abudawud}{1}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ أَبِي سَلَمَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا ذَهَبَ الْمَذْهَبَ أَبْعَدَ ‏.‏\hadithno{1}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mughirah ibn Shu'bah: When the Prophet (ﷺ) went (outside) to relieve himself, he went to a far-off place}}
\hadithdefcmd{abudawud}{2}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ عَبْدِ الْمَلِكِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ الْبَرَازَ انْطَلَقَ حَتَّى لاَ يَرَاهُ أَحَدٌ ‏.‏\hadithno{2}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: When the Prophet (ﷺ) felt the need of relieving himself, he went far off where no one could see him}}
\hadithdefcmd{abudawud}{3}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا أَبُو التَّيَّاحِ، حَدَّثَنِي شَيْخٌ، قَالَ لَمَّا قَدِمَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ الْبَصْرَةَ فَكَانَ يُحَدَّثُ عَنْ أَبِي مُوسَى، فَكَتَبَ عَبْدُ اللَّهِ إِلَى أَبِي مُوسَى يَسْأَلُهُ عَنْ أَشْيَاءَ، فَكَتَبَ إِلَيْهِ أَبُو مُوسَى إِنِّي كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَأَرَادَ أَنْ يَبُولَ فَأَتَى دَمِثًا فِي أَصْلِ جِدَارٍ فَبَالَ ثُمَّ قَالَ صلى الله عليه وسلم ‏ "‏ إِذَا أَرَادَ أَحَدُكُمْ أَنْ يَبُولَ فَلْيَرْتَدْ لِبَوْلِهِ مَوْضِعًا ‏"‏ ‏.‏\hadithno{3}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu al-Tayyah reported on the authority of a shaykh (an old man):When Abdullah ibn Abbas came to Basrah, people narrated to him traditions from AbuMusa. Therefore Ibn Abbas wrote to him asking him about certain things. In reply AbuMusa wrote to him saying: One day I was in the company of the Messenger of Allah (ﷺ). He wanted to urinate. Then he came to a soft ground at the foot of a wall and urinated. He (the Prophet) then said: If any of you wants to urinate, he should look for a place (like this) for his urination}}
\hadithdefcmd{abudawud}{4}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، وَعَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ - قَالَ عَنْ حَمَّادٍ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ ‏"‏ ‏.‏ وَقَالَ عَنْ عَبْدِ الْوَارِثِ - قَالَ ‏"‏ أَعُوذُ بِاللَّهِ مِنَ الْخُبُثِ وَالْخَبَائِثِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُد رَوَاهُ شُعْبَةُ عَنْ عَبْدِ الْعَزِيزِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ وَقَالَ مَرَّةً أَعُوذُ بِاللَّهِ و قَالَ وُهَيْبٌ فَلْيَتَعَوَّذْ بِاللَّهِ\hadithno{4}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (142) Sahih Muslim (375)}\hadithtrans{Anas b. Malik reported:When the Apostle of Allaah (sal Allahu alayhi wa sallam) entered the toilet, he used to say (before entering): "O Allaah, I seek refuge in Thee." This is according to the version of Hammad. 'Abd al-Warith has another version :"I seek refuge in Allaah from male and female devils}}
\hadithdefcmd{abudawud}{5}{حَدَّثَنَا الْحَسَنُ بْنُ عَمْرٍو، - يَعْنِي السَّدُوسِيَّ - حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ عَبْدِ الْعَزِيزِ، - هُوَ ابْنُ صُهَيْبٍ - عَنْ أَنَسٍ، بِهَذَا الْحَدِيثِ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ ‏"‏ ‏.‏ وَقَالَ شُعْبَةُ وَقَالَ مَرَّةً ‏"‏ أَعُوذُ بِاللَّهِ ‏"‏ ‏.‏\hadithno{5}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Another tradition on the authority of Anas has:" O Allaah, I seek refuge in Thee." Shu'bah said: Anas sometimes reported the words: "I take refuge in Allah}}
\hadithdefcmd{abudawud}{6}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ هَذِهِ الْحُشُوشَ مُحْتَضَرَةٌ فَإِذَا أَتَى أَحَدُكُمُ الْخَلاَءَ فَلْيَقُلْ أَعُوذُ بِاللَّهِ مِنَ الْخُبُثِ وَالْخَبَائِثِ ‏"‏ ‏.‏\hadithno{6}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Zayd ibn Arqam: The Messenger of Allah (ﷺ) said: These privies are frequented by the jinns and devils. So when anyone amongst you goes there, he should say: "I seek refuge in Allah from male and female devils}}
\hadithdefcmd{abudawud}{7}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ سَلْمَانَ، قَالَ قِيلَ لَهُ لَقَدْ عَلَّمَكُمْ نَبِيُّكُمْ كُلَّ شَىْءٍ حَتَّى الْخِرَاءَةَ ‏.‏ قَالَ أَجَلْ لَقَدْ نَهَانَا صلى الله عليه وسلم أَنْ نَسْتَقْبِلَ الْقِبْلَةَ بِغَائِطٍ أَوْ بَوْلٍ وَأَنْ لاَ نَسْتَنْجِيَ بِالْيَمِينِ وَأَنْ لاَ يَسْتَنْجِيَ أَحَدُنَا بِأَقَلَّ مِنْ ثَلاَثَةِ أَحْجَارٍ أَوْ يَسْتَنْجِيَ بِرَجِيعٍ أَوْ عَظْمٍ ‏.‏\hadithno{7}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (262)}\hadithtrans{Narrated Salman al-Farsi: It was said to Salman: Your Prophet teaches you everything, even about excrement. He replied: Yes. He has forbidden us to face the qiblah at the time of easing or urinating, and cleansing with right hand, and cleansing with less than three stones, or cleansing with dung or bone}}
\hadithdefcmd{abudawud}{8}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا أَنَا لَكُمْ بِمَنْزِلَةِ الْوَالِدِ أُعَلِّمُكُمْ فَإِذَا أَتَى أَحَدُكُمُ الْغَائِطَ فَلاَ يَسْتَقْبِلِ الْقِبْلَةَ وَلاَ يَسْتَدْبِرْهَا وَلاَ يَسْتَطِبْ بِيَمِينِهِ ‏"‏ ‏.‏ وَكَانَ يَأْمُرُ بِثَلاَثَةِ أَحْجَارٍ وَيَنْهَى عَنِ الرَّوْثِ وَالرِّمَّةِ ‏.‏\hadithno{8}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:The Apostle of Allaah ( sal Allaahu alayhi wa sallam ) as saying: I am like father to you. When any of you goes to privy, he should not face or turn his back towards the qiblah. He should not cleanse with his right hand. He (the Prophet, sal Allaahu alayhi wa sallam) also commanded the Muslims to use three stones and forbade them to use dung or decayed bone}}
\hadithdefcmd{abudawud}{9}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ، رِوَايَةً قَالَ ‏ "‏ إِذَا أَتَيْتُمُ الْغَائِطَ فَلاَ تَسْتَقْبِلُوا الْقِبْلَةَ بِغَائِطٍ وَلاَ بَوْلٍ وَلَكِنْ شَرِّقُوا أَوْ غَرِّبُوا ‏"‏ ‏.‏ فَقَدِمْنَا الشَّامَ فَوَجَدْنَا مَرَاحِيضَ قَدْ بُنِيَتْ قِبَلَ الْقِبْلَةِ فَكُنَّا نَنْحَرِفُ عَنْهَا وَنَسْتَغْفِرُ اللَّهَ ‏.‏\hadithno{9}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (394) Sahih Muslim (264)}\hadithtrans{Narrated Abu Ayyub :That he (the Holy Prophet, sal Allahu alayhi wa sallam) said:"When you go to the privy, neither turn your face nor your back towards the qiblah at the time of excretion or urination, but turn towards the east or the west. (Abu Ayyub said): When we came to Syria, we found that the toilets already built there were facing the qiblah, We turned our faces away from them and begged pardon of Allaah}}
\hadithdefcmd{abudawud}{10}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِي زَيْدٍ، عَنْ مَعْقِلِ بْنِ أَبِي مَعْقِلٍ الأَسَدِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَسْتَقْبِلَ الْقِبْلَتَيْنِ بِبَوْلٍ أَوْ غَائِطٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَأَبُو زَيْدٍ هُوَ مَوْلَى بَنِي ثَعْلَبَةَ ‏.‏\hadithno{10}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ma'qil ibn AbuMa'qil al-Asadi: The Messenger of Allah (ﷺ) has forbidden us to face the two qiblahs at the time of urination or excretion}}
\hadithdefcmd{abudawud}{11}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، عَنِ الْحَسَنِ بْنِ ذَكْوَانَ، عَنْ مَرْوَانَ الأَصْفَرِ، قَالَ رَأَيْتُ ابْنَ عُمَرَ أَنَاخَ رَاحِلَتَهُ مُسْتَقْبِلَ الْقِبْلَةِ ثُمَّ جَلَسَ يَبُولُ إِلَيْهَا فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ أَلَيْسَ قَدْ نُهِيَ عَنْ هَذَا قَالَ بَلَى إِنَّمَا نُهِيَ عَنْ ذَلِكَ فِي الْفَضَاءِ فَإِذَا كَانَ بَيْنَكَ وَبَيْنَ الْقِبْلَةِ شَىْءٌ يَسْتُرُكَ فَلاَ بَأْسَ ‏.‏\hadithno{11}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Marwan al-Asfar said:I saw Ibn Umar make his camel kneel down facing the qiblah, then he sat down urinating in its direction. So I said: AbuAbdurRahman, has this not been forbidden? He replied: Why not, that was forbidden only in open country; but when there is something between you and the qiblah that conceals you , then there is no harm}}
\hadithdefcmd{abudawud}{12}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ لَقَدِ ارْتَقَيْتُ عَلَى ظَهْرِ الْبَيْتِ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى لَبِنَتَيْنِ مُسْتَقْبِلَ بَيْتِ الْمَقْدِسِ لِحَاجَتِهِ\hadithno{12}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (145) Sahih Muslim (266)}\hadithtrans{Narrated 'Abd Allaah b. 'Umar :I ascended the roof of the house and saw the Apostle of Allaah ( sal Allaahu alayhi wa sallam) sitting on two bricks facing Jerusalem (Bait al-Maqdis) for relieving himself}}
\hadithdefcmd{abudawud}{13}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ مُحَمَّدَ بْنَ إِسْحَاقَ، يُحَدِّثُ عَنْ أَبَانَ بْنِ صَالِحٍ، عَنْ مُجَاهِدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى نَبِيُّ اللَّهِ صلى الله عليه وسلم أَنْ نَسْتَقْبِلَ الْقِبْلَةَ بِبَوْلٍ فَرَأَيْتُهُ قَبْلَ أَنْ يُقْبَضَ بِعَامٍ يَسْتَقْبِلُهَا ‏.‏\hadithno{13}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet of Allah (ﷺ) forbade us to face the qiblah at the time of making water. Then I saw him facing it (qiblah) urinating or easing himself one year before his death}}
\hadithdefcmd{abudawud}{14}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ رَجُلٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ حَاجَةً لاَ يَرْفَعُ ثَوْبَهُ حَتَّى يَدْنُوَ مِنَ الأَرْضِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَبْدُ السَّلاَمِ بْنُ حَرْبٍ عَنِ الأَعْمَشِ عَنْ أَنَسِ بْنِ مَالِكٍ وَهُوَ ضَعِيفٌ ‏.‏ قَالَ أَبُو عِيسَى الرَّمْلِيُّ حَدَّثَنَا أَحْمَدُ بْنُ الْوَلِيدِ حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ أَخْبَرَنَا عَبْدُ السَّلاَمِ بِهِ ‏.‏\hadithno{14}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: When the Prophet (ﷺ) wanted to relieve himself, he would not raise his garment, until he lowered himself near the ground. Abu DAwud said: This tradition has been transmitted by 'Abd al-Salam b. Harb on the authority of al-A'mash from Anas b. Malik. This chain of narrators is weak (because A'mash's hearing tradition from Anas b. Malik is not established)}}
\hadithdefcmd{abudawud}{15}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ عِيَاضٍ، قَالَ حَدَّثَنِي أَبُو سَعِيدٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَخْرُجُ الرَّجُلاَنِ يَضْرِبَانِ الْغَائِطَ كَاشِفَيْنِ عَنْ عَوْرَتِهِمَا يَتَحَدَّثَانِ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ يَمْقُتُ عَلَى ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا لَمْ يُسْنِدْهُ إِلاَّ عِكْرِمَةُ بْنُ عَمَّارٍ ‏.‏\hadithno{15}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: I heard the Messenger of Allah (ﷺ) say: When two persons go together for relieving themselves uncovering their private parts and talking together, Allah, the Great and Majestic, becomes wrathful at this (action). Abu Dawud said: This tradition has been narrated only by 'Ikrimah b. 'Ammar}}
\hadithdefcmd{abudawud}{16}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا عُمَرُ بْنُ سَعْدٍ، عَنْ سُفْيَانَ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَرَّ رَجُلٌ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَبُولُ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُوِيَ عَنِ ابْنِ عُمَرَ وَغَيْرِهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَيَمَّمَ ثُمَّ رَدَّ عَلَى الرَّجُلِ السَّلاَمَ ‏.‏\hadithno{16}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (370)}\hadithtrans{Narrated Ibn 'Umar : A man passed by the Prophet (sal Allaahu alayhi wa sallam ) while he was urinating, and saluted him. The Prophet (sal Allaahu alayhi wa sallam) did not return the salutation to him. Abu Dawud said : It is narrated on the authority of Ibn 'Umar that the Prophet (sal Allaahu alayhi wa sallam) performed tayammum, then he returned the salutation to the man}}
\hadithdefcmd{abudawud}{17}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ حُضَيْنِ بْنِ الْمُنْذِرِ أَبِي سَاسَانَ، عَنِ الْمُهَاجِرِ بْنِ قُنْفُذٍ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ يَبُولُ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْهِ حَتَّى تَوَضَّأَ ثُمَّ اعْتَذَرَ إِلَيْهِ فَقَالَ ‏"‏ إِنِّي كَرِهْتُ أَنْ أَذْكُرَ اللَّهَ عَزَّ وَجَلَّ إِلاَّ عَلَى طُهْرٍ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ عَلَى طَهَارَةٍ ‏"‏ ‏.‏\hadithno{17}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Muhajir ibn Qunfudh: Muhajir came to the Prophet (ﷺ) while he was urinating. He saluted him. The Prophet (ﷺ) did not return the salutation to him until he performed ablution. He then apologised to him, saying: I disliked remembering Allah except in the state of purification}}
\hadithdefcmd{abudawud}{18}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ خَالِدِ بْنِ سَلَمَةَ، - يَعْنِي الْفَأْفَاءَ - عَنِ الْبَهِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَذْكُرُ اللَّهَ عَزَّ وَجَلَّ عَلَى كُلِّ أَحْيَانِهِ ‏.‏\hadithno{18}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (373)}\hadithtrans{Narrated A'ishah:The Apostle of Allaah ( sal Allaahu alayhi wa sallam ) used to remember Allaah, the Great and Majestic, at all moments}}
\hadithdefcmd{abudawud}{19}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، عَنْ أَبِي عَلِيٍّ الْحَنَفِيِّ، عَنْ هَمَّامٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ وَضَعَ خَاتَمَهُ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حَدِيثٌ مُنْكَرٌ وَإِنَّمَا يُعْرَفُ عَنِ ابْنِ جُرَيْجٍ عَنْ زِيَادِ بْنِ سَعْدٍ عَنِ الزُّهْرِيِّ عَنْ أَنَسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ وَرِقٍ ثُمَّ أَلْقَاهُ ‏.‏ وَالْوَهَمُ فِيهِ مِنْ هَمَّامٍ وَلَمْ يَرْوِهِ إِلاَّ هَمَّامٌ ‏.‏\hadithno{19}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: When the Prophet (ﷺ) entered the privy, he removed his ring. Abu Dawud said: This is a munkar tradition, i.e. it contradicts the well-known version reported by reliable narrators. On the authority of Anas the well-known version says: The Prophet (ﷺ) had a silver ring made for him. Then he cast it off. The misunderstanding is on the part of Hammam (who is the narrator of the previous tradition mentioned in the text). This is transmitted only by Hammam}}
\hadithdefcmd{abudawud}{20}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ مُجَاهِدًا، يُحَدِّثُ عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى قَبْرَيْنِ فَقَالَ ‏"‏ إِنَّهُمَا يُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا هَذَا فَكَانَ لاَ يَسْتَنْزِهُ مِنَ الْبَوْلِ وَأَمَّا هَذَا فَكَانَ يَمْشِي بِالنَّمِيمَةِ ‏"‏ ‏.‏ ثُمَّ دَعَا بِعَسِيبٍ رَطْبٍ فَشَقَّهُ بِاثْنَيْنِ ثُمَّ غَرَسَ عَلَى هَذَا وَاحِدًا وَعَلَى هَذَا وَاحِدًا وَقَالَ ‏"‏ لَعَلَّهُ يُخَفَّفُ عَنْهُمَا مَا لَمْ يَيْبَسَا ‏"‏ ‏.‏ قَالَ هَنَّادٌ ‏"‏ يَسْتَتِرُ ‏"‏ ‏.‏ مَكَانَ ‏"‏ يَسْتَنْزِهُ ‏"‏ ‏.‏\hadithno{20}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6052) Sahih Muslim (292)}\hadithtrans{Narrated Ibn 'Abbas : The Prophet (sal Allaahu alayhi wa sallam ) passed by two graves. He said : Both (the dead) are being punished, but they are not being punished for a major (sin). One did not safeguard himself from urine. The other carried tales. He then called for a fresh twig and split it into two parts and planted one part on each grave and said: Perhaps their punishment may be mitigated as long as the twigs remain fresh. Another version of Hannad has: "One of them did not cover himself while urinating." This version does not have the words: "He did not safeguard himself from urine}}
\hadithdefcmd{abudawud}{21}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ ‏"‏ كَانَ لاَ يَسْتَتِرُ مِنْ بَوْلِهِ ‏"‏ ‏.‏ وَقَالَ أَبُو مُعَاوِيَةَ ‏"‏ يَسْتَنْزِهُ ‏"‏ ‏.‏\hadithno{21}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (216)}\hadithtrans{Narrated Ibn 'Abbas: A tradition from the Prophet (sal Allaahu alayhi wa sallam ) conveying similar meaning. The version of Jarir has the wording : "he did not cover himself while urinating." The version of Abu Mu'awiyah has the wording: "he did not safeguard himself (from urine)}}
\hadithdefcmd{abudawud}{22}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ ابْنِ حَسَنَةَ، قَالَ انْطَلَقْتُ أَنَا وَعَمْرُو بْنُ الْعَاصِ، إِلَى النَّبِيِّ صلى الله عليه وسلم فَخَرَجَ وَمَعَهُ دَرَقَةٌ ثُمَّ اسْتَتَرَ بِهَا ثُمَّ بَالَ فَقُلْنَا انْظُرُوا إِلَيْهِ يَبُولُ كَمَا تَبُولُ الْمَرْأَةُ ‏.‏ فَسَمِعَ ذَلِكَ فَقَالَ ‏"‏ أَلَمْ تَعْلَمُوا مَا لَقِيَ صَاحِبُ بَنِي إِسْرَائِيلَ كَانُوا إِذَا أَصَابَهُمُ الْبَوْلُ قَطَعُوا مَا أَصَابَهُ الْبَوْلُ مِنْهُمْ فَنَهَاهُمْ فَعُذِّبَ فِي قَبْرِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مَنْصُورٌ عَنْ أَبِي وَائِلٍ عَنْ أَبِي مُوسَى فِي هَذَا الْحَدِيثِ قَالَ ‏"‏ جِلْدَ أَحَدِهِمْ ‏"‏ ‏.‏ وَقَالَ عَاصِمٌ عَنْ أَبِي وَائِلٍ عَنْ أَبِي مُوسَى عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ جَسَدَ أَحَدِهِمْ ‏"‏ ‏.‏\hadithno{22}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amr ibn al-'As: AbdurRahman ibn Hasanah reported: I and Amr ibn al-'As went to the Prophet (ﷺ). He came out with a leather shield (in his hand). He covered himself with it and urinated. Then we said: Look at him. He is urinating as a woman does. The Prophet (ﷺ), heard this and said: Do you not know what befell a person from amongst Banu Isra'il (the children of Israel)? When urine fell on them, they would cut off the place where the urine fell; but he (that person) forbade them (to do so), and was punished in his grave. Abu Dawud said: One version of Abu Musa has the wording: "he cut off his skin". Another version of Abu Musa goes: "he cut off (part of) his body}}
\hadithdefcmd{abudawud}{23}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، - وَهَذَا لَفْظُ حَفْصٍ - عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم سُبَاطَةَ قَوْمٍ فَبَالَ قَائِمًا ثُمَّ دَعَا بِمَاءٍ فَمَسَحَ عَلَى خُفَّيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مُسَدَّدٌ قَالَ فَذَهَبْتُ أَتَبَاعَدُ فَدَعَانِي حَتَّى كُنْتُ عِنْدَ عَقِبِهِ ‏.‏\hadithno{23}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (224) Sahih Muslim (273)}\hadithtrans{Narrated Hudhaifah : The Apostle of Allaah ( sal Allaahu alayhi wa sallam ) came to a midden of some people and urinated while standing. He then asked for water and wiped his shoes. Abu Dawud said: Musaddad, a narrator, reported: I went far away from him. He then called me and I reached just near his heals}}
\hadithdefcmd{abudawud}{24}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، عَنْ حُكَيْمَةَ بِنْتِ أُمَيْمَةَ بِنْتِ رُقَيْقَةَ، عَنْ أُمِّهَا، أَنَّهَا قَالَتْ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم قَدَحٌ مِنْ عَيْدَانٍ تَحْتَ سَرِيرِهِ يَبُولُ فِيهِ بِاللَّيْلِ ‏.‏\hadithno{24}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umaymah daughter of Ruqayqah: The Prophet (ﷺ) had a wooden vessel under his bed in which he would urinate at night}}
\hadithdefcmd{abudawud}{25}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اتَّقُوا اللاَّعِنَيْنِ ‏"‏ ‏.‏ قَالُوا وَمَا اللاَّعِنَانِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الَّذِي يَتَخَلَّى فِي طَرِيقِ النَّاسِ أَوْ ظِلِّهِمْ ‏"‏ ‏.‏\hadithno{25}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (269)}\hadithtrans{Narrated Abu Hurairah:The Prophet (sal Allaahu alayhi wa sallam ) as saying : Be on your guard against two things which provoke cursing. They (the hearers) said : Prophet of Allaah ( sal Allaahu alayhi wa sallam), what are these things which provoke cursing: easing in the watering places and on the thoroughfares, and in the shade (of the tree)(where they take shelter and rest)}}
\hadithdefcmd{abudawud}{26}{حَدَّثَنَا إِسْحَاقُ بْنُ سُوَيْدٍ الرَّمْلِيُّ، وَعُمَرُ بْنُ الْخَطَّابِ أَبُو حَفْصٍ، وَحَدِيثُهُ، أَتَمُّ أَنَّ سَعِيدَ بْنَ الْحَكَمِ، حَدَّثَهُمْ قَالَ أَخْبَرَنَا نَافِعُ بْنُ يَزِيدَ، حَدَّثَنِي حَيْوَةُ بْنُ شُرَيْحٍ، أَنَّ أَبَا سَعِيدٍ الْحِمْيَرِيَّ، حَدَّثَهُ عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اتَّقُوا الْمَلاَعِنَ الثَّلاَثَ الْبَرَازَ فِي الْمَوَارِدِ وَقَارِعَةِ الطَّرِيقِ وَالظِّلِّ ‏"‏ ‏.‏\hadithno{26}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: The Messenger of Allah (ﷺ) said: Be on your guard against three things which provoke cursing: easing in the watering places and on the thoroughfares, and in the shade (of the tree)}}
\hadithdefcmd{abudawud}{27}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، وَالْحَسَنُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَحْمَدُ حَدَّثَنَا مَعْمَرٌ، أَخْبَرَنِي أَشْعَثُ، وَقَالَ الْحَسَنُ، عَنْ أَشْعَثَ بْنِ عَبْدِ اللَّهِ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي مُسْتَحَمِّهِ ثُمَّ يَغْتَسِلُ فِيهِ ‏"‏ ‏.‏ قَالَ أَحْمَدُ ‏"‏ ثُمَّ يَتَوَضَّأُ فِيهِ فَإِنَّ عَامَّةَ الْوَسْوَاسِ مِنْهُ ‏"‏ ‏.‏\hadithno{27}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mughaffal: The Messenger of Allah (ﷺ) said: No one of you should make water in his bath and then wash himself there (after urination). The version of Ahmad has: Then performs ablution there, for evil thoughts come from it}}
\hadithdefcmd{abudawud}{28}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، عَنْ دَاوُدَ بْنِ عَبْدِ اللَّهِ، عَنْ حُمَيْدٍ الْحِمْيَرِيِّ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ - قَالَ لَقِيتُ رَجُلاً صَحِبَ النَّبِيَّ صلى الله عليه وسلم كَمَا صَحِبَهُ أَبُو هُرَيْرَةَ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَمْتَشِطَ أَحَدُنَا كُلَّ يَوْمٍ أَوْ يَبُولَ فِي مُغْتَسَلِهِ ‏.‏\hadithno{28}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated A Man from the Companions: Humayd al-Himyari said: I met a man (Companion of the Prophet) who remained in the company of the Prophet (ﷺ) just as AbuHurayrah remained in his company. He then added: The Messenger of Allah (ﷺ) forbade that anyone amongst us should comb (his hair) every day or urinate in the place where he takes a bath}}
\hadithdefcmd{abudawud}{29}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُبَالَ فِي الْجُحْرِ ‏.‏ قَالَ قَالُوا لِقَتَادَةَ مَا يُكْرَهُ مِنَ الْبَوْلِ فِي الْجُحْرِ قَالَ كَانَ يُقَالُ إِنَّهَا مَسَاكِنُ الْجِنِّ ‏.‏\hadithno{29}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Sarjis: The Prophet (ﷺ) prohibited to urinate in a hole. Qatadah (a narrator) was asked about the reason for the disapproval of urinating in a hole. He replied: It is said that these (holes) are the habitats of the jinn}}
\hadithdefcmd{abudawud}{30}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ يُوسُفَ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، حَدَّثَتْنِي عَائِشَةُ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ مِنَ الْغَائِطِ قَالَ ‏ "‏ غُفْرَانَكَ ‏"‏ ‏.‏\hadithno{30}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When the Prophet (ﷺ) came out of the privy, he used to say: "Grant me Thy forgiveness}}
\hadithdefcmd{abudawud}{31}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا أَبَانُ، حَدَّثَنَا يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا بَالَ أَحَدُكُمْ فَلاَ يَمَسَّ ذَكَرَهُ بِيَمِينِهِ وَإِذَا أَتَى الْخَلاَءَ فَلاَ يَتَمَسَّحْ بِيَمِينِهِ وَإِذَا شَرِبَ فَلاَ يَشْرَبْ نَفَسًا وَاحِدًا ‏"‏ ‏.‏\hadithno{31}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (153، 154) Sahih Muslim (267)}\hadithtrans{Narrated Abu Qatadah:The Prophet (sal Allaahu alayhi wa sallam) said: When any one of you urinates, he must not touch his penis with his right hand, and when he goes to relieve himself he must not wipe himself with his right hand (in the privy), and when he drinks, he must not drink in one breath}}
\hadithdefcmd{abudawud}{32}{حَدَّثَنَا مُحَمَّدُ بْنُ آدَمَ بْنِ سُلَيْمَانَ الْمِصِّيصِيُّ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، قَالَ حَدَّثَنِي أَبُو أَيُّوبَ، - يَعْنِي الإِفْرِيقِيَّ - عَنْ عَاصِمٍ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، وَمَعْبَدٍ، عَنْ حَارِثَةَ بْنِ وَهْبٍ الْخُزَاعِيِّ، قَالَ حَدَّثَتْنِي حَفْصَةُ، زَوْجُ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَجْعَلُ يَمِينَهُ لِطَعَامِهِ وَشَرَابِهِ وَثِيَابِهِ وَيَجْعَلُ شِمَالَهُ لِمَا سِوَى ذَلِكَ ‏.‏\hadithno{32}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hafsah, Ummul Mu'minin: The Prophet (ﷺ) used his right hand for taking his food and drink and used his left hand for other purposes}}
\hadithdefcmd{abudawud}{33}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنِي عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ يَدُ رَسُولِ اللَّهِ صلى الله عليه وسلم الْيُمْنَى لِطُهُورِهِ وَطَعَامِهِ وَكَانَتْ يَدُهُ الْيُسْرَى لِخَلاَئِهِ وَمَا كَانَ مِنْ أَذًى ‏.‏\hadithno{33}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) used his right hand for getting water for ablution and taking food, and his left hand for his evacuation and for anything repugnant}}
\hadithdefcmd{abudawud}{34}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ بَزِيعٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، عَنْ سَعِيدٍ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏\hadithno{34}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah, also reported a tradition bearing similar meaning through another chain of transmitters}}
\hadithdefcmd{abudawud}{35}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ ثَوْرٍ، عَنِ الْحُصَيْنِ الْحُبْرَانِيِّ، عَنْ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اكْتَحَلَ فَلْيُوتِرْ مَنْ فَعَلَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ وَمَنِ اسْتَجْمَرَ فَلْيُوتِرْ مَنْ فَعَلَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ وَمَنْ أَكَلَ فَمَا تَخَلَّلَ فَلْيَلْفِظْ وَمَا لاَكَ بِلِسَانِهِ فَلْيَبْتَلِعْ مَنْ فَعَلَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ وَمَنْ أَتَى الْغَائِطَ فَلْيَسْتَتِرْ فَإِنْ لَمْ يَجِدْ إِلاَّ أَنْ يَجْمَعَ كَثِيبًا مِنْ رَمْلٍ فَلْيَسْتَدْبِرْهُ فَإِنَّ الشَّيْطَانَ يَلْعَبُ بِمَقَاعِدِ بَنِي آدَمَ مَنْ فَعَلَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَبُو عَاصِمٍ عَنْ ثَوْرٍ قَالَ حُصَيْنٌ الْحِمْيَرِيُّ وَرَوَاهُ عَبْدُ الْمَلِكِ بْنُ الصَّبَّاحِ عَنْ ثَوْرٍ فَقَالَ أَبُو سَعِيدٍ الْخَيْرُ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو سَعِيدٍ الْخَيْرُ هُوَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{35}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone applies collyrium, he should do it an odd number of times. If he does so, he has done well; but if not, there is no harm. If anyone cleanses himself with pebbles, he should use an odd number. If he does so, he has done well; but if not, there is no harm. If anyone eats, he should throw away what he removes with a toothpick and swallow what sticks to his tongue. If he does so, he has done well; if not, there is no harm. If anyone goes to relieve himself, he should conceal himself, and if all he can do is to collect a heap of send, he should sit with his back to it, for the devil makes sport with the posteriors of the children of Adam. If he does so, he has done well; but if not, there is no harm}}
\hadithdefcmd{abudawud}{36}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، حَدَّثَنَا الْمُفَضَّلُ، - يَعْنِي ابْنَ فَضَالَةَ الْمِصْرِيَّ - عَنْ عَيَّاشِ بْنِ عَبَّاسٍ الْقِتْبَانِيِّ، أَنَّ شُيَيْمَ بْنَ بَيْتَانَ، أَخْبَرَهُ عَنْ شَيْبَانَ الْقِتْبَانِيِّ، قَالَ إِنَّ مَسْلَمَةَ بْنَ مُخَلَّدٍ اسْتَعْمَلَ رُوَيْفِعَ بْنَ ثَابِتٍ، عَلَى أَسْفَلِ الأَرْضِ ‏.‏ قَالَ شَيْبَانُ فَسِرْنَا مَعَهُ مِنْ كُومِ شَرِيكٍ إِلَى عَلْقَمَاءَ أَوْ مِنْ عَلْقَمَاءَ إِلَى كُومِ شَرِيكٍ - يُرِيدُ عَلْقَامَ - فَقَالَ رُوَيْفِعٌ إِنْ كَانَ أَحَدُنَا فِي زَمَنِ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيَأْخُذُ نِضْوَ أَخِيهِ عَلَى أَنَّ لَهُ النِّصْفَ مِمَّا يَغْنَمُ وَلَنَا النِّصْفُ وَإِنْ كَانَ أَحَدُنَا لَيَطِيرُ لَهُ النَّصْلُ وَالرِّيشُ وَلِلآخَرِ الْقَدَحُ ‏.‏ ثُمَّ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا رُوَيْفِعُ لَعَلَّ الْحَيَاةَ سَتَطُولُ بِكَ بَعْدِي فَأَخْبِرِ النَّاسَ أَنَّهُ مَنْ عَقَدَ لِحْيَتَهُ أَوْ تَقَلَّدَ وَتَرًا أَوِ اسْتَنْجَى بِرَجِيعِ دَابَّةٍ أَوْ عَظْمٍ فَإِنَّ مُحَمَّدًا صلى الله عليه وسلم مِنْهُ بَرِيءٌ ‏"‏ ‏.‏\hadithno{36}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ruwayfi' ibn Thabit: Shayban al-Qatbani reported that Maslamah ibn Mukhallad made Ruwayfi' ibn Thabit the governor of the lower parts (of Egypt). He added: We travelled with him from Kum Sharik to Alqamah or from Alqamah to Kum Sharik (the narrator doubts) for Alqam. Ruwayfi' said: Any one of us would borrow a camel during the lifetime of the Prophet (ﷺ) from the other, on condition that he would give him half the booty, and the other half he would retain himself. Further, one of us received an arrowhead and a feather, and the other an arrow-shaft as a share from the booty. He then reported: The Messenger of Allah (ﷺ) said: You may live for a long time after I am gone, Ruwayfi', so, tell people that if anyone ties his beard or wears round his neck a string to ward off the evil eye, or cleanses himself with animal dung or bone, Muhammad has nothing to do with him}}
\hadithdefcmd{abudawud}{37}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ، حَدَّثَنَا مُفَضَّلٌ، عَنْ عَيَّاشٍ، أَنَّ شُيَيْمَ بْنَ بَيْتَانَ، أَخْبَرَهُ بِهَذَا الْحَدِيثِ، أَيْضًا عَنْ أَبِي سَالِمٍ الْجَيْشَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، يَذْكُرُ ذَلِكَ وَهُوَ مَعَهُ مُرَابِطٌ بِحِصْنِ بَابِ أَلْيُونَ ‏.‏ قَالَ أَبُو دَاوُدَ حِصْنُ أَلْيُونَ عَلَى جَبَلٍ بِالْفُسْطَاطِ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ شَيْبَانُ بْنُ أُمَيَّةَ يُكْنَى أَبَا حُذَيْفَةَ ‏.‏\hadithno{37}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{This tradition has also been narrated by Abu Salim al-Jaishani on the authority of 'Abd Allaah b. 'Amr. He narrated this tradition at the time when he besieged the fort at the gate of Alyun. Abu Dawud said:The fort of Alyun lies at the mountain in Fustat. Abu Dawud said: The kunyah (surname) of Shaiban b. Umayyah is Abu Hudhaifah}}
\hadithdefcmd{abudawud}{38}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَتَمَسَّحَ بِعَظْمٍ أَوْ بَعْرٍ ‏.‏\hadithno{38}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (263)}\hadithtrans{Narrated Jabir b. 'Abd Allaah:The Apostle of Allaah ( sal Allaahu alayhi wa sallam ) forbade us to use a bone or dung for wiping}}
\hadithdefcmd{abudawud}{39}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحِمْصِيُّ، حَدَّثَنَا ابْنُ عَيَّاشٍ، عَنْ يَحْيَى بْنِ أَبِي عَمْرٍو السَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الدَّيْلَمِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَدِمَ وَفْدُ الْجِنِّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا مُحَمَّدُ انْهَ أُمَّتَكَ أَنْ يَسْتَنْجُوا بِعَظْمٍ أَوْ رَوْثَةٍ أَوْ حُمَمَةٍ فَإِنَّ اللَّهَ تَعَالَى جَعَلَ لَنَا فِيهَا رِزْقًا ‏.‏ قَالَ فَنَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ ذَلِكَ ‏.‏\hadithno{39}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: A deputation of the jinn came to the Prophet (ﷺ) and said: O Muhammad, forbid your community to cleans themselves with a bone or dung or charcoal, for in them Allah has provided sustenance for us. So the Prophet (ﷺ) forbade them to do so}}
\hadithdefcmd{abudawud}{40}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ مُسْلِمِ بْنِ قُرْطٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا ذَهَبَ أَحَدُكُمْ إِلَى الْغَائِطِ فَلْيَذْهَبْ مَعَهُ بِثَلاَثَةِ أَحْجَارٍ يَسْتَطِيبُ بِهِنَّ فَإِنَّهَا تُجْزِئُ عَنْهُ ‏"‏ ‏.‏\hadithno{40}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: When any of you goes to relieve himself, he should take with him three stones to cleans himself, for they will be enough for him}}
\hadithdefcmd{abudawud}{41}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عَمْرِو بْنِ خُزَيْمَةَ، عَنْ عُمَارَةَ بْنِ خُزَيْمَةَ، عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ الاِسْتِطَابَةِ فَقَالَ ‏ "‏ بِثَلاَثَةِ أَحْجَارٍ لَيْسَ فِيهَا رَجِيعٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ كَذَا رَوَاهُ أَبُو أُسَامَةَ وَابْنُ نُمَيْرٍ عَنْ هِشَامٍ يَعْنِي ابْنَ عُرْوَةَ ‏.‏\hadithno{41}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Khuzaymah ibn Thabit: The Prophet (ﷺ) was asked about cleansing (after relieving oneself). He said: (One should cleanse oneself) with three stones which should be free from dung. Abu Dawud said: A similar tradition has been narrated by Abu Usamah and Ibn Numair from Hisham}}
\hadithdefcmd{abudawud}{42}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَخَلَفُ بْنُ هِشَامٍ الْمُقْرِئُ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَحْيَى التَّوْأَمُ، ح وَحَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ أَخْبَرَنَا أَبُو يَعْقُوبَ التَّوْأَمُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ بَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَامَ عُمَرُ خَلْفَهُ بِكُوزٍ مِنْ مَاءٍ فَقَالَ ‏"‏ مَا هَذَا يَا عُمَرُ ‏"‏ ‏.‏ فَقَالَ هَذَا مَاءٌ تَتَوَضَّأُ بِهِ ‏.‏ قَالَ ‏"‏ مَا أُمِرْتُ كُلَّمَا بُلْتُ أَنْ أَتَوَضَّأَ وَلَوْ فَعَلْتُ لَكَانَتْ سُنَّةً ‏"‏ ‏.‏\hadithno{42}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) urinated and Umar was standing behind him with a jug of water. He said: What is this, Umar? He replied: Water for you to perform ablution with. He said: I have not been commanded to perform ablution every time I urinate. If I were to do so, it would become a sunnah}}
\hadithdefcmd{abudawud}{43}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، - يَعْنِي الْوَاسِطِيَّ - عَنْ خَالِدٍ، - يَعْنِي الْحَذَّاءَ - عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ حَائِطًا وَمَعَهُ غُلاَمٌ مَعَهُ مِيضَأَةٌ وَهُوَ أَصْغَرُنَا فَوَضَعَهَا عِنْدَ السِّدْرَةِ فَقَضَى حَاجَتَهُ فَخَرَجَ عَلَيْنَا وَقَدِ اسْتَنْجَى بِالْمَاءِ ‏.‏\hadithno{43}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (152) Sahih Muslim (270)}\hadithtrans{Narrated Anas b. Malik :The Apostle of Allaah ( sal Allaahu alayhi wa sallam ) entered a park. He was accompanied by a boy who had a jug of water with him. He was the youngest of us. He placed it near the lote-tree. He ( the Prophet, sal Allaahu alayhi wa sallam ) relieved himself. He came to us after he had cleansed himself with water}}
\hadithdefcmd{abudawud}{44}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ يُونُسَ بْنِ الْحَارِثِ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ نَزَلَتْ هَذِهِ الآيَةُ فِي أَهْلِ قُبَاءَ ‏\{‏ فِيهِ رِجَالٌ يُحِبُّونَ أَنْ يَتَطَهَّرُوا ‏\}‏ قَالَ كَانُوا يَسْتَنْجُونَ بِالْمَاءِ فَنَزَلَتْ فِيهِمْ هَذِهِ الآيَةُ ‏.‏\hadithno{44}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The following verse was revealed in connection with the people of Quba': "In it are men who love to be purified" (ix.108). He (AbuHurayrah) said: They used to cleanse themselves with water after easing. So the verse was revealed in connection with them}}
\hadithdefcmd{abudawud}{45}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا شَرِيكٌ، وَهَذَا، لَفْظُهُ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، - يَعْنِي الْمُخَرِّمِيَّ - حَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ إِبْرَاهِيمَ بْنِ جَرِيرٍ، عَنِ الْمُغِيرَةِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَتَى الْخَلاَءَ أَتَيْتُهُ بِمَاءٍ فِي تَوْرٍ أَوْ رَكْوَةٍ فَاسْتَنْجَى ‏.‏ قَالَ أَبُو دَاوُدَ فِي حَدِيثِ وَكِيعٍ ثُمَّ مَسَحَ يَدَهُ عَلَى الأَرْضِ ثُمَّ أَتَيْتُهُ بِإِنَاءٍ آخَرَ فَتَوَضَّأَ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ الأَسْوَدِ بْنِ عَامِرٍ أَتَمُّ ‏.‏\hadithno{45}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah : When the Prophet (sal Allaahu alayhi wa sallam ) went to the privy, I took to him water in a small vessel or a skin, and he cleansed himself. He then wiped his hand on the ground. I then took to him another vessel and he performed ablution. Abu Dawud said : The tradition is transmitted by al-Aswad b. 'Amir is more perfect}}
\hadithdefcmd{abudawud}{46}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَرْفَعُهُ قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ، عَلَى الْمُؤْمِنِينَ لأَمَرْتُهُمْ بِتَأْخِيرِ الْعِشَاءِ وَبِالسِّوَاكِ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏\hadithno{46}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (887، 7240) Sahih Muslim (252)}\hadithtrans{Narrated Abu Hurayrah :(the Prophet, sal Allaahu alayhi wa sallam ) as saying : Were it not that I might oeverburdern the believers, I would order them to delay the night ('isha ) prayer and use the tooth-stick at the time of every prayer}}
\hadithdefcmd{abudawud}{47}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِالسِّوَاكِ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏ قَالَ أَبُو سَلَمَةَ فَرَأَيْتُ زَيْدًا يَجْلِسُ فِي الْمَسْجِدِ وَإِنَّ السِّوَاكَ مِنْ أُذُنِهِ مَوْضِعُ الْقَلَمِ مِنْ أُذُنِ الْكَاتِبِ فَكُلَّمَا قَامَ إِلَى الصَّلاَةِ اسْتَاكَ ‏.‏\hadithno{47}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zayd ibn Khalid al-Juhani: I heard the Messenger of Allah (ﷺ) say: Were it not hard on my ummah, I would order them to use the tooth-stick at the time of every prayer. AbuSalamah said: Zayd ibn Khalid used to attend the prayers in the mosque with his tooth-stick on his ear where a clerk carries a pen, and whenever he got up for prayer he used it}}
\hadithdefcmd{abudawud}{48}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قُلْتُ أَرَأَيْتَ تَوَضُّؤَ ابْنِ عُمَرَ لِكُلِّ صَلاَةٍ طَاهِرًا وَغَيْرَ طَاهِرٍ عَمَّ ذَاكَ فَقَالَ حَدَّثَتْنِيهِ أَسْمَاءُ بِنْتُ زَيْدِ بْنِ الْخَطَّابِ أَنَّ عَبْدَ اللَّهِ بْنَ حَنْظَلَةَ بْنِ أَبِي عَامِرٍ حَدَّثَهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُمِرَ بِالْوُضُوءِ لِكُلِّ صَلاَةٍ طَاهِرًا وَغَيْرَ طَاهِرٍ فَلَمَّا شَقَّ ذَلِكَ عَلَيْهِ أُمِرَ بِالسِّوَاكِ لِكُلِّ صَلاَةٍ فَكَانَ ابْنُ عُمَرَ يَرَى أَنَّ بِهِ قُوَّةً فَكَانَ لاَ يَدَعُ الْوُضُوءَ لِكُلِّ صَلاَةٍ ‏.‏ قَالَ أَبُو دَاوُدَ إِبْرَاهِيمُ بْنُ سَعْدٍ رَوَاهُ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ قَالَ عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ ‏.‏\hadithno{48}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah b. 'Abd Allah b. 'Umar: Muhammad ibn Yahya ibn Habban asked Abdullah ibn Abdullah ibn Umar about the reason for Ibn Umar's performing ablution for every prayer, whether he was with or without ablution. He replied: Asma', daughter of Zayd ibn al-Khattab, reported to me that Abdullah ibn Hanzalah ibn AbuAmir narrated to her that the Messenger of Allah (ﷺ) was earlier commanded to perform ablution for every prayer whether or not he was with ablution. When it became a burden for him, he was ordered to use tooth-stick for every prayer. As Ibn Umar thought that he had the strength (to perform the ablution for every prayer), he did not give up performing ablution for every prayer. Abu Dawud said: Ibrahim b. Sa'd narrated this tradition on the authority of Muhammad b. Ishaq, and there he mentions the name of 'Ubaid Allah b. 'Abd Allah (instead of 'Abd Allah b. 'Abd Allah b. 'Umar)}}
\hadithdefcmd{abudawud}{49}{حَدَّثَنَا مُسَدَّدٌ، وَسُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ مُسَدَّدٌ قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم نَسْتَحْمِلُهُ فَرَأَيْتُهُ يَسْتَاكُ عَلَى لِسَانِهِ - قَالَ أَبُو دَاوُدَ وَقَالَ سُلَيْمَانُ قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَسْتَاكُ وَقَدْ وَضَعَ السِّوَاكَ عَلَى طَرَفِ لِسَانِهِ - وَهُوَ يَقُولُ ‏ "‏ إِهْ إِهْ ‏"‏ ‏.‏ يَعْنِي يَتَهَوَّعُ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مُسَدَّدٌ فَكَانَ حَدِيثًا طَوِيلاً اخْتَصَرْتُهُ ‏.‏\hadithno{49}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (244) Sahih Muslim (254)}\hadithtrans{Narrated Abu Burdah: On the authority of his father ( Abu Musa al-Ash'ari), reported (according to the version of Musaddad) : We came to the Apostle of Allaah (sal Allaahu alayhi wa sallam) to provide us with a mount, and found him using the tooth-stick, its one end being at his tongue (i.e. he wsa rinsing his mouth). According to the version of Sulaiman it goes : I entered upon the Prophet (sal Allaahu alayhi wa sallam ) who was using the tooth-stick, and had it placed at one side of his tongue, producing a gurgling sound. Abu Dawud said : Musaddad said that the tradition was a lengthy but he shortened it}}
\hadithdefcmd{abudawud}{50}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا عَنْبَسَةُ بْنُ عَبْدِ الْوَاحِدِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَنُّ وَعِنْدَهُ رَجُلاَنِ أَحَدُهُمَا أَكْبَرُ مِنَ الآخَرِ فَأُوحِيَ إِلَيْهِ فِي فَضْلِ السِّوَاكِ ‏ "‏ أَنْ كَبِّرْ ‏"‏ ‏.‏ أَعْطِ السِّوَاكَ أَكْبَرَهُمَا ‏.‏ قَالَ أَحْمَدُ - هُوَ ابْنُ حَزْمٍ - قَالَ لَنَا أَبُو سَعِيدٍ هُوَ ابْنُ الأَعْرَابِيِّ هَذَا مِمَّا تَفَرَّدَ بِهِ أَهْلُ الْمَدِينَةِ ‏.‏\hadithno{50}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) was using the tooth-stick, when two men, one older than the other, were with him. A revelation came to him about the merit of using the tooth-stick. He was asked to show proper respect and give it to the elder of the two}}
\hadithdefcmd{abudawud}{51}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ مِسْعَرٍ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، قَالَ قُلْتُ لِعَائِشَةَ بِأَىِّ شَىْءٍ كَانَ يَبْدَأُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ بَيْتَهُ قَالَتْ بِالسِّوَاكِ ‏.‏\hadithno{51}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (253)}\hadithtrans{Shuraih asked 'Aishah:"What would the Messenger of Allah (ﷺ) do as soon as he entered the house?" She replied: "(He would use) the siwak}}
\hadithdefcmd{abudawud}{52}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا عَنْبَسَةُ بْنُ سَعِيدٍ الْكُوفِيُّ الْحَاسِبُ، حَدَّثَنِي كَثِيرٌ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يَسْتَاكُ فَيُعْطِينِي السِّوَاكَ لأَغْسِلَهُ فَأَبْدَأُ بِهِ فَأَسْتَاكُ ثُمَّ أَغْسِلُهُ وَأَدْفَعُهُ إِلَيْهِ ‏.‏\hadithno{52}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated:"The Prophet of Allah (ﷺ) would clean his teeth with the Siwak, then he would give me the Siwak in order to wash it. So I would first use it myself, then wash it and return it}}
\hadithdefcmd{abudawud}{53}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا وَكِيعٌ، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ طَلْقِ بْنِ حَبِيبٍ، عَنِ ابْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَشْرٌ مِنَ الْفِطْرَةِ قَصُّ الشَّارِبِ وَإِعْفَاءُ اللِّحْيَةِ وَالسِّوَاكُ وَالاِسْتِنْشَاقُ بِالْمَاءِ وَقَصُّ الأَظْفَارِ وَغَسْلُ الْبَرَاجِمِ وَنَتْفُ الإِبِطِ وَحَلْقُ الْعَانَةِ وَانْتِقَاصُ الْمَاءِ ‏"‏ ‏.‏ يَعْنِي الاِسْتِنْجَاءَ بِالْمَاءِ ‏.‏ قَالَ زَكَرِيَّا قَالَ مُصْعَبٌ وَنَسِيتُ الْعَاشِرَةَ إِلاَّ أَنْ تَكُونَ الْمَضْمَضَةَ ‏.‏\hadithno{53}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: Ten are the acts according to fitrah (nature): clipping the moustache, letting the beard grow, using the tooth-stick, cleansing the nose (Al-Istinshaq) with water, cutting the nails, washing the finger joints, plucking the hair under the arm-pits, shaving the pubes, and cleansing one's private parts (after easing or urinating) with water. The narrator said: I have forgotten the tenth, but it may have been rinsing the mouth}}
\hadithdefcmd{abudawud}{54}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَدَاوُدُ بْنُ شَبِيبٍ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَلَمَةَ بْنِ مُحَمَّدِ بْنِ عَمَّارِ بْنِ يَاسِرٍ، قَالَ مُوسَى عَنْ أَبِيهِ، - وَقَالَ دَاوُدُ عَنْ عَمَّارِ بْنِ يَاسِرٍ، - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ مِنَ الْفِطْرَةِ الْمَضْمَضَةَ وَالاِسْتِنْشَاقَ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرْ إِعْفَاءَ اللِّحْيَةِ وَزَادَ ‏"‏ وَالْخِتَانَ ‏"‏ ‏.‏ قَالَ ‏"‏ وَالاِنْتِضَاحَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ ‏"‏ انْتِقَاصَ الْمَاءِ ‏"‏ ‏.‏ يَعْنِي الاِسْتِنْجَاءَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُوِيَ نَحْوُهُ عَنِ ابْنِ عَبَّاسٍ وَقَالَ خَمْسٌ كُلُّهَا فِي الرَّأْسِ وَذَكَرَ فِيهَا الْفَرْقَ وَلَمْ يَذْكُرْ إِعْفَاءَ اللِّحْيَةِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُوِيَ نَحْوُ حَدِيثِ حَمَّادٍ عَنْ طَلْقِ بْنِ حَبِيبٍ وَمُجَاهِدٍ وَعَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ قَوْلُهُمْ وَلَمْ يَذْكُرُوا إِعْفَاءَ اللِّحْيَةِ ‏.‏ وَفِي حَدِيثِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي مَرْيَمَ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِيهِ وَإِعْفَاءُ اللِّحْيَةِ وَعَنْ إِبْرَاهِيمَ النَّخَعِيِّ نَحْوُهُ وَذَكَرَ إِعْفَاءَ اللِّحْيَةِ وَالْخِتَانَ ‏.‏\hadithno{54}\hadithgrade{Al-Albani: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ammar b. Yasir: The Apostle of Allaah ( sal Allaahu alayhi wa sallam ) said : The rinsing of mouth and snuffing up water in the nose are acts that bear the characteristics of fitrah (nature). He then narrated a similar tradition (as reported by Aishah), but he did not mention the words "letting the beard grow". He added the words "circumcision" and "sprinkling water on the private part of the body". He did not mention the words "cleansing oneself after easing". Abu Dawud said : A similar tradition has been reported on the authority of Ibn 'Abbas. He mentioned only five sunnahs all relating to the head, one of them being parting of the hair; it did not include wearing the beard. Abu Dawud said: The tradition as reported by Hammad has also been transmitted by Talq b. Habib , Mujahid, and Bakr b. 'Abd Allaah b. al-Muzani as their own statement ( not as a tradition from the Prophet, sal Allaahu alayhi wa sallam ).They did not mention the words "letting the beard grow". The version transmitted by Muhammad b. Abd Allaah b. Abi Maryam, Abu Salamah, and Abu Hurairah from the Prophet ( sal Allaahu alayhi wa sallam ) mentions the words "letting the beard grow". A similar tradition has been reported by Ibrahim al-Nakha'i. He mentioned the words "wearing the beard and circumcision}}
\hadithdefcmd{abudawud}{55}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَحُصَيْنٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ مِنَ اللَّيْلِ يَشُوصُ فَاهُ بِالسِّوَاكِ ‏.‏\hadithno{55}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (245، 889) Sahih Muslim (255)}\hadithtrans{Narrated Hudhaifah:When the Apostle of Allaah (sal Allaahu alayhi wa sallam) got up during the night (to pray), he cleansed his mouth with the tooth-stick}}
\hadithdefcmd{abudawud}{56}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا بَهْزُ بْنُ حَكِيمٍ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُوضَعُ لَهُ وَضُوءُهُ وَسِوَاكُهُ فَإِذَا قَامَ مِنَ اللَّيْلِ تَخَلَّى ثُمَّ اسْتَاكَ ‏.‏\hadithno{56}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Ablution water and tooth-stick were placed by the side of the Prophet (ﷺ). When he got up during the night (for prayer), he relieved himself, then he used the tooth-stick}}
\hadithdefcmd{abudawud}{57}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا هَمَّامٌ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أُمِّ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَرْقُدُ مِنْ لَيْلٍ وَلاَ نَهَارٍ فَيَسْتَيْقِظُ إِلاَّ تَسَوَّكَ قَبْلَ أَنْ يَتَوَضَّأَ ‏.‏\hadithno{57}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) did not get up after sleeping by night or by day without using the tooth-stick before performing ablution}}
\hadithdefcmd{abudawud}{58}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حُصَيْنٌ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ بِتُّ لَيْلَةً عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَلَمَّا اسْتَيْقَظَ مِنْ مَنَامِهِ أَتَى طَهُورَهُ فَأَخَذَ سِوَاكَهُ فَاسْتَاكَ ثُمَّ تَلاَ هَذِهِ الآيَاتِ ‏\{‏ إِنَّ فِي خَلْقِ السَّمَوَاتِ وَالأَرْضِ وَاخْتِلاَفِ اللَّيْلِ وَالنَّهَارِ لآيَاتٍ لأُولِي الأَلْبَابِ ‏\}‏ حَتَّى قَارَبَ أَنْ يَخْتِمَ السُّورَةَ أَوْ خَتَمَهَا ثُمَّ تَوَضَّأَ فَأَتَى مُصَلاَّهُ فَصَلَّى رَكْعَتَيْنِ ثُمَّ رَجَعَ إِلَى فِرَاشِهِ فَنَامَ مَا شَاءَ اللَّهُ ثُمَّ اسْتَيْقَظَ فَفَعَلَ مِثْلَ ذَلِكَ ثُمَّ رَجَعَ إِلَى فِرَاشِهِ فَنَامَ ثُمَّ اسْتَيْقَظَ فَفَعَلَ مِثْلَ ذَلِكَ ثُمَّ رَجَعَ إِلَى فِرَاشِهِ فَنَامَ ثُمَّ اسْتَيْقَظَ فَفَعَلَ مِثْلَ ذَلِكَ كُلُّ ذَلِكَ يَسْتَاكُ وَيُصَلِّي رَكْعَتَيْنِ ثُمَّ أَوْتَرَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ فُضَيْلٍ عَنْ حُصَيْنٍ قَالَ فَتَسَوَّكَ وَتَوَضَّأَ وَهُوَ يَقُولُ ‏\{‏ إِنَّ فِي خَلْقِ السَّمَوَاتِ وَالأَرْضِ ‏\}‏ حَتَّى خَتَمَ السُّورَةَ ‏.‏\hadithno{58}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (763)}\hadithtrans{Narrated Ibn 'Abbas: I spent a night with the Prophet (sal Allaahu alayhi wa sallam). When he woke up from his sleep (in the latter part of the night for prayer) he came to his ablution water. He took the tooth-stick and used it. He then recited the verse: "Verily in the creation of the heavens and the earth and the alternation of the night and the day are tokens (of His Sovereignty) for men of understanding" (iii-190). He recited these verses up to the end of the chapter or he finished the whole chapter. He then performed ablution and came to the place of prayer. He then said two rak'ahs of prayer. He then lay down on the bed and slept as much as Allaah wished. He then got up and did the same. He then lay down and slept. He then got up and did the same. Every time he used the tooth-stick and offered two rak'ah of prayer. He then offered the prayer known as witr. Abu Dawud said: Fudail on the authority if Husain reported the wording: He then used the tooth-stick and performed ablution while he was reciting the verses: "Verily in the creation of the heaves and the earth..." until he finished the chapter}}
\hadithdefcmd{abudawud}{59}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقْبَلُ اللَّهُ عَزَّ وَجَلَّ صَدَقَةً مِنْ غُلُولٍ وَلاَ صَلاَةً بِغَيْرِ طُهُورٍ ‏"‏ ‏.‏\hadithno{59}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbulMalih: The Prophet (ﷺ) said: Allah does not accept charity from goods acquired by embezzlement as He does not accept prayer without purification}}
\hadithdefcmd{abudawud}{60}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقْبَلُ اللَّهُ صَلاَةَ أَحَدِكُمْ إِذَا أَحْدَثَ حَتَّى يَتَوَضَّأَ ‏"‏ ‏.‏\hadithno{60}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (135) Sahih Muslim (225)}\hadithtrans{Narrated Abu Hurairah:The Apostle of Allaah ( sal Allaahu alayhi wa sallam ) said : Allaah, the Exalted, does not accept the prayer of any of you when you are defiled until you performed ablution}}
\hadithdefcmd{abudawud}{61}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ ابْنِ عَقِيلٍ، عَنْ مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِفْتَاحُ الصَّلاَةِ الطُّهُورُ وَتَحْرِيمُهَا التَّكْبِيرُ وَتَحْلِيلُهَا التَّسْلِيمُ ‏"‏ ‏.‏\hadithno{61}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The key to prayer is purification; its beginning is takbir and its end is taslim}}
\hadithdefcmd{abudawud}{62}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زِيَادٍ، - قَالَ أَبُو دَاوُدَ وَأَنَا لِحَدِيثِ ابْنِ يَحْيَى، أَتْقَنُ - عَنْ غُطَيْفٍ، - وَقَالَ مُحَمَّدٌ عَنْ أَبِي غُطَيْفٍ الْهُذَلِيِّ، - قَالَ كُنْتُ عِنْدَ عَبْدِ اللَّهِ بْنِ عُمَرَ فَلَمَّا نُودِيَ بِالظُّهْرِ تَوَضَّأَ فَصَلَّى فَلَمَّا نُودِيَ بِالْعَصْرِ تَوَضَّأَ فَقُلْتُ لَهُ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ تَوَضَّأَ عَلَى طُهْرٍ كَتَبَ اللَّهُ لَهُ عَشْرَ حَسَنَاتٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا حَدِيثُ مُسَدَّدٍ وَهُوَ أَتَمُّ ‏.‏\hadithno{62}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: AbuGhutayf al-Hudhali reported: I was in the company of Ibn Umar. When the call was made for the noon (zuhr) prayer, he performed ablution and said the prayer. When the call for the afternoon ('asr) prayer was made, he again performed ablution. Thus I asked him (about the reason of performing ablution). He replied: The Messenger of Allah (ﷺ) said: For a man who performs ablution in a state of purity, ten virtuous deeds will be recorded (in his favour). AbuDawud said: This is the tradition narrated by Musaddad, and it is more perfect}}
\hadithdefcmd{abudawud}{63}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَالْحَسَنُ بْنُ عَلِيٍّ، وَغَيْرُهُمْ، قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمَاءِ وَمَا يَنُوبُهُ مِنَ الدَّوَابِّ وَالسِّبَاعِ فَقَالَ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ الْمَاءُ قُلَّتَيْنِ لَمْ يَحْمِلِ الْخَبَثَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا لَفْظُ ابْنِ الْعَلاَءِ وَقَالَ عُثْمَانُ وَالْحَسَنُ بْنُ عَلِيٍّ عَنْ مُحَمَّدِ بْنِ عَبَّادِ بْنِ جَعْفَرٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ الصَّوَابُ ‏.‏\hadithno{63}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ), was asked about water (in desert country) and what is frequented by animals and wild beasts. He replied: When there is enough water to fill two pitchers, it bears no impurity}}
\hadithdefcmd{abudawud}{64}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، - قَالَ أَبُو كَامِلٍ ابْنُ الزُّبَيْرِ - عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الْمَاءِ يَكُونُ فِي الْفَلاَةِ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{64}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Abd Allaah b. 'Umar:The Messenger of Allaah (sal Allaahu alayhi wa sallam) was asked about water in desert. He then narrated a similar tradition (as mentioned above)}}
\hadithdefcmd{abudawud}{65}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَاصِمُ بْنُ الْمُنْذِرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ حَدَّثَنِي أَبِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ الْمَاءُ قُلَّتَيْنِ فَإِنَّهُ لاَ يَنْجُسُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ حَمَّادُ بْنُ زَيْدٍ وَقَفَهُ عَنْ عَاصِمٍ ‏.‏\hadithno{65}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdullah b. 'Umar: The Apostle of Allaah ( sal Allaahu alayhi wa sallam ) said: When there is enough water to fill two pitchers, it does not become impure. Abu Dawud said : Hammad b. Zaid has narrated this tradition on the authority of 'Asim ( without any reference to the Prophet)}}
\hadithdefcmd{abudawud}{66}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَالْحَسَنُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ رَافِعِ بْنِ خَدِيجٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَتَوَضَّأُ مِنْ بِئْرِ بُضَاعَةَ وَهِيَ بِئْرٌ يُطْرَحُ فِيهَا الْحِيَضُ وَلَحْمُ الْكِلاَبِ وَالنَّتْنُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَاءُ طَهُورٌ لاَ يُنَجِّسُهُ شَىْءٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ بَعْضُهُمْ عَبْدُ الرَّحْمَنِ بْنُ رَافِعٍ ‏.‏\hadithno{66}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: The people asked the Messenger of Allah (ﷺ): Can we perform ablution out of the well of Buda'ah, which is a well into which menstrual clothes, dead dogs and stinking things were thrown? He replied: Water is pure and is not defiled by anything}}
\hadithdefcmd{abudawud}{67}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، وَعَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيَّانِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَلِيطِ بْنِ أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ رَافِعٍ الأَنْصَارِيِّ، ثُمَّ الْعَدَوِيِّ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يُقَالُ لَهُ إِنَّهُ يُسْتَقَى لَكَ مِنْ بِئْرِ بُضَاعَةَ وَهِيَ بِئْرٌ يُلْقَى فِيهَا لُحُومُ الْكِلاَبِ وَالْمَحَايِضُ وَعَذِرُ النَّاسِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَاءَ طَهُورٌ لاَ يُنَجِّسُهُ شَىْءٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَسَمِعْتُ قُتَيْبَةَ بْنَ سَعِيدٍ قَالَ سَأَلْتُ قَيِّمَ بِئْرِ بُضَاعَةَ عَنْ عُمْقِهَا قَالَ أَكْثَرُ مَا يَكُونُ فِيهَا الْمَاءُ إِلَى الْعَانَةِ ‏.‏ قُلْتُ فَإِذَا نَقَصَ قَالَ دُونَ الْعَوْرَةِ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَدَّرْتُ أَنَا بِئْرَ بُضَاعَةَ بِرِدَائِي مَدَدْتُهُ عَلَيْهَا ثُمَّ ذَرَعْتُهُ فَإِذَا عَرْضُهَا سِتَّةُ أَذْرُعٍ وَسَأَلْتُ الَّذِي فَتَحَ لِي بَابَ الْبُسْتَانِ فَأَدْخَلَنِي إِلَيْهِ هَلْ غُيِّرَ بِنَاؤُهَا عَمَّا كَانَتْ عَلَيْهِ قَالَ لاَ ‏.‏ وَرَأَيْتُ فِيهَا مَاءً مُتَغَيِّرَ اللَّوْنِ ‏.‏\hadithno{67}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: I heard that the people asked the Prophet of Allah (ﷺ): Water is brought for you from the well of Buda'ah. It is a well in which dead dogs, menstrual clothes and excrement of people are thrown. The Messenger of Allah (ﷺ) replied: Verily water is pure and is not defiled by anything. Abu Dawud said I heard Qutaibah b. Sa'id say: I asked the person in charge of the well of Bud'ah about the depth of the well. He replied: At most the water reaches pubes. Then I asked: Where does it reach when its level goes down ? He replied: Below the private part of the body. Abu Dawud said: I measured the breadth of the well of Buda'ah with my sheet which I stretched over it. I them measured it with the hand. It measured six cubits in breadth. I then asked the man who opened the door of garden for me and admitted me to it: Has the condition of this well changed from what it had originally been in the past ? He replied: No. I saw the color of water in this well had changed}}
\hadithdefcmd{abudawud}{68}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا سِمَاكٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ اغْتَسَلَ بَعْضُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم فِي جَفْنَةٍ فَجَاءَ النَّبِيُّ صلى الله عليه وسلم لِيَتَوَضَّأَ مِنْهَا - أَوْ يَغْتَسِلَ - فَقَالَتْ لَهُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ جُنُبًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَاءَ لاَ يَجْنُبُ ‏"‏ ‏.‏\hadithno{68}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: One of the wives of the Prophet (ﷺ) took a bath from a large bowl. The Prophet (ﷺ) wanted to perform ablution or take from the water left over. She said to him: O Prophet of Allah, verily I was sexually defiled. The Prophet said: Water not defiled}}
\hadithdefcmd{abudawud}{69}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زَائِدَةُ، فِي حَدِيثِ هِشَامٍ عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ ثُمَّ يَغْتَسِلُ مِنْهُ ‏"‏ ‏.‏\hadithno{69}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (282)}\hadithtrans{Narrated Abu Hurairah :The Prophet ( sal Allaahu alayhi wa sallam ) said : None amongst you should urinate in stagnant water , and then wash in it}}
\hadithdefcmd{abudawud}{70}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ وَلاَ يَغْتَسِلْ فِيهِ مِنَ الْجَنَابَةِ ‏"‏ ‏.‏\hadithno{70}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: None amongst you should urinate in standing water, then wash in it after sexual defilement}}
\hadithdefcmd{abudawud}{71}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زَائِدَةُ، - فِي حَدِيثِ هِشَامٍ - عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ طُهُورُ إِنَاءِ أَحَدِكُمْ إِذَا وَلَغَ فِيهِ الْكَلْبُ أَنْ يُغْسَلَ سَبْعَ مِرَارٍ أُولاَهُنَّ بِتُرَابٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ قَالَ أَيُّوبُ وَحَبِيبُ بْنُ الشَّهِيدِ عَنْ مُحَمَّدٍ ‏.‏\hadithno{71}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (279)}\hadithtrans{Narrated Abu Hurairah: The Prophet (sal Allaahu alayhi wa sallam) said: The purification of the utensil belonging to any one of you, after it has been licked by a dog, consists of washing it seven times, using sand in the first instance. Abu Dawud said : A similar tradition has been narrated by Abu Ayyub and Habib b. al-Shahid on the authority of Muhammad}}
\hadithdefcmd{abudawud}{72}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ يَعْنِي ابْنَ سُلَيْمَانَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، جَمِيعًا عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، بِمَعْنَاهُ وَلَمْ يَرْفَعَاهُ زَادَ ‏ "‏ وَإِذَا وَلَغَ الْهِرُّ غُسِلَ مَرَّةً ‏"‏ ‏.‏\hadithno{72}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A similar tradition has been transmitted by Abu Hurairah through a different chain of narrators. But this version has been narrated as a statement of Abu Hurairah himself and not attributed to the Prophet (sal Allaahu alayhi wa sallam ). The version has the addition of the words :"If the cat licks (a utensil), it should be washed once}}
\hadithdefcmd{abudawud}{73}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، أَنَّ مُحَمَّدَ بْنَ سِيرِينَ، حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي الإِنَاءِ فَاغْسِلُوهُ سَبْعَ مَرَّاتٍ السَّابِعَةُ بِالتُّرَابِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَأَمَّا أَبُو صَالِحٍ وَأَبُو رَزِينٍ وَالأَعْرَجُ وَثَابِتٌ الأَحْنَفُ وَهَمَّامُ بْنُ مُنَبِّهٍ وَأَبُو السُّدِّيِّ عَبْدُ الرَّحْمَنِ رَوَوْهُ عَنْ أَبِي هُرَيْرَةَ وَلَمْ يَذْكُرُوا التُّرَابَ ‏.‏\hadithno{73}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah : The Prophet (sal Allaahu alayhi wa sallam) as saying : When a dog licks a (thing contained in a) utensil you must wash it seven times, using earth (sand) for the seventh time. Abu Dawud said : This tradition has been transmitted by another chain of narrators in which there is no mention of earth}}
\hadithdefcmd{abudawud}{74}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، حَدَّثَنَا أَبُو التَّيَّاحِ، عَنْ مُطَرِّفٍ، عَنِ ابْنِ مُغَفَّلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ ثُمَّ قَالَ ‏"‏ مَا لَهُمْ وَلَهَا ‏"‏ ‏.‏ فَرَخَّصَ فِي كَلْبِ الصَّيْدِ وَفِي كَلْبِ الْغَنَمِ وَقَالَ ‏"‏ إِذَا وَلَغَ الْكَلْبُ فِي الإِنَاءِ فَاغْسِلُوهُ سَبْعَ مِرَارٍ وَالثَّامِنَةُ عَفِّرُوهُ بِالتُّرَابِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَكَذَا قَالَ ابْنُ مُغَفَّلٍ ‏.‏\hadithno{74}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (280)}\hadithtrans{Narrated Ibn Mughaffal: The Messenger of Allaah (sal Allaahu alayhi wa sallam) ordered the killing of the dogs, and then said: Why are they (people) after them (dogs)? and then granted permission (to keep) for hunting and for (the security) of the herd, and said : When the dog licks the utensil wash it seven times, and rub it with earth the eighth time. Abu Dawud said : Ibn Mughaffal narrated in a similar way}}
\hadithdefcmd{abudawud}{75}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ حُمَيْدَةَ بِنْتِ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ كَبْشَةَ بِنْتِ كَعْبِ بْنِ مَالِكٍ، - وَكَانَتْ تَحْتَ ابْنِ أَبِي قَتَادَةَ - أَنَّ أَبَا قَتَادَةَ، دَخَلَ فَسَكَبَتْ لَهُ وَضُوءًا فَجَاءَتْ هِرَّةٌ فَشَرِبَتْ مِنْهُ فَأَصْغَى لَهَا الإِنَاءَ حَتَّى شَرِبَتْ قَالَتْ كَبْشَةُ فَرَآنِي أَنْظُرُ إِلَيْهِ فَقَالَ أَتَعْجَبِينَ يَا ابْنَةَ أَخِي فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهَا لَيْسَتْ بِنَجَسٍ إِنَّهَا مِنَ الطَّوَّافِينَ عَلَيْكُمْ وَالطَّوَّافَاتِ ‏"‏ ‏.‏\hadithno{75}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuQatadah: Kabshah, daughter of Ka'b ibn Malik and wife of Ibn AbuQatadah, reported: AbuQatadah visited (me) and I poured out water for him for ablution. A cat came and drank some of it and he tilted the vessel for it until it drank some of it. Kabshah said: He saw me looking at him; he asked me: Are you surprised, my niece? I said: Yes. He then reported the Messenger of Allah (ﷺ) as saying: It is not unclean; it is one of those (males or females) who go round among you}}
\hadithdefcmd{abudawud}{76}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ دَاوُدَ بْنِ صَالِحِ بْنِ دِينَارٍ التَّمَّارِ، عَنْ أُمِّهِ، أَنَّ مَوْلاَتَهَا، أَرْسَلَتْهَا بِهَرِيسَةٍ إِلَى عَائِشَةَ رضى الله عنها فَوَجَدْتُهَا تُصَلِّي فَأَشَارَتْ إِلَىَّ أَنْ ضَعِيهَا فَجَاءَتْ هِرَّةٌ فَأَكَلَتْ مِنْهَا فَلَمَّا انْصَرَفَتْ أَكَلَتْ مِنْ حَيْثُ أَكَلَتِ الْهِرَّةُ فَقَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهَا لَيْسَتْ بِنَجَسٍ إِنَّمَا هِيَ مِنَ الطَّوَّافِينَ عَلَيْكُمْ ‏"‏ ‏.‏ وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ بِفَضْلِهَا ‏.‏\hadithno{76}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Dawud ibn Salih ibn Dinar at-Tammar quoted his mother as saying that her mistress sent her with some pudding (harisah) to Aisha who was offering prayer. She made a sign to me to place it down. A cat came and ate some of it, but when Aisha finished her prayer, she ate from the place where the cat had eaten. She stated: The Messenger of Allah (ﷺ) said: It is not unclean: it is one of those who go round among you. She added: I saw the Messenger of Allah (ﷺ) performing ablution from the water left over by the cat}}
\hadithdefcmd{abudawud}{77}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي مَنْصُورٌ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ وَنَحْنُ جُنُبَانِ ‏.‏\hadithno{77}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (299)}\hadithtrans{Narrated Aishah :I and the Messenger of Allaah ( sal Allaahu alayhi wa sallam ) took a bath from one vessel while we were sexually defiled}}
\hadithdefcmd{abudawud}{78}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا وَكِيعٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ ابْنِ خَرَّبُوذَ، عَنْ أُمِّ صُبَيَّةَ الْجُهَنِيَّةِ، قَالَتِ اخْتَلَفَتْ يَدِي وَيَدُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْوُضُوءِ مِنْ إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{78}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: My hands and the hands of the Messenger of Allah (ﷺ) alternated into one vessel while we performed ablution}}
\hadithdefcmd{abudawud}{79}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ الرِّجَالُ وَالنِّسَاءُ يَتَوَضَّئُونَ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ مُسَدَّدٌ - مِنَ الإِنَاءِ الْوَاحِدِ جَمِيعًا ‏.‏\hadithno{79}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (193)}\hadithtrans{Narrated Ibn 'Umar: The males and females during the time of the Apostle of Allaah ( sal Allahu alayhi wa sallam ) used to perform the ablution from one vessel together. The wordings "from one vessel" occur in the version of Musaddad}}
\hadithdefcmd{abudawud}{80}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كُنَّا نَتَوَضَّأُ نَحْنُ وَالنِّسَاءُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ نُدْلِي فِيهِ أَيْدِيَنَا ‏.‏\hadithno{80}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abd Allaah b. 'Umar:We (men) and women during the life-time of the Apostle of Allaah ( sal Allaahu alayhi wa sallam) used to perform ablution from one vessel. We all put our hands in it}}
\hadithdefcmd{abudawud}{81}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، عَنْ دَاوُدَ بْنِ عَبْدِ اللَّهِ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ دَاوُدَ بْنِ عَبْدِ اللَّهِ، عَنْ حُمَيْدٍ الْحِمْيَرِيِّ، قَالَ لَقِيتُ رَجُلاً صَحِبَ النَّبِيَّ صلى الله عليه وسلم أَرْبَعَ سِنِينَ كَمَا صَحِبَهُ أَبُو هُرَيْرَةَ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَغْتَسِلَ الْمَرْأَةُ بِفَضْلِ الرَّجُلِ أَوْ يَغْتَسِلَ الرَّجُلُ بِفَضْلِ الْمَرْأَةِ - زَادَ مُسَدَّدٌ - وَلْيَغْتَرِفَا جَمِيعًا ‏.‏\hadithno{81}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Humayd al-Himyari: Humayd al-Himyari reported: I met a person (among the Companion of Prophet) who remained in the company of the Prophet (ﷺ)for four years as AbuHurayrah remained in his company. He reported: The Messenger of Allah (ﷺ) forbade that the female should wash with the water left over by the male, and that the male should wash with the left-over of the female. The version of Musaddad adds: "That they both take the handful of water together}}
\hadithdefcmd{abudawud}{82}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، - يَعْنِي الطَّيَالِسِيَّ - حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ أَبِي حَاجِبٍ، عَنِ الْحَكَمِ بْنِ عَمْرٍو، وَهُوَ الأَقْرَعُ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَتَوَضَّأَ الرَّجُلُ بِفَضْلِ طَهُورِ الْمَرْأَةِ ‏.‏\hadithno{82}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hakam ibn Amr: The Prophet (ﷺ) forbade that the male should perform ablution with the water left over by the female}}
\hadithdefcmd{abudawud}{83}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ سَلَمَةَ، - مِنْ آلِ ابْنِ الأَزْرَقِ - أَنَّ الْمُغِيرَةَ بْنَ أَبِي بُرْدَةَ، - وَهُوَ مِنْ بَنِي عَبْدِ الدَّارِ - أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَأَلَ رَجُلٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نَرْكَبُ الْبَحْرَ وَنَحْمِلُ مَعَنَا الْقَلِيلَ مِنَ الْمَاءِ فَإِنْ تَوَضَّأْنَا بِهِ عَطِشْنَا أَفَنَتَوَضَّأُ بِمَاءِ الْبَحْرِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏\hadithno{83}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: A man asked the Messenger of Allah (ﷺ): Messenger of Allah, we travel on the sea and take a small quantity of water with us. If we use this for ablution, we would suffer from thirst. Can we perform ablution with sea water? The Messenger (ﷺ) replied: Its water is pure and what dies in it is lawful food}}
\hadithdefcmd{abudawud}{84}{حَدَّثَنَا هَنَّادٌ، وَسُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، قَالاَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي فَزَارَةَ، عَنْ أَبِي زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ لَيْلَةَ الْجِنِّ ‏"‏ مَا فِي إِدَاوَتِكَ ‏"‏ ‏.‏ قَالَ نَبِيذٌ ‏.‏ قَالَ ‏"‏ تَمْرَةٌ طَيِّبَةٌ وَمَاءٌ طَهُورٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ سُلَيْمَانُ بْنُ دَاوُدَ عَنْ أَبِي زَيْدٍ أَوْ زَيْدٍ كَذَا قَالَ شَرِيكٌ وَلَمْ يَذْكُرْ هَنَّادٌ لَيْلَةَ الْجِنِّ ‏.‏\hadithno{84}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: AbuZayd quoted Abdullah ibn Mas'ud as saying that on the night when the jinn listened to the Qur'an the Prophet (ﷺ) said: What is in your skin vessel? He said: I have some nabidh. He (the Holy Prophet) said: It consists of fresh dates and pure water. Sulayman ibn Dawud reported the same version of this tradition on the authority of AbuZayd or Zayd. But Sharik said that Hammad did not mention the words "night of the jinn}}
\hadithdefcmd{abudawud}{85}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ دَاوُدَ، عَنْ عَامِرٍ، عَنْ عَلْقَمَةَ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ مَسْعُودٍ مَنْ كَانَ مِنْكُمْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْجِنِّ فَقَالَ مَا كَانَ مَعَهُ مِنَّا أَحَدٌ ‏.‏\hadithno{85}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (450)}\hadithtrans{Narrated 'Alqamah:I asked 'Abd Allaah b Mas'ud: Which of you was in the company of the Messenger of Allaah ( sal Allaahu alayhi wa sallam ) on the night when the jinn attended him? He replied : None of us was with him}}
\hadithdefcmd{abudawud}{86}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا بِشْرُ بْنُ مَنْصُورٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، أَنَّهُ كَرِهَ الْوُضُوءَ بِاللَّبَنِ وَالنَّبِيذِ وَقَالَ إِنَّ التَّيَمُّمَ أَعْجَبُ إِلَىَّ مِنْهُ ‏.‏\hadithno{86}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It is reported that 'Ata did not approve of performing ablution with milk and nabidh and said:tayammum is more my liking (than performing ablution with milk and nabidh)}}
\hadithdefcmd{abudawud}{87}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا أَبُو خَلْدَةَ، قَالَ سَأَلْتُ أَبَا الْعَالِيَةِ عَنْ رَجُلٍ، أَصَابَتْهُ جَنَابَةٌ وَلَيْسَ عِنْدَهُ مَاءٌ وَعِنْدَهُ نَبِيذٌ أَيَغْتَسِلُ بِهِ قَالَ لاَ ‏.‏\hadithno{87}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Khaldah:I asked Abu'l-'Aliyah whether a person who is sexually defiled and has no water with him, but he has only nabidh, can wash with it? He replied in the negative}}
\hadithdefcmd{abudawud}{88}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الأَرْقَمِ، أَنَّهُ خَرَجَ حَاجًّا أَوْ مُعْتَمِرًا وَمَعَهُ النَّاسُ وَهُوَ يَؤُمُّهُمْ فَلَمَّا كَانَ ذَاتَ يَوْمٍ أَقَامَ الصَّلاَةَ صَلاَةَ الصُّبْحِ ثُمَّ قَالَ لِيَتَقَدَّمْ أَحَدُكُمْ ‏.‏ وَذَهَبَ إِلَى الْخَلاَءِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أَرَادَ أَحَدُكُمْ أَنْ يَذْهَبَ الْخَلاَءَ وَقَامَتِ الصَّلاَةُ فَلْيَبْدَأْ بِالْخَلاَءِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى وُهَيْبُ بْنُ خَالِدٍ وَشُعَيْبُ بْنُ إِسْحَاقَ وَأَبُو ضَمْرَةَ هَذَا الْحَدِيثَ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ رَجُلٍ حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ أَرْقَمَ وَالأَكْثَرُ الَّذِينَ رَوَوْهُ عَنْ هِشَامٍ قَالُوا كَمَا قَالَ زُهَيْرٌ ‏.‏\hadithno{88}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn al-Arqam: Urwah reported on the authority of his father that Abdullah ibn al-Arqam travelled for performing hajj (pilgrimage) or umrah. He was accompanied by the people whom he led in prayer. One day when he was leading them in the dawn (fajr) prayer, he said to them: One of you should come forward. He then went away to relieve himself. He said: I heard the Messenger of Allah (ﷺ) say: When any of you feels the need of relieving himself while the congregational prayer is ready, he should go to relieve himself}}
\hadithdefcmd{abudawud}{89}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، وَمُسَدَّدٌ، وَمُحَمَّدُ بْنُ عِيسَى، - الْمَعْنَى - قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ أَبِي حَزْرَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، - قَالَ ابْنُ عِيسَى فِي حَدِيثِهِ ابْنُ أَبِي بَكْرٍ ثُمَّ اتَّفَقُوا أَخُو الْقَاسِمِ بْنِ مُحَمَّدٍ - قَالَ كُنَّا عِنْدَ عَائِشَةَ فَجِيءَ بِطَعَامِهَا فَقَامَ الْقَاسِمُ يُصَلِّي فَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يُصَلَّى بِحَضْرَةِ الطَّعَامِ وَلاَ وَهُوَ يُدَافِعُهُ الأَخْبَثَانِ ‏"‏ ‏.‏\hadithno{89}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (560)}\hadithtrans{Narrated 'Abd Allaah b. Muhammad:We were in the company of 'Aishah. When her food was brought in, al-Qasim stood up to say his prayer. Thereupon , 'Aishah said : I heard the Messenger of Allaah (sal Allaahu alayhi wa sallam) say: Prayer should not be offered in presence of meals, nor at the moment when one is struggling with two evils (e.g. when one is feeling the call of nature)}}
\hadithdefcmd{abudawud}{90}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ عَيَّاشٍ، عَنْ حَبِيبِ بْنِ صَالِحٍ، عَنْ يَزِيدَ بْنِ شُرَيْحٍ الْحَضْرَمِيِّ، عَنْ أَبِي حَىٍّ الْمُؤَذِّنِ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثٌ لاَ يَحِلُّ لأَحَدٍ أَنْ يَفْعَلَهُنَّ لاَ يَؤُمُّ رَجُلٌ قَوْمًا فَيَخُصُّ نَفْسَهُ بِالدُّعَاءِ دُونَهُمْ فَإِنْ فَعَلَ فَقَدْ خَانَهُمْ وَلاَ يَنْظُرُ فِي قَعْرِ بَيْتٍ قَبْلَ أَنْ يَسْتَأْذِنَ فَإِنْ فَعَلَ فَقَدْ دَخَلَ وَلاَ يُصَلِّي وَهُوَ حَقِنٌ حَتَّى يَتَخَفَّفَ ‏"‏ ‏.‏\hadithno{90}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Thawban: The Messenger of Allah (ﷺ) said: Three things one is not allowed to do: supplicating Allah specifically for himself and ignoring others while leading people in prayer; if he did so, he deceived them; looking inside a house before taking permission: if he did so, it is as if he entered the house, saying prayer while one is feeling the call of nature until one eases oneself}}
\hadithdefcmd{abudawud}{91}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ السُّلَمِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ عَلِيٍّ، حَدَّثَنَا ثَوْرٌ، عَنْ يَزِيدَ بْنِ شُرَيْحٍ الْحَضْرَمِيِّ، عَنْ أَبِي حَىٍّ الْمُؤَذِّنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَحِلُّ لِرَجُلٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يُصَلِّيَ وَهُوَ حَقِنٌ حَتَّى يَتَخَفَّفَ ‏"‏ ‏.‏ ثُمَّ سَاقَ نَحْوَهُ عَلَى هَذَا اللَّفْظِ قَالَ ‏"‏ وَلاَ يَحِلُّ لِرَجُلٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَؤُمَّ قَوْمًا إِلاَّ بِإِذْنِهِمْ وَلاَ يَخْتَصَّ نَفْسَهُ بِدَعْوَةٍ دُونَهُمْ فَإِنْ فَعَلَ فَقَدْ خَانَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا مِنْ سُنَنِ أَهْلِ الشَّامِ لَمْ يَشْرَكْهُمْ فِيهَا أَحَدٌ ‏.‏\hadithno{91}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: It is not permissible for a man who believes in Allah and in the Last Day that he should say the prayer while he is feeling the call of nature until he becomes light (by relieving himself). Then the narrator Thawr b. Yazid transmitted a similar tradition with the following wordings: "It is not permissible for a man who believes in Allah and in the Last Day that he should lead the people in prayer but with their permission; and that he should not supplicate to Allah exclusively for himself leaving all others. If he did so, he violated trust." Abu Dawud said: This is a tradition reported by the narrators of Syria; no other person has joined them in relating this tradition}}
\hadithdefcmd{abudawud}{92}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَغْتَسِلُ بِالصَّاعِ وَيَتَوَضَّأُ بِالْمُدِّ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَبَانُ عَنْ قَتَادَةَ قَالَ سَمِعْتُ صَفِيَّةَ ‏.‏\hadithno{92}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) used to wash himself with a sa' (of water) and perform ablution with a mudd (of water). Abu Dawud said: This tradition has also been narrated by Aban on the authority of Qatadah. In this version he said: "I herd safiyyah}}
\hadithdefcmd{abudawud}{93}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ بِالصَّاعِ وَيَتَوَضَّأُ بِالْمُدِّ ‏.‏\hadithno{93}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) used to take a bath with a sa' (of water) and perform ablution with a mudd (of water)}}
\hadithdefcmd{abudawud}{94}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبٍ الأَنْصَارِيِّ، قَالَ سَمِعْتُ عَبَّادَ بْنَ تَمِيمٍ، عَنْ جَدَّتِهِ، وَهِيَ أُمُّ عُمَارَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ فَأُتِيَ بِإِنَاءٍ فِيهِ مَاءٌ قَدْرُ ثُلُثَىِ الْمُدِّ ‏.‏\hadithno{94}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umm Umarah: Habib al-Ansari reported: I heard Abbad ibn Tamim who reported on the authority of my grandmother, Umm Umarah, saying: The Prophet (ﷺ) wanted to perform ablution. A vessel containing 2/3 mudd of water was brought to him}}
\hadithdefcmd{abudawud}{95}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا شَرِيكٌ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ عَبْدِ اللَّهِ بْنِ جَبْرٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَوَضَّأُ بِإِنَاءٍ يَسَعُ رَطْلَيْنِ وَيَغْتَسِلُ بِالصَّاعِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ يَحْيَى بْنُ آدَمَ عَنْ شَرِيكٍ قَالَ عَنِ ابْنِ جَبْرِ بْنِ عَتِيكٍ ‏.‏ قَالَ وَرَوَاهُ سُفْيَانُ عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى حَدَّثَنِي جَبْرُ بْنُ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ شُعْبَةُ قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ جَبْرٍ سَمِعْتُ أَنَسًا إِلاَّ أَنَّهُ قَالَ يَتَوَضَّأُ بِمَكُّوكٍ ‏.‏ وَلَمْ يَذْكُرْ رَطْلَيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ وَسَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ الصَّاعُ خَمْسَةُ أَرْطَالٍ وَهُوَ صَاعُ ابْنِ أَبِي ذِئْبٍ وَهُوَ صَاعُ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{95}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas reported :The Prophet (ﷺ) performed ablution with a vessel which contained two rotls (of water) and took a bath with a sa’ (of water).1 Abu Dawud Said : This tradition has berated on the authority of Anas through a different chain. This version mentions: “He performed ablution with one makkuk. “It makes no mention of two rotls. 2 Abu Dawud said : This tradition has also been narrated by Yahya b. Adam from Sharik. But this chain mentions Ibn Jabr b. ‘Atik instead of ‘ Abd Allah b. Jabr. Abu Dawud Said : This tradition has also been narrated by Sufyan from ‘Abd Allah b. ‘Isa. This chain mentions the name Jabr b. ‘Abd Allah instead of ‘Abd Allah b. Jabr. Abu Dawud Said : I heard Ahmad b. Hanbal say : one sa’ measures five rotls. It was the sa’ of Ibn Abi Dhi’b and also of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{96}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا سَعِيدٌ الْجُرَيْرِيُّ، عَنْ أَبِي نَعَامَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ مُغَفَّلٍ، سَمِعَ ابْنَهُ، يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْقَصْرَ الأَبْيَضَ عَنْ يَمِينِ الْجَنَّةِ، إِذَا دَخَلْتُهَا ‏.‏ فَقَالَ أَىْ بُنَىَّ سَلِ اللَّهَ الْجَنَّةَ وَتَعَوَّذْ بِهِ مِنَ النَّارِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّهُ سَيَكُونُ فِي هَذِهِ الأُمَّةِ قَوْمٌ يَعْتَدُونَ فِي الطُّهُورِ وَالدُّعَاءِ ‏"‏ ‏.‏\hadithno{96}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Mughaffal: Abdullah heard his son praying to Allah: O Allah, I ask Thee a white palace on the right of Paradise when I enter it. He said: O my son, ask Allah for Paradise and seek refuge in Him from Hell-Fire, for I heard the Messenger of Allah (ﷺ) say: In this community there will be some people who will exceed the limits in purification as well as in supplication}}
\hadithdefcmd{abudawud}{97}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنَا مَنْصُورٌ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ أَبِي يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى قَوْمًا وَأَعْقَابُهُمْ تَلُوحُ فَقَالَ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ أَسْبِغُوا الْوُضُوءَ ‏"‏ ‏.‏\hadithno{97}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (241)}\hadithtrans{‘Abd Allah b. ‘Amr reported :The Messenger of Allah (ﷺ) saw some people (performing ablution) while their heels were dry. He then said : Woe to the heels because of Hell. Perform the ablution in full}}
\hadithdefcmd{abudawud}{98}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنِي صَاحِبٌ، لِي عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم فِي تَوْرٍ مِنْ شَبَهٍ ‏.‏\hadithno{98}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I and the Messenger of Allah (ﷺ) used to take bath with a brass vessel}}
\hadithdefcmd{abudawud}{99}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَنَّ إِسْحَاقَ بْنَ مَنْصُورٍ، حَدَّثَهُمْ عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ رَجُلٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{99}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been narrated on the authority of ‘A’ishah through a different chain}}
\hadithdefcmd{abudawud}{100}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو الْوَلِيدِ، وَسَهْلُ بْنُ حَمَّادٍ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، قَالَ جَاءَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْرَجْنَا لَهُ مَاءً فِي تَوْرٍ مِنْ صُفْرٍ فَتَوَضَّأَ ‏.‏\hadithno{100}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (191، 197) Sahih Muslim (235)}\hadithtrans{Narrated Abdullah ibn Zayd: The Messenger of Allah (ﷺ) came upon us. We brought water for him in a brass vessel and he performed ablution}}
\hadithdefcmd{abudawud}{101}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى، عَنْ يَعْقُوبَ بْنِ سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ صَلاَةَ لِمَنْ لاَ وُضُوءَ لَهُ وَلاَ وُضُوءَ لِمَنْ لَمْ يَذْكُرِ اسْمَ اللَّهِ تَعَالَى عَلَيْهِ ‏"‏ ‏.‏\hadithno{101}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) said: The prayer of a person who does not perform ablution is not valid, and the ablution of a person who does not mention the name of Allah (in the beginning) is not valid}}
\hadithdefcmd{abudawud}{102}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ الدَّرَاوَرْدِيِّ، قَالَ وَذَكَرَ رَبِيعَةُ أَنَّ تَفْسِيرَ، حَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لاَ وُضُوءَ لِمَنْ لَمْ يَذْكُرِ اسْمَ اللَّهِ عَلَيْهِ ‏"‏ ‏.‏ أَنَّهُ الَّذِي يَتَوَضَّأُ وَيَغْتَسِلُ وَلاَ يَنْوِي وُضُوءًا لِلصَّلاَةِ وَلاَ غُسْلاً لِلْجَنَابَةِ ‏.‏\hadithno{102}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Explaining the tradition of the Prophet (ﷺ) that the ablution of a person who does not mention the name of Allah is valid, Rabi’ah said:This tradition means that if a person performs ablution and takes a bath but does not have the intention to perform ablution for prayer and purify himself from sexual defilement, his ablution or bath is not valid}}
\hadithdefcmd{abudawud}{103}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي رَزِينٍ، وَأَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَامَ أَحَدُكُمْ مِنَ اللَّيْلِ فَلاَ يَغْمِسْ يَدَهُ فِي الإِنَاءِ حَتَّى يَغْسِلَهَا ثَلاَثَ مَرَّاتٍ فَإِنَّهُ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏\hadithno{103}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (278)}\hadithtrans{Abu Hurairah reported :The Messenger of Allah (ﷺ) said: When anyone amongst you wakes up from sleep at night, he should not put his hand in the utensil until he has washed his hand three times, for he does’ not know where his hand was during the night}}
\hadithdefcmd{abudawud}{104}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم - يَعْنِي بِهَذَا الْحَدِيثِ - قَالَ مَرَّتَيْنِ أَوْ ثَلاَثًا وَلَمْ يَذْكُرْ أَبَا رَزِينٍ ‏.‏\hadithno{104}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This Tradition has been reported by Abu Hurairah through another chain of transmitters. It adds :“ twice or thrice.” This version does not mention Abu Razin}}
\hadithdefcmd{abudawud}{105}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ أَبِي مَرْيَمَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ نَوْمِهِ فَلاَ يُدْخِلْ يَدَهُ فِي الإِنَاءِ حَتَّى يَغْسِلَهَا ثَلاَثَ مَرَّاتٍ فَإِنَّ أَحَدَكُمْ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ أَوْ أَيْنَ كَانَتْ تَطُوفُ يَدُهُ ‏"‏ ‏.‏\hadithno{105}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported :I heard the Messenger of Allah (May Peace be upon him) say: When any of you wakes up from sleep, he should not put his hand in the utensil until he washes it three times, for none of you knows where his hand remained during the night or where it went round}}
\hadithdefcmd{abudawud}{106}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ حُمْرَانَ بْنِ أَبَانَ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ قَالَ رَأَيْتُ عُثْمَانَ بْنَ عَفَّانَ تَوَضَّأَ فَأَفْرَغَ عَلَى يَدَيْهِ ثَلاَثًا فَغَسَلَهُمَا ثُمَّ تَمَضْمَضَ وَاسْتَنْثَرَ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا وَغَسَلَ يَدَهُ الْيُمْنَى إِلَى الْمِرْفَقِ ثَلاَثًا ثُمَّ الْيُسْرَى مِثْلَ ذَلِكَ ثُمَّ مَسَحَ رَأْسَهُ ثُمَّ غَسَلَ قَدَمَهُ الْيُمْنَى ثَلاَثًا ثُمَّ الْيُسْرَى مِثْلَ ذَلِكَ ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ مِثْلَ وُضُوئِي هَذَا ثُمَّ قَالَ ‏ "‏ مَنْ تَوَضَّأَ مِثْلَ وُضُوئِي هَذَا ثُمَّ صَلَّى رَكْعَتَيْنِ لاَ يُحَدِّثُ فِيهِمَا نَفْسَهُ غَفَرَ اللَّهُ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{106}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1934) Sahih Muslim (226)}\hadithtrans{Humran b. Abban, the freed slave of ‘Uthman, said :I saw ‘ Uthman’ b. ‘Affan while he performed ablution. He poured water over his hands three times and then washed them. He then rinsed his mouth and then cleansed his nose with water (three times). He then washed his right arm up to the elbow three times, then washed his left arm in a similar manner; then wiped his head; then washed his right foot three times, then washed his left foot in a similar manner, and then said : I saw the Messenger of Allah (ﷺ) performing ablution like this ablution of mine. Then he (the Prophet) said: He who performs ablution like this ablution of mine and then offered two rakhahs of prayer without allowing his thoughts to be distracted, Allah will pardon all his past sins}}
\hadithdefcmd{abudawud}{107}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ وَرْدَانَ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي حُمْرَانُ، قَالَ رَأَيْتُ عُثْمَانَ بْنَ عَفَّانَ تَوَضَّأَ ‏.‏ فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرِ الْمَضْمَضَةَ وَالاِسْتِنْشَاقَ وَقَالَ فِيهِ وَمَسَحَ رَأْسَهُ ثَلاَثًا ثُمَّ غَسَلَ رِجْلَيْهِ ثَلاَثًا ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ هَكَذَا وَقَالَ ‏ "‏ مَنْ تَوَضَّأَ دُونَ هَذَا كَفَاهُ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ أَمْرَ الصَّلاَةِ ‏.‏\hadithno{107}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Humran said :I saw ‘Uthman b. ‘Affan performing ablution. He then narrated the same tradition. In this version there is no mention of rinsing the mouth and snuffing up water. This traditions adds : “He wiped his head three times. He then washed his feet three times. He then said : I saw the Messenger of Allah (ﷺ) performing ablution in like manner. He (the Prophet) said: He who performs ablution less than this, it is sufficient for him. 73	The narrator did not mention prayer (in this version)}}
\hadithdefcmd{abudawud}{108}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ الإِسْكَنْدَرَانِيُّ، حَدَّثَنَا زِيَادُ بْنُ يُونُسَ، حَدَّثَنِي سَعِيدُ بْنُ زِيَادٍ الْمُؤَذِّنُ، عَنْ عُثْمَانَ بْنِ عَبْدِ الرَّحْمَنِ التَّيْمِيِّ، قَالَ سُئِلَ ابْنُ أَبِي مُلَيْكَةَ عَنِ الْوُضُوءِ، فَقَالَ رَأَيْتُ عُثْمَانَ بْنَ عَفَّانَ سُئِلَ عَنِ الْوُضُوءِ، فَدَعَا بِمَاءٍ فَأُتِيَ بِمِيضَأَةٍ فَأَصْغَى عَلَى يَدِهِ الْيُمْنَى ثُمَّ أَدْخَلَهَا فِي الْمَاءِ فَتَمَضْمَضَ ثَلاَثًا وَاسْتَنْثَرَ ثَلاَثًا وَغَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى ثَلاَثًا وَغَسَلَ يَدَهُ الْيُسْرَى ثَلاَثًا ثُمَّ أَدْخَلَ يَدَهُ فَأَخَذَ مَاءً فَمَسَحَ بِرَأْسِهِ وَأُذُنَيْهِ فَغَسَلَ بُطُونَهُمَا وَظُهُورَهُمَا مَرَّةً وَاحِدَةً ثُمَّ غَسَلَ رِجْلَيْهِ ثُمَّ قَالَ أَيْنَ السَّائِلُونَ عَنِ الْوُضُوءِ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ ‏.‏ قَالَ أَبُو دَاوُدَ أَحَادِيثُ عُثْمَانَ - رضى الله عنه - الصِّحَاحُ كُلُّهَا تَدُلُّ عَلَى مَسْحِ الرَّأْسِ أَنَّهُ مَرَّةٌ فَإِنَّهُمْ ذَكَرُوا الْوُضُوءَ ثَلاَثًا وَقَالُوا فِيهَا وَمَسَحَ رَأْسَهُ ‏.‏ وَلَمْ يَذْكُرُوا عَدَدًا كَمَا ذَكَرُوا فِي غَيْرِهِ ‏.‏\hadithno{108}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{‘Abd al-Rahman al-TamiI reported:Ibn Abi Mulaikah was asked about ablution. He said : I saw ‘Uthman b. ‘Affan who was asked about ablution. He called for water. A vessel was then brought to him. He inclined it towords his right hand (poured water upon it). He then put it in the water three times, and washed his face three times. He then put his hand in the water and took it out; then he wiped his head and ears, in and out only once. He then washed his feet, and said : Where are those who asked me to perform ablution? I saw the Messenger of Allah (ﷺ) performing ablution like that. Abu Dawud said : All the sound traditions narrated by ‘ Uthman indicated that the head is to be wiped once, because they mentioned (the washing of each part in) ablution three times. In their versions of tradition they mentioned the wordings: “he wiped his head.” In this case they did not mention any number as they did in other cases}}
\hadithdefcmd{abudawud}{109}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، أَخْبَرَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ أَبِي زِيَادٍ - عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ أَبِي عَلْقَمَةَ، أَنَّ عُثْمَانَ، دَعَا بِمَاءٍ فَتَوَضَّأَ فَأَفْرَغَ بِيَدِهِ الْيُمْنَى عَلَى الْيُسْرَى ثُمَّ غَسَلَهُمَا إِلَى الْكُوعَيْنِ - قَالَ - ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ ثَلاَثًا وَذَكَرَ الْوُضُوءَ ثَلاَثًا - قَالَ - وَمَسَحَ بِرَأْسِهِ ثُمَّ غَسَلَ رِجْلَيْهِ وَقَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ مِثْلَ مَا رَأَيْتُمُونِي تَوَضَّأْتُ ‏.‏ ثُمَّ سَاقَ نَحْوَ حَدِيثِ الزُّهْرِيِّ وَأَتَمَّ ‏.‏\hadithno{109}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu ‘Alqamah said that ‘Uthman called for water and performed ablution. He then poured water with the right hand or the left hand ; he then washed them up to the wrist ; he then rinsed the mouth and snuffed up water three times. The narrator mentioned that ‘ Uthman washed each part three times. He then wiped head and washed his feet. He said :I saw the Messenger of Allah (ﷺ) performing ablution as you saw me perform ablution. He then reported the tradition like that of al-Zuhrl and completed it}}
\hadithdefcmd{abudawud}{110}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ عَامِرِ بْنِ شَقِيقِ بْنِ جَمْرَةَ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، قَالَ رَأَيْتُ عُثْمَانَ بْنَ عَفَّانَ غَسَلَ ذِرَاعَيْهِ ثَلاَثًا ثَلاَثًا وَمَسَحَ رَأْسَهُ ثَلاَثًا ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ هَذَا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ وَكِيعٌ عَنْ إِسْرَائِيلَ قَالَ تَوَضَّأَ ثَلاَثًا فَقَطْ ‏.‏\hadithno{110}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shaqiq b. Salamah said :I saw ‘ Uthman b. ‘ Affan (perform ablution). He washed his forearms three times and washed his head thrice. He then said : I saw the Messenger of Allah (ﷺ) doing like that. Abu Dawud said: Another version says: "He performed ablution three times only}}
\hadithdefcmd{abudawud}{111}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ خَالِدِ بْنِ عَلْقَمَةَ، عَنْ عَبْدِ خَيْرٍ، قَالَ أَتَانَا عَلِيٌّ - رضى الله عنه - وَقَدْ صَلَّى فَدَعَا بِطَهُورٍ فَقُلْنَا مَا يَصْنَعُ بِالطَّهُورِ وَقَدْ صَلَّى مَا يُرِيدُ إِلاَّ أَنْ يُعَلِّمَنَا فَأُتِيَ بِإِنَاءٍ فِيهِ مَاءٌ وَطَسْتٍ فَأَفْرَغَ مِنَ الإِنَاءِ عَلَى يَمِينِهِ فَغَسَلَ يَدَيْهِ ثَلاَثًا ثُمَّ تَمَضْمَضَ وَاسْتَنْثَرَ ثَلاَثًا فَمَضْمَضَ وَنَثَرَ مِنَ الْكَفِّ الَّذِي يَأْخُذُ فِيهِ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى ثَلاَثًا وَغَسَلَ يَدَهُ الشِّمَالَ ثَلاَثًا ثُمَّ جَعَلَ يَدَهُ فِي الإِنَاءِ فَمَسَحَ بِرَأْسِهِ مَرَّةً وَاحِدَةً ثُمَّ غَسَلَ رِجْلَهُ الْيُمْنَى ثَلاَثًا وَرِجْلَهُ الشِّمَالَ ثَلاَثًا ثُمَّ قَالَ مَنْ سَرَّهُ أَنْ يَعْلَمَ وُضُوءَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهُوَ هَذَا ‏.‏\hadithno{111}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ali ibn AbuTalib: Abdu Khayr said: Ali came upon us and he had already offered prayer. He called for water. We asked: What will you do with water when you have already offered prayer? - Perhaps to teach us. A utensil containing water and a wash-basin were brought (to him). He poured water from the utensil on his right hand and washed both his hands three times, rinsed the mouth, snuffed up water and cleansed the nose three times. He then rinsed the mouth and snuffed up water with the same hand by which he took water. He then washed his face three times, and washed his right hand three times and washed his left hand three times. He then put his hand in water and wiped his head once. He then washed his right foot thrice and left foot thrice, then said: If one is pleased to know the method of performing ablution of the Messenger of Allah, this is how he did it}}
\hadithdefcmd{abudawud}{112}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، حَدَّثَنَا خَالِدُ بْنُ عَلْقَمَةَ الْهَمْدَانِيُّ، عَنْ عَبْدِ خَيْرٍ، قَالَ صَلَّى عَلِيُّ رضى الله عنه الْغَدَاةَ ثُمَّ دَخَلَ الرَّحْبَةَ فَدَعَا بِمَاءٍ فَأَتَاهُ الْغُلاَمُ بِإِنَاءٍ فِيهِ مَاءٌ وَطَسْتٍ - قَالَ - فَأَخَذَ الإِنَاءَ بِيَدِهِ الْيُمْنَى فَأَفْرَغَ عَلَى يَدِهِ الْيُسْرَى وَغَسَلَ كَفَّيْهِ ثَلاَثًا ثُمَّ أَدْخَلَ يَدَهُ الْيُمْنَى فِي الإِنَاءِ فَتَمَضْمَضَ ثَلاَثًا وَاسْتَنْشَقَ ثَلاَثًا ‏.‏ ثُمَّ سَاقَ قَرِيبًا مِنْ حَدِيثِ أَبِي عَوَانَةَ قَالَ ثُمَّ مَسَحَ رَأْسَهُ مُقَدَّمَهُ وَمُؤَخَّرَهُ مَرَّةً ‏.‏ ثُمَّ سَاقَ الْحَدِيثَ نَحْوَهُ ‏.‏\hadithno{112}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Abd Khair said :‘All offered the dawn prayer and went to Rahbah (a locality in Kufah). He called for water. A boy brought him a vessel containing water and a wash-basin. He held the vessel with his right hand and poured water over his left hand. He washed both of his hands (to the wrist) three times. He then put his right hand in the vessel ( to take water) and rinsed his mouth three times and snuffed up water three times. He then narrated almost the same tradition as narrated by Abu ‘Awanah. He then wiped his head, both its front and back sides, once. He then narrated the tradition in like manner}}
\hadithdefcmd{abudawud}{113}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنِي شُعْبَةُ، قَالَ سَمِعْتُ مَالِكَ بْنَ عُرْفُطَةَ، سَمِعْتُ عَبْدَ خَيْرٍ، قَالَ رَأَيْتُ عَلِيًّا - رضى الله عنه - أُتِيَ بِكُرْسِيٍّ فَقَعَدَ عَلَيْهِ ثُمَّ أُتِيَ بِكُوزٍ مِنْ مَاءٍ فَغَسَلَ يَدَيْهِ ثَلاَثًا ثُمَّ تَمَضْمَضَ مَعَ الاِسْتِنْشَاقِ بِمَاءٍ وَاحِدٍ ‏.‏ وَذَكَرَ الْحَدِيثَ ‏.‏\hadithno{113}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Malik b. Ghurfatah says :I heard ‘Abd Khair say: I saw a chair was brought to ‘Ali who sat on it. A vessel of water was then brought to him. He washed his hands three times ; he then rinsed his mouth and snuffed up water with one handful of water. He narrated the tradition completely}}
\hadithdefcmd{abudawud}{114}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا رَبِيعَةُ الْكِنَانِيُّ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ زِرِّ بْنِ حُبَيْشٍ، أَنَّهُ سَمِعَ عَلِيًّا، رضى الله عنه وَسُئِلَ عَنْ وُضُوءِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ الْحَدِيثَ وَقَالَ وَمَسَحَ عَلَى رَأْسِهِ حَتَّى لَمَّا يَقْطُرْ وَغَسَلَ رِجْلَيْهِ ثَلاَثًا ثَلاَثًا ثُمَّ قَالَ هَكَذَا كَانَ وُضُوءُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{114}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Zirr b. Hubaish said that the heard that ‘ Ali was asked how the Messenger of Allah (ﷺ) used to perform ablution. He then narrated the tradition and said:he wiped his head so much so that drops (of water) were about to trickle down. He then washed his feet three times and said: This is how the Messenger of Allah (ﷺ) performed ablutions}}
\hadithdefcmd{abudawud}{115}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ الطُّوسِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا فِطْرٌ، عَنْ أَبِي فَرْوَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ رَأَيْتُ عَلِيًّا - رضى الله عنه - تَوَضَّأَ فَغَسَلَ وَجْهَهُ ثَلاَثًا وَغَسَلَ ذِرَاعَيْهِ ثَلاَثًا وَمَسَحَ بِرَأْسِهِ وَاحِدَةً ثُمَّ قَالَ هَكَذَا تَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{115}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Abd al-Rahman b. Abi Laila says:I saw ‘ Ali performing ablution. He washed his face three times and his hands three times and wiped his head once. Then he (‘Ali) said: The Messenger of Allah (ﷺ) used to perform ablution in this way}}
\hadithdefcmd{abudawud}{116}{حَدَّثَنَا مُسَدَّدٌ، وَأَبُو تَوْبَةَ قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، ح وَحَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ، قَالَ رَأَيْتُ عَلِيًّا - رضى الله عنه - تَوَضَّأَ فَذَكَرَ وُضُوءَهُ كُلَّهُ ثَلاَثًا ثَلاَثًا - قَالَ - ثُمَّ مَسَحَ رَأْسَهُ ثُمَّ غَسَلَ رِجْلَيْهِ إِلَى الْكَعْبَيْنِ ثُمَّ قَالَ إِنَّمَا أَحْبَبْتُ أَنْ أُرِيَكُمْ طُهُورَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{116}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hayyah said:I saw ‘Ali perform ablution. He (Abu Hayyah) then described that ‘Ali went through every part of the ablution three times, i.e. he performed each detail of his ablution three times. He then wiped his head, then washed his feet up to the ankles. He then said: I wanted to show you how the Messenger of Allah (ﷺ) performed ablution}}
\hadithdefcmd{abudawud}{117}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ طَلْحَةَ بْنِ يَزِيدَ بْنِ رُكَانَةَ، عَنْ عُبَيْدِ اللَّهِ الْخَوْلاَنِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ دَخَلَ عَلَىَّ عَلِيٌّ - يَعْنِي ابْنَ أَبِي طَالِبٍ - وَقَدْ أَهْرَاقَ الْمَاءَ فَدَعَا بِوَضُوءٍ فَأَتَيْنَاهُ بِتَوْرٍ فِيهِ مَاءٌ حَتَّى وَضَعْنَاهُ بَيْنَ يَدَيْهِ فَقَالَ يَا ابْنَ عَبَّاسٍ أَلاَ أُرِيكَ كَيْفَ كَانَ يَتَوَضَّأُ رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ بَلَى ‏.‏ قَالَ فَأَصْغَى الإِنَاءَ عَلَى يَدِهِ فَغَسَلَهَا ثُمَّ أَدْخَلَ يَدَهُ الْيُمْنَى فَأَفْرَغَ بِهَا عَلَى الأُخْرَى ثُمَّ غَسَلَ كَفَّيْهِ ثُمَّ تَمَضْمَضَ وَاسْتَنْثَرَ ثُمَّ أَدْخَلَ يَدَيْهِ فِي الإِنَاءِ جَمِيعًا فَأَخَذَ بِهِمَا حَفْنَةً مِنْ مَاءٍ فَضَرَبَ بِهَا عَلَى وَجْهِهِ ثُمَّ أَلْقَمَ إِبْهَامَيْهِ مَا أَقْبَلَ مِنْ أُذُنَيْهِ ثُمَّ الثَّانِيَةَ ثُمَّ الثَّالِثَةَ مِثْلَ ذَلِكَ ثُمَّ أَخَذَ بِكَفِّهِ الْيُمْنَى قَبْضَةً مِنْ مَاءٍ فَصَبَّهَا عَلَى نَاصِيَتِهِ فَتَرَكَهَا تَسْتَنُّ عَلَى وَجْهِهِ ثُمَّ غَسَلَ ذِرَاعَيْهِ إِلَى الْمِرْفَقَيْنِ ثَلاَثًا ثَلاَثًا ثُمَّ مَسَحَ رَأْسَهُ وَظُهُورَ أُذُنَيْهِ ثُمَّ أَدْخَلَ يَدَيْهِ جَمِيعًا فَأَخَذَ حَفْنَةً مِنْ مَاءٍ فَضَرَبَ بِهَا عَلَى رِجْلِهِ وَفِيهَا النَّعْلُ فَفَتَلَهَا بِهَا ثُمَّ الأُخْرَى مِثْلَ ذَلِكَ ‏.‏ قَالَ قُلْتُ وَفِي النَّعْلَيْنِ قَالَ وَفِي النَّعْلَيْنِ ‏.‏ قَالَ قُلْتُ وَفِي النَّعْلَيْنِ قَالَ وَفِي النَّعْلَيْنِ ‏.‏ قَالَ قُلْتُ وَفِي النَّعْلَيْنِ قَالَ وَفِي النَّعْلَيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ ابْنِ جُرَيْجٍ عَنْ شَيْبَةَ يُشْبِهُ حَدِيثَ عَلِيٍّ لأَنَّهُ قَالَ فِيهِ حَجَّاجُ بْنُ مُحَمَّدٍ عَنِ ابْنِ جُرَيْجٍ وَمَسَحَ بِرَأْسِهِ مَرَّةً وَاحِدَةً ‏.‏ وَقَالَ ابْنُ وَهْبٍ فِيهِ عَنِ ابْنِ جُرَيْجٍ وَمَسَحَ بِرَأْسِهِ ثَلاَثًا ‏.‏\hadithno{117}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn’Abbas said:‘Ali b. Abi Talib entered upon me after he has passed water. He then called for water for ablution. We brought to him a vessel containing water, and placed it before him. He said: O Ibn’Abbas, may I not show you how the Messenger of Allah(ﷺ) used to perform ablution? I replied : Why not? He then inclined the vessel to his hand and washed it. He then put his right hand in the vessel and poured water over the other hand and washed his hands up to the wrist. He then rinsed his mouth and snuffed up water. He then put both of his hands together in the water and took out a handful of water and threw it upon the face. He then inserted both of his thumbs in the front part of the ears. He did like that twice and thrice. He then took a handful of water and poured it over his forehead and left it running down his face. He then washed his forearms up to the elbow three times. He then wiped his head and the back of his ears. He then put both of his hands together in the water and took a handful of it and threw it on his foot. He had a shoe foot like that. Do you wash your foot while it is in the shoe? He replied : Yes, while it is in the shoe. This question and answer were repeated thrice. Abu Dawud said: The version transmitted by Ibn Juraij from Shaibah is similar to the one narrated by ‘ Ali. In this version Hajjaj reported on the authority of Ibn Juraij the wording: He wiped his head once. Ibn Wahb narrated from Ibn Juraij the wording: he wiped his head three times}}
\hadithdefcmd{abudawud}{118}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ زَيْدِ بْنِ عَاصِمٍ - وَهُوَ جَدُّ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ هَلْ تَسْتَطِيعُ أَنْ تُرِيَنِي، كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ فَقَالَ عَبْدُ اللَّهِ بْنُ زَيْدٍ نَعَمْ ‏.‏ فَدَعَا بِوَضُوءٍ فَأَفْرَغَ عَلَى يَدَيْهِ فَغَسَلَ يَدَيْهِ ثُمَّ تَمَضْمَضَ وَاسْتَنْثَرَ ثَلاَثًا ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ إِلَى الْمِرْفَقَيْنِ ثُمَّ مَسَحَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ بَدَأَ بِمُقَدَّمِ رَأْسِهِ ثُمَّ ذَهَبَ بِهِمَا إِلَى قَفَاهُ ثُمَّ رَدَّهُمَا حَتَّى رَجَعَ إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ ثُمَّ غَسَلَ رِجْلَيْهِ ‏.‏\hadithno{118}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (185) Sahih Muslim (235)}\hadithtrans{‘Amr b. Yahya al-Mazini reports on the authority of his father who asked ‘Abd Allah b. Zaid, the grandfather of ‘Amr b. Yahya al-Mazini:Can you show me how the Messenger of Allah (ﷺ) performed ablution? ‘Abd Allah b. Zaid replied: Yes. He called for ablution water, poured it over his hands, and washed them; then he rinsed his mouth and snuffed up water in the nose three times; then he washed his face three times and washed his forearms up to elbow twice; then he wiped his head with both hands, moving them front and back of the head, beginning from his forehead, and moved them to the nape; then he pulled them back to the place from where he had started (wiping); then he washed his feet}}
\hadithdefcmd{abudawud}{119}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدِ بْنِ عَاصِمٍ، بِهَذَا الْحَدِيثِ قَالَ فَمَضْمَضَ وَاسْتَنْشَقَ مِنْ كَفٍّ وَاحِدَةٍ يَفْعَلُ ذَلِكَ ثَلاَثًا ‏.‏ ثُمَّ ذَكَرَ نَحْوَهُ ‏.‏\hadithno{119}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (191) Sahih Muslim (235)}\hadithtrans{‘Abd Allah b. Zaid b. ‘Asim reported this tradition saying:He rinsed his mouth and snuffed up water from one hand, doing that three times}}
\hadithdefcmd{abudawud}{120}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ حَبَّانَ بْنَ وَاسِعٍ، حَدَّثَهُ أَنَّ أَبَاهُ حَدَّثَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ زَيْدِ بْنِ عَاصِمٍ الْمَازِنِيَّ، يَذْكُرُ أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ وُضُوءَهُ وَقَالَ وَمَسَحَ رَأْسَهُ بِمَاءٍ غَيْرِ فَضْلِ يَدَيْهِ وَغَسَلَ رِجْلَيْهِ حَتَّى أَنْقَاهُمَا ‏.‏\hadithno{120}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (236)}\hadithtrans{Habban b. Wasi’ reported on the authority of his father who heard ‘Abd Allah b. Zaid al-Asim al-Mazini say that he saw the Messenger of Allah (ﷺ) performing ablution. He then described his ablution saying:He wiped his head with water which was not what was left over after washing his hands (i.e. he wiped his head with clean water); then he washed his feet until he cleansed them}}
\hadithdefcmd{abudawud}{121}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا حَرِيزٌ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ مَيْسَرَةَ الْحَضْرَمِيُّ، سَمِعْتُ الْمِقْدَامَ بْنَ مَعْدِيكَرِبَ الْكِنْدِيَّ، قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَضُوءٍ فَتَوَضَّأَ فَغَسَلَ كَفَّيْهِ ثَلاَثًا ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ ثَلاَثًا وَغَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ ذِرَاعَيْهِ ثَلاَثًا ثَلاَثًا ثُمَّ مَسَحَ بِرَأْسِهِ وَأُذُنَيْهِ ظَاهِرِهِمَا وَبَاطِنِهِمَا ‏.‏\hadithno{121}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Miqdam ibn Ma'dikarib al-Kindi: The ablution water was brought to the Messenger (ﷺ) and he performed ablution; he washed his hands up to wrists three times, then washed his forearms three times. He then rinsed his mouth and snuffed up water three times; then he wiped his head and ears inside and outside}}
\hadithdefcmd{abudawud}{122}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، وَيَعْقُوبُ بْنُ كَعْبٍ الأَنْطَاكِيُّ، - لَفْظُهُ - قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ حَرِيزِ بْنِ عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَيْسَرَةَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ فَلَمَّا بَلَغَ مَسْحَ رَأْسِهِ وَضَعَ كَفَّيْهِ عَلَى مُقَدَّمِ رَأْسِهِ فَأَمَرَّهُمَا حَتَّى بَلَغَ الْقَفَا ثُمَّ رَدَّهُمَا إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ ‏.‏ قَالَ مَحْمُودٌ قَالَ أَخْبَرَنِي حَرِيزٌ ‏.‏\hadithno{122}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Al-Miqdam b. Ma’dikarib reported :I saw the Messenger of Allah (ﷺ) perform ablution. When he reached the stage of wiping his head, he placed his palms on the front of the head. Then he moved them until he reached the nape. He then returned them to the place from where he had started}}
\hadithdefcmd{abudawud}{123}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، وَهِشَامُ بْنُ خَالِدٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا الْوَلِيدُ، بِهَذَا الإِسْنَادِ قَالَ وَمَسَحَ بِأُذُنَيْهِ ظَاهِرِهِمَا وَبَاطِنِهِمَا ‏.‏ زَادَ هِشَامٌ وَأَدْخَلَ أَصَابِعَهُ فِي صِمَاخِ أُذُنَيْهِ ‏.‏\hadithno{123}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Another version says:He wiped his ears inside and outside. Hisham adds: He inserted his fingers in the ear-holes}}
\hadithdefcmd{abudawud}{124}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو الأَزْهَرِ الْمُغِيرَةُ بْنُ فَرْوَةَ، وَيَزِيدُ بْنُ أَبِي مَالِكٍ، أَنَّ مُعَاوِيَةَ، تَوَضَّأَ لِلنَّاسِ كَمَا رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ فَلَمَّا بَلَغَ رَأْسَهُ غَرَفَ غَرْفَةً مِنْ مَاءٍ فَتَلَقَّاهَا بِشِمَالِهِ حَتَّى وَضَعَهَا عَلَى وَسَطِ رَأْسِهِ حَتَّى قَطَرَ الْمَاءُ أَوْ كَادَ يَقْطُرُ ثُمَّ مَسَحَ مِنْ مُقَدَّمِهِ إِلَى مُؤَخَّرِهِ وَمِنْ مُؤَخَّرِهِ إِلَى مُقَدَّمِهِ ‏.‏\hadithno{124}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{AbulAzhar al-Mughirah ibn Farwah and Yazid ibn AbuMalik reported:Mu'awiyah performed ablution before the people, as he saw the Messenger of Allah (ﷺ) performed ablution. When he reached the stage of wiping his head, he took a handful of water and poured it with his left hand over the middle of his head so much so that drops of water came down or almost came down. Then he wiped (his head) from its front to its back and from its back to its front}}
\hadithdefcmd{abudawud}{125}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا الْوَلِيدُ، بِهَذَا الإِسْنَادِ قَالَ فَتَوَضَّأَ ثَلاَثًا ثَلاَثًا وَغَسَلَ رِجْلَيْهِ بِغَيْرِ عَدَدٍ ‏.‏\hadithno{125}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Another version says:He performed each part of the ablution three times and washed his feet times without number}}
\hadithdefcmd{abudawud}{126}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ ابْنِ عَفْرَاءَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْتِينَا فَحَدَّثَتْنَا أَنَّهُ قَالَ ‏ "‏ اسْكُبِي لِي وَضُوءًا ‏"‏ ‏.‏ فَذَكَرَتْ وُضُوءَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ فِيهِ فَغَسَلَ كَفَّيْهِ ثَلاَثًا وَوَضَّأَ وَجْهَهُ ثَلاَثًا وَمَضْمَضَ وَاسْتَنْشَقَ مَرَّةً وَوَضَّأَ يَدَيْهِ ثَلاَثًا ثَلاَثًا وَمَسَحَ بِرَأْسِهِ مَرَّتَيْنِ يَبْدَأُ بِمُؤَخَّرِ رَأْسِهِ ثُمَّ بِمُقَدَّمِهِ وَبِأُذُنَيْهِ كِلْتَيْهِمَا ظُهُورِهِمَا وَبُطُونِهِمَا وَوَضَّأَ رِجْلَيْهِ ثَلاَثًا ثَلاَثًا ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا مَعْنَى حَدِيثِ مُسَدَّدٍ ‏.‏\hadithno{126}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ar-Rubayyi' daughter of Mu'awwidh ibn Afra': The Messenger of Allah (ﷺ) used to come to us. He once said: Pour ablution water on me. She then described how the Prophet (ﷺ) performed ablution saying: He washed his hands up to wrist three times and washed his face three times, and rinsed his mouth and snuffed up water once. Then he washed his forearms three times and wiped his head twice beginning from the back of his head, then wiped its front. He wiped his ears outside and inside. Then he washed his feet three times. Abu Dawud said: The tradition narrated by Musaddad carries the same meaning}}
\hadithdefcmd{abudawud}{127}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَقِيلٍ، بِهَذَا الْحَدِيثِ يُغَيِّرُ بَعْضَ مَعَانِي بِشْرٍ قَالَ فِيهِ وَتَمَضْمَضَ وَاسْتَنْثَرَ ثَلاَثًا ‏.‏\hadithno{127}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Uqail reported this tradition with a slight change of wording. In his tradition he said:He rinsed his mouth three times and snuffed up water three times}}
\hadithdefcmd{abudawud}{128}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ خَالِدٍ الْهَمْدَانِيُّ، قَالاَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ ابْنِ عَفْرَاءَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ عِنْدَهَا فَمَسَحَ الرَّأْسَ كُلَّهُ مِنْ قَرْنِ الشَّعْرِ كُلَّ نَاحِيَةٍ لِمُنْصَبِّ الشَّعْرِ لاَ يُحَرِّكُ الشَّعْرَ عَنْ هَيْئَتِهِ ‏.‏\hadithno{128}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Al-Rubayyi’ daughter of Mu’awwidh b. ‘Afra’ reported:The Messenger of Allah (ﷺ) performed ablution in her presence. He wiped the whole of his head from its upper to the lower part moving every side. He did not move the hair from their original position}}
\hadithdefcmd{abudawud}{129}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - يَعْنِي ابْنَ مُضَرَ - عَنِ ابْنِ عَجْلاَنَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، أَنَّ رُبَيِّعَ بِنْتَ مُعَوِّذِ ابْنِ عَفْرَاءَ، أَخْبَرَتْهُ قَالَتْ، رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ - قَالَتْ - فَمَسَحَ رَأْسَهُ وَمَسَحَ مَا أَقْبَلَ مِنْهُ وَمَا أَدْبَرَ وَصُدْغَيْهِ وَأُذُنَيْهِ مَرَّةً وَاحِدَةً ‏.‏\hadithno{129}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Al-Rubayyi’ daughter of Mu’awwidh b. ‘Afra’ said:I saw the Messenger of Allah (ﷺ) performing ablution. He wiped his head front and back, his temples and his ears once}}
\hadithdefcmd{abudawud}{130}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ سُفْيَانَ بْنِ سَعِيدٍ، عَنِ ابْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَسَحَ بِرَأْسِهِ مِنْ فَضْلِ مَاءٍ كَانَ فِي يَدِهِ ‏.‏\hadithno{130}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Rubayyi’ reported:The Prophet (ﷺ) wiped his head with water which was left over in his hand}}
\hadithdefcmd{abudawud}{131}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الْحَسَنُ بْنُ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ ابْنِ عَفْرَاءَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ فَأَدْخَلَ إِصْبَعَيْهِ فِي جُحْرَىْ أُذُنَيْهِ ‏.‏\hadithno{131}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ar-Rubayyi' daughter of Mu'awwidh ibn Afra': The Prophet (ﷺ) performed ablution. He inserted his two fingers in the ear-holes}}
\hadithdefcmd{abudawud}{132}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ لَيْثٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ رَأْسَهُ مَرَّةً وَاحِدَةً حَتَّى بَلَغَ الْقَذَالَ - وَهُوَ أَوَّلُ الْقَفَا - وَقَالَ مُسَدَّدٌ وَمَسَحَ رَأْسَهُ مِنْ مُقَدَّمِهِ إِلَى مُؤَخَّرِهِ حَتَّى أَخْرَجَ يَدَيْهِ مِنْ تَحْتِ أُذُنَيْهِ ‏.‏ قَالَ مُسَدَّدٌ فَحَدَّثْتُ بِهِ يَحْيَى فَأَنْكَرَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَسَمِعْتُ أَحْمَدَ يَقُولُ ابْنُ عُيَيْنَةَ زَعَمُوا كَانَ يُنْكِرُهُ وَيَقُولُ أَيْشِ هَذَا طَلْحَةُ عَنْ أَبِيهِ عَنْ جَدِّهِ\hadithno{132}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Talhah ibn Musarrif: I saw the Messenger of Allah (ﷺ) wiping his head once up to his nape. Musaddad reported: He wiped his head from front to back until he moved his hands from beneath the ears. Abu Dawud said: I heard Ahmad say: People thought that Ibn 'Uyainah had considered it to be munkar (rejected) and said: What is this chain: Talhah - his father - his grandfather ?}}
\hadithdefcmd{abudawud}{133}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عَبَّادُ بْنُ مَنْصُورٍ، عَنْ عِكْرِمَةَ بْنِ خَالِدٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ ‏.‏ فَذَكَرَ الْحَدِيثَ كُلَّهُ ثَلاَثًا ثَلاَثًا قَالَ وَمَسَحَ بِرَأْسِهِ وَأُذُنَيْهِ مَسْحَةً وَاحِدَةً ‏.‏\hadithno{133}\hadithgrade{Al-Albani: Very Daif; Muhammad Muhyi Al-Din Abdul Hamid: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: Sa'id ibn Jubayr reported: Ibn Abbas saw the Messenger of Allah (ﷺ) performed ablution. He narrated the tradition which says that he (the Prophet) performed each detail of ablution three times. He wiped his head and ears once}}
\hadithdefcmd{abudawud}{134}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، وَقُتَيْبَةُ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ سِنَانِ بْنِ رَبِيعَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي أُمَامَةَ، وَذَكَرَ، وُضُوءَ النَّبِيِّ، صلى الله عليه وسلم قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْسَحُ الْمَأْقَيْنِ ‏.‏ قَالَ وَقَالَ ‏ "‏ الأُذُنَانِ مِنَ الرَّأْسِ ‏"‏ ‏.‏ قَالَ سُلَيْمَانُ بْنُ حَرْبٍ يَقُولُهَا أَبُو أُمَامَةَ ‏.‏ قَالَ قُتَيْبَةُ قَالَ حَمَّادٌ لاَ أَدْرِي هُوَ مِنْ قَوْلِ النَّبِيِّ صلى الله عليه وسلم أَوْ مِنْ أَبِي أُمَامَةَ ‏.‏ يَعْنِي قِصَّةَ الأُذُنَيْنِ ‏.‏ قَالَ قُتَيْبَةُ عَنْ سِنَانٍ أَبِي رَبِيعَةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ ابْنُ رَبِيعَةَ كُنْيَتُهُ أَبُو رَبِيعَةَ ‏.‏\hadithno{134}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuUmamah: AbuUmamah mentioned how the Messenger of Allah (ﷺ) performed ablution, saying that he used to wipe the corners of his eyes, and he said that the ears are treated as part of the head. Sulaiman b. Harb said: the wording "the ears are treated as part of the head" were uttered by Abu Umamah. Hammad said: I do not know whether the phrase "the ears are treated as part of the head" was he statement of the Prophet (ﷺ) or of Abu Umamah}}
\hadithdefcmd{abudawud}{135}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ الطُّهُورُ فَدَعَا بِمَاءٍ فِي إِنَاءٍ فَغَسَلَ كَفَّيْهِ ثَلاَثًا ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ ذِرَاعَيْهِ ثَلاَثًا ثُمَّ مَسَحَ بِرَأْسِهِ فَأَدْخَلَ إِصْبَعَيْهِ السَّبَّاحَتَيْنِ فِي أُذُنَيْهِ وَمَسَحَ بِإِبْهَامَيْهِ عَلَى ظَاهِرِ أُذُنَيْهِ وَبِالسَّبَّاحَتَيْنِ بَاطِنَ أُذُنَيْهِ ثُمَّ غَسَلَ رِجْلَيْهِ ثَلاَثًا ثَلاَثًا ثُمَّ قَالَ ‏"‏ هَكَذَا الْوُضُوءُ فَمَنْ زَادَ عَلَى هَذَا أَوْ نَقَصَ فَقَدْ أَسَاءَ وَظَلَمَ ‏"‏ ‏.‏ أَوْ ‏"‏ ظَلَمَ وَأَسَاءَ ‏"‏ ‏.‏\hadithno{135}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: A man came to the Prophet (ﷺ) and asked him: Messenger of Allah, how is the ablution (to performed)? He (the Prophet) then called for water in a vessel and washed his hands up to the wrists three times, then washed his face three times, and washed his forearms three times. He then wiped his head and inserted both his index fingers in his ear-holes; he wiped the back of his ears with his thumbs and the front of his ears with the index fingers. He then washed his feet three times. Then he said: This is how ablution should be performed. If anyone does more or less than this, he has done wrong and transgressed, or (said) transgressed and done wrong}}
\hadithdefcmd{abudawud}{136}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا زَيْدٌ، - يَعْنِي ابْنَ الْحُبَابِ - حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ ثَوْبَانَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْفَضْلِ الْهَاشِمِيُّ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ مَرَّتَيْنِ مَرَّتَيْنِ ‏.‏\hadithno{136}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (my peace be upon him) washed the limbs in ablution twice}}
\hadithdefcmd{abudawud}{137}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، حَدَّثَنَا زَيْدٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، قَالَ قَالَ لَنَا ابْنُ عَبَّاسٍ أَتُحِبُّونَ أَنْ أُرِيَكُمْ، كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ فَدَعَا بِإِنَاءٍ فِيهِ مَاءٌ فَاغْتَرَفَ غُرْفَةً بِيَدِهِ الْيُمْنَى فَتَمَضْمَضَ وَاسْتَنْشَقَ ثُمَّ أَخَذَ أُخْرَى فَجَمَعَ بِهَا يَدَيْهِ ثُمَّ غَسَلَ وَجْهَهُ ثُمَّ أَخَذَ أُخْرَى فَغَسَلَ بِهَا يَدَهُ الْيُمْنَى ثُمَّ أَخَذَ أُخْرَى فَغَسَلَ بِهَا يَدَهُ الْيُسْرَى ثُمَّ قَبَضَ قَبْضَةً مِنَ الْمَاءِ ثُمَّ نَفَضَ يَدَهُ ثُمَّ مَسَحَ بِهَا رَأْسَهُ وَأُذُنَيْهِ ثُمَّ قَبَضَ قَبْضَةً أُخْرَى مِنَ الْمَاءِ فَرَشَّ عَلَى رِجْلِهِ الْيُمْنَى وَفِيهَا النَّعْلُ ثُمَّ مَسَحَهَا بِيَدَيْهِ يَدٍ فَوْقَ الْقَدَمِ وَيَدٍ تَحْتَ النَّعْلِ ثُمَّ صَنَعَ بِالْيُسْرَى مِثْلَ ذَلِكَ ‏.‏\hadithno{137}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Ata’ b. Yasar quoting Ibn ‘Abbas said:Do you like that I should show you how the Messenger of Allah (ﷺ) performed ablution? He then called for a vessel of water and took out a handful of water with his right hand. He then rinsed his mouth and snuffed up water. He then took out another handful of water and washed his face by both his hands together. He then took out another handful of water and washed his right hand and then washed his left hand by taking out another. He then took out some water and shook off his hand and wiped his head and ears with it. He then took out a handful of water and sprinkled it over his right foot in his shoe and wiped the upper part of the foot with his one hand, and beneath the shoe with his other hand. He then did the same with his left foot}}
\hadithdefcmd{abudawud}{138}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَلاَ أُخْبِرُكُمْ بِوُضُوءِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَوَضَّأَ مَرَّةً مَرَّةً ‏.‏\hadithno{138}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (157)}\hadithtrans{‘Ata’ b. Yasar quoting Ibn. ‘Abbas said:May I not tell you how the Messenger of Allah (ﷺ) performed ablution? He then performed ablution washing each limb once only}}
\hadithdefcmd{abudawud}{139}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ لَيْثًا، يَذْكُرُ عَنْ طَلْحَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ دَخَلْتُ - يَعْنِي - عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَتَوَضَّأُ وَالْمَاءُ يَسِيلُ مِنْ وَجْهِهِ وَلِحْيَتِهِ عَلَى صَدْرِهِ فَرَأَيْتُهُ يَفْصِلُ بَيْنَ الْمَضْمَضَةِ وَالاِسْتِنْشَاقِ ‏.‏\hadithno{139}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Grandfather of Talhah: I entered upon the Prophet (ﷺ) while he was performing ablution, and the water was running down his face and beard to his chest. I saw him rinsing his mouth and snuffing up water separately}}
\hadithdefcmd{abudawud}{140}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ أَحَدُكُمْ فَلْيَجْعَلْ فِي أَنْفِهِ مَاءً ثُمَّ لْيَنْثُرْ ‏"‏ ‏.‏\hadithno{140}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (162) Sahih Muslim (141)}\hadithtrans{Abu Hurairah reported:The Messenger of Allah (ﷺ) said: When any of you performs ablution, he should snuff up water in his nose and eject mucus}}
\hadithdefcmd{abudawud}{141}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ قَارِظٍ، عَنْ أَبِي غَطَفَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْتَنْثِرُوا مَرَّتَيْنِ بَالِغَتَيْنِ أَوْ ثَلاَثًا ‏"‏ ‏.‏\hadithno{141}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) said: Cleanse your nose well (after snuffing up water) twice or thrice}}
\hadithdefcmd{abudawud}{142}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ كَثِيرٍ، عَنْ عَاصِمِ بْنِ لَقِيطِ بْنِ صَبْرَةَ، عَنْ أَبِيهِ، لَقِيطِ بْنِ صَبْرَةَ قَالَ كُنْتُ وَافِدَ بَنِي الْمُنْتَفِقِ - أَوْ فِي وَفْدِ بَنِي الْمُنْتَفِقِ - إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَلَمَّا قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ نُصَادِفْهُ فِي مَنْزِلِهِ وَصَادَفْنَا عَائِشَةَ أُمَّ الْمُؤْمِنِينَ قَالَ فَأَمَرَتْ لَنَا بِخَزِيرَةٍ فَصُنِعَتْ لَنَا قَالَ وَأُتِينَا بِقِنَاعٍ - وَلَمْ يَقُلْ قُتَيْبَةُ الْقِنَاعَ وَالْقِنَاعُ الطَّبَقُ فِيهِ تَمْرٌ - ثُمَّ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ هَلْ أَصَبْتُمْ شَيْئًا أَوْ أُمِرَ لَكُمْ بِشَىْءٍ ‏"‏ ‏.‏ قَالَ قُلْنَا نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ فَبَيْنَا نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم جُلُوسٌ إِذْ دَفَعَ الرَّاعِي غَنَمَهُ إِلَى الْمُرَاحِ وَمَعَهُ سَخْلَةٌ تَيْعَرُ فَقَالَ ‏"‏ مَا وَلَّدْتَ يَا فُلاَنُ ‏"‏ ‏.‏ قَالَ بَهْمَةً ‏.‏ قَالَ فَاذْبَحْ لَنَا مَكَانَهَا شَاةً ‏.‏ ثُمَّ قَالَ لاَ تَحْسِبَنَّ - وَلَمْ يَقُلْ لاَ تَحْسَبَنَّ - أَنَّا مِنْ أَجْلِكَ ذَبَحْنَاهَا لَنَا غَنَمٌ مِائَةٌ لاَ نُرِيدُ أَنْ تَزِيدَ فَإِذَا وَلَّدَ الرَّاعِي بَهْمَةً ذَبَحْنَا مَكَانَهَا شَاةً ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لِي امْرَأَةً وَإِنَّ فِي لِسَانِهَا شَيْئًا يَعْنِي الْبَذَاءَ ‏.‏ قَالَ ‏"‏ فَطَلِّقْهَا إِذًا ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لَهَا صُحْبَةً وَلِي مِنْهَا وَلَدٌ ‏.‏ قَالَ ‏"‏ فَمُرْهَا - يَقُولُ عِظْهَا - فَإِنْ يَكُ فِيهَا خَيْرٌ فَسَتَفْعَلُ وَلاَ تَضْرِبْ ظَعِينَتَكَ كَضَرْبِكَ أُمَيَّتَكَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ أَخْبِرْنِي عَنِ الْوُضُوءِ ‏.‏ قَالَ ‏"‏ أَسْبِغِ الْوُضُوءَ وَخَلِّلْ بَيْنَ الأَصَابِعِ وَبَالِغْ فِي الاِسْتِنْشَاقِ إِلاَّ أَنْ تَكُونَ صَائِمًا ‏"‏ ‏.‏\hadithno{142}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Laqit ibn Sabirah: I was the leader of the delegation of Banu al-Muntafiq or (the narrator doubted) I was among the delegation of Banu al-Muntafiq that came to the Messenger of Allah (ﷺ). When we reached the Prophet, we did not find him in his house. We found there Aisha, the Mother of the Believers. She ordered that a dish called Khazirah should be prepared for us. It was then prepared. A tray containing dates was then presented to us. (The narrator Qutaybah did not mention the word qina', tray). Then the Messenger of Allah (ﷺ) came. He asked: Has anything been served to you or ordered for you? We replied: Yes, Messenger of Allah. While we were sitting in the company of the Messenger of Allah (ﷺ) we suddenly saw that a shepherd was driving a herd of sheep to their fold. He had with him a newly-born lamb that was crying. He (the Prophet) asked him: What did it bear, O so and so? He replied: A ewe. He then said: Slaughter for us in its place a sheep. Do not think that we are slaughtering it for you. We have one hundred sheep and we do not want their number to increase. Whenever a ewe is born, we slaughter a sheep in its place. (The narrator says that the Prophet (ﷺ) used the word la tahsabanna, do not think). I (the narrator Laqit) then said: Messenger of Allah, I have a wife who has something (wrong) in her tongue, i.e. she is insolent. He said: Then divorce her. I said: Messenger of Allah, she had company with me and I have children from her. He said: Then ask her (to obey you). If there is something good in her, she will do so (obey); and do not beat your wife as you beat your slave-girl. I said: Messenger of Allah, tell me about ablution. He said: Perform ablution in full and make the fingers go through the beard and snuff with water well except when you are fasting}}
\hadithdefcmd{abudawud}{143}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ كَثِيرٍ، عَنْ عَاصِمِ بْنِ لَقِيطِ بْنِ صَبْرَةَ، عَنْ أَبِيهِ، وَافِدِ بَنِي الْمُنْتَفِقِ، أَنَّهُ أَتَى عَائِشَةَ فَذَكَرَ مَعْنَاهُ ‏.‏ قَالَ فَلَمْ يَنْشَبْ أَنْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَقَلَّعُ يَتَكَفَّأُ ‏.‏ وَقَالَ عَصِيدَةٍ ‏.‏ مَكَانَ خَزِيرَةٍ ‏.‏\hadithno{143}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Laqit b. Sabirah reported that he was the leader of Banu’l-Muntafiq (name of a tribe). He came to ‘A’ishah. He then narrated the tradition in a similar manner. He said:The Prophet (ﷺ) then came shortly with rapid strides inclining forward. The narrator used the word ‘asidah (name of a dish) in this version instead of Khazirah}}
\hadithdefcmd{abudawud}{144}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، بِهَذَا الْحَدِيثِ قَالَ فِيهِ ‏ "‏ إِذَا تَوَضَّأْتَ فَمَضْمِضْ ‏"‏ ‏.‏\hadithno{144}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The version of Ibn Juraij has the working:“If you perform ablution, then rinse your mouth.”}}
\hadithdefcmd{abudawud}{145}{حَدَّثَنَا أَبُو تَوْبَةَ، - يَعْنِي الرَّبِيعَ بْنَ نَافِعٍ - حَدَّثَنَا أَبُو الْمَلِيحِ، عَنِ الْوَلِيدِ بْنِ زَوْرَانَ، عَنْ أَنَسٍ يَعْنِي ابْنَ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا تَوَضَّأَ أَخَذَ كَفًّا مِنْ مَاءٍ فَأَدْخَلَهُ تَحْتَ حَنَكِهِ فَخَلَّلَ بِهِ لِحْيَتَهُ وَقَالَ ‏ "‏ هَكَذَا أَمَرَنِي رَبِّي عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ابْنُ زَوْرَانَ رَوَى عَنْهُ حَجَّاجُ بْنُ حَجَّاجٍ وَأَبُو الْمَلِيحِ الرَّقِّيُّ ‏.‏\hadithno{145}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: Whenever the Messenger of Allah (ﷺ) performed ablution, he took a handful of water, and, putting it under his chin, made it go through his beard, saying: Thus did my Lord command me}}
\hadithdefcmd{abudawud}{146}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ ثَوْرٍ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ ثَوْبَانَ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً فَأَصَابَهُمُ الْبَرْدُ فَلَمَّا قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَمَرَهُمْ أَنْ يَمْسَحُوا عَلَى الْعَصَائِبِ وَالتَّسَاخِينِ ‏.‏\hadithno{146}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Thawban: The Messenger of Allah (ﷺ) sent out an expedition. They were affected by cold. When they returned to the Messenger of Allah (ﷺ), he commanded them to wipe over turbans and stockings}}
\hadithdefcmd{abudawud}{147}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ مُسْلِمٍ، عَنِ أَبِي مَعْقِلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ وَعَلَيْهِ عِمَامَةٌ قِطْرِيَّةٌ فَأَدْخَلَ يَدَهُ مِنْ تَحْتِ الْعِمَامَةِ فَمَسَحَ مُقَدَّمَ رَأْسِهِ وَلَمْ يَنْقُضِ الْعِمَامَةَ ‏.‏\hadithno{147}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: I saw the Messenger (ﷺ) perform ablution. He had a Qutri turban. He inserted his hand beneath the turban and wiped over the forelock, and did not untie the turban}}
\hadithdefcmd{abudawud}{148}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ عَمْرٍو، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنِ الْمُسْتَوْرِدِ بْنِ شَدَّادٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا تَوَضَّأَ يَدْلُكُ أَصَابِعَ رِجْلَيْهِ بِخِنْصَرِهِ ‏.‏\hadithno{148}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Mustawrid ibn Shaddad: I saw the Messenger of Allah (ﷺ) rubbing his toes with his little finger when he performed ablution}}
\hadithdefcmd{abudawud}{149}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عَبَّادُ بْنُ زِيَادٍ، أَنَّ عُرْوَةَ بْنَ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَاهُ الْمُغِيرَةَ، يَقُولُ عَدَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَعَهُ فِي غَزْوَةِ تَبُوكَ قَبْلَ الْفَجْرِ فَعَدَلْتُ مَعَهُ فَأَنَاخَ النَّبِيُّ صلى الله عليه وسلم فَتَبَرَّزَ ثُمَّ جَاءَ فَسَكَبْتُ عَلَى يَدِهِ مِنَ الإِدَاوَةِ فَغَسَلَ كَفَّيْهِ ثُمَّ غَسَلَ وَجْهَهُ ثُمَّ حَسَرَ عَنْ ذِرَاعَيْهِ فَضَاقَ كُمَّا جُبَّتِهِ فَأَدْخَلَ يَدَيْهِ فَأَخْرَجَهُمَا مِنْ تَحْتِ الْجُبَّةِ فَغَسَلَهُمَا إِلَى الْمِرْفَقِ وَمَسَحَ بِرَأْسِهِ ثُمَّ تَوَضَّأَ عَلَى خُفَّيْهِ ثُمَّ رَكِبَ فَأَقْبَلْنَا نَسِيرُ حَتَّى نَجِدَ النَّاسَ فِي الصَّلاَةِ قَدْ قَدَّمُوا عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ فَصَلَّى بِهِمْ حِينَ كَانَ وَقْتُ الصَّلاَةِ وَوَجَدْنَا عَبْدَ الرَّحْمَنِ وَقَدْ رَكَعَ بِهِمْ رَكْعَةً مِنْ صَلاَةِ الْفَجْرِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَفَّ مَعَ الْمُسْلِمِينَ فَصَلَّى وَرَاءَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ الرَّكْعَةَ الثَّانِيَةَ ثُمَّ سَلَّمَ عَبْدُ الرَّحْمَنِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَتِهِ ‏.‏ فَفَزِعَ الْمُسْلِمُونَ فَأَكْثَرُوا التَّسْبِيحَ لأَنَّهُمْ سَبَقُوا النَّبِيَّ صلى الله عليه وسلم بِالصَّلاَةِ فَلَمَّا سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لَهُمْ ‏"‏ قَدْ أَصَبْتُمْ ‏"‏ ‏.‏ أَوْ ‏"‏ قَدْ أَحْسَنْتُمْ ‏"‏ ‏.‏\hadithno{149}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (274 After  421)}\hadithtrans{Al-Mughirah b. Shu’bah reported:I was in the company of the Messenger of Allah (ﷺ) in the expedition of Tabuk. He abandoned the main road before the dawn prayer, and I also did the same along with him. The Prophet (ﷺ) made his camel kneel down and (went to ) relieve himself. He then came back and I poured water upon his hands from the skin-vessel. He then washed his hands and face. He tried to get his forearms out (of the gown), but the sleeves of the gown were too narrow, so he entered back both his hands, and brought them out from beneath the gown. He washed his forearms up to the elbows and wiped his head and wiped over his socks.80 He then mounted (his camel) and we began to proceed until we found people offering the prayer. They brought forward ‘Abd al-Rahman b. ‘Awf who was leading them in prayer. The Prophet(ﷺ) stood in the row side by side with other Muslims. He performed the second rak’ah of the prayer behind ‘Abd al-Rahman b. ‘Awf. Then ‘Abd al-Rahman uttered salutation. The Prophet(ﷺ) stood to perform the remaining rak’ah of the prayer. The Muslims were alarmed. They began to utter tasbih (Subhan Allah) presuming that they had offered prayer before the Prophet (ﷺ) had done. When he uttered the salutation (i.e. finished his prayer), he said: You were right, or (he said) you did well}}
\hadithdefcmd{abudawud}{150}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى يَعْنِي ابْنَ سَعِيدٍ، ح حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، عَنِ التَّيْمِيِّ، حَدَّثَنَا بَكْرٌ، عَنِ الْحَسَنِ، عَنِ ابْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ وَمَسَحَ نَاصِيَتَهُ ‏.‏ وَذَكَرَ فَوْقَ الْعِمَامَةِ - قَالَ عَنِ الْمُعْتَمِرِ - سَمِعْتُ أَبِي يُحَدِّثُ عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ عَنِ الْحَسَنِ عَنِ ابْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ الْمُغِيرَةِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَمْسَحُ عَلَى الْخُفَّيْنِ وَعَلَى نَاصِيَتِهِ وَعَلَى عِمَامَتِهِ ‏.‏ قَالَ بَكْرٌ وَقَدْ سَمِعْتُهُ مِنَ ابْنِ الْمُغِيرَةِ ‏.‏\hadithno{150}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (274)}\hadithtrans{Al-Mughirah b. Shu’bah said:The Messenger of Allah (ﷺ) performed ablution and wiped his forelock and turban. Another version says : The Messenger of Allah (ﷺ) wiped his socks and his forelock and his turban. Bakr said: I heard it from Ibn al-Mughirah}}
\hadithdefcmd{abudawud}{151}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنِي أَبِي، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ عُرْوَةَ بْنَ الْمُغِيرَةِ بْنِ شُعْبَةَ، يَذْكُرُ عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَكْبِهِ وَمَعِي إِدَاوَةٌ فَخَرَجَ لِحَاجَتِهِ ثُمَّ أَقْبَلَ فَتَلَقَّيْتُهُ بِالإِدَاوَةِ فَأَفْرَغْتُ عَلَيْهِ فَغَسَلَ كَفَّيْهِ وَوَجْهَهُ ثُمَّ أَرَادَ أَنْ يُخْرِجَ ذِرَاعَيْهِ وَعَلَيْهِ جُبَّةٌ مِنْ صُوفٍ مِنْ جِبَابِ الرُّومِ ضَيِّقَةُ الْكُمَّيْنِ فَضَاقَتْ فَادَّرَعَهُمَا ادِّرَاعًا ثُمَّ أَهْوَيْتُ إِلَى الْخُفَّيْنِ لأَنْزِعَهُمَا فَقَالَ لِي ‏ "‏ دَعِ الْخُفَّيْنِ فَإِنِّي أَدْخَلْتُ الْقَدَمَيْنِ الْخُفَّيْنِ وَهُمَا طَاهِرَتَانِ ‏"‏ ‏.‏ فَمَسَحَ عَلَيْهِمَا ‏.‏ قَالَ أَبِي قَالَ الشَّعْبِيُّ شَهِدَ لِي عُرْوَةُ عَلَى أَبِيهِ وَشَهِدَ أَبُوهُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{151}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (206) Sahih Muslim (274)}\hadithtrans{‘Urwah b. al-Mughirah reported his father as saying :We accompanied the Messenger of Allah (ﷺ) to a caravan, and I had a jug of water. He went to relieve himself and came back. I came to him with the jug of water and poured upon him. He washed his hands and face. He had a tight-sleeved Syrian woolen gown. He tried to get his forearms out, but the sleeve of the gown was very narrow, so he brought his hands out from under the gown. I then bent down to take off his socks. But he said to me : Leave them, for my feet were clean when I put them in, and he only wiped over them. Yunus said on the authority of al-Sha’bi that ‘Urwah narrated his tradition from his father before him, and his father reported it from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{152}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، وَعَنْ زُرَارَةَ بْنِ أَوْفَى، أَنَّ الْمُغِيرَةَ بْنَ شُعْبَةَ، قَالَ تَخَلَّفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ هَذِهِ الْقِصَّةَ ‏.‏ قَالَ فَأَتَيْنَا النَّاسَ وَعَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ يُصَلِّي بِهِمُ الصُّبْحَ فَلَمَّا رَأَى النَّبِيَّ صلى الله عليه وسلم أَرَادَ أَنْ يَتَأَخَّرَ فَأَوْمَأَ إِلَيْهِ أَنْ يَمْضِيَ - قَالَ - فَصَلَّيْتُ أَنَا وَالنَّبِيُّ صلى الله عليه وسلم خَلْفَهُ رَكْعَةً فَلَمَّا سَلَّمَ قَامَ النَّبِيُّ صلى الله عليه وسلم فَصَلَّى الرَّكْعَةَ الَّتِي سُبِقَ بِهَا وَلَمْ يَزِدْ عَلَيْهَا شَيْئًا ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو سَعِيدٍ الْخُدْرِيُّ وَابْنُ الزُّبَيْرِ وَابْنُ عُمَرَ يَقُولُونَ مَنْ أَدْرَكَ الْفَرْدَ مِنَ الصَّلاَةِ عَلَيْهِ سَجْدَتَا السَّهْوِ ‏.‏\hadithno{152}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Al-Mughirah b. Shu’bah said :The Messenger of Allah (ﷺ) lagged behind (in a journey). He then narrated this story saying : Then we came to people. ‘Abd al-Rahman was leading them in the dawn prayer. When he perceived the presence of the Prophet (ﷺ), he intended to retire. The Prophet (ﷺ) asked him to continue and I and the Prophet (ﷺ)offered one rak’ah of prayer behind him. When he had pronounced the salutation, the Prophet(ﷺ) got up and offered the rak’ah which had been finished before, and he made no addition to it. Abu Dawud said: Abu Sa’id al-Khudri, Ibn al-Zubair and Ibn ‘Umar hold the opinion that whoever gets an odd number of the rak’ahs of prayer, he should perform two prostrations on account of forgetfulness}}
\hadithdefcmd{abudawud}{153}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرٍ، - يَعْنِي ابْنَ حَفْصِ بْنِ عُمَرَ بْنِ سَعْدٍ - سَمِعَ أَبَا عَبْدِ اللَّهِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، أَنَّهُ شَهِدَ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ يَسْأَلُ بِلاَلاً عَنْ وُضُوءِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ كَانَ يَخْرُجُ يَقْضِي حَاجَتَهُ فَآتِيهِ بِالْمَاءِ فَيَتَوَضَّأُ وَيَمْسَحُ عَلَى عِمَامَتِهِ وَمُوقَيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ هُوَ أَبُو عَبْدِ اللَّهِ مَوْلَى بَنِي تَيْمِ بْنِ مُرَّةَ ‏.‏\hadithno{153}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu ‘Abd al-Rahman al-Sulami said that he witnessed ‘Abd al-Rahman b. ‘Awf asking Bilal about the ablution of the Prophet (ﷺ). Bilal said:He went out to relieve himself. Then I brought water for him and he performed ablution, and wiped over his turban and socks}}
\hadithdefcmd{abudawud}{154}{حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ الدِّرْهَمِيُّ، حَدَّثَنَا ابْنُ دَاوُدَ، عَنْ بُكَيْرِ بْنِ عَامِرٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، أَنَّ جَرِيرًا، بَالَ ثُمَّ تَوَضَّأَ فَمَسَحَ عَلَى الْخُفَّيْنِ وَقَالَ مَا يَمْنَعُنِي أَنْ أَمْسَحَ وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ قَالُوا إِنَّمَا كَانَ ذَلِكَ قَبْلَ نُزُولِ الْمَائِدَةِ ‏.‏ قَالَ مَا أَسْلَمْتُ إِلاَّ بَعْدَ نُزُولِ الْمَائِدَةِ ‏.‏\hadithno{154}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Abu Zur’ah b. ‘Amr b. Jarir said :Jarir urinated. He then performed ablution and wiped over the socks. He said: What can prevent me from wiping (over the socks); I saw the Messenger of Allah (doing so). They (the people) said: This (action of yours) might be valid before the revelation of Surat al-Ma’idah. He replied: I embraced Islam after the revelation of Surat al-Ma’idah}}
\hadithdefcmd{abudawud}{155}{حَدَّثَنَا مُسَدَّدٌ، وَأَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا دَلْهَمُ بْنُ صَالِحٍ، عَنْ حُجَيْرِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّجَاشِيَّ، أَهْدَى إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم خُفَّيْنِ أَسْوَدَيْنِ سَاذَجَيْنِ فَلَبِسَهُمَا ثُمَّ تَوَضَّأَ وَمَسَحَ عَلَيْهِمَا ‏.‏ قَالَ مُسَدَّدٌ عَنْ دَلْهَمِ بْنِ صَالِحٍ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا مِمَّا تَفَرَّدَ بِهِ أَهْلُ الْبَصْرَةِ ‏.‏\hadithno{155}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMusa al-Ash'ari: Negus presented to the Messenger of Allah (ﷺ) two black and simple socks. He put them on; then he performed ablution and wiped over them. Musaddad reported this tradition from Dulham b. Salih. Abu Dawud said: This tradition has been narrated by the people of Basrah alone}}
\hadithdefcmd{abudawud}{156}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ حَىٍّ، - هُوَ الْحَسَنُ بْنُ صَالِحٍ - عَنْ بُكَيْرِ بْنِ عَامِرٍ الْبَجَلِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي نُعْمٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَسَحَ عَلَى الْخُفَّيْنِ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ أَنَسِيتَ قَالَ ‏ "‏ بَلْ أَنْتَ نَسِيتَ بِهَذَا أَمَرَنِي رَبِّي عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{156}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Mughirah b. Shu’bah said:The Messenger of Allah (ﷺ) wiped over the socks and I said: Messenger of Allah, have you forgotten ? He said: My Lord has commanded me to do this}}
\hadithdefcmd{abudawud}{157}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، وَحَمَّادٍ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي عَبْدِ اللَّهِ الْجَدَلِيِّ، عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَسْحُ عَلَى الْخُفَّيْنِ لِلْمُسَافِرِ ثَلاَثَةُ أَيَّامٍ وَلِلْمُقِيمِ يَوْمٌ وَلَيْلَةٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ مَنْصُورُ بْنُ الْمُعْتَمِرِ عَنْ إِبْرَاهِيمَ التَّيْمِيِّ بِإِسْنَادِهِ قَالَ فِيهِ وَلَوِ اسْتَزَدْنَاهُ لَزَادَنَا ‏.‏\hadithno{157}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Khuzaymah ibn Thabit: The Prophet (ﷺ) said: The time limit for wiping over the socks for a traveller is three days (and three nights) and for a resident it is one day and one night. Abu Dawud said: Another version adds: Had we requested him to extend (the period of wiping), he would have extended}}
\hadithdefcmd{abudawud}{158}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا عَمْرُو بْنُ الرَّبِيعِ بْنِ طَارِقٍ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَزِينٍ، عَنْ مُحَمَّدِ بْنِ يَزِيدَ، عَنْ أَيُّوبَ بْنِ قَطَنٍ، عَنْ أُبَىِّ بْنِ عِمَارَةَ، - قَالَ يَحْيَى بْنُ أَيُّوبَ وَكَانَ قَدْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِلْقِبْلَتَيْنِ - أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَمْسَحُ عَلَى الْخُفَّيْنِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ يَوْمًا قَالَ ‏"‏ يَوْمًا ‏"‏ ‏.‏ قَالَ وَيَوْمَيْنِ قَالَ ‏"‏ وَيَوْمَيْنِ ‏"‏ ‏.‏ قَالَ وَثَلاَثَةً قَالَ ‏"‏ نَعَمْ وَمَا شِئْتَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ أَبِي مَرْيَمَ الْمِصْرِيُّ عَنْ يَحْيَى بْنِ أَيُّوبَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَزِينٍ عَنْ مُحَمَّدِ بْنِ يَزِيدَ بْنِ أَبِي زِيَادٍ عَنْ عُبَادَةَ بْنِ نُسَىٍّ عَنْ أُبَىِّ بْنِ عِمَارَةَ قَالَ فِيهِ حَتَّى بَلَغَ سَبْعًا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ وَمَا بَدَا لَكَ ‏"‏ قَالَ أَبُو دَاوُدَ وَقَدِ اخْتُلِفَ فِي إِسْنَادِهِ وَلَيْسَ هُوَ بِالْقَوِيِّ وَرَوَاهُ ابْنُ أَبِي مَرْيَمَ وَيَحْيَى بْنُ إِسْحَاقَ السِّيْلَحِينِيُّ عَنْ يَحْيَى بْنِ أَيُّوبَ وَقَدِ اخْتُلِفَ فِي إِسْنَادِهِ ‏.‏\hadithno{158}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ubayy ibn Umarah: I asked: Messenger of Allah (ﷺ) may I wipe over the socks? He replied: Yes. He asked: For one day? He replied: For one day. He again asked: And for two days? He replied: For two days too. He again asked: And for three days? He replied: Yes, as long as you wish. Abu Dawud said: Another version says: He asked him about the period until he reached the period of seven days. The Messenger of Allah (ﷺ) replied: Yes, as long as you wish (i.e. there is no time limit). Abu Dawud said: There is a variance in the chain of narrators of this tradition. The chain is not strong. Another chain from Yahya b. Ayyub is also disputed}}
\hadithdefcmd{abudawud}{159}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، عَنْ وَكِيعٍ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ أَبِي قَيْسٍ الأَوْدِيِّ، - هُوَ عَبْدُ الرَّحْمَنِ بْنُ ثَرْوَانَ - عَنْ هُزَيْلِ بْنِ شُرَحْبِيلَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ وَمَسَحَ عَلَى الْجَوْرَبَيْنِ وَالنَّعْلَيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ لاَ يُحَدِّثُ بِهَذَا الْحَدِيثِ لأَنَّ الْمَعْرُوفَ عَنِ الْمُغِيرَةِ أَنَّ النَّبِيَّ صلى الله عليه وسلم مَسَحَ عَلَى الْخُفَّيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُوِيَ هَذَا أَيْضًا عَنْ أَبِي مُوسَى الأَشْعَرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ مَسَحَ عَلَى الْجَوْرَبَيْنِ ‏.‏ وَلَيْسَ بِالْمُتَّصِلِ وَلاَ بِالْقَوِيِّ ‏.‏ قَالَ أَبُو دَاوُدَ وَمَسَحَ عَلَى الْجَوْرَبَيْنِ عَلِيُّ بْنُ أَبِي طَالِبٍ وَابْنُ مَسْعُودٍ وَالْبَرَاءُ بْنُ عَازِبٍ وَأَنَسُ بْنُ مَالِكٍ وَأَبُو أُمَامَةَ وَسَهْلُ بْنُ سَعْدٍ وَعَمْرُو بْنُ حُرَيْثٍ وَرُوِيَ ذَلِكَ عَنْ عُمَرَ بْنِ الْخَطَّابِ وَابْنِ عَبَّاسٍ ‏.‏\hadithno{159}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Mughirah ibn Shu'bah: The Messenger of Allah (ﷺ) performed ablution and wiped over the stockings and shoes. Abu Dawud said: 'Abd al-Rahman b. Mahdi did not narrate this tradition because the familiar version from al-Mughirah says that the Prophet (ﷺ) wiped over the socks. Abu Musa al-Ash'ari has also reported: The Prophet (ﷺ) wiped over stockings. But the chain of narrators of this tradition is neither continous nor strong. 'Ali b. Abi Talib, Ibn Mas'ud, al-Bara' b. 'Aziz, Anas b. Malik, Abu Umamah, Sahl b. Sa'd and 'Amr b. Huriath also wiped over the stockings}}
\hadithdefcmd{abudawud}{160}{حَدَّثَنَا مُسَدَّدٌ، وَعَبَّادُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا هُشَيْمٌ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ أَبِيهِ، - قَالَ عَبَّادٌ - قَالَ أَخْبَرَنِي أَوْسُ بْنُ أَبِي أَوْسٍ الثَّقَفِيُّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ وَمَسَحَ عَلَى نَعْلَيْهِ وَقَدَمَيْهِ ‏.‏ وَقَالَ عَبَّادٌ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى كِظَامَةَ قَوْمٍ - يَعْنِي الْمِيضَأَةَ وَلَمْ يَذْكُرْ مُسَدَّدٌ الْمِيضَأَةَ وَالْكِظَامَةَ ثُمَّ اتَّفَقَا - فَتَوَضَّأَ وَمَسَحَ عَلَى نَعْلَيْهِ وَقَدَمَيْهِ ‏.‏\hadithno{160}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aws ibn AbuAws ath-Thaqafi: The Messenger of Allah (ﷺ) performed ablution and wiped over his shoes and feet. Abbad (a sub-narrator) said: The Messenger of Allah (ﷺ) came to the well of a people. Musaddad did not mention the words Midat (a place where ablution is performed), and Kazamah (well). Then both agreed on the wording:"He performed ablution and wiped over his shoes and feet}}
\hadithdefcmd{abudawud}{161}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، قَالَ ذَكَرَهُ أَبِي عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَمْسَحُ عَلَى الْخُفَّيْنِ ‏.‏ وَقَالَ غَيْرُ مُحَمَّدٍ عَلَى ظَهْرِ الْخُفَّيْنِ ‏.‏\hadithno{161}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Mughirah ibn Shu'bah: The Messenger of Allah (ﷺ) wiped over the socks. Another version adds: "On the back (upper part) of the socks}}
\hadithdefcmd{abudawud}{162}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ خَيْرٍ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ لَوْ كَانَ الدِّينُ بِالرَّأْىِ لَكَانَ أَسْفَلُ الْخُفِّ أَوْلَى بِالْمَسْحِ مِنْ أَعْلاَهُ وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ عَلَى ظَاهِرِ خُفَّيْهِ ‏.‏\hadithno{162}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: If the religion were based on opinion, it would be more important to wipe the under part of the shoe than the upper but I have seen the Messenger of Allah (ﷺ) wiping over the upper part of his shoes}}
\hadithdefcmd{abudawud}{163}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنِ الأَعْمَشِ، بِإِسْنَادِهِ بِهَذَا الْحَدِيثِ قَالَ مَا كُنْتُ أُرَى بَاطِنَ الْقَدَمَيْنِ إِلاَّ أَحَقَّ بِالْغَسْلِ حَتَّى رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ عَلَى ظَهْرِ خُفَّيْهِ ‏.‏\hadithno{163}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{This tradition has been transmitted through a different chain of narrators. This version adds:“I always preferred to wash the under part of the feet until I saw the Messenger of Allah (ﷺ) wiping the upper part of them}}
\hadithdefcmd{abudawud}{164}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، بِهَذَا الْحَدِيثِ قَالَ لَوْ كَانَ الدِّينُ بِالرَّأْىِ لَكَانَ بَاطِنُ الْقَدَمَيْنِ أَحَقَّ بِالْمَسْحِ مِنْ ظَاهِرِهِمَا وَقَدْ مَسَحَ النَّبِيُّ صلى الله عليه وسلم عَلَى ظَهْرِ خُفَّيْهِ وَرَوَاهُ وَكِيعٌ عَنِ الأَعْمَشِ بِإِسْنَادِهِ قَالَ كُنْتُ أُرَى أَنَّ بَاطِنَ الْقَدَمَيْنِ أَحَقُّ بِالْمَسْحِ مِنْ ظَاهِرِهِمَا حَتَّى رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ عَلَى ظَاهِرِهِمَا ‏.‏ قَالَ وَكِيعٌ يَعْنِي الْخُفَّيْنِ ‏.‏ وَرَوَاهُ عِيسَى بْنُ يُونُسَ عَنِ الأَعْمَشِ كَمَا رَوَاهُ وَكِيعٌ وَرَوَاهُ أَبُو السَّوْدَاءِ عَنِ ابْنِ عَبْدِ خَيْرٍ عَنْ أَبِيهِ قَالَ رَأَيْتُ عَلِيًّا تَوَضَّأَ فَغَسَلَ ظَاهِرَ قَدَمَيْهِ وَقَالَ لَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{164}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{A ‘mash transmitted this tradition saying:If religion were based on opinion, it would be more proper to wipe the under part of the feet than the upper. The Prophet (ﷺ) wiped over the upper part of his shoes. The narrator Waki’ said: I saw ‘ Ali perform ablution and wash the upper part of his feet, and say : Had I not seen the Messenger of Allah(ﷺ) doing like this –and he narrated the tradition in full}}
\hadithdefcmd{abudawud}{165}{حَدَّثَنَا مُوسَى بْنُ مَرْوَانَ، وَمَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا الْوَلِيدُ، - قَالَ مَحْمُودٌ - أَخْبَرَنَا ثَوْرُ بْنُ يَزِيدَ، عَنْ رَجَاءِ بْنِ حَيْوَةَ، عَنْ كَاتِبِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ وَضَّأْتُ النَّبِيَّ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ فَمَسَحَ أَعْلَى الْخُفَّيْنِ وَأَسْفَلَهُمَا ‏.‏ قَالَ أَبُو دَاوُدَ وَبَلَغَنِي أَنَّهُ لَمْ يَسْمَعْ ثَوْرٌ هَذَا الْحَدِيثَ مِنْ رَجَاءٍ ‏.‏\hadithno{165}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Mughirah ibn Shu'bah: I poured water while the Prophet (ﷺ) performed ablution in the battle of Tabuk. He wiped over the upper part of the socks and their lower part. Abu Dawud said: I have been told that Thawr did not hear this tradition from Raja}}
\hadithdefcmd{abudawud}{166}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، - هُوَ الثَّوْرِيُّ - عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ سُفْيَانَ بْنِ الْحَكَمِ الثَّقَفِيِّ، أَوِ الْحَكَمِ بْنِ سُفْيَانَ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا بَالَ يَتَوَضَّأُ وَيَنْتَضِحُ ‏.‏ قَالَ أَبُو دَاوُدَ وَافَقَ سُفْيَانَ جَمَاعَةٌ عَلَى هَذَا الإِسْنَادِ وَقَالَ بَعْضُهُمُ الْحَكَمُ أَوِ ابْنُ الْحَكَمِ ‏.‏\hadithno{166}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Hakam ibn Sufyan ath-Thaqafi: When the Messenger of Allah (ﷺ) urinated, he performed ablution and sprinkled water on private parts of the body. Abu Dawud said: A group of scholars agreed with Sufyan upon this chain of narrators. Some have mentioned the name of Sufyan b. al-Hakam, and others al-Hakam b. Sufyan}}
\hadithdefcmd{abudawud}{167}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ رَجُلٍ، مِنْ ثَقِيفٍ عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَالَ ثُمَّ نَضَحَ فَرْجَهُ ‏.‏\hadithno{167}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{A man from Thaqif on the authority of his father reported:I saw the Messenger of Allah (ﷺ) urinate, and he sprinkled water on the private parts of his body}}
\hadithdefcmd{abudawud}{168}{حَدَّثَنَا نَصْرُ بْنُ الْمُهَاجِرِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا زَائِدَةُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ الْحَكَمِ، أَوِ ابْنِ الْحَكَمِ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَالَ ثُمَّ تَوَضَّأَ وَنَضَحَ فَرْجَهُ ‏.‏\hadithno{168}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hakam or Ibn al-Hakam on the authority of his father reported:The Prophet (ﷺ) urinated; then he performed ablution and sprinkled water on the private parts of his body}}
\hadithdefcmd{abudawud}{169}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، سَمِعْتُ مُعَاوِيَةَ، - يَعْنِي ابْنَ صَالِحٍ - يُحَدِّثُ عَنْ أَبِي عُثْمَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم خُدَّامَ أَنْفُسِنَا نَتَنَاوَبُ الرِّعَايَةَ رِعَايَةَ إِبِلِنَا فَكَانَتْ عَلَىَّ رِعَايَةُ الإِبِلِ فَرَوَّحْتُهَا بِالْعَشِيِّ فَأَدْرَكْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ النَّاسَ فَسَمِعْتُهُ يَقُولُ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ يَتَوَضَّأُ فَيُحْسِنُ الْوُضُوءَ ثُمَّ يَقُومُ فَيَرْكَعُ رَكْعَتَيْنِ يُقْبِلُ عَلَيْهِمَا بِقَلْبِهِ وَوَجْهِهِ إِلاَّ قَدْ أَوْجَبَ ‏"‏ ‏.‏ فَقُلْتُ بَخْ بَخْ مَا أَجْوَدَ هَذِهِ ‏.‏ فَقَالَ رَجُلٌ مِنْ بَيْنِ يَدَىَّ الَّتِي قَبْلَهَا يَا عُقْبَةُ أَجْوَدُ مِنْهَا ‏.‏ فَنَظَرْتُ فَإِذَا هُوَ عُمَرُ بْنُ الْخَطَّابِ فَقُلْتُ مَا هِيَ يَا أَبَا حَفْصٍ قَالَ إِنَّهُ قَالَ آنِفًا قَبْلَ أَنْ تَجِيءَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ يَتَوَضَّأُ فَيُحْسِنُ الْوُضُوءَ ثُمَّ يَقُولُ حِينَ يَفْرُغُ مِنْ وُضُوئِهِ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ إِلاَّ فُتِحَتْ لَهُ أَبْوَابُ الْجَنَّةِ الثَّمَانِيَةُ يَدْخُلُ مِنْ أَيِّهَا شَاءَ ‏"‏ ‏.‏ قَالَ مُعَاوِيَةُ وَحَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ عَنْ أَبِي إِدْرِيسَ عَنْ عُقْبَةَ بْنِ عَامِرٍ ‏.‏\hadithno{169}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (234)}\hadithtrans{‘Uqbah b. ‘Amir said:We served ourselves in the company of Messenger of Allah (ﷺ). We tended our camels by turn. One day I had my turn to tend the camels, and I drove them in the afternoon. I found the Messenger of Allah (ﷺ) addressing the people. I heard him say: Anyone amongst you who performs ablution, and does it well, then he stands and offers two rak’ahs of prayer, concentrating on it with his heart and body, Paradise will be his lot by all means. I said: Ha-ha! How fine it is! A man in front of me said: The action (mentioned by the Prophet) earlier, O ‘Uqbah, is finer that this one. I looked at him and found him to be ‘Umar b. al-Khattab. I asked him: What is that, O Abu Hafs? He replied: He (the Prophet) had said before you came: If any one of you performs ablution, and does it well, and when he finishes the ablution, he utters the words : I bear witness that there is no deity except Allah, He has no associate, and I bear witness that Muhammad is His Servant and His Messenger, all the eight doors of Paradise will be opened for him; he may enter (through) any of them. Mu’awiyah said: Rabi’ah b. Yazid narrated this tradition to me from Abu Idris and the authority of ‘Uqbah b.’Amir}}
\hadithdefcmd{abudawud}{170}{حَدَّثَنَا الْحُسَيْنُ بْنُ عِيسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، عَنْ حَيْوَةَ، - وَهُوَ ابْنُ شُرَيْحٍ - عَنْ أَبِي عَقِيلٍ، عَنِ ابْنِ عَمِّهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ أَمْرَ الرِّعَايَةِ قَالَ عِنْدَ قَوْلِهِ ‏ "‏ فَأَحْسَنَ الْوُضُوءَ ‏"‏ ‏.‏ ثُمَّ رَفَعَ بَصَرَهُ إِلَى السَّمَاءِ ‏.‏ فَقَالَ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ مُعَاوِيَةَ ‏.‏\hadithno{170}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Uqbah b. ‘Amir al-JuhanI narrated this tradition from the Prophet(ﷺ) in a similar way. He did not mention about tending the camels. After the words “and he performed ablution well” he added the words:“he then raises his eyes towards the sky”. He transmitted the tradition conveying the same meaning as that of Mu’awiyah}}
\hadithdefcmd{abudawud}{171}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا شَرِيكٌ، عَنْ عَمْرِو بْنِ عَامِرٍ الْبَجَلِيِّ، - قَالَ مُحَمَّدٌ هُوَ أَبُو أَسَدِ بْنِ عَمْرٍو - قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنِ الْوُضُوءِ، فَقَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَوَضَّأُ لِكُلِّ صَلاَةٍ وَكُنَّا نُصَلِّي الصَّلَوَاتِ بِوُضُوءٍ وَاحِدٍ ‏.‏\hadithno{171}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (214)}\hadithtrans{Abu Asad b. ‘Amr said:I asked Anas b. Malik about ablution. He replied: The Prophet (ﷺ) performed ablution for each prayer and we offered (many) prayers with the same ablution}}
\hadithdefcmd{abudawud}{172}{حَدَّثَنَا مُسَدَّدٌ، أَخْبَرَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي عَلْقَمَةُ بْنُ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ خَمْسَ صَلَوَاتٍ بِوُضُوءٍ وَاحِدٍ وَمَسَحَ عَلَى خُفَّيْهِ فَقَالَ لَهُ عُمَرُ إِنِّي رَأَيْتُكَ صَنَعْتَ الْيَوْمَ شَيْئًا لَمْ تَكُنْ تَصْنَعُهُ ‏.‏ قَالَ ‏ "‏ عَمْدًا صَنَعْتُهُ ‏"‏ ‏.‏\hadithno{172}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (277)}\hadithtrans{Buraidah on the authority of his father reported:The Messenger of Allah (ﷺ) performed five prayers with the same ablution of the occasion of the capture of Mecca, and he wiped over his socks. ‘Umar said to him(the Prophet): I saw you doing a thing today that you never did. He said: I did it deliberately}}
\hadithdefcmd{abudawud}{173}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ جَرِيرِ بْنِ حَازِمٍ، أَنَّهُ سَمِعَ قَتَادَةَ بْنَ دِعَامَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَدْ تَوَضَّأَ وَتَرَكَ عَلَى قَدَمَيْهِ مِثْلَ مَوْضِعِ الظُّفْرِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ارْجِعْ فَأَحْسِنْ وُضُوءَكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا الْحَدِيثُ لَيْسَ بِمَعْرُوفٍ عَنْ جَرِيرِ بْنِ حَازِمٍ وَلَمْ يَرْوِهِ إِلاَّ ابْنُ وَهْبٍ وَحْدَهُ وَقَدْ رُوِيَ عَنْ مَعْقِلِ بْنِ عُبَيْدِ اللَّهِ الْجَزَرِيِّ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنْ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ قَالَ ‏"‏ ارْجِعْ فَأَحْسِنْ وُضُوءَكَ ‏"‏ ‏.‏\hadithno{173}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas reported:A person came to the Messenger of Allah (ﷺ). He performed ablution and left a small part equal to the space of a nail upon his foot. The Messenger of Allah (ﷺ) said to him : Go back and perform ablution well. Abu Dawud said: This tradition is not known through Jarir b. Hazim. It was transmitted only by Ibn Wahab. Another version adds the wording : “ Go back and perform the ablution well.”}}
\hadithdefcmd{abudawud}{174}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا يُونُسُ، وَحُمَيْدٌ، عَنِ الْحَسَنِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى قَتَادَةَ ‏.‏\hadithno{174}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Hasan narrated from the Prophet (ﷺ) a tradition conveying the same meaning as that of Qatadah}}
\hadithdefcmd{abudawud}{175}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، - هُوَ ابْنُ سَعْدٍ - عَنْ خَالِدٍ، عَنْ بَعْضِ، أَصْحَابِ النَّبِيِّ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى رَجُلاً يُصَلِّي وَفِي ظَهْرِ قَدَمِهِ لُمْعَةٌ قَدْرُ الدِّرْهَمِ لَمْ يُصِبْهَا الْمَاءُ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يُعِيدَ الْوُضُوءَ وَالصَّلاَةَ ‏.‏\hadithno{175}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Some Companions of the Prophet: The Prophet (ﷺ) saw a person offering prayer, and on the back of his foot a small part equal to the space of a dirham remained unwashed; the water did not reach it. The Prophet (ﷺ) commanded him to repeat the ablution and prayer}}
\hadithdefcmd{abudawud}{176}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَعَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ شُكِيَ إِلَى النَّبِيِّ صلى الله عليه وسلم الرَّجُلُ يَجِدُ الشَّىْءَ فِي الصَّلاَةِ حَتَّى يُخَيَّلَ إِلَيْهِ فَقَالَ ‏ "‏ لاَ يَنْفَتِلُ حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏ ‏.‏\hadithno{176}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (137) Sahih Muslim (361)}\hadithtrans{Abbad b. Tamim reported from his uncle that a person made a complaint to the Prophet (ﷺ) that he entertained (doubt) as if something had happened to him which had rendered his ablution invalid. He (the Prophet) said:He should not cease (to pray) unless he hears a sound or perceives a smell (of passing wind)}}
\hadithdefcmd{abudawud}{177}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ فِي الصَّلاَةِ فَوَجَدَ حَرَكَةً فِي دُبُرِهِ أَحْدَثَ أَوْ لَمْ يُحْدِثْ فَأَشْكَلَ عَلَيْهِ فَلاَ يَنْصَرِفْ حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏ ‏.‏\hadithno{177}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (362)}\hadithtrans{Abu Hurairah said:The Messenger of Allah (ﷺ) said: If any one of you offers prayer and feels a movement between his paddocks, but is doubtful whether or not his ablution broke, he should not cease praying unless he hears a sound or perceives a smell}}
\hadithdefcmd{abudawud}{178}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، وَعَبْدُ الرَّحْمَنِ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي رَوْقٍ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَبَّلَهَا وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ أَبُو دَاوُدَ كَذَا رَوَاهُ الْفِرْيَابِيُّ وَغَيْرُهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ مُرْسَلٌ إِبْرَاهِيمُ التَّيْمِيُّ لَمْ يَسْمَعْ مِنْ عَائِشَةَ ‏.‏ قَالَ أَبُو دَاوُدَ مَاتَ إِبْرَاهِيمُ التَّيْمِيُّ وَلَمْ يَبْلُغْ أَرْبَعِينَ سَنَةً وَكَانَ يُكْنَى أَبَا أَسْمَاءَ ‏.‏\hadithno{178}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) kissed me and did not perform ablution. Abu Dawud said: This tradition is Mursal (i.e. where the link of the Companions is missing and the Successor reports from the Prophet directly). Ibrahim at-Taimi did not hear anything from 'Aishah. Abu Dawud said: Al-Firyabi and other narrated this tradition in a like manner}}
\hadithdefcmd{abudawud}{179}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ حَبِيبٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَبَّلَ امْرَأَةً مِنْ نِسَائِهِ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ عُرْوَةُ فَقُلْتُ لَهَا مَنْ هِيَ إِلاَّ أَنْتِ فَضَحِكَتْ ‏.‏ قَالَ أَبُو دَاوُدَ هَكَذَا رَوَاهُ زَائِدَةُ وَعَبْدُ الْحَمِيدِ الْحِمَّانِيُّ عَنْ سُلَيْمَانَ الأَعْمَشِ ‏.‏\hadithno{179}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah reported:The Prophet (ﷺ) kissed one of his wives and went out to pray (salah). He did not perform ablution. 'Urwah said: I said to her: Who is she except you! Thereupon she laughed. Abu Dawud said: The same version has been reported through a different chain of narrators}}
\hadithdefcmd{abudawud}{180}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مَخْلَدٍ الطَّالْقَانِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَغْرَاءَ - حَدَّثَنَا الأَعْمَشُ، أَخْبَرَنَا أَصْحَابٌ، لَنَا عَنْ عُرْوَةَ الْمُزَنِيِّ، عَنْ عَائِشَةَ، بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ لِرَجُلٍ احْكِ عَنِّي أَنَّ هَذَيْنِ - يَعْنِي حَدِيثَ الأَعْمَشِ هَذَا عَنْ حَبِيبٍ وَحَدِيثَهُ بِهَذَا الإِسْنَادِ فِي الْمُسْتَحَاضَةِ أَنَّهَا تَتَوَضَّأُ لِكُلِّ صَلاَةٍ - قَالَ يَحْيَى احْكِ عَنِّي أَنَّهُمَا شِبْهُ لاَ شَىْءَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُوِيَ عَنِ الثَّوْرِيِّ قَالَ مَا حَدَّثَنَا حَبِيبٌ إِلاَّ عَنْ عُرْوَةَ الْمُزَنِيِّ يَعْنِي لَمْ يُحَدِّثْهُمْ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ بِشَىْءٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَدْ رَوَى حَمْزَةُ الزَّيَّاتُ عَنْ حَبِيبٍ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ عَنْ عَائِشَةَ حَدِيثًا صَحِيحًا ‏.‏\hadithno{180}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{This tradition has been reported through another chain of narrators on the authority of 'Aishah. Abu Dawud said:Yahya b. Sa'id al-Qattan said to a person: Narrate these two tradition from me, that is to say, one tradition on the authority of al-A'mash from Habib (about kissing); another through the same chain about a woman who has prolonged flow of bloos and she is asked to perform ablution for every prayer. Yahya said: Narrate from me that both these traditions are weak in respect of their chains. Abu Dawud said: Al-Thawri is reported to have said: Habib narrated this tradition to us only on the authority of 'Urwat al-Muzani, that is, he did not narrated any tradition on the authority of 'Urwah b. al-Zubair. Abu Dawud said: Hamzah al-Zayyat reported a sound tradition on the authority of Habib, from 'Urwah b. al-Zubair from 'Aishah}}
\hadithdefcmd{abudawud}{181}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّهُ سَمِعَ عُرْوَةَ، يَقُولُ دَخَلْتُ عَلَى مَرْوَانَ بْنِ الْحَكَمِ فَذَكَرْنَا مَا يَكُونُ مِنْهُ الْوُضُوءُ ‏.‏ فَقَالَ مَرْوَانُ وَمِنْ مَسِّ الذَّكَرِ ‏.‏ فَقَالَ عُرْوَةُ مَا عَلِمْتُ ذَلِكَ ‏.‏ فَقَالَ مَرْوَانُ أَخْبَرَتْنِي بُسْرَةُ بِنْتُ صَفْوَانَ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ مَسَّ ذَكَرَهُ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{181}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Busrah daughter of Safwan: Abdullah ibn AbuBakr reported that he heard Urwah say: I entered upon Marwan ibn al-Hakam. We mentioned things that render the ablution void. Marwan said: Does it become void by touching the penis? Urwah replied: This I do not know. Marwan said: Busrah daughter of Safwan reported to me that she heard the Messenger of Allah (ﷺ) say: He who touches his penis should perform ablution}}
\hadithdefcmd{abudawud}{182}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو الْحَنَفِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَدْرٍ، عَنْ قَيْسِ بْنِ طَلْقٍ، عَنْ أَبِيهِ، قَالَ قَدِمْنَا عَلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم فَجَاءَ رَجُلٌ كَأَنَّهُ بَدَوِيٌّ فَقَالَ يَا نَبِيَّ اللَّهِ مَا تَرَى فِي مَسِّ الرَّجُلِ ذَكَرَهُ بَعْدَ مَا يَتَوَضَّأُ فَقَالَ ‏"‏ هَلْ هُوَ إِلاَّ مُضْغَةٌ مِنْهُ ‏"‏ ‏.‏ أَوْ قَالَ - ‏"‏ بَضْعَةٌ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ هِشَامُ بْنُ حَسَّانَ وَسُفْيَانُ الثَّوْرِيُّ وَشُعْبَةُ وَابْنُ عُيَيْنَةَ وَجَرِيرٌ الرَّازِيُّ عَنْ مُحَمَّدِ بْنِ جَابِرٍ عَنْ قَيْسِ بْنِ طَلْقٍ ‏.‏\hadithno{182}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Talq: We came upon the Prophet of Allah (ﷺ). A man came to him: he seemed to be a bedouin. He said: Prophet of Allah, what do you think about a man who touches his penis after performing ablution? He (ﷺ) replied: That is only a part of his body. Abu Dawud said: The tradition has been transmitted through a different chain of narrators}}
\hadithdefcmd{abudawud}{183}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُحَمَّدُ بْنُ جَابِرٍ، عَنْ قَيْسِ بْنِ طَلْقٍ، بِإِسْنَادِهِ وَمَعْنَاهُ وَقَالَ فِي الصَّلاَةِ ‏.‏\hadithno{183}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition has also been reported by Qais b. Talq through a different chain of narrators. This version adds the wording:"during the prayer}}
\hadithdefcmd{abudawud}{184}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ الرَّازِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوُضُوءِ مِنْ لُحُومِ الإِبِلِ فَقَالَ ‏"‏ تَوَضَّئُوا مِنْهَا ‏"‏ ‏.‏ وَسُئِلَ عَنْ لُحُومِ الْغَنَمِ فَقَالَ ‏"‏ لاَ تَتَوَضَّئُوا مِنْهَا ‏"‏ ‏.‏ وَسُئِلَ عَنِ الصَّلاَةِ فِي مَبَارِكِ الإِبِلِ فَقَالَ ‏"‏ لاَ تُصَلُّوا فِي مَبَارِكِ الإِبِلِ فَإِنَّهَا مِنَ الشَّيَاطِينِ ‏"‏ ‏.‏ وَسُئِلَ عَنِ الصَّلاَةِ فِي مَرَابِضِ الْغَنَمِ فَقَالَ ‏"‏ صَلُّوا فِيهَا فَإِنَّهَا بَرَكَةٌ ‏"‏ ‏.‏\hadithno{184}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Bara' ibn Azib: The Messenger of Allah (ﷺ) was asked about performing ablution after eating the flesh of the camel. He replied: Perform ablution, after eating it. He was asked about performing ablution after eating meat. He replied: Do not perform ablution after eating it. He was asked about saying prayer in places where the camels lie down. He replied: Do not offer prayer in places where the camels lie down. These are the places of Satan. He was asked about saying prayer in the sheepfolds. He replied: You may offer prayer in such places; these are the places of blessing}}
\hadithdefcmd{abudawud}{185}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَأَيُّوبُ بْنُ مُحَمَّدٍ الرَّقِّيُّ، وَعَمْرُو بْنُ عُثْمَانَ الْحِمْصِيُّ، - الْمَعْنَى - قَالُوا حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، أَخْبَرَنَا هِلاَلُ بْنُ مَيْمُونٍ الْجُهَنِيُّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، - قَالَ هِلاَلٌ لاَ أَعْلَمُهُ إِلاَّ عَنْ أَبِي سَعِيدٍ ‏.‏ وَقَالَ أَيُّوبُ وَعَمْرٌو أُرَاهُ - عَنْ أَبِي سَعِيدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِغُلاَمٍ وَهُوَ يَسْلُخُ شَاةً فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَنَحَّ حَتَّى أُرِيَكَ فَأَدْخَلَ يَدَهُ بَيْنَ الْجِلْدِ وَاللَّحْمِ فَدَحَسَ بِهَا حَتَّى تَوَارَتْ إِلَى الإِبْطِ ثُمَّ مَضَى فَصَلَّى لِلنَّاسِ وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ أَبُو دَاوُدَ زَادَ عَمْرٌو فِي حَدِيثِهِ - يَعْنِي - لَمْ يَمَسَّ مَاءً ‏.‏ وَقَالَ عَنْ هِلاَلِ بْنِ مَيْمُونٍ الرَّمْلِيِّ وَرَوَاهُ عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ وَأَبُو مُعَاوِيَةَ عَنْ هِلاَلٍ عَنْ عَطَاءٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً لَمْ يَذْكُرَا أَبَا سَعِيدٍ ‏.‏\hadithno{185}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) passed by a boy who was skinning a goat. The Messenger of Allah (ﷺ) said: Give it up until I show you. He (the Prophet) inserted his hand between the skin and the flesh until it reached the armpit. He then went away and led the people in prayer and he did not perform ablution. The version of Amr added that he did not touch water. Abu Dawud said: This tradition has been narrated though another chain of transmitters, making no mention of Abu Sa'id}}
\hadithdefcmd{abudawud}{186}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِالسُّوقِ دَاخِلاً مِنْ بَعْضِ الْعَالِيَةِ وَالنَّاسُ كَنَفَتَيْهِ فَمَرَّ بِجَدْىٍ أَسَكَّ مَيِّتٍ فَتَنَاوَلَهُ فَأَخَذَ بِأُذُنِهِ ثُمَّ قَالَ ‏ "‏ أَيُّكُمْ يُحِبُّ أَنَّ هَذَا لَهُ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{186}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2957)}\hadithtrans{Jabir narrated:The Messenger of Allah (ﷺ) passed by the market when on his return from one of the villages of 'Aliyah. People accompanied him from both sides. One the way he found a dead kid with both its ears joined together. He caught hold of it by its ear. He then said: Which of you likes to take it ? The narrator transmitted the tradition in full}}
\hadithdefcmd{abudawud}{187}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَكَلَ كَتِفَ شَاةٍ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{187}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (207) Sahih Muslim (354)}\hadithtrans{Ibn 'Abbas said:The Messenger of Allah (ﷺ) took (the meat of) a (goat's) shoulder and offered prayer and did not perform ablution}}
\hadithdefcmd{abudawud}{188}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ أَبِي صَخْرَةَ، جَامِعِ بْنِ شَدَّادٍ عَنِ الْمُغِيرَةِ بْنِ عَبْدِ اللَّهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ ضِفْتُ النَّبِيَّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَأَمَرَ بِجَنْبٍ فَشُوِيَ وَأَخَذَ الشَّفْرَةَ فَجَعَلَ يَحُزُّ لِي بِهَا مِنْهُ - قَالَ - فَجَاءَ بِلاَلٌ فَآذَنَهُ بِالصَّلاَةِ - قَالَ - فَأَلْقَى الشَّفْرَةَ وَقَالَ ‏ "‏ مَا لَهُ تَرِبَتْ يَدَاهُ ‏"‏ ‏.‏ وَقَامَ يُصَلِّي ‏.‏ زَادَ الأَنْبَارِيُّ وَكَانَ شَارِبِي وَفَى فَقَصَّهُ لِي عَلَى سِوَاكٍ ‏.‏ أَوْ قَالَ أَقُصُّهُ لَكَ عَلَى سِوَاكٍ ‏.‏\hadithno{188}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Mughirah ibn Shu'bah: One night I became the guest of the Prophet (ﷺ). He ordered that a piece of mutton be roasted, and it was roasted. He then took a knife and began to cut the meat with it for me. In the meantime Bilal came and called him for prayer. He threw the knife and said: What happened! may his hands be smeared with earth! He then stood for offering prayer. Al-Anbari added: My moustaches became lengthy. He trimmed them by placing a took-stick; or he said: I shall trim your moustaches by placing the tooth-stick there. Al-Anbari said: My moustaches became lengthy. He trimmed them by placing a tooth-stick ; or he said: I shall trim your moustaches by placing the tooth-stick there}}
\hadithdefcmd{abudawud}{189}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا سِمَاكٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَتِفًا ثُمَّ مَسَحَ يَدَهُ بِمِسْحٍ كَانَ تَحْتَهُ ثُمَّ قَامَ فَصَلَّى ‏.‏\hadithno{189}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) took a shoulder (of goat's meat) and after wiping his hand with a cloth on which he was sitting, he got up and prayed}}
\hadithdefcmd{abudawud}{190}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ يَحْيَى بْنِ يَعْمُرَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْتَهَشَ مِنْ كَتِفٍ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{190}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Abbas said:The Prophet (ﷺ) ate a little meat from a (goat's) shoulder. He then offered prayer and did not perform ablution}}
\hadithdefcmd{abudawud}{191}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ الْخَثْعَمِيُّ، حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَرَّبْتُ لِلنَّبِيِّ صلى الله عليه وسلم خُبْزًا وَلَحْمًا فَأَكَلَ ثُمَّ دَعَا بِوَضُوءٍ فَتَوَضَّأَ بِهِ ثُمَّ صَلَّى الظُّهْرَ ثُمَّ دَعَا بِفَضْلِ طَعَامِهِ فَأَكَلَ ثُمَّ قَامَ إِلَى الصَّلاَةِ وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{191}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad b. al-Munkadir said:I heard Jabir b. 'Abd Allah say: I presented bread and meat to the Prophet (ﷺ). He ate them and called for ablution water. he performed ablution and offered the noon (Dhuhr) prayer. He then called for the remaining food and ate it. He then got up and prayed and did not perform ablution}}
\hadithdefcmd{abudawud}{192}{حَدَّثَنَا مُوسَى بْنُ سَهْلٍ أَبُو عِمْرَانَ الرَّمْلِيُّ، حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ كَانَ آخِرُ الأَمْرَيْنِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم تَرْكَ الْوُضُوءِ مِمَّا غَيَّرَتِ النَّارُ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا اخْتِصَارٌ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏\hadithno{192}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir said:The last practice of the Messenger of Allah (ﷺ) was that he did not perform ablution after taking anything that was cooked with the help of fire. Abu Dawud said: This is the abridgment of the former tradition}}
\hadithdefcmd{abudawud}{193}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي كَرِيمَةَ، - قَالَ ابْنُ السَّرْحِ ابْنُ أَبِي كَرِيمَةَ مِنْ خِيَارِ الْمُسْلِمِينَ - قَالَ حَدَّثَنِي عُبَيْدُ بْنُ ثُمَامَةَ الْمُرَادِيُّ، قَالَ قَدِمَ عَلَيْنَا مِصْرَ عَبْدُ اللَّهِ بْنُ الْحَارِثِ بْنِ جَزْءٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَسَمِعْتُهُ يُحَدِّثُ فِي مَسْجِدِ مِصْرَ قَالَ لَقَدْ رَأَيْتُنِي سَابِعَ سَبْعَةٍ أَوْ سَادِسَ سِتَّةٍ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي دَارِ رَجُلٍ فَمَرَّ بِلاَلٌ فَنَادَاهُ بِالصَّلاَةِ فَخَرَجْنَا فَمَرَرْنَا بِرَجُلٍ وَبُرْمَتُهُ عَلَى النَّارِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَطَابَتْ بُرْمَتُكَ ‏"‏ ‏.‏ قَالَ نَعَمْ بِأَبِي أَنْتَ وَأُمِّي ‏.‏ فَتَنَاوَلَ مِنْهَا بَضْعَةً فَلَمْ يَزَلْ يَعْلِكُهَا حَتَّى أَحْرَمَ بِالصَّلاَةِ وَأَنَا أَنْظُرُ إِلَيْهِ ‏.‏\hadithno{193}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Harith ibn Jaz': One of the Companions of the Prophet (may peace be upon), came upon us in Egypt. When he was narrating traditions in the Mosque of Egypt, I heard him say: I was the seventh or the sixth person in the company of the Messenger of Allah ( peace be upon him) in the house of a person. In the meantime Bilal came and called him for prayer. He came out and passed by a person who had his fire-pan on the fire. The Messenger of Allah (ﷺ) said to him: Has the food in the fire-pan been cooked? He replied: Yes, my parents be sacrificed upon you. He then took a piece out of it and continued to chew it until he uttered the first takbir (AllahuAkbar) of the prayer. All this time I was looking at him}}
\hadithdefcmd{abudawud}{194}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي أَبُو بَكْرِ بْنُ حَفْصٍ، عَنِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوُضُوءُ مِمَّا أَنْضَجَتِ النَّارُ ‏"‏ ‏.‏\hadithno{194}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported:The Messenger of Allah (ﷺ) said: Perform ablution after eating anything which has been cooked by fire}}
\hadithdefcmd{abudawud}{195}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، عَنْ يَحْيَى، - يَعْنِي ابْنَ أَبِي كَثِيرٍ - عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا سُفْيَانَ بْنَ سَعِيدِ بْنِ الْمُغِيرَةِ، حَدَّثَهُ أَنَّهُ، دَخَلَ عَلَى أُمِّ حَبِيبَةَ فَسَقَتْهُ قَدَحًا مِنْ سَوِيقٍ فَدَعَا بِمَاءٍ فَتَمَضْمَضَ فَقَالَتْ يَا ابْنَ أُخْتِي أَلاَ تَوَضَّأُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ تَوَضَّئُوا مِمَّا غَيَّرَتِ النَّارُ ‏"‏ ‏.‏ أَوْ قَالَ مِمَّا مَسَّتِ النَّارُ ‏.‏ قَالَ أَبُو دَاوُدَ فِي حَدِيثِ الزُّهْرِيِّ يَا ابْنَ أَخِي ‏.‏\hadithno{195}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Umm Habibah: AbuSufyan ibn Sa'id ibn al-Mughirah reported that he entered upon Umm Habibah who presented him a glass of sawiq (a drink prepared with flour and water) to drink. He called for water and rinsed his mouth. She said: O my cousin, don't you perform ablution? The Prophet (ﷺ) said: Perform ablution after eating anything cooked with fire, or he said: anything touched by fire. Abu Dawud said: The version of al-Zuhri has: O my paternal cousin}}
\hadithdefcmd{abudawud}{196}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عَقِيلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم شَرِبَ لَبَنًا فَدَعَا بِمَاءٍ فَتَمَضْمَضَ ثُمَّ قَالَ ‏ "‏ إِنَّ لَهُ دَسَمًا ‏"‏ ‏.‏\hadithno{196}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (211) Sahih Muslim (358)}\hadithtrans{‘Abd Allah b.’Abbas said that the Prophet (peace be upon him) drank some milk and then rinsed his mouth saying :it contains greasiness}}
\hadithdefcmd{abudawud}{197}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، عَنْ زَيْدِ بْنِ الْحُبَابِ، عَنْ مُطِيعِ بْنِ رَاشِدٍ، عَنْ تَوْبَةَ الْعَنْبَرِيِّ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شَرِبَ لَبَنًا فَلَمْ يُمَضْمِضْ وَلَمْ يَتَوَضَّأْ وَصَلَّى ‏.‏ قَالَ زَيْدٌ دَلَّنِي شُعْبَةُ عَلَى هَذَا الشَّيْخِ ‏.‏\hadithno{197}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: The Messenger of Allah (ﷺ) drank some milk and he did not rinse his mouth nor did he perform ablution, and he offered the prayer}}
\hadithdefcmd{abudawud}{198}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي صَدَقَةُ بْنُ يَسَارٍ، عَنْ عَقِيلِ بْنِ جَابِرٍ، عَنْ جَابِرٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم - يَعْنِي فِي غَزْوَةِ ذَاتِ الرِّقَاعِ - فَأَصَابَ رَجُلٌ امْرَأَةَ رَجُلٍ مِنَ الْمُشْرِكِينَ فَحَلَفَ أَنْ لاَ أَنْتَهِي حَتَّى أُهَرِيقَ دَمًا فِي أَصْحَابِ مُحَمَّدٍ فَخَرَجَ يَتْبَعُ أَثَرَ النَّبِيِّ صلى الله عليه وسلم فَنَزَلَ النَّبِيُّ صلى الله عليه وسلم مَنْزِلاً فَقَالَ مَنْ رَجُلٌ يَكْلَؤُنَا فَانْتَدَبَ رَجُلٌ مِنَ الْمُهَاجِرِينَ وَرَجُلٌ مِنَ الأَنْصَارِ فَقَالَ ‏ "‏ كُونَا بِفَمِ الشِّعْبِ ‏"‏ ‏.‏ قَالَ فَلَمَّا خَرَجَ الرَّجُلاَنِ إِلَى فَمِ الشِّعْبِ اضْطَجَعَ الْمُهَاجِرِيُّ وَقَامَ الأَنْصَارِيُّ يُصَلِّي وَأَتَى الرَّجُلُ فَلَمَّا رَأَى شَخْصَهُ عَرَفَ أَنَّهُ رَبِيئَةٌ لِلْقَوْمِ فَرَمَاهُ بِسَهْمٍ فَوَضَعَهُ فِيهِ فَنَزَعَهُ حَتَّى رَمَاهُ بِثَلاَثَةِ أَسْهُمٍ ثُمَّ رَكَعَ وَسَجَدَ ثُمَّ انْتَبَهَ صَاحِبُهُ فَلَمَّا عَرَفَ أَنَّهُمْ قَدْ نَذِرُوا بِهِ هَرَبَ وَلَمَّا رَأَى الْمُهَاجِرِيُّ مَا بِالأَنْصَارِيِّ مِنَ الدَّمِ قَالَ سَبْحَانَ اللَّهِ أَلاَ أَنْبَهْتَنِي أَوَّلَ مَا رَمَى قَالَ كُنْتُ فِي سُورَةٍ أَقْرَأُهَا فَلَمْ أُحِبَّ أَنْ أَقْطَعَهَا ‏.‏\hadithno{198}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: We proceeded in the company of the Messenger of Allah (ﷺ) for the battle of Dhat ar-Riqa. One of the Muslims killed the wife of one of the unbelievers. He (the husband of the woman killed) took an oath saying: I shall not rest until I kill one of the companions of Muhammad. He went out following the footsteps of the Prophet (ﷺ). The Prophet (ﷺ) encamped at a certain place. He said: Who will keep a watch on us? A person from the Muhajirun (Emigrants) and another from the Ansar (Helpers) responded. He said: Go to the mouth of the mountain-pass. When they went to the mouth of the mountain-pass the man from the Muhajirun lay down while the man from the Ansar stood praying. The man (enemy) came to them. When he saw the person he realised that he was the watchman of the Muslims. He shot him with an arrow and hit the target. But he (took the arrow out and) threw it away. He (the enemy) then shot three arrows. Then he (the Muslim) bowed and prostrated and awoke his companion. When he (the enemy) perceived that they (the Muslims) had become aware of his presence, he ran away. When the man from the Muhajirun saw the (man from the Ansar) bleeding, he asked him: Glory be to Allah! Why did you not wake me up the first time when he shot at you. He replied: I was busy reciting a chapter of the Qur'an. I did not like to leave it}}
\hadithdefcmd{abudawud}{199}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي نَافِعٌ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شُغِلَ عَنْهَا لَيْلَةً فَأَخَّرَهَا حَتَّى رَقَدْنَا فِي الْمَسْجِدِ ثُمَّ اسْتَيْقَظْنَا ثُمَّ رَقَدْنَا ثُمَّ اسْتَيْقَظْنَا ثُمَّ رَقَدْنَا ثُمَّ خَرَجَ عَلَيْنَا فَقَالَ ‏ "‏ لَيْسَ أَحَدٌ يَنْتَظِرُ الصَّلاَةَ غَيْرَكُمْ ‏"‏ ‏.‏\hadithno{199}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (570) Sahih Muslim (639)}\hadithtrans{‘Abd Allah b. ‘Umar said:One night the Messenger of Allah (May peace be upon him) was busy and he delayed the night (isha) prayer so much so that we dosed in the mosque. We awoke, then dozed, and again awoke and again dozed. He (the prophet) then came upon us and said: There is none except you who is waiting for prayer}}
\hadithdefcmd{abudawud}{200}{حَدَّثَنَا شَاذُّ بْنُ فَيَّاضٍ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَنْتَظِرُونَ الْعِشَاءَ الآخِرَةَ حَتَّى تَخْفِقَ رُءُوسُهُمْ ثُمَّ يُصَلُّونَ وَلاَ يَتَوَضَّئُونَ ‏.‏ قَالَ أَبُو دَاوُدَ زَادَ فِيهِ شُعْبَةُ عَنْ قَتَادَةَ قَالَ كُنَّا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ ابْنُ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ بِلَفْظٍ آخَرَ ‏.‏\hadithno{200}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (376)}\hadithtrans{Narrated Anas: The Companions during the lifetime of the messenger of Allah (May peace be upon him) used to wait for the night prayer so much so that their heads were lowered down (by dozing). Then they offered prayer and did not perform ablution. Abu Dawud said: Shu’bah on the authority of Qatadah added: We lowered down our heads (on accounts of dozing) in the day of the Messenger of Allah (May peace be upon him). Abu Dawud said; This tradition has been transmitted through a different chain of narrators}}
\hadithdefcmd{abudawud}{201}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَدَاوُدُ بْنُ شَبِيبٍ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، أَنَّ أَنَسَ بْنَ مَالِكٍ، قَالَ أُقِيمَتْ صَلاَةُ الْعِشَاءِ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي حَاجَةً ‏.‏ فَقَامَ يُنَاجِيهِ حَتَّى نَعَسَ الْقَوْمُ أَوْ بَعْضُ الْقَوْمِ ثُمَّ صَلَّى بِهِمْ وَلَمْ يَذْكُرْ وُضُوءًا ‏.‏\hadithno{201}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (376)}\hadithtrans{Anas b. Malik reported:(The people) stood up for the night prayer and a man stood up and spoke forth: Messenger of Allah, I have to say something to you. He (the Prophet) entered into secret conversation with him, till the people or some of the people dozed off, ad then he led them in prayer. He (Thabit al-Bunani) did not mention ablution}}
\hadithdefcmd{abudawud}{202}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، وَهَنَّادُ بْنُ السَّرِيِّ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، عَنْ عَبْدِ السَّلاَمِ بْنِ حَرْبٍ، - وَهَذَا لَفْظُ حَدِيثِ يَحْيَى - عَنْ أَبِي خَالِدٍ الدَّالاَنِيِّ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسْجُدُ وَيَنَامُ وَيَنْفُخُ ثُمَّ يَقُومُ فَيُصَلِّي وَلاَ يَتَوَضَّأُ ‏.‏ قَالَ فَقُلْتُ لَهُ صَلَّيْتَ وَلَمْ تَتَوَضَّأْ وَقَدْ نِمْتَ فَقَالَ ‏"‏ إِنَّمَا الْوُضُوءُ عَلَى مَنْ نَامَ مُضْطَجِعًا ‏"‏ ‏.‏ زَادَ عُثْمَانُ وَهَنَّادٌ ‏"‏ فَإِنَّهُ إِذَا اضْطَجَعَ اسْتَرْخَتْ مَفَاصِلُهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَوْلُهُ ‏"‏ الْوُضُوءُ عَلَى مَنْ نَامَ مُضْطَجِعًا ‏"‏ ‏.‏ هُوَ حَدِيثٌ مُنْكَرٌ لَمْ يَرْوِهِ إِلاَّ يَزِيدُ أَبُو خَالِدٍ الدَّالاَنِيُّ عَنْ قَتَادَةَ وَرَوَى أَوَّلَهُ جَمَاعَةٌ عَنِ ابْنِ عَبَّاسٍ وَلَمْ يَذْكُرُوا شَيْئًا مِنْ هَذَا وَقَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم مَحْفُوظًا وَقَالَتْ عَائِشَةُ - رضى الله عنها - قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَنَامُ عَيْنَاىَ وَلاَ يَنَامُ قَلْبِي ‏"‏ ‏.‏ وَقَالَ شُعْبَةُ إِنَّمَا سَمِعَ قَتَادَةُ مِنْ أَبِي الْعَالِيَةِ أَرْبَعَةَ أَحَادِيثَ حَدِيثَ يُونُسَ بْنِ مَتَّى وَحَدِيثَ ابْنِ عُمَرَ فِي الصَّلاَةِ وَحَدِيثَ الْقُضَاةُ ثَلاَثَةٌ وَحَدِيثَ ابْنِ عَبَّاسٍ حَدَّثَنِي رِجَالٌ مَرْضِيُّونَ مِنْهُمْ عُمَرُ وَأَرْضَاهُمْ عِنْدِي عُمَرُ ‏.‏ قَالَ أَبُو دَاوُدَ وَذَكَرْتُ حَدِيثَ يَزِيدَ الدَّالاَنِيِّ لأَحْمَدَ بْنِ حَنْبَلٍ فَانْتَهَرَنِي اسْتِعْظَامًا لَهُ وَقَالَ مَا لِيَزِيدَ الدَّالاَنِيِّ يُدْخِلُ عَلَى أَصْحَابِ قَتَادَةَ وَلَمْ يَعْبَأْ بِالْحَدِيثِ ‏.‏\hadithno{202}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) used to prostrate and sleep (in prostration) and produce puffing sounds (during sleep). Then he would stand and pray and would not perform ablution. I said to him: you prayed but did not perform ablution though you slept (in prostration). He replied: Ablution is necessary for one who sleeps while he is lying down. Uthman and Hannad added: For when he lies down, his joints are relaxed. Abu Dawud said: The statement "ablution is necessary for one who sleeps while one is lying down" is a munkar (rejected) tradition. It has been narrated only by Yazid Abu Khalid al-Dalani, on the authority of Qatadah. And its earlier part has been narrated by a group (of narrators) from Ibn 'Abbas; they did not mention anything about it. He (Ibn 'Abbas) said: The Prophet (ﷺ) was protected (during his sleep). 'Aishah reported: The Prophet (ﷺ) said: My eyes sleep, but my heart does not sleep. Shu'bah said: Qatadah heard from Abu'l-'Aliyah only four traditions: the tradition about Jonah son of Matthew, the tradition reported by Ibn 'Umar about prayer, the tradition stating that the judges are three, and the tradition narrated by Ibn 'Abbas saying: (This tradition) has been narrated to me by reliable persons ; 'Umar is one of them, and the most reliable of them in my opinion is 'Umar. Abu Dawud said: I asked Ahmad b. Hanbal about the tradition narrated by Yazid al-Dalani. He rebuked me out of respect for him. Then he said: Yazid al-Dalani does not add anything to what has been narrated by the teachers of Qatadah. He did not care of this tradition (due to its weakness)}}
\hadithdefcmd{abudawud}{203}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحِمْصِيُّ، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا بَقِيَّةُ، عَنِ الْوَضِينِ بْنِ عَطَاءٍ، عَنْ مَحْفُوظِ بْنِ عَلْقَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَائِذٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وِكَاءُ السَّهِ الْعَيْنَانِ فَمَنْ نَامَ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{203}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) said: The eyes are the leather strap of the anus, so one who sleeps should perform ablution}}
\hadithdefcmd{abudawud}{204}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، وَإِبْرَاهِيمُ بْنُ أَبِي مُعَاوِيَةَ، عَنْ أَبِي مُعَاوِيَةَ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنِي شَرِيكٌ، وَجَرِيرٌ، وَابْنُ، إِدْرِيسَ عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ قَالَ عَبْدُ اللَّهِ كُنَّا لاَ نَتَوَضَّأُ مِنْ مَوْطِئٍ وَلاَ نَكُفُّ شَعْرًا وَلاَ ثَوْبًا ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ إِبْرَاهِيمُ بْنُ أَبِي مُعَاوِيَةَ فِيهِ عَنِ الأَعْمَشِ عَنْ شَقِيقٍ عَنْ مَسْرُوقٍ أَوْ حَدَّثَهُ عَنْهُ قَالَ قَالَ عَبْدُ اللَّهِ وَقَالَ هَنَّادٌ عَنْ شَقِيقٍ أَوْ حَدَّثَهُ عَنْهُ ‏.‏\hadithno{204}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: We would not wash our feet after treading on something unclean, nor would we hold our hair and garments (during prayer). Abu Dawud said: The tradition has been reported by Ibrahim b. Abi Mu'awiyah through a different chain of narrators: A'mash - Shaqiq - Masruq - 'Abd Allah (b. Mas'ud). And Hannad reported from Shaqiq, or reported on his authority saying: 'Abd Allah (b. Mas'ud) said}}
\hadithdefcmd{abudawud}{205}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عِيسَى بْنِ حِطَّانَ، عَنْ مُسْلِمِ بْنِ سَلاَّمٍ، عَنْ عَلِيِّ بْنِ طَلْقٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا فَسَا أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَنْصَرِفْ فَلْيَتَوَضَّأْ وَلْيُعِدِ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{205}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn Talq: The Messenger of Allah (ﷺ) said: When any of you breaks wind during the prayer, he should turn away and perform ablution and repeat the prayer}}
\hadithdefcmd{abudawud}{206}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ الْحَذَّاءُ، عَنِ الرُّكَيْنِ بْنِ الرَّبِيعِ، عَنْ حُصَيْنِ بْنِ قَبِيصَةَ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ كُنْتُ رَجُلاً مَذَّاءً فَجَعَلْتُ أَغْتَسِلُ حَتَّى تَشَقَّقَ ظَهْرِي فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم - أَوْ ذُكِرَ لَهُ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَفْعَلْ إِذَا رَأَيْتَ الْمَذْىَ فَاغْسِلْ ذَكَرَكَ وَتَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ فَإِذَا فَضَخْتَ الْمَاءَ فَاغْتَسِلْ ‏"‏ ‏.‏\hadithno{206}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Ali said:My prostatic fluid flowed excessively. I used to take a bath until my back cracked (because of frequent washing). I mentioned it to the prophet (May peace be upon him), or the fact was mentioned to him (by someone else). The Messenger of Allah (May peace be upon him) said; Do not do so. When you find prostatic fluid, wash your penis and perform ablution as you do for your prayer, but when you have seminal emission, you should take a bath}}
\hadithdefcmd{abudawud}{207}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ، أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، - رضى الله عنه - أَمَرَهُ أَنْ يَسْأَلَ لَهُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ إِذَا دَنَا مِنْ أَهْلِهِ فَخَرَجَ مِنْهُ الْمَذْىُ مَاذَا عَلَيْهِ فَإِنَّ عِنْدِي ابْنَتَهُ وَأَنَا أَسْتَحْيِي أَنْ أَسْأَلَهُ ‏.‏ قَالَ الْمِقْدَادُ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِذَا وَجَدَ أَحَدُكُمْ ذَلِكَ فَلْيَنْضَحْ فَرْجَهُ وَلْيَتَوَضَّأْ وُضُوءَهُ لِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{207}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Miqdad ibn al-Aswad: Ali ibn AbuTalib commanded him to ask the Messenger of Allah (ﷺ) what a man should do when he wants to have intercourse with his wife and the prostatic fluid comes out (at this moment). (He said): I am ashamed of consulting him because of the position of his daughter. Al-Miqdad said: I asked the Messenger of Allah (ﷺ) about it. He said: When any of you finds, he should wash his private part, and perform ablution as he does for prayer}}
\hadithdefcmd{abudawud}{208}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، قَالَ لِلْمِقْدَادِ وَذَكَرَ نَحْوَ هَذَا قَالَ فَسَأَلَهُ الْمِقْدَادُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِيَغْسِلْ ذَكَرَهُ وَأُنْثَيَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ الثَّوْرِيُّ وَجَمَاعَةٌ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فِيهِ ‏:‏ ‏"‏ وَالأُنْثَيَيْنِ ‏"‏ ‏.‏\hadithno{208}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{‘Urwah said :‘Ali b abi Talib said to al-miqdad, and made a similar statement as above. Al-Miqdad asked him (the prophet). The prophet (peace be upon him) said: he should wash his penis and testicles. Abu Dawud said : The tradition has been narrators by al-Thawri and a group of narrators from Hisham on the authority of his father from al-Miqdad, from ‘Ali reporting from the prophet (May peace be upon him)}}
\hadithdefcmd{abudawud}{209}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، قَالَ حَدَّثَنَا أَبِي، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ حَدِيثٍ، حَدَّثَهُ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قُلْتُ لِلْمِقْدَادِ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ الْمُفَضَّلُ بْنُ فَضَالَةَ وَجَمَاعَةٌ وَالثَّوْرِيُّ وَابْنُ عُيَيْنَةَ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ وَرَوَاهُ ابْنُ إِسْحَاقَ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنِ الْمِقْدَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم لَمْ يَذْكُرْ ‏ "‏ أُنْثَيَيْهِ ‏"‏ ‏.‏\hadithno{209}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{‘Urwah reported on the Authority of his father a tradition from ‘Ali b. Abi Talib who said :I Asked al-Miqdad (to consult the prophet). He then narrated the tradition bearing the same meaning. Abu Dawud said; this tradition has been reported with another chain of narrators. This version does not mention the word “testicles”}}
\hadithdefcmd{abudawud}{210}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، حَدَّثَنِي سَعِيدُ بْنُ عُبَيْدِ بْنِ السَّبَّاقِ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ حُنَيْفٍ، قَالَ كُنْتُ أَلْقَى مِنَ الْمَذْىِ شِدَّةً وَكُنْتُ أُكْثِرُ مِنْهُ الاِغْتِسَالَ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏"‏ إِنَّمَا يُجْزِيكَ مِنْ ذَلِكَ الْوُضُوءُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ فَكَيْفَ بِمَا يُصِيبُ ثَوْبِي مِنْهُ قَالَ ‏"‏ يَكْفِيكَ بِأَنْ تَأْخُذَ كَفًّا مِنْ مَاءٍ فَتَنْضَحَ بِهَا مِنْ ثَوْبِكَ حَيْثُ تُرَى أَنَّهُ أَصَابَهُ ‏"‏ ‏.‏\hadithno{210}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sahl ibn Hunayf: I felt greatly distressed by the frequent flowing of prostatic fluid. For this reason I used to take a bath very often. I asked the apostle of Allah (ﷺ) about this. He replied: Ablution will be sufficient for you because of this. I asked: Messenger of Allah, what should I do if it smears my clothes. He replied: It is sufficient if you take a handful of water and sprinkle it on your clothe when you find it has smeared it}}
\hadithdefcmd{abudawud}{211}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ صَالِحٍ - عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ حَرَامِ بْنِ حَكِيمٍ، عَنْ عَمِّهِ عَبْدِ اللَّهِ بْنِ سَعْدٍ الأَنْصَارِيِّ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَمَّا يُوجِبُ الْغُسْلَ وَعَنِ الْمَاءِ يَكُونُ بَعْدَ الْمَاءِ فَقَالَ ‏ "‏ ذَاكَ الْمَذْىُ وَكُلُّ فَحْلٍ يُمْذِي فَتَغْسِلُ مِنْ ذَلِكَ فَرْجَكَ وَأُنْثَيَيْكَ وَتَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{211}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Sa'd al-Ansari: I asked the Messenger of Allah (ﷺ) as to what makes it necessary to take a bath and about the (prostatic) fluid that flows after taking a bath. He replied: that is called madhi (prostatic fluid). It flows from every male. You should wash your private parts and testicles because of it and perform ablution as you do for prayer}}
\hadithdefcmd{abudawud}{212}{حَدَّثَنَا هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارٍ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي ابْنَ مُحَمَّدٍ - حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، حَدَّثَنَا الْعَلاَءُ بْنُ الْحَارِثِ، عَنْ حَرَامِ بْنِ حَكِيمٍ، عَنْ عَمِّهِ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا يَحِلُّ لِي مِنَ امْرَأَتِي وَهِيَ حَائِضٌ قَالَ ‏ "‏ لَكَ مَا فَوْقَ الإِزَارِ ‏"‏ ‏.‏ وَذَكَرَ مُؤَاكَلَةَ الْحَائِضِ أَيْضًا وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{212}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Sa'd al-Ansari: Abdullah asked the Messenger of Allah (ﷺ): What is lawful for me to do with my wife when she is menstruating? He replied: What is above the waist-wrapper is lawful for you. The narrator also mentioned (the lawfulness of) eating with a woman in menstruation, and he transmitted the tradition in full}}
\hadithdefcmd{abudawud}{213}{حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ الْيَزَنِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ سَعْدٍ الأَغْطَشِ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَائِذٍ الأَزْدِيِّ، - قَالَ هِشَامٌ وَهُوَ ابْنُ قُرْطٍ أَمِيرُ حِمْصَ - عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَمَّا يَحِلُّ لِلرَّجُلِ مِنَ امْرَأَتِهِ وَهِيَ حَائِضٌ قَالَ فَقَالَ ‏ "‏ مَا فَوْقَ الإِزَارِ وَالتَّعَفُّفُ عَنْ ذَلِكَ أَفْضَلُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَيْسَ هُوَ - يَعْنِي الْحَدِيثَ - بِالْقَوِيِّ ‏.‏\hadithno{213}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: I asked the Messenger of Allah (ﷺ): What is lawful for a man to do with his wife when she is menstruating? He replied: What is above the waist-wrapper, but it is better to abstain from it, too. Abu Dawud said: This (tradition) is not strong}}
\hadithdefcmd{abudawud}{214}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - يَعْنِي ابْنَ الْحَارِثِ - عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي بَعْضُ، مَنْ أَرْضَى أَنَّ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، أَخْبَرَهُ أَنَّ أُبَىَّ بْنَ كَعْبٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم إِنَّمَا جَعَلَ ذَلِكَ رُخْصَةً لِلنَّاسِ فِي أَوَّلِ الإِسْلاَمِ لِقِلَّةِ الثِّيَابِ ثُمَّ أَمَرَ بِالْغُسْلِ وَنَهَى عَنْ ذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي ‏ "‏ الْمَاءَ مِنَ الْمَاءِ ‏"‏ ‏.‏\hadithno{214}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ubayy b. Ka’b reported :The Messenger of Allah (May peace be upon him) made a concession in the early days of Islam on account of the paucity of clothes that one should not take a bath if one has sexual intercourse (and has no seminal emission). But later on her commanded to take a bath in such a case and prohibited its omission}}
\hadithdefcmd{abudawud}{215}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الْبَزَّازُ الرَّازِيُّ، حَدَّثَنَا مُبَشِّرٌ الْحَلَبِيُّ، عَنْ مُحَمَّدٍ أَبِي غَسَّانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، حَدَّثَنِي أُبَىُّ بْنُ كَعْبٍ، أَنَّ الْفُتْيَا الَّتِي، كَانُوا يُفْتُونَ أَنَّ الْمَاءَ مِنَ الْمَاءِ كَانَتْ رُخْصَةً رَخَّصَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَدْءِ الإِسْلاَمِ ثُمَّ أَمَرَ بِالاِغْتِسَالِ بَعْدُ ‏.‏\hadithno{215}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ubayy b. Ka’b said :The verdict that water (bath) is necessary when there is emission given by the people (in the early days of Islam) was due to the concession granted by the Messenger of Allah in the beginning of Islam. He then commanded to take a bath (in such a case). Abu Dawud said : By Abu Ghassan is meant Muhammad b. mutarrif}}
\hadithdefcmd{abudawud}{216}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ الْفَرَاهِيدِيُّ، حَدَّثَنَا هِشَامٌ، وَشُعْبَةُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَعَدَ بَيْنَ شُعَبِهَا الأَرْبَعِ وَأَلْزَقَ الْخِتَانَ بِالْخِتَانِ فَقَدْ وَجَبَ الْغُسْلُ ‏"‏ ‏.‏\hadithno{216}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (291) Sahih Muslim (248)}\hadithtrans{Abu Hurairah reported the Prophet (May peace be upon him) as saying :when anyone sits between the four parts of a woman and the parts (of the male and female) which are circumscised join together, then bath becomes obligatory}}
\hadithdefcmd{abudawud}{217}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَاءُ مِنَ الْمَاءِ ‏"‏ ‏.‏ وَكَانَ أَبُو سَلَمَةَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{217}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (343)}\hadithtrans{Aba Sa’id al-Khudri reported :The Messenger of Allah (May peace be upon him) said : water (bath) is necessary only when there is seminal emission. And Abu Salamah followed it}}
\hadithdefcmd{abudawud}{218}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ ذَاتَ يَوْمٍ عَلَى نِسَائِهِ فِي غُسْلٍ وَاحِدٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَكَذَا رَوَاهُ هِشَامُ بْنُ زَيْدٍ عَنْ أَنَسٍ وَمَعْمَرٌ عَنْ قَتَادَةَ عَنْ أَنَسٍ وَصَالِحُ بْنُ أَبِي الأَخْضَرِ عَنِ الزُّهْرِيِّ كُلُّهُمْ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{218}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas reported :One day the Messenger of Allah (May peace be upon him) had sexual intercourse with (all) his wives with a single bath. Abu Dawud said: This tradition has been transmitted through another chain of narrators}}
\hadithdefcmd{abudawud}{219}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي رَافِعٍ، عَنْ عَمَّتِهِ، سَلْمَى عَنْ أَبِي رَافِعٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم طَافَ ذَاتَ يَوْمٍ عَلَى نِسَائِهِ يَغْتَسِلُ عِنْدَ هَذِهِ وَعِنْدَ هَذِهِ ‏.‏ قَالَ فَقُلْتُ لَهُ يَا رَسُولَ اللَّهِ أَلاَ تَجْعَلُهُ غُسْلاً وَاحِدًا قَالَ ‏ "‏ هَذَا أَزْكَى وَأَطْيَبُ وَأَطْهَرُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ أَنَسٍ أَصَحُّ مِنْ هَذَا ‏.‏\hadithno{219}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuRafi': One day the Prophet (ﷺ) had intercourse with all his wives. He took a bath after each intercourse. I asked him: Messenger of Allah, why don't you make it a single bath? He replied: This is more purifying, better and cleaning. Abu Dawud said: The tradition narrated by Anas is more sound that this tradition}}
\hadithdefcmd{abudawud}{220}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَتَى أَحَدُكُمْ أَهْلَهُ ثُمَّ بَدَا لَهُ أَنْ يُعَاوِدَ فَلْيَتَوَضَّأْ بَيْنَهُمَا وُضُوءًا ‏"‏ ‏.‏\hadithno{220}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (308)}\hadithtrans{Abu sa’id al-Khudri reported :The Prophet (May peace be upon him) said : When any of you has intercourse with his wife and desire to repeat it, he should perform ablution between them}}
\hadithdefcmd{abudawud}{221}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ ذَكَرَ عُمَرُ بْنُ الْخَطَّابِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ تُصِيبُهُ الْجَنَابَةُ مِنَ اللَّيْلِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَوَضَّأْ وَاغْسِلْ ذَكَرَكَ ثُمَّ نَمْ ‏"‏ ‏.‏\hadithno{221}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (290) Sahih Muslim (306)}\hadithtrans{‘Abd Allah b. ‘Umar reported :‘Umar b. al-Khattab said to the Messenger of Allah (May peace be upon him) that he became sexually defiled at night (asking him what he should do). The Messenger of Allah (May peace be upon him) said : You should perform ablution and wash your penis and then sleep}}
\hadithdefcmd{abudawud}{222}{حَدَّثَنَا مُسَدَّدٌ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَنَامَ وَهُوَ جُنُبٌ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ‏.‏\hadithno{222}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (305)}\hadithtrans{‘A’ishah reported:when the prophet (ﷺ) intended to sleep while he was sexually defiled, he would perform ablution as he did for prayer}}
\hadithdefcmd{abudawud}{223}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، بِإِسْنَادِهِ وَمَعْنَاهُ زَادَ ‏ "‏ وَإِذَا أَرَادَ أَنْ يَأْكُلَ وَهُوَ جُنُبٌ غَسَلَ يَدَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ ابْنُ وَهْبٍ عَنْ يُونُسَ فَجَعَلَ قِصَّةَ الأَكْلِ قَوْلَ عَائِشَةَ مَقْصُورًا وَرَوَاهُ صَالِحُ بْنُ أَبِي الأَخْضَرِ عَنِ الزُّهْرِيِّ كَمَا قَالَ ابْنُ الْمُبَارَكِ إِلاَّ أَنَّهُ قَالَ عَنْ عُرْوَةَ أَوْ أَبِي سَلَمَةَ وَرَوَاهُ الأَوْزَاعِيُّ عَنْ يُونُسَ عَنِ الزُّهْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم كَمَا قَالَ ابْنُ الْمُبَارَكِ ‏.‏\hadithno{223}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This Tradition has been narrated on the Authority of al-Zuhri through a different chain. It adds :If he intends to eat while he is defiled, he should wash both his hands. Abu Dawud said: Ibn Wahb narrated this tradition on the authority of Yunus. He described the fact of eating as the statement of ‘A’ishah (not the saying of the prophet). It has also been narrated it from ‘Urwah or Abu Salamah. Al-Awza’I narrated it from Yunus on the Authority of Al-Zuhri from the prophet (ﷺ) as narrated by Ibn al-Mubarak}}
\hadithdefcmd{abudawud}{224}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَأْكُلَ أَوْ يَنَامَ تَوَضَّأَ ‏.‏ تَعْنِي وَهُوَ جُنُبٌ ‏.‏\hadithno{224}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (305)}\hadithtrans{‘A’ishah reported :When the Prophet (May peace be upon him) wanted to eat or sleep, he would perform ablution. She meant that (the prophet did so) when he was sexually defiled}}
\hadithdefcmd{abudawud}{225}{حَدَّثَنَا مُوسَى، - يَعْنِي ابْنَ إِسْمَاعِيلَ - حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - أَخْبَرَنَا عَطَاءٌ الْخُرَاسَانِيُّ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ لِلْجُنُبِ إِذَا أَكَلَ أَوْ شَرِبَ أَوْ نَامَ أَنْ يَتَوَضَّأَ ‏.‏ قَالَ أَبُو دَاوُدَ بَيْنَ يَحْيَى بْنِ يَعْمَرَ وَعَمَّارِ بْنِ يَاسِرٍ فِي هَذَا الْحَدِيثِ رَجُلٌ وَقَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ وَابْنُ عُمَرَ وَعَبْدُ اللَّهِ بْنُ عَمْرٍو الْجُنُبُ إِذَا أَرَادَ أَنْ يَأْكُلَ تَوَضَّأَ ‏.‏\hadithno{225}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ammar ibn Yasir: The Prophet (ﷺ) granted permission to a person who was sexually defiled to eat or drink or sleep after performing ablution. Abu Dawud said: In the chain of this tradition there is a narrator between Yahya b. Ya'mur and 'Ammar b. Yasir. 'Ali b. Abi Talib, Ibn 'Umar and 'Abd Allah b. 'Amr said: When a person is sexually defiled wants to eat, he should perform ablution}}
\hadithdefcmd{abudawud}{226}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، ح حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا بُرْدُ بْنُ سِنَانٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ غُضَيْفِ بْنِ الْحَارِثِ، قَالَ قُلْتُ لِعَائِشَةَ أَرَأَيْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْتَسِلُ مِنَ الْجَنَابَةِ فِي أَوَّلِ اللَّيْلِ أَوْ فِي آخِرِهِ قَالَتْ رُبَّمَا اغْتَسَلَ فِي أَوَّلِ اللَّيْلِ وَرُبَّمَا اغْتَسَلَ فِي آخِرِهِ ‏.‏ قُلْتُ اللَّهُ أَكْبَرُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏.‏ قُلْتُ أَرَأَيْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُوتِرُ أَوَّلَ اللَّيْلِ أَمْ فِي آخِرِهِ قَالَتْ رُبَّمَا أَوْتَرَ فِي أَوَّلِ اللَّيْلِ وَرُبَّمَا أَوْتَرَ فِي آخِرِهِ ‏.‏ قُلْتُ اللَّهُ أَكْبَرُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏.‏ قُلْتُ أَرَأَيْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَجْهَرُ بِالْقُرْآنِ أَمْ يَخْفِتُ بِهِ قَالَتْ رُبَّمَا جَهَرَ بِهِ وَرُبَّمَا خَفَتَ ‏.‏ قُلْتُ اللَّهُ أَكْبَرُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏.‏\hadithno{226}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Ghudayf ibn al-Harith reported: I asked Aisha: Have you seen the Messenger of Allah (ﷺ) washing (because of defilement) at the beginning of the night or at the end? She replied: Sometimes he would take a bath at the beginning of the night and sometimes at the end. Thereupon I exclaimed: Allah is most Great. All Praise be to Allah Who made this matter accommodative. I again asked her: What do you think, did the Messenger of Allah (ﷺ) say the witr prayer (additional prayer after obligatory prayer at night) in the beginning of the night or at the end? She replied: Sometimes he would say the witr prayer at the beginning of the night and sometimes at the end. I exclaimed: Allah is most Great. All praise be to Allah Who made the matter accommodative. Again I asked her: What do you think, did the Messenger of Allah (ﷺ) recite the Qur'an (in the prayer) loudly or softly? She replied: Sometimes he would recite loudly and sometimes softly. I exclaimed: Allah is most Great. All praise be to Allah Who made the matter flexible}}
\hadithdefcmd{abudawud}{227}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ نُجَىٍّ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ صُورَةٌ وَلاَ كَلْبٌ وَلاَ جُنُبٌ ‏"‏ ‏.‏\hadithno{227}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: Angels do not enter the house where there is a picture, or a dog, or a person who is sexually defiled}}
\hadithdefcmd{abudawud}{228}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنَامُ وَهُوَ جُنُبٌ مِنْ غَيْرِ أَنْ يَمَسَّ مَاءً ‏.‏ قَالَ أَبُو دَاوُدَ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْوَاسِطِيُّ قَالَ سَمِعْتُ يَزِيدَ بْنَ هَارُونَ يَقُولُ هَذَا الْحَدِيثُ وَهَمٌ ‏.‏ يَعْنِي حَدِيثَ أَبِي إِسْحَاقَ ‏.‏\hadithno{228}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) would sleep while he was sexually defiled without touching water. Abu Dawud said: Hasan b. 'Ali al-Wasiti said that the heard Yazid b. Harun say: This tradition is based on a misunderstanding, i.e. the tradition reported by Abu Ishaq}}
\hadithdefcmd{abudawud}{229}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، قَالَ دَخَلْتُ عَلَى عَلِيٍّ - رضى الله عنه - أَنَا وَرَجُلاَنِ رَجُلٌ مِنَّا وَرَجُلٌ مِنْ بَنِي أَسَدٍ - أَحْسِبُ فَبَعَثَهُمَا عَلِيٌّ - رضى الله عنه - وَجْهًا وَقَالَ إِنَّكُمَا عِلْجَانِ فَعَالِجَا عَنْ دِينِكُمَا ‏.‏ ثُمَّ قَامَ فَدَخَلَ الْمَخْرَجَ ثُمَّ خَرَجَ فَدَعَا بِمَاءٍ فَأَخَذَ مِنْهُ حَفْنَةً فَتَمَسَّحَ بِهَا ثُمَّ جَعَلَ يَقْرَأُ الْقُرْآنَ فَأَنْكَرُوا ذَلِكَ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْرُجُ مِنَ الْخَلاَءِ فَيُقْرِئُنَا الْقُرْآنَ وَيَأْكُلُ مَعَنَا اللَّحْمَ وَلَمْ يَكُنْ يَحْجُبُهُ - أَوْ قَالَ يَحْجُزُهُ - عَنِ الْقُرْآنِ شَىْءٌ لَيْسَ الْجَنَابَةَ ‏.‏\hadithno{229}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: Abdullah ibn Salamah said: I, accompanied by other two persons, one from us and the other from Banu Asad, called upon Ali. He sent them to a certain territory (on some mission) saying: You are sturdy and vigorous people; hence display your power for religion. He then stood and entered the toilet. He then came out and called for water and took a handful of it. Then he wiped (his hands) with it and began to recite the Qur'an. They were surprised at this (action). Thereupon he said: The Messenger of Allah (ﷺ) came out from the privy and taught us the Qur'an and took meat with us. Nothing prevented him; or the narrator said: Nothing prevented him from (reciting) the Qur'an except sexual defilement}}
\hadithdefcmd{abudawud}{230}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ مِسْعَرٍ، عَنْ وَاصِلٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَقِيَهُ فَأَهْوَى إِلَيْهِ فَقَالَ إِنِّي جُنُبٌ ‏.‏ فَقَالَ ‏ "‏ إِنَّ الْمُسْلِمَ لاَ يَنْجُسُ ‏"‏ ‏.‏\hadithno{230}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (372)}\hadithtrans{Hudhaifah reported :The prophet (ﷺ) visited him and inclined towards him (for shaking hand). He said : I am sexually defiled. The prophet (ﷺ) replied : A muslim is not defiled}}
\hadithdefcmd{abudawud}{231}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، وَبِشْرٌ، عَنْ حُمَيْدٍ، عَنْ بَكْرٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي طَرِيقٍ مِنْ طُرُقِ الْمَدِينَةِ وَأَنَا جُنُبٌ فَاخْتَنَسْتُ فَذَهَبْتُ فَاغْتَسَلْتُ ثُمَّ جِئْتُ فَقَالَ ‏"‏ أَيْنَ كُنْتَ يَا أَبَا هُرَيْرَةَ ‏"‏ ‏.‏ قَالَ قُلْتُ إِنِّي كُنْتُ جُنُبًا فَكَرِهْتُ أَنْ أُجَالِسَكَ عَلَى غَيْرِ طَهَارَةٍ ‏.‏ فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ إِنَّ الْمُسْلِمَ لاَ يَنْجُسُ ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِ بِشْرٍ حَدَّثَنَا حُمَيْدٌ حَدَّثَنِي بَكْرٌ ‏.‏\hadithno{231}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (283) Sahih Muslim (371)}\hadithtrans{Abu Hudhaifah reported :The Messenger of Allah (ﷺ) met me on one of the streets of medina while I was sexually defiled. I retreated and went away. I then took a bath and came to him. He asked : Where were you, O Abu Hurairah? I replied : As I was sexually defiled, I disliked to sit in your company without purification. He exclaimed: Glory be to Allah! A Muslim is not defiled. He (Abu Dawud) said : The version of this tradition reported by Bishr has the chain: Humaid reported from Bakr}}
\hadithdefcmd{abudawud}{232}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الأَفْلَتُ بْنُ خَلِيفَةَ، قَالَ حَدَّثَتْنِي جَسْرَةُ بِنْتُ دِجَاجَةَ، قَالَتْ سَمِعْتُ عَائِشَةَ، رضى الله عنها تَقُولُ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَوُجُوهُ بُيُوتِ أَصْحَابِهِ شَارِعَةٌ فِي الْمَسْجِدِ فَقَالَ ‏"‏ وَجِّهُوا هَذِهِ الْبُيُوتَ عَنِ الْمَسْجِدِ ‏"‏ ‏.‏ ثُمَّ دَخَلَ النَّبِيُّ صلى الله عليه وسلم وَلَمْ يَصْنَعِ الْقَوْمُ شَيْئًا رَجَاءَ أَنْ تَنْزِلَ فِيهِمْ رُخْصَةٌ فَخَرَجَ إِلَيْهِمْ بَعْدُ فَقَالَ ‏"‏ وَجِّهُوا هَذِهِ الْبُيُوتَ عَنِ الْمَسْجِدِ فَإِنِّي لاَ أُحِلُّ الْمَسْجِدَ لِحَائِضٍ وَلاَ جُنُبٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ فُلَيْتٌ الْعَامِرِيُّ ‏.‏\hadithno{232}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) came and saw that the doors of the houses of his Companions were facing the mosque. He said: Turn the direction of the houses from the mosque. The Prophet (ﷺ) then entered (the houses or the mosque), and the people did take any step in this regard hoping that some concession might be revealed. He the Prophet) again came upon them and said: Turn the direction of these (doors) from the mosque I do not make the mosque lawful for a menstruating woman and for a person who is sexually defiled. Abu Dawud said: Aflat b. Khalifah is also called Fulait al-'Amiri}}
\hadithdefcmd{abudawud}{233}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ زِيَادٍ الأَعْلَمِ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ فِي صَلاَةِ الْفَجْرِ فَأَوْمَأَ بِيَدِهِ أَنْ مَكَانَكُمْ ثُمَّ جَاءَ وَرَأْسُهُ يَقْطُرُ فَصَلَّى بِهِمْ ‏.‏\hadithno{233}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuBakrah: The Messenger of Allah (ﷺ) began to lead (the people) in the dawn prayer. He then signalled with his hand: (Stay) at your places. (Then he entered his home). He then returned while drops of water were coming down from him (from his body) and he led them in prayer}}
\hadithdefcmd{abudawud}{234}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ فِي أَوَّلِهِ فَكَبَّرَ ‏.‏ وَقَالَ فِي آخِرِهِ فَلَمَّا قَضَى الصَّلاَةَ قَالَ ‏"‏ إِنَّمَا أَنَا بَشَرٌ وَإِنِّي كُنْتُ جُنُبًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الزُّهْرِيُّ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ قَالَ فَلَمَّا قَامَ فِي مُصَلاَّهُ وَانْتَظَرْنَا أَنْ يُكَبِّرَ انْصَرَفَ ثُمَّ قَالَ ‏"‏ كَمَا أَنْتُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ أَيُّوبُ وَابْنُ عَوْنٍ وَهِشَامٌ عَنْ مُحَمَّدٍ مُرْسَلاً عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فَكَبَّرَ ثُمَّ أَوْمَأَ بِيَدِهِ إِلَى الْقَوْمِ أَنِ اجْلِسُوا فَذَهَبَ فَاغْتَسَلَ ‏.‏ وَكَذَلِكَ رَوَاهُ مَالِكٌ عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ عَنْ عَطَاءِ بْنِ يَسَارٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَبَّرَ فِي صَلاَةٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ حَدَّثَنَاهُ مُسْلِمُ بْنُ إِبْرَاهِيمَ حَدَّثَنَا أَبَانُ عَنْ يَحْيَى عَنِ الرَّبِيعِ بْنِ مُحَمَّدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَبَّرَ ‏.‏\hadithno{234}\hadithgrade{Al-Albani: Mursal; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{This tradition has been reported by Hammad b. Salamah through the same chain of narrators and conveying a similar meaning. This version adds in the beginning:He uttered TAKBIR (Allahu akbar), and in the end : when he finished the prayer, he said : I am a human being; I was sexually defiled. Abu Dawud said : This tradition has been narrated al-Zuhri from Abu Salamah b. ‘Abd al-Rahman on the authority of Abu Hurairah. It says: When he stood at the place of prayer, we waited for his utterance of takbir (Allah-u akbar).He went away and said : (remain) as you were. Another version on the authority of Muhammad reporting from the Prophet (ﷺ) says: He uttered takbir (Allah-u-Akbar) and then made a sign to the people, meaning "sit down". He then went away and took a bath. This tradition has also been narrated through a different chain. It says: The Messenger of Allah (ﷺ) uttered takbir (Allah-u-akbar) in a prayer. Abu Dawud said: Another version through a different chain says; The Prophet (May peace be upon him) uttered takbir (Allah-u akbar)}}
\hadithdefcmd{abudawud}{235}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا الزُّبَيْدِيُّ، ح وَحَدَّثَنَا عَيَّاشُ بْنُ الأَزْرَقِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، ح وَحَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ، - إِمَامُ مَسْجِدِ صَنْعَاءَ - حَدَّثَنَا رَبَاحٌ، عَنْ مَعْمَرٍ، ح وَحَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُقِيمَتِ الصَّلاَةُ وَصَفَّ النَّاسُ صُفُوفَهُمْ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا قَامَ فِي مَقَامِهِ ذَكَرَ أَنَّهُ لَمْ يَغْتَسِلْ فَقَالَ لِلنَّاسِ ‏ "‏ مَكَانَكُمْ ‏"‏ ‏.‏ ثُمَّ رَجَعَ إِلَى بَيْتِهِ فَخَرَجَ عَلَيْنَا يَنْطُفُ رَأْسُهُ وَقَدِ اغْتَسَلَ وَنَحْنُ صُفُوفٌ ‏.‏ وَهَذَا لَفْظُ ابْنِ حَرْبٍ وَقَالَ عَيَّاشٌ فِي حَدِيثِهِ فَلَمْ نَزَلْ قِيَامًا نَنْتَظِرُهُ حَتَّى خَرَجَ عَلَيْنَا وَقَدِ اغْتَسَلَ ‏.‏\hadithno{235}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (639، 640) Sahih Muslim (605)}\hadithtrans{Abu Hurairah reported:The prayer (in congregation) began and people stood in their rows. The Messenger of Allah (May peace be upon him) came out (from his residence). When he stood at his proper place he recalled that he did not take a bath. He then said to the people: (Remain standing) at your places. Then he returned to his house and came out upon us after taking a bath while the drops of water were coming down from his head. We were standing in the rows (of prayer). This is the version of Ibn Harb. ‘Ayyash reported in his version: we kept on waiting for him while we were standing until he came upon us after he had taken a bath}}
\hadithdefcmd{abudawud}{236}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ الْخَيَّاطُ، حَدَّثَنَا عَبْدُ اللَّهِ الْعُمَرِيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ يَجِدُ الْبَلَلَ وَلاَ يَذْكُرُ احْتِلاَمًا قَالَ ‏"‏ يَغْتَسِلُ ‏"‏ ‏.‏ وَعَنِ الرَّجُلِ يَرَى أَنَّهُ قَدِ احْتَلَمَ وَلاَ يَجِدُ الْبَلَلَ قَالَ ‏"‏ لاَ غُسْلَ عَلَيْهِ ‏"‏ ‏.‏ فَقَالَتْ أُمُّ سُلَيْمٍ الْمَرْأَةُ تَرَى ذَلِكَ أَعَلَيْهَا غُسْلٌ قَالَ ‏"‏ نَعَمْ إِنَّمَا النِّسَاءُ شَقَائِقُ الرِّجَالِ ‏"‏ ‏.‏\hadithno{236}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) was asked about a person who found moisture (on his body or clothes) but did not remember the sexual dream. He replied: He should take a bath. He was asked about a person who remembered that he had a sexual dream but did not find moisture. He replied: Bath is not necessary for him. Umm Salamah then asked: Is washing necessary for a woman if she sees that (in her dream)? He replied: Yes. Woman are counterpart of men}}
\hadithdefcmd{abudawud}{237}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ عُرْوَةُ عَنْ عَائِشَةَ، أَنَّ أُمَّ سُلَيْمٍ الأَنْصَارِيَّةَ، - وَهِيَ أُمُّ أَنَسِ بْنِ مَالِكٍ - قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ عَزَّ وَجَلَّ لاَ يَسْتَحْيِي مِنَ الْحَقِّ أَرَأَيْتَ الْمَرْأَةَ إِذَا رَأَتْ فِي النَّوْمِ مَا يَرَى الرَّجُلُ أَتَغْتَسِلُ أَمْ لاَ قَالَتْ عَائِشَةُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ فَلْتَغْتَسِلْ إِذَا وَجَدَتِ الْمَاءَ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَأَقْبَلْتُ عَلَيْهَا فَقُلْتُ أُفٍّ لَكِ وَهَلْ تَرَى ذَلِكَ الْمَرْأَةُ فَأَقْبَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ تَرِبَتْ يَمِينُكِ يَا عَائِشَةُ وَمِنْ أَيْنَ يَكُونُ الشَّبَهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَى عُقَيْلٌ وَالزُّبَيْدِيُّ وَيُونُسُ وَابْنُ أَخِي الزُّهْرِيِّ عَنِ الزُّهْرِيِّ وَإِبْرَاهِيمُ بْنُ أَبِي الْوَزِيرِ عَنْ مَالِكٍ عَنِ الزُّهْرِيِّ وَوَافَقَ الزُّهْرِيَّ مُسَافِعٌ الْحَجَبِيُّ قَالَ عَنْ عُرْوَةَ عَنْ عَائِشَةَ ‏.‏ وَأَمَّا هِشَامُ بْنُ عُرْوَةَ فَقَالَ عَنْ عُرْوَةَ عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ عَنْ أُمِّ سَلَمَةَ أَنَّ أُمَّ سُلَيْمٍ جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{237}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (314)}\hadithtrans{‘A’ishah reported on the authority of Umm Sulaim al-Ansariyah, who was the mother of Anas b. Malik, said:Messenger of Allah. Allah is not ashamed of truth what do you think, if a woman sees what a man sees in dream, should she take a bath or not? The prophet (ﷺ) replied: Yes, she should take a bath if she finds the liquid (vaginal secretion) ‘A’ishah said : Then I came upon her and said her : Woe to you! Does a woman see that (sexual dream)? In the meantime, the Messenger of Allah (ﷺ) came upon me and said: May your right hand be covered with dust! How can there be the resemblance (i.e., between the child and the mother)? Abu Dawud said: A similar version has been narrated by Zubaid, ‘Uqail, Yunus, cousin of Al-Zuhri, Ibn Abi-Wazir, on the authority of al-Zuhr, musan, al-Hajabi, like al-Zuhri, narrated on the authority of ‘Urwah from ‘A’ishah, but Hisham b. ‘Urwah narrated from ‘Urwah on the authority of Zainab daughter of Abu Salamah from Umm Salamah saying. Umm Sulaim came to the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{238}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْتَسِلُ مِنْ إِنَاءٍ - هُوَ الْفَرَقُ - مِنَ الْجَنَابَةِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مَعْمَرٌ عَنِ الزُّهْرِيِّ فِي هَذَا الْحَدِيثِ قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ فِيهِ قَدْرُ الْفَرَقِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى ابْنُ عُيَيْنَةَ نَحْوَ حَدِيثِ مَالِكٍ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ الْفَرَقُ سِتَّةَ عَشَرَ رِطْلاً ‏.‏ وَسَمِعْتُهُ يَقُولُ صَاعُ ابْنِ أَبِي ذِئْبٍ خَمْسَةُ أَرْطَالٍ وَثُلُثٌ ‏.‏ قَالَ فَمَنْ قَالَ ثَمَانِيَةُ أَرْطَالٍ قَالَ لَيْسَ ذَلِكَ بِمَحْفُوظٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَسَمِعْتُ أَحْمَدَ يَقُولُ مَنْ أَعْطَى فِي صَدَقَةِ الْفِطْرِ بِرَطْلِنَا هَذَا خَمْسَةَ أَرْطَالٍ وَثُلُثًا فَقَدْ أَوْفَى ‏.‏ قِيلَ الصَّيْحَانِيُّ ثَقِيلٌ قَالَ الصَّيْحَانِيُّ أَطْيَبُ ‏.‏ قَالَ لاَ أَدْرِي ‏.‏\hadithno{238}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (250) Sahih Muslim (319)}\hadithtrans{Aishah said:The Messenger of Allah (May peace be upon him) used to take bath with from a vessel (which contained seven to eight seers, i.e., fifteen to sixteen pounds) because of sexual intercourse. Abu Dawud said: The version narrated by Mu’ammar on the authority of al-Zuhri has: She (‘A’ishah) said: I and the Messenger of Allah (May peace be upon him) took a bath from a vessel which was equal to al-faraq in measurement (i.e., containing water about seven or eight seers). Abu Dawud said: Ibn ‘Uyainah also narrated like the version of Malik. Abu Dawud said; I heard Ahmad b. Hanbal say: Al-Faraq contains sixteen rotls (of water). I also heard him say: The sa’of of Ibn Abi Dhi’b contained 5 rotls (of water). The view that a sa’ contains eight rotls (of water) is not safe. Abu Dawud said: I heard Ahmad (b. Hanbal) say: Whoever gave 5 1/3 rotls (measuring) with our rotl alms of fitr (sadaqat al-fitr), he gave in full, Thereupon he was questioned: Are the dates called al-saihani heavier (can one sa’ of them be given as alms of fitr)? He replied: The dates called al-saihani are good. But I do not know (whether water is heavier or the dates)}}
\hadithdefcmd{abudawud}{239}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، أَخْبَرَنِي سُلَيْمَانُ بْنُ صُرَدٍ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّهُمْ ذَكَرُوا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْغُسْلَ مِنَ الْجَنَابَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمَّا أَنَا فَأُفِيضُ عَلَى رَأْسِي ثَلاَثًا ‏"‏ ‏.‏ وَأَشَارَ بِيَدَيْهِ كِلْتَيْهِمَا ‏.‏\hadithno{239}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (254) Sahih Muslim (327)}\hadithtrans{Jubair b. Mut’im reported :People made a mention of washing because of sexual defilement before the Messenger of Allah (May peace be upon him). The Messenger of Allah (May peace be upon him) said: I pour (water) on my head three times. And he made a sign with both his hands}}
\hadithdefcmd{abudawud}{240}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ حَنْظَلَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ دَعَا بِشَىْءٍ نَحْوِ الْحِلاَبِ فَأَخَذَ بِكَفِّهِ فَبَدَأَ بِشِقِّ رَأْسِهِ الأَيْمَنِ ثُمَّ الأَيْسَرِ ثُمَّ أَخَذَ بِكَفَّيْهِ فَقَالَ بِهِمَا عَلَى رَأْسِهِ ‏.‏\hadithno{240}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (258) Sahih Muslim (318)}\hadithtrans{Aishah reported :when the Messenger of Allah (May peace be upon him) wanted to wash himself because of sexual defilement, he called for a vessel like HILAB (a vessel used for milking the camel). He then took a handful of water and began to pour it on the right side of his head and then on the left side. He then took water in both his hands together and poured it on his head}}
\hadithdefcmd{abudawud}{241}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - عَنْ زَائِدَةَ بْنِ قُدَامَةَ، عَنْ صَدَقَةَ، حَدَّثَنَا جُمَيْعُ بْنُ عُمَيْرٍ، - أَحَدُ بَنِي تَيْمِ اللَّهِ بْنِ ثَعْلَبَةَ - قَالَ دَخَلْتُ مَعَ أُمِّي وَخَالَتِي عَلَى عَائِشَةَ فَسَأَلَتْهَا إِحْدَاهُمَا كَيْفَ كُنْتُمْ تَصْنَعُونَ عِنْدَ الْغُسْلِ فَقَالَتْ عَائِشَةُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ يُفِيضُ عَلَى رَأْسِهِ ثَلاَثَ مَرَّاتٍ وَنَحْنُ نُفِيضُ عَلَى رُءُوسِنَا خَمْسًا مِنْ أَجْلِ الضَّفْرِ ‏.‏\hadithno{241}\hadithgrade{Al-Albani: Very Daif; Muhammad Muhyi Al-Din Abdul Hamid: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Jumay' ibn Umayr, one of the sons of Banu Taym Allah ibn Tha'labah, said: Accompanied by my mother and aunt I entered upon Aisha. One of them asked her: How did you do while taking a bath? Aisha replied: The Messenger of Allah (ﷺ) performed ablution (in the beginning) as he did for prayer. He then poured (water) upon his head three times. But we poured water upon our heads five times due to plaits}}
\hadithdefcmd{abudawud}{242}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ الْوَاشِحِيُّ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ - قَالَ سُلَيْمَانُ يَبْدَأُ فَيُفْرِغُ مِنْ يَمِينِهِ عَلَى شِمَالِهِ ‏.‏ وَقَالَ مُسَدَّدٌ غَسَلَ يَدَيْهِ يَصُبُّ الإِنَاءَ عَلَى يَدِهِ الْيُمْنَى ثُمَّ اتَّفَقَا فَيَغْسِلُ فَرْجَهُ ‏.‏ - قَالَ مُسَدَّدٌ - يُفْرِغُ عَلَى شِمَالِهِ وَرُبَّمَا كَنَتْ عَنِ الْفَرْجِ ثُمَّ يَتَوَضَّأُ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ يُدْخِلُ يَدَيْهِ فِي الإِنَاءِ فَيُخَلِّلُ شَعْرَهُ حَتَّى إِذَا رَأَى أَنَّهُ قَدْ أَصَابَ الْبَشَرَةَ أَوْ أَنْقَى الْبَشَرَةَ أَفْرَغَ عَلَى رَأْسِهِ ثَلاَثًا فَإِذَا فَضَلَ فَضْلَةٌ صَبَّهَا عَلَيْهِ ‏.‏\hadithno{242}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (248) Sahih Muslim (316)}\hadithtrans{Aishah reported :When the Messenger of Allah (May peace be upon him) would take a bath because of sexual defilement, according to the version of Sulaiman, in the beginning he would pour water with his right hand (upon his left hand); and according to the version of Musaddad, he would wash both (hands) pouring water from the vessel upon his right hand. According to the agreed version, he then would wash the private part. He would then perform ablution as he did for prayer, then put his hands in the vessel and made the water go through his hair. When he knew that water had reached the entire surface of the body and cleaned it well, he would pour water upon his head three times. If some water was left, he would pour it also upon himself}}
\hadithdefcmd{abudawud}{243}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ الْبَاهِلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، حَدَّثَنِي سَعِيدٌ، عَنْ أَبِي مَعْشَرٍ، عَنِ النَّخَعِيِّ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَغْتَسِلَ مِنَ الْجَنَابَةِ بَدَأَ بِكَفَّيْهِ فَغَسَلَهُمَا ثُمَّ غَسَلَ مَرَافِغَهُ وَأَفَاضَ عَلَيْهِ الْمَاءَ فَإِذَا أَنْقَاهُمَا أَهْوَى بِهِمَا إِلَى حَائِطٍ ثُمَّ يَسْتَقْبِلُ الْوُضُوءَ وَيُفِيضُ الْمَاءَ عَلَى رَأْسِهِ ‏.‏\hadithno{243}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah said; When the Messenger of Allah (May peace be upon him) intended to take a bath because of sexual defilement, he would begin with his hands and wash them. Then he would wash the joints of his limbs and pour water upon him when he cleansed both his (hands), he would rub them on the wall (to make them perfectly clean with the dust). Then he would perform ablution and pour water over his head}}
\hadithdefcmd{abudawud}{244}{حَدَّثَنَا الْحَسَنُ بْنُ شَوْكَرٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ عُرْوَةَ الْهَمْدَانِيِّ، حَدَّثَنَا الشَّعْبِيُّ، قَالَ قَالَتْ عَائِشَةُ رضى الله عنها لَئِنْ شِئْتُمْ لأُرِيَنَّكُمْ أَثَرَ يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْحَائِطِ حَيْثُ كَانَ يَغْتَسِلُ مِنَ الْجَنَابَةِ ‏.‏\hadithno{244}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: If you want, I can certainly show you the marks of the hand of the Messenger of Allah (ﷺ) on the wall where he took a bath because of sexual defilement}}
\hadithdefcmd{abudawud}{245}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنِ الأَعْمَشِ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، حَدَّثَنَا ابْنُ عَبَّاسٍ، عَنْ خَالَتِهِ، مَيْمُونَةَ قَالَتْ وَضَعْتُ لِلنَّبِيِّ صلى الله عليه وسلم غُسْلاً يَغْتَسِلُ بِهِ مِنَ الْجَنَابَةِ فَأَكْفَأَ الإِنَاءَ عَلَى يَدِهِ الْيُمْنَى فَغَسَلَهَا مَرَّتَيْنِ أَوْ ثَلاَثًا ثُمَّ صَبَّ عَلَى فَرْجِهِ فَغَسَلَ فَرْجَهُ بِشِمَالِهِ ثُمَّ ضَرَبَ بِيَدِهِ الأَرْضَ فَغَسَلَهَا ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ وَغَسَلَ وَجْهَهُ وَيَدَيْهِ ثُمَّ صَبَّ عَلَى رَأْسِهِ وَجَسَدِهِ ثُمَّ تَنَحَّى نَاحِيَةً فَغَسَلَ رِجْلَيْهِ فَنَاوَلْتُهُ الْمِنْدِيلَ فَلَمْ يَأْخُذْهُ وَجَعَلَ يَنْفُضُ الْمَاءَ عَنْ جَسَدِهِ ‏.‏ فَذَكَرْتُ ذَلِكَ لإِبْرَاهِيمَ فَقَالَ كَانُوا لاَ يَرَوْنَ بِالْمِنْدِيلِ بَأْسًا وَلَكِنْ كَانُوا يَكْرَهُونَ الْعَادَةَ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مُسَدَّدٌ فَقُلْتُ لِعَبْدِ اللَّهِ بْنِ دَاوُدَ كَانُوا يَكْرَهُونَهُ لِلْعَادَةِ فَقَالَ هَكَذَا هُوَ وَلَكِنْ وَجَدْتُهُ فِي كِتَابِي هَكَذَا ‏.‏\hadithno{245}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (249) Sahih Muslim (317)}\hadithtrans{Maimunah reported:I placed (the vessel of) water for the Prophet (May peace be upon him) to wash himself because of sexual intercourse. He lowered down the vessel and poured water on his right hand. He then washed it twice or thrice. He then poured water over his private parts and washed them with his left hand. Then he put it on the ground and wiped it. He then rinsed his mouth and snuffed up water, and washed his face and hands. He then poured water over his head and body. Then he moved aside and washed his feet. I handed him a garment, but he began to shake he moved aside and washed his feet. I handed him a garment, but he began to shake off water from his body. I mentioned it to Ibrahim. He said that they (companions) did not think there was any harm in using the garment (to wipe the water), but they disliked its use as a habit. Abu Dawud said: Musaddad said: I asked ‘Abd Allah b. Dawud whether they (the companions) disliked to make it a habit. He replied: it (the tradition) goes in a similar way and I found it in a similar way in this book of mine}}
\hadithdefcmd{abudawud}{246}{حَدَّثَنَا حُسَيْنُ بْنُ عِيسَى الْخُرَاسَانِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ شُعْبَةَ، قَالَ إِنَّ ابْنَ عَبَّاسٍ كَانَ إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ يُفْرِغُ بِيَدِهِ الْيُمْنَى عَلَى يَدِهِ الْيُسْرَى سَبْعَ مِرَارٍ ثُمَّ يَغْسِلُ فَرْجَهُ فَنَسِيَ مَرَّةً كَمْ أَفْرَغَ فَسَأَلَنِي كَمْ أَفْرَغْتُ فَقُلْتُ لاَ أَدْرِي ‏.‏ فَقَالَ لاَ أُمَّ لَكَ وَمَا يَمْنَعُكَ أَنْ تَدْرِيَ ثُمَّ يَتَوَضَّأُ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ يُفِيضُ عَلَى جِلْدِهِ الْمَاءَ ثُمَّ يَقُولُ هَكَذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَطَهَّرُ ‏.‏\hadithno{246}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Shu’bah reported :when Ibn ‘Abbas took a bath because of sexual defilement, he poured (water) over his left hand with his right hand seven times. Once he forgot how many times he had poured (water). Therefore he asked me: how many times did I pour (water)? I do not know. He said : may you miss your mother! What prevented you from remembering it? He then performed ablution as he did for prayer and poured water over his skin (body). He then said: this is how the Messenger of Allah (May peace be upon him) purified (himself)}}
\hadithdefcmd{abudawud}{247}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَيُّوبُ بْنُ جَابِرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُصْمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كَانَتِ الصَّلاَةُ خَمْسِينَ وَالْغُسْلُ مِنَ الْجَنَابَةِ سَبْعَ مِرَارٍ وَغَسْلُ الْبَوْلِ مِنَ الثَّوْبِ سَبْعَ مِرَارٍ فَلَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْأَلُ حَتَّى جُعِلَتِ الصَّلاَةُ خَمْسًا وَالْغُسْلُ مِنَ الْجَنَابَةِ مَرَّةً وَغَسْلُ الْبَوْلِ مِنَ الثَّوْبِ مَرَّةً ‏.‏\hadithno{247}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: There were fifty prayers (obligatory in the beginning); and (in the beginning of Islam) washing seven times because of sexual defilement (was obligatory); and washing the urine from the cloth seven times (was obligatory). The Apostle of Allah (ﷺ) kept on praying to Allah until the number of prayers was reduced to five and washing because of sexual defilement was allowed only once and washing the urine from the clothe was also permitted only once}}
\hadithdefcmd{abudawud}{248}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنِي الْحَارِثُ بْنُ وَجِيهٍ، حَدَّثَنَا مَالِكُ بْنُ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ تَحْتَ كُلِّ شَعْرَةٍ جَنَابَةً فَاغْسِلُوا الشَّعْرَ وَأَنْقُوا الْبَشَرَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْحَارِثُ بْنُ وَجِيهٍ حَدِيثُهُ مُنْكَرٌ وَهُوَ ضَعِيفٌ ‏.‏\hadithno{248}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) said: There is sexual defilement under every hair; so wash the hair and cleanse the skin. Abu Dawud said: The tradition narrated by Harith b. Wajih is rejected (Munkar). He is weak (in transmission)}}
\hadithdefcmd{abudawud}{249}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ زَاذَانَ، عَنْ عَلِيٍّ، - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَرَكَ مَوْضِعَ شَعْرَةٍ مِنْ جَنَابَةٍ لَمْ يَغْسِلْهَا فُعِلَ بِهِ كَذَا وَكَذَا مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ عَلِيٌّ فَمِنْ ثَمَّ عَادَيْتُ رَأْسِي فَمِنْ ثَمَّ عَادَيْتُ رَأْسِي ثَلاَثًا ‏.‏ وَكَانَ يَجِزُّ شَعْرَهُ ‏.‏\hadithno{249}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) said: If anyone who is sexual defiled leaves a spot equal to the breadth of a hair without washing, such and such an amount of Hell-fire will have to be suffered for it. Ali said: On that account I treated my head (hair) as an enemy, meaning I cut my hair. He used to cut the hair (of his head). May Allah be pleased with him}}
\hadithdefcmd{abudawud}{250}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ وَيُصَلِّي الرَّكْعَتَيْنِ وَصَلاَةَ الْغَدَاةِ وَلاَ أُرَاهُ يُحْدِثُ وُضُوءًا بَعْدَ الْغُسْلِ ‏.‏\hadithno{250}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) took a bath and offered two rak'ahs of prayer and said the dawn prayer. I do not think he performed ablution afresh after taking a bath}}
\hadithdefcmd{abudawud}{251}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ السَّرْحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، مَوْلَى أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، أَنَّ امْرَأَةً، مِنَ الْمُسْلِمِينَ - وَقَالَ زُهَيْرٌ إِنَّهَا - قَالَتْ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أَشُدُّ ضَفْرَ رَأْسِي أَفَأَنْقُضُهُ لِلْجَنَابَةِ قَالَ ‏"‏ إِنَّمَا يَكْفِيكِ أَنْ تَحْفِنِي عَلَيْهِ ثَلاَثًا ‏"‏ ‏.‏ وَقَالَ زُهَيْرٌ ‏"‏ تَحْثِي عَلَيْهِ ثَلاَثَ حَثَيَاثٍ مِنْ مَاءٍ ثُمَّ تُفِيضِي عَلَى سَائِرِ جَسَدِكِ فَإِذَا أَنْتِ قَدْ طَهُرْتِ ‏"‏ ‏.‏\hadithno{251}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (330)}\hadithtrans{Umm Salamah said:one of the Muslims asked, and Zubair reported: Umm Salamah (herself) asked: Messenger of Allah. I am a women who keeps her hair closely plaited; should I undo it when I wash after sexual defilement? He replied (no), it is enough for you to throw three handfuls over it. Then pour water over all your body and will be purified}}
\hadithdefcmd{abudawud}{252}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ نَافِعٍ، - يَعْنِي الصَّائِغَ - عَنْ أُسَامَةَ، عَنِ الْمَقْبُرِيِّ، عَنْ أُمِّ سَلَمَةَ، أَنَّ امْرَأَةً، جَاءَتْ إِلَى أُمِّ سَلَمَةَ بِهَذَا الْحَدِيثِ ‏.‏ قَالَتْ فَسَأَلْتُ لَهَا النَّبِيَّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ فِيهِ ‏ "‏ وَاغْمِزِي قُرُونَكِ عِنْدَ كُلِّ حَفْنَةٍ ‏"‏ ‏.‏\hadithno{252}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umm Salamah said:A women came to her, this is according to the version of the former tradition. I asked the Prophet (May peace be upon him) a similar question (as in the former tradition). But this version adds: “And wring out your locks after every handful of water”}}
\hadithdefcmd{abudawud}{253}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ إِحْدَانَا إِذَا أَصَابَتْهَا جَنَابَةٌ أَخَذَتْ ثَلاَثَ حَفَنَاتٍ هَكَذَا - تَعْنِي بِكَفَّيْهَا جَمِيعًا - فَتَصُبُّ عَلَى رَأْسِهَا وَأَخَذَتْ بِيَدٍ وَاحِدَةٍ فَصَبَّتْهَا عَلَى هَذَا الشِّقِّ وَالأُخْرَى عَلَى الشِّقِّ الآخَرِ ‏.‏\hadithno{253}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (277)}\hadithtrans{Aishah said:When any of us was sexually defiled, she took three handfuls (of water) in this way, that is to say, with both hands together and poured (water) over her head. She took one handful (of water) and threw it on one side and the other on the other side}}
\hadithdefcmd{abudawud}{254}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ عُمَرَ بْنِ سُوَيْدٍ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنَّا نَغْتَسِلُ وَعَلَيْنَا الضِّمَادُ وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُحِلاَّتٌ وَمُحْرِمَاتٌ ‏.‏\hadithno{254}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah said:we took a bath while having an adhesive substance over us (our head) in both states, namely, when wearing a robe for Hajj (ihram) and when wearing ordinary clothes (not meant for Hajj)}}
\hadithdefcmd{abudawud}{255}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، قَالَ قَرَأْتُ فِي أَصْلِ إِسْمَاعِيلَ بْنِ عَيَّاشٍ - قَالَ ابْنُ عَوْفٍ - وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِيهِ، حَدَّثَنِي ضَمْضَمُ بْنُ زُرْعَةَ، عَنْ شُرَيْحِ بْنِ عُبَيْدٍ، قَالَ أَفْتَانِي جُبَيْرُ بْنُ نُفَيْرٍ عَنِ الْغُسْلِ، مِنَ الْجَنَابَةِ أَنَّ ثَوْبَانَ، حَدَّثَهُمْ أَنَّهُمُ، اسْتَفْتَوُا النَّبِيَّ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ أَمَّا الرَّجُلُ فَلْيَنْشُرْ رَأْسَهُ فَلْيَغْسِلْهُ حَتَّى يَبْلُغَ أُصُولَ الشَّعْرِ وَأَمَّا الْمَرْأَةُ فَلاَ عَلَيْهَا أَنْ لاَ تَنْقُضَهُ لِتَغْرِفْ عَلَى رَأْسِهَا ثَلاَثَ غَرَفَاتٍ بِكَفَّيْهَا ‏"‏ ‏.‏\hadithno{255}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Thawban: Shurayh ibn Ubayd said: Jubayr ibn Nufayr gave me a verdict about the bath because of sexual defilement that Thawban reported to them that they asked the Prophet (ﷺ) about it. He (the Prophet) replied: As regards man, he should undo the hair of his head and wash it until the water should reach the roots of the hair. But there is no harm if the woman does not undo it (her hair) and pour three handfuls of water over her head}}
\hadithdefcmd{abudawud}{256}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ، حَدَّثَنَا شَرِيكٌ، عَنْ قَيْسِ بْنِ وَهْبٍ، عَنْ رَجُلٍ، مِنْ بَنِي سُوَاءَةَ بْنِ عَامِرٍ عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَغْسِلُ رَأْسَهُ بِالْخِطْمِيِّ وَهُوَ جُنُبٌ يَجْتَزِئُ بِذَلِكَ وَلاَ يَصُبُّ عَلَيْهِ الْمَاءَ ‏.‏\hadithno{256}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah said:The Messenger of Allah (May peace be upon him) used to wash his head with marsh-mallow while he was sexually defiled. It was sufficient for him and he did not pour water upon it}}
\hadithdefcmd{abudawud}{257}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا شَرِيكٌ، عَنْ قَيْسِ بْنِ وَهْبٍ، عَنْ رَجُلٍ، مِنْ بَنِي سُوَاءَةَ بْنِ عَامِرٍ عَنْ عَائِشَةَ، فِيمَا يَفِيضُ بَيْنَ الرَّجُلِ وَالْمَرْأَةِ مِنَ الْمَاءِ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْخُذُ كَفًّا مِنْ مَاءٍ يَصُبُّ عَلَىَّ الْمَاءَ ثُمَّ يَأْخُذُ كَفًّا مِنْ مَاءٍ ثُمَّ يَصُبُّهُ عَلَيْهِ ‏.‏\hadithno{257}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{On being asked about (washing) the fluid that flows between man and woman ‘A’ishah said:The Messenger of Allah (May peace be upon him) used to take a handful of water and pour it on the fluid. Again, he would take a handful of water and pour it over the fluid}}
\hadithdefcmd{abudawud}{258}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ الْيَهُودَ، كَانَتْ إِذَا حَاضَتْ مِنْهُمُ امْرَأَةٌ أَخْرَجُوهَا مِنَ الْبَيْتِ وَلَمْ يُؤَاكِلُوهَا وَلَمْ يُشَارِبُوهَا وَلَمْ يُجَامِعُوهَا فِي الْبَيْتِ فَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَنْزَلَ اللَّهُ سُبْحَانَهُ ‏\{‏ وَيَسْأَلُونَكَ عَنِ الْمَحِيضِ قُلْ هُوَ أَذًى فَاعْتَزِلُوا النِّسَاءَ فِي الْمَحِيضِ ‏\}‏ إِلَى آخِرِ الآيَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ جَامِعُوهُنَّ فِي الْبُيُوتِ وَاصْنَعُوا كُلَّ شَىْءٍ غَيْرَ النِّكَاحِ ‏"‏ ‏.‏ فَقَالَتِ الْيَهُودُ مَا يُرِيدُ هَذَا الرَّجُلُ أَنْ يَدَعَ شَيْئًا مِنْ أَمْرِنَا إِلاَّ خَالَفَنَا فِيهِ ‏.‏ فَجَاءَ أُسَيْدُ بْنُ حُضَيْرٍ وَعَبَّادُ بْنُ بِشْرٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالاَ يَا رَسُولَ اللَّهِ إِنَّ الْيَهُودَ تَقُولُ كَذَا وَكَذَا أَفَلاَ نَنْكِحُهُنَّ فِي الْمَحِيضِ فَتَمَعَّرَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى ظَنَنَّا أَنْ قَدْ وَجَدَ عَلَيْهِمَا فَخَرَجَا فَاسْتَقْبَلَتْهُمَا هَدِيَّةٌ مِنْ لَبَنٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَعَثَ فِي آثَارِهِمَا فَسَقَاهُمَا فَظَنَنَّا أَنَّهُ لَمْ يَجِدْ عَلَيْهِمَا ‏.‏\hadithno{258}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (302)}\hadithtrans{Anas b. malik said:Among the jews, when a women menstruated, they ejected her from the house, and they did not eat with her, nor did they drink with her, nor did they associate with her in (their houses) so the Messenger of Allah (May peace be upon him) was questioned about that. Thereupon Allah revealed : “They question thee concerning menstruation. Say : I: is an illness, so let woman alone at such times” (ii 222). The Messenger of Allah (May peace be upon him) then said: Associate with them in the houses and do everything except sexual intercourse. Thereupon the Jews said: This man does not want to leave anything we do without opposing us in it. Usaid b. Hudair and Abbad b. Bishr came and said: Messenger of Allah, the jews are saying such and such a thing. Shall we not then have intercourse with women during mensuration? The face of the Apostle Allah(ﷺ) underwent such a change that we thought he was angry with them; but when they went out they received a gift of milk which was being brought to the Messenger of Allah(ﷺ), and he sent after them and gave them a drink, whereupon we thought that he was not angry with them}}
\hadithdefcmd{abudawud}{259}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ مِسْعَرٍ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَتَعَرَّقُ الْعَظْمَ وَأَنَا حَائِضٌ، فَأُعْطِيهِ النَّبِيَّ صلى الله عليه وسلم فَيَضَعُ فَمَهُ فِي الْمَوْضِعِ الَّذِي فِيهِ وَضَعْتُهُ وَأَشْرَبُ الشَّرَابَ فَأُنَاوِلُهُ فَيَضَعُ فَمَهُ فِي الْمَوْضِعِ الَّذِي كُنْتُ أَشْرَبُ مِنْهُ ‏.‏\hadithno{259}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (300)}\hadithtrans{Aishah said:I would eat flesh from a bone when I was menstruating, then hand it over to the Prophet(ﷺ) and he would put his mouth where I had put my mouth: I would drink, then hand it over to him, and he would put his mouth( at the place) where I drank}}
\hadithdefcmd{abudawud}{260}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ صَفِيَّةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضَعُ رَأْسَهُ فِي حِجْرِي فَيَقْرَأُ وَأَنَا حَائِضٌ ‏.‏\hadithno{260}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (297، 7549) Sahih Muslim (301)}\hadithtrans{Aishah said:The Messenger of Allah(ﷺ) would recline on my lap when I was menstruating, then recite the Qur’an}}
\hadithdefcmd{abudawud}{261}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَاوِلِينِي الْخُمْرَةَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي حَائِضٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ حَيْضَتَكِ لَيْسَتْ فِي يَدِكِ ‏"‏ ‏.‏\hadithno{261}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (298)}\hadithtrans{Aishah said:The Messenger of Allah (May peace be upon him) said to me; Get me the mat from the mosque. I said ; I am menstruating. The Messenger of Allah (May peace be upon him) then replied: Your menstruation is not in your hand}}
\hadithdefcmd{abudawud}{262}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ مُعَاذَةَ، أَنَّ امْرَأَةً، سَأَلَتْ عَائِشَةَ أَتَقْضِي الْحَائِضُ الصَّلاَةَ فَقَالَتْ أَحَرُورِيَّةٌ أَنْتِ لَقَدْ كُنَّا نَحِيضُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلاَ نَقْضِي وَلاَ نُؤْمَرُ بِالْقَضَاءِ ‏.‏\hadithno{262}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (335)}\hadithtrans{Mu’adhah reported :A woman asked ‘A’ishah: should a menstruating woman complete the prayer abandoned during the period of menses? ‘A’ishah said: Are you a Haruriyyah? During menstruation in the time of the Messenger of Allah (May peace be upon him) we would not complete (the abandoned prayers), nor were we commanded to complete them}}
\hadithdefcmd{abudawud}{263}{حَدَّثَنَا الْحَسَنُ بْنُ عَمْرٍو، أَخْبَرَنَا سُفْيَانُ، - يَعْنِي ابْنَ عَبْدِ الْمَلِكِ - عَنِ ابْنِ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، عَنْ مُعَاذَةَ الْعَدَوِيَّةِ، عَنْ عَائِشَةَ، بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ وَزَادَ فِيهِ فَنُؤْمَرُ بِقَضَاءِ الصَّوْمِ وَلاَ نُؤْمَرُ بِقَضَاءِ الصَّلاَةِ ‏.‏\hadithno{263}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been narrated through a different chain of the authority of Mu’adhah al-‘Adawiyyah from ‘A’ishah. This version adds; we were commanded to complete the (abandoned) fast, but were commanded to complete the (abandoned) prayer}}
\hadithdefcmd{abudawud}{264}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي الْحَكَمُ، عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الَّذِي يَأْتِي امْرَأَتَهُ وَهِيَ حَائِضٌ قَالَ ‏"‏ يَتَصَدَّقُ بِدِينَارٍ أَوْ نِصْفِ دِينَارٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَكَذَا الرِّوَايَةُ الصَّحِيحَةُ قَالَ ‏"‏ دِينَارٌ أَوْ نِصْفُ دِينَارٍ ‏"‏ ‏.‏ وَرُبَّمَا لَمْ يَرْفَعْهُ شُعْبَةُ ‏.‏\hadithno{264}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said about a person who had intercourse with his wife while she was menstruating: He must give one dinar or half a dinar in alms. Abu Dawud said: The correct version says si: One dinar or half a dinar. Shu'bah (a narrator) did not sometimes narrate this tradition as a statement of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{265}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ مُطَهَّرٍ، حَدَّثَنَا جَعْفَرٌ، - يَعْنِي ابْنَ سُلَيْمَانَ - عَنْ عَلِيِّ بْنِ الْحَكَمِ الْبُنَانِيِّ، عَنْ أَبِي الْحَسَنِ الْجَزَرِيِّ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِذَا أَصَابَهَا فِي أَوَّلِ الدَّمِ فَدِينَارٌ وَإِذَا أَصَابَهَا فِي انْقِطَاعِ الدَّمِ فَنِصْفُ دِينَارٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ قَالَ ابْنُ جُرَيْجٍ عَنْ عَبْدِ الْكَرِيمِ عَنْ مِقْسَمٍ ‏.‏\hadithno{265}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas said:If one has intercourse in the beginning of the menses,(one should give) one dinar; in case one has intercourse towards the end of the menses, then half a dinar (should be given)}}
\hadithdefcmd{abudawud}{266}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا شَرِيكٌ، عَنْ خُصَيْفٍ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا وَقَعَ الرَّجُلُ بِأَهْلِهِ وَهِيَ حَائِضٌ فَلْيَتَصَدَّقْ بِنِصْفِ دِينَارٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا قَالَ عَلِيُّ بْنُ بَذِيمَةَ عَنْ مِقْسَمٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَرَوَى الأَوْزَاعِيُّ عَنْ يَزِيدَ بْنِ أَبِي مَالِكٍ عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ آمُرُهُ أَنْ يَتَصَدَّقَ بِخُمْسَىْ دِينَارٍ ‏"‏ ‏.‏ وَهَذَا مُعْضَلٌ ‏.‏\hadithno{266}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas reported the Prophet (May peace be upon him) as saying; when a man has intercourse with his wife while she is menstruating, he must give half a dinar in alms. Abu Dawud said; ‘Ali b. Budhaimah reported similarly on the authority of Miqsam from the Prophet (May peace be upon him). Al-Awza’I narrated from Yazid b. Abi Malik, from ‘Abd al-Hamid b. ‘Abd al-Rahman from the Prophet (May peace be upon him); He ordered him to give two fifth of a dinar in alms. But this is a chain where two narrators (Miqsam and Ibn ‘Abbas) are missing}}
\hadithdefcmd{abudawud}{267}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حَبِيبٍ، مَوْلَى عُرْوَةَ عَنْ نُدْبَةَ، مَوْلاَةِ مَيْمُونَةَ عَنْ مَيْمُونَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُبَاشِرُ الْمَرْأَةَ مِنْ نِسَائِهِ وَهِيَ حَائِضٌ إِذَا كَانَ عَلَيْهَا إِزَارٌ إِلَى أَنْصَافِ الْفَخِذَيْنِ أَوِ الرُّكْبَتَيْنِ تَحْتَجِزُ بِهِ ‏.‏\hadithno{267}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Maimunah said:The Prophet (ﷺ) would contact and embrace any of his wives while she was menstruating. She would wear the wrapper up to half the the thighs or cover her knees with it}}
\hadithdefcmd{abudawud}{268}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ إِحْدَانَا إِذَا كَانَتْ حَائِضًا أَنْ تَتَّزِرَ ثُمَّ يُضَاجِعُهَا زَوْجُهَا وَقَالَ مَرَّةً يُبَاشِرُهَا ‏.‏\hadithno{268}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (300، 2030) Sahih Muslim (293)}\hadithtrans{Aishah said; When anyone amongst us (the wives of the Prophet) menstruated, the Messenger of Allah (May peace be upon him) asked her to tie a waist wrapper (over her body) and then husband lay with her, or he (Shu’bah) said:embraced her}}
\hadithdefcmd{abudawud}{269}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ جَابِرِ بْنِ صُبْحٍ، سَمِعْتُ خِلاَسًا الْهَجَرِيَّ، قَالَ سَمِعْتُ عَائِشَةَ، - رضى الله عنها - تَقُولُ كُنْتُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم نَبِيتُ فِي الشِّعَارِ الْوَاحِدِ وَأَنَا حَائِضٌ طَامِثٌ فَإِنْ أَصَابَهُ مِنِّي شَىْءٌ غَسَلَ مَكَانَهُ وَلَمْ يَعْدُهُ ثُمَّ صَلَّى فِيهِ وَإِنْ أَصَابَ - تَعْنِي ثَوْبَهُ - مِنْهُ شَىْءٌ غَسَلَ مَكَانَهُ وَلَمْ يَعْدُهُ ثُمَّ صَلَّى فِيهِ ‏.‏\hadithno{269}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Khallas al-Hujari reported: Aisha said: I and the Messenger of Allah (ﷺ) used to pass night in one (piece of) cloth (on me) while I menstruated profusely. If anything from me (i.e. blood) smeared him (i.e. his body), he would wash that spot and would not exceed it (in washing), then he would offer prayer with it}}
\hadithdefcmd{abudawud}{270}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ عُمَرَ بْنِ غَانِمٍ - عَنْ عَبْدِ الرَّحْمَنِ، - يَعْنِي ابْنَ زِيَادٍ - عَنْ عُمَارَةَ بْنِ غُرَابٍ، أَنَّ عَمَّةً، لَهُ حَدَّثَتْهُ أَنَّهَا، سَأَلَتْ عَائِشَةَ قَالَتْ إِحْدَانَا تَحِيضُ وَلَيْسَ لَهَا وَلِزَوْجِهَا إِلاَّ فِرَاشٌ وَاحِدٌ قَالَتْ أُخْبِرُكِ بِمَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم دَخَلَ لَيْلاً وَأَنَا حَائِضٌ فَمَضَى إِلَى مَسْجِدِهِ - قَالَ أَبُو دَاوُدَ تَعْنِي مَسْجِدَ بَيْتِهِ - فَلَمْ يَنْصَرِفْ حَتَّى غَلَبَتْنِي عَيْنِي وَأَوْجَعَهُ الْبَرْدُ فَقَالَ ‏"‏ ادْنِي مِنِّي ‏"‏ ‏.‏ فَقُلْتُ إِنِّي حَائِضٌ ‏.‏ فَقَالَ ‏"‏ وَإِنْ اكْشِفِي عَنْ فَخِذَيْكِ ‏"‏ ‏.‏ فَكَشَفْتُ فَخِذَىَّ فَوَضَعَ خَدَّهُ وَصَدْرَهُ عَلَى فَخِذَىَّ وَحَنَيْتُ عَلَيْهِ حَتَّى دَفِئَ وَنَامَ ‏.‏\hadithno{270}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Umarah ibn Ghurab said that his paternal aunt narrated to him that she asked Aisha: What if one of us menstruates and she and her husband have no bed except one? She replied: I relate to you what the Messenger of Allah (ﷺ) had done. One night he entered (upon me) while I was menstruating. He went to the place of his prayer, that is, to the place of prayer reserved (for this purpose) in his house. He did not return until I felt asleep heavily, and he felt pain from cold. And he said: Come near me. I said: I am menstruating. He said: Uncover your thighs. I, therefore, uncovered both of my thighs. Then he put his cheek and chest on my thighs and I lent upon he until he became warm and slept}}
\hadithdefcmd{abudawud}{271}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْجَبَّارِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ أَبِي الْيَمَانِ، عَنْ أُمِّ ذَرَّةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كُنْتُ إِذَا حِضْتُ نَزَلْتُ عَنِ الْمِثَالِ عَلَى الْحَصِيرِ فَلَمْ نَقْرُبْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَلَمْ نَدْنُ مِنْهُ حَتَّى نَطْهُرَ ‏.‏\hadithno{271}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When I menstruated, I left the bed and lay on the reed-mat and did not approach or come near the Messenger of Allah (ﷺ) until we were purified}}
\hadithdefcmd{abudawud}{272}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنْ بَعْضِ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ مِنَ الْحَائِضِ شَيْئًا أَلْقَى عَلَى فَرْجِهَا ثَوْبًا ‏.‏\hadithno{272}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated One of the Wives of the Prophet: Ikrimah reported on the authority of one of the wives of the Prophet (ﷺ) saying: When the Prophet (ﷺ) wanted to do something (i.e. kissing, embracing) with (his) menstruating wife, he would put a garment on her private part}}
\hadithdefcmd{abudawud}{273}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا فِي فَوْحِ حَيْضِنَا أَنْ نَتَّزِرَ ثُمَّ يُبَاشِرُنَا وَأَيُّكُمْ يَمْلِكُ إِرْبَهُ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْلِكُ إِرْبَهُ ‏.‏\hadithno{273}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (302) Sahih Muslim (293)}\hadithtrans{Aishah said; The Messenger of Allah (May peace be upon him) would ask us in the beginning of our menstruation to tie the waist-wrapper. Then he would embrace us. And who amongst you can have as much control over his desire as the Messenger of Allah (May peace be upon him) had over his desire?}}
\hadithdefcmd{abudawud}{274}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ امْرَأَةً كَانَتْ تُهَرَاقُ الدِّمَاءَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَفْتَتْ لَهَا أُمُّ سَلَمَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لِتَنْظُرْ عِدَّةَ اللَّيَالِي وَالأَيَّامِ الَّتِي كَانَتْ تَحِيضُهُنَّ مِنَ الشَّهْرِ قَبْلَ أَنْ يُصِيبَهَا الَّذِي أَصَابَهَا فَلْتَتْرُكِ الصَّلاَةَ قَدْرَ ذَلِكَ مِنَ الشَّهْرِ فَإِذَا خَلَّفَتْ ذَلِكَ فَلْتَغْتَسِلْ ثُمَّ لْتَسْتَثْفِرْ بِثَوْبٍ ثُمَّ لْتُصَلِّ فِيهِ ‏"‏ ‏.‏\hadithno{274}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: In the time of the Messenger of Allah (ﷺ) there was a woman who had an issue of blood. So Umm Salamah asked the Messenger of Allah (ﷺ) to give a decision about her. He said: She should consider the number of nights and days during which she used to menstruate each month before she was afflicted with this trouble and abandon prayer during that period each month. When those days and nights are over, she should take a bath, tie a cloth over her private parts and pray}}
\hadithdefcmd{abudawud}{275}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ خَالِدِ بْنِ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، قَالاَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ رَجُلاً، أَخْبَرَهُ عَنْ أُمِّ سَلَمَةَ، أَنَّ امْرَأَةً، كَانَتْ تُهَرَاقُ الدَّمَ ‏.‏ فَذَكَرَ مَعْنَاهُ قَالَ ‏ "‏ فَإِذَا خَلَّفَتْ ذَلِكَ وَحَضَرَتِ الصَّلاَةُ فَلْتَغْتَسِلْ ‏"‏ ‏.‏ بِمَعْنَاهُ ‏.‏\hadithno{275}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Sulaiman b. Yasar said that a man reported to him from Umm Salamah; There was a woman who had an issue of blood. And he narrated the rest of the tradition to the same effect saying; when the menstruation period is over and the time of prayer arrives, she should take a bath, as mentioned in the previous tradition}}
\hadithdefcmd{abudawud}{276}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا أَنَسٌ، - يَعْنِي ابْنَ عِيَاضٍ - عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ رَجُلٍ، مِنَ الأَنْصَارِ أَنَّ امْرَأَةً، كَانَتْ تُهَرَاقُ الدِّمَاءَ فَذَكَرَ مَعْنَى حَدِيثِ اللَّيْثِ قَالَ ‏ "‏ فَإِذَا خَلَّفَتْهُنَّ وَحَضَرَتِ الصَّلاَةُ فَلْتَغْتَسِلْ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَاهُ ‏.‏\hadithno{276}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Sulaiman b. Yasar reported on the authority of a person from the Ansar; There was a woman who had an issue of blood. He then narrated the rest of the tradition like that of al-Laith. He said; when the period of menstruation is over and the time of prayer arrives, she should take a bath. He narrated the tradition conveying the same meaning}}
\hadithdefcmd{abudawud}{277}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا صَخْرُ بْنُ جُوَيْرِيَةَ، عَنْ نَافِعٍ، بِإِسْنَادِ اللَّيْثِ وَبِمَعْنَاهُ قَالَ ‏ "‏ فَلْتَتْرُكِ الصَّلاَةَ قَدْرَ ذَلِكَ ثُمَّ إِذَا حَضَرَتِ الصَّلاَةُ فَلْتَغْتِسِلْ وَلْتَسْتَثْفِرْ بِثَوْبٍ ثُمَّ تُصَلِّي ‏"‏ ‏.‏\hadithno{277}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{This tradition has been transmitted through the chain of narrators like that of al-Laith to the same effect. It says; She should abandon prayer considering that period (she used to menstruate). When the time of prayer approaches, she should take a bath, tie a cloth over her private parts and offer prayer}}
\hadithdefcmd{abudawud}{278}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، بِهَذِهِ الْقِصَّةِ قَالَ فِيهِ ‏ "‏ تَدَعُ الصَّلاَةَ وَتَغْتَسِلُ فِيمَا سِوَى ذَلِكَ وَتَسْتَثْفِرُ بِثَوْبٍ وَتُصَلِّي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمَّى الْمَرْأَةَ الَّتِي كَانَتِ اسْتُحِيضَتْ حَمَّادُ بْنُ زَيْدٍ عَنْ أَيُّوبَ فِي هَذَا الْحَدِيثِ قَالَ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ ‏.‏\hadithno{278}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Sulaiman b. Yasar reported this narrative on the authority of Umm Salamah. This version has:He (the Prophet) said: She should abandon prayer and take a bath at the beginning of the additional period, and tie a cloth over her private parts and offer prayer. Abu Dawud said; Hammad b. Zaid on the authority of Ayyub has pointed out the name of the woman who had a prolonged flow of blood (referred to) in this tradition to be Fatimah daughter of Abu Hubaish}}
\hadithdefcmd{abudawud}{279}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ جَعْفَرٍ، عَنْ عِرَاكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ إِنَّ أُمَّ حَبِيبَةَ سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم عَنِ الدَّمِ - فَقَالَتْ عَائِشَةُ فَرَأَيْتُ مِرْكَنَهَا مَلآنَ دَمًا - فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ امْكُثِي قَدْرَ مَا كَانَتْ تَحْبِسُكِ حَيْضَتُكِ ثُمَّ اغْتَسِلِي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ قُتَيْبَةُ بَيْنَ أَضْعَافِ حَدِيثِ جَعْفَرِ بْنِ رَبِيعَةَ فِي آخِرِهَا وَرَوَاهُ عَلِيُّ بْنُ عَيَّاشٍ وَيُونُسُ بْنُ مُحَمَّدٍ عَنِ اللَّيْثِ فَقَالاَ جَعْفَرُ بْنُ رَبِيعَةَ ‏.‏\hadithno{279}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (334)}\hadithtrans{Aishah reported :Umm Habibah asked the prophet (ﷺ) about the blood (which flows beyond the period of menstruation). ‘A’ishah said: I saw her wash-tub full of blood. The apostle of Allah (May peace be upon him) said; Keep away (from prayer) equal (to the length of time) that your menses prevented you. Then wash yourself. Abu Dawud said: Qutaibah mentioned the name Jaftar b. Rabi’ah in the middle of the text of the tradition for the second time (i.e., Qutaibah, being doubtful about the narrator Jafar b. Rabi’ah, mentioned his name twice: once in the chain and again while reporting the text). Ali b. ‘Ayyash and yunus b. Muhammad reported it on the authority of al-Laith. They mentioned the name Jafar b. Rabi’ah}}
\hadithdefcmd{abudawud}{280}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنِ الْمُنْذِرِ بْنِ الْمُغِيرَةِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، حَدَّثَتْهُ أَنَّهَا، سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَشَكَتْ إِلَيْهِ الدَّمَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكَ عِرْقٌ فَانْظُرِي إِذَا أَتَى قُرْؤُكِ فَلاَ تُصَلِّي فَإِذَا مَرَّ قُرْؤُكِ فَتَطَهَّرِي ثُمَّ صَلِّي مَا بَيْنَ الْقُرْءِ إِلَى الْقُرْءِ ‏"‏ ‏.‏\hadithno{280}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Fatimah daughter of AbuHubaysh: Urwah ibn az-Zubayr said that Fatimah daughter of AbuHubaysh narrated to him that she asked the Messenger of Allah (ﷺ) and complained to him about the flowing of (her) blood. The Messenger of Allah (ﷺ) said to her: That is only (due to) a vein: look, when your menstruation comes, do not pray; and when your menstruation ends, wash yourself and then offer prayer during the period from one menstruation to another}}
\hadithdefcmd{abudawud}{281}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، - يَعْنِي ابْنَ أَبِي صَالِحٍ - عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، حَدَّثَتْنِي فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ، أَنَّهَا أَمَرَتْ أَسْمَاءَ - أَوْ أَسْمَاءُ حَدَّثَتْنِي أَنَّهَا، أَمَرَتْهَا فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ - أَنْ تَسْأَلَ، رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرَهَا أَنْ تَقْعُدَ الأَيَّامَ الَّتِي كَانَتْ تَقْعُدُ ثُمَّ تَغْتَسِلُ ‏.1 قَالَ أَبُو دَاوُدَ وَرَوَاهُ قَتَادَةُ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ اسْتُحِيضَتْ فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم أَنْ تَدَعَ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلَ وَتُصَلِّيَ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَسْمَعْ قَتَادَةُ مِنْ عُرْوَةَ شَيْئًا ‏.2 وَزَادَ ابْنُ عُيَيْنَةَ فِي حَدِيثِ الزُّهْرِيِّ عَنْ عَمْرَةَ عَنْ عَائِشَةَ أَنَّ أُمَّ حَبِيبَةَ كَانَتْ تُسْتَحَاضُ فَسَأَلَتِ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهَا أَنْ تَدَعَ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا وَهَمٌ مِنَ ابْنِ عُيَيْنَةَ لَيْسَ هَذَا فِي حَدِيثِ الْحُفَّاظِ عَنِ الزُّهْرِيِّ إِلاَّ مَا ذَكَرَ سُهَيْلُ بْنُ أَبِي صَالِحٍ وَقَدْ رَوَى الْحُمَيْدِيُّ هَذَا الْحَدِيثَ عَنِ ابْنِ عُيَيْنَةَ لَمْ يَذْكُرْ فِيهِ ‏"‏ تَدَعُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ‏"‏ ‏.1 وَرَوَتْ قَمِيرُ بِنْتُ عَمْرٍو زَوْجُ مَسْرُوقٍ عَنْ عَائِشَةَ الْمُسْتَحَاضَةُ تَتْرُكُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلُ ‏.3 وَقَالَ عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ عَنْ أَبِيهِ إِنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهَا أَنْ تَتْرُكَ الصَّلاَةَ قَدْرَ أَقْرَائِهَا ‏.2 وَرَوَى أَبُو بِشْرٍ جَعْفَرُ بْنُ أَبِي وَحْشِيَّةَ عَنْ عِكْرِمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ اسْتُحِيضَتْ فَذَكَرَ مِثْلَهُ وَرَوَى شَرِيكٌ عَنْ أَبِي الْيَقْظَانِ عَنْ عَدِيِّ بْنِ ثَابِتٍ عَنْ أَبِيهِ عَنْ جَدِّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ الْمُسْتَحَاضَةُ تَدَعُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلُ وَتُصَلِّي ‏"‏ ‏.1 وَرَوَى الْعَلاَءُ بْنُ الْمُسَيَّبِ عَنِ الْحَكَمِ عَنْ أَبِي جَعْفَرٍ أَنَّ سَوْدَةَ اسْتُحِيضَتْ فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم إِذَا مَضَتْ أَيَّامُهَا اغْتَسَلَتْ وَصَلَّتْ ‏.1 وَرَوَى سَعِيدُ بْنُ جُبَيْرٍ عَنْ عَلِيٍّ وَابْنِ عَبَّاسٍ ‏"‏ الْمُسْتَحَاضَةُ تَجْلِسُ أَيَّامَ قُرْئِهَا ‏"‏ ‏.1 وَكَذَلِكَ رَوَاهُ عَمَّارٌ مَوْلَى بَنِي هَاشِمٍ وَطَلْقُ بْنُ حَبِيبٍ عَنِ ابْنِ عَبَّاسٍ 1 وَكَذَلِكَ رَوَاهُ مَعْقِلٌ الْخَثْعَمِيُّ عَنْ عَلِيٍّ رَضِيَ اللَّهُ عَنْهُ 4 وَكَذَلِكَ رَوَى الشَّعْبِيُّ عَنْ قَمِيرَ امْرَأَةِ مَسْرُوقٍ عَنْ عَائِشَةَ رضى الله عنها ‏. قَالَ أَبُو دَاوُدَ وَهُوَ قَوْلُ الْحَسَنِ وَسَعِيدِ بْنِ الْمُسَيَّبِ وَعَطَاءٍ وَمَكْحُولٍ وَإِبْرَاهِيمَ وَسَالِمٍ وَالْقَاسِمِ إِنَّ الْمُسْتَحَاضَةَ تَدَعُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَسْمَعْ قَتَادَةُ مِنْ عُرْوَةَ شَيْئًا ‏.‏\hadithno{281}\hadithgrade{Al-Albani: Sahih Muquf; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Urwah b. al-Zubair said:Fatimah daughter of Abu Hubaish narrated to me that she asked Asma' (daughter of Abu Bakr), or Asma' narrated to me that Fatimah daughter of Abu Hubaish asked her to question the Messenger of Allah (ﷺ). He advised her to refrain (from prayer) equal to the period she refrained previously. She then should wash herself.1 Abu Dawud said: Qatadah narrated it from 'Urwah b. al-Zubair, from Zainab daughter of Umm Salamah, that Umm Habibah daughter of Jahsh had a prolonged flow of blood. The Prophet (ﷺ) commanded her to abandon prayer for the period of her menses. She then should take a bath, and offer prayer. Abu Dawud said: Qatadah did not hear anything from 'Urwah. 2 And Ibn 'Uyainah added in the tradition narrated by al-Zuhri from 'Umrah on the authority of 'Aishah. Umm Habibah had a prolonged flow of blood. She asked the Prophet (ﷺ). He commanded her to abandon prayer during her menstrual period. Abu Dawud said: This is a misunderstanding on the part of Ibn 'Uyainah. This is not found in the tradition reported by the transmitter from al-Zuhri except that mentioned by Suhail b. Abu Salih. Al-Humaidi also narrated this tradition from Ibn 'Uyainah, but he did not mention the words "she should abandon prayer during her menstrual period."1 Qumair daughter of Masruq reported on the authority of 'Aishah: The woman who has prolonged flow of blood should abandon prayer during her menstrual period.3 'Abd al-Rahman b. al-Qasim reported on the authority of his father: The Prophet (ﷺ) commanded her to abandon prayers equal (to the length of time) that she has her (usual) menses.2 Abu Bishr Ja'far b. Abi Wahshiyyah reported on the authority of 'Ikrimah from the Prophet (ﷺ) saying: Umm Habibah daughter of Jahsh had a prolonged flow of blood; and he transmitted like that.1 Sharik narrated from Abu al-Yaqzan from 'Adi b. Thabit from his father on the authority of his grandfather from the Prophet (ﷺ): The woman suffering from a prolonged flow of blood should abandon prayer during her menstrual period ; she then should was herself and pray. 1 Al-'Ala b. al-Musayyab reported from al-Hakam on the authority of Abu Ja'far, saying: Saudah had a prolonged flow of blood. The Prophet (ﷺ) commanded that when he menstruation was finished, she should take bath and pray.1 Sa'id b. Jubair reported from 'Ali and Ibn 'Abbas : A woman suffering from a prolonged flow of blood should refrain from prayers during her menstrual period.1 'Ammar, the freed slave of Banu Hashim and Talq b. Habib narrated in a similar way.1 Similarly, it was reported by Ma'qil al-Khath'ami from 'Ali4, al-Sha'bi also transmitted it in a similar manner from Qumair, the wife of Masruq, on the authority of 'Aishah.1 Abu Dawud said: Al-Hasan, Sa'id b. al-Musayyab, 'Ata, Makhul, Ibrahim, Salim and al-Qasim also hold that a woman suffering from a prolonged flow of blood should abandon prayer during her menstrual period. Abu Dawud said: Qatadah did not hear anything from 'Urwah}}
\hadithdefcmd{abudawud}{282}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، قَالاَ حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي امْرَأَةٌ أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ ثُمَّ صَلِّي ‏"‏ ‏.‏\hadithno{282}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (306) Sahih Muslim (333)}\hadithtrans{Urwah reported on the authority of 'Aishah:Fatimah daughter of Abu Hubaish came to the Messenger of Allah (ﷺ) and said: I am a woman who has prolonged flow of blood; I am never purified ; should I abandon prayer ? He replied: This is (due to) a vein, and not menstruation. When the menstruation begins, you should abandon prayer ; when it is finished, you should wash away the blood and pray}}
\hadithdefcmd{abudawud}{283}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ هِشَامٍ، بِإِسْنَادِ زُهَيْرٍ وَمَعْنَاهُ وَقَالَ ‏ "‏ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَاتْرُكِي الصَّلاَةَ فَإِذَا ذَهَبَ قَدْرُهَا فَاغْسِلِي الدَّمَ عَنْكِ وَصَلِّي ‏"‏ ‏.‏\hadithno{283}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (306)}\hadithtrans{This tradition has also been transmitted by Zuhair through a different chain of narrators, to the same effect. He said:When the menstruation begins, you should abandon prayer; when the period equal to its length of time passes, you should wash away the blood and pray}}
\hadithdefcmd{abudawud}{284}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَقِيلٍ، عَنْ بُهَيَّةَ، قَالَتْ سَمِعْتُ امْرَأَةً، تَسْأَلُ عَائِشَةَ عَنِ امْرَأَةٍ، فَسَدَ حَيْضُهَا وَأُهَرِيقَتْ دَمًا فَأَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ آمُرَهَا فَلْتَنْظُرْ قَدْرَ مَا كَانَتْ تَحِيضُ فِي كُلِّ شَهْرٍ وَحَيْضُهَا مُسْتَقِيمٌ فَلْتَعْتَدَّ بِقَدْرِ ذَلِكَ مِنَ الأَيَّامِ ثُمَّ لْتَدَعِ الصَّلاَةَ فِيهِنَّ أَوْ بِقَدْرِهِنَّ ثُمَّ لْتَغْتَسِلْ ثُمَّ لْتَسْتَثْفِرْ بِثَوْبٍ ثُمَّ لْتُصَلِّي ‏.‏\hadithno{284}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Bahiyyah said: I heard a woman asking Aisha about the woman whose menses became abnormal and she had an issue of blood. The Messenger of Allah (ﷺ) asked me to advise her that she should consider the period during which she used to menstruate every month, when her menstruation was normal. Then she should count the days equal to the length of time (of her normal menses); then she should abandon prayer during those days or equal to that period. She should then take a bath, tie a cloth on her private parts a pray}}
\hadithdefcmd{abudawud}{285}{حَدَّثَنَا ابْنُ أَبِي عَقِيلٍ، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَعَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ، خَتَنَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَتَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ اسْتُحِيضَتْ سَبْعَ سِنِينَ فَاسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ هَذِهِ لَيْسَتْ بِالْحَيْضَةِ وَلَكِنْ هَذَا عِرْقٌ فَاغْتَسِلِي وَصَلِّي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ زَادَ الأَوْزَاعِيُّ فِي هَذَا الْحَدِيثِ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ وَعَمْرَةَ عَنْ عَائِشَةَ قَالَتِ اسْتُحِيضَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ - وَهِيَ تَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ - سَبْعَ سِنِينَ فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْتَسِلِي وَصَلِّي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَمْ يَذْكُرْ هَذَا الْكَلاَمَ أَحَدٌ مِنْ أَصْحَابِ الزُّهْرِيِّ غَيْرَ الأَوْزَاعِيِّ وَرَوَاهُ عَنِ الزُّهْرِيِّ عَمْرُو بْنُ الْحَارِثِ وَاللَّيْثُ وَيُونُسُ وَابْنُ أَبِي ذِئْبٍ وَمَعْمَرٌ وَإِبْرَاهِيمُ بْنُ سَعْدٍ وَسُلَيْمَانُ بْنُ كَثِيرٍ وَابْنُ إِسْحَاقَ وَسُفْيَانُ بْنُ عُيَيْنَةَ وَلَمْ يَذْكُرُوا هَذَا الْكَلاَمَ ‏.‏ قَالَ أَبُو دَاوُدَ وَإِنَّمَا هَذَا لَفْظُ حَدِيثِ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَزَادَ ابْنُ عُيَيْنَةَ فِيهِ أَيْضًا أَمَرَهَا أَنْ تَدَعَ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ‏.‏ وَهُوَ وَهَمٌ مِنَ ابْنِ عُيَيْنَةَ وَحَدِيثُ مُحَمَّدِ بْنِ عَمْرٍو عَنِ الزُّهْرِيِّ فِيهِ شَىْءٌ يَقْرُبُ مِنَ الَّذِي زَادَ الأَوْزَاعِيُّ فِي حَدِيثِهِ ‏.‏\hadithno{285}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (327) Sahih Muslim (334)}\hadithtrans{Aishah said:Umm Habibah, daughter of Jahsh and sister-in-law of Messenger of Allah (ﷺ)m and wife of 'Abd al-Rahman b. 'Awf, had a prolonged flow of blood for seven years. She inquired from the Messenger of Allah (ﷺ) about it. The Messenger of Allah (ﷺ) said: This is not menstruation, but this (due to) a vein. Therefore, wash yourself and pray. Abu Dawud said: In this tradition which is transmitted by al-Zuhri from 'Urwah and 'Urwah on the authority of 'Aishah, al-Awza'i added: She ('Aishah) said: Umm Habibah daughter of Jahsh and wife of 'Abd al-Rahman b. 'Awf had a prolonged flow of blood for seven years. The Prophet (ﷺ) commander her saying: When the menstruation begins, abandon prayer; when it is finished, take a bath and pray. Abu Dawud said: None of the disciple of al-Zuhri mentioned these words except al-Awza'i, from al-Zuhri it has been narrated by 'Amr b. al-Harith, al-Laith, Yunus, Ibn Abi Dhi'b, Ma'mar, Ibrahim b. Sa'd, Sulaiman b. Kathir, Ibn Ishaq and Sufyan b. 'Uyainah, they did not narrate these words. Abu Dawud said: These are the words of the version reported by Hisham b. 'Urwah from this father on the authority of 'Aishah. Abu Dawud said: In this tradition Ibn 'Uyainah also added the words: He commander her to abandon prayer during her menstrual period. This is a misunderstanding on the part of Ibn 'Uyainah. The version of this tradition narrated by Muhammad b. 'Amr from al-Zuhri has the addition similar to that made by al-Awza'i in his version}}
\hadithdefcmd{abudawud}{286}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ عَمْرٍو - قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ فَاطِمَةَ بِنْتِ أَبِي حُبَيْشٍ، أَنَّهَا كَانَتْ تُسْتَحَاضُ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ دَمُ الْحَيْضَةِ فَإِنَّهُ دَمٌ أَسْوَدُ يُعْرَفُ فَإِذَا كَانَ ذَلِكَ فَأَمْسِكِي عَنِ الصَّلاَةِ فَإِذَا كَانَ الآخَرُ فَتَوَضَّئِي وَصَلِّي فَإِنَّمَا هُوَ عِرْقٌ ‏"‏ ‏.1 قَالَ أَبُو دَاوُدَ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا بِهِ ابْنُ أَبِي عَدِيٍّ مِنْ كِتَابِهِ هَكَذَا ثُمَّ حَدَّثَنَا بِهِ بَعْدُ حِفْظًا قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ أَنَّ فَاطِمَةَ كَانَتْ تُسْتَحَاضُ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَدْ رَوَى أَنَسُ بْنُ سِيرِينَ عَنِ ابْنِ عَبَّاسٍ فِي الْمُسْتَحَاضَةِ قَالَ إِذَا رَأَتِ الدَّمَ الْبَحْرَانِيَّ فَلاَ تُصَلِّي وَإِذَا رَأَتِ الطُّهْرَ وَلَوْ سَاعَةً فَلْتَغْتَسِلْ وَتُصَلِّي ‏.‏2 وَقَالَ مَكْحُولٌ إِنَّ النِّسَاءَ لاَ تَخْفَى عَلَيْهِنَّ الْحَيْضَةُ إِنَّ دَمَهَا أَسْوَدُ غَلِيظٌ فَإِذَا ذَهَبَ ذَلِكَ وَصَارَتْ صُفْرَةً رَقِيقَةً فَإِنَّهَا مُسْتَحَاضَةٌ فَلْتَغْتَسِلْ وَلْتُصَلِّي ‏.3 قَالَ أَبُو دَاوُدَ وَرَوَى حَمَّادُ بْنُ زَيْدٍ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ فِي الْمُسْتَحَاضَةِ إِذَا أَقْبَلَتِ الْحَيْضَةُ تَرَكَتِ الصَّلاَةَ وَإِذَا أَدْبَرَتِ اغْتَسَلَتْ وَصَلَّتْ ‏.2‏ ‏ وَرَوَى سُمَىٌّ وَغَيْرُهُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ تَجْلِسُ أَيَّامَ أَقْرَائِهَا ‏.2‏ وَكَذَلِكَ رَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى يُونُسُ عَنِ الْحَسَنِ الْحَائِضُ إِذَا مَدَّ بِهَا الدَّمُ تُمْسِكُ بَعْدَ حَيْضَتِهَا يَوْمًا أَوْ يَوْمَيْنِ فَهِيَ مُسْتَحَاضَةٌ ‏.‏ وَقَالَ التَّيْمِيُّ عَنْ قَتَادَةَ إِذَا زَادَ عَلَى أَيَّامِ حَيْضِهَا خَمْسَةُ أَيَّامٍ فَلْتُصَلِّي ‏.‏ قَالَ التَّيْمِيُّ فَجَعَلْتُ أَنْقُصُ حَتَّى بَلَغْتُ يَوْمَيْنِ فَقَالَ إِذَا كَانَ يَوْمَيْنِ فَهُوَ مِنْ حَيْضِهَا ‏.‏ وَسُئِلَ ابْنُ سِيرِينَ عَنْهُ فَقَالَ النِّسَاءُ أَعْلَمُ بِذَلِكَ ‏.‏\hadithno{286}\hadithgrade{Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Fatimah daughter of AbuHubaysh: Urwah ibn az-Zubayr reported from Fatimah daughter of AbuHubaysh that her blood kept flowing, so the Prophet (ﷺ) said to her: When the blood of the menses comes, it is black blood which can be recognised; so when that comes, refrain from prayer; but when a different type of blood comes, perform ablution and pray, for it is (due only to) a vein. Abu Dawud said: Ibn al-Muthanna narrates this tradition from his book on the authority of Ibn 'Adi in a similar way. Later on he transmitted it to us from his memory: Muhammad b. 'Amr reported to us from al-Zuhri from 'Urwah on the authority of 'Aishah who said: Fatimah used to have her blood flowing. He then reported the tradition conveying the same meaning. Abu Dawud said: Anas b. Sirin reported from Ibn 'Abbas about the woman who has a prolonged flow of blood. He said: If she sees thick blood, she should not pray; if she finds herself purified even for a moment, she should was an pray. Makhul said: Menses are not hidden from women. Their blood is black and thick. When it (blackness and thickness) goes away and there appears yellowness and liquidness, that is the flow of blood (from vein). She should wash and pray. Abu Dawud said: This tradition has been transmitted by Sa'id b. al-Musayyab through a different chain of narrators, saying: The woman who has a prolonged flow of blood should abandon prayer when the menstruation begins; when it is finished, she should wash and pray. Sumayy and others have also reported it from Sa'id b. al-Musayyab. This version adds: She should refrain (from prayer) during her menstrual period. Hammad b. Salamah has reported it similarly from Yahya b. Sa'id on the authority of Sa'id b. al-Musayyab. Abu Dawud said: Yunus has reported from Al-Hasan: When the bleeding of a menstruating woman extends (beyond the normal period), she should refrain (from prayer), after her menses are over, for one or two days. Now she becomes the woman who has a prolonged flow of blood. Al-Taimi reported from Qatadah: If her menstrual period is prolonged by five days, she should pray. Al-Taimi said: I kept on reducing (the number of days) until I reached two days. He said: If the period extends by two days, they will be counted from the menstrual period. When Ibn Sirin was questioned about it, he said: Women have better knowledge of that}}
\hadithdefcmd{abudawud}{287}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَغَيْرُهُ، قَالاَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ، عَنْ عَمِّهِ، عِمْرَانَ بْنِ طَلْحَةَ عَنْ أُمِّهِ، حَمْنَةَ بِنْتِ جَحْشٍ قَالَتْ كُنْتُ أُسْتَحَاضُ حَيْضَةً كَثِيرَةً شَدِيدَةً فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَسْتَفْتِيهِ وَأُخْبِرُهُ فَوَجَدْتُهُ فِي بَيْتِ أُخْتِي زَيْنَبَ بِنْتِ جَحْشٍ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أُسْتَحَاضُ حَيْضَةً كَثِيرَةً شَدِيدَةً فَمَا تَرَى فِيهَا قَدْ مَنَعَتْنِي الصَّلاَةَ وَالصَّوْمَ فَقَالَ ‏"‏ أَنْعَتُ لَكِ الْكُرْسُفَ فَإِنَّهُ يُذْهِبُ الدَّمَ ‏"‏ ‏.‏ قَالَتْ هُوَ أَكْثَرُ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَاتَّخِذِي ثَوْبًا ‏"‏ ‏.‏ فَقَالَتْ هُوَ أَكْثَرُ مِنْ ذَلِكَ إِنَّمَا أَثُجُّ ثَجًّا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَآمُرُكِ بِأَمْرَيْنِ أَيَّهُمَا فَعَلْتِ أَجْزَأَ عَنْكِ مِنَ الآخَرِ وَإِنْ قَوِيتِ عَلَيْهِمَا فَأَنْتِ أَعْلَمُ ‏"‏ ‏.‏ فَقَالَ لَهَا ‏"‏ إِنَّمَا هَذِهِ رَكْضَةٌ من رَكَضَاتِ الشَّيْطَانِ فَتَحَيَّضِي سِتَّةَ أَيَّامٍ أَوْ سَبْعَةَ أَيَّامٍ فِي عِلْمِ اللَّهِ ثُمَّ اغْتَسِلِي حَتَّى إِذَا رَأَيْتِ أَنَّكِ قَدْ طَهُرْتِ وَاسْتَنْقَأْتِ فَصَلِّي ثَلاَثًا وَعِشْرِينَ لَيْلَةً أَوْ أَرْبَعًا وَعِشْرِينَ لَيْلَةً وَأَيَّامَهَا وَصُومِي فَإِنَّ ذَلِكَ يُجْزِئُكِ وَكَذَلِكَ فَافْعَلِي فِي كُلِّ شَهْرٍ كَمَا تَحِيضُ النِّسَاءُ وَكَمَا يَطْهُرْنَ مِيقَاتَ حَيْضِهِنَّ وَطُهْرِهِنَّ وَإِنْ قَوِيتِ عَلَى أَنْ تُؤَخِّرِي الظُّهْرَ وَتُعَجِّلِي الْعَصْرَ فَتَغْتَسِلِينَ وَتَجْمَعِينَ بَيْنَ الصَّلاَتَيْنِ الظُّهْرِ وَالْعَصْرِ وَتُؤَخِّرِينَ الْمَغْرِبَ وَتُعَجِّلِينَ الْعِشَاءَ ثُمَّ تَغْتَسِلِينَ وَتَجْمَعِينَ بَيْنَ الصَّلاَتَيْنِ فَافْعَلِي وَتَغْتَسِلِينَ مَعَ الْفَجْرِ فَافْعَلِي وَصُومِي إِنْ قَدَرْتِ عَلَى ذَلِكَ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَهَذَا أَعْجَبُ الأَمْرَيْنِ إِلَىَّ ‏"‏ ‏.1 قَالَ أَبُو دَاوُدَ وَرَوَاهُ عَمْرُو بْنُ ثَابِتٍ عَنِ ابْنِ عَقِيلٍ قَالَ فَقَالَتْ حَمْنَةُ فَقُلْتُ هَذَا أَعْجَبُ الأَمْرَيْنِ إِلَىَّ ‏.‏2 لَمْ يَجْعَلْهُ مِنْ قَوْلِ النَّبِيِّ صلى الله عليه وسلم جَعَلَهُ كَلاَمَ حَمْنَةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَعَمْرُو بْنُ ثَابِتٍ رَافِضِيٌّ رَجُلُ سَوْءٍ وَلَكِنَّهُ كَانَ صَدُوقًا فِي الْحَدِيثِ وَثَابِتُ بْنُ الْمِقْدَامِ رَجُلٌ ثِقَةٌ وَذَكَرَهُ عَنْ يَحْيَى بْنِ مَعِينٍ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ يَقُولُ حَدِيثُ ابْنِ عَقِيلٍ فِي نَفْسِي مِنْهُ شَىْءٌ ‏.‏\hadithno{287}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hamnah daughter of Jahsh: Hamnah said my menstruation was great in quantity and severe. So I came to the Messenger of Allah (ﷺ) for a decision and told him. I found him in the house of my sister, Zaynab, daughter of Jahsh. I said: Messenger of Allah, I am a woman who menstruates in great quantity and it is severe, so what do you think about it? It has prevented me from praying and fasting. He said: I suggest that you should use cotton, for it absorbs the blood. She replied: It is too copious for that. He said: Then take a cloth. She replied: It is too copious for that, for my blood keeps flowing. The Messenger of Allah (ﷺ) said: I shall give you two commands; whichever of them you follow, that will be sufficient for you without the other, but you know best whether you are strong enough to follow both of them. He added: This is a stroke of the Devil, so observe your menses for six or seven days, Allah alone knows which it should be; then wash. And when you see that you are purified and quite clean, pray during twenty-three or twenty-four days and nights and fast, for that will be enough for you, and do so every month, just as women menstruate and are purified at the time of their menstruation and their purification. But if you are strong enough to delay the noon (Zuhr) prayer and advance the afternoon ('Asr) prayer, to wash, and then combine the noon and the afternoon prayer; to delay the sunset prayer and advance the night prayer, to wash, and then combine the two prayers, do so: and to wash at dawn, do so: and fast if you are able to do so if possible. The Messenger of Allah (ﷺ) said: Of the two commands this is more to my liking.1 Abu Dawud said: 'Amr b. Thabit narrated from Ibn 'Aqil: Hamnah said: Of the two commands this is the one which is more to my liking.2 In this version these words were not quoted as the statement of the Prophet (ﷺ); it gives it as a statement of Hamnah. Abu Dawud said: 'Amr b. Thabit was a Rafidi. This has been said by Yahya b. Ma'in. Abu Dawud said: I heard Ahmad (b. Hanbal) say: I am doubtful about the tradition transmitted by Ibn 'Aqil}}
\hadithdefcmd{abudawud}{288}{حَدَّثَنَا ابْنُ أَبِي عَقِيلٍ، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ خَتَنَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَتَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ اسْتُحِيضَتْ سَبْعَ سِنِينَ فَاسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذِهِ لَيْسَتْ بِالْحَيْضَةِ وَلَكِنْ هَذَا عِرْقٌ فَاغْتَسِلِي وَصَلِّي ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَكَانَتْ تَغْتَسِلُ فِي مِرْكَنٍ فِي حُجْرَةِ أُخْتِهَا زَيْنَبَ بِنْتِ جَحْشٍ حَتَّى تَعْلُوَ حُمْرَةُ الدَّمِ الْمَاءَ ‏.‏\hadithno{288}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah, wife of Prophet (ﷺ), said:Umm Habibah, daughter of Jahsh, sister-in-law of Messenger of Allah (ﷺ) and wife of 'Abd al-Rahman b. 'Awf, had a flow of blood for seven years. She asked the Messenger of Allah (ﷺ) about it. The Messenger of Allah (ﷺ) said: This is not menstruation but only vein; so you should take a bath and pray. 'Aishah said: She used to take bath in a wash-tub in the apartment of her sister Zainab daughter of Jahsh ; the redness of (her) blood dominated the water}}
\hadithdefcmd{abudawud}{289}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَتْنِي عَمْرَةُ بِنْتُ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّ حَبِيبَةَ، بِهَذَا الْحَدِيثِ قَالَتْ عَائِشَةُ رَضِيَ اللَّهُ عَنْهَا ‏.‏ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ ‏.‏\hadithno{289}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{This tradition has been transmitted through a different chain of narrators. According to this version. 'Aishah said:She would wash herself for every prayer}}
\hadithdefcmd{abudawud}{290}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، حَدَّثَنِي اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، بِهَذَا الْحَدِيثِ قَالَ فِيهِ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الْقَاسِمُ بْنُ مَبْرُورٍ عَنْ يُونُسَ عَنِ ابْنِ شِهَابٍ عَنْ عَمْرَةَ عَنْ عَائِشَةَ عَنْ أُمِّ حَبِيبَةَ بِنْتِ جَحْشٍ وَكَذَلِكَ رَوَاهُ مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عَمْرَةَ عَنْ عَائِشَةَ وَرُبَّمَا قَالَ مَعْمَرٌ عَنْ عَمْرَةَ عَنْ أُمِّ حَبِيبَةَ بِمَعْنَاهُ وَكَذَلِكَ رَوَاهُ إِبْرَاهِيمُ بْنُ سَعْدٍ وَابْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ عَمْرَةَ عَنْ عَائِشَةَ وَقَالَ ابْنُ عُيَيْنَةَ فِي حَدِيثِهِ وَلَمْ يَقُلْ إِنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهَا أَنْ تَغْتَسِلَ ‏.‏ وَكَذَلِكَ رَوَاهُ الأَوْزَاعِيُّ أَيْضًا قَالَ فِيهِ قَالَتْ عَائِشَةُ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ ‏.‏\hadithno{290}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (334)}\hadithtrans{This has bee	n narrated though a different chain of narrators by 'Aishah. This version has the words:"She used to take a bath for every prayer." Abu Dawud said: Al-Qasim b. Mabrur reported from Yunus from Ibn Shihab from 'Amrah from 'Aishah from Umm Habibah daughter of Jahsh. Similarly, it was reported by Ma'mar from al-Zuhri from 'Amrah from 'Aishah. Ma'mar sometimes reported from 'Amrah on the authority of Umm Habibah to the same effect. Similarly, it was reported by Ibrahim b. Sa'd and Ibn 'Uyainah from al-Zuhri from 'Amrah from 'Aishah. Ibn 'Uyainah said in his version: He (al-Zuhri) did not say that the Prophet (ﷺ) commanded her to take bath. It has also been transmitted by al-Awza'i in a similar way. In this version he said: 'Aishah said: She used to take bath for very prayer}}
\hadithdefcmd{abudawud}{291}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، حَدَّثَنِي أَبِي، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ، اسْتُحِيضَتْ سَبْعَ سِنِينَ فَأَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَغْتَسِلَ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ ‏.‏\hadithno{291}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari (327) Sahih Muslim (334)}\hadithtrans{Aishah said:Umm Habibah had a prolonged flow of blood for seven years. The Messenger of Allah (ﷺ) commanded her to take bath; so she used to take bath for every prayer}}
\hadithdefcmd{abudawud}{292}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدَةَ، عَنِ ابْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ، اسْتُحِيضَتْ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَهَا بِالْغُسْلِ لِكُلِّ صَلاَةٍ وَسَاقَ الْحَدِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ أَبُو الْوَلِيدِ الطَّيَالِسِيُّ وَلَمْ أَسْمَعْهُ مِنْهُ عَنْ سُلَيْمَانَ بْنِ كَثِيرٍ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ قَالَتِ اسْتُحِيضَتْ زَيْنَبُ بِنْتُ جَحْشٍ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ اغْتَسِلِي لِكُلِّ صَلاَةٍ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ عَبْدُ الصَّمَدِ عَنْ سُلَيْمَانَ بْنِ كَثِيرٍ قَالَ ‏"‏ تَوَضَّئِي لِكُلِّ صَلاَةٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا وَهَمٌ مِنْ عَبْدِ الصَّمَدِ وَالْقَوْلُ فِيهِ قَوْلُ أَبِي الْوَلِيدِ ‏.‏\hadithno{292}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah said:Umm Habibah had a prolonged flow of blood during the time of Messenger of Allah (ﷺ). He commanded her to take bath for every prayer. The narrator then transmitted the tradition (in full). Abu Dawud said: It has also been narrated by Abu al-Walid al-Tayalisi, but I did not hear him. He reported it from 'Aishah through a different chain of narrators. 'Aishah said: Zainab daughter of Jahsh had a prolonged flow of blood. The Prophet (ﷺ) said to her: Take bath for every prayer. The narrator then reported the tradition (in full). Abu Dawud said: The version transmitted by 'Abd al-Samad from Sulaiman b. Kathir has: "Perform ablution for every prayer." This is a misunderstanding on the part of 'Abd al-Samad. The correct version is the one narrated by Abu al-Walid}}
\hadithdefcmd{abudawud}{293}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ أَبِي الْحَجَّاجِ أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنِ الْحُسَيْنِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، قَالَ أَخْبَرَتْنِي زَيْنَبُ بِنْتُ أَبِي سَلَمَةَ، أَنَّ امْرَأَةً، كَانَتْ تُهَرَاقُ الدَّمَ - وَكَانَتْ تَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَهَا أَنْ تَغْتَسِلَ عِنْدَ كُلِّ صَلاَةٍ وَتُصَلِّيَ وَأَخْبَرَنِي أَنَّ أُمَّ بَكْرٍ أَخْبَرَتْهُ أَنَّ عَائِشَةَ قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي الْمَرْأَةِ تَرَى مَا يَرِيبُهَا بَعْدَ الطُّهْرِ ‏"‏ إِنَّمَا هِيَ - أَوْ قَالَ إِنَّمَا هُوَ - عِرْقٌ أَوْ قَالَ عُرُوقٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَفِي حَدِيثِ ابْنِ عَقِيلٍ الأَمْرَانِ جَمِيعًا وَقَالَ ‏"‏ إِنْ قَوِيتِ فَاغْتَسِلِي لِكُلِّ صَلاَةٍ وَإِلاَّ فَاجْمَعِي ‏"‏ ‏.‏ كَمَا قَالَ الْقَاسِمُ فِي حَدِيثِهِ وَقَدْ رُوِيَ هَذَا الْقَوْلُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنْ عَلِيٍّ وَابْنِ عَبَّاسٍ رضى الله عنهما ‏.‏\hadithno{293}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zaynab daughter of AbuSalamah: AbuSalamah said: Zaynab daughter of AbuSalamah reported to me that a woman had a copious flow of blood. She was the wife of AbdurRahman ibn Awf. The Messenger of Allah (ﷺ) commanded her to take a bath at the time of every prayer, and then to pray. He reported to me that Umm Bakr told him that Aisha said: The Messenger of Allah (ﷺ) said about a woman who was doubtful of her menstruation after purification that it was a vein or veins. Abu Dawud said: The two commands (of which the Prophet gave option) were as follows in the version reported by Ibn 'Aqil: He said: If you are strong enough, then take a bath for every prayer; otherwise combine the (two prayers), as al-Qasim reported in his version. This statement was also narrated by Sa'id b. Jubair from 'Ali and Ibn 'Abbas}}
\hadithdefcmd{abudawud}{294}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتِ اسْتُحِيضَتِ امْرَأَةٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأُمِرَتْ أَنْ تُعَجِّلَ الْعَصْرَ وَتُؤَخِّرَ الظُّهْرَ وَتَغْتَسِلَ لَهُمَا غُسْلاً ‏.‏ وَأَنْ تُؤَخِّرَ الْمَغْرِبَ وَتُعَجِّلَ الْعِشَاءَ وَتَغْتَسِلَ لَهُمَا غُسْلاً وَتَغْتَسِلَ لِصَلاَةِ الصُّبْحِ غُسْلاً ‏.‏ فَقُلْتُ لِعَبْدِ الرَّحْمَنِ أَعَنِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لاَ أُحَدِّثُكَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِشَىْءٍ ‏.‏\hadithno{294}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A woman had a prolonged flow of blood in the time of the Messenger of Allah (ﷺ). She was commanded to advance the afternoon prayer and delay the noon prayer, and to take a bath for them only once; and to delay the sunset prayer and advance the night prayer and to take a bath only once for them; and to take a bath separately for the dawn prayer. I (Shu'bah) asked AbdurRahman: (Is it) from the Prophet (ﷺ)? I do not report to you anything except from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{295}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى، حَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ سَهْلَةَ بِنْتَ سُهَيْلٍ، اسْتُحِيضَتْ فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهَا أَنْ تَغْتَسِلَ عِنْدَ كُلِّ صَلاَةٍ فَلَمَّا جَهَدَهَا ذَلِكَ أَمَرَهَا أَنْ تَجْمَعَ بَيْنَ الظُّهْرِ وَالْعَصْرِ بِغُسْلٍ وَالْمَغْرِبِ وَالْعِشَاءِ بِغُسْلٍ وَتَغْتَسِلَ لِلصُّبْحِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ ابْنُ عُيَيْنَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ عَنْ أَبِيهِ أَنَّ امْرَأَةً اسْتُحِيضَتْ فَسَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرَهَا بِمَعْنَاهُ ‏.‏\hadithno{295}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Sahlah daughter of Suhayl had a prolonged flow of blood. She came to the Prophet (ﷺ). He commanded her to take a bath for every prayer. When it became hard for her, he commanded her to combine the noon and afternoon prayers with one bath and the sunset and night prayer with one bath, and to take a bath (separately) for the dawn prayer. Abu Dawud said: Ibn 'Uyainah reported from 'Abd al-Rahman b. al-Qasim on the authority of his father, saying: A woman had a prolonged flow of blood. She asked the Prophet (ﷺ). He commanded her to the same effect}}
\hadithdefcmd{abudawud}{296}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ سُهَيْلٍ، - يَعْنِي ابْنَ أَبِي صَالِحٍ - عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ أَسْمَاءَ بِنْتِ عُمَيْسٍ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ اسْتُحِيضَتْ مُنْذُ كَذَا وَكَذَا فَلَمْ تُصَلِّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سُبْحَانَ اللَّهِ إِنَّ هَذَا مِنَ الشَّيْطَانِ لِتَجْلِسْ فِي مِرْكَنٍ فَإِذَا رَأَتْ صُفْرَةً فَوْقَ الْمَاءِ فَلْتَغْتَسِلْ لِلظُّهْرِ وَالْعَصْرِ غُسْلاً وَاحِدًا وَتَغْتَسِلْ لِلْمَغْرِبِ وَالْعِشَاءِ غُسْلاً وَاحِدًا وَتَغْتَسِلْ لِلْفَجْرِ غُسْلاً وَاحِدًا وَتَتَوَضَّأْ فِيمَا بَيْنَ ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ مُجَاهِدٌ عَنِ ابْنِ عَبَّاسٍ لَمَّا اشْتَدَّ عَلَيْهَا الْغُسْلُ أَمَرَهَا أَنْ تَجْمَعَ بَيْنَ الصَّلاَتَيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ إِبْرَاهِيمُ عَنِ ابْنِ عَبَّاسٍ وَهُوَ قَوْلُ إِبْرَاهِيمَ النَّخَعِيِّ وَعَبْدِ اللَّهِ بْنِ شَدَّادٍ ‏.‏\hadithno{296}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Asma' daughter of 'Unais said:I said: Messenger of Allah, Fatimah daughter of Abu Hubaish had a flow of blood for a certain period and did not pray. The Messenger of Allah (ﷺ) said: Glory be to Allah! This comes from the devil. She should sit in a tub, and when she sees yellowness of the top of the water, she would take a bath once for the Zuhr and 'Asr prayer, and take another bath for the Maghrib and 'Isha prayers, and take a bath once for the fajr prayer, and in between times she would perform ablution. Abu Dawud said: Mujahid reported on the authority of Ibn 'Abbas: When bathing became hard for her, he commanded her to combine the two prayers. Abu Dawud said: Ibrahim reported it from Ibn 'Abbas. This is also the view of Ibrahim al-Nakha'i and 'Abd Allah b. Shaddad}}
\hadithdefcmd{abudawud}{297}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ، قَالَ أَنْبَأَنَا ح، وَأَخْبَرَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي الْيَقْظَانِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْمُسْتَحَاضَةِ ‏"‏ تَدَعُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلُ وَتُصَلِّي وَالْوُضُوءُ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ زَادَ عُثْمَانُ ‏"‏ وَتَصُومُ وَتُصَلِّي ‏"‏ ‏.‏\hadithno{297}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Grandfather of Adi ibn Thabit ?: The Prophet (ﷺ) said about the woman having a prolonged flow of blood: She should abandon prayer during her menstrual period: then she should take a bath and pray. She should perform ablution for every prayer. Abu Dawud said: 'Uthman added: She should keep fast and pray}}
\hadithdefcmd{abudawud}{298}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ خَبَرَهَا وَقَالَ ‏ "‏ ثُمَّ اغْتَسِلِي ثُمَّ تَوَضَّئِي لِكُلِّ صَلاَةٍ وَصَلِّي ‏"‏ ‏.‏\hadithno{298}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Fatimah daughter of AbuHubaysh came to the Prophet (ﷺ) and narrated what happened with her. He said: Then take a bath and then perform ablution for every prayer and pray}}
\hadithdefcmd{abudawud}{299}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ الْقَطَّانُ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ، عَنْ أَيُّوبَ بْنِ أَبِي مِسْكِينٍ، عَنِ الْحَجَّاجِ، عَنْ أُمِّ كُلْثُومٍ، عَنْ عَائِشَةَ، فِي الْمُسْتَحَاضَةِ تَغْتَسِلُ - تَعْنِي مَرَّةً وَاحِدَةً - ثُمَّ تَوَضَّأُ إِلَى أَيَّامِ أَقْرَائِهَا ‏.‏\hadithno{299}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said about the woman who has a prolonged flow of blood:She should take bath, i.e. only once; then she should perform ablution until he next menstrual period}}
\hadithdefcmd{abudawud}{300}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ الْقَطَّانُ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ، عَنْ أَيُّوبَ أَبِي الْعَلاَءِ، عَنِ ابْنِ شُبْرُمَةَ، عَنِ امْرَأَةِ، مَسْرُوقٍ عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ عَدِيِّ بْنِ ثَابِتٍ وَالأَعْمَشِ عَنْ حَبِيبٍ وَأَيُّوبَ أَبِي الْعَلاَءِ كُلُّهَا ضَعِيفَةٌ لاَ تَصِحُّ وَدَلَّ عَلَى ضَعْفِ حَدِيثِ الأَعْمَشِ عَنْ حَبِيبٍ هَذَا الْحَدِيثُ أَوْقَفَهُ حَفْصُ بْنُ غِيَاثٍ عَنِ الأَعْمَشِ وَأَنْكَرَ حَفْصُ بْنُ غِيَاثٍ أَنْ يَكُونَ حَدِيثُ حَبِيبٍ مَرْفُوعًا وَأَوْقَفَهُ أَيْضًا أَسْبَاطٌ عَنِ الأَعْمَشِ مَوْقُوفٌ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ ابْنُ دَاوُدَ عَنِ الأَعْمَشِ مَرْفُوعًا أَوَّلُهُ وَأَنْكَرَ أَنْ يَكُونَ فِيهِ الْوُضُوءُ عِنْدَ كُلِّ صَلاَةٍ وَدَلَّ عَلَى ضَعْفِ حَدِيثِ حَبِيبٍ هَذَا أَنَّ رِوَايَةَ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ قَالَتْ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ ‏.‏ فِي حَدِيثِ الْمُسْتَحَاضَةِ وَرَوَى أَبُو الْيَقْظَانِ عَنْ عَدِيِّ بْنِ ثَابِتٍ عَنْ أَبِيهِ عَنْ عَلِيٍّ - رَضِيَ اللَّهُ عَنْهُ - وَعَمَّارٌ مَوْلَى بَنِي هَاشِمٍ عَنِ ابْنِ عَبَّاسٍ وَرَوَى عَبْدُ الْمَلِكِ بْنُ مَيْسَرَةَ وَبَيَانٌ وَالْمُغِيرَةُ وَفِرَاسٌ وَمُجَالِدٌ عَنِ الشَّعْبِيِّ عَنْ حَدِيثِ قَمِيرَ عَنْ عَائِشَةَ ‏"‏ تَوَضَّئِي لِكُلِّ صَلاَةٍ ‏"‏ ‏.‏ وَرِوَايَةُ دَاوُدَ وَعَاصِمٍ عَنِ الشَّعْبِيِّ عَنْ قَمِيرَ عَنْ عَائِشَةَ ‏"‏ تَغْتَسِلُ كُلَّ يَوْمٍ مَرَّةً ‏"‏ ‏.‏ وَرَوَى هِشَامُ بْنُ عُرْوَةَ عَنْ أَبِيهِ الْمُسْتَحَاضَةُ تَتَوَضَّأُ لِكُلِّ صَلاَةٍ ‏.‏ وَهَذِهِ الأَحَادِيثُ كُلُّهَا ضَعِيفَةٌ إِلاَّ حَدِيثَ قَمِيرَ وَحَدِيثَ عَمَّارٍ مَوْلَى بَنِي هَاشِمٍ وَحَدِيثَ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ وَالْمَعْرُوفُ عَنِ ابْنِ عَبَّاسٍ الْغُسْلُ ‏.‏\hadithno{300}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{This tradition has also been narrated by 'Aishah through a different chain of transmitters. Abu Dawud said:All the traditions (on this subject) transmitted by 'Adi b. Thabit and A'mash on the authority of Habib and Ayyub al-'Ala, all of them are weak; none of them is sound. This tradition indicates	the tradition reported by al-A'mash a a statement of Companion, i.e. 'Aishah. Hafs b. Ghayath has rejected the tradition transmitted by Habib as the statement (of the Prophet). And Asbat also reported it as a statement of 'Aishah. Abu Dawud said: Ibn Dawud has narrated the first part of this tradition as a statement (of the Prophet), and denied that there was any mention of performing ablution for every prayer. The weakness of the tradition reported by Habib is also indicated by the fact that the version transmuted by al-Zuhri from 'Urwah on the authority of 'Aishah says that she used to wash herself for every prayer; (these words occur) in the tradition about the woman who has a flow of blood. This tradition has been reported by Abu al-Yaqzan from 'Adi b. Thabit from his father from 'Ali, and narrated by 'Ammar, the freed salve of Banu Hashim, from Ibn 'Abbas, and transmitted by 'Abd al-Malik b. Maisarah, Bayan, al-Mughirah, Firas, on the authority of al-Sha'bi, from Qumair from 'Aishah, stating: You should perform ablution for every prayer. The version transmitted by Dawud, and 'Asim from al-Sha'bi from Qumair from 'Aishah has the words: She should take bath only once every day. The version reported by Hisham b. 'Urwah from his father has the words: The woman having a flow of blood should perform ablution for every prayer. All these traditions are weak except the tradition reported by Qumair and the tradition reported by 'Ammar, the freed slave of Banu Hashim, and the tradition narrated by Hisham b. 'Urwah on the authority of his father. What is commonly known from Ibn 'Abbas is bathing (for every prayer)}}
\hadithdefcmd{abudawud}{301}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ أَنَّ الْقَعْقَاعَ، وَزَيْدَ بْنَ أَسْلَمَ، أَرْسَلاَهُ إِلَى سَعِيدِ بْنِ الْمُسَيَّبِ يَسْأَلُهُ كَيْفَ تَغْتَسِلُ الْمُسْتَحَاضَةُ فَقَالَ تَغْتَسِلُ مِنْ ظُهْرٍ إِلَى ظُهْرٍ وَتَتَوَضَّأُ لِكُلِّ صَلاَةٍ فَإِنْ غَلَبَهَا الدَّمُ اسْتَثْفَرَتْ بِثَوْبٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُوِيَ عَنِ ابْنِ عُمَرَ وَأَنَسِ بْنِ مَالِكٍ تَغْتَسِلُ مِنْ ظُهْرٍ إِلَى ظُهْرٍ ‏.‏ وَكَذَلِكَ رَوَى دَاوُدُ وَعَاصِمٌ عَنِ الشَّعْبِيِّ عَنِ امْرَأَتِهِ عَنْ قَمِيرَ عَنْ عَائِشَةَ إِلاَّ أَنَّ دَاوُدَ قَالَ كُلَّ يَوْمٍ ‏.‏ وَفِي حَدِيثِ عَاصِمٍ عِنْدَ الظُّهْرِ ‏.‏ وَهُوَ قَوْلُ سَالِمِ بْنِ عَبْدِ اللَّهِ وَالْحَسَنِ وَعَطَاءٍ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مَالِكٌ إِنِّي لأَظُنُّ حَدِيثَ ابْنِ الْمُسَيَّبِ مِنْ طُهْرٍ إِلَى طُهْرٍ ‏.‏ فَقَلَبَهَا النَّاسُ مِنْ ظُهْرٍ إِلَى ظُهْرٍ وَلَكِنَّ الْوَهَمَ دَخَلَ فِيهِ وَرَوَاهُ الْمِسْوَرُ بْنُ عَبْدِ الْمَلِكِ بْنِ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَرْبُوعٍ قَالَ فِيهِ مِنْ طُهْرٍ إِلَى طُهْرٍ ‏.‏ فَقَلَبَهَا النَّاسُ مِنْ ظُهْرٍ إِلَى ظُهْرٍ ‏.‏\hadithno{301}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sumayy, the freed slave of Abu Bakr, says that al-Qa'qa and Zaid b. Aslam sent him to Sa'id b. al-Musayyab to ask him as to how the woman who has flow of blood should wash. He replied:She should wash at the time of the Zuhr prayer (the bath will be valid one Zuhr prayer to the next Zuhr prayer); and should perform ablution for every prayer. If there is excessive bleed gin, she should tie a cloth over her private part. Abu Dawud said: It has been narrated by Ibn 'Umar and Anas b. Malik that she should take bath at the time of the Zuhr prayer (being valid) until the next Zuhr prayer. This tradition has also been transmuted by Dawud and 'Asim from al-Sha'bi from his wife from Qumair on the authority of 'Aishah, except that the version of Dawud has the words: "every day," and the version of 'Asim has the words: "at the time of Zuhr prayer". This is the view of Salim b. 'Abd Allah, al-Hassan, and 'Ata. Abu Dawud said: Malik said: I think that the tradition narrated by Ibn a;-Musayyab must contain the words: "from one purification to another". But it was misunderstood and the people changed it to: "for one Zuhr prayer to another". It has also been reported by Miswar b. 'Abd al-Malik b. Sa'id b. 'Abd al-Rahman b. Yarbu', saying: "from one purification to another," but the people changed it to: "from one zuhr to another}}
\hadithdefcmd{abudawud}{302}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ أَبِي إِسْمَاعِيلَ، - وَهُوَ مُحَمَّدُ بْنُ رَاشِدٍ - عَنْ مَعْقِلٍ الْخَثْعَمِيِّ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ الْمُسْتَحَاضَةُ إِذَا انْقَضَى حَيْضُهَا اغْتَسَلَتْ كُلَّ يَوْمٍ وَاتَّخَذَتْ صُوفَةً فِيهَا سَمْنٌ أَوْ زَيْتٌ ‏.‏\hadithno{302}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The woman who has a prolonged flow of blood should wash herself every day when her menstrual period is over and take a woollen cloth greased with fat or oil (to tie over the private parts)}}
\hadithdefcmd{abudawud}{303}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ مُحَمَّدِ بْنِ عُثْمَانَ، أَنَّهُ سَأَلَ الْقَاسِمَ بْنَ مُحَمَّدٍ عَنِ الْمُسْتَحَاضَةِ، فَقَالَ تَدَعُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلُ فَتُصَلِّي ثُمَّ تَغْتَسِلُ فِي الأَيَّامِ ‏.‏\hadithno{303}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad b. 'Uthman asked al-Qasim b. Muhammad about the woman who has a prolonged flow of blood. He replied:She should abandon prayer during her menstrual period, then wash and pray ; then she should wash during her menstrual period}}
\hadithdefcmd{abudawud}{304}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ عَمْرٍو - حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ فَاطِمَةَ بِنْتِ أَبِي حُبَيْشٍ، أَنَّهَا كَانَتْ تُسْتَحَاضُ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ دَمُ الْحَيْضِ فَإِنَّهُ دَمٌ أَسْوَدُ يُعْرَفُ فَإِذَا كَانَ ذَلِكَ فَأَمْسِكِي عَنِ الصَّلاَةِ فَإِذَا كَانَ الآخَرُ فَتَوَضَّئِي وَصَلِّي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ ابْنُ الْمُثَنَّى وَحَدَّثَنَا بِهِ ابْنُ أَبِي عَدِيٍّ حِفْظًا فَقَالَ عَنْ عُرْوَةَ عَنْ عَائِشَةَ أَنَّ فَاطِمَةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُوِيَ عَنِ الْعَلاَءِ بْنِ الْمُسَيَّبِ وَشُعْبَةَ عَنِ الْحَكَمِ عَنْ أَبِي جَعْفَرٍ قَالَ الْعَلاَءُ عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَوْقَفَهُ شُعْبَةُ عَلَى أَبِي جَعْفَرٍ تَوَضَّأُ لِكُلِّ صَلاَةٍ ‏.‏\hadithno{304}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Urwah b. al-Zubair said the Fatimah daughter of Abu Hubaish had a prolonged flow of blood. The Prophet (ﷺ) said to her:When the blood of menses comes, it is black blood with can be recognized; so when that comes, refrain from prayer, but when a different type comes, perform ablution and pray. Abu Dawud said: Ibn al-Muthanna said: Ibn 'Adi narrated this tradition from his memory on the authority of 'Urwah from 'Aishah. Abu Dawud said: This tradition has also been transmitted by al-'Ala b. al-Musayyab and Shu'bah from al-Hakam on the authority of Abu Ja'far. Al-'Ala reported it as a statement of the Prophet (ﷺ), and Shu'bah as a statement of Abu Ja'far, saying: She should perform ablution for every prayer}}
\hadithdefcmd{abudawud}{305}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ عِكْرِمَةَ، أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ، اسْتُحِيضَتْ فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم أَنْ تَنْتَظِرَ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلُ وَتُصَلِّي فَإِنْ رَأَتْ شَيْئًا مِنْ ذَلِكَ تَوَضَّأَتْ وَصَلَّتْ ‏.‏\hadithno{305}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Habibah daughter of Jahsh: Ikrimah said: Umm Habibah daughter of Jahsh had a prolonged flow of blood. The Prophet (ﷺ) commanded her to refrain (from prayer) during her menstrual period; then she should wash and pray, if she sees anything (which renders ablution void) she should perform ablution and pray}}
\hadithdefcmd{abudawud}{306}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ رَبِيعَةَ، أَنَّهُ كَانَ لاَ يَرَى عَلَى الْمُسْتَحَاضَةِ وُضُوءًا عِنْدَ كُلِّ صَلاَةٍ إِلاَّ أَنْ يُصِيبَهَا حَدَثٌ غَيْرُ الدَّمِ فَتَوَضَّأُ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا قَوْلُ مَالِكٍ يَعْنِي ابْنَ أَنَسٍ ‏.‏\hadithno{306}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Rabi'ah said:Umm Habibah daughter of Jahsh had a prolonged flow of blood. The Prophet (ﷺ) commander her to refrain (from prayer) during her menstrual period; then she should wash and pray. If she sees anything (which renders ablution void) she should perform ablution and pray. Abu Dawud said: This is the view held by Malik b. Anas}}
\hadithdefcmd{abudawud}{307}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، أَخْبَرَنَا حَمَّادٌ، عَنْ قَتَادَةَ، عَنْ أُمِّ الْهُذَيْلِ، عَنْ أُمِّ عَطِيَّةَ، وَكَانَتْ، بَايَعَتِ النَّبِيَّ صلى الله عليه وسلم قَالَتْ كُنَّا لاَ نَعُدُّ الْكُدْرَةَ وَالصُّفْرَةَ بَعْدَ الطُّهْرِ شَيْئًا ‏.‏\hadithno{307}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm 'Atiyyah who took an oath of allegiance to the Prophet (ﷺ) said:We would not take into consideration brown and yellow (fluid) after purification}}
\hadithdefcmd{abudawud}{308}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا أَيُّوبُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، بِمِثْلِهِ ‏.‏ قَالَ أَبُو دَاوُدَ أُمُّ الْهُذَيْلِ هِيَ حَفْصَةُ بِنْتُ سِيرِينَ كَانَ ابْنُهَا اسْمُهُ هُذَيْلٌ وَاسْمُ زَوْجِهَا عَبْدُ الرَّحْمَنِ ‏.‏\hadithno{308}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (326)}\hadithtrans{Umm 'Atiyyah has narrated this tradition through a different chain of transmitters. Abu DAwud said:The name of Umm al-Hudhail is Hafsah daughter os Sirin. The name of her son was Hudhail and his husband 'Abd al-Rahman}}
\hadithdefcmd{abudawud}{309}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، عَنْ عَلِيِّ بْنِ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، عَنْ عِكْرِمَةَ، قَالَ كَانَتْ أُمُّ حَبِيبَةَ تُسْتَحَاضُ فَكَانَ زَوْجُهَا يَغْشَاهَا ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ يَحْيَى بْنُ مَعِينٍ مُعَلَّى ثِقَةٌ ‏.‏ وَكَانَ أَحْمَدُ بْنُ حَنْبَلٍ لاَ يَرْوِي عَنْهُ لأَنَّهُ كَانَ يَنْظُرُ فِي الرَّأْىِ ‏.‏\hadithno{309}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ikrimah said:Umm Habibah had a prolonged flow of blood ; her husband used to cohabit with her. Abu Dawud said: Yahya b. Ma'in has pronounced Mu'alla (a narrator of this tradition) as trustworthy. But Ahmad b. Hanbal would not report (traditions) from him because he exercised personal opinion}}
\hadithdefcmd{abudawud}{310}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي سُرَيْجٍ الرَّازِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْجَهْمِ، حَدَّثَنَا عَمْرُو بْنُ أَبِي قَيْسٍ، عَنْ عَاصِمٍ، عَنْ عِكْرِمَةَ، عَنْ حَمْنَةَ بِنْتِ جَحْشٍ، أَنَّهَا كَانَتْ مُسْتَحَاضَةً وَكَانَ زَوْجُهَا يُجَامِعُهَا ‏.‏\hadithno{310}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ikrimah reported Hamnah daughter of Jahsh as saying that her husband would have intercourse with her during the period she had a flow of blood}}
\hadithdefcmd{abudawud}{311}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، أَخْبَرَنَا زُهَيْرٌ، حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ الأَعْلَى، عَنْ أَبِي سَهْلٍ، عَنْ مُسَّةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَتِ النُّفَسَاءُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم تَقْعُدُ بَعْدَ نِفَاسِهَا أَرْبَعِينَ يَوْمًا أَوْ أَرْبَعِينَ لَيْلَةً وَكُنَّا نَطْلِي عَلَى وُجُوهِنَا الْوَرْسَ يَعْنِي مِنَ الْكَلَفِ ‏.‏\hadithno{311}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The woman having bleeding after delivery (puerperal haemorrhage) would refrain (from prayer) for forty days or forty nights; and we would anoint our faces with an aromatic herb called wars to remove dark spots}}
\hadithdefcmd{abudawud}{312}{حَدَّثَنَا الْحَسَنُ بْنُ يَحْيَى، أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، - يَعْنِي حِبِّي - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ نَافِعٍ، عَنْ كَثِيرِ بْنِ زِيَادٍ، قَالَ حَدَّثَتْنِي الأَزْدِيَّةُ، - يَعْنِي مُسَّةَ - قَالَتْ حَجَجْتُ فَدَخَلْتُ عَلَى أُمِّ سَلَمَةَ فَقُلْتُ يَا أُمَّ الْمُؤْمِنِينَ إِنَّ سَمُرَةَ بْنَ جُنْدُبٍ يَأْمُرُ النِّسَاءَ يَقْضِينَ صَلاَةَ الْمَحِيضِ ‏.‏ فَقَالَتْ لاَ يَقْضِينَ كَانَتِ الْمَرْأَةُ مِنْ نِسَاءِ النَّبِيِّ صلى الله عليه وسلم تَقْعُدُ فِي النِّفَاسِ أَرْبَعِينَ لَيْلَةً لاَ يَأْمُرُهَا النَّبِيُّ صلى الله عليه وسلم بِقَضَاءِ صَلاَةِ النِّفَاسِ ‏.‏ قَالَ مُحَمَّدٌ يَعْنِي ابْنَ حَاتِمٍ وَاسْمُهَا مُسَّةُ تُكْنَى أُمَّ بُسَّةَ ‏.‏ قَالَ أَبُو دَاوُدَ كَثِيرُ بْنُ زِيَادٍ كُنْيَتُهُ أَبُو سَهْلٍ ‏.‏\hadithno{312}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi}\hadithtrans{Al-Azdiyyah, viz. Mussah, said:I performed Hajj and came to Umm Salamah and said (to her): Mother of the believers, Samurah b. Jundub commands women to complete the prayers abandoned during their menstrual period. She said: They should not do so. The wives of the Prophet (ﷺ) would refrain (from prayer) for forty nights (i.e. days) during the course of bleeding after child birth. The Prophet (ﷺ) would not command them to complete the prayers abandoned during the period of bleeding. Muhammad b. Hatim said: The name of Al-Azdiyyah is Mussah and her patronymic name is Umm Busrah. Abu Dawud said: The patronymic names of Kathir b. Ziyad s Abu Sahl}}
\hadithdefcmd{abudawud}{313}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ الْفَضْلِ - أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ إِسْحَاقَ - عَنْ سُلَيْمَانَ بْنِ سُحَيْمٍ، عَنْ أُمَيَّةَ بِنْتِ أَبِي الصَّلْتِ، عَنِ امْرَأَةٍ، مِنْ بَنِي غِفَارٍ قَدْ سَمَّاهَا لِي قَالَتْ أَرْدَفَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى حَقِيبَةِ رَحْلِهِ - قَالَتْ - فَوَاللَّهِ لَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الصُّبْحِ فَأَنَاخَ وَنَزَلْتُ عَنْ حَقِيبَةِ رَحْلِهِ فَإِذَا بِهَا دَمٌ مِنِّي فَكَانَتْ أَوَّلَ حَيْضَةٍ حِضْتُهَا - قَالَتْ - فَتَقَبَّضْتُ إِلَى النَّاقَةِ وَاسْتَحْيَيْتُ فَلَمَّا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَا بِي وَرَأَى الدَّمَ قَالَ ‏"‏ مَا لَكِ لَعَلَّكِ نُفِسْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَأَصْلِحِي مِنْ نَفْسِكِ ثُمَّ خُذِي إِنَاءً مِنْ مَاءٍ فَاطْرَحِي فِيهِ مِلْحًا ثُمَّ اغْسِلِي مَا أَصَابَ الْحَقِيبَةَ مِنَ الدَّمِ ثُمَّ عُودِي لِمَرْكَبِكِ ‏"‏ ‏.‏ قَالَتْ فَلَمَّا فَتَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ رَضَخَ لَنَا مِنَ الْفَىْءِ - قَالَتْ - وَكَانَتْ لاَ تَطَّهَّرُ مِنْ حَيْضَةٍ إِلاَّ جَعَلَتْ فِي طَهُورِهَا مِلْحًا وَأَوْصَتْ بِهِ أَنْ يُجْعَلَ فِي غُسْلِهَا حِينَ مَاتَتْ ‏.‏\hadithno{313}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Woman of Banu Ghifar: Umayyah, daughter of AbusSalt, quoted a certain woman of Banu Ghifar, whose name was mentioned to me, as saying: The Messenger of Allah (ﷺ) made me ride behind him on the rear of the camel saddle. By Allah, the Messenger of Allah (ﷺ) got down in the morning. He made his camel kneel down and I came down from the back of his saddle. There was a mark of blood on it (saddle) and that was the first menstruation that I had. I stuck to the camel and felt ashamed. When the Messenger of Allah (ﷺ) saw what had happened to me and saw the blood, he said: Perhaps you are menstruating. I said: Yes. He then said: Set yourself right (i.e. tie some cloth to prevent bleeding), then take a vessel of water and put some salt in it, and then wash the blood from the back of the saddle, and then return to your mount. When the Messenger of Allah (ﷺ) conquered Khaybar, he gave us a portion of the booty. Whenever the woman became purified from her menses, she would put salt in water. And when she died, she left a will to put salt in the water for washing her (after death)}}
\hadithdefcmd{abudawud}{314}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، أَخْبَرَنَا سَلاَّمُ بْنُ سُلَيْمٍ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَتْ أَسْمَاءُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ كَيْفَ تَغْتَسِلُ إِحْدَانَا إِذَا طَهُرَتْ مِنَ الْمَحِيضِ قَالَ ‏ "‏ تَأْخُذُ سِدْرَهَا وَمَاءَهَا فَتَوَضَّأُ ثُمَّ تَغْسِلُ رَأْسَهَا وَتَدْلُكُهُ حَتَّى يَبْلُغَ الْمَاءُ أُصُولَ شَعْرِهَا ثُمَّ تُفِيضُ عَلَى جَسَدِهَا ثُمَّ تَأْخُذُ فِرْصَتَهَا فَتَطَّهَّرُ بِهَا ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ كَيْفَ أَتَطَهَّرُ بِهَا قَالَتْ عَائِشَةُ فَعَرَفْتُ الَّذِي يَكْنِي عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهَا تَتَّبِعِينَ بِهَا آثَارَ الدَّمِ ‏.‏\hadithno{314}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim (332)}\hadithtrans{Aishah reported:Asma' entered upon the Messenger of Allah (ﷺ) and said: Messenger of Allah, how should one of us take bath when she is purified from her menses ? He said: She should take water mixed with the leaves of lote-tree; then should perform ablution and wash her head and rub it so much so that water reaches the roots of the hair; she should then our water upon her body. Then she should take a piece of cloth (or cotton or wool) and purify with it. She asked: Messenger of Allah, how should I purify with it ? 'Aishah said: I understood what he (the Prophet) said metaphorically. I, therefore, said to her: Remove the marks of blood}}
\hadithdefcmd{abudawud}{315}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، أَنَّهَا ذَكَرَتْ نِسَاءَ الأَنْصَارِ فَأَثْنَتْ عَلَيْهِنَّ وَقَالَتْ لَهُنَّ مَعْرُوفًا وَقَالَتْ دَخَلَتِ امْرَأَةٌ مِنْهُنَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مَعْنَاهُ إِلاَّ أَنَّهُ قَالَ ‏ "‏ فِرْصَةً مُمَسَّكَةً ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ كَانَ أَبُو عَوَانَةَ يَقُولُ فِرْصَةً وَكَانَ أَبُو الأَحْوَصِ يَقُولُ قَرْصَةً ‏.‏\hadithno{315}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah made a mention of the women of the Ansar and admired them stating that they had obliged (all Muslims). She then said:One of their women came upon the Messenger of Allah (ﷺ). She then reported the rest of the tradition to the same effect; but this version she said the words: "a musk-scented piece of cloth." Musaddad said: Abu 'Awanah used the word firsah (i.e. a piece of cloth), but Abu Al-Ahwas used the word qasrah (i.e. a small piece of cloth)}}
\hadithdefcmd{abudawud}{316}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ إِبْرَاهِيمَ، - يَعْنِي ابْنَ مُهَاجِرٍ - عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، أَنَّ أَسْمَاءَ، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ ‏"‏ فِرْصَةً مُمَسَّكَةً ‏"‏ ‏.‏ قَالَتْ كَيْفَ أَتَطَهَّرُ بِهَا قَالَ ‏"‏ سُبْحَانَ اللَّهِ تَطَهَّرِي بِهَا وَاسْتَتِرِي بِثَوْبٍ ‏"‏ ‏.‏ وَزَادَ وَسَأَلَتْهُ عَنِ الْغُسْلِ مِنَ الْجَنَابَةِ فَقَالَ ‏"‏ تَأْخُذِينَ مَاءَكِ فَتَطَهَّرِينَ أَحْسَنَ الطُّهُورِ وَأَبْلَغَهُ ثُمَّ تَصُبِّينَ عَلَى رَأْسِكِ الْمَاءَ ثُمَّ تَدْلُكِينَهُ حَتَّى يَبْلُغَ شُئُونَ رَأْسِكِ ثُمَّ تُفِيضِينَ عَلَيْكِ الْمَاءَ ‏"‏ ‏.‏ قَالَ وَقَالَتْ عَائِشَةُ نِعْمَ النِّسَاءُ نِسَاءُ الأَنْصَارِ لَمْ يَكُنْ يَمْنَعُهُنَّ الْحَيَاءُ أَنْ يَسْأَلْنَ عَنِ الدِّينِ وَيَتَفَقَّهْنَ فِيهِ ‏.‏\hadithno{316}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said:Asma' asked the Prophet (ﷺ) and then narrated the rest of the tradition to the same effect. He (the Prophet) said: "a musk-scented piece of cloth." She (Asma') said: How should I purify with it ? He said: By glory of Allah ! Purify with it, and he covered his face with the cloth. This version also adds: "She asked about the washing because of sexual defilement." He said: Take your water and purify yourself as best as possible. Then pour water over yourself. 'Aishah said: The best of the women are the women of the Ansar. Shyness would not prevent them from inquiring about religion and from acquiring deep understanding in it}}
\hadithdefcmd{abudawud}{317}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، أَخْبَرَنَا عَبْدَةُ، - الْمَعْنَى وَاحِدٌ - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم أُسَيْدَ بْنَ حُضَيْرٍ وَأُنَاسًا مَعَهُ فِي طَلَبِ قِلاَدَةٍ أَضَلَّتْهَا عَائِشَةُ فَحَضَرَتِ الصَّلاَةُ فَصَلَّوْا بِغَيْرِ وُضُوءٍ فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَذَكَرُوا ذَلِكَ لَهُ فَأُنْزِلَتْ آيَةُ التَّيَمُّمِ زَادَ ابْنُ نُفَيْلٍ فَقَالَ لَهَا أُسَيْدُ بْنُ حُضَيْرٍ يَرْحَمُكِ اللَّهُ مَا نَزَلَ بِكِ أَمْرٌ تَكْرَهِينَهُ إِلاَّ جَعَلَ اللَّهُ لِلْمُسْلِمِينَ وَلَكِ فِيهِ فَرَجًا ‏.‏\hadithno{317}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (336) Sahih Muslim (367)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) sent Usayd ibn Hudayr and some people with him to search the necklace lost by Aisha. The time of prayer came and they prayed without ablution. When they returned to the Prophet (ﷺ) and related the fact to him, the verse concerning tayammum was revealed. Ibn Nufayl added: Usayd said to her: May Allah have mercy upon you! Never has there been an occasion when you were beset with an unpleasant matter but Allah made the Muslims and you come out of that}}
\hadithdefcmd{abudawud}{318}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، حَدَّثَهُ عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّهُ كَانَ يُحَدِّثُ أَنَّهُمْ تَمَسَّحُوا وَهُمْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالصَّعِيدِ لِصَلاَةِ الْفَجْرِ فَضَرَبُوا بِأَكُفِّهِمُ الصَّعِيدَ ثُمَّ مَسَحُوا وُجُوهَهُمْ مَسْحَةً وَاحِدَةً ثُمَّ عَادُوا فَضَرَبُوا بِأَكُفِّهِمُ الصَّعِيدَ مَرَّةً أُخْرَى فَمَسَحُوا بِأَيْدِيهِمْ كُلِّهَا إِلَى الْمَنَاكِبِ وَالآبَاطِ مِنْ بُطُونِ أَيْدِيهِمْ ‏.‏\hadithno{318}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ammar ibn Yasir: They (the Companions of the Prophet) wiped with pure earth (their hands and face) to offer the dawn prayer in the company of the Messenger of Allah (ﷺ). They struck the ground with their palms and wiped their faces once. Then they repeated and struck the ground with their palms once again and wiped their arms completely up to the shoulders and up to the armpits with the inner side of their hands}}
\hadithdefcmd{abudawud}{319}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، وَعَبْدُ الْمَلِكِ بْنُ شُعَيْبٍ، عَنِ ابْنِ وَهْبٍ، نَحْوَ هَذَا الْحَدِيثِ قَالَ قَامَ الْمُسْلِمُونَ فَضَرَبُوا بِأَكُفِّهِمُ التُّرَابَ وَلَمْ يَقْبِضُوا مِنَ التُّرَابِ شَيْئًا فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرِ الْمَنَاكِبَ وَالآبَاطَ ‏.‏ قَالَ ابْنُ اللَّيْثِ إِلَى مَا فَوْقَ الْمِرْفَقَيْنِ ‏.‏\hadithno{319}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition has also been reported through a different chain of narrators. This version has:The Muslims stood up and struck the earth with their palms, but did not get any earth (in their hands). He (Ibn Wahb) then narrated the rest of the tradition in like manner, but he did not mention the words "shoulders" and "armpits". Ibn al-Laith said: (They) wiped above the elbows}}
\hadithdefcmd{abudawud}{320}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، وَمُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا يَعْقُوبُ، أَخْبَرَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَرَّسَ بِأُولاَتِ الْجَيْشِ وَمَعَهُ عَائِشَةُ فَانْقَطَعَ عِقْدٌ لَهَا مِنْ جَزْعِ ظَفَارِ فَحَبَسَ النَّاسَ ابْتِغَاءُ عِقْدِهَا ذَلِكَ حَتَّى أَضَاءَ الْفَجْرُ وَلَيْسَ مَعَ النَّاسِ مَاءٌ فَتَغَيَّظَ عَلَيْهَا أَبُو بَكْرٍ وَقَالَ حَبَسْتِ النَّاسَ وَلَيْسَ مَعَهُمْ مَاءٌ فَأَنْزَلَ اللَّهُ تَعَالَى عَلَى رَسُولِهِ صلى الله عليه وسلم رُخْصَةَ التَّطَهُّرِ بِالصَّعِيدِ الطَّيِّبِ فَقَامَ الْمُسْلِمُونَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَضَرَبُوا بِأَيْدِيهِمْ إِلَى الأَرْضِ ثُمَّ رَفَعُوا أَيْدِيَهُمْ وَلَمْ يَقْبِضُوا مِنَ التُّرَابِ شَيْئًا فَمَسَحُوا بِهَا وُجُوهَهُمْ وَأَيْدِيَهُمْ إِلَى الْمَنَاكِبِ وَمِنْ بُطُونِ أَيْدِيهِمْ إِلَى الآبَاطِ ‏.‏ زَادَ ابْنُ يَحْيَى فِي حَدِيثِهِ قَالَ ابْنُ شِهَابٍ فِي حَدِيثِهِ وَلاَ يَعْتَبِرُ بِهَذَا النَّاسُ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ ابْنُ إِسْحَاقَ قَالَ فِيهِ عَنِ ابْنِ عَبَّاسٍ وَذَكَرَ ضَرْبَتَيْنِ كَمَا ذَكَرَ يُونُسُ وَرَوَاهُ مَعْمَرٌ عَنِ الزُّهْرِيِّ ضَرْبَتَيْنِ وَقَالَ مَالِكٌ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِيهِ عَنْ عَمَّارٍ وَكَذَلِكَ قَالَ أَبُو أُوَيْسٍ عَنِ الزُّهْرِيِّ وَشَكَّ فِيهِ ابْنُ عُيَيْنَةَ قَالَ مَرَّةً عَنْ عُبَيْدِ اللَّهِ عَنْ أَبِيهِ أَوْ عَنْ عُبَيْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ وَمَرَّةً قَالَ عَنْ أَبِيهِ وَمَرَّةً قَالَ عَنِ ابْنِ عَبَّاسٍ اضْطَرَبَ ابْنُ عُيَيْنَةَ فِيهِ وَفِي سَمَاعِهِ مِنَ الزُّهْرِيِّ وَلَمْ يَذْكُرْ أَحَدٌ مِنْهُمْ فِي هَذَا الْحَدِيثِ الضَّرْبَتَيْنِ إِلاَّ مَنْ سَمَّيْتُ ‏.‏\hadithno{320}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ammar ibn Yasir: The Messenger of Allah (ﷺ) encamped at Ulat al-Jaysh and Aisha was in his company. Her necklace of onyx of Zifar was broken (and fell somewhere). The people were detained to make a search for that necklace until the dawn broke. There was no water with the people. Therefore AbuBakr became angry with her and said: You detained the people and they have no water with them. Thereupon Allah, the Exalted, sent down revelation about it to His Apostle (ﷺ) granting concession to purify themselves with pure earth. Then the Muslims stood up with the Messenger of Allah (ﷺ) and struck the ground with their hands and then they raised their hands, and did not take any earth (in their hands). Then they wiped with them their faces and hands up to the shoulders, and from their palms up to the armpits. Ibn Yahya added in his version: Ibn Shihab said in his tradition: The people do not take this (tradition) into account. Abu Dawud said: Ibn Ishaq also reported it in a similar way. In this (version) he said on the authority of Ibn 'Abbas. He mentioned the words "two strikes" (i.e. striking the earth twice) as mentioned by Yunus. And Ma'mar also narrated on the authority of al-Zuhri "two strikes". And Malik said: From al-Zuhri from 'Ubaid Allah b. 'Abd Allah from his father on the authority of 'Ammar. Abu Uwais also reported it in a similar way on the authority of al-Zuhri. But Ibn 'Uyainah doubted it, he sometimes said: from his father, and sometimes he said: from Ibn 'Abbas. Ibn 'Uyainah was confused in it and in his hearing from al-Zuhri. No one has mentioned "two strikes" in this tradition except those whose names I have mentioned}}
\hadithdefcmd{abudawud}{321}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ الضَّرِيرُ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ كُنْتُ جَالِسًا بَيْنَ عَبْدِ اللَّهِ وَأَبِي مُوسَى فَقَالَ أَبُو مُوسَى يَا أَبَا عَبْدِ الرَّحْمَنِ أَرَأَيْتَ لَوْ أَنَّ رَجُلاً أَجْنَبَ فَلَمْ يَجِدِ الْمَاءَ شَهْرًا ‏.‏ أَمَا كَانَ يَتَيَمَّمُ فَقَالَ لاَ وَإِنْ لَمْ يَجِدِ الْمَاءَ شَهْرًا فَقَالَ أَبُو مُوسَى فَكَيْفَ تَصْنَعُونَ بِهَذِهِ الآيَةِ الَّتِي فِي سُورَةِ الْمَائِدَةِ ‏\{‏ فَلَمْ تَجِدُوا مَاءً فَتَيَمَّمُوا صَعِيدًا طَيِّبًا ‏\}‏ فَقَالَ عَبْدُ اللَّهِ لَوْ رُخِّصَ لَهُمْ فِي هَذَا لأَوْشَكُوا إِذَا بَرَدَ عَلَيْهِمُ الْمَاءُ أَنْ يَتَيَمَّمُوا بِالصَّعِيدِ ‏.‏ فَقَالَ لَهُ أَبُو مُوسَى وَإِنَّمَا كَرِهْتُمْ هَذَا لِهَذَا قَالَ نَعَمْ فَقَالَ لَهُ أَبُو مُوسَى أَلَمْ تَسْمَعْ قَوْلَ عَمَّارٍ لِعُمَرَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَاجَةٍ فَأَجْنَبْتُ فَلَمْ أَجِدِ الْمَاءَ فَتَمَرَّغْتُ فِي الصَّعِيدِ كَمَا تَتَمَرَّغُ الدَّابَّةُ ثُمَّ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏"‏ إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَصْنَعَ هَكَذَا ‏"‏ ‏.‏ فَضَرَبَ بِيَدِهِ عَلَى الأَرْضِ فَنَفَضَهَا ثُمَّ ضَرَبَ بِشِمَالِهِ عَلَى يَمِينِهِ وَبِيَمِينِهِ عَلَى شِمَالِهِ عَلَى الْكَفَّيْنِ ثُمَّ مَسَحَ وَجْهَهُ ‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ أَفَلَمْ تَرَ عُمَرَ لَمْ يَقْنَعْ بِقَوْلِ عَمَّارٍ\hadithno{321}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (345، 346) Sahih Muslim (368)}\hadithtrans{Shaqiq said:While I was sitting between 'Abd Allah and Abu Musa, the latter said: Abu 'Abd al-Rahman, what do you think if a man becomes defiled (because of seminal omission) and does not find water for a month; should he not perform tayammum ? He replied: No, even if he does not find water for a month. Abu Musa then said: How will you do with the Qur'anic version (about tayammum) in the chapter al-Ma'idah which says: "... and you find no water, then go to clean, high ground" (5:6)? 'Abd Allah (b. Mas'ud) then said: If they (the people) are granted concession in this respect, they might perform tayammum with pure earth when water is cold. Abu Musa said: For this (reason) you forbade it ? He said: Yes. Abu Musa then said: Did you not hear what 'Ammar said to 'Umar ? (He said): The Messenger of Allah (ﷺ) sent me on some errand. I had seminal emission and I did not find water. Therefore, I rolled on the ground just as an animal rolls down. I then came to the Prophet (ﷺ) and made a mention of that to him. He said: It would have been enough for you to do thus. Then he struck the ground with his hands and shook them off and then stuck the right hand with his left hand and his left hand with his right hand (and wiped) over his hands (up to the wrist) and wiped his face. 'Abd Allah then said to him: Did you not see that 'Umar was not satisfied with the statement of 'Ammar ?}}
\hadithdefcmd{abudawud}{322}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ الْعَبْدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، قَالَ كُنْتُ عِنْدَ عُمَرَ فَجَاءَهُ رَجُلٌ فَقَالَ إِنَّا نَكُونُ بِالْمَكَانِ الشَّهْرَ وَالشَّهْرَيْنِ ‏.‏ فَقَالَ عُمَرُ أَمَّا أَنَا فَلَمْ أَكُنْ أُصَلِّي حَتَّى أَجِدَ الْمَاءَ ‏.‏ قَالَ فَقَالَ عَمَّارٌ يَا أَمِيرَ الْمُؤْمِنِينَ أَمَا تَذْكُرُ إِذْ كُنْتُ أَنَا وَأَنْتَ فِي الإِبِلِ فَأَصَابَتْنَا جَنَابَةٌ فَأَمَّا أَنَا فَتَمَعَّكْتُ فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَقُولَ هَكَذَا ‏"‏ ‏.‏ وَضَرَبَ بِيَدَيْهِ إِلَى الأَرْضِ ثُمَّ نَفَخَهُمَا ثُمَّ مَسَحَ بِهِمَا وَجْهَهُ وَيَدَيْهِ إِلَى نِصْفِ الذِّرَاعِ ‏.‏ فَقَالَ عُمَرُ يَا عَمَّارُ اتَّقِ اللَّهَ ‏.‏ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ إِنْ شِئْتَ وَاللَّهِ لَمْ أَذْكُرْهُ أَبَدًا ‏.‏ فَقَالَ عُمَرُ كَلاَّ وَاللَّهِ لَنُوَلِّيَنَّكَ مِنْ ذَلِكَ مَا تَوَلَّيْتَ ‏.‏\hadithno{322}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Abd al-Rahman b. Abza said:While I was with 'Umar, a man came to him and said: We live at a place (where water is not found) for a month or two (what should we do, if we are sexually defiled). 'Umar said: So far as I am concerned, I do not pray until I find water. 'Ammar said: Commanded of the faithful, do you not remember when I and you were among the camels (For tending them)? There we became sexually defiled. I rolled down on the ground. We then came to the Prophet (ﷺ) and I mentioned that to him. He said: It was enough for you to do so. Then he struck the ground with both his hands. He then blew over them and wiped his face and both hands by means of them up to half the arms. 'Umar said: 'Ammar, fear Allah. He said: Commander of the faithful, if you want, I will never narrate it. 'Umar said: Nay, by Allah, we shall turn you from that towards which you turned (i.e. you have your choice)}}
\hadithdefcmd{abudawud}{323}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا حَفْصٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنِ ابْنِ أَبْزَى، عَنْ عَمَّارِ بْنِ يَاسِرٍ، فِي هَذَا الْحَدِيثِ فَقَالَ ‏ "‏ يَا عَمَّارُ إِنَّمَا كَانَ يَكْفِيكَ هَكَذَا ‏"‏ ‏.‏ ثُمَّ ضَرَبَ بِيَدَيْهِ الأَرْضَ ثُمَّ ضَرَبَ إِحْدَاهُمَا عَلَى الأُخْرَى ثُمَّ مَسَحَ وَجْهَهُ وَالذِّرَاعَيْنِ إِلَى نِصْفِ السَّاعِدَيْنِ وَلَمْ يَبْلُغِ الْمِرْفَقَيْنِ ضَرْبَةً وَاحِدَةً ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ وَكِيعٌ عَنِ الأَعْمَشِ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى وَرَوَاهُ جَرِيرٌ عَنِ الأَعْمَشِ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى يَعْنِي عَنْ أَبِيهِ ‏.‏\hadithno{323}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abza reported on the authority of 'Ammar b. Yasir in this tradition as saying (from the Prophet):'Ammar, it would have been enough for you (to do) so. He then stuck only one stroke on the ground with both his hands; he then stuck one with the other; then wiped his face and both arms up to half the forearms and did not reach the elbows. Abu Dawud said: This is also transmitted by Waki' from al-A'mash from Salamah b. Kuhail from 'Abd al-Rahman b. Abza. It is also transmitted through a different chain by Jarir from al-A'mash from Salamah from Sa'id b. 'Abd al-Rahman b. Abza from his father}}
\hadithdefcmd{abudawud}{324}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - أَخْبَرَنَا شُعْبَةُ، عَنْ سَلَمَةَ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ عَمَّارٍ، بِهَذِهِ الْقِصَّةِ فَقَالَ ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ ‏"‏ ‏.‏ وَضَرَبَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ إِلَى الأَرْضِ ثُمَّ نَفَخَ فِيهَا وَمَسَحَ بِهَا وَجْهَهُ وَكَفَّيْهِ شَكَّ سَلَمَةُ وَقَالَ لاَ أَدْرِي فِيهِ إِلَى الْمِرْفَقَيْنِ ‏.‏ يَعْنِي أَوْ إِلَى الْكَفَّيْنِ ‏.‏\hadithno{324}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (338) Sahih Muslim (368)}\hadithtrans{Ibn 'Abd al-Rahman b. Abza reported on the authority of his father this incident from 'Ammar. He said:This would have been enough for you, and the Prophet (ﷺ) struck the ground with his hand. He then blew it and wiped with it his face and hands. Being doubtful Salamah said: I do not know (whether he wiped) up to the elbows or the wrists}}
\hadithdefcmd{abudawud}{325}{حَدَّثَنَا عَلِيُّ بْنُ سَهْلٍ الرَّمْلِيُّ، حَدَّثَنَا حَجَّاجٌ، - يَعْنِي الأَعْوَرَ - حَدَّثَنِي شُعْبَةُ، بِإِسْنَادِهِ بِهَذَا الْحَدِيثِ قَالَ ثُمَّ نَفَخَ فِيهَا وَمَسَحَ بِهَا وَجْهَهُ وَكَفَّيْهِ إِلَى الْمِرْفَقَيْنِ أَوْ إِلَى الذِّرَاعَيْنِ ‏.‏ قَالَ شُعْبَةُ كَانَ سَلَمَةُ يَقُولُ الْكَفَّيْنِ وَالْوَجْهَ وَالذِّرَاعَيْنِ فَقَالَ لَهُ مَنْصُورٌ ذَاتَ يَوْمٍ انْظُرْ مَا تَقُولُ فَإِنَّهُ لاَ يَذْكُرُ الذِّرَاعَيْنِ غَيْرُكَ ‏.‏\hadithno{325}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{This is transmitted by Shu'bah through a different chain of narrators. This version adds:He ('Ammar) said: He (the Prophet) then blew it and wiped with it his face and hands up to elbows or up to the forearms. Shu'bah said: Salamah used to narrate (the words) "the hands and the face and the forearms". One day Mansur said to him: Look, what are you saying, because no one except you mentions the (word) "forearms}}
\hadithdefcmd{abudawud}{326}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي الْحَكَمُ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ عَمَّارٍ، فِي هَذَا الْحَدِيثِ قَالَ فَقَالَ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَضْرِبَ بِيَدَيْكَ إِلَى الأَرْضِ فَتَمْسَحَ بِهِمَا وَجْهَكَ وَكَفَّيْكَ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ شُعْبَةُ عَنْ حُصَيْنٍ عَنْ أَبِي مَالِكٍ قَالَ سَمِعْتُ عَمَّارًا يَخْطُبُ بِمِثْلِهِ إِلاَّ أَنَّهُ قَالَ لَمْ يَنْفُخْ ‏.‏ وَذَكَرَ حُسَيْنُ بْنُ مُحَمَّدٍ عَنْ شُعْبَةَ عَنِ الْحَكَمِ فِي هَذَا الْحَدِيثِ قَالَ ضَرَبَ بِكَفَّيْهِ إِلَى الأَرْضِ وَنَفَخَ ‏.‏\hadithno{326}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{This is also transmitted by Ibn 'Abd al-Rahman b. Abza on the authority of his father from 'Ammar. He reported the Prophet (ﷺ) as saying:It would have been enough for you to strike the ground with you hands and then wipe them your face and your hands (up to the wrists). He then narrated the rest of the tradition. Abu Dawud said: This is also transmitted by Shu'bah from Husain on the authority of Abu Malik. He said: I heard 'Ammar saying so him his speech, except that in this version he added the words: "He blew." And Husain b. Muhammad narrated from Shu'bah on the authority of al-Hakam and in this version added the words:"He (the Prophet) struck the earth with his plans and blew}}
\hadithdefcmd{abudawud}{327}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمِنْهَالِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنِ التَّيَمُّمِ فَأَمَرَنِي ضَرْبَةً وَاحِدَةً لِلْوَجْهِ وَالْكَفَّيْنِ ‏.‏\hadithno{327}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ammar b. Yasir said:I asked the Prophet (ﷺ) about tayammum. He commanded me to strike only one stroke (i.e. the strike the ground) for (wiping) the face and the hands}}
\hadithdefcmd{abudawud}{328}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، قَالَ سُئِلَ قَتَادَةُ عَنِ التَّيَمُّمِ، فِي السَّفَرِ فَقَالَ حَدَّثَنِي مُحَدِّثٌ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِلَى الْمِرْفَقَيْنِ ‏"‏ ‏.‏\hadithno{328}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aban said:Qatadah was asked about tayammum during a journey. He said: A traditionist reported to me from al-Sha'bi from 'Abd al-Rahman b. Abza on the authority of 'Ammar b. Yasir who reported the Messenger of Allah (ﷺ) as saying: (He should wipe) up to the elbows}}
\hadithdefcmd{abudawud}{329}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، أَخْبَرَنَا أَبِي، عَنْ جَدِّي، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ عُمَيْرٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّهُ سَمِعَهُ يَقُولُ أَقْبَلْتُ أَنَا وَعَبْدُ اللَّهِ بْنُ يَسَارٍ، مَوْلَى مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حَتَّى دَخَلْنَا عَلَى أَبِي الْجُهَيْمِ بْنِ الْحَارِثِ بْنِ الصِّمَّةِ الأَنْصَارِيِّ فَقَالَ أَبُو الْجُهَيْمِ أَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نَحْوِ بِئْرِ جَمَلٍ فَلَقِيَهُ رَجُلٌ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَيْهِ السَّلاَمَ حَتَّى أَتَى عَلَى جِدَارٍ فَمَسَحَ بِوَجْهِهِ وَيَدَيْهِ ثُمَّ رَدَّ عَلَيْهِ السَّلاَمَ ‏.‏\hadithno{329}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (337) Sahih Muslim (369)}\hadithtrans{Umair, the freed slave of Ibn 'Abbas, said that he heard him say:I and 'Abd Allah b. Yasar, the freed slave of Maimunah, wife of the Prophet (ﷺ), came and entered upon Abu al-Juhaim b. al-Harith b. al-Simmat al-Ansari. Abu al-Juhaim said: The Messenger of Allah (ﷺ) came from Bir Jamal (a place near Medina) and a man met him and saluted him. The Messenger of Allah (ﷺ) did not return the salutation until he came to a wall and wiped his face and hands and then returned the salutation (i.e. after performing tayammum)}}
\hadithdefcmd{abudawud}{330}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الْمَوْصِلِيُّ أَبُو عَلِيٍّ، أَخْبَرَنَا مُحَمَّدُ بْنُ ثَابِتٍ الْعَبْدِيُّ، أَخْبَرَنَا نَافِعٌ، قَالَ انْطَلَقْتُ مَعَ ابْنِ عُمَرَ فِي حَاجَةٍ إِلَى ابْنِ عَبَّاسٍ فَقَضَى ابْنُ عُمَرَ حَاجَتَهُ فَكَانَ مِنْ حَدِيثِهِ يَوْمَئِذٍ أَنْ قَالَ مَرَّ رَجُلٌ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سِكَّةٍ مِنَ السِّكَكِ وَقَدْ خَرَجَ مِنْ غَائِطٍ أَوْ بَوْلٍ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْهِ حَتَّى إِذَا كَادَ الرَّجُلُ أَنْ يَتَوَارَى فِي السِّكَّةِ ضَرَبَ بِيَدَيْهِ عَلَى الْحَائِطِ وَمَسَحَ بِهِمَا وَجْهَهُ ثُمَّ ضَرَبَ ضَرْبَةً أُخْرَى فَمَسَحَ ذِرَاعَيْهِ ثُمَّ رَدَّ عَلَى الرَّجُلِ السَّلاَمَ وَقَالَ ‏ "‏ إِنَّهُ لَمْ يَمْنَعْنِي أَنْ أَرُدَّ عَلَيْكَ السَّلاَمَ إِلاَّ أَنِّي لَمْ أَكُنْ عَلَى طُهْرٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ رَوَى مُحَمَّدُ بْنُ ثَابِتٍ حَدِيثًا مُنْكَرًا فِي التَّيَمُّمِ ‏.‏ قَالَ ابْنُ دَاسَةَ قَالَ أَبُو دَاوُدَ لَمْ يُتَابَعْ مُحَمَّدُ بْنُ ثَابِتٍ فِي هَذِهِ الْقِصَّةِ عَلَى ضَرْبَتَيْنِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَرَوَوْهُ فِعْلَ ابْنِ عُمَرَ ‏.‏\hadithno{330}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Nafi' said:Accompanied by 'Abd Allah b. 'Umar, I went to Ibn 'Abbas for a certain work. He (Ibn 'Abbas) narrated a tradition saying: A man passed by the Messenger of Allah (ﷺ) in a street, while he returned from the toilet or just urinated. He (the man) saluted him, but the Prophet did not return the salutation. When the man was about to disappear (from sight) in the street he struck the wall with both his hands and wiped his face with them. He then struck another stroke and wipes his arms. He then returned the man's salutation. Then he said: I did not return the salutation to you because I was not purified. Abu Dawud said: I heard Ahmad b. Hanbal say: Muhammad b. Thabit reported a rejected tradition. Ibn Dasah said: Abu Dawud said: No one supported Muhammad b. Thabit in respect of narrating this tradition as to striking the wall twice (for wiping) from the Prophet (ﷺ), but reported it as an action of Ibn 'Umar}}
\hadithdefcmd{abudawud}{331}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَحْيَى الْبُرُلُّسِيُّ، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، عَنِ ابْنِ الْهَادِ، أَنَّ نَافِعًا، حَدَّثَهُ عَنِ ابْنِ عُمَرَ، قَالَ أَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْغَائِطِ فَلَقِيَهُ رَجُلٌ عِنْدَ بِئْرِ جَمَلٍ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَقْبَلَ عَلَى الْحَائِطِ فَوَضَعَ يَدَهُ عَلَى الْحَائِطِ ثُمَّ مَسَحَ وَجْهَهُ وَيَدَيْهِ ثُمَّ رَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الرَّجُلِ السَّلاَمَ ‏.‏\hadithno{331}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn 'Umar said:The Messenger of Allah (ﷺ) came from the privy. A man met him near Bir Jamal and saluted him. The Messenger of Allah (ﷺ) did not return the salutation until he came to a wall and placed his hands on the wall and wiped his face and hands; he then returned the man's salutation}}
\hadithdefcmd{abudawud}{332}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا خَالِدٌ الْوَاسِطِيُّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، ح وَحَدَّثَنَا مُسَدَّدٌ، أَخْبَرَنَا خَالِدٌ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ الْوَاسِطِيَّ - عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَمْرِو بْنِ بُجْدَانَ، عَنْ أَبِي ذَرٍّ، قَالَ اجْتَمَعَتْ غُنَيْمَةٌ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ ابْدُ فِيهَا ‏"‏ ‏.‏ فَبَدَوْتُ إِلَى الرَّبَذَةِ فَكَانَتْ تُصِيبُنِي الْجَنَابَةُ فَأَمْكُثُ الْخَمْسَ وَالسِّتَّ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَبُو ذَرٍّ ‏"‏ ‏.‏ فَسَكَتُّ فَقَالَ ‏"‏ ثَكِلَتْكَ أُمُّكَ أَبَا ذَرٍّ لأُمِّكَ الْوَيْلُ ‏"‏ ‏.‏ فَدَعَا لِي بِجَارِيَةٍ سَوْدَاءَ فَجَاءَتْ بِعُسٍّ فِيهِ مَاءٌ فَسَتَرَتْنِي بِثَوْبٍ وَاسْتَتَرْتُ بِالرَّاحِلَةِ وَاغْتَسَلْتُ فَكَأَنِّي أَلْقَيْتُ عَنِّي جَبَلاً فَقَالَ ‏"‏ الصَّعِيدُ الطَّيِّبُ وَضُوءُ الْمُسْلِمِ وَلَوْ إِلَى عَشْرِ سِنِينَ فَإِذَا وَجَدْتَ الْمَاءَ فَأَمِسَّهُ جِلْدَكَ فَإِنَّ ذَلِكَ خَيْرٌ ‏"‏ ‏.‏ وَقَالَ مُسَدَّدٌ غُنَيْمَةٌ مِنَ الصَّدَقَةِ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ عَمْرٍو أَتَمُّ ‏.‏\hadithno{332}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Dharr said:A few goats got collected with the Messenger of Allah (ﷺ). He said: Abu Dharr, drive them to the wood. I drove them to Rabadhah (a place near Medina). I would have sexual defilement (during my stay there) and I would remain (in this condition) for five or six days. Then I came to the Messenger of Allah (ﷺ). He said: O Abu Dharr. I kept silence. He then said: May your mother bereave you, Abu Dharr: woe be to your mother. He then called a black slave-girl for me. She brought a vessel which contained water. She then concealed me by drawing a curtain and I concealed myself behind a she-camel, and took a bath. I felt as if I had thrown away a mountain from me. He said: Clean earth is a means for ablution for a Muslim, even for ten years (he does not find water); but when you find water, you should make it touch your skin, for that is better. The version of Musaddad has: "the goats (were collected) from the alms," and the tradition reported by 'Amr is complete}}
\hadithdefcmd{abudawud}{333}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، أَخْبَرَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ رَجُلٍ، مِنْ بَنِي عَامِرٍ قَالَ دَخَلْتُ فِي الإِسْلاَمِ فَأَهَمَّنِي دِينِي فَأَتَيْتُ أَبَا ذَرٍّ فَقَالَ أَبُو ذَرٍّ إِنِّي اجْتَوَيْتُ الْمَدِينَةَ فَأَمَرَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَوْدٍ وَبِغَنَمٍ فَقَالَ لِي ‏"‏ اشْرَبْ مِنْ أَلْبَانِهَا ‏"‏ ‏.‏ قَالَ حَمَّادٌ وَأَشُكُّ فِي ‏"‏ أَبْوَالِهَا ‏"‏ ‏.‏ هَذَا قَوْلُ حَمَّادٍ ‏.‏ فَقَالَ أَبُو ذَرٍّ فَكُنْتُ أَعْزُبُ عَنِ الْمَاءِ وَمَعِي أَهْلِي فَتُصِيبُنِي الْجَنَابَةُ فَأُصَلِّي بِغَيْرِ طُهُورٍ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِنِصْفِ النَّهَارِ وَهُوَ فِي رَهْطٍ مِنْ أَصْحَابِهِ وَهُوَ فِي ظِلِّ الْمَسْجِدِ فَقَالَ ‏"‏ أَبُو ذَرٍّ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ هَلَكْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَمَا أَهْلَكَكَ ‏"‏ ‏.‏ قُلْتُ إِنِّي كُنْتُ أَعْزُبُ عَنِ الْمَاءِ وَمَعِي أَهْلِي فَتُصِيبُنِي الْجَنَابَةُ فَأُصَلِّي بِغَيْرِ طُهُورٍ فَأَمَرَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَاءٍ فَجَاءَتْ بِهِ جَارِيَةٌ سَوْدَاءُ بِعُسٍّ يَتَخَضْخَضُ مَا هُوَ بِمَلآنَ فَتَسَتَّرْتُ إِلَى بَعِيرِي فَاغْتَسَلْتُ ثُمَّ جِئْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا ذَرٍّ إِنَّ الصَّعِيدَ الطَّيِّبَ طَهُورٌ وَإِنْ لَمْ تَجِدِ الْمَاءَ إِلَى عَشْرِ سِنِينَ فَإِذَا وَجَدْتَ الْمَاءَ فَأَمِسَّهُ جِلْدَكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ حَمَّادُ بْنُ زَيْدٍ عَنْ أَيُّوبَ لَمْ يَذْكُرْ ‏"‏ أَبْوَالَهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا لَيْسَ بِصَحِيحٍ وَلَيْسَ فِي أَبْوَالِهَا إِلاَّ حَدِيثُ أَنَسٍ تَفَرَّدَ بِهِ أَهْلُ الْبَصْرَةِ ‏.‏\hadithno{333}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{A man from Banu 'Amir said:I embraced Islam and my (ignorance of the) religion made me anxious (to learn the essentials). I came to Abu Dharr. Abu Dharr said: The climate of Medina did not suit me. The Messenger of Allah (ﷺ) ordered me to have a few camels and goats. He said to me: Drink their milk. (The narrator Hammad said): I doubt whether he (the Prophet) said: "their urine." Abu Dharr said: I was away from the watering place and I had my family with me. I would have sexual defilement and pray without purification. I came to the Messenger of Allah (ﷺ) at noon. He was resting in the shade of the mosque along with a group of Companions. He (the Prophet) said: Abu Dharr. I said: Yes, I am ruined, Messenger of Allah. He said: What ruined you ? I said: I was away from the watering place and I had family with me. I used to be sexually defiled and pray without purification. He commanded (to bring) water for me. Then a black slave-girl brought a vessel of water that was shaking as the vessel was not full. I concealed myself behind a camel and took bath and them came (to the Prophet). The Messenger of Allah (ﷺ) said: Abu Dharr, clean earth is a means of ablution, even if you do not find water for ten years. When you find water, you should make it touch your skin. Abu Dawud said: This is transmitted by Hammad b. Zaid from Ayyub. This version does not mention the words "their urine." This is not correct. The words "their urine" occur only in the version reported by Anas and transmitted only by the people of Basrah}}
\hadithdefcmd{abudawud}{334}{حَدَّثَنَا ابْنُ الْمُثَنَّى، أَخْبَرَنَا وَهْبُ بْنُ جَرِيرٍ، أَخْبَرَنَا أَبِي قَالَ، سَمِعْتُ يَحْيَى بْنَ أَيُّوبَ، يُحَدِّثُ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ الْمِصْرِيِّ، عَنْ عَمْرِو بْنِ الْعَاصِ، قَالَ احْتَلَمْتُ فِي لَيْلَةٍ بَارِدَةٍ فِي غَزْوَةِ ذَاتِ السَّلاَسِلِ فَأَشْفَقْتُ إِنِ اغْتَسَلْتُ أَنْ أَهْلِكَ فَتَيَمَّمْتُ ثُمَّ صَلَّيْتُ بِأَصْحَابِي الصُّبْحَ فَذَكَرُوا ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا عَمْرُو صَلَّيْتَ بِأَصْحَابِكَ وَأَنْتَ جُنُبٌ ‏"‏ ‏.‏ فَأَخْبَرْتُهُ بِالَّذِي مَنَعَنِي مِنَ الاِغْتِسَالِ وَقُلْتُ إِنِّي سَمِعْتُ اللَّهَ يَقُولُ ‏\{‏ وَلاَ تَقْتُلُوا أَنْفُسَكُمْ إِنَّ اللَّهَ كَانَ بِكُمْ رَحِيمًا ‏\}‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَمْ يَقُلْ شَيْئًا ‏.‏ قَالَ أَبُو دَاوُدَ عَبْدُ الرَّحْمَنِ بْنُ جُبَيْرٍ مِصْرِيٌّ مَوْلَى خَارِجَةَ بْنِ حُذَافَةَ وَلَيْسَ هُوَ ابْنَ جُبَيْرِ بْنِ نُفَيْرٍ ‏.‏\hadithno{334}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Amr ibn al-'As: I had a sexual dream on a cold night in the battle of Dhat as-Salasil. I was afraid, if I washed I would die. I, therefore, performed tayammum and led my companions in the dawn prayer. They mentioned that to the Messenger of Allah (ﷺ). He said: Amr, you led your companions is prayer while you were sexually defiled? I informed him of the cause which impeded me from washing. And I said: I heard Allah say: "Do not kill yourself, verily Allah is merciful to you." The Messenger of Allah (ﷺ) laughed and did not say anything. Abu Dawud said: 'Abd al-Rahman b. Jubair is an Egyptian and a freed slave of Kharijah b. Hudhafah. He is not Jubair b. Nufair}}
\hadithdefcmd{abudawud}{335}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنِ ابْنِ لَهِيعَةَ، وَعَمْرِو بْنِ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ، عَنْ أَبِي قَيْسٍ، مَوْلَى عَمْرِو بْنِ الْعَاصِ أَنَّ عَمْرَو بْنَ الْعَاصِ، كَانَ عَلَى سَرِيَّةٍ وَذَكَرَ الْحَدِيثَ نَحْوَهُ ‏.‏ قَالَ فَغَسَلَ مَغَابِنَهُ وَتَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ صَلَّى بِهِمْ فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرِ التَّيَمُّمَ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُوِيَتْ هَذِهِ الْقِصَّةُ عَنِ الأَوْزَاعِيِّ عَنْ حَسَّانَ بْنِ عَطِيَّةَ قَالَ فِيهِ فَتَيَمَّمَ ‏.‏\hadithno{335}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Qais, the freed slave of 'Amr b. al-'As, said 'Amr b. al-'As was in a battle. He then narrated the rest of the tradition. He then said:He washed his armpits and other joints where dirt was found, and he performed ablution like that for prayer. Then he led them in prayer. He then narrated the tradition in a similar way but did not mention of tayammum. Abu Dawud said: This incident has also been narrated by al-'Awza'i on the authority of Hassan b. 'Atiyyah. This version has the words: Then he performed tayammum}}
\hadithdefcmd{abudawud}{336}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الأَنْطَاكِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ الزُّبَيْرِ بْنِ خُرَيْقٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ خَرَجْنَا فِي سَفَرٍ فَأَصَابَ رَجُلاً مِنَّا حَجَرٌ فَشَجَّهُ فِي رَأْسِهِ ثُمَّ احْتَلَمَ فَسَأَلَ أَصْحَابَهُ فَقَالَ هَلْ تَجِدُونَ لِي رُخْصَةً فِي التَّيَمُّمِ فَقَالُوا مَا نَجِدُ لَكَ رُخْصَةً وَأَنْتَ تَقْدِرُ عَلَى الْمَاءِ فَاغْتَسَلَ فَمَاتَ فَلَمَّا قَدِمْنَا عَلَى النَّبِيِّ صلى الله عليه وسلم أُخْبِرَ بِذَلِكَ فَقَالَ ‏"‏ قَتَلُوهُ قَتَلَهُمُ اللَّهُ أَلاَّ سَأَلُوا إِذْ لَمْ يَعْلَمُوا فَإِنَّمَا شِفَاءُ الْعِيِّ السُّؤَالُ إِنَّمَا كَانَ يَكْفِيهِ أَنْ يَتَيَمَّمَ وَيَعْصِرَ ‏"‏ ‏.‏ أَوْ ‏"‏ يَعْصِبَ ‏"‏ ‏.‏ شَكَّ مُوسَى ‏"‏ عَلَى جُرْحِهِ خِرْقَةً ثُمَّ يَمْسَحَ عَلَيْهَا وَيَغْسِلَ سَائِرَ جَسَدِهِ ‏"‏ ‏.‏\hadithno{336}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir said:We set out on a journey. One of our people was hurt by a stone, that injured his head. He then had a sexual dream. He asked his fellow travelers: Do you find a concession for me to perform tayammum? They said: We do not find any concession for you while you can use water. He took a bath and died. When we came to the Prophet (ﷺ), the incident was reported to him. He said: They killed him, may Allah kill them! Could they not ask when they did not know? The cure for ignorance is inquiry. It was enough for him to perform tayammum and to pour some drops of water or bind a bandage over the wound (the narrator Musa was doubtful); then he should have wiped over it and washed the rest of his body}}
\hadithdefcmd{abudawud}{337}{حَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ الأَنْطَاكِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، أَخْبَرَنِي الأَوْزَاعِيُّ، أَنَّهُ بَلَغَهُ عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، قَالَ أَصَابَ رَجُلاً جُرْحٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ احْتَلَمَ فَأُمِرَ بِالاِغْتِسَالِ فَاغْتَسَلَ فَمَاتَ فَبَلَغَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قَتَلُوهُ قَتَلَهُمُ اللَّهُ أَلَمْ يَكُنْ شِفَاءُ الْعِيِّ السُّؤَالَ ‏"‏ ‏.‏\hadithno{337}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: A man was injured during the lifetime of the Messenger of Allah (ﷺ); he then had a sexual dream, and he was advised to wash and he washed himself. Consequently he died. When this was reported to the Messenger of Allah (ﷺ) he said: They killed him; may Allah kill them! Is not inquiry the cure of ignorance?}}
\hadithdefcmd{abudawud}{338}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ خَرَجَ رَجُلاَنِ فِي سَفَرٍ فَحَضَرَتِ الصَّلاَةُ وَلَيْسَ مَعَهُمَا مَاءٌ فَتَيَمَّمَا صَعِيدًا طَيِّبًا فَصَلَّيَا ثُمَّ وَجَدَا الْمَاءَ فِي الْوَقْتِ فَأَعَادَ أَحَدُهُمَا الصَّلاَةَ وَالْوُضُوءَ وَلَمْ يُعِدِ الآخَرُ ثُمَّ أَتَيَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَا ذَلِكَ لَهُ فَقَالَ لِلَّذِي لَمْ يُعِدْ ‏"‏ أَصَبْتَ السُّنَّةَ وَأَجْزَأَتْكَ صَلاَتُكَ ‏"‏ ‏.‏ وَقَالَ لِلَّذِي تَوَضَّأَ وَأَعَادَ ‏"‏ لَكَ الأَجْرُ مَرَّتَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَغَيْرُ ابْنِ نَافِعٍ يَرْوِيهِ عَنِ اللَّيْثِ عَنْ عَمِيرَةَ بْنِ أَبِي نَاجِيَةَ عَنْ بَكْرِ بْنِ سَوَادَةَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ وَذِكْرُ أَبِي سَعِيدٍ الْخُدْرِيِّ فِي هَذَا الْحَدِيثِ لَيْسَ بِمَحْفُوظٍ وَهُوَ مُرْسَلٌ ‏.‏\hadithno{338}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'id al-Khudri said:Two persons set out on a journey. Meanwhile the time of prayer came and they had no water. They performed tayammum with clean earth and prayed. Later on they found water within the time of the prayer. One of them repeated the prayer and ablution but the other did not repeat. Then they came to the Messenger of Allah (ﷺ) and related the matter to him. Addressing himself to the one who did not repeat, he said: You followed the sunnah (model behavior of the Prophet) and your (first) prayer was enough for you. He said to the one who performed ablution and repeated: For you there is the double reward. Abu Dawud said: Besides Ibn Nafi' this is transmitted by al-Laith from 'Umairah b. Abi Najiyyah from Bakr b. Sawadah on the authority of 'Ata b. Yasar from the Prophet (ﷺ). Abu Dawud said: The mention of (the name of the Companion) Abu Sa'id in this tradition is not guarded. This is a mural tradition (i.e. the Successor 'Ata b. Yasar directly narrates it from the Prophet, leaving the name of the Companion in the chain)}}
\hadithdefcmd{abudawud}{339}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ أَبِي عَبْدِ اللَّهِ، مَوْلَى إِسْمَاعِيلَ بْنِ عُبَيْدٍ عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَجُلَيْنِ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏\hadithno{339}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Ata b. Yasar said:Two persons from the Companions of the Messenger of Allah (ﷺ); he then narrated the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{340}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، أَخْبَرَنَا مُعَاوِيَةُ، عَنْ يَحْيَى، أَخْبَرَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ بَيْنَا هُوَ يَخْطُبُ يَوْمَ الْجُمُعَةِ إِذْ دَخَلَ رَجُلٌ فَقَالَ عُمَرُ أَتَحْتَبِسُونَ عَنِ الصَّلاَةِ فَقَالَ الرَّجُلُ مَا هُوَ إِلاَّ أَنْ سَمِعْتُ النِّدَاءَ فَتَوَضَّأْتُ ‏.‏ فَقَالَ عُمَرُ وَالْوُضُوءَ أَيْضًا أَوَلَمْ تَسْمَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أَتَى أَحَدُكُمُ الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{340}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (882) Sahih Muslim (845)}\hadithtrans{Abu Hurairah said:While 'Umar b. al-Khattab was making a speech on Friday (in the mosque), a man came in. 'Umar said: Are you detained from prayer ? The man said: As soon as I heard the call for prayer, I perfumed ablution. Then 'Umar said: Only ablution ? Did you not hear the Messenger of Allah (ﷺ) say: When any one of you comes for Friday (prayer) he should take a bath}}
\hadithdefcmd{abudawud}{341}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ غُسْلُ يَوْمِ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏ ‏.‏\hadithno{341}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (895) Sahih Muslim (846)}\hadithtrans{Abu Sa'id al-Khudri reported the Messenger of Allah (ﷺ) as saying:Taking bath on Friday is necessary for every adult}}
\hadithdefcmd{abudawud}{342}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الرَّمْلِيُّ، أَخْبَرَنَا الْمُفَضَّلُ، - يَعْنِي ابْنَ فَضَالَةَ - عَنْ عَيَّاشِ بْنِ عَبَّاسٍ، عَنْ بُكَيْرٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَى كُلِّ مُحْتَلِمٍ رَوَاحُ الْجُمُعَةِ وَعَلَى كُلِّ مَنْ رَاحَ إِلَى الْجُمُعَةِ الْغُسْلُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ إِذَا اغْتَسَلَ الرَّجُلُ بَعْدَ طُلُوعِ الْفَجْرِ أَجْزَأَهُ مِنْ غُسْلِ الْجُمُعَةِ وَإِنْ أَجْنَبَ ‏.‏\hadithno{342}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hafsah, Ummul Mu'minin: The Prophet (ﷺ) said: It is necessary for every adult (person) to go for (saying) Friday (prayer), and for everyone who goes for Friday (prayer) washing is necessary. Abu Dawud said: If one takes bath after sunrise, even though he washes because of seminal emission, that will be enough for him for his washing on Friday}}
\hadithdefcmd{abudawud}{343}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الرَّمْلِيُّ الْهَمْدَانِيُّ، ح وَحَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، - وَهَذَا حَدِيثُ مُحَمَّدِ بْنِ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، - قَالَ أَبُو دَاوُدَ قَالَ يَزِيدُ وَعَبْدُ الْعَزِيزِ فِي حَدِيثِهِمَا عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ وَأَبِي أُمَامَةَ بْنِ سَهْلٍ - عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ وَأَبِي هُرَيْرَةَ قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ وَلَبِسَ مِنْ أَحْسَنِ ثِيَابِهِ وَمَسَّ مِنْ طِيبٍ - إِنْ كَانَ عِنْدَهُ - ثُمَّ أَتَى الْجُمُعَةَ فَلَمْ يَتَخَطَّ أَعْنَاقَ النَّاسِ ثُمَّ صَلَّى مَا كَتَبَ اللَّهُ لَهُ ثُمَّ أَنْصَتَ إِذَا خَرَجَ إِمَامُهُ حَتَّى يَفْرُغَ مِنْ صَلاَتِهِ كَانَتْ كَفَّارَةً لِمَا بَيْنَهَا وَبَيْنَ جُمُعَتِهِ الَّتِي قَبْلَهَا ‏"‏ ‏.‏ قَالَ وَيَقُولُ أَبُو هُرَيْرَةَ ‏"‏ وَزِيَادَةُ ثَلاَثَةِ أَيَّامٍ ‏"‏ ‏.‏ وَيَقُولُ ‏"‏ إِنَّ الْحَسَنَةَ بِعَشْرِ أَمْثَالِهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ مُحَمَّدِ بْنِ سَلَمَةَ أَتَمُّ وَلَمْ يَذْكُرْ حَمَّادٌ كَلاَمَ أَبِي هُرَيْرَةَ ‏.‏\hadithno{343}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'id al-Khudri and Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:If anyone takes a bath on Friday, puts on his best clothes, applies a touch of perfume if has any, then goes to congregational prayer (in the mosque), and takes care not to step over people, then prayer what Allah has prescribes for him, then keeps silent from the time his Imam comes out until he finishes his prayer, it will atone for his sins during the previous week. Abu Hurairah said: (It will atone for his sins) for three days more. he further said: One is rewarded ten times for doing a good work. Abu Dawud said: The version narrated by Muhammad b. Salamah is perfect, and Hammad did not make a mention of the statement of Abu Hurairah}}
\hadithdefcmd{abudawud}{344}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ سَعِيدَ بْنَ أَبِي هِلاَلٍ، وَبُكَيْرَ بْنَ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، حَدَّثَاهُ عَنْ أَبِي بَكْرِ بْنِ الْمُنْكَدِرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْغُسْلُ يَوْمَ الْجُمُعَةِ عَلَى كُلِّ مُحْتَلِمٍ وَالسِّوَاكُ وَيَمَسُّ مِنَ الطِّيبِ مَا قُدِّرَ لَهُ ‏"‏ ‏.‏ إِلاَّ أَنَّ بُكَيْرًا لَمْ يَذْكُرْ عَبْدَ الرَّحْمَنِ وَقَالَ فِي الطِّيبِ ‏"‏ وَلَوْ مِنْ طِيبِ الْمَرْأَةِ ‏"‏ ‏.‏\hadithno{344}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (846)}\hadithtrans{Abd al-Rahman b. Abi Sa'id al-Khudri quotes his father as saying:The Prophet (ﷺ) said: Washing and the use of tooth-stick are necessary for every adult (person) on Friday; and everyone should apply perfume whatever one has. The narrator Bukair did not mention of 'Abd al-Rahman; and about perfume he said that even it might be of the kind used by women}}
\hadithdefcmd{abudawud}{345}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْجَرْجَرَائِيُّ، حِبِّي حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنِي حَسَّانُ بْنُ عَطِيَّةَ، حَدَّثَنِي أَبُو الأَشْعَثِ الصَّنْعَانِيُّ، حَدَّثَنِي أَوْسُ بْنُ أَوْسٍ الثَّقَفِيُّ، سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ غَسَّلَ يَوْمَ الْجُمُعَةِ وَاغْتَسَلَ ثُمَّ بَكَّرَ وَابْتَكَرَ وَمَشَى وَلَمْ يَرْكَبْ وَدَنَا مِنَ الإِمَامِ فَاسْتَمَعَ وَلَمْ يَلْغُ كَانَ لَهُ بِكُلِّ خُطْوَةٍ عَمَلُ سَنَةٍ أَجْرُ صِيَامِهَا وَقِيَامِهَا ‏"‏ ‏.‏\hadithno{345}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aws ibn Aws ath-Thaqafi: I heard the apostle of Allah (ﷺ) say: If anyone makes (his wife) wash and he washes himself on Friday, goes out early (for Friday prayer), attends the sermon from the beginning, walking, not riding, takes his seat near the imam, listens attentively, and does not indulge in idle talk, he will get the reward of a year's fasting and praying at night for every step he takes}}
\hadithdefcmd{abudawud}{346}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ أَوْسٍ الثَّقَفِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ غَسَلَ رَأْسَهُ يَوْمَ الْجُمُعَةِ وَاغْتَسَلَ ‏"‏ ‏.‏ ثُمَّ سَاقَ نَحْوَهُ ‏.‏\hadithno{346}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aws al-Thaqafi reported the Messenger of Allah (ﷺ) as saying:If anyone washes his head on Friday and washes himself; and he narrated the rest of the tradition as above}}
\hadithdefcmd{abudawud}{347}{حَدَّثَنَا ابْنُ أَبِي عَقِيلٍ، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، - قَالَ ابْنُ أَبِي عَقِيلٍ - أَخْبَرَنِي أُسَامَةُ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ وَمَسَّ مِنْ طِيبِ امْرَأَتِهِ - إِنْ كَانَ لَهَا - وَلَبِسَ مِنْ صَالِحِ ثِيَابِهِ ثُمَّ لَمْ يَتَخَطَّ رِقَابَ النَّاسِ وَلَمْ يَلْغُ عِنْدَ الْمَوْعِظَةِ كَانَتْ كَفَّارَةً لِمَا بَيْنَهُمَا وَمَنْ لَغَا وَتَخَطَّى رِقَابَ النَّاسِ كَانَتْ لَهُ ظُهْرًا ‏"‏ ‏.‏\hadithno{347}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abd Allah b. 'Amr al-'As reported the Prophet (ﷺ) as saying:Whoever washed himself on Friday and applies perfume of his wife if she has one, and wears good clothes and does not step over the necks of the people (in the mosque to sit in the front row) and does not indulge in idle talk during the sermon, that will atone (for his sins) between the two Fridays. But he who indulges in idle talk and steps over the necks of people (in the mosque), that (Friday) will be for him like the noon prayer}}
\hadithdefcmd{abudawud}{348}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا زَكَرِيَّا، حَدَّثَنَا مُصْعَبُ بْنُ شَيْبَةَ، عَنْ طَلْقِ بْنِ حَبِيبٍ الْعَنَزِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّهَا حَدَّثَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَغْتَسِلُ مِنْ أَرْبَعٍ مِنَ الْجَنَابَةِ وَيَوْمِ الْجُمُعَةِ وَمِنَ الْحِجَامَةِ وَمِنْ غُسْلِ الْمَيِّتِ ‏.‏\hadithno{348}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) would take a bath because of sexual defilement on Friday, after opening a vein and after washing a dead body}}
\hadithdefcmd{abudawud}{349}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، أَخْبَرَنَا مَرْوَانُ، حَدَّثَنَا عَلِيُّ بْنُ حَوْشَبٍ، قَالَ سَأَلْتُ مَكْحُولاً عَنْ هَذَا الْقَوْلِ، ‏ "‏ غَسَّلَ وَاغْتَسَلَ ‏"‏ ‏.‏ فَقَالَ غَسَّلَ رَأْسَهُ وَغَسَلَ جَسَدَهُ ‏.‏\hadithno{349}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Makhul was asked about the meaning of words ghassala and ightasala (that occur in tradition 345) and he said:one should was one's head and body well (and not than one should makes one's wife wash)}}
\hadithdefcmd{abudawud}{350}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا أَبُو مُسْهِرٍ، عَنْ سَعِيدِ بْنِ عَبْدِ الْعَزِيزِ، فِي ‏ "‏ غَسَّلَ وَاغْتَسَلَ ‏"‏ ‏.‏ قَالَ قَالَ سَعِيدٌ غَسَّلَ رَأْسَهُ وَغَسَلَ جَسَدَهُ ‏.‏\hadithno{350}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Explaining the meaning of the words ghassala and ightasala (that occur in tradition 345) Sa'id (b. 'Abd al-'Aziz) said:One should wash one's head and body well (And not that one should make one's wife wash)}}
\hadithdefcmd{abudawud}{351}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ غُسْلَ الْجَنَابَةِ ثُمَّ رَاحَ فَكَأَنَّمَا قَرَّبَ بَدَنَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّانِيَةِ فَكَأَنَّمَا قَرَّبَ بَقَرَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّالِثَةِ فَكَأَنَّمَا قَرَّبَ كَبْشًا أَقْرَنَ وَمَنْ رَاحَ فِي السَّاعَةِ الرَّابِعَةِ فَكَأَنَّمَا قَرَّبَ دَجَاجَةً وَمَنْ رَاحَ فِي السَّاعَةِ الْخَامِسَةِ فَكَأَنَّمَا قَرَّبَ بَيْضَةً فَإِذَا خَرَجَ الإِمَامُ حَضَرَتِ الْمَلاَئِكَةُ يَسْتَمِعُونَ الذِّكْرَ ‏"‏ ‏.‏\hadithno{351}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (881) Sahih Muslim (850)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:Whoever takes bath due to sexual defilement on Friday and goes out (for Friday prayer), is treated like one who offers a camel as sacrifice; he who goes out in the second instance as one who offers a cow; he who goes out in the third instance is treated as one who offers horned cow ; he who goes out in the fourth instance is treated as one who offers hen ; he who goes out in the fifth instance is treated as one who offers an egg. When the Imam comes out (for sermon), the angels too attend to listen to the sermon}}
\hadithdefcmd{abudawud}{352}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّاسُ مُهَّانَ أَنْفُسِهِمْ فَيَرُوحُونَ إِلَى الْجُمُعَةِ بِهَيْئَتِهِمْ فَقِيلَ لَهُمْ لَوِ اغْتَسَلْتُمْ ‏.‏\hadithno{352}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (903) Sahih Muslim (847)}\hadithtrans{Aishah said:The people (mostly) were workers and they would come for Friday prayer in the same condition, so it was said to them: If only you were to perform Ghusl}}
\hadithdefcmd{abudawud}{353}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عِكْرِمَةَ، أَنَّ أُنَاسًا، مِنْ أَهْلِ الْعِرَاقِ جَاءُوا فَقَالُوا يَا ابْنَ عَبَّاسٍ أَتَرَى الْغُسْلَ يَوْمَ الْجُمُعَةِ وَاجِبًا قَالَ لاَ وَلَكِنَّهُ أَطْهَرُ وَخَيْرٌ لِمَنِ اغْتَسَلَ وَمَنْ لَمْ يَغْتَسِلْ فَلَيْسَ عَلَيْهِ بِوَاجِبٍ وَسَأُخْبِرُكُمْ كَيْفَ بَدْءُ الْغُسْلِ كَانَ النَّاسُ مَجْهُودِينَ يَلْبَسُونَ الصُّوفَ وَيَعْمَلُونَ عَلَى ظُهُورِهِمْ وَكَانَ مَسْجِدُهُمْ ضَيِّقًا مُقَارِبَ السَّقْفِ إِنَّمَا هُوَ عَرِيشٌ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَوْمٍ حَارٍّ وَعَرِقَ النَّاسُ فِي ذَلِكَ الصُّوفِ حَتَّى ثَارَتْ مِنْهُمْ رِيَاحٌ آذَى بِذَلِكَ بَعْضُهُمْ بَعْضًا فَلَمَّا وَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم تِلْكَ الرِّيحَ قَالَ ‏ "‏ أَيُّهَا النَّاسُ إِذَا كَانَ هَذَا الْيَوْمُ فَاغْتَسِلُوا وَلْيَمَسَّ أَحَدُكُمْ أَفْضَلَ مَا يَجِدُ مِنْ دُهْنِهِ وَطِيبِهِ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ ثُمَّ جَاءَ اللَّهُ بِالْخَيْرِ وَلَبِسُوا غَيْرَ الصُّوفِ وَكُفُوا الْعَمَلَ وَوُسِّعَ مَسْجِدُهُمْ وَذَهَبَ بَعْضُ الَّذِي كَانَ يُؤْذِي بَعْضُهُمْ بَعْضًا مِنَ الْعَرَقِ ‏.‏\hadithno{353}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Amr b. Abi 'Amr and 'Ikrimah reported:Some people of Iraq came and said: Ibn 'Abbas, do you regard taking a bath on Friday as obligatory ? He said: No, it is only a means of cleanliness, and is better for one who washes oneself. Anyone who does not take a bath, it is not essential for him. I inform you how the bath (on Friday) commenced. The people were poor and used to wear woolen clothes, and would carry loads on their backs. Their mosque was small and its rood was lowered down. It was a sort of trellis of vine. The Messenger of Allah (ﷺ) once came out on a hot day and the people perspired profusely in the woolen clothes so much so that foul smell emitted from them and it caused trouble to each other. When the Messenger of Allah (ﷺ) found the foul smell, he said: O people, when this day (Friday) comes, you should take bath and every one should anoint the best oil and perfume one has. Ibn 'Abbas then said: Then Allah, the Exalted, provided wealth (to the people) and they wore clothes other than the woolen, and were spared from work, and their mosque became vast. The foul smell that caused trouble to them became non-existent}}
\hadithdefcmd{abudawud}{354}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ يَوْمَ الْجُمُعَةِ فَبِهَا وَنِعْمَتْ وَمَنِ اغْتَسَلَ فَهُوَ أَفْضَلُ ‏"‏ ‏.‏\hadithno{354}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Samurah: If any one of you performs ablution (on Friday) that is all right; and if any of you takes a bath, that is better}}
\hadithdefcmd{abudawud}{355}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ الْعَبْدِيُّ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا الأَغَرُّ، عَنْ خَلِيفَةَ بْنِ حُصَيْنٍ، عَنْ جَدِّهِ، قَيْسِ بْنِ عَاصِمٍ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم أُرِيدُ الإِسْلاَمَ فَأَمَرَنِي أَنْ أَغْتَسِلَ بِمَاءٍ وَسِدْرٍ ‏.‏\hadithno{355}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Qays ibn Asim: I came to the Prophet (ﷺ) with the intention of embracing Islam. He commanded me to take a bath with water (boiled with) the leaves of the lote-tree}}
\hadithdefcmd{abudawud}{356}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أُخْبِرْتُ عَنْ عُثَيْمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ قَدْ أَسْلَمْتُ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلْقِ عَنْكَ شَعْرَ الْكُفْرِ ‏"‏ ‏.‏ يَقُولُ احْلِقْ ‏.‏ قَالَ وَأَخْبَرَنِي آخَرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لآخَرَ مَعَهُ ‏"‏ أَلْقِ عَنْكَ شَعْرَ الْكُفْرِ وَاخْتَتِنْ ‏"‏ ‏.‏\hadithno{356}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Uthaim b. Kulaib reported from his father (Kuthair) on the authority of his grandfather (Kulaib) that he came to the Prophet (ﷺ):I have embraced Islam. The Prophet (ﷺ) said to him: Remove from yourself the hair that grew during of unbelief, saying "shave them". He further says that another person (other than the grandfather of 'Uthaim) reported to him that the Prophet (ﷺ) said to another person who accompanied him: Remove from yourself the hair that grew during the period of unbelief and get yourself circumcised}}
\hadithdefcmd{abudawud}{357}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنِي أَبِي، حَدَّثَتْنِي أُمُّ الْحَسَنِ، - يَعْنِي جَدَّةَ أَبِي بَكْرٍ الْعَدَوِيِّ - عَنْ مُعَاذَةَ، قَالَتْ سَأَلْتُ عَائِشَةَ - رضى الله عنها - عَنِ الْحَائِضِ يُصِيبُ ثَوْبَهَا الدَّمُ ‏.‏ قَالَتْ تَغْسِلُهُ فَإِنْ لَمْ يَذْهَبْ أَثَرُهُ فَلْتُغَيِّرْهُ بِشَىْءٍ مِنَ صُفْرَةٍ ‏.‏ قَالَتْ وَلَقَدْ كُنْتُ أَحِيضُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثَلاَثَ حِيَضٍ جَمِيعًا لاَ أَغْسِلُ لِي ثَوْبًا ‏.‏\hadithno{357}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Mu'adhah said that 'Aishah was asked about (washing) the clothes of a menstruating woman smeared with blood. She said:She should wash it; in case mark is not removed she should change it by applying some yellow color. I had three menstruations together while I lives with the Messenger of Allah (ﷺ), but I did not wash my clothes}}
\hadithdefcmd{abudawud}{358}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ الْعَبْدِيُّ، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، قَالَ سَمِعْتُ الْحَسَنَ، - يَعْنِي ابْنَ مُسْلِمٍ - يَذْكُرُ عَنْ مُجَاهِدٍ، قَالَ قَالَتْ عَائِشَةُ مَا كَانَ لإِحْدَانَا إِلاَّ ثَوْبٌ وَاحِدٌ تَحِيضُ فِيهِ فَإِنْ أَصَابَهُ شَىْءٌ مِنْ دَمٍ بَلَّتْهُ بِرِيقِهَا ثُمَّ قَصَعَتْهُ بِرِيقِهَا ‏.‏\hadithno{358}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah said:Each of us (wives of the Prophet) had only one clothe in which she would menstruate. Whenever it was smeared with blood, she would moisten it with her saliva and scratch it with saliva}}
\hadithdefcmd{abudawud}{359}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا بَكَّارُ بْنُ يَحْيَى، حَدَّثَتْنِي جَدَّتِي، قَالَتْ دَخَلْتُ عَلَى أُمِّ سَلَمَةَ فَسَأَلَتْهَا امْرَأَةٌ مِنْ قُرَيْشٍ عَنِ الصَّلاَةِ فِي ثَوْبِ الْحَائِضِ فَقَالَتْ أُمُّ سَلَمَةَ قَدْ كَانَ يُصِيبُنَا الْحَيْضُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَلْبَثُ إِحْدَانَا أَيَّامَ حَيْضِهَا ثُمَّ تَطْهُرُ فَتَنْظُرُ الثَّوْبَ الَّذِي كَانَتْ تَقْلِبُ فِيهِ فَإِنْ أَصَابَهُ دَمٌ غَسَلْنَاهُ وَصَلَّيْنَا فِيهِ وَإِنْ لَمْ يَكُنْ أَصَابَهُ شَىْءٌ تَرَكْنَاهُ وَلَمْ يَمْنَعْنَا ذَلِكَ مِنْ أَنْ نُصَلِّيَ فِيهِ وَأَمَّا الْمُمْتَشِطَةُ فَكَانَتْ إِحْدَانَا تَكُونُ مُمْتَشِطَةً فَإِذَا اغْتَسَلَتْ لَمْ تَنْقُضْ ذَلِكَ وَلَكِنَّهَا تَحْفِنُ عَلَى رَأْسِهَا ثَلاَثَ حَفَنَاتٍ فَإِذَا رَأَتِ الْبَلَلَ فِي أُصُولِ الشَّعْرِ دَلَكَتْهُ ثُمَّ أَفَاضَتْ عَلَى سَائِرِ جَسَدِهَا ‏.‏\hadithno{359}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Bakkar ibn Yahya said that his grandmother narrated to him: I entered upon Umm Salamah. A woman from the Quraysh asked her about praying with the clothes which a woman wore while she menstruated. Umm Salamah said: We would menstruate in the lifetime of the Messenger of Allah (ﷺ). Then each one of us refrained (from prayer) during menstrual period. When she was purified, she would look at the clothe in which she menstruated. If it were smeared with blood, we would wash it and pray with it; if there were nothing in it, we would leave it and that would not prevent us from praying with it (the same clothe). As regards the woman who had plaited hair - sometimes each of us had plaited hair - when she washed, she would not undo the hair. She would instead pour three handfuls of water upon her head. When she felt moisture in the roots of her hair, she would rub them. Then she would pour water upon her whole body}}
\hadithdefcmd{abudawud}{360}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ سَمِعْتُ امْرَأَةً، تَسْأَلُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَيْفَ تَصْنَعُ إِحْدَانَا بِثَوْبِهَا إِذَا رَأَتِ الطُّهْرَ أَتُصَلِّي فِيهِ قَالَ ‏ "‏ تَنْظُرُ فَإِنْ رَأَتْ فِيهِ دَمًا فَلْتَقْرُصْهُ بِشَىْءٍ مِنْ مَاءٍ وَلْتَنْضَحْ مَا لَمْ تَرَ وَلْتُصَلِّ فِيهِ ‏"‏ ‏.‏\hadithno{360}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asma' daughter of Abu Bakr said:I heard a woman asking the Messenger of Allah (ﷺ): What should any of us to with her clothe (in which she menstruated) when she becomes purified ? Can she pray in that (clothe) ? He said: She should see; if she finds blood in it, she should scratch it with some water and (in case of doubt) sprinkle upon it (some water) and pray so long as she does not find (any blood)}}
\hadithdefcmd{abudawud}{361}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا قَالَتْ سَأَلَتِ امْرَأَةٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِحْدَانَا إِذَا أَصَابَ ثَوْبَهَا الدَّمُ مِنَ الْحَيْضَةِ كَيْفَ تَصْنَعُ قَالَ ‏ "‏ إِذَا أَصَابَ إِحْدَاكُنَّ الدَّمُ مِنَ الْحَيْضِ فَلْتَقْرِصْهُ ثُمَّ لْتَنْضَحْهُ بِالْمَاءِ ثُمَّ لْتُصَلِّي ‏"‏ ‏.‏\hadithno{361}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (307) Sahih Muslim (291)}\hadithtrans{Asma' daughter of Abu Bakr said:A woman asked the Messenger of Allah (ﷺ): Messenger of Allah, what do you think if the clothe of any of us smeared with the blood of menstruation; what should she do ? He said: If (the clothe of) any of you is smeared with blood of menstruation, she should scratch it; then she should sprinkle water upon it and then she may pray}}
\hadithdefcmd{abudawud}{362}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ هِشَامٍ، بِهَذَا الْمَعْنَى قَالَ ‏ "‏ حُتِّيهِ ثُمَّ اقْرُصِيهِ بِالْمَاءِ ثُمَّ انْضَحِيهِ ‏"‏ ‏.‏\hadithno{362}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{This tradition has been transmitted by Hisham through a different chain of narrators to the same effect:Rub it off (with a stone), and then scratch it (with finger) by pouring water, then sprinkle water upon it}}
\hadithdefcmd{abudawud}{363}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ الْقَطَّانَ - عَنْ سُفْيَانَ، حَدَّثَنِي ثَابِتٌ الْحَدَّادُ، حَدَّثَنِي عَدِيُّ بْنُ دِينَارٍ، قَالَ سَمِعْتُ أُمَّ قَيْسٍ بِنْتَ مِحْصَنٍ، تَقُولُ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنْ دَمِ الْحَيْضِ يَكُونُ فِي الثَّوْبِ قَالَ ‏ "‏ حُكِّيهِ بِضِلْعٍ وَاغْسِلِيهِ بِمَاءٍ وَسِدْرٍ ‏"‏ ‏.‏\hadithno{363}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umm Qays daughter of Mihsan: I asked the Prophet (ﷺ) about the blood of menstruation on the clothe. He said: Erase it off with a piece of wood and then wash it away with water and the leaves of the lote-tree}}
\hadithdefcmd{abudawud}{364}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، قَالَتْ قَدْ كَانَ يَكُونُ لإِحْدَانَا الدِّرْعُ فِيهِ تَحِيضُ وَفِيهِ تُصِيبُهَا الْجَنَابَةُ ثُمَّ تَرَى فِيهِ قَطْرَةً مِنْ دَمٍ فَتَقْصَعُهُ بِرِيقِهَا ‏.‏\hadithno{364}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah said:One of us would have a shirt in which she would menstruate and in it she became sexually defiled. Then if she ever saw any drop of blood in it, she would rub it off by applying her saliva}}
\hadithdefcmd{abudawud}{365}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَخْبَرَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ خَوْلَةَ بِنْتَ يَسَارٍ، أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّهُ لَيْسَ لِي إِلاَّ ثَوْبٌ وَاحِدٌ وَأَنَا أَحِيضُ فِيهِ فَكَيْفَ أَصْنَعُ قَالَ ‏"‏ إِذَا طَهُرْتِ فَاغْسِلِيهِ ثُمَّ صَلِّي فِيهِ ‏"‏ ‏.‏ فَقَالَتْ فَإِنْ لَمْ يَخْرُجِ الدَّمُ قَالَ ‏"‏ يَكْفِيكِ غَسْلُ الدَّمِ وَلاَ يَضُرُّكِ أَثَرُهُ ‏"‏ ‏.‏\hadithno{365}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah reported that Khawlah daughter of Yasar came to the Prophet (ﷺ) and said:Messenger of Allah, I have only one clothe and I menstruate in it, how should I do ? He said: When you are purified, wash it and pray in it. She asked: If the blood is not removed, (then what) ? He said: It is enough for you to wash the blood, its mark will not do any harm to you}}
\hadithdefcmd{abudawud}{366}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، عَنْ مُعَاوِيَةَ بْنِ حُدَيْجٍ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، أَنَّهُ سَأَلَ أُخْتَهُ أُمَّ حَبِيبَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي الثَّوْبِ الَّذِي يُجَامِعُهَا فِيهِ فَقَالَتْ نَعَمْ إِذَا لَمْ يَرَ فِيهِ أَذًى ‏.‏\hadithno{366}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umm Habibah: Mu'awiyah ibn AbuSufyan asked his sister Umm Habibah, the wife of the Prophet (ﷺ): Would the apostle of Allah (ﷺ) pray in the clothe in which he had an intercourse? She said: Yes, when he would not see any impurity in it}}
\hadithdefcmd{abudawud}{367}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَشْعَثُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُصَلِّي فِي شُعُرِنَا أَوْ فِي لُحُفِنَا ‏.‏ قَالَ عُبَيْدُ اللَّهِ شَكَّ أَبِي ‏.‏\hadithno{367}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) would not pray in our wrappers or in our quilts. Ubaydullah said: My father (Mu'adh) doubted this}}
\hadithdefcmd{abudawud}{368}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يُصَلِّي فِي مَلاَحِفِنَا ‏.‏ قَالَ حَمَّادٌ وَسَمِعْتُ سَعِيدَ بْنَ أَبِي صَدَقَةَ قَالَ سَأَلْتُ مُحَمَّدًا عَنْهُ فَلَمْ يُحَدِّثْنِي وَقَالَ سَمِعْتُهُ مُنْذُ زَمَانٍ وَلاَ أَدْرِي مِمَّنْ سَمِعْتُهُ وَلاَ أَدْرِي أَسَمِعْتُهُ مِنْ ثَبَتٍ أَوْ لاَ فَسَلُوا عَنْهُ ‏.‏\hadithno{368}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said:The Prophet (ﷺ) would not in our quilts. Hammad said: I heard Sa'id b. Abi Sadaqah say: I asked Muhammad (b. Sirin) about it. He did not narrate it to me, but said: I heard it a long time ago and I do not know whom I heard it. I do not know whether I heard it from a trustworthy person or not. Make an inquiry about it}}
\hadithdefcmd{abudawud}{369}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، سَمِعَهُ مِنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، يُحَدِّثُهُ عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى وَعَلَيْهِ مِرْطٌ وَعَلَى بَعْضِ أَزْوَاجِهِ مِنْهُ وَهِيَ حَائِضٌ وَهُوَ يُصَلِّي وَهُوَ عَلَيْهِ ‏.‏\hadithno{369}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Maimunah reported:The Prophet (ﷺ) prayed on a sheet of cloth put on by one of his wives who was menstruating. He was praying while (a part of) it was upon him}}
\hadithdefcmd{abudawud}{370}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِاللَّيْلِ وَأَنَا إِلَى جَنْبِهِ وَأَنَا حَائِضٌ وَعَلَىَّ مِرْطٌ لِي وَعَلَيْهِ بَعْضُهُ ‏.‏\hadithno{370}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (514)}\hadithtrans{Aishah said:The Messenger of Allah (ﷺ) would pray at night while I lay by his side during my menstrual period. A sheet of cloth would be partly on me and partly on him}}
\hadithdefcmd{abudawud}{371}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، أَنَّهُ كَانَ عِنْدَ عَائِشَةَ - رضى الله عنها - فَاحْتَلَمَ فَأَبْصَرَتْهُ جَارِيَةٌ لِعَائِشَةَ وَهُوَ يَغْسِلُ أَثَرَ الْجَنَابَةِ مِنْ ثَوْبِهِ أَوْ يَغْسِلُ ثَوْبَهُ فَأَخْبَرَتْ عَائِشَةَ فَقَالَتْ لَقَدْ رَأَيْتُنِي وَأَنَا أَفْرُكُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الأَعْمَشُ كَمَا رَوَاهُ الْحَكَمُ ‏.‏\hadithno{371}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (288)}\hadithtrans{Hammam b. al-Harith reported, he has a sexual dream when he was staying with 'Aishah. The slave girl of 'Aishah saw him while he was washing the mark of defilement, or he was washing his clothe. She informed 'Aishah who said:He witnessed me rubbing off the semen from the clothe of the Messenger of Allah (ﷺ). Abu Dawud said: Al-A'mash narrated it as narrated by al-Hakam}}
\hadithdefcmd{abudawud}{372}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حَمَّادِ بْنِ أَبِي سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْرُكُ الْمَنِيَّ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيُصَلِّي فِيهِ ‏.‏ قَالَ أَبُو دَاوُدَ وَافَقَهُ مُغِيرَةُ وَأَبُو مَعْشَرٍ وَوَاصِلٌ ‏.‏\hadithno{372}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (288)}\hadithtrans{Aishah reported:I used to rub off the semen from the clothe of the Messenger of Allah (ﷺ). He would would pray in it. Abu Dawud said: Mughirah, Abu Ma'shar, and Wasil also narrated it to the same effect}}
\hadithdefcmd{abudawud}{373}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، ح حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ حِسَابٍ الْبَصْرِيُّ، حَدَّثَنَا سُلَيْمٌ، - يَعْنِي ابْنَ أَخْضَرَ الْمَعْنَى وَالإِخْبَارُ فِي حَدِيثِ سُلَيْمٍ - قَالاَ حَدَّثَنَا عَمْرُو بْنُ مَيْمُونِ بْنِ مِهْرَانَ سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ يَقُولُ سَمِعْتُ عَائِشَةَ تَقُولُ إِنَّهَا كَانَتْ تَغْسِلُ الْمَنِيَّ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ ثُمَّ أَرَى فِيهِ بُقْعَةً أَوْ بُقَعًا ‏.‏\hadithno{373}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (229) Sahih Muslim (289)}\hadithtrans{Sulaiman b. Yasar reported:I heard 'Aishah say that she would wash semen from the clothe of the Messenger of Allah (ﷺ). She added: Then I would see a mark or marks (after washing)}}
\hadithdefcmd{abudawud}{374}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، أَنَّهَا أَتَتْ بِابْنٍ لَهَا صَغِيرٍ لَمْ يَأْكُلِ الطَّعَامَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَجْلَسَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حِجْرِهِ فَبَالَ عَلَى ثَوْبِهِ فَدَعَا بِمَاءٍ فَنَضَحَهُ وَلَمْ يَغْسِلْهُ ‏.‏\hadithno{374}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (223) Sahih Muslim (287)}\hadithtrans{Umm Qais daughter of Mihsan reported that she came to the Messenger of Allah (ﷺ) with her little son who had not attained the age of eating food. The Messenger of Allah (ﷺ) seated him in his lap, and he urinated on his clothe. He sent for water and sprayed it (over his clothe) and did not wash it}}
\hadithdefcmd{abudawud}{375}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، وَالرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ قَابُوسَ، عَنْ لُبَابَةَ بِنْتِ الْحَارِثِ، قَالَتْ كَانَ الْحُسَيْنُ بْنُ عَلِيٍّ - رضى الله عنه - فِي حِجْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَالَ عَلَيْهِ فَقُلْتُ الْبَسْ ثَوْبًا وَأَعْطِنِي إِزَارَكَ حَتَّى أَغْسِلَهُ قَالَ ‏ "‏ إِنَّمَا يُغْسَلُ مِنْ بَوْلِ الأُنْثَى وَيُنْضَحُ مِنْ بَوْلِ الذَّكَرِ ‏"‏ ‏.‏\hadithno{375}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Lubabah daughter of al-Harith: Al-Husayn ibn Ali was (sitting) in the lap of the Messenger of Allah (ﷺ). He passed water on him. I said: Put on (another) clothe, and give me your wrapper to wash. He said: The urine of a female child should be washed (thoroughly) and the urine of a male child should be sprinkled over}}
\hadithdefcmd{abudawud}{376}{حَدَّثَنَا مُجَاهِدُ بْنُ مُوسَى، وَعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنِي يَحْيَى بْنُ الْوَلِيدِ، حَدَّثَنِي مُحِلُّ بْنُ خَلِيفَةَ، حَدَّثَنِي أَبُو السَّمْحِ، قَالَ كُنْتُ أَخْدُمُ النَّبِيَّ صلى الله عليه وسلم فَكَانَ إِذَا أَرَادَ أَنْ يَغْتَسِلَ قَالَ ‏"‏ وَلِّنِي قَفَاكَ ‏"‏ ‏.‏ فَأُوَلِّيهِ قَفَاىَ فَأَسْتُرُهُ بِهِ فَأُتِيَ بِحَسَنٍ أَوْ حُسَيْنٍ - رضى الله عنهما - فَبَالَ عَلَى صَدْرِهِ فَجِئْتُ أَغْسِلُهُ فَقَالَ ‏"‏ يُغْسَلُ مِنْ بَوْلِ الْجَارِيَةِ وَيُرَشُّ مِنْ بَوْلِ الْغُلاَمِ ‏"‏ ‏.‏ قَالَ عَبَّاسٌ حَدَّثَنَا يَحْيَى بْنُ الْوَلِيدِ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ أَبُو الزَّعْرَاءِ ‏.‏ قَالَ هَارُونُ بْنُ تَمِيمٍ عَنِ الْحَسَنِ قَالَ الأَبْوَالُ كُلُّهَا سَوَاءٌ ‏.‏\hadithno{376}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbusSamh: I used to serve the Prophet (ﷺ). Whenever he intended to wash himself, he would say: Turn your back towards me, So I would turn my back and hide him. (Once) Hasan or Husayn (may Allah be pleased with them) was brought to him and he passed water on his chest. I came to wash it. He said: It is only the urine of a female which should be washed; the urine of a male should be sprinkled over. 'Abbas (a narrator) said: Yahya b. al-Walid narrated the tradition to us. Abu Dawud said: He (Yahya) is Abu al-Za'ra'. Harun b. Tamim said on the authority of al-Hasan: All sorts of urine are equal}}
\hadithdefcmd{abudawud}{377}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي حَرْبِ بْنِ أَبِي الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ يُغْسَلُ مِنْ بَوْلِ الْجَارِيَةِ وَيُنْضَحُ مِنْ بَوْلِ الْغُلاَمِ مَا لَمْ يَطْعَمْ ‏.‏\hadithno{377}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The urine of a female (child) should be washed and the urine of a male (child) should be sprinkled over until the age of eating}}
\hadithdefcmd{abudawud}{378}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي حَرْبِ بْنِ أَبِي الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، - رضى الله عنه - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ فَذَكَرَ مَعْنَاهُ وَلَمْ يَذْكُرْ ‏ "‏ مَا لَمْ يَطْعَمْ ‏"‏ ‏.‏ زَادَ قَالَ قَتَادَةُ هَذَا مَا لَمْ يَطْعَمَا الطَّعَامَ فَإِذَا طَعِمَا غُسِلاَ جَمِيعًا ‏.‏\hadithno{378}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ali b. Abi Talib reported the Prophet (ﷺ) as saying:He narrated the tradition to the same effect, but he did not mention the words "until the age of eating". This version adds: Qatadah said: This is valid until the time they do not eat food; when they begin to eat, their urine should be washed}}
\hadithdefcmd{abudawud}{379}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ أَبِي الْحَجَّاجِ أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أُمِّهِ، أَنَّهَا أَبْصَرَتْ أُمَّ سَلَمَةَ تَصُبُّ الْمَاءَ عَلَى بَوْلِ الْغُلاَمِ مَا لَمْ يَطْعَمْ فَإِذَا طَعِمَ غَسَلَتْهُ وَكَانَتْ تَغْسِلُ بَوْلَ الْجَارِيَةِ ‏.‏\hadithno{379}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Al-Hasan reported on the authority of his mother that she was Umm Salamah pouring water on the urine of the male child until the age when he did not eat food. When he began to eat food, she would wash (his urine). And she would wash the urine of the female child}}
\hadithdefcmd{abudawud}{380}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَابْنُ، عَبْدَةَ - فِي آخَرِينَ وَهَذَا لَفْظُ ابْنِ عَبْدَةَ - أَخْبَرَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ أَعْرَابِيًّا، دَخَلَ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ فَصَلَّى - قَالَ ابْنُ عَبْدَةَ - رَكْعَتَيْنِ ثُمَّ قَالَ اللَّهُمَّ ارْحَمْنِي وَمُحَمَّدًا وَلاَ تَرْحَمْ مَعَنَا أَحَدًا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدْ تَحَجَّرْتَ وَاسِعًا ‏"‏ ‏.‏ ثُمَّ لَمْ يَلْبَثْ أَنْ بَالَ فِي نَاحِيةِ الْمَسْجِدِ فَأَسْرَعَ النَّاسُ إِلَيْهِ فَنَهَاهُمُ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏"‏ إِنَّمَا بُعِثْتُمْ مُيَسِّرِينَ وَلَمْ تُبْعَثُوا مُعَسِّرِينَ صُبُّوا عَلَيْهِ سَجْلاً مِنْ مَاءٍ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ ذَنُوبًا مِنْ مَاءٍ ‏"‏ ‏.‏\hadithno{380}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported:A bedouin entered the	mosque while the Messenger of Allah (ﷺ) was sitting. He offered two rak'ahs of prayer, according to the version of Ibn 'Abdah. He then said: O Allah, have mercy on me and on Muhammad and do not have mercy on anyone along with us. The Prophet (ﷺ) said: You have narrowed down (a thing) that was broader. After a short while he passed a water in the corner of the mosque. The people rushed towards him. The Prophet (ﷺ) prevented them and said: You have been sent to facilitate and not create difficulties. Pour a bucket of water upon it}}
\hadithdefcmd{abudawud}{381}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - قَالَ سَمِعْتُ عَبْدَ الْمَلِكِ، - يَعْنِي ابْنَ عُمَيْرٍ - يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ مَعْقِلِ بْنِ مُقَرِّنٍ، قَالَ صَلَّى أَعْرَابِيٌّ مَعَ النَّبِيِّ صلى الله عليه وسلم بِهَذِهِ الْقِصَّةِ قَالَ فِيهِ وَقَالَ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏ "‏ خُذُوا مَا بَالَ عَلَيْهِ مِنَ التُّرَابِ فَأَلْقُوهُ وَأَهْرِيقُوا عَلَى مَكَانِهِ مَاءً ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ مُرْسَلٌ ابْنُ مَعْقِلٍ لَمْ يُدْرِكِ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{381}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Ma'qil ibn Muqarrin: A bedouin prayed with the Prophet (ﷺ). He then narrated the tradition (No 0380) about urinating of that bedouin. This version adds: The Prophet (ﷺ) said: Remove the earth where he urinated and throw it away and pour water upon the place. Abu Dawud said: This is a mursal tradition (i.e. the narrator quotes the Prophet (ﷺ) directly, although he did not see him). Ibn Ma'qil did not see the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{382}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي حَمْزَةُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ ابْنُ عُمَرَ كُنْتُ أَبِيتُ فِي الْمَسْجِدِ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكُنْتُ فَتًى شَابًّا عَزَبًا وَكَانَتِ الْكِلاَبُ تَبُولُ وَتُقْبِلُ وَتُدْبِرُ فِي الْمَسْجِدِ فَلَمْ يَكُونُوا يَرُشُّونَ شَيْئًا مِنْ ذَلِكَ ‏.‏\hadithno{382}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (174)}\hadithtrans{Ibn 'Umar said:I used to sleep in the mosque in the lifetime of the Messenger of Allah (ﷺ) when I was young and bachelor. The dogs would urinate frequently visit the mosque, and no one would sprinkle over it}}
\hadithdefcmd{abudawud}{383}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عُمَارَةَ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أُمِّ وَلَدٍ، لإِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهَا سَأَلَتْ أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنِّي امْرَأَةٌ أُطِيلُ ذَيْلِي وَأَمْشِي فِي الْمَكَانِ الْقَذِرِ ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُطَهِّرُهُ مَا بَعْدَهُ ‏"‏ ‏.‏\hadithno{383}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The slave-mother of Ibrahim ibn AbdurRahman ibn Awf asked Umm Salamah, the wife of the Prophet (ﷺ): I am a woman having a long border of clothe and I walk in filthy place; (then what should I do?). Umm Salamah replied: The Messenger of Allah ( peace be upon him) said: What comes after it cleanses it}}
\hadithdefcmd{abudawud}{384}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، وَأَحْمَدُ بْنُ يُونُسَ، قَالاَ حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عِيسَى، عَنْ مُوسَى بْنِ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنِ امْرَأَةٍ، مِنْ بَنِي عَبْدِ الأَشْهَلِ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لَنَا طَرِيقًا إِلَى الْمَسْجِدِ مُنْتِنَةً فَكَيْفَ نَفْعَلُ إِذَا مُطِرْنَا قَالَ ‏"‏ أَلَيْسَ بَعْدَهَا طَرِيقٌ هِيَ أَطْيَبُ مِنْهَا ‏"‏ ‏.‏ قَالَتْ قُلْتُ بَلَى ‏.‏ قَالَ ‏"‏ فَهَذِهِ بِهَذِهِ ‏"‏ ‏.‏\hadithno{384}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated A woman of the Banu AbdulAshhal: She reported: I said Messenger of Allah, our road to the mosque has an unpleasant stench; what should we do when it is raining? He asked: Is there not a cleaner part after the filthy part of the road? She replied: Why not (there is one)! He said: It makes up for the other}}
\hadithdefcmd{abudawud}{385}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، ح وَحَدَّثَنَا عَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدٍ، أَخْبَرَنِي أَبِي ح، وَحَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا عُمَرُ، - يَعْنِي ابْنَ عَبْدِ الْوَاحِدِ - عَنِ الأَوْزَاعِيِّ، - الْمَعْنَى - قَالَ أُنْبِئْتُ أَنَّ سَعِيدَ بْنَ أَبِي سَعِيدٍ الْمَقْبُرِيَّ، حَدَّثَ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَطِئَ أَحَدُكُمْ بِنَعْلَيْهِ الأَذَى فَإِنَّ التُّرَابَ لَهُ طَهُورٌ ‏"‏ ‏.‏\hadithno{385}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah reported:The Messenger of Allah (ﷺ) said: When any one of you treads with his sandal upon an unclean place, the earth will render it purified}}
\hadithdefcmd{abudawud}{386}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي مُحَمَّدُ بْنُ كَثِيرٍ، - يَعْنِي الصَّنْعَانِيَّ - عَنِ الأَوْزَاعِيِّ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ ‏ "‏ إِذَا وَطِئَ الأَذَى بِخُفَّيْهِ فَطَهُورُهُمَا التُّرَابُ ‏"‏ ‏.‏\hadithno{386}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah reported the tradition to the same effect from the Prophet (ﷺ):When any of you treads with his shoes upon something unclean, they will be purified with the earth}}
\hadithdefcmd{abudawud}{387}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ عَائِذٍ - حَدَّثَنِي يَحْيَى، - يَعْنِي ابْنَ حَمْزَةَ - عَنِ الأَوْزَاعِيِّ، عَنْ مُحَمَّدِ بْنِ الْوَلِيدِ، أَخْبَرَنِي أَيْضًا، سَعِيدُ بْنُ أَبِي سَعِيدٍ عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏\hadithno{387}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah reported a similar tradition from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{388}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَتْنَا أُمُّ يُونُسَ بِنْتُ شَدَّادٍ، قَالَتْ حَدَّثَتْنِي حَمَاتِي أُمُّ جَحْدَرٍ الْعَامِرِيَّةُ، أَنَّهَا سَأَلَتْ عَائِشَةَ عَنْ دَمِ الْحَيْضِ يُصِيبُ الثَّوْبَ فَقَالَتْ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْنَا شِعَارُنَا وَقَدْ أَلْقَيْنَا فَوْقَهُ كِسَاءً فَلَمَّا أَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَخَذَ الْكِسَاءَ فَلَبِسَهُ ثُمَّ خَرَجَ فَصَلَّى الْغَدَاةَ ثُمَّ جَلَسَ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ هَذِهِ لُمْعَةٌ مِنْ دَمٍ ‏.‏ فَقَبَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى مَا يَلِيهَا فَبَعَثَ بِهَا إِلَىَّ مَصْرُورَةً فِي يَدِ الْغُلاَمِ فَقَالَ ‏ "‏ اغْسِلِي هَذِهِ وَأَجِفِّيهَا ثُمَّ أَرْسِلِي بِهَا إِلَىَّ ‏"‏ ‏.‏ فَدَعَوْتُ بِقَصْعَتِي فَغَسَلْتُهَا ثُمَّ أَجْفَفْتُهَا فَأَحَرْتُهَا إِلَيْهِ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِنِصْفِ النَّهَارِ وَهِيَ عَلَيْهِ ‏.‏\hadithno{388}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umm Jahdar al-'Amiriyyah said that she asked 'Aishah about the blood of menses which drops on the clothe. She replied:I was (lying) with the Messenger of Allah (ﷺ) and we had our garment over us, and we had put a blanket over it. When the day broke, the Messenger of Allah (ﷺ) took the blanket, wore it and went out and offered the dawn prayer. He then sat (in the mosque among the people). A man said: Messenger of Allah, this is a spot of blood. The Messenger of Allah (ﷺ) caught hold of it from around and sent it to me folded in the hand of a slave and said: Wash it and dry it and then send it to me. I sent for my vessel and washed it. I then dried it and returned it to him. The Messenger of Allah (ﷺ) came at noon while he had the blanket over him}}
\hadithdefcmd{abudawud}{389}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَبِي نَضْرَةَ، قَالَ بَزَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَوْبِهِ وَحَكَّ بَعْضَهُ بِبَعْضٍ ‏.‏\hadithno{389}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuNadrah: The Messenger of Allah (ﷺ) spat on his clothe and scrubbed with a part of it}}
\hadithdefcmd{abudawud}{390}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{390}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (241)}\hadithtrans{A similar tradition has also been narrated by Anas from the Prophet (ﷺ) through a different chain of narrators}}
