% Auto-generated chapter 77 for bukhari
% Hadiths in this chapter: 185

\hadithdefcmd{bukhari}{5783}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، وَزَيْدِ بْنِ أَسْلَمَ، يُخْبِرُونَهُ عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْظُرُ اللَّهُ إِلَى مَنْ جَرَّ ثَوْبَهُ خُيَلاَءَ ‏"‏‏.‏\hadithno{5783}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, 'Allah will not look at the person who drags his garment (behind him) out of conceit}}
\hadithdefcmd{bukhari}{5784}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ جَرَّ ثَوْبَهُ خُيَلاَءَ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ إِنَّ أَحَدَ شِقَّىْ إِزَارِي يَسْتَرْخِي، إِلاَّ أَنْ أَتَعَاهَدَ ذَلِكَ مِنْهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَسْتَ مِمَّنْ يَصْنَعُهُ خُيَلاَءَ ‏"‏‏.‏\hadithno{5784}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said Allah will not look, on the Day of Resurrection at the person who drags his garment (behind him) out of conceit. On that Abu Bakr said, "O Allah's Messenger (ﷺ)! One side of my Izar hangs low if I do not take care of it." The Prophet (ﷺ) said, 'You are not one of those who do that out of conceit}}
\hadithdefcmd{bukhari}{5785}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ الأَعْلَى، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ ـ رضى الله عنه ـ قَالَ خَسَفَتِ الشَّمْسُ وَنَحْنُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَامَ يَجُرُّ ثَوْبَهُ مُسْتَعْجِلاً، حَتَّى أَتَى الْمَسْجِدَ وَثَابَ النَّاسُ فَصَلَّى رَكْعَتَيْنِ، فَجُلِّيَ عَنْهَا، ثُمَّ أَقْبَلَ عَلَيْنَا وَقَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ، فَإِذَا رَأَيْتُمْ مِنْهَا شَيْئًا فَصَلُّوا وَادْعُوا اللَّهَ حَتَّى يَكْشِفَهَا ‏"‏‏.‏\hadithno{5785}\hadithtrans{Narrated Abu Bakra:The solar eclipse occurred while we were sitting with the Prophet (ﷺ) He got up dragging his garment (on the ground) hurriedly till he reached the mosque The people turned (to the mosque) and he offered a two-rak`at prayer whereupon the eclipse was over and he traced us and said, "The sun and the moon are two signs among the signs of Allah, so if you see a thing like this (eclipse) then offer the prayer and invoke Allah till He remove that state}}
\hadithdefcmd{bukhari}{5786}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا ابْنُ شُمَيْلٍ، أَخْبَرَنَا عُمَرُ بْنُ أَبِي زَائِدَةَ، أَخْبَرَنَا عَوْنُ بْنُ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ أَبِي جُحَيْفَةَ، قَالَ فَرَأَيْتُ بِلاَلاً جَاءَ بِعَنَزَةٍ فَرَكَزَهَا، ثُمَّ أَقَامَ الصَّلاَةَ، فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ فِي حُلَّةٍ مُشَمِّرًا، فَصَلَّى رَكْعَتَيْنِ إِلَى الْعَنَزَةِ، وَرَأَيْتُ النَّاسَ وَالدَّوَابَّ يَمُرُّونَ بَيْنَ يَدَيْهِ مِنْ وَرَاءِ الْعَنَزَةِ‏.‏\hadithno{5786}\hadithtrans{Narrated Abu Juhaifa:I saw Bilal bringing a short spear (or stick) and fixing it in the ground, and then he proclaimed the Iqama of the prayer, and I saw Allah's Messenger (ﷺ) coming out, wearing a cloak with its sleeves rolled up. He then offered a two-rak`at prayer while facing the stick, and I saw the people and animals passing in front of him beyond the stick}}
\hadithdefcmd{bukhari}{5787}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَسْفَلَ مِنَ الْكَعْبَيْنِ مِنَ الإِزَارِ فَفِي النَّارِ ‏"‏‏.‏\hadithno{5787}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The part of an Izar which hangs below the ankles is in the Fire}}
\hadithdefcmd{bukhari}{5788}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْظُرُ اللَّهُ يَوْمَ الْقِيَامَةِ إِلَى مَنْ جَرَّ إِزَارَهُ بَطَرًا ‏"‏‏.‏\hadithno{5788}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ), "Allah will not look, on the Day of Resurrection, at a person who drags his Izar (behind him) out of pride and arrogance}}
\hadithdefcmd{bukhari}{5789}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ النَّبِيُّ ـ أَوْ قَالَ أَبُو الْقَاسِمِ ـ صلى الله عليه وسلم ‏ "‏ بَيْنَمَا رَجُلٌ يَمْشِي فِي حُلَّةٍ، تُعْجِبُهُ نَفْسُهُ مُرَجِّلٌ جُمَّتَهُ، إِذْ خَسَفَ اللَّهُ بِهِ، فَهْوَ يَتَجَلَّلُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏\hadithno{5789}\hadithtrans{Narrated Abu Huraira:The Prophet (or 'Abul Qasim) said, "While a man was walking, clad in a two-piece garment and proud of himself with his hair well-combed, suddenly Allah made him sink into the earth and he will go on sinking into it till the Day of Resurrection}}
\hadithdefcmd{bukhari}{5790}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَا رَجُلٌ يَجُرُّ إِزَارَهُ، خُسِفَ بِهِ، فَهْوَ يَتَجَلَّلُ فِي الأَرْضِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏ تَابَعَهُ يُونُسُ عَنِ الزُّهْرِيِّ‏.‏ وَلَمْ يَرْفَعْهُ شُعَيْبٌ عَنِ الزُّهْرِيِّ‏.‏ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، أَخْبَرَنَا أَبِي، عَنْ عَمِّهِ، جَرِيرِ بْنِ زَيْدٍ قَالَ كُنْتُ مَعَ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ عَلَى باب دَارِهِ فَقَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم نَحْوَهُ‏.‏\hadithno{5790}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "While a man was dragging his Izar on the ground (behind him), suddenly Allah made him sink into the earth and he will go on sinking into it till the Day of Resurrection." Narrated Abu Huraira: that he heard the Prophet (narrating as above No)}}
\hadithdefcmd{bukhari}{5791}{حَدَّثَنَا مَطَرُ بْنُ الْفَضْلِ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، قَالَ لَقِيتُ مُحَارِبَ بْنَ دِثَارٍ عَلَى فَرَسٍ وَهْوَ يَأْتِي مَكَانَهُ الَّذِي يَقْضِي فِيهِ فَسَأَلْتُهُ عَنْ هَذَا الْحَدِيثِ فَحَدَّثَنِي فَقَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ جَرَّ ثَوْبَهُ مَخِيلَةً، لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ فَقُلْتُ لِمُحَارِبٍ أَذَكَرَ إِزَارَهُ قَالَ مَا خَصَّ إِزَارًا وَلاَ قَمِيصًا‏.‏ تَابَعَهُ جَبَلَةُ بْنُ سُحَيْمٍ وَزَيْدُ بْنُ أَسْلَمَ وَزَيْدُ بْنُ عَبْدِ اللَّهِ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ اللَّيْثُ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ مِثْلَهُ‏.‏ وَتَابَعَهُ مُوسَى بْنُ عُقْبَةَ وَعُمَرُ بْنُ مُحَمَّدٍ وَقُدَامَةُ بْنُ مُوسَى عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ مَنْ جَرَّ ثَوْبَهُ ‏"‏‏.‏\hadithno{5791}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Whoever drags his clothes (on the ground) out of pride and arrogance, Allah will not look at him on the Day of Resurrection}}
\hadithdefcmd{bukhari}{5792}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ جَاءَتِ امْرَأَةُ رِفَاعَةَ الْقُرَظِيِّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَنَا جَالِسَةٌ وَعِنْدَهُ أَبُو بَكْرٍ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ تَحْتَ رِفَاعَةَ فَطَلَّقَنِي فَبَتَّ طَلاَقِي، فَتَزَوَّجْتُ بَعْدَهُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ، وَإِنَّهُ وَاللَّهِ مَا مَعَهُ يَا رَسُولَ اللَّهِ إِلاَّ مِثْلُ هَذِهِ الْهُدْبَةِ‏.‏ وَأَخَذَتْ هُدْبَةً مِنْ جِلْبَابِهَا، فَسَمِعَ خَالِدُ بْنُ سَعِيدٍ قَوْلَهَا وَهْوَ بِالْبَابِ لَمْ يُؤْذَنْ لَهُ، قَالَتْ فَقَالَ خَالِدٌ يَا أَبَا بَكْرٍ أَلاَ تَنْهَى هَذِهِ عَمَّا تَجْهَرُ بِهِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلاَ وَاللَّهِ مَا يَزِيدُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى التَّبَسُّمِ، فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَلَّكِ تُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ، لاَ، حَتَّى يَذُوقَ عُسَيْلَتَكِ وَتَذُوقِي عُسَيْلَتَهُ ‏"‏‏.‏ فَصَارَ سُنَّةً بَعْدُ‏.‏\hadithno{5792}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) The wife of Rifa`a Al-Qurazi came to Allah's Messenger (ﷺ) while I was sitting, and Abu Bakr was also there. She said, 'O Allah's Apostle! I was the wife of Rifa`a and he divorced me irrevocably. Then I married `AbdurRahman bin Az-Zubair who, by Allah, O Allah's Messenger (ﷺ), has only something like a fringe of a garment, Showing the fringe of her veil. Khalid bin Sa`id, who was standing at the door, for he had not been admitted, heard her statement and said, "O Abu Bakr! Why do you not stop this lady from saying such things openly before Allah's Messenger (ﷺ)?" No, by Allah, Allah's Messenger (ﷺ) did nothing but smiled. Then he said to the lady, "Perhaps you want to return to Rifa`a? That is impossible unless `Abdur-Rahman consummates his marriage with you." That became the tradition after him}}
\hadithdefcmd{bukhari}{5793}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ حُسَيْنَ بْنَ عَلِيٍّ، أَخْبَرَهُ أَنَّ عَلِيًّا ـ رضى الله عنه ـ قَالَ فَدَعَا النَّبِيُّ صلى الله عليه وسلم بِرِدَائِهِ، ثُمَّ انْطَلَقَ يَمْشِي، وَاتَّبَعْتُهُ أَنَا وَزَيْدُ بْنُ حَارِثَةَ، حَتَّى جَاءَ الْبَيْتَ الَّذِي فِيهِ حَمْزَةُ، فَاسْتَأْذَنَ فَأَذِنُوا لَهُمْ‏.‏\hadithno{5793}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) asked for his Rida, put it on and set out walking. Zaid bin Haritha and I followed him till he reached the house where Harnza (bin `Abdul Muttalib) was present and asked for permission to enter, and they gave us permission}}
\hadithdefcmd{bukhari}{5794}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَلْبَسُ الْمُحْرِمُ الْقَمِيصَ، وَلاَ السَّرَاوِيلَ، وَلاَ الْبُرْنُسَ، وَلاَ الْخُفَّيْنِ، إِلاَّ أَنْ لاَ يَجِدَ النَّعْلَيْنِ، فَلْيَلْبَسْ مَا هُوَ أَسْفَلُ مِنَ الْكَعْبَيْنِ ‏"‏‏.‏\hadithno{5794}\hadithtrans{Narrated Ibn `Umar:A man asked, "O Allah's Apostle What kind of clothes should a Muhrim wear?" The Prophet, said, "A Muhrim should not wear a shirt, trousers a hooded cloak, or Khuffs (socks made from thick fabric or leather) unless he cannot get sandals, in which case he should cut the part (of the Khuff) that covers the ankles}}
\hadithdefcmd{bukhari}{5795}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ أَتَى النَّبِيُّ صلى الله عليه وسلم عَبْدَ اللَّهِ بْنَ أُبَىٍّ بَعْدَ مَا أُدْخِلَ قَبْرَهُ، فَأَمَرَ بِهِ فَأُخْرِجَ، وَوُضِعَ عَلَى رُكْبَتَيْهِ، وَنَفَثَ عَلَيْهِ مِنْ رِيقِهِ، وَأَلْبَسَهُ قَمِيصَهُ، وَاللَّهُ أَعْلَمُ‏.‏\hadithno{5795}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) came to visit `Abdullah bin Ubai (bin Salul) after he had been put in his grave. The Prophet (ﷺ) ordered that `Abdullah be taken out. He was taken out and was placed on the knees of the Prophet, who blew his (blessed) breath on him and dressed the body with his own shirt. And Allah knows better}}
\hadithdefcmd{bukhari}{5796}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، قَالَ لَمَّا تُوُفِّيَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ جَاءَ ابْنُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَعْطِنِي قَمِيصَكَ أُكَفِّنْهُ فِيهِ، وَصَلِّ عَلَيْهِ، وَاسْتَغْفِرْ لَهُ، فَأَعْطَاهُ قَمِيصَهُ، وَقَالَ ‏"‏ إِذَا فَرَغْتَ فَآذِنَّا ‏"‏‏.‏ فَلَمَّا فَرَغَ آذَنَهُ، فَجَاءَ لِيُصَلِّيَ عَلَيْهِ، فَجَذَبَهُ عُمَرُ فَقَالَ أَلَيْسَ قَدْ نَهَاكَ اللَّهُ أَنْ تُصَلِّيَ عَلَى الْمُنَافِقِينَ فَقَالَ ‏\{‏اسْتَغْفِرْ لَهُمْ أَوْ لاَ تَسْتَغْفِرْ لَهُمْ إِنْ تَسْتَغْفِرْ لَهُمْ سَبْعِينَ مَرَّةً فَلَنْ يَغْفِرَ اللَّهُ لَهُمْ‏\}‏‏.‏ فَنَزَلَتْ ‏\{‏وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا‏\}‏ فَتَرَكَ الصَّلاَةَ عَلَيْهِمْ‏.‏\hadithno{5796}\hadithtrans{Narrated `Abdullah bin `Umar:When `Abdullah bin Ubdi (bin Salul) died, his son came to Allah's Messenger (ﷺ) and said ' O Allah's Apostle, give me your shirt so that I may shroud my fathers body in it. And please offer a funeral prayer for him and invoke Allah for his forgiveness." The Prophet (ﷺ) gave him his shirt and said to him 'Inform us when you finish (and the funeral procession is ready) call us. When he had finished he told the Prophet (ﷺ) and the Prophet (ﷺ) proceeded to order his funeral prayers but `Umar stopped him and said, "Didn't Allah forbid you to offer the funeral prayer for the hypocrites when He said: "Whether you (O Muhammad) ask forgiveness for them or ask not forgiveness for them: (and even) if you ask forgiveness for them seventy times. Allah will not forgive them." (9.80) Then there was revealed: "And never (O Muhammad) pray for any of them that dies, nor stand at his grave." (9.34) Thenceforth the Prophet (ﷺ) did not offer funeral prayers for the hypocrites}}
\hadithdefcmd{bukhari}{5797}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ الْحَسَنِ، عَنْ طَاوُسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَثَلَ الْبَخِيلِ وَالْمُتَصَدِّقِ، كَمَثَلِ رَجُلَيْنِ عَلَيْهِمَا جُبَّتَانِ مِنْ حَدِيدٍ، قَدِ اضْطُرَّتْ أَيْدِيهِمَا إِلَى ثُدِيِّهِمَا وَتَرَاقِيهِمَا، فَجَعَلَ الْمُتَصَدِّقُ كُلَّمَا تَصَدَّقَ بِصَدَقَةٍ انْبَسَطَتْ عَنْهُ حَتَّى تَغْشَى أَنَامِلَهُ وَتَعْفُوَ أَثَرَهُ، وَجَعَلَ الْبَخِيلُ كُلَّمَا هَمَّ بِصَدَقَةٍ قَلَصَتْ، وَأَخَذَتْ كُلُّ حَلْقَةٍ بِمَكَانِهَا‏.‏ قَالَ أَبُو هُرَيْرَةَ فَأَنَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِإِصْبَعِهِ هَكَذَا فِي جَيْبِهِ، فَلَوْ رَأَيْتَهُ يُوَسِّعُهَا وَلاَ تَتَوَسَّعُ‏.‏ تَابَعَهُ ابْنُ طَاوُسٍ عَنْ أَبِيهِ وَأَبُو الزِّنَادِ عَنِ الأَعْرَجِ فِي الْجُبَّتَيْنِ‏.‏ وَقَالَ حَنْظَلَةُ سَمِعْتُ طَاوُسًا سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ جُبَّتَانِ‏.‏ وَقَالَ جَعْفَرٌ عَنِ الأَعْرَجِ جُبَّتَانِ‏.‏\hadithno{5797}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) has set forth an example for a miser and a charitable person by comparing them to two men wearing two iron cloaks and their hands are raised to their breasts and necks. Whenever the charitable man tries to give a charitable gift, his iron cloak expands till it becomes so wide that it will cover his fingertips and obliterate his tracks And, whenever the miser wants to give a charitable gift, his cloak becomes very tight over him and every ring gets stuck to its place Abu Huraira added; I saw Allah's Messenger (ﷺ) putting his finger in the (chest) pocket of his shirt like that If you but saw him trying to widen (the opening of his shirt) but it did not widen}}
\hadithdefcmd{bukhari}{5798}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي أَبُو الضُّحَى، قَالَ حَدَّثَنِي مَسْرُوقٌ، قَالَ حَدَّثَنِي الْمُغِيرَةُ بْنُ شُعْبَةَ، قَالَ انْطَلَقَ النَّبِيُّ صلى الله عليه وسلم لِحَاجَتِهِ ثُمَّ أَقْبَلَ، فَتَلَقَّيْتُهُ بِمَاءٍ، فَتَوَضَّأَ وَعَلَيْهِ جُبَّةٌ شَأْمِيَّةٌ، فَمَضْمَضَ وَاسْتَنْشَقَ وَغَسَلَ وَجْهَهُ، فَذَهَبَ يُخْرِجُ يَدَيْهِ مِنْ كُمَّيْهِ فَكَانَا ضَيِّقَيْنِ، فَأَخْرَجَ يَدَيْهِ مِنْ تَحْتِ الْجُبَّةِ، فَغَسَلَهُمَا وَمَسَحَ بِرَأْسِهِ وَعَلَى خُفَّيْهِ‏.‏\hadithno{5798}\hadithtrans{Narrated Al-Mughira bin Shu`ba:The Prophet (ﷺ) went to answer the call of nature, and when he returned, I met him with water and he performed the ablution while he was wearing a Sham, cloak. He rinsed his mouth, put the water in his nose and blew it out, washed his face and tried to take his hands out of his sleeves, but they were too narrow, so he took out his hands from under his chest and washed them and then passed his wet hands over his head and Khuffs (socks made from thick fabric or leather)}}
\hadithdefcmd{bukhari}{5799}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فِي سَفَرٍ فَقَالَ ‏"‏ أَمَعَكَ مَاءٌ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَنَزَلَ عَنْ رَاحِلَتِهِ، فَمَشَى حَتَّى تَوَارَى عَنِّي فِي سَوَادِ اللَّيْلِ، ثُمَّ جَاءَ فَأَفْرَغْتُ عَلَيْهِ الإِدَاوَةَ، فَغَسَلَ وَجْهَهُ وَيَدَيْهِ، وَعَلَيْهِ جُبَّةٌ مِنْ صُوفٍ، فَلَمْ يَسْتَطِعْ أَنْ يُخْرِجَ ذِرَاعَيْهِ مِنْهَا حَتَّى أَخْرَجَهُمَا مِنْ أَسْفَلِ الْجُبَّةِ، فَغَسَلَ ذِرَاعَيْهِ، ثُمَّ مَسَحَ بِرَأْسِهِ، ثُمَّ أَهْوَيْتُ لأَنْزِعَ خُفَّيْهِ فَقَالَ ‏"‏ دَعْهُمَا، فَإِنِّي أَدْخَلْتُهُمَا طَاهِرَتَيْنِ، فَمَسَحَ عَلَيْهِمَا ‏"‏‏.‏\hadithno{5799}\hadithtrans{Narrated Al-Mughira:One night I was with the Prophet (ﷺ) on a journey. He asked (me), "Have you got water with you?" I replied, "Yes" So he got down from his she-camel and went away till he disappeared in the darkness of the night. Then he came back and I poured water for him from the pot (for the ablution). He washed his face and hands while he was wearing a woollen cloak (the sleeves of which were narrow), so he could not take his arms out of it. So he took them out from underneath the cloak. Then he washed his forearms and passed his wet hands over his head. Then I tried to take off his Khuffs (socks made from thick fabric or leather), but he said, "Leave them, for I have performed ablution before putting them on." And so he passed his wet hands over them}}
\hadithdefcmd{bukhari}{5800}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْبِيَةً، وَلَمْ يُعْطِ مَخْرَمَةَ شَيْئًا فَقَالَ مَخْرَمَةُ يَا بُنَىَّ انْطَلِقْ بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَانْطَلَقْتُ مَعَهُ فَقَالَ ادْخُلْ فَادْعُهُ لِي‏.‏ قَالَ فَدَعَوْتُهُ لَهُ، فَخَرَجَ إِلَيْهِ وَعَلَيْهِ قَبَاءٌ مِنْهَا فَقَالَ ‏ "‏ خَبَأْتُ هَذَا لَكَ ‏"‏‏.‏ قَالَ فَنَظَرَ إِلَيْهِ فَقَالَ رَضِيَ مَخْرَمَةُ‏.‏\hadithno{5800}\hadithtrans{Narrated Al-Miswar bin Makhrama:Allah's Messenger (ﷺ) distributed some Qaba's but he did not give anything to Makhrama. Makhrama said (to me), "O my son! Let us go to Allah's Messenger (ﷺ)." So I proceeded with him and he said, "Go in and call him 'or me." So I called the Prophet (ﷺ) for him The Prophet (ﷺ) came out to him, wearing one of those Qaba's and said, (to Makhrama), "I have kept this for you " Makhrama looked at it and said, "Makhrama is satisfied now}}
\hadithdefcmd{bukhari}{5801}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ ـ رضى الله عنه ـ أَنَّهُ قَالَ أُهْدِيَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَرُّوجُ حَرِيرٍ، فَلَبِسَهُ، ثُمَّ صَلَّى فِيهِ، ثُمَّ انْصَرَفَ فَنَزَعَهُ نَزْعًا شَدِيدًا كَالْكَارِهِ لَهُ ثُمَّ قَالَ ‏ "‏ لاَ يَنْبَغِي هَذَا لِلْمُتَّقِينَ ‏"‏‏.‏ تَابَعَهُ عَبْدُ اللَّهِ بْنُ يُوسُفَ عَنِ اللَّيْثِ، وَقَالَ غَيْرُهُ فَرُّوجٌ حَرِيرٌ‏.‏\hadithno{5801}\hadithtrans{Narrated `Uqba bin 'Amir:A silken Farruj was presented to Allah's Messenger (ﷺ) and he put it on and offered the prayer in it. When he finished the prayer, he took it off violently as if he disliked it and said, "This (garment) does not befit those who fear Allah}}
\hadithdefcmd{bukhari}{5802}{وَقَالَ لِي مُسَدَّدٌ حَدَّثَنَا مُعْتَمِرٌ، سَمِعْتُ أَبِي قَالَ، رَأَيْتُ عَلَى أَنَسٍ بُرْنُسًا أَصْفَرَ مِنْ خَزٍّ‏.‏\hadithno{5802}\hadithtrans{Narrated Mu'tamir:I heard my father saying, "I saw Anas wearing a yellow hooded cloak of Khazz}}
\hadithdefcmd{bukhari}{5803}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْقُمُصَ، وَلاَ الْعَمَائِمَ، وَلاَ السَّرَاوِيلاَتِ، وَلاَ الْبَرَانِسَ، وَلاَ الْخِفَافَ، إِلاَّ أَحَدٌ لاَ يَجِدُ النَّعْلَيْنِ، فَلْيَلْبَسْ خُفَّيْنِ، وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ، وَلاَ تَلْبَسُوا مِنَ الثِّيَابِ شَيْئًا مَسَّهُ زَعْفَرَانٌ وَلاَ الْوَرْسُ ‏"‏‏.‏\hadithno{5803}\hadithtrans{Narrated `Abdullah bin `Umar:A man said, "O Allah's Messenger (ﷺ). What type of clothes should a Muhrim wear Allah's Messenger (ﷺ) replied, 'Do not wear shirts, turbans trousers hooded cloaks or Khuffs (socks made from thick fabric or leather); but if someone cannot get sandals, then he can wear Khuffs after cutting them short below the ankles. Do not wear clothes touched by saffon or wars (two kinds of perfumes)}}
\hadithdefcmd{bukhari}{5804}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يَجِدْ إِزَارًا فَلْيَلْبَسْ سَرَاوِيلَ، وَمَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ ‏"‏‏.‏\hadithno{5804}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Whoever cannot get an Izar, can wear trousers, and whoever cannot wear sandals can wear Khuffs (socks made from thick fabric or leather)}}
\hadithdefcmd{bukhari}{5805}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ مَا تَأْمُرُنَا أَنْ نَلْبَسَ إِذَا أَحْرَمْنَا‏.‏ قَالَ ‏ "‏ لاَ تَلْبَسُوا الْقَمِيصَ، وَالسَّرَاوِيلَ، وَالْعَمَائِمَ وَالْبَرَانِسَ، وَالْخِفَافَ، إِلاَّ أَنْ يَكُونَ رَجُلٌ لَيْسَ لَهُ نَعْلاَنِ، فَلْيَلْبَسِ الْخُفَّيْنِ أَسْفَلَ مِنَ الْكَعْبَيْنِ، وَلاَ تَلْبَسُوا شَيْئًا مِنَ الثِّيَابِ مَسَّهُ زَعْفَرَانٌ وَلاَ وَرْسٌ ‏"‏‏.‏\hadithno{5805}\hadithtrans{Narrated `Abdullah:A man got up and said, O Allah's Messenger (ﷺ)! What do you order us to wear when we assume the state of Ihram?" The Prophet (ﷺ) replied, "Do not wear shirts, trousers, turbans, hooded cloaks or Khuffs (socks made from thick fabric or leather), but if a man has no sandals, he can wear Khuffs after cutting them short below the ankles; and do not wear clothes touched with (perfumes) of saffron or wars}}
\hadithdefcmd{bukhari}{5806}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَلْبَسُ الْمُحْرِمُ الْقَمِيصَ، وَلاَ الْعِمَامَةَ، وَلاَ السَّرَاوِيلَ، وَلاَ الْبُرْنُسَ، وَلاَ ثَوْبًا مَسَّهُ زَعْفَرَانٌ، وَلاَ وَرْسٌ، وَلاَ الْخُفَّيْنِ، إِلاَّ لِمَنْ لَمْ يَجِدِ النَّعْلَيْنِ، فَإِنْ لَمْ يَجِدْهُمَا فَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏‏.‏\hadithno{5806}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "A Muhrim should not wear a shirt, a turban, trousers, hooded cloaks, a garment touched with (perfumes) of saffron or wars, or Khuffs (socks made from thick fabric or leather) except if one has no sandals in which case he should cut short the Khuffs below the ankles}}
\hadithdefcmd{bukhari}{5807}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ هَاجَرَ إِلَى الْحَبَشَةِ نَاسٌ مِنَ الْمُسْلِمِينَ، وَتَجَهَّزَ أَبُو بَكْرٍ مُهَاجِرًا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى رِسْلِكَ، فَإِنِّي أَرْجُو أَنْ يُؤْذَنَ لِي ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ أَوَ تَرْجُوهُ بِأَبِي أَنْتَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ فَحَبَسَ أَبُو بَكْرٍ نَفْسَهُ عَلَى النَّبِيِّ صلى الله عليه وسلم لِصُحْبَتِهِ، وَعَلَفَ رَاحِلَتَيْنِ كَانَتَا عِنْدَهُ وَرَقَ السَّمُرِ أَرْبَعَةَ أَشْهُرٍ‏.‏ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ فَبَيْنَا نَحْنُ يَوْمًا جُلُوسٌ فِي بَيْتِنَا فِي نَحْرِ الظَّهِيرَةِ فَقَالَ قَائِلٌ لأَبِي بَكْرٍ هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُقْبِلاً مُتَقَنِّعًا، فِي سَاعَةٍ لَمْ يَكُنْ يَأْتِينَا فِيهَا‏.‏ قَالَ أَبُو بَكْرٍ فِدًا لَهُ بِأَبِي وَأُمِّي، وَاللَّهِ إِنْ جَاءَ بِهِ فِي هَذِهِ السَّاعَةِ إِلاَّ لأَمْرٍ‏.‏ فَجَاءَ النَّبِيُّ صلى الله عليه وسلم فَاسْتَأْذَنَ، فَأَذِنَ لَهُ فَدَخَلَ، فَقَالَ حِينَ دَخَلَ لأَبِي بَكْرٍ ‏"‏ أَخْرِجْ مَنْ عِنْدَكَ ‏"‏‏.‏ قَالَ إِنَّمَا هُمْ أَهْلُكَ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنِّي قَدْ أُذِنَ لِي فِي الْخُرُوجِ ‏"‏‏.‏ قَالَ فَالصُّحْبَةُ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قَالَ فَخُذْ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ إِحْدَى رَاحِلَتَىَّ هَاتَيْنِ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِالثَّمَنِ ‏"‏‏.‏ قَالَتْ فَجَهَّزْنَاهُمَا أَحَثَّ الْجِهَازِ، وَضَعْنَا لَهُمَا سُفْرَةً فِي جِرَابٍ، فَقَطَعَتْ أَسْمَاءُ بِنْتُ أَبِي بَكْرٍ قِطْعَةً مِنْ نِطَاقِهَا، فَأَوْكَتْ بِهِ الْجِرَابَ، وَلِذَلِكَ كَانَتْ تُسَمَّى ذَاتَ النِّطَاقِ، ثُمَّ لَحِقَ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ بِغَارٍ فِي جَبَلٍ يُقَالُ لَهُ ثَوْرٌ، فَمَكُثَ فِيهِ ثَلاَثَ لَيَالٍ يَبِيتُ عِنْدَهُمَا عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، وَهْوَ غُلاَمٌ شَابٌّ لَقِنٌ ثَقِفٌ، فَيَرْحَلُ مِنْ عِنْدِهِمَا سَحَرًا، فَيُصْبِحُ مَعَ قُرَيْشٍ بِمَكَّةَ كَبَائِتٍ، فَلاَ يَسْمَعُ أَمْرًا يُكَادَانِ بِهِ إِلاَّ وَعَاهُ، حَتَّى يَأْتِيَهُمَا بِخَبَرِ ذَلِكَ حِينَ يَخْتَلِطُ الظَّلاَمُ، وَيَرْعَى عَلَيْهِمَا عَامِرُ بْنُ فُهَيْرَةَ مَوْلَى أَبِي بَكْرٍ مِنْحَةً مِنْ غَنَمٍ، فَيُرِيحُهَا عَلَيْهِمَا حِينَ تَذْهَبُ سَاعَةٌ مِنَ الْعِشَاءِ، فَيَبِيتَانِ فِي رِسْلِهَا حَتَّى يَنْعِقَ بِهَا عَامِرُ بْنُ فُهَيْرَةَ بِغَلَسٍ، يَفْعَلُ ذَلِكَ كُلَّ لَيْلَةٍ مِنْ تِلْكَ اللَّيَالِي الثَّلاَثِ‏.‏\hadithno{5807}\hadithtrans{Narrated `Aisha:Some Muslim men emigrated to Ethiopia whereupon Abu Bakr also prepared himself for the emigration, but the Prophet (ﷺ) said (to him), "Wait, for I hope that Allah will allow me also to emigrate." Abu Bakr said, "Let my father and mother be sacrificed for you. Do you hope that (emigration)?" The Prophet said, 'Yes." So Abu Bakr waited to accompany the Prophet (ﷺ) and fed two she-camels he had on the leaves of As-Samur tree regularly for four months One day while we were sitting in our house at midday, someone said to Abu Bakr, "Here is Allah's Messenger (ﷺ), coming with his head and a part of his face covered with a cloth-covering at an hour he never used to come to us." Abu Bakr said, "Let my father and mother be sacrificed for you, (O Prophet)! An urgent matter must have brought you here at this hour." The Prophet (ﷺ) came and asked the permission to enter, and he was allowed. The Prophet (ﷺ) entered and said to Abu Bakr, "Let those who are with you, go out." Abu Bakr replied, "(There is no stranger); they are your family. Let my father be sacrificed for you, O Allah's Apostle!" The Prophet (ﷺ) said, "I have been allowed to leave (Mecca)." Abu Bakr said, " I shall accompany you, O Allah's Messenger (ﷺ), Let my father be sacrificed for you!" The Prophet (ﷺ) said, "Yes," Abu Bakr said, 'O Allah's Messenger (ﷺ)! Let my father be sacrificed for you. Take one of these two shecamels of mine" The Prophet (ﷺ) said. I will take it only after paying its price." So we prepared their baggage and put their journey food In a leather bag. And Asma' bint Abu Bakr cut a piece of her girdle and tied the mouth of the leather bag with it. That is why she was called Dhatan- Nitaqaln. Then the Prophet (ﷺ) and Abu Bakr went to a cave in a mountain called Thour and remained there for three nights. `Abdullah bin Abu Bakr. who was a young intelligent man. used to stay with them at night and leave before dawn so that in the morning, he would he with the Quraish at Mecca as if he had spent the night among them. If he heard of any plot contrived by the Quraish against the Prophet and Abu Bakr, he would understand it and (return to) inform them of it when it became dark. 'Amir bin Fuhaira, the freed slave of Abu Bakr used to graze a flock of milch sheep for them and he used to take those sheep to them when an hour had passed after the `Isha prayer. They would sleep soundly till 'Amir bin Fuhaira awakened them when it was still dark. He used to do that in each of those three nights}}
\hadithdefcmd{bukhari}{5808}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا مَالِكٌ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ عَامَ الْفَتْحِ وَعَلَى رَأْسِهِ الْمِغْفَرُ‏.‏\hadithno{5808}\hadithtrans{Narrated Anas bin Malik:In the year of the conquest of Mecca the Prophet (ﷺ) entered Mecca, wearing a helmet on his head}}
\hadithdefcmd{bukhari}{5809}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنْتُ أَمْشِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ بُرْدٌ نَجْرَانِيٌّ غَلِيظُ الْحَاشِيَةِ، فَأَدْرَكَهُ أَعْرَابِيٌّ فَجَبَذَهُ بِرِدَائِهِ جَبْذَةً شَدِيدَةً، حَتَّى نَظَرْتُ إِلَى صَفْحَةِ عَاتِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَدْ أَثَّرَتْ بِهَا حَاشِيَةُ الْبُرْدِ مِنْ شِدَّةِ جَبْذَتِهِ، ثُمَّ قَالَ يَا مُحَمَّدُ مُرْ لِي مِنْ مَالِ اللَّهِ الَّذِي عِنْدَكَ‏.‏ فَالْتَفَتَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ ضَحِكَ ثُمَّ أَمَرَ لَهُ بِعَطَاءٍ‏.‏\hadithno{5809}\hadithtrans{Narrated Anas bin Malik:Once I was walking with Allah's Messenger (ﷺ) and he was wearing a Najram Burd with thick margin. A bedouin followed him and pulled his Burd so violently that I noticed the side of the shoulder of Allah's Messenger (ﷺ) affected by the margin of the Burd because of that violent pull. The Bedouin said, "O Muhammad! Give me some of Allah's wealth which is with you." Allah's Messenger (ﷺ) turned and looked at him, and smiling, 'he ordered that he be given something}}
\hadithdefcmd{bukhari}{5810}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ جَاءَتِ امْرَأَةٌ بِبُرْدَةٍ ـ قَالَ سَهْلٌ هَلْ تَدْرِي مَا الْبُرْدَةُ قَالَ نَعَمْ هِيَ الشَّمْلَةُ، مَنْسُوجٌ فِي حَاشِيَتِهَا ـ قَالَتْ يَا رَسُولَ اللَّهِ إِنِّي نَسَجْتُ هَذِهِ بِيَدِي أَكْسُوكَهَا‏.‏ فَأَخَذَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُحْتَاجًا إِلَيْهَا، فَخَرَجَ إِلَيْنَا وَإِنَّهَا لإِزَارُهُ، فَجَسَّهَا رَجُلٌ مِنَ الْقَوْمِ فَقَالَ يَا رَسُولَ اللَّهِ اكْسُنِيهَا‏.‏ قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ فَجَلَسَ مَا شَاءَ اللَّهُ فِي الْمَجْلِسِ، ثُمَّ رَجَعَ، فَطَوَاهَا ثُمَّ أَرْسَلَ بِهَا إِلَيْهِ‏.‏ فَقَالَ لَهُ الْقَوْمُ مَا أَحْسَنْتَ، سَأَلْتَهَا إِيَّاهُ وَقَدْ عَرَفْتَ أَنَّهُ لاَ يَرُدُّ سَائِلاً‏.‏ فَقَالَ الرَّجُلُ وَاللَّهِ مَا سَأَلْتُهَا إِلاَّ لِتَكُونَ كَفَنِي يَوْمَ أَمُوتُ‏.‏ قَالَ سَهْلٌ فَكَانَتْ كَفَنَهُ‏.‏\hadithno{5810}\hadithtrans{Narrated Abu Hazim:Shahl bin Sa`d said, "A lady came with a Burda. Sahl then asked (the people), "Do you know what Burda is?" Somebody said, "Yes. it is a Shamla with a woven border." Sahl added, "The lady said, 'O Allah's Messenger (ﷺ)! I have knitted this (Burda) with my own hands for you to wear it." Allah's Messenger (ﷺ) took it and he was in need of it. Allah's Messenger (ﷺ) came out to us and he was wearing it as an Izar. A man from the people felt it and said, 'O Allah's Messenger (ﷺ)! Give it to me to wear.' The Prophet (ﷺ) said, 'Yes.' Then he sat there for some time (and when he went to his house), he folded it and sent it to him. The people said to that man, 'You have not done a right thing. You asked him for it, though you know that he does not put down anybody's request.' The man said, 'By Allah! I have only asked him so that it may be my shroud when I die." Sahl added, "Late it was his shroud}}
\hadithdefcmd{bukhari}{5811}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ يَدْخُلُ الْجَنَّةَ مِنْ أُمَّتِي زُمْرَةٌ هِيَ سَبْعُونَ أَلْفًا، تُضِيءُ وُجُوهُهُمْ إِضَاءَةَ الْقَمَرِ ‏"‏‏.‏ فَقَامَ عُكَاشَةُ بْنُ مِحْصَنٍ الأَسَدِيُّ يَرْفَعُ نَمِرَةً عَلَيْهِ قَالَ ادْعُ اللَّهَ لِي يَا رَسُولَ اللَّهِ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَقَالَ ‏"‏ اللَّهُمَّ اجْعَلْهُ مِنْهُمْ ‏"‏‏.‏ ثُمَّ قَامَ رَجُلٌ مِنَ الأَنْصَارِ فَقَالَ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَقَالَ رَسُولُ اللَّهِ ‏"‏ سَبَقَكَ عُكَاشَةُ ‏"‏‏.‏\hadithno{5811}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying "From among my followers, a group (o 70,000) will enter Paradise without being asked for their accounts, Their faces will be shining like the moon." 'Ukasha bin Muhsin Al-Asadi got up, lifting his covering sheet and said, "O Allah's Messenger (ﷺ) Invoke Allah for me that He may include me with them." The Prophet (ﷺ) said! "O Allah! Make him from them." Then another man from Al-Ansar got up and said, "O Allah's Messenger (ﷺ)! Invoke Allah for me that He may include me with them." On that Allah's Messenger (ﷺ) said, "'Ukasha has anticipated you}}
\hadithdefcmd{bukhari}{5812}{حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قُلْتُ لَهُ أَىُّ الثِّيَابِ كَانَ أَحَبَّ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ الْحِبَرَةُ‏.‏\hadithno{5812}\hadithtrans{Narrated Qatada:I asked Anas, "What kind of clothes was most beloved to the Prophet?" He replied, "The Hibra (a kind of Yemenese cloth)}}
\hadithdefcmd{bukhari}{5813}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا مُعَاذٌ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، رضى الله عنه ـ قَالَ كَانَ أَحَبُّ الثِّيَابِ إِلَى النَّبِيِّ صلى الله عليه وسلم أَنْ يَلْبَسَهَا الْحِبَرَةَ‏.‏\hadithno{5813}\hadithtrans{Narrated Anas bin Malik:The most beloved garment to the Prophet (ﷺ) to wear was the Hibra (a kind of Yemenese cloth)}}
\hadithdefcmd{bukhari}{5814}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ تُوُفِّيَ سُجِّيَ بِبُرْدٍ حِبَرَةٍ‏.‏\hadithno{5814}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) When Allah's Messenger (ﷺ) died, he was covered with a Hibra Burd (green square decorated garment)}}
\hadithdefcmd{bukhari}{5816}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَائِشَةَ، وَعَبْدَ اللَّهِ بْنَ عَبَّاسٍ، رضى الله عنهم قَالاَ لَمَّا نَزَلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم طَفِقَ يَطْرَحُ خَمِيصَةً لَهُ عَلَى وَجْهِهِ، فَإِذَا اغْتَمَّ كَشَفَهَا عَنْ وَجْهِهِ، فَقَالَ وَهْوَ كَذَلِكَ ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الْيَهُودِ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏‏.‏ يُحَذِّرُ مَا صَنَعُوا‏.‏\hadithno{5816}\hadithtrans{Narrated `Aisha and `Abdullah bin `Abbas:When the disease of Allah's Messenger (ﷺ) got aggravated, he covered his face with a Khamisa, but when he became short of breath, he would remove it from his face and say, "It is like that! May Allah curse the Jews Christians because they took the graves of their prophets as places of worship." By that he warned his follower of imitating them, by doing that which they did}}
\hadithdefcmd{bukhari}{5817}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي خَمِيصَةٍ لَهُ لَهَا أَعْلاَمٌ، فَنَظَرَ إِلَى أَعْلاَمِهَا نَظْرَةً، فَلَمَّا سَلَّمَ قَالَ ‏ "‏ اذْهَبُوا بِخَمِيصَتِي هَذِهِ إِلَى أَبِي جَهْمٍ، فَإِنَّهَا أَلْهَتْنِي آنِفًا عَنْ صَلاَتِي، وَائْتُونِي بِأَنْبِجَانِيَّةِ أَبِي جَهْمِ بْنِ حُذَيْفَةَ بْنِ غَانِمٍ مِنْ بَنِي عَدِيِّ بْنِ كَعْبٍ ‏"‏‏.‏\hadithno{5817}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) offered prayer while he was wearing a Khamisa of his that had printed marks. He looked at its marks and when he finished prayer, he said, "Take this Khamisa of mine to Abu Jahm, for it has just now diverted my attention from my prayer, and bring to me the Anbijania (a plain thick sheet) of Abu Jahm bin Hudhaifa bin Ghanim who belonged to Bani Adi bin Ka`b}}
\hadithdefcmd{bukhari}{5818}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا أَيُّوبُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ، قَالَ أَخْرَجَتْ إِلَيْنَا عَائِشَةُ كِسَاءً وَإِزَارًا غَلِيظًا فَقَالَتْ قُبِضَ رُوحُ النَّبِيِّ صلى الله عليه وسلم فِي هَذَيْنِ‏.‏\hadithno{5818}\hadithtrans{Narrated Abu Burda:Aisha brought out to us a Kisa and an Izar and said, "The Prophet (ﷺ) died while wearing these two." (Kisa, a square black piece of woolen cloth. Izar, a sheet cloth garment covering the lower half of the body)}}
\hadithdefcmd{bukhari}{5819}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ خُبَيْبٍ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الْمُلاَمَسَةِ، وَالْمُنَابَذَةِ، وَعَنْ صَلاَتَيْنِ بَعْدَ الْفَجْرِ حَتَّى تَرْتَفِعَ الشَّمْسُ، وَبَعْدَ الْعَصْرِ حَتَّى تَغِيبَ، وَأَنْ يَحْتَبِيَ بِالثَّوْبِ الْوَاحِدِ، لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ بَيْنَهُ وَبَيْنَ السَّمَاءِ، وَأَنْ يَشْتَمِلَ الصَّمَّاءَ‏.‏\hadithno{5819}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) had forbidden: (A) the Mulamasa and Munabadha (bargains), (B) the offering of two prayers, one after the morning compulsory prayer till the sun rises, and the others, after the `Asr prayer till the sun sets (C) He also forbade that one should sit wearing one garment, nothing of which covers his private parts (D) and prevent them from exposure to the sky; (E) he also forbade Ishtimalas- Samma}}
\hadithdefcmd{bukhari}{5820}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَامِرُ بْنُ سَعْدٍ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لِبْسَتَيْنِ وَعَنْ بَيْعَتَيْنِ، نَهَى عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ فِي الْبَيْعِ، وَالْمُلاَمَسَةُ لَمْسُ الرَّجُلِ ثَوْبَ الآخَرِ بِيَدِهِ بِاللَّيْلِ أَوْ بِالنَّهَارِ، وَلاَ يُقَلِّبُهُ إِلاَّ بِذَلِكَ، وَالْمُنَابَذَةُ أَنْ يَنْبِذَ الرَّجُلُ إِلَى الرَّجُلِ بِثَوْبِهِ، وَيَنْبِذَ الآخَرُ ثَوْبَهُ، وَيَكُونَ ذَلِكَ بَيْعَهُمَا، عَنْ غَيْرِ نَظَرٍ وَلاَ تَرَاضٍ، وَاللِّبْسَتَيْنِ اشْتِمَالُ الصَّمَّاءِ، وَالصَّمَّاءُ أَنْ يَجْعَلَ ثَوْبَهُ عَلَى أَحَدِ عَاتِقَيْهِ، فَيَبْدُو أَحَدُ شِقَّيْهِ لَيْسَ عَلَيْهِ ثَوْبٌ، وَاللِّبْسَةُ الأُخْرَى احْتِبَاؤُهُ بِثَوْبِهِ وَهْوَ جَالِسٌ، لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ‏.‏\hadithno{5820}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) forbade two ways of wearing clothes and two kinds of dealings. (A) He forbade the dealings of the Mulamasa and the Munabadha. In the Mulamasa transaction the buyer just touches the garment he wants to buy at night or by daytime, and that touch would oblige him to buy it. In the Munabadha, one man throws his garment at another and the latter throws his at the former and the barter is complete and valid without examining the two objects or being satisfied with them (B) The two ways of wearing clothes were Ishtimal-as-Samma, i e., to cover one's shoulder with one's garment and leave the other bare: and the other way was to wrap oneself with a garment while one was sitting in such a way that nothing of that garment would cover one's private part}}
\hadithdefcmd{bukhari}{5821}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لِبْسَتَيْنِ أَنْ يَحْتَبِيَ الرَّجُلُ فِي الثَّوْبِ الْوَاحِدِ لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ، وَأَنْ يَشْتَمِلَ بِالثَّوْبِ الْوَاحِدِ، لَيْسَ عَلَى أَحَدِ شِقَّيْهِ، وَعَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ‏.‏\hadithno{5821}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade two types of dresses: (A) To sit in an Ihtiba' posture in one garment nothing of which covers his private parts. (B) to cover one side of his body with one garment and leave the other side bare The Prophet (ﷺ) also forbade the Mulamasa and Munabadha}}
\hadithdefcmd{bukhari}{5822}{حَدَّثَنِي مُحَمَّدٌ، قَالَ أَخْبَرَنِي مَخْلَدٌ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ اشْتِمَالِ الصَّمَّاءِ، وَأَنْ يَحْتَبِيَ الرَّجُلُ فِي ثَوْبٍ وَاحِدٍ، لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ‏.‏\hadithno{5822}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) forbade Ishtimal-as-Samma' and that a man should sit in an Ihtiba' posture in one garment, nothing of which covers his private parts}}
\hadithdefcmd{bukhari}{5823}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدٍ، عَنْ أَبِيهِ، سَعِيدِ بْنِ فُلاَنٍ ـ هُوَ عَمْرُو بْنُ سَعِيدِ بْنِ الْعَاصِ ـ عَنْ أُمِّ خَالِدٍ بِنْتِ خَالِدٍ، أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِثِيَابٍ فِيهَا خَمِيصَةٌ سَوْدَاءُ صَغِيرَةٌ فَقَالَ ‏"‏ مَنْ تَرَوْنَ نَكْسُو هَذِهِ ‏"‏‏.‏ فَسَكَتَ الْقَوْمُ قَالَ ‏"‏ ائْتُونِي بِأُمِّ خَالِدٍ ‏"‏‏.‏ فَأُتِيَ بِهَا تُحْمَلُ فَأَخَذَ الْخَمِيصَةَ بِيَدِهِ فَأَلْبَسَهَا وَقَالَ ‏"‏ أَبْلِي وَأَخْلِقِي ‏"‏‏.‏ وَكَانَ فِيهَا عَلَمٌ أَخْضَرُ أَوْ أَصْفَرُ فَقَالَ ‏"‏ يَا أُمَّ خَالِدٍ هَذَا سَنَاهْ ‏"‏‏.‏ وَسَنَاهْ بِالْحَبَشِيَّةِ حَسَنٌ‏.‏\hadithno{5823}\hadithtrans{Narrated Um Khalid bint Khalid:The Prophet (ﷺ) was given some clothes including a black Khamisa. The Prophet (ﷺ) said, "To whom shall we give this to wear?" The people kept silent whereupon the Prophet (ﷺ) said, "Fetch Um Khalid for me." I (Um Khalid) was brought carried (as I was small girl at that time). The Prophet (ﷺ) took the Khamisa in his hands and made me wear it and said, "May you live so long that your dress will wear out and you will mend it many times." On the Khamisa there were some green or pale designs (The Prophet (ﷺ) saw these designs) and said, "O Um Khalid! This is Sanah." (Sanah in a Ethiopian word meaning beautiful)}}
\hadithdefcmd{bukhari}{5824}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لَمَّا وَلَدَتْ أُمُّ سُلَيْمٍ قَالَتْ لِي يَا أَنَسُ انْظُرْ هَذَا الْغُلاَمَ فَلاَ يُصِيبَنَّ شَيْئًا حَتَّى تَغْدُوَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم يُحَنِّكُهُ‏.‏ فَغَدَوْتُ بِهِ، فَإِذَا هُوَ فِي حَائِطٍ وَعَلَيْهِ خَمِيصَةٌ حُرَيْثِيَّةٌ، وَهْوَ يَسِمُ الظَّهْرَ الَّذِي قَدِمَ عَلَيْهِ فِي الْفَتْحِ‏.‏\hadithno{5824}\hadithtrans{Narrated Anas:When Um Sulaim gave birth to a child. she said to me, "O Anas! Watch this boy carefully and do not give him anything to eat or drink until you have taken him to the Prophet (ﷺ) tomorrow morning for the Tahnik." So the next morning I took the child to the Prophet (ﷺ) who was sitting in a garden and was wearing a Huraithiya Khamisa and was branding the she-camel on which he had come during the Conquest of Mecca}}
\hadithdefcmd{bukhari}{5825}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، أَخْبَرَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، أَنَّ رِفَاعَةَ، طَلَّقَ امْرَأَتَهُ، فَتَزَوَّجَهَا عَبْدُ الرَّحْمَنِ بْنُ الزَّبِيرِ الْقُرَظِيُّ، قَالَتْ عَائِشَةُ وَعَلَيْهَا خِمَارٌ أَخْضَرُ‏.‏ فَشَكَتْ إِلَيْهَا، وَأَرَتْهَا خُضْرَةً بِجِلْدِهَا، فَلَمَّا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنِّسَاءُ يَنْصُرُ بَعْضُهُنَّ بَعْضًا قَالَتْ عَائِشَةُ مَا رَأَيْتُ مِثْلَ مَا يَلْقَى الْمُؤْمِنَاتُ، لَجِلْدُهَا أَشَدُّ خُضْرَةً مِنْ ثَوْبِهَا‏.‏ قَالَ وَسَمِعَ أَنَّهَا قَدْ أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَجَاءَ وَمَعَهُ ابْنَانِ لَهُ مِنْ غَيْرِهَا‏.‏ قَالَتْ وَاللَّهِ مَا لِي إِلَيْهِ مِنْ ذَنْبٍ، إِلاَّ أَنَّ مَا مَعَهُ لَيْسَ بِأَغْنَى عَنِّي مِنْ هَذِهِ‏.‏ وَأَخَذَتْ هُدْبَةً مِنْ ثَوْبِهَا، فَقَالَ كَذَبَتْ وَاللَّهِ يَا رَسُولَ اللَّهِ، إِنِّي لأَنْفُضُهَا نَفْضَ الأَدِيمِ، وَلَكِنَّهَا نَاشِزٌ تُرِيدُ رِفَاعَةَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنْ كَانَ ذَلِكَ لَمْ تَحِلِّي لَهُ ـ أَوْ لَمْ تَصْلُحِي لَهُ ـ حَتَّى يَذُوقَ مِنْ عُسَيْلَتِكِ ‏"‏‏.‏ قَالَ وَأَبْصَرَ مَعَهُ ابْنَيْنِ فَقَالَ ‏"‏ بَنُوكَ هَؤُلاَءِ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ هَذَا الَّذِي تَزْعُمِينَ مَا تَزْعُمِينَ، فَوَاللَّهِ لَهُمْ أَشْبَهُ بِهِ مِنَ الْغُرَابِ بِالْغُرَابِ ‏"‏‏.‏\hadithno{5825}\hadithtrans{Narrated `Ikrima:Rifa`a divorced his wife whereupon `AbdurRahman bin Az-Zubair Al-Qurazi married her. `Aisha said that the lady (came), wearing a green veil (and complained to her (Aisha) of her husband and showed her a green spot on her skin caused by beating). It was the habit of ladies to support each other, so when Allah's Messenger (ﷺ) came, `Aisha said, "I have not seen any woman suffering as much as the believing women. Look! Her skin is greener than her clothes!" When `AbdurRahman heard that his wife had gone to the Prophet, he came with his two sons from another wife. She said, "By Allah! I have done no wrong to him but he is impotent and is as useless to me as this," holding and showing the fringe of her garment, `Abdur-Rahman said, "By Allah, O Allah's Messenger (ﷺ)! She has told a lie! I am very strong and can satisfy her but she is disobedient and wants to go back to Rifa`a." Allah's Messenger (ﷺ) said, to her, "If that is your intention, then know that it is unlawful for you to remarry Rifa`a unless `Abdur-Rahman has had sexual intercourse with you." Then the Prophet (ﷺ) saw two boys with `Abdur- Rahman and asked (him), "Are these your sons?" On that `AbdurRahman said, "Yes." The Prophet (ﷺ) said, "You claim what you claim (i.e.. that he is impotent)? But by Allah, these boys resemble him as a crow resembles a crow}}
\hadithdefcmd{bukhari}{5826}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مِسْعَرٌ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، قَالَ رَأَيْتُ بِشِمَالِ النَّبِيِّ صلى الله عليه وسلم وَبِيَمِينِهِ رَجُلَيْنِ عَلَيْهِمَا ثِيَابٌ بِيضٌ يَوْمَ أُحُدٍ، مَا رَأَيْتُهُمَا قَبْلُ وَلاَ بَعْدُ‏.‏\hadithno{5826}\hadithtrans{Narrated Sa`d:On the day of the battle of Uhud, on the right and on the left of the Prophet (ﷺ) were two men wearing white clothes, and I had neither seen them before, nor did I see them afterwards}}
\hadithdefcmd{bukhari}{5827}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنِ الْحُسَيْنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، حَدَّثَهُ أَنَّ أَبَا الأَسْوَدِ الدِّيلِيَّ حَدَّثَهُ أَنَّ أَبَا ذَرٍّ ـ رضى الله عنه ـ حَدَّثَهُ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَعَلَيْهِ ثَوْبٌ أَبْيَضُ وَهْوَ نَائِمٌ، ثُمَّ أَتَيْتُهُ وَقَدِ اسْتَيْقَظَ فَقَالَ ‏"‏ مَا مِنْ عَبْدٍ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ ثُمَّ مَاتَ عَلَى ذَلِكَ، إِلاَّ دَخَلَ الْجَنَّةَ ‏"‏‏.‏ قُلْتُ وَإِنْ زَنَى وَإِنْ سَرَقَ قَالَ ‏"‏ وَإِنْ زَنَى وَإِنْ سَرَقَ ‏"‏‏.‏ قُلْتُ وَإِنْ زَنَى وَإِنْ سَرَقَ قَالَ ‏"‏ وَإِنْ زَنَى وَإِنْ سَرَقَ ‏"‏‏.‏ قُلْتُ وَإِنْ زَنَى وَإِنْ سَرَقَ قَالَ ‏"‏ وَإِنْ زَنَى وَإِنْ سَرَقَ عَلَى رَغْمِ أَنْفِ أَبِي ذَرٍّ ‏"‏‏.‏ وَكَانَ أَبُو ذَرٍّ إِذَا حَدَّثَ بِهَذَا قَالَ وَإِنْ رَغِمَ أَنْفُ أَبِي ذَرٍّ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ هَذَا عِنْدَ الْمَوْتِ أَوْ قَبْلَهُ، إِذَا تَابَ وَنَدِمَ وَقَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ غُفِرَ لَهُ‏.‏\hadithno{5827}\hadithtrans{Narrated Abu Dharr:I came to the Prophet (ﷺ) while he was wearing white clothes and sleeping. Then I went back to him again after he had got up from his sleep. He said, "Nobody says: 'None has the right to be worshipped but Allah' and then later on he dies while believing in that, except that he will enter Paradise." I said, "Even if he had committed illegal sexual intercourse and theft?" He said. 'Even if he had committed illegal sexual intercourse and theft." I said, "Even if he had committed illegal sexual intercourse and theft?" He said. 'Even if he had committed illegal sexual intercourse and theft." I said, 'Even it he had committed illegal sexual intercourse and theft?' He said, "Even if he had committed illegal sexual intercourse and theft, inspite of the Abu Dharr's dislike. Abu `Abdullah said, "This is at the time of death or before it if one repents and regrets and says "None has the right to be worshipped but Allah. He will be forgiven his sins}}
\hadithdefcmd{bukhari}{5828}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا قَتَادَةُ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ النَّهْدِيَّ، أَتَانَا كِتَابُ عُمَرَ وَنَحْنُ مَعَ عُتْبَةَ بْنِ فَرْقَدٍ بِأَذْرَبِيجَانَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْحَرِيرِ، إِلاَّ هَكَذَا، وَأَشَارَ بِإِصْبَعَيْهِ اللَّتَيْنِ تَلِيَانِ الإِبْهَامَ قَالَ فِيمَا عَلِمْنَا أَنَّهُ يَعْنِي الأَعْلاَمَ‏.‏\hadithno{5828}\hadithtrans{Narrated Aba `Uthman An-Nahdi:While we were with `Utba bin Farqad at Adharbijan, there came `Umar's letter indicating that Allah's Apostle had forbidden the use of silk except this much, then he pointed with his index and middle fingers. To our knowledge, by that he meant embroidery}}
\hadithdefcmd{bukhari}{5829}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَاصِمٌ، عَنْ أَبِي عُثْمَانَ، قَالَ كَتَبَ إِلَيْنَا عُمَرُ وَنَحْنُ بِأَذْرَبِيجَانَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الْحَرِيرِ إِلاَّ هَكَذَا، وَصَفَّ لَنَا النَّبِيُّ صلى الله عليه وسلم إِصْبَعَيْهِ‏.‏ وَرَفَعَ زُهَيْرٌ الْوُسْطَى وَالسَّبَّابَةَ‏.‏\hadithno{5829}\hadithtrans{Narrated Abu `Uthman:While we were at Adharbijan, `Umar wrote to us: 'Allah's Messenger (ﷺ) forbade wearing silk except this much. Then the Prophet (ﷺ) approximated his two fingers (index and middle fingers) (to illustrate that) to us.' Zuhair (the sub-narrator) raised up his middle and index fingers}}
\hadithdefcmd{bukhari}{5830}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، قَالَ كُنَّا مَعَ عُتْبَةَ فَكَتَبَ إِلَيْهِ عُمَرُ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُلْبَسُ الْحَرِيرُ فِي الدُّنْيَا، إِلاَّ لَمْ يُلْبَسْ فِي الآخِرَةِ مِنْهُ ‏"‏‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عُمَرَ، حَدَّثَنَا مُعْتَمِرٌ، حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو عُثْمَانَ،، وَأَشَارَ أَبُو عُثْمَانَ، بِإِصْبَعَيْهِ الْمُسَبِّحَةِ وَالْوُسْطَى‏.‏\hadithno{5830}\hadithtrans{Narrated Abu `Uthman:While we were with `Utba. `Umar wrote to us: The Prophet (ﷺ) said, "There is none who wears silk in this world except that he will wear nothing of it in the Hereafter." ' Abu `Uthman pointed out with his middle and index fingers. This hadith has also been narrated by Abu `Uthman}}
\hadithdefcmd{bukhari}{5831}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ كَانَ حُذَيْفَةُ بِالْمَدَايِنِ فَاسْتَسْقَى، فَأَتَاهُ دِهْقَانٌ بِمَاءٍ فِي إِنَاءٍ مِنْ فِضَّةٍ فَرَمَاهُ بِهِ وَقَالَ إِنِّي لَمْ أَرْمِهِ إِلاَّ أَنِّي نَهَيْتُهُ فَلَمْ يَنْتَهِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ وَالْفِضَّةُ وَالْحَرِيرُ وَالدِّيبَاجُ هِيَ لَهُمْ فِي الدُّنْيَا، وَلَكُمْ فِي الآخِرَةِ ‏"‏‏.‏\hadithno{5831}\hadithtrans{Narrated Ibn Abi Laila:While Hudhaifa was at Al-Madain, he asked for water whereupon the chief of the village brought him water in a silver cup. Hudhaifa threw it at him and said, "I have thrown it only because I have forbidden him to use it, but he does not stop using it. Allah's Messenger (ﷺ) said, 'Gold, silver, silk and Dibaj (a kind of silk) are for them (unbelievers) in this world and for you (Muslims) in the hereafter}}
\hadithdefcmd{bukhari}{5832}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ قَالَ شُعْبَةُ فَقُلْتُ أَعَنِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ شَدِيدًا عَنِ النَّبِيِّ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا فَلَنْ يَلْبَسَهُ فِي الآخِرَةِ ‏"‏‏.‏\hadithno{5832}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, Whoever wears silk in this world shall not wear it in the Hereafter}}
\hadithdefcmd{bukhari}{5833}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، قَالَ سَمِعْتُ ابْنَ الزُّبَيْرِ، يَخْطُبُ يَقُولُ قَالَ مُحَمَّدٌ صلى الله عليه وسلم ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا لَمْ يَلْبَسْهُ فِي الآخِرَةِ ‏"‏‏.‏\hadithno{5833}\hadithtrans{Narrated Thabit:I heard Ibn Az-Zubair delivering a sermon, saying, "Muhammad said, 'Whoever wears silk in this world, shall not wear it in the Hereafter}}
\hadithdefcmd{bukhari}{5834}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي ذُبْيَانَ، خَلِيفَةَ بْنِ كَعْبٍ قَالَ سَمِعْتُ ابْنَ الزُّبَيْرِ، يَقُولُ سَمِعْتُ عُمَرَ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا لَمْ يَلْبَسْهُ فِي الآخِرَةِ ‏"‏‏.‏ وَقَالَ لَنَا أَبُو مَعْمَرٍ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ يَزِيدَ، قَالَتْ مُعَاذَةُ أَخْبَرَتْنِي أُمُّ عَمْرٍو بِنْتُ عَبْدِ اللَّهِ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، سَمِعَ عُمَرَ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم‏ نَحْوَهُ\hadithno{5834}\hadithtrans{Narrated Ibn Az-Zubair:I heard `Umar saying, "The Prophet (ﷺ) said, 'Whoever wears silk in this world, shall not wear it in the Hereafter." This hadith is also narrated through 'Umar ibn al-Khattab}}
\hadithdefcmd{bukhari}{5835}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِمْرَانَ بْنِ حِطَّانَ، قَالَ سَأَلْتُ عَائِشَةَ عَنِ الْحَرِيرِ، فَقَالَتِ ائْتِ ابْنَ عَبَّاسٍ فَسَلْهُ‏.‏ قَالَ فَسَأَلْتُهُ فَقَالَ سَلِ ابْنَ عُمَرَ‏.‏ قَالَ فَسَأَلْتُ ابْنَ عُمَرَ فَقَالَ أَخْبَرَنِي أَبُو حَفْصٍ ـ يَعْنِي عُمَرَ بْنَ الْخَطَّابِ ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا يَلْبَسُ الْحَرِيرَ فِي الدُّنْيَا مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏‏.‏ فَقُلْتُ صَدَقَ وَمَا كَذَبَ أَبُو حَفْصٍ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ رَجَاءٍ حَدَّثَنَا حَرْبٌ عَنْ يَحْيَى حَدَّثَنِي عِمْرَانُ‏.‏ وَقَصَّ الْحَدِيثَ‏.‏\hadithno{5835}\hadithtrans{Narrated 'Umar bin Al-Khattab (ra):Allah's Messenger (ﷺ) said, "None wears silk in this world, but he who will have no share in the Hereafter}}
\hadithdefcmd{bukhari}{5836}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ أُهْدِيَ لِلنَّبِيِّ صلى الله عليه وسلم ثَوْبُ حَرِيرٍ، فَجَعَلْنَا نَلْمُسُهُ، وَنَتَعَجَّبُ مِنْهُ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَتَعْجَبُونَ مِنْ هَذَا ‏"‏‏.‏ قُلْنَا نَعَمْ‏.‏ قَالَ ‏"‏ مَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ خَيْرٌ مِنْ هَذَا ‏"‏‏.‏\hadithno{5836}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) was given a silk garment as a gift and we started touching it with our hands and admiring it. On that the Prophet (ﷺ) said, "Do you wonder at this?" We said, "Yes." He said, "The handkerchiefs of Sa`d bin Mu`adh in Paradise are better than this}}
\hadithdefcmd{bukhari}{5837}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ ابْنَ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ قَالَ نَهَانَا النَّبِيُّ صلى الله عليه وسلم أَنْ نَشْرَبَ فِي آنِيَةِ الذَّهَبِ وَالْفِضَّةِ، وَأَنْ نَأْكُلَ فِيهَا، وَعَنْ لُبْسِ الْحَرِيرِ وَالدِّيبَاجِ، وَأَنْ نَجْلِسَ عَلَيْهِ‏.‏\hadithno{5837}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) forbade us to drink out of gold and silver vessels, or eat in it, Ann also forbade the wearing of silk and Dibaj or sitting on it}}
\hadithdefcmd{bukhari}{5838}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ ابْنِ عَازِبٍ، قَالَ نَهَانَا النَّبِيُّ صلى الله عليه وسلم عَنِ الْمَيَاثِرِ الْحُمْرِ وَالْقَسِّيِّ‏.‏\hadithno{5838}\hadithtrans{Narrated Ibn Azib:The Prophet (ﷺ) forbade us to use the red Mayathir and to use Al-Qassiy}}
\hadithdefcmd{bukhari}{5839}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا وَكِيعٌ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ رَخَّصَ النَّبِيُّ صلى الله عليه وسلم لِلزُّبَيْرِ وَعَبْدِ الرَّحْمَنِ فِي لُبْسِ الْحَرِيرِ لِحِكَّةٍ بِهِمَا‏.‏\hadithno{5839}\hadithtrans{Narrated Anas:The Prophet (ﷺ) allowed Az-Zubair and `Abdur-Rahman to wear silk because they were suffering from an itch}}
\hadithdefcmd{bukhari}{5840}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ كَسَانِي النَّبِيُّ صلى الله عليه وسلم حُلَّةً سِيَرَاءَ، فَخَرَجْتُ فِيهَا، فَرَأَيْتُ الْغَضَبَ فِي وَجْهِهِ، فَشَقَّقْتُهَا بَيْنَ نِسَائِي‏.‏\hadithno{5840}\hadithtrans{Narrated `Ali bin Abi Talib:The Prophet (ﷺ) gave me a silk suit. I went out wearing it, but seeing the signs of anger on his face, I tore it and distributed it among my wives}}
\hadithdefcmd{bukhari}{5841}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ عُمَرَ ـ رضى الله عنه ـ رَأَى حُلَّةً سِيَرَاءَ تُبَاعُ فَقَالَ يَا رَسُولَ اللَّهِ لَوِ ابْتَعْتَهَا، تَلْبَسُهَا لِلْوَفْدِ إِذَا أَتَوْكَ وَالْجُمُعَةِ‏.‏ قَالَ ‏"‏ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ ‏"‏‏.‏ وَأَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ بَعْدَ ذَلِكَ إِلَى عُمَرَ حُلَّةَ سِيَرَاءَ حَرِيرٍ، كَسَاهَا إِيَّاهُ فَقَالَ عُمَرُ كَسَوْتَنِيهَا وَقَدْ سَمِعْتُكَ تَقُولُ فِيهَا مَا قُلْتَ فَقَالَ ‏"‏ إِنَّمَا بَعَثْتُ إِلَيْكَ لِتَبِيعَهَا أَوْ تَكْسُوَهَا ‏"‏‏.‏\hadithno{5841}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar saw a silk suit being sold, so he said, "O Allah's Messenger (ﷺ)! Why don't you buy it so that you may wear it when delegates come to you, and also on Fridays?" The Prophet (ﷺ) said, "This is worn only by him who has no share in the Hereafter." Afterwards the Prophet (ﷺ) sent to `Umar a silk suit suitable for wearing. `Umar said to the Prophet, "You have given it to me to wear, yet I have heard you saying about it what you said?" The Prophet (ﷺ) said, "I sent it to you so that you might either sell it or give it to somebody else to wear}}
\hadithdefcmd{bukhari}{5842}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّهُ رَأَى عَلَى أُمِّ كُلْثُومٍ ـ عَلَيْهَا السَّلاَمُ ـ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم بُرْدَ حَرِيرٍ سِيَرَاءَ‏.‏\hadithno{5842}\hadithtrans{Narrated Anas bin Malik:that he had seen Um Kulthum, the daughter of Allah's Messenger (ﷺ) , wearing a red silk garment}}
\hadithdefcmd{bukhari}{5843}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَبِثْتُ سَنَةً وَأَنَا أُرِيدُ أَنْ أَسْأَلَ عُمَرَ عَنِ الْمَرْأَتَيْنِ اللَّتَيْنِ تَظَاهَرَتَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَجَعَلْتُ أَهَابُهُ، فَنَزَلَ يَوْمًا مَنْزِلاً فَدَخَلَ الأَرَاكَ، فَلَمَّا خَرَجَ سَأَلْتُهُ فَقَالَ عَائِشَةُ وَحَفْصَةُ ـ ثُمَّ قَالَ ـ كُنَّا فِي الْجَاهِلِيَّةِ لاَ نَعُدُّ النِّسَاءَ شَيْئًا، فَلَمَّا جَاءَ الإِسْلاَمُ وَذَكَرَهُنَّ اللَّهُ، رَأَيْنَا لَهُنَّ بِذَلِكَ عَلَيْنَا حَقًّا، مِنْ غَيْرِ أَنْ نُدْخِلَهُنَّ فِي شَىْءٍ مِنْ أُمُورِنَا، وَكَانَ بَيْنِي وَبَيْنَ امْرَأَتِي كَلاَمٌ فَأَغْلَظَتْ لِي فَقُلْتُ لَهَا وَإِنَّكِ لَهُنَاكِ‏.‏ قَالَتْ تَقُولُ هَذَا لِي وَابْنَتُكَ تُؤْذِي النَّبِيَّ صلى الله عليه وسلم فَأَتَيْتُ حَفْصَةَ فَقُلْتُ لَهَا إِنِّي أُحَذِّرُكِ أَنْ تَعْصِي اللَّهَ وَرَسُولَهُ‏.‏ وَتَقَدَّمْتُ إِلَيْهَا فِي أَذَاهُ، فَأَتَيْتُ أُمَّ سَلَمَةَ فَقُلْتُ لَهَا‏.‏ فَقَالَتْ أَعْجَبُ مِنْكَ يَا عُمَرُ قَدْ دَخَلْتَ فِي أُمُورِنَا، فَلَمْ يَبْقَ إِلاَّ أَنْ تَدْخُلَ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَزْوَاجِهِ، فَرَدَّدَتْ، وَكَانَ رَجُلٌ مِنَ الأَنْصَارِ إِذَا غَابَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَشَهِدْتُهُ أَتَيْتُهُ بِمَا يَكُونُ، وَإِذَا غِبْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَشَهِدَ أَتَانِي بِمَا يَكُونُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ مَنْ حَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَدِ اسْتَقَامَ لَهُ، فَلَمْ يَبْقَ إِلاَّ مَلِكُ غَسَّانَ بِالشَّأْمِ، كُنَّا نَخَافُ أَنْ يَأْتِيَنَا، فَمَا شَعَرْتُ إِلاَّ بِالأَنْصَارِيِّ وَهْوَ يَقُولُ إِنَّهُ قَدْ حَدَثَ أَمْرٌ‏.‏ قُلْتُ لَهُ وَمَا هُوَ أَجَاءَ الْغَسَّانِيُّ قَالَ أَعْظَمُ مِنْ ذَاكَ، طَلَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ‏.‏ فَجِئْتُ فَإِذَا الْبُكَاءُ مِنْ حُجَرِهَا كُلِّهَا، وَإِذَا النَّبِيُّ صلى الله عليه وسلم قَدْ صَعِدَ فِي مَشْرُبَةٍ لَهُ، وَعَلَى باب الْمَشْرُبَةِ وَصِيفٌ فَأَتَيْتُهُ فَقُلْتُ اسْتَأْذِنْ لِي‏.‏ فَدَخَلْتُ فَإِذَا النَّبِيُّ صلى الله عليه وسلم عَلَى حَصِيرٍ قَدْ أَثَّرَ فِي جَنْبِهِ، وَتَحْتَ رَأْسِهِ مِرْفَقَةٌ مِنْ أَدَمٍ، حَشْوُهَا لِيفٌ، وَإِذَا أُهُبٌ مُعَلَّقَةٌ وَقَرَظٌ، فَذَكَرْتُ الَّذِي قُلْتُ لِحَفْصَةَ وَأُمِّ سَلَمَةَ، وَالَّذِي رَدَّتْ عَلَىَّ أُمُّ سَلَمَةَ، فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَبِثَ تِسْعًا وَعِشْرِينَ لَيْلَةً، ثُمَّ نَزَلَ‏.‏\hadithno{5843}\hadithtrans{Narrated Ibn `Abbas:For one year I wanted to ask `Umar about the two women who helped each other against the Prophet (ﷺ) but I was afraid of him. One day he dismounted his riding animal and went among the trees of Arak to answer the call of nature, and when he returned, I asked him and he said, "(They were) `Aisha and Hafsa." Then he added, "We never used to give significance to ladies in the days of the Pre-Islamic period of ignorance, but when Islam came and Allah mentioned their rights, we used to give them their rights but did not allow them to interfere in our affairs. Once there was some dispute between me and my wife and she answered me back in a loud voice. I said to her, 'Strange! You can retort in this way?' She said, 'Yes. Do you say this to me while your daughter troubles Allah's Messenger (ﷺ)?' So I went to Hafsa and said to her, 'I warn you not to disobey Allah and His Apostle.' I first went to Hafsa and then to Um Salama and told her the same. She said to me, 'O `Umar! It surprises me that you interfere in our affairs so much that you would poke your nose even into the affairs of Allah's Messenger (ﷺ) and his wives.' So she rejected my advice. There was an Ansari man; whenever he was absent from Allah's Messenger (ﷺ) and I was present there, I used to convey to him what had happened (on that day), and when I was absent and he was present there, he used to convey to me what had happened as regards news from Allah's Messenger (ﷺ) . During that time all the rulers of the nearby lands had surrendered to Allah's Messenger (ﷺ) except the king of Ghassan in Sham, and we were afraid that he might attack us. All of a sudden the Ansari came and said, 'A great event has happened!' I asked him, 'What is it? Has the Ghassani (king) come?' He said, 'Greater than that! Allah's Messenger (ﷺ) has divorced his wives! I went to them and found all of them weeping in their dwellings, and the Prophet (ﷺ) had ascended to an upper room of his. At the door of the room there was a slave to whom I went and said, "Ask the permission for me to enter." He admitted me and I entered to see the Prophet (ﷺ) lying on a mat that had left its imprint on his side. Under his head there was a leather pillow stuffed with palm fibres. Behold! There were some hides hanging there and some grass for tanning. Then I mentioned what I had said to Hafsa and Um Salama and what reply Um Salama had given me. Allah's Messenger (ﷺ) smiled and stayed there for twenty nine days and then came down." (See Hadith No. 648, Vol. 3 for details)}}
\hadithdefcmd{bukhari}{5844}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَتْنِي هِنْدُ بِنْتُ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ، قَالَتِ اسْتَيْقَظَ النَّبِيُّ صلى الله عليه وسلم مِنَ اللَّيْلِ وَهْوَ يَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ، مَاذَا أُنْزِلَ اللَّيْلَةَ مِنَ الْفِتْنَةِ، مَاذَا أُنْزِلَ مِنَ الْخَزَائِنِ، مَنْ يُوقِظُ صَوَاحِبَ الْحُجُرَاتِ، كَمْ مِنْ كَاسِيَةٍ فِي الدُّنْيَا عَارِيَةٍ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ قَالَ الزُّهْرِيُّ وَكَانَتْ هِنْدٌ لَهَا أَزْرَارٌ فِي كُمَّيْهَا بَيْنَ أَصَابِعِهَا‏.‏\hadithno{5844}\hadithtrans{Narrated Um Salama:One night the Prophet (ﷺ) woke up, saying, "None has the right to be worshipped but Allah! How many afflictions have been sent down tonight, and how many treasures have been sent down (disclosed)! Who will go and wake up (for prayers) the lady dwellers of these rooms? Many well dressed soul (people) in this world, will be naked on the Day of Resurrection}}
\hadithdefcmd{bukhari}{5845}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدِ بْنِ عَمْرِو بْنِ سَعِيدِ بْنِ الْعَاصِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَتْنِي أُمُّ خَالِدٍ بِنْتُ خَالِدٍ، قَالَتْ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِثِيَابٍ فِيهَا خَمِيصَةٌ سَوْدَاءُ قَالَ ‏"‏ مَنْ تَرَوْنَ نَكْسُوهَا هَذِهِ الْخَمِيصَةَ ‏"‏‏.‏ فَأُسْكِتَ الْقَوْمُ‏.‏ قَالَ ‏"‏ ائْتُونِي بِأُمِّ خَالِدٍ ‏"‏‏.‏ فَأُتِيَ بِي النَّبِيُّ صلى الله عليه وسلم فَأَلْبَسَهَا بِيَدِهِ وَقَالَ ‏"‏ أَبْلِي وَأَخْلِقِي ‏"‏‏.‏ مَرَّتَيْنِ فَجَعَلَ يَنْظُرُ إِلَى عَلَمِ الْخَمِيصَةِ، وَيُشِيرُ بِيَدِهِ إِلَىَّ وَيَقُولُ ‏"‏ يَا أُمَّ خَالِدٍ هَذَا سَنَا ‏"‏‏.‏ وَالسَّنَا بِلِسَانِ الْحَبَشِيَّةِ الْحَسَنُ‏.‏ قَالَ إِسْحَاقُ حَدَّثَتْنِي امْرَأَةٌ مِنْ أَهْلِي أَنَّهَا رَأَتْهُ عَلَى أُمِّ خَالِدٍ‏.‏\hadithno{5845}\hadithtrans{Narrated Um Khalid bint Khalid:Some clothes were presented to Allah's Messenger (ﷺ) as a gift and there was a black Khamisa with it. The Prophet asked (his companions), "To whom do you suggest we give this Khamisa?" The people kept quiet. Then he said, "Bring me Um Khalid," So I was brought to him and he dressed me with it with his own hands and said twice, "May you live so long that you will wear out many garments." He then started looking at the embroidery of that Khamisa and said, "O Um Khalid! This is Sana!" (Sana in Ethiopian language means beautiful.) 'Is-haq, a sub-narrator, said: A woman of my family had told me that she had seen the Khamisa worn by Um Khalid}}
\hadithdefcmd{bukhari}{5846}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَتَزَعْفَرَ الرَّجُلُ‏.‏\hadithno{5846}\hadithtrans{Narrated Anas:The Prophet (ﷺ) forbade men to use saffron}}
\hadithdefcmd{bukhari}{5847}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَلْبَسَ الْمُحْرِمُ ثَوْبًا مَصْبُوغًا بِوَرْسٍ أَوْ بِزَعْفَرَانٍ‏.‏\hadithno{5847}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) forbade Muhrims to wear clothes dyed with Wars or saffron}}
\hadithdefcmd{bukhari}{5848}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، سَمِعَ الْبَرَاءَ ـ رضى الله عنه ـ يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم مَرْبُوعًا، وَقَدْ رَأَيْتُهُ فِي حُلَّةٍ حَمْرَاءَ مَا رَأَيْتُ شَيْئًا أَحْسَنَ مِنْهُ‏.‏\hadithno{5848}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) was of a modest height. I saw him wearing a red suit, and I did not see anything better than him}}
\hadithdefcmd{bukhari}{5849}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ أَشْعَثَ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ أَمَرَنَا النَّبِيُّ صلى الله عليه وسلم بِسَبْعٍ عِيَادَةِ الْمَرِيضِ، وَاتِّبَاعِ الْجَنَائِزِ، وَتَشْمِيتِ الْعَاطِسِ، وَنَهَانَا عَنْ لُبْسِ الْحَرِيرِ، وَالدِّيبَاجِ، وَالْقَسِّيِّ، وَالإِسْتَبْرَقِ، وَمَيَاثِرِ الْحُمْرِ‏.‏\hadithno{5849}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) ordered us to observe seven things: To visit the sick; follow funeral processions; say 'May Allah bestow His Mercy on you', to the sneezer if he says, 'Praise be to Allah!; He forbade us to wear silk, Dibaj, Qassiy and Istibarq (various kinds of silken clothes); or to use red Mayathir (silkcushions). (See Hadith No. 253 A, Vol)}}
\hadithdefcmd{bukhari}{5850}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ سَعِيدٍ أَبِي مَسْلَمَةَ، قَالَ سَأَلْتُ أَنَسًا أَكَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي فِي نَعْلَيْهِ قَالَ نَعَمْ‏.‏\hadithno{5850}\hadithtrans{Narrated Sa`id Abu Maslama:I asked Anas (bin Malik), "Did the Prophet (ﷺ) use to offer the prayers with his shoes on?" He said, "Yes}}
\hadithdefcmd{bukhari}{5851}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ رَأَيْتُكَ تَصْنَعُ أَرْبَعًا لَمْ أَرَ أَحَدًا مِنْ أَصْحَابِكَ يَصْنَعُهَا‏.‏ قَالَ مَا هِيَ يَا ابْنَ جُرَيْجٍ قَالَ رَأَيْتُكَ لاَ تَمَسُّ مِنَ الأَرْكَانِ إِلاَّ الْيَمَانِيَيْنِ، وَرَأَيْتُكَ تَلْبَسُ النِّعَالَ السِّبْتِيَّةَ، وَرَأَيْتُكَ تَصْبُغُ بِالصُّفْرَةِ، وَرَأَيْتُكَ إِذَا كُنْتَ بِمَكَّةَ أَهَلَّ النَّاسُ إِذَا رَأَوُا الْهِلاَلَ، وَلَمْ تُهِلَّ أَنْتَ حَتَّى كَانَ يَوْمَ التَّرْوِيَةِ‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ أَمَّا الأَرْكَانُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمَسُّ إِلاَّ الْيَمَانِيَيْنِ، وَأَمَّا النِّعَالُ السِّبْتِيَّةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْبَسُ النِّعَالَ الَّتِي لَيْسَ فِيهَا شَعَرٌ وَيَتَوَضَّأُ فِيهَا فَأَنَا أُحِبُّ أَنْ أَلْبَسَهَا، وَأَمَّا الصُّفْرَةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْبُغُ بِهَا، فَأَنَا أُحِبُّ أَنْ أَصْبُغَ بِهَا وَأَمَّا الإِهْلاَلُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ حَتَّى تَنْبَعِثَ بِهِ رَاحِلَتُهُ‏.‏\hadithno{5851}\hadithtrans{Narrated Sa`id Al-Maqburi:'Ubai bin Juraij said to `Abdullah Ben `Umar, "I see you doing four things which are not done by your friends." Ibn `Umar said, "What are they, O Ibn Juraij?" He said, "I see that you do not touch except the two Yemenite corners of the Ka`ba (while performing the Tawaf): and I see you wearing the Sabtiyya shoes; and I see you dyeing (your hair) with Sufra; and I see that when you are in Mecca, the people assume the state of Ihram on seeing the crescent (on the first day of Dhul-Hijja) while you do not assume the state of Ihram till the Day of Tarwiya (8th Dhul Hijja)." `Abdullah bin `Umar said to him, "As for the corners of the Ka`ba, I have not seen Allah's Messenger (ﷺ) touching except the two Yemenite corners, As for the Sabtiyya shoes, I saw Allah's Messenger (ﷺ) wearing leather shoes that had no hair, and he used to perform the ablution while wearing them. Therefore, I like to wear such shoes. As regards dyeing with Sufra, I saw Allah's Messenger (ﷺ) dyeing his hair with it, so I like to dye (my hair) with it. As regards the crescent (of Dhul-Hijja), I have not seen Allah's Messenger (ﷺ) assuming the state of Ihram till his she-camel set out (on the 8th of Dhul-Hijja)}}
\hadithdefcmd{bukhari}{5852}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَلْبَسَ الْمُحْرِمُ ثَوْبًا مَصْبُوغًا بِزَعْفَرَانٍ أَوْ وَرْسٍ، وَقَالَ ‏ "‏ مَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ، وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏‏.‏\hadithno{5852}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) forbade that a Muhrim should wear clothes dyed with Saffron or Wars, and said, "Whoever has no shoes can put on Khuffs (socks made from thick fabric or leather) after cutting it below the ankles}}
\hadithdefcmd{bukhari}{5853}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ لَمْ يَكُنْ لَهُ إِزَارٌ فَلْيَلْبَسِ السَّرَاوِيلَ، وَمَنْ لَمْ يَكُنْ لَهُ نَعْلاَنِ فَلْيَلْبَسْ خُفَّيْنِ ‏"‏‏.‏\hadithno{5853}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Whoever has no Izar (waist sheet), can wear trousers; and whoever has no sandals, can wear Khuffs (socks made from thick fabric or leather, but cut them short below the ankles)}}
\hadithdefcmd{bukhari}{5854}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي أَشْعَثُ بْنُ سُلَيْمٍ، سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُحِبُّ التَّيَمُّنَ فِي طُهُورِهِ وَتَرَجُّلِهِ وَتَنَعُّلِهِ‏.‏\hadithno{5854}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to like starting from the right in performing ablution, combing his hair and putting on his shoes}}
\hadithdefcmd{bukhari}{5855}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا انْتَعَلَ أَحَدُكُمْ فَلْيَبْدَأْ بِالْيَمِينِ وَإِذَا نَزَعَ فَلْيَبْدَأْ بِالشِّمَالِ، لِتَكُنِ الْيُمْنَى أَوَّلَهُمَا تُنْعَلُ وَآخِرَهُمَا تُنْزَعُ ‏"‏‏.‏\hadithno{5855}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If you want to put on your shoes, put on the right shoe first; and if you want to take them off, take the left one first. Let the right shoe be the first to be put on and the last to be taken off}}
\hadithdefcmd{bukhari}{5856}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْشِي أَحَدُكُمْ فِي نَعْلٍ وَاحِدَةٍ لِيُحْفِهِمَا جَمِيعًا، أَوْ لِيَنْعَلْهُمَا جَمِيعًا ‏"‏‏.‏\hadithno{5856}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "None of you should walk, wearing one shoe only; he should either put on both shoes or put on no shoes whatsoever}}
\hadithdefcmd{bukhari}{5857}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسٌ ـ رضى الله عنه ـ أَنَّ نَعْلَ، النَّبِيِّ صلى الله عليه وسلم كَانَ لَهَا قِبَالاَنِ‏.‏\hadithno{5857}\hadithtrans{Narrated Anas:The sandal of the Prophet (ﷺ) had two straps}}
\hadithdefcmd{bukhari}{5858}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عِيسَى بْنُ طَهْمَانَ، قَالَ خَرَجَ إِلَيْنَا أَنَسُ بْنُ مَالِكٍ بِنَعْلَيْنِ لَهُمَا قِبَالاَنِ، فَقَالَ ثَابِتٌ الْبُنَانِيُّ هَذِهِ نَعْلُ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5858}\hadithtrans{Narrated Isaa bin Tahman:Anas bin Malik brought out for us, two sandals having two straps. Thabit Al-Banani said, "These were the sandals of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{5859}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، قَالَ حَدَّثَنِي عُمَرُ بْنُ أَبِي زَائِدَةَ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهْوَ فِي قُبَّةٍ حَمْرَاءَ مِنْ أَدَمٍ، وَرَأَيْتُ بِلاَلاً أَخَذَ وَضُوءَ النَّبِيِّ صلى الله عليه وسلم وَالنَّاسُ يَبْتَدِرُونَ الْوَضُوءَ، فَمَنْ أَصَابَ مِنْهُ شَيْئًا تَمَسَّحَ بِهِ، وَمَنْ لَمْ يُصِبْ مِنْهُ شَيْئًا أَخَذَ مِنْ بَلَلِ يَدِ صَاحِبِهِ‏.‏\hadithno{5859}\hadithtrans{Narrated Abu Juhaifa:I came to the Prophet (ﷺ) while he was inside a red leather tent, and I saw Bilal taking the remaining water of the ablution of the Prophet, and the people were taking of that water and rubbing it on their faces; and whoever could not get anything of it, would share the moisture of the hand of his companion (and then rub it on his face)}}
\hadithdefcmd{bukhari}{5860}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، ح وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ قَالَ أَرْسَلَ النَّبِيُّ صلى الله عليه وسلم إِلَى الأَنْصَارِ، وَجَمَعَهُمْ فِي قُبَّةٍ مِنْ أَدَمٍ‏.‏\hadithno{5860}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) called for the Ansar and gathered them in a leather tent}}
\hadithdefcmd{bukhari}{5861}{حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَحْتَجِرُ حَصِيرًا بِاللَّيْلِ فَيُصَلِّي، وَيَبْسُطُهُ بِالنَّهَارِ فَيَجْلِسُ عَلَيْهِ، فَجَعَلَ النَّاسُ يَثُوبُونَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَيُصَلُّونَ بِصَلاَتِهِ حَتَّى كَثُرُوا فَأَقْبَلَ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ خُذُوا مِنَ الأَعْمَالِ مَا تُطِيقُونَ، فَإِنَّ اللَّهَ لاَ يَمَلُّ حَتَّى تَمَلُّوا، وَإِنَّ أَحَبَّ الأَعْمَالِ إِلَى اللَّهِ مَا دَامَ وَإِنْ قَلَّ ‏"‏‏.‏\hadithno{5861}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to construct a loom with a Hasir at night m order to pray therein, and during the day he used to spread it out and sit on it. The people started coming to the Prophet (ﷺ) at night to offer the prayer behind him When their number increased, the Prophet (ﷺ) faced them and said. O people! Do only those good deeds which you can do, for Allah does not get tired (of giving reward) till you get tired, and the best deeds to Allah are the incessant ones though they were few}}
\hadithdefcmd{bukhari}{5862}{وَقَالَ اللَّيْثُ حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّ أَبَاهُ، مَخْرَمَةَ قَالَ لَهُ يَا بُنَىَّ إِنَّهُ بَلَغَنِي أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدِمَتْ عَلَيْهِ أَقْبِيَةٌ فَهْوَ يَقْسِمُهَا، فَاذْهَبْ بِنَا إِلَيْهِ، فَذَهَبْنَا فَوَجَدْنَا النَّبِيَّ صلى الله عليه وسلم فِي مَنْزِلِهِ، فَقَالَ لِي يَا بُنَىَّ ادْعُ لِي النَّبِيَّ صلى الله عليه وسلم فَأَعْظَمْتُ ذَلِكَ‏.‏ فَقُلْتُ أَدْعُو لَكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا بُنَىَّ إِنَّهُ لَيْسَ بِجَبَّارٍ‏.‏ فَدَعَوْتُهُ فَخَرَجَ وَعَلَيْهِ قَبَاءٌ مِنْ دِيبَاجٍ مُزَرَّرٌ بِالذَّهَبِ، فَقَالَ ‏ "‏ يَا مَخْرَمَةُ هَذَا خَبَأْنَاهُ لَكَ ‏"‏‏.‏ فَأَعْطَاهُ إِيَّاهُ‏.‏\hadithno{5862}\hadithtrans{Narrated Al-Miswar bin Makhrama:My father, Makhrama said to me, "I have come to know that some cloaks have come to the Prophet (ﷺ) and he is distributing them. So O my son! take me to him." We went to the Prophet (ﷺ) and found him in the house. My father said to me, "O my son! Call the Prophet (ﷺ) for me." I found it hard to do so, so I said surprisingly, "Shall I call Allah's Messenger (ﷺ) for you ?" My father said, "O mu son! He is not a tyrant." So I called him and he came out wearing a Dibaj cloak having gold buttons, and said: "O Makhrama, I kept this for you." The Prophet (ﷺ) then gave it to him}}
\hadithdefcmd{bukhari}{5863}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَشْعَثُ بْنُ سُلَيْمٍ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ سُوَيْدِ بْنِ مُقَرِّنٍ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ يَقُولُ نَهَانَا النَّبِيُّ صلى الله عليه وسلم عَنْ سَبْعٍ نَهَى عَنْ خَاتَمِ الذَّهَبِ ـ أَوْ قَالَ حَلْقَةِ الذَّهَبِ ـ وَعَنِ الْحَرِيرِ، وَالإِسْتَبْرَقِ، وَالدِّيبَاجِ، وَالْمِيثَرَةِ الْحَمْرَاءِ، وَالْقَسِّيِّ، وَآنِيَةِ الْفِضَّةِ، وَأَمَرَنَا بِسَبْعٍ بِعِيَادَةِ الْمَرِيضِ، وَاتِّبَاعِ الْجَنَائِزِ، وَتَشْمِيتِ الْعَاطِسِ، وَرَدِّ السَّلاَمِ، وَإِجَابَةِ الدَّاعِي، وَإِبْرَارِ الْمُقْسِمِ، وَنَصْرِ الْمَظْلُومِ‏.‏\hadithno{5863}\hadithtrans{Narrated Al-Bara' bin `Azib:The Prophet (ﷺ) forbade us to use seven things: He forbade using gold rings, silk, Istabraq, Dibaj, red Mayathir, Al-Qassiy, and silver utensils. He ordered us to do seven other things. To pay a visit to the sick; to follow funeral processions; to say, "May Allah be merciful to you" to a sneezer if he says "Praise be to Allah"; to return greetings, to accept invitations; to help others to fulfil their oaths and to help the oppressed ones}}
\hadithdefcmd{bukhari}{5864}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ خَاتَمِ الذَّهَبِ‏.‏ وَقَالَ عَمْرٌو أَخْبَرَنَا شُعْبَةُ عَنْ قَتَادَةَ سَمِعَ النَّضْرَ سَمِعَ بَشِيرًا مِثْلَهُ‏.‏\hadithno{5864}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) forbade the wearing of a gold ring}}
\hadithdefcmd{bukhari}{5865}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ ذَهَبٍ، وَجَعَلَ فَصَّهُ مِمَّا يَلِي كَفَّهُ، فَاتَّخَذَهُ النَّاسُ، فَرَمَى بِهِ، وَاتَّخَذَ خَاتَمًا مِنْ وَرِقٍ أَوْ فِضَّةٍ‏.‏\hadithno{5865}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) wore a gold or silver .. ring and placed its stone towards the palm of his hand. The people also started wearing gold rings like it, but when the Prophet (ﷺ) saw them wearing such rings, he threw away that golden ring and then wore a silver ring}}
\hadithdefcmd{bukhari}{5866}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ ذَهَبٍ أَوْ فِضَّةٍ، وَجَعَلَ فَصَّهُ مِمَّا يَلِي كَفَّهُ، وَنَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏ فَاتَّخَذَ النَّاسُ مِثْلَهُ، فَلَمَّا رَآهُمْ قَدِ اتَّخَذُوهَا رَمَى بِهِ، وَقَالَ ‏ "‏ لاَ أَلْبَسُهُ أَبَدًا ‏"‏‏.‏ ثُمَّ اتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ، فَاتَّخَذَ النَّاسُ خَوَاتِيمَ الْفِضَّةِ‏.‏ قَالَ ابْنُ عُمَرَ فَلَبِسَ الْخَاتَمَ بَعْدَ النَّبِيِّ صلى الله عليه وسلم أَبُو بَكْرٍ ثُمَّ عُمَرُ ثُمَّ عُثْمَانُ، حَتَّى وَقَعَ مِنْ عُثْمَانَ فِي بِئْرِ أَرِيسَ‏.‏\hadithno{5866}\hadithtrans{Narrated Ibn. `Umar:Allah's Messenger (ﷺ) wore a gold ring or a silver ring and placed its stone towards the palm of his hand and had the name 'Muhammad, the Messenger of Allah' engraved on it. The people also started wearing gold rings like it, but when the Prophet (ﷺ) saw them wearing such rings, he threw away his own ring and said. "I will never wear it," and then wore a silver ring, whereupon the people too started wearing silver rings. Ibn `Umar added: After the Prophet (ﷺ) Abu Bakr wore the ring, and then `Umar and then `Uthman wore it till it fell in the Aris well from `Uthman}}
\hadithdefcmd{bukhari}{5867}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَلْبَسُ خَاتَمًا مِنْ ذَهَبٍ فَنَبَذَهُ فَقَالَ ‏ "‏ لاَ أَلْبَسُهُ أَبَدًا ‏"‏‏.‏ فَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ‏.‏\hadithno{5867}\hadithtrans{Narrated Abdullah bin `Umar:Allah's Messenger (ﷺ) wore a gold ring, then he threw it and said, "I will never wear it." The people also threw their (gold) rings}}
\hadithdefcmd{bukhari}{5868}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ رَأَى فِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ وَرِقٍ يَوْمًا وَاحِدًا، ثُمَّ إِنَّ النَّاسَ اصْطَنَعُوا الْخَوَاتِيمَ مِنْ وَرِقٍ وَلَبِسُوهَا، فَطَرَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمَهُ، فَطَرَحَ النَّاسُ خَوَاتِيمَهُمْ‏.‏ تَابَعَهُ إِبْرَاهِيمُ بْنُ سَعْدٍ وَزِيَادٌ وَشُعَيْبٌ عَنِ الزُّهْرِيِّ‏.‏ وَقَالَ ابْنُ مُسَافِرٍ عَنِ الزُّهْرِيِّ أَرَى خَاتَمًا مِنْ وَرِقٍ‏.‏\hadithno{5868}\hadithtrans{Narrated Anas bin Malik:that he saw a silver ring on the hand of Allah's Messenger (ﷺ) for one day only. Then the people had silver rings made for themselves and wore it. On that, Allah's Messenger (ﷺ) threw away their rings as well. (For the details of this Hadith, see Fath-ul-Bari, Vol. 12, page)}}
\hadithdefcmd{bukhari}{5869}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَخْبَرَنَا حُمَيْدٌ، قَالَ سُئِلَ أَنَسٌ هَلِ اتَّخَذَ النَّبِيُّ صلى الله عليه وسلم خَاتَمًا قَالَ أَخَّرَ لَيْلَةً صَلاَةَ الْعِشَاءِ إِلَى شَطْرِ اللَّيْلِ، ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ، فَكَأَنِّي أَنْظُرُ إِلَى وَبِيصِ خَاتَمِهِ‏.‏ قَالَ ‏ "‏ إِنَّ النَّاسَ قَدْ صَلَّوْا وَنَامُوا، وَإِنَّكُمْ لَمْ تَزَالُوا فِي صَلاَةٍ مَا انْتَظَرْتُمُوهَا ‏"‏‏.‏\hadithno{5869}\hadithtrans{Narrated Humaid:Anas was asked, "Did the Prophet (ﷺ) wear a ring?" Anas said, "Once he delayed the: `Isha' prayer till midnight. Then he came, facing us ..... as if I am now Looking at the glitter of his ring ..... and said, "The people have offered their prayers and slept but you have been in prayer as you have been waiting for it}}
\hadithdefcmd{bukhari}{5870}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ حُمَيْدًا، يُحَدِّثُ عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ خَاتَمُهُ مِنْ فِضَّةٍ وَكَانَ فَصُّهُ مِنْهُ‏.‏ وَقَالَ يَحْيَى بْنُ أَيُّوبَ حَدَّثَنِي حُمَيْدٌ سَمِعَ أَنَسًا عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5870}\hadithtrans{Narrated Anas:The ring of the Prophet (ﷺ) was of silver, and its stone was of silver too}}
\hadithdefcmd{bukhari}{5871}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ سَهْلاً، يَقُولُ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ جِئْتُ أَهَبُ نَفْسِي‏.‏ فَقَامَتْ طَوِيلاً فَنَظَرَ وَصَوَّبَ، فَلَمَّا طَالَ مُقَامُهَا فَقَالَ رَجُلٌ زَوِّجْنِيهَا، إِنْ لَمْ تَكُنْ لَكَ بِهَا حَاجَةٌ‏.‏ قَالَ ‏"‏ عِنْدَكَ شَىْءٌ تُصْدِقُهَا ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ انْظُرْ ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ وَاللَّهِ إِنْ وَجَدْتُ شَيْئًا‏.‏ قَالَ ‏"‏ اذْهَبْ فَالْتَمِسْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ قَالَ لاَ وَاللَّهِ وَلاَ خَاتَمًا مِنْ حَدِيدٍ‏.‏ وَعَلَيْهِ إِزَارٌ مَا عَلَيْهِ رِدَاءٌ‏.‏ فَقَالَ أُصْدِقُهَا إِزَارِي فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِزَارُكَ إِنْ لَبِسَتْهُ لَمْ يَكُنْ عَلَيْكَ مِنْهُ شَىْءٌ، وَإِنْ لَبِسْتَهُ لَمَ يَكُنْ عَلَيْهَا مِنْهُ شَىْءٌ ‏"‏‏.‏ فَتَنَحَّى الرَّجُلُ فَجَلَسَ فَرَآهُ النَّبِيُّ صلى الله عليه وسلم مُوَلِّيًا فَأَمَرَ بِهِ فَدُعِيَ فَقَالَ ‏"‏ مَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏ قَالَ سُورَةُ كَذَا وَكَذَا لِسُوَرٍ عَدَّدَهَا‏.‏ قَالَ ‏"‏ قَدْ مَلَّكْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5871}\hadithtrans{Narrated Sahl:A woman came to the Prophet (ﷺ) and said, "I have come to present myself to you (for marriage)." She kept standing for a long period during which period the Prophet (ﷺ) looked at her carefully. When she stayed for a Long period, a man said to the Prophet (ﷺ) "If you are not in need of her, then marry her to me." The Prophet (ﷺ) said, "Have you got anything to give her (as Mahr)?" The man said, "No." The Prophet said, "Go (to your house) and search for something." The man went and came back to say, "By Allah, I could not find anything." The Prophet (ﷺ) said, "Go again and search for something, even if it be an iron ring." He went again and came back saying, "No, by Allah, I could not get even an iron ring." The man had only an Izar and had no Rida' (upper garment). He said, "I will give her my Izar as Mahr." On that the Prophet (ﷺ) said, "Your Izar? If she wears it, nothing of it will remain on you, and if you wear it nothing of it will be on her" The man went aside and sat down When the Prophet (ﷺ) saw him leaving (after a while), he called back and asked. "How much Qur'an do you know (by heart)? He said, 'I know such and such Suras," naming some Suras. The Prophet (ﷺ) said, "I marry her to you for the amount of Qur'an you know (by heart)}}
\hadithdefcmd{bukhari}{5872}{حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم أَرَادَ أَنْ يَكْتُبَ إِلَى رَهْطٍ أَوْ أُنَاسٍ مِنَ الأَعَاجِمِ، فَقِيلَ لَهُ إِنَّهُمْ لاَ يَقْبَلُونَ كِتَابًا إِلاَّ عَلَيْهِ خَاتَمٌ، فَاتَّخَذَ النَّبِيُّ صلى الله عليه وسلم خَاتَمًا مِنْ فِضَّةٍ نَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ فَكَأَنِّي بِوَبِيصِ أَوْ بِبَصِيصِ الْخَاتَمِ فِي إِصْبَعِ النَّبِيِّ صلى الله عليه وسلم أَوْ فِي كَفِّهِ‏.‏\hadithno{5872}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) wanted to write a letter to a group of people or some non-Arabs. It was said to him, "They do not accept any letter unless it is stamped." So the Prophet (ﷺ) had a silver ring made for himself, and on it was engraved: 'Muhammad, the Messenger of Allah'. .. as if I am now looking at the glitter of the ring on the finger (or in the palm) of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{5873}{حَدَّثَنِي مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ وَرِقٍ، وَكَانَ فِي يَدِهِ، ثُمَّ كَانَ بَعْدُ فِي يَدِ أَبِي بَكْرٍ، ثُمَّ كَانَ بَعْدُ فِي يَدِ عُمَرَ، ثُمَّ كَانَ بَعْدُ فِي يَدِ عُثْمَانَ، حَتَّى وَقَعَ بَعْدُ فِي بِئْرِ أَرِيسَ، نَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏\hadithno{5873}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) had a silver ring made for himself and it was worn by him on his hand. Afterwards it was worn by Abu Bakr, and then by `Umar, and then by `Uthman till it fell in the Aris well. (On that ring) was engraved: 'Muhammad, the Messenger of Allah}}
\hadithdefcmd{bukhari}{5874}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ صَنَعَ النَّبِيُّ صلى الله عليه وسلم خَاتَمًا قَالَ ‏ "‏ إِنَّا اتَّخَذْنَا خَاتَمًا، وَنَقَشْنَا فِيهِ نَقْشًا، فَلاَ يَنْقُشْ عَلَيْهِ أَحَدٌ ‏"‏‏.‏ قَالَ فَإِنِّي لأَرَى بَرِيقَهُ فِي خِنْصَرِهِ‏.‏\hadithno{5874}\hadithtrans{Narrated Anas:The Prophet (ﷺ) got a ring made for himself and said, "I have got a ring made (for myself) and engraved a certain engraving on it so none of you should get such an engraving on his ring." I saw the glitter of the ring on his little finger}}
\hadithdefcmd{bukhari}{5875}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ لَمَّا أَرَادَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَكْتُبَ إِلَى الرُّومِ قِيلَ لَهُ إِنَّهُمْ لَنْ يَقْرَءُوا كِتَابَكَ إِذَا لَمْ يَكُنْ مَخْتُومًا‏.‏ فَاتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ، وَنَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏ فَكَأَنَّمَا أَنْظُرُ إِلَى بَيَاضِهِ فِي يَدِهِ‏.‏\hadithno{5875}\hadithtrans{Narrated Anas bin Malik:When the Prophet (ﷺ) intended to write to the Byzantines, it was said to him, "Those people do not read your letter unless it is stamped." So the Prophet (ﷺ) took a silver ring and got 'Muhammad, the Apostle of Allah' engraved on it .... as if I am now looking at its glitter in his hand}}
\hadithdefcmd{bukhari}{5876}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ، حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم اصْطَنَعَ خَاتَمًا مِنْ ذَهَبٍ، جَعَلَ فَصَّهُ فِي بَطْنِ كَفِّهِ إِذَا لَبِسَهُ، فَاصْطَنَعَ النَّاسُ خَوَاتِيمَ مِنْ ذَهَبٍ، فَرَقِيَ الْمِنْبَرَ، فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ فَقَالَ ‏ "‏ إِنِّي كُنْتُ اصْطَنَعْتُهُ، وَإِنِّي لاَ أَلْبَسُهُ ‏"‏‏.‏ فَنَبَذَهُ فَنَبَذَ النَّاسُ‏.‏ قَالَ جُوَيْرِيَةُ وَلاَ أَحْسِبُهُ إِلاَّ قَالَ فِي يَدِهِ الْيُمْنَى‏.‏\hadithno{5876}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) had a golden ring made for himself, and when he wore it. he used to turn its stone toward the palm of his! hand. So the people too had gold made for themselves. The Prophet (ﷺ) then ascended the pulpit, and after glorifying and praising Allah, he said, "I had it made for me, but now I will never wear it again." He threw it away, and then the people threw away their rings too. (Juwairiya, a subnarrator, said: I think Anas said that the Prophet (ﷺ) was wearing the ring in his right hand}}
\hadithdefcmd{bukhari}{5877}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ، وَنَقَشَ فِيهِ، مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏ وَقَالَ ‏ "‏ إِنِّي اتَّخَذْتُ خَاتَمًا مِنْ وَرِقٍ، وَنَقَشْتُ فِيهِ، مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏ فَلاَ يَنْقُشَنَّ أَحَدٌ عَلَى نَقْشِهِ ‏"‏‏.‏\hadithno{5877}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) took a silver ring and had 'Muhammad, the Apostle' of Allah' engraved on it. The Prophet then said (to us), 'I have a silver ring with 'Muhammad, the Messenger of Allah engraved on it, so none of you should have the same engraving on his ring}}
\hadithdefcmd{bukhari}{5878}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسٍ، أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ لَمَّا اسْتُخْلِفَ كَتَبَ لَهُ، وَكَانَ نَقْشُ الْخَاتَمِ ثَلاَثَةَ أَسْطُرٍ‏.‏ مُحَمَّدٌ سَطْرٌ، وَرَسُولُ سَطْرٌ، وَاللَّهِ سَطْرٌ‏.‏\hadithno{5878}\hadithtrans{Narrated Anas:that when Abu Bakr became the Caliph, he wrote a letter to him (and stamped it with the Prophet's ring) and the engraving of the ring was in three lines: Muhammad in one line, 'Apostle' in another line, and 'Allah' in a third line}}
\hadithdefcmd{bukhari}{5879}{وَزَادَنِي أَحْمَدُ حَدَّثَنَا الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسٍ، قَالَ كَانَ خَاتَمُ النَّبِيِّ صلى الله عليه وسلم فِي يَدِهِ، وَفِي يَدِ أَبِي بَكْرٍ بَعْدَهُ، وَفِي يَدِ عُمَرَ بَعْدَ أَبِي بَكْرٍ، فَلَمَّا كَانَ عُثْمَانُ جَلَسَ عَلَى بِئْرِ أَرِيسَ ـ قَالَ ـ فَأَخْرَجَ الْخَاتَمَ، فَجَعَلَ يَعْبَثُ بِهِ فَسَقَطَ قَالَ فَاخْتَلَفْنَا ثَلاَثَةَ أَيَّامٍ مَعَ عُثْمَانَ فَنَنْزَحُ الْبِئْرَ فَلَمْ نَجِدْهُ‏.‏\hadithno{5879}\hadithtrans{Anas added:The ring of the Prophet (ﷺ) was in his hand, and after him, in Abu Bakr's hand, and then in `Umar's hand after Abu Bakr. When `Uthman was the Caliph, once he was sitting at the well of Aris. He removed the ring from his hand and while he was trifling with it, dropped into the well. We kept on going to the well with `Uthman for three days looking for the ring, and finally the well was drained, but the ring was not found}}
\hadithdefcmd{bukhari}{5880}{حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنَا الْحَسَنُ بْنُ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ شَهِدْتُ الْعِيدَ مَعَ النَّبِيِّ صلى الله عليه وسلم فَصَلَّى قَبْلَ الْخُطْبَةِ‏.‏ وَزَادَ ابْنُ وَهْبٍ عَنِ ابْنِ جُرَيْجٍ فَأَتَى النِّسَاءَ فَجَعَلْنَ يُلْقِينَ الْفَتَخَ وَالْخَوَاتِيمَ فِي ثَوْبِ بِلاَلٍ‏.‏\hadithno{5880}\hadithtrans{Narrated Ibn `Abbas:I offered the `Id prayer with the Prophet (ﷺ) and he offered prayer before the Khutba (sermon). ibn `Abbas added: After the prayer the Prophet (ﷺ) came towards (the rows of) the women and ordered them to give alms, and the women started putting their big and small rings in the garment of Bilal}}
\hadithdefcmd{bukhari}{5881}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ عِيدٍ فَصَلَّى رَكْعَتَيْنِ، لَمْ يُصَلِّ قَبْلُ وَلاَ بَعْدُ، ثُمَّ أَتَى النِّسَاءَ فَأَمَرَهُنَّ بِالصَّدَقَةِ، فَجَعَلَتِ الْمَرْأَةُ تَصَدَّقُ بِخُرْصِهَا وَسِخَابِهَا‏.‏\hadithno{5881}\hadithtrans{Narrated ibn `Abbas:The Prophet (ﷺ) came out on the day of `Id and offered a two-rak`at prayer, and he did not pray any rak`a before it, nor after it. Then he went towards the women and ordered them to give alms. The women started donating their earring and necklaces}}
\hadithdefcmd{bukhari}{5882}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدَةُ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ هَلَكَتْ قِلاَدَةٌ لأَسْمَاءَ، فَبَعَثَ النَّبِيُّ صلى الله عليه وسلم فِي طَلَبِهَا رِجَالاً، فَحَضَرَتِ الصَّلاَةُ وَلَيْسُوا عَلَى وُضُوءٍ وَلَمْ يَجِدُوا مَاءً، فَصَلَّوْا وَهُمْ عَلَى غَيْرِ وُضُوءٍ، فَذَكَرُوا ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ آيَةَ التَّيَمُّمِ‏.‏ زَادَ ابْنُ نُمَيْرٍ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ عَائِشَةَ اسْتَعَارَتْ مِنْ أَسْمَاءَ‏.‏\hadithno{5882}\hadithtrans{Narrated `Aisha:A necklace belonging to Asma' was lost, and the Prophet (ﷺ) sent men in its search. The time for the prayer became due and they were without ablution and they could not find water; therefore they prayed without ablution, They mentioned that to the Prophet (ﷺ) . Then Allah revealed the Verse of Tayammum. (`Aisha added: that she had borrowed (the necklace) from Asma}}
\hadithdefcmd{bukhari}{5883}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَدِيٌّ، قَالَ سَمِعْتُ سَعِيدًا، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى يَوْمَ الْعِيدِ رَكْعَتَيْنِ، لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا ثُمَّ أَتَى النِّسَاءَ وَمَعَهُ بِلاَلٌ فَأَمَرَهُنَّ بِالصَّدَقَةِ، فَجَعَلَتِ الْمَرْأَةُ تُلْقِي قُرْطَهَا‏.‏\hadithno{5883}\hadithtrans{Narrated Ibn `Abbas:"The Prophet (ﷺ) offered a two-rak`at prayer on `Id day and he did not offer any (Nawafil prayer) before or after it. He then went towards the women, and Bilal was accompanying him, and ordered them to give alms. And so the women started giving their earrings (etc)}}
\hadithdefcmd{bukhari}{5884}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا وَرْقَاءُ بْنُ عُمَرَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سُوقٍ مِنْ أَسْوَاقِ الْمَدِينَةِ فَانْصَرَفَ فَانْصَرَفْتُ فَقَالَ ‏"‏ أَيْنَ لُكَعُ ـ ثَلاَثًا ـ ادْعُ الْحَسَنَ بْنَ عَلِيٍّ ‏"‏‏.‏ فَقَامَ الْحَسَنُ بْنُ عَلِيٍّ يَمْشِي وَفِي عُنُقِهِ السِّخَابُ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ هَكَذَا، فَقَالَ الْحَسَنُ بِيَدِهِ، هَكَذَا فَالْتَزَمَهُ فَقَالَ ‏"‏ اللَّهُمَّ إِنِّي أُحِبُّهُ، فَأَحِبَّهُ، وَأَحِبَّ مَنْ يُحِبُّهُ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ فَمَا كَانَ أَحَدٌ أَحَبَّ إِلَىَّ مِنَ الْحَسَنِ بْنِ عَلِيٍّ بَعْدَ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا قَالَ‏.‏\hadithno{5884}\hadithtrans{Narrated Abu Huraira:I was with Allah's Messenger (ﷺ) in one of the Markets of Medina. He left (the market) and so did I. Then he asked thrice, "Where is the small (child)?" Then he said, "Call Al-Hasan bin `Ali." So Al-Hasan bin `Ali got up and started walking with a necklace (of beads) around his neck. The Prophet (ﷺ) stretched his hand out like this, and Al-Hasan did the same. The Prophet (ﷺ) embraced him and said, "O Allah! I love him, so please love him and love those who love him." Since Allah's Messenger (ﷺ) said that. nothing has been dearer to me than Al-Hasan}}
\hadithdefcmd{bukhari}{5885}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُتَشَبِّهِينَ مِنَ الرِّجَالِ بِالنِّسَاءِ، وَالْمُتَشَبِّهَاتِ مِنَ النِّسَاءِ بِالرِّجَالِ‏.‏ تَابَعَهُ عَمْرٌو أَخْبَرَنَا شُعْبَةُ‏.‏\hadithno{5885}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) cursed those men who are in the similitude (assume the manners) of women and those women who are in the similitude (assume the manners) of men}}
\hadithdefcmd{bukhari}{5886}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَعَنَ النَّبِيُّ صلى الله عليه وسلم الْمُخَنَّثِينَ مِنَ الرِّجَالِ، وَالْمُتَرَجِّلاَتِ مِنَ النِّسَاءِ وَقَالَ ‏ "‏ أَخْرِجُوهُمْ مِنْ بُيُوتِكُمْ ‏"‏‏.‏ قَالَ فَأَخْرَجَ النَّبِيُّ صلى الله عليه وسلم فُلاَنًا، وَأَخْرَجَ عُمَرُ فُلاَنًا‏.‏\hadithno{5886}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) cursed effeminate men (those men who are in the similitude (assume the manners of women) and those women who assume the manners of men, and he said, "Turn them out of your houses ." The Prophet (ﷺ) turned out such-and-such man, and `Umar turned out such-and-such woman}}
\hadithdefcmd{bukhari}{5887}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، أَنَّ عُرْوَةَ، أَخْبَرَهُ أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ أَخْبَرَتْهُ أَنَّ أُمَّ سَلَمَةَ أَخْبَرَتْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ عِنْدَهَا وَفِي الْبَيْتِ مُخَنَّثٌ، فَقَالَ لِعَبْدِ اللَّهِ أَخِي أُمِّ سَلَمَةَ يَا عَبْدَ اللَّهِ إِنْ فُتِحَ لَكُمْ غَدًا الطَّائِفُ، فَإِنِّي أَدُلُّكَ عَلَى بِنْتِ غَيْلاَنَ، فَإِنَّهَا تُقْبِلُ بِأَرْبَعٍ وَتُدْبِرُ بِثَمَانٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلَنَّ هَؤُلاَءِ عَلَيْكُنَّ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ تُقْبِلُ بِأَرْبَعٍ وَتُدْبِرُ بِثَمَانٍ يَعْنِي أَرْبَعَ عُكَنِ بَطْنِهَا، فَهْىَ تُقْبِلُ بِهِنَّ، وَقَوْلُهُ وَتُدْبِرُ بِثَمَانٍ‏.‏ يَعْنِي أَطْرَافَ هَذِهِ الْعُكَنِ الأَرْبَعِ، لأَنَّهَا مُحِيطَةٌ بِالْجَنْبَيْنِ حَتَّى لَحِقَتْ وَإِنَّمَا قَالَ بِثَمَانٍ‏.‏ وَلَمْ يَقُلْ بِثَمَانِيَةٍ‏.‏ وَوَاحِدُ الأَطْرَافِ وَهْوَ ذَكَرٌ، لأَنَّهُ لَمْ يَقُلْ ثَمَانِيَةَ أَطْرَافٍ‏.‏\hadithno{5887}\hadithtrans{Narrated Um Salama:that once the Prophet (ﷺ) was in her house, and an effeminate man was there too. The effeminate man said to `Abdullah, (Um Salama's brother) "0 `Abdullah! If Ta'if should be conquered tomorrow, I recommend you the daughter of Ghailan, for she is so fat that she has four curves in the front (of her belly) and eight at the back." So the Prophet (ﷺ) said (to his wives) "These effeminate (men) should not enter upon you (your houses)}}
\hadithdefcmd{bukhari}{5888}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، عَنْ حَنْظَلَةَ، عَنْ نَافِعٍ، قَالَ أَصْحَابُنَا عَنِ الْمَكِّيِّ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مِنَ الْفِطْرَةِ قَصُّ الشَّارِبِ ‏"‏‏.‏\hadithno{5888}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "To get the moustaches cut 'short is characteristic of the Fitra}}
\hadithdefcmd{bukhari}{5889}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ حَدَّثَنَا عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، رِوَايَةً ‏ "‏ الْفِطْرَةُ خَمْسٌ ـ أَوْ خَمْسٌ مِنَ الْفِطْرَةِ ـ الْخِتَانُ، وَالاِسْتِحْدَادُ، وَنَتْفُ الإِبْطِ، وَتَقْلِيمُ الأَظْفَارِ، وَقَصُّ الشَّارِبِ ‏"‏‏.‏\hadithno{5889}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Five practices are characteristics of the Fitra: circumcision, shaving the pubic region, clipping the nails and cutting the moustaches short}}
\hadithdefcmd{bukhari}{5890}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ حَنْظَلَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مِنَ الْفِطْرَةِ حَلْقُ الْعَانَةِ، وَتَقْلِيمُ الأَظْفَارِ، وَقَصُّ الشَّارِبِ ‏"‏‏.‏\hadithno{5890}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "To shave the pubic hair. to clip the nails and to cut the moustaches short, are characteristics of the Fitra}}
\hadithdefcmd{bukhari}{5891}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْفِطْرَةُ خَمْسٌ الْخِتَانُ، وَالاِسْتِحْدَادُ، وَقَصُّ الشَّارِبِ، وَتَقْلِيمُ الأَظْفَارِ، وَنَتْفُ الآبَاطِ ‏"‏‏.‏\hadithno{5891}\hadithtrans{Narrated Abu Huraira:I heard the Prophet (ﷺ) saying. "Five practices are characteristics of the Fitra: circumcision, shaving the pubic hair, cutting the moustaches short, clipping the nails, and depilating the hair of the armpits}}
\hadithdefcmd{bukhari}{5892}{حَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا عُمَرُ بْنُ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَالِفُوا الْمُشْرِكِينَ، وَفِّرُوا اللِّحَى، وَأَحْفُوا الشَّوَارِبَ ‏"‏‏.‏ وَكَانَ ابْنُ عُمَرَ إِذَا حَجَّ أَوِ اعْتَمَرَ قَبَضَ عَلَى لِحْيَتِهِ، فَمَا فَضَلَ أَخَذَهُ‏.‏\hadithno{5892}\hadithtrans{Narrated Nafi`:Ibn `Umar said, The Prophet (ﷺ) said, 'Do the opposite of what the pagans do. Keep the beards and cut the moustaches short.' Whenever Ibn `Umar performed the Hajj or `Umra, he used to hold his beard with his hand and cut whatever remained outside his hold}}
\hadithdefcmd{bukhari}{5893}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ انْهَكُوا الشَّوَارِبَ، وَأَعْفُوا اللِّحَى ‏"‏‏.‏\hadithno{5893}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Cut the moustaches short and leave the beard (as it is)}}
\hadithdefcmd{bukhari}{5894}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ سَأَلْتُ أَنَسًا أَخَضَبَ النَّبِيُّ صلى الله عليه وسلم قَالَ لَمْ يَبْلُغِ الشَّيْبَ إِلاَّ قَلِيلاً‏.‏\hadithno{5894}\hadithtrans{Narrated Muhammad bin Seereen:I asked Anas, "Did the Prophet (ﷺ) dye his hair?" Anas replied, "The Prophet (ﷺ) did not have except a few grey hairs}}
\hadithdefcmd{bukhari}{5895}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، قَالَ سُئِلَ أَنَسٌ عَنْ خِضَابِ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ إِنَّهُ لَمْ يَبْلُغْ مَا يَخْضِبُ، لَوْ شِئْتُ أَنْ أَعُدَّ شَمَطَاتِهِ فِي لِحْيَتِهِ‏.‏\hadithno{5895}\hadithtrans{Narrated Thabit:Anas was asked whether the Prophet (ﷺ) used a a hair dye or not. He replied, "The Prophet (ﷺ) did not have enough grey hair to dye, (such that) if I wanted to count the fading hairs in his beard (I could have)}}
\hadithdefcmd{bukhari}{5896}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، قَالَ أَرْسَلَنِي أَهْلِي إِلَى أُمِّ سَلَمَةَ بِقَدَحٍ مِنْ مَاءٍ ـ وَقَبَضَ إِسْرَائِيلُ ثَلاَثَ أَصَابِعَ ـ مِنْ فِضَّةٍ فِيهِ شَعَرٌ مِنْ شَعَرِ النَّبِيِّ صلى الله عليه وسلم وَكَانَ إِذَا أَصَابَ الإِنْسَانَ عَيْنٌ أَوْ شَىْءٌ بَعَثَ إِلَيْهَا مِخْضَبَهُ، فَاطَّلَعْتُ فِي الْجُلْجُلِ فَرَأَيْتُ شَعَرَاتٍ حُمْرًا‏.‏\hadithno{5896}\hadithtrans{Narrated IsraiI:`Uthman bin `Abdullah bin Mauhab said, "My people sent me with a bowl of water to Um Salama." Isra'il approximated three fingers ('indicating the small size of the container in which there was some hair of the Prophet. `Uthman added, "If any person suffered from evil eye or some other disease, he would send a vessel (containing water) to Um Salama. I looked into the container (that held the hair of the Prophet) and saw a few red hairs in it}}
\hadithdefcmd{bukhari}{5897}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سَلاَّمٌ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، قَالَ دَخَلْتُ عَلَى أُمِّ سَلَمَةَ فَأَخْرَجَتْ إِلَيْنَا شَعَرًا مِنْ شَعَرِ النَّبِيِّ صلى الله عليه وسلم مَخْضُوبًا‏.‏\hadithno{5897}\hadithtrans{Narrated `Uthman bin `Abdullah bin Mauhab:I went to Um Salama and she brought out for us some of the dyed hair of the Prophet}}
\hadithdefcmd{bukhari}{5898}{وَقَالَ لَنَا أَبُو نُعَيْمٍ حَدَّثَنَا نُصَيْرُ بْنُ أَبِي الأَشْعَثِ، عَنِ ابْنِ مَوْهَبٍ، أَنَّ أُمَّ سَلَمَةَ، أَرَتْهُ شَعَرَ النَّبِيِّ صلى الله عليه وسلم أَحْمَرَ‏.‏\hadithno{5898}\hadithtrans{Ibn Mauhab also said that Um Salama had shown him the red hair of the Prophet}}
\hadithdefcmd{bukhari}{5899}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ أَبِي سَلَمَةَ، وَسُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ الْيَهُودَ وَالنَّصَارَى لاَ يَصْبُغُونَ فَخَالِفُوهُمْ ‏"‏‏.‏\hadithno{5899}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Jews and Christians do not dye their hair so you should do the opposite of what they do}}
\hadithdefcmd{bukhari}{5900}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْسَ بِالطَّوِيلِ الْبَائِنِ، وَلاَ بِالْقَصِيرِ، وَلَيْسَ بِالأَبْيَضِ الأَمْهَقِ، وَلَيْسَ بِالآدَمِ، وَلَيْسَ بِالْجَعْدِ الْقَطَطِ، وَلاَ بِالسَّبْطِ، بَعَثَهُ اللَّهُ عَلَى رَأْسِ أَرْبَعِينَ سَنَةً، فَأَقَامَ بِمَكَّةَ عَشْرَ سِنِينَ، وَبِالْمَدِينَةِ عَشْرَ سِنِينَ، وَتَوَفَّاهُ اللَّهُ عَلَى رَأْسِ سِتِّينَ سَنَةً، وَلَيْسَ فِي رَأْسِهِ وَلِحْيَتِهِ عِشْرُونَ شَعَرَةً بَيْضَاءَ‏.‏\hadithno{5900}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) was neither conspicuously tall, nor short; neither, very white, nor tawny. His hair was neither much curled, nor very straight. Allah sent him (as an Apostle) at the age of forty (and after that) he stayed for ten years in Mecca, and for ten more years in Medina. Allah took him unto Him at the age of sixty, and he scarcely had ten white hairs on his head and in his beard}}
\hadithdefcmd{bukhari}{5901}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، سَمِعْتُ الْبَرَاءَ، يَقُولُ مَا رَأَيْتُ أَحَدًا أَحْسَنَ فِي حُلَّةٍ حَمْرَاءَ مِنَ النَّبِيِّ صلى الله عليه وسلم‏.‏ قَالَ بَعْضُ أَصْحَابِي عَنْ مَالِكٍ إِنَّ جُمَّتَهُ لَتَضْرِبُ قَرِيبًا مِنْ مَنْكِبَيْهِ‏.‏ قَالَ أَبُو إِسْحَاقَ سَمِعْتُهُ يُحَدِّثُهُ غَيْرَ مَرَّةٍ، مَا حَدَّثَ بِهِ قَطُّ إِلاَّ ضَحِكَ‏.‏ تَابَعَهُ شُعْبَةُ شَعَرُهُ يَبْلُغُ شَحْمَةَ أُذُنَيْهِ‏.‏\hadithno{5901}\hadithtrans{Narrated Al-Bara':I did not see anybody in a red cloak looking more handsome than the Prophet. Narrated Malik: The hair of the Prophet (ﷺ) used to hang near his shoulders. Abu Ishaq said, "I heard him relate it more than once. He always laughed when he related it." Narrated Shu`ba: The hair of the Prophet (ﷺ) used to hang down to the earlobes}}
\hadithdefcmd{bukhari}{5902}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُرَانِي اللَّيْلَةَ عِنْدَ الْكَعْبَةِ، فَرَأَيْتُ رَجُلاً آدَمَ كَأَحْسَنِ مَا أَنْتَ رَاءٍ مِنْ أُدْمِ الرِّجَالِ، لَهُ لِمَّةٌ كَأَحْسَنِ مَا أَنْتَ رَاءٍ مِنَ اللِّمَمِ، قَدْ رَجَّلَهَا، فَهْىَ تَقْطُرُ مَاءً مُتَّكِئًا عَلَى رَجُلَيْنِ، أَوْ عَلَى عَوَاتِقِ رَجُلَيْنِ، يَطُوفُ بِالْبَيْتِ فَسَأَلْتُ مَنْ هَذَا فَقِيلَ الْمَسِيحُ ابْنُ مَرْيَمَ‏.‏ وَإِذَا أَنَا بِرَجُلٍ جَعْدٍ، قَطَطٍ، أَعْوَرِ الْعَيْنِ الْيُمْنَى كَأَنَّهَا عِنَبَةٌ طَافِيَةٌ، فَسَأَلْتُ مَنْ هَذَا فَقِيلَ الْمَسِيحُ الدَّجَّالُ ‏"‏‏.‏\hadithno{5902}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Today I saw myself in a dream near the Ka`ba. I saw a whitish brown man, the handsomest of all brown men you might ever see. He had the most beautiful Limma (hair hanging down to the earlobes) you might ever see. He had combed it and it was dripping water; and he was performing the Tawaf around the Ka`ba leaning on two men or on the shoulders of two men. I asked, "Who is this?" It was said. "Messiah, the son of Mary." Suddenly I saw a curly-haired man, blind in the right eye which looked like a protruding out grape. I asked, "Who is this?" It was said, "He is Masiah Ad-Dajjal}}
\hadithdefcmd{bukhari}{5903}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسٌ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَضْرِبُ شَعَرُهُ مَنْكِبَيْهِ‏.‏\hadithno{5903}\hadithtrans{Narrated Anas : The hair of the Prophet (ﷺ) used to hang down up to his shoulders}}
\hadithdefcmd{bukhari}{5904}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، كَانَ يَضْرِبُ شَعَرُ النَّبِيِّ صلى الله عليه وسلم مَنْكِبَيْهِ‏.‏\hadithno{5904}\hadithtrans{Narrated Anas: The head-hair of the Prophet (ﷺ) used to hang down to his shoulders}}
\hadithdefcmd{bukhari}{5905}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ عَنْ شَعَرِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ كَانَ شَعَرُ رَسُولِ اللَّهِ صلى الله عليه وسلم رَجِلاً، لَيْسَ بِالسَّبِطِ، وَلاَ الْجَعْدِ، بَيْنَ أُذُنَيْهِ وَعَاتِقِهِ‏.‏\hadithno{5905}\hadithtrans{Narrated Qatada:l asked Anas bin Malik about the hair of Allah's Messenger (ﷺ). He said, "The hair of Allah's Messenger (ﷺ) was neither much straight, nor much curly, and it used to hang down till between his shoulders and his earlobes}}
\hadithdefcmd{bukhari}{5906}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا جَرِيرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم ضَخْمَ الْيَدَيْنِ، لَمْ أَرَ بَعْدَهُ مِثْلَهُ، وَكَانَ شَعَرُ النَّبِيِّ صلى الله عليه وسلم رَجِلاً، لاَ جَعْدَ، وَلاَ سَبِطَ‏.‏\hadithno{5906}\hadithtrans{Narrated Anas:The Prophet (ﷺ) had big hands, and I have never seen anybody like him after him. The hair of the Prophet was wavy, neither curly nor straight}}
\hadithdefcmd{bukhari}{5907}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم ضَخْمَ الْيَدَيْنِ وَالْقَدَمَيْنِ حَسَنَ الْوَجْهِ، لَمْ أَرَ بَعْدَهُ وَلاَ قَبْلَهُ مِثْلَهُ، وَكَانَ بَسِطَ الْكَفَّيْنِ‏.‏\hadithno{5907}\hadithtrans{Narrated Anas:The Prophet (ﷺ) had big hands and feet, and I have not seen anybody like him, neither before nor after him, and his palms were soft}}
\hadithdefcmd{bukhari}{5909}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا مُعَاذُ بْنُ هَانِئٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ،‏.‏ أَوْ عَنْ رَجُلٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم ضَخْمَ الْقَدَمَيْنِ، حَسَنَ الْوَجْهِ، لَمْ أَرَ بَعْدَهُ مِثْلَهُ‏.‏\hadithno{5909}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) had big feet and a good-looking face and I have not seen anybody like him after him}}
\hadithdefcmd{bukhari}{5910}{وَقَالَ هِشَامٌ عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، كَانَ النَّبِيُّ صلى الله عليه وسلم شَثْنَ الْقَدَمَيْنِ وَالْكَفَّيْنِ‏.‏\hadithno{5910}\hadithtrans{Narrated Anas:The Prophet (ﷺ) had big feet and hands}}
\hadithdefcmd{bukhari}{5912}{وَقَالَ أَبُو هِلاَلٍ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ،‏.‏ أَوْ جَابِرِ بْنِ عَبْدِ اللَّهِ كَانَ النَّبِيُّ صلى الله عليه وسلم ضَخْمَ الْكَفَّيْنِ وَالْقَدَمَيْنِ، لَمْ أَرَ بَعْدَهُ شَبَهًا لَهُ‏.‏\hadithno{5912}\hadithtrans{Narrated Anas or Jabir bin `Abdullah:The Prophet (ﷺ) had big hands and feet and I have not seen anybody like him after him}}
\hadithdefcmd{bukhari}{5913}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُجَاهِدٍ، قَالَ كُنَّا عِنْدَ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ فَذَكَرُوا الدَّجَّالَ فَقَالَ إِنَّهُ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ لَمْ أَسْمَعْهُ قَالَ ذَاكَ وَلَكِنَّهُ قَالَ ‏ "‏ أَمَّا إِبْرَاهِيمُ فَانْظُرُوا إِلَى صَاحِبِكُمْ، وَأَمَّا مُوسَى فَرَجُلٌ آدَمُ جَعْدٌ، عَلَى جَمَلٍ أَحْمَرَ مَخْطُومٍ بِخُلْبَةٍ، كَأَنِّي أَنْظُرُ إِلَيْهِ إِذِ انْحَدَرَ فِي الْوَادِي يُلَبِّي ‏"‏‏.‏\hadithno{5913}\hadithtrans{Narrated Mujahid:We were with Ibn `Abbas and the people mentioned Ad-Dajjal. Someone said, "The word 'Kafir' (unbeliever) is written in between his (Ad-Dajjal's) eyes." Ibn `Abbas said, "I have not heard the Prophet saying this, but he said, 'As regards Abraham, he looks like your companion (i.e. the Prophet, Muhammad), and as regards Moses, he is a brown curly haired man riding a camel and reigned with a strong jute rope, as if I am now looking at him getting down in the valley and saying, "Labbaik}}
\hadithdefcmd{bukhari}{5914}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ سَمِعْتُ عُمَرَ ـ رضى الله عنه ـ يَقُولُ مَنْ ضَفَّرَ فَلْيَحْلِقْ، وَلاَ تَشَبَّهُوا بِالتَّلْبِيدِ‏.‏ وَكَانَ ابْنُ عُمَرَ يَقُولُ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مُلَبِّدًا‏.‏\hadithno{5914}\hadithtrans{Narrated `Abdullah bin `Umar:I heard `Umar saying, "Whoever braids his hair should shave it (on finishing Ihram). You'd better not do, something like Talbid." Ibn `Umar used to say: "I saw Allah's Messenger (ﷺ) with his hair stuck together with gum}}
\hadithdefcmd{bukhari}{5915}{حَدَّثَنِي حِبَّانُ بْنُ مُوسَى، وَأَحْمَدُ بْنُ مُحَمَّدٍ، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ مُلَبِّدًا يَقُولُ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ، لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ، إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏‏.‏ لاَ يَزِيدُ عَلَى هَؤُلاَءِ الْكَلِمَاتِ‏.‏\hadithno{5915}\hadithtrans{Narrated Ibn `Umar:I heard Allah's Messenger (ﷺ), while he was in the state of Ihram and his hair was stuck together with gum, saying, "Labbaik, Allahumma Labbaik, Labbaik La Sharika laka Labbaik. Inn-al-Hamda Wan-Ni'mata Laka wal-Mulk, La Sharika Lak." He did not add anything to those words}}
\hadithdefcmd{bukhari}{5916}{حَدَّثَنِي إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ حَفْصَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَا شَأْنُ النَّاسِ حَلُّوا بِعُمْرَةٍ، وَلَمْ تَحْلِلْ أَنْتَ مِنْ عُمْرَتِكَ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي، وَقَلَّدْتُ هَدْيِي، فَلاَ أَحِلُّ حَتَّى أَنْحَرَ ‏"‏‏.‏\hadithno{5916}\hadithtrans{Narrated Hafsa:(the wife of the Prophet) I said, "O Allah's Messenger (ﷺ)! Why have the people finished their Ihram after performing the `Umra while you have not finished your Ihram after your `Umra?" He said, "I have done Talbid (of my hair) and have decorated my Hadis with garlands, so I shall not finish my Ihram till I have slaughtered my Hadi (animal for sacrifice)}}
\hadithdefcmd{bukhari}{5917}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُحِبُّ مُوَافَقَةَ أَهْلِ الْكِتَابِ فِيمَا لَمْ يُؤْمَرْ فِيهِ، وَكَانَ أَهْلُ الْكِتَابِ يَسْدِلُونَ أَشْعَارَهُمْ، وَكَانَ الْمُشْرِكُونَ يَفْرُقُونَ رُءُوسَهُمْ، فَسَدَلَ النَّبِيُّ صلى الله عليه وسلم نَاصِيَتَهُ، ثُمَّ فَرَقَ بَعْدُ‏.‏\hadithno{5917}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) used to copy the people of the Scriptures in matters in which there was no order from Allah. The people of the Scripture used to let their hair hang down while the pagans used to part their hair. So the Prophet (ﷺ) let his hair hang down first, but later on he parted it}}
\hadithdefcmd{bukhari}{5918}{حَدَّثَنَا أَبُو الْوَلِيدِ، وَعَبْدُ اللَّهِ بْنُ رَجَاءٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ النَّبِيِّ صلى الله عليه وسلم وَهْوَ مُحْرِمٌ‏.‏ قَالَ عَبْدُ اللَّهِ فِي مَفْرِقِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5918}\hadithtrans{Narrated `Aisha:As if I am now looking at the shine of the hair parting of the Prophet (ﷺ) while he was in the state of Ihram}}
\hadithdefcmd{bukhari}{5919}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْفَضْلُ بْنُ عَنْبَسَةَ، أَخْبَرَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بِتُّ لَيْلَةً عِنْدَ مَيْمُونَةَ بِنْتِ الْحَارِثِ خَالَتِي، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَهَا فِي لَيْلَتِهَا ـ قَالَ ـ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ، فَقُمْتُ عَنْ يَسَارِهِ ـ قَالَ ـ فَأَخَذَ بِذُؤَابَتِي فَجَعَلَنِي عَنْ يَمِينِهِ‏.‏ حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، بِهَذَا، وَقَالَ بِذُؤَابَتِي أَوْ بِرَأْسِي‏.‏\hadithno{5919}\hadithtrans{Narrated Ibn `Abbas:Once I stayed overnight in the house of my aunt Maimuna bint Al-Harith and Allah's Messenger (ﷺ) was with her as it was her turn. Allah's Messenger (ﷺ) got up to offer the night prayer. I stood on his left but he took hold of my two locks of hair and made me stand on his right. Narrated Abu Bishr: (the above Hadith) but he quoted: Ibn `Abbas said, (took hold of) my two braids on my head}}
\hadithdefcmd{bukhari}{5920}{حَدَّثَنِي مُحَمَّدٌ، قَالَ أَخْبَرَنِي مَخْلَدٌ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ حَفْصٍ، أَنَّ عُمَرَ بْنَ نَافِعٍ، أَخْبَرَهُ عَنْ نَافِعٍ، مَوْلَى عَبْدِ اللَّهِ أَنَّهُ سَمِعَ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ الْقَزَعِ‏.‏ قَالَ عُبَيْدُ اللَّهِ قُلْتُ وَمَا الْقَزَعُ فَأَشَارَ لَنَا عُبَيْدُ اللَّهِ قَالَ إِذَا حَلَقَ الصَّبِيَّ وَتَرَكَ هَا هُنَا شَعَرَةً وَهَا هُنَا وَهَا هُنَا‏.‏ فَأَشَارَ لَنَا عُبَيْدُ اللَّهِ إِلَى نَاصِيَتِهِ وَجَانِبَىْ رَأْسِهِ‏.‏ قِيلَ لِعُبَيْدِ اللَّهِ فَالْجَارِيَةُ وَالْغُلاَمُ قَالَ لاَ أَدْرِي هَكَذَا قَالَ الصَّبِيِّ‏.‏ قَالَ عُبَيْدُ اللَّهِ وَعَاوَدْتُهُ فَقَالَ أَمَّا الْقُصَّةُ وَالْقَفَا لِلْغُلاَمِ فَلاَ بَأْسَ بِهِمَا وَلَكِنَّ الْقَزَعَ أَنْ يُتْرَكَ بِنَاصِيَتِهِ شَعَرٌ، وَلَيْسَ فِي رَأْسِهِ غَيْرُهُ، وَكَذَلِكَ شَقُّ رَأْسِهِ هَذَا وَهَذَا‏.‏\hadithno{5920}\hadithtrans{Narrated Ubaidullah bin Hafs:that `Umar bin Nafi` told him that Nafi`, Maula `Abdullah had heard `Umar saying, "I heard Allah's Apostle forbidding Al-Qaza'." 'Ubaidullah added: I said, "What is Al-Qaza'?" 'Ubaidullah pointed (towards his head) to show us and added, "Nafi` said, 'It is when a boy has his head shaved leaving a tuft of hair here and a tuft of hair there." Ubaidullah pointed towards his forehead and the sides of his head. 'Ubaidullah was asked, "Does this apply to both girls and boys?" He said, "I don't know, but Nafi` said, 'The boy.'" 'Ubaidullah added, "I asked Nafi` again, and he said, 'As for leaving hair on the temples and the back part of the boy's head, there is no harm, but Al-Qaza' is to leave a tuft of hair on his forehead unshaved while there is no hair on the rest of his head, and also to leave hair on either side of his head}}
\hadithdefcmd{bukhari}{5921}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُثَنَّى بْنِ عَبْدِ اللَّهِ بْنِ أَنَسِ بْنِ مَالِكٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْقَزَعِ‏.‏\hadithno{5921}\hadithtrans{Narrated (Abdullah) bin `Umar:Allah's Messenger (ﷺ) forbade Al-Qaza' (leaving a tuft of hair here and there after shaving one's head)}}
\hadithdefcmd{bukhari}{5922}{حَدَّثَنِي أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ النَّبِيَّ صلى الله عليه وسلم بِيَدِي لِحُرْمِهِ، وَطَيَّبْتُهُ بِمِنًى قَبْلَ أَنْ يُفِيضَ‏.‏\hadithno{5922}\hadithtrans{Narrated `Aisha:I applied perfume to the Prophet (ﷺ) with my own hands when he wanted to assume the state of Ihram, and I also perfumed him at Mina before he departed from there (to perform Tawaf-al-Ifada)}}
\hadithdefcmd{bukhari}{5923}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُطَيِّبُ النَّبِيَّ صلى الله عليه وسلم بِأَطْيَبِ مَا يَجِدُ، حَتَّى أَجِدَ وَبِيصَ الطِّيبِ فِي رَأْسِهِ وَلِحْيَتِهِ‏.‏\hadithno{5923}\hadithtrans{Narrated `Aisha:I used to perfume Allah's Messenger (ﷺ) with the best scent available till I saw the shine of the scent on his head and shine beard}}
\hadithdefcmd{bukhari}{5924}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَجُلاً، اطَّلَعَ مِنْ جُحْرٍ فِي دَارِ النَّبِيِّ صلى الله عليه وسلم وَالنَّبِيُّ صلى الله عليه وسلم يَحُكُّ رَأْسَهُ بِالْمِدْرَى فَقَالَ ‏ "‏ لَوْ عَلِمْتُ أَنَّكَ تَنْظُرُ لَطَعَنْتُ بِهَا فِي عَيْنِكَ، إِنَّمَا جُعِلَ الإِذْنُ مِنْ قِبَلِ الأَبْصَارِ ‏"‏‏.‏\hadithno{5924}\hadithtrans{Narrated Sa`d:A man peeped into the house of the Prophet (ﷺ) through a hole while the Prophet (ﷺ) was scratching his head with a Midrai (a certain kind of comb). On that the Prophet (ﷺ) said (to him), "If I had known you had been looking, then I would have pierced your eye with that instrument, because the asking of permission has been ordained so that one would not see things unlawfully}}
\hadithdefcmd{bukhari}{5925}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كُنْتُ أُرَجِّلُ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا حَائِضٌ‏.‏ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، مِثْلَهُ‏.‏\hadithno{5925}\hadithtrans{Narrated `Aisha:I used to comb the hair of Allah's Messenger (ﷺ) during my periods. This hadith also reaches us through another chain}}
\hadithdefcmd{bukhari}{5926}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَشْعَثَ بْنِ سُلَيْمٍ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يُعْجِبُهُ التَّيَمُّنُ مَا اسْتَطَاعَ فِي تَرَجُّلِهِ وَوُضُوئِهِ‏.‏\hadithno{5926}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to like to start from the right side as far as possible in combing and in performing ablution}}
\hadithdefcmd{bukhari}{5927}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ عَمَلِ ابْنِ آدَمَ لَهُ، إِلاَّ الصَّوْمَ فَإِنَّهُ لِي، وَأَنَا أَجْزِي بِهِ، وَلَخَلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏‏.‏\hadithno{5927}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "(Allah said), 'Every good deed of Adam's son is for him except fasting; it is for Me. and I shall reward (the fasting person) for it.' Verily, the smell of the mouth of a fasting person is better to Allah than the smell of musk}}
\hadithdefcmd{bukhari}{5928}{حَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ عُثْمَانَ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كُنْتُ أُطَيِّبُ النَّبِيَّ صلى الله عليه وسلم عِنْدَ إِحْرَامِهِ بِأَطْيَبِ مَا أَجِدُ‏.‏\hadithno{5928}\hadithtrans{Narrated `Aisha:used to perfume the Prophet (ﷺ) before his assuming the state of with the best scent available}}
\hadithdefcmd{bukhari}{5929}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي ثُمَامَةُ بْنُ عَبْدِ اللَّهِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّهُ كَانَ لاَ يَرُدُّ الطِّيبَ، وَزَعَمَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَرُدُّ الطِّيبَ‏.‏\hadithno{5929}\hadithtrans{Narrated Thumama bin `Abdullah;:Anas never used to refuse (a gift of) scent and used to say that the Prophet (ﷺ) never used to refuse (a gift of) scent}}
\hadithdefcmd{bukhari}{5930}{حَدَّثَنَا عُثْمَانُ بْنُ الْهَيْثَمِ، أَوْ مُحَمَّدٌ عَنْهُ عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عُمَرُ بْنُ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، سَمِعَ عُرْوَةَ، وَالْقَاسِمَ، يُخْبِرَانِ عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ بِذَرِيرَةٍ فِي حَجَّةِ الْوَدَاعِ، لِلْحِلِّ وَالإِحْرَامِ‏.‏\hadithno{5930}\hadithtrans{Narrated `Aisha:During Hajjat-al-Wada`, I perfumed Allah's Messenger (ﷺ) with Dharira with my own hands, both on his assuming Ihram and on finishing it}}
\hadithdefcmd{bukhari}{5931}{حَدَّثَنَا عُثْمَانُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، لَعَنَ اللَّهُ الْوَاشِمَاتِ، وَالْمُسْتَوْشِمَاتِ، وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ، الْمُغَيِّرَاتِ خَلْقَ اللَّهِ تَعَالَى، مَالِي لاَ أَلْعَنُ مَنْ لَعَنَ النَّبِيُّ صلى الله عليه وسلم وَهْوَ فِي كِتَابِ اللَّهِ ‏\{‏وَمَا آتَاكُمُ الرَّسُولُ فَخُذُوهُ‏\}‏‏.‏\hadithno{5931}\hadithtrans{Narrated `Abdullah:Allah has cursed those women who practise tattooing and those who get themselves tattooed, and those who remove their face hairs, and those who create a space between their teeth artificially to look beautiful, and such women as change the features created by Allah. Why then should I not curse those whom the Prophet (ﷺ) has cursed? And that is in Allah's Book. i.e. His Saying: 'And what the Apostle gives you take it and what he forbids you abstain (from it)}}
\hadithdefcmd{bukhari}{5932}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، عَامَ حَجَّ وَهْوَ عَلَى الْمِنْبَرِ، وَهْوَ يَقُولُ ـ وَتَنَاوَلَ قُصَّةً مِنْ شَعَرٍ كَانَتْ بِيَدِ حَرَسِيٍّ ـ أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ مِثْلِ هَذِهِ وَيَقُولُ ‏ "‏ إِنَّمَا هَلَكَتْ بَنُو إِسْرَائِيلَ حِينَ اتَّخَذَ هَذِهِ نِسَاؤُهُمْ ‏"‏‏.‏\hadithno{5932}\hadithtrans{Narrated Humaid bin `Abdur-Rahman bin `Auf:that in the year he performed Hajj. he heard Mu'awiya bin Abi Sufyan, who was on the pulpit and was taking a tuft of hair from one of his guards, saying, "Where are your religious learned men? I heard Allah's Messenger (ﷺ) forbidding this (false hair) and saying, 'The children of Israel were destroyed when their women started using this}}
\hadithdefcmd{bukhari}{5933}{وَقَالَ ابْنُ أَبِي شَيْبَةَ حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا فُلَيْحٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ، وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏"‏‏.‏\hadithno{5933}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah has cursed the lady who artificially lengthens (her or someone else's) hair and the one who gets her hair lengthened and the One who tattoos (herself or someone else) and the one who gets herself tattooed}}
\hadithdefcmd{bukhari}{5934}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ الْحَسَنَ بْنَ مُسْلِمِ بْنِ يَنَّاقٍ، يُحَدِّثُ عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ جَارِيَةً، مِنَ الأَنْصَارِ تَزَوَّجَتْ، وَأَنَّهَا مَرِضَتْ فَتَمَعَّطَ شَعَرُهَا، فَأَرَادُوا أَنْ يَصِلُوهَا فَسَأَلُوا النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ ‏"‏‏.‏ تَابَعَهُ ابْنُ إِسْحَاقَ عَنْ أَبَانَ بْنِ صَالِحٍ عَنِ الْحَسَنِ عَنْ صَفِيَّةَ عَنْ عَائِشَةَ‏.‏\hadithno{5934}\hadithtrans{Narrated `Aisha:An Ansari girl was married and she became sick and all her hair fell out intending to provide her with false hair. They asked the Prophet (ﷺ) who said, "Allah has cursed the lady who artificially lengthens (her or someone else's) hair and also the one who gets her hair lengthened}}
\hadithdefcmd{bukhari}{5935}{حَدَّثَنِي أَحْمَدُ بْنُ الْمِقْدَامِ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مَنْصُورُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَتْنِي أُمِّي، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ أَنَّ امْرَأَةً، جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي أَنْكَحْتُ ابْنَتِي، ثُمَّ أَصَابَهَا شَكْوَى فَتَمَرَّقَ رَأْسُهَا، وَزَوْجُهَا يَسْتَحِثُّنِي بِهَا أَفَأَصِلُ رَأْسَهَا فَسَبَّ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ‏.‏\hadithno{5935}\hadithtrans{Narrated Asma:(the daughter of Abu' Bakr) A woman came to Allah's Messenger (ﷺ) and said, "I married my daughter to someone, but she became sick and all her hair fell out, and (because of that) her husband does not like her. May I let her use false hair?" On that the Prophet (ﷺ) cursed such a lady as artificially lengthening (her or someone else's) hair or got her hair lengthened artificially}}
\hadithdefcmd{bukhari}{5936}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنِ امْرَأَتِهِ، فَاطِمَةَ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ لَعَنَ النَّبِيُّ صلى الله عليه وسلم الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ‏.‏\hadithno{5936}\hadithtrans{Narrated Asma':(the daughter of Abu Bakr) Allah's Messenger (ﷺ) has cursed such a lady as artificially lengthening (her or someone else's) hair or gets her hair lengthened}}
\hadithdefcmd{bukhari}{5937}{حَدَّثَنِي مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ، وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏"‏‏.‏ قَالَ نَافِعٌ الْوَشْمُ فِي اللِّثَةِ‏.‏\hadithno{5937}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Allah has cursed such a lady as lengthens (her or someone else's) hair artificially or gets it lengthened, and also a lady who tattoos (herself or someone else) or gets herself tattooed}}
\hadithdefcmd{bukhari}{5938}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ قَدِمَ مُعَاوِيَةُ الْمَدِينَةَ آخِرَ قَدْمَةٍ قَدِمَهَا، فَخَطَبَنَا فَأَخْرَجَ كُبَّةً مِنْ شَعَرٍ قَالَ مَا كُنْتُ أَرَى أَحَدًا يَفْعَلُ هَذَا غَيْرَ الْيَهُودِ، إِنَّ النَّبِيَّ صلى الله عليه وسلم سَمَّاهُ الزُّورَ‏.‏ يَعْنِي الْوَاصِلَةَ فِي الشَّعَرِ‏.‏\hadithno{5938}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:Mu'awiya came to Medina for the last time and delivered a sermon. He took out a tuft of hair and said, "I thought that none used to do this (i.e. use false hair) except Jews. The Prophet (ﷺ) labelled such practice, (i.e. the use of false hair), as cheating}}
\hadithdefcmd{bukhari}{5939}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ لَعَنَ عَبْدُ اللَّهِ الْوَاشِمَاتِ، وَالْمُتَنَمِّصَاتِ، وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ، الْمُغَيِّرَاتِ خَلْقَ اللَّهِ‏.‏ فَقَالَتْ أُمُّ يَعْقُوبَ مَا هَذَا قَالَ عَبْدُ اللَّهِ وَمَا لِيَ لاَ أَلْعَنُ مَنْ لَعَنَ رَسُولُ اللَّهِ، وَفِي كِتَابِ اللَّهِ‏.‏ قَالَتْ وَاللَّهِ لَقَدْ قَرَأْتُ مَا بَيْنَ اللَّوْحَيْنِ فَمَا وَجَدْتُهُ‏.‏ قَالَ وَاللَّهِ لَئِنْ قَرَأْتِيهِ لَقَدْ وَجَدْتِيهِ ‏\{‏وَمَا آتَاكُمُ الرَّسُولُ فَخُذُوهُ وَمَا نَهَاكُمْ عَنْهُ فَانْتَهُوا‏\}‏‏.‏\hadithno{5939}\hadithtrans{Narrated 'Alqama:`Abdullah cursed those women who practiced tattooing and those who removed hair from their faces and those who created spaces between their teeth artificially to look beautiful, such ladies as changed what Allah has created. Um Ya'qub said, "What is that?" `Abdullah said, "Why should I not curse those who were cursed by Allah's Messenger (ﷺ) and are referred to in Allah's Book?" She said to him "By Allah, I have read the whole Qur'an but I have not found such a thing. `Abdullah said, "By Allah, if you had read it (carefully) you would have found it. (Allah says:) 'And what the Apostle gives you take it and what he forbids you abstain (from it)}}
\hadithdefcmd{bukhari}{5940}{حَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ لَعَنَ النَّبِيُّ صلى الله عليه وسلم الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ، وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ‏.‏\hadithno{5940}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) has cursed the lady who lengthens her hair artificially and the one who gets her hair lengthened, and also the lady who tattoos (herself or others) and the one who gets herself tattooed}}
\hadithdefcmd{bukhari}{5941}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا هِشَامٌ، أَنَّهُ سَمِعَ فَاطِمَةَ بِنْتَ الْمُنْذِرِ، تَقُولُ سَمِعْتُ أَسْمَاءَ، قَالَتْ سَأَلَتِ امْرَأَةٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي أَصَابَتْهَا الْحَصْبَةُ، فَامَّرَقَ شَعَرُهَا، وَإِنِّي زَوَّجْتُهَا أَفَأَصِلُ فِيهِ فَقَالَ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمَوْصُولَةَ ‏"‏‏.‏\hadithno{5941}\hadithtrans{Narrated Asma':A woman asked the Prophet (ﷺ) saying, "O Allah's Messenger (ﷺ)! My daughter got measles and her hair fell out. Now that I got her married, may I let her use false hair?" He said (to her), "Allah has cursed the lady who lengthens hair artificially and the one who gets her hair lengthened artificially}}
\hadithdefcmd{bukhari}{5942}{حَدَّثَنِي يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا صَخْرُ بْنُ جُوَيْرِيَةَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم أَوْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْوَاشِمَةُ وَالْمُوتَشِمَةُ، وَالْوَاصِلَةُ وَالْمُسْتَوْصِلَةُ ‏"‏‏.‏ يَعْنِي لَعَنَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{5942}\hadithtrans{Narrated Ibn `Umar:I heard the Prophet (ﷺ) saying, (or the Prophet (ﷺ) said), "Allah has cursed the lady who practices tattooing and that who gets it done for herself, and also the lady who lengthens hair artificially and that who gets her hair lengthened artificially." The Prophet (ﷺ) has cursed such ladies}}
\hadithdefcmd{bukhari}{5943}{حَدَّثَنِي مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ لَعَنَ اللَّهُ الْوَاشِمَاتِ، وَالْمُسْتَوْشِمَاتِ، وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ، الْمُغَيِّرَاتِ خَلْقَ اللَّهِ، مَا لِي لاَ أَلْعَنُ مَنْ لَعَنَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي كِتَابِ اللَّهِ‏.‏\hadithno{5943}\hadithtrans{Narrated Ibn Mas`ud:Allah has cursed those women who practise tattooing or get it done for themselves, and those who remove hair from their faces, and those who create spaces between their teeth artificially to look beautiful, such ladies as change the features created by Allah. Why then shall I not curse those whom Allah's Messenger (ﷺ) has cursed and who are cursed in Allah's Book too?}}
\hadithdefcmd{bukhari}{5944}{حَدَّثَنِي يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعَيْنُ حَقٌّ ‏"‏‏.‏ وَنَهَى عَنِ الْوَشْمِ‏.‏\hadithno{5944}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The evil eye is a fact," and he forbade tattooing}}
\hadithdefcmd{bukhari}{5944p2}{حَدَّثَنِي ابْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، قَالَ ذَكَرْتُ لِعَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ حَدِيثَ مَنْصُورٍ عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ،، فَقَالَ سَمِعْتُهُ مِنْ أُمِّ يَعْقُوبَ، عَنْ عَبْدِ اللَّهِ، مِثْلَ حَدِيثِ مَنْصُورٍ‏.‏\hadithno{5944.2}\hadithtrans{Narrated `Abdullah:(As above)}}
\hadithdefcmd{bukhari}{5945}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، قَالَ رَأَيْتُ أَبِي فَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الدَّمِ، وَثَمَنِ الْكَلْبِ، وَآكِلِ الرِّبَا وَمُوكِلِهِ، وَالْوَاشِمَةِ وَالْمُسْتَوْشِمَةِ‏.‏\hadithno{5945}\hadithtrans{Narrated Abu Juhaifa:The Prophet (ﷺ) forbade the use of the price of blood and the price of a dog, the one who takes (eats) usury the one who gives usury, the woman who practises tattooing and the woman who gets herself tattooed}}
\hadithdefcmd{bukhari}{5946}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ عُمَرُ بِامْرَأَةٍ تَشِمُ فَقَامَ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ مَنْ سَمِعَ مِنَ النَّبِيِّ صلى الله عليه وسلم فِي الْوَشْمِ فَقَالَ أَبُو هُرَيْرَةَ فَقُمْتُ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ أَنَا سَمِعْتُ‏.‏ قَالَ مَا سَمِعْتَ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَشِمْنَ وَلاَ تَسْتَوْشِمْنَ ‏"‏‏.‏\hadithno{5946}\hadithtrans{Narrated Abu Huraira:A woman who used to practise tattooing was brought to `Umar. `Umar got up and said, "I beseech you by Allah, which of you heard the Prophet (ﷺ) saying something about tattooing?" I got up and said, "O chief of the Believers! I heard something." He said, "What did you hear?" I said, "I heard the Prophet (addressing the ladies), saying, 'Do not practise tattooing and do not get yourselves tattooed}}
\hadithdefcmd{bukhari}{5947}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ لَعَنَ النَّبِيُّ صلى الله عليه وسلم الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ، وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ‏.‏\hadithno{5947}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) has cursed the lady who lengthens hair artificially and that who gets her hair lengthened in such away, and the lady who practises tattooing and that who gets it done for herself}}
\hadithdefcmd{bukhari}{5948}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ لَعَنَ اللَّهُ الْوَاشِمَاتِ وَالْمُسْتَوْشِمَاتِ، وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ، الْمُغَيِّرَاتِ خَلْقَ اللَّهِ‏.‏ مَا لِي لاَ أَلْعَنُ مَنْ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي كِتَابِ اللَّهِ‏.‏\hadithno{5948}\hadithtrans{Narrated `Abdullah:Allah has cursed those women who practise tattooing and those who get it done for themselves, and those who remove hair from their faces, and those who artificially create spaces between their teeth to look beautiful, such women as alter the features created by Allah. Why should I not then curse those whom Allah's Messenger (ﷺ) has cursed and that is in Allah's Book?}}
\hadithdefcmd{bukhari}{5949}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي طَلْحَةَ ـ رضى الله عنهم ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ تَصَاوِيرُ ‏"‏‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ، سَمِعَ ابْنَ عَبَّاسٍ، سَمِعْتُ أَبَا طَلْحَةَ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{5949}\hadithtrans{Narrated Abu Talha:The Prophet (ﷺ) said, "Angels do not enter a house in which there is a dog or there are pictures}}
\hadithdefcmd{bukhari}{5950}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، قَالَ كُنَّا مَعَ مَسْرُوقٍ فِي دَارِ يَسَارِ بْنِ نُمَيْرٍ، فَرَأَى فِي صُفَّتِهِ تَمَاثِيلَ فَقَالَ سَمِعْتُ عَبْدَ اللَّهِ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَشَدَّ النَّاسِ عَذَابًا عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ الْمُصَوِّرُونَ ‏"‏‏.‏\hadithno{5950}\hadithtrans{Narrated Muslim:We were with Masruq at the house of Yasar bin Numair. Masruq saw pictures on his terrace and said, "I heard `Abdullah saying that he heard the Prophet (ﷺ) saying, "The people who will receive the severest punishment from Allah will be the picture makers}}
\hadithdefcmd{bukhari}{5951}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الَّذِينَ يَصْنَعُونَ هَذِهِ الصُّوَرَ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ يُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏‏.‏\hadithno{5951}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Those who make these pictures will be punished on the Day of Resurrection, and it will be said to them. 'Make alive what you have created}}
\hadithdefcmd{bukhari}{5952}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ عِمْرَانَ بْنِ حِطَّانَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ حَدَّثَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَكُنْ يَتْرُكُ فِي بَيْتِهِ شَيْئًا فِيهِ تَصَالِيبُ إِلاَّ نَقَضَهُ‏.‏\hadithno{5952}\hadithtrans{Narrated `Aisha:I never used to leave in the Prophet (ﷺ) house anything carrying images or crosses but he obliterated it}}
\hadithdefcmd{bukhari}{5953}{حَدَّثَنَا مُوسَى، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عُمَارَةُ، حَدَّثَنَا أَبُو زُرْعَةَ، قَالَ دَخَلْتُ مَعَ أَبِي هُرَيْرَةَ دَارًا بِالْمَدِينَةِ فَرَأَى أَعْلاَهَا مُصَوِّرًا يُصَوِّرُ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَمَنْ أَظْلَمُ مِمَّنْ ذَهَبَ يَخْلُقُ كَخَلْقِي، فَلْيَخْلُقُوا حَبَّةً، وَلْيَخْلُقُوا ذَرَّةً ‏"‏‏.‏ ثُمَّ دَعَا بِتَوْرٍ مِنْ مَاءٍ فَغَسَلَ يَدَيْهِ حَتَّى بَلَغَ إِبْطَهُ فَقُلْتُ يَا أَبَا هُرَيْرَةَ أَشَىْءٌ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ مُنْتَهَى الْحِلْيَةِ‏.‏\hadithno{5953}\hadithtrans{Narrated Abu Zur'a:l entered a house in Medina with Abu Huraira, and he saw a man making pictures at the top of the house. Abu Huraira said, "I heard Allah's Messenger (ﷺ) saying that Allah said, 'Who would be more unjust than the one who tries to create the like of My creatures? Let them create a grain: let them create a gnat.' "Abu Huraira then asked for a water container and washed his arms up to his armpits. I said, "0 Abu i Huraira! Is this something you have heard I from Allah's Messenger (ﷺ)?" He said, "The limit for ablution is up to the place where the ornaments will reach on the Day of Resurrection}}
\hadithdefcmd{bukhari}{5954}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ ـ وَمَا بِالْمَدِينَةِ يَوْمَئِذٍ أَفْضَلُ مِنْهُ ـ قَالَ سَمِعْتُ أَبِي قَالَ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ سَفَرٍ وَقَدْ سَتَرْتُ بِقِرَامٍ لِي عَلَى سَهْوَةٍ لِي فِيهَا تَمَاثِيلُ، فَلَمَّا رَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم هَتَكَهُ وَقَالَ ‏ "‏ أَشَدُّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الَّذِينَ يُضَاهُونَ بِخَلْقِ اللَّهِ ‏"‏‏.‏ قَالَتْ فَجَعَلْنَاهُ وِسَادَةً أَوْ وِسَادَتَيْنِ‏.‏\hadithno{5954}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) returned from a journey when I had placed a curtain of mine having pictures over (the door of) a chamber of mine. When Allah's Messenger (ﷺ) saw it, he tore it and said, "The people who will receive the severest punishment on the Day of Resurrection will be those who try to make the like of Allah's creations." So we turned it (i.e., the curtain) into one or two cushions}}
\hadithdefcmd{bukhari}{5955}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَدِمَ النَّبِيُّ صلى الله عليه وسلم مِنْ سَفَرٍ، وَعَلَّقْتُ دُرْنُوكًا فِيهِ تَمَاثِيلُ، فَأَمَرَنِي أَنْ أَنْزِعَهُ، فَنَزَعْتُهُ‏.‏\hadithno{5955}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) returned from a journey when I had hung a thick curtain having pictures (in front of a door). He ordered me to remove it and I removed it}}
\hadithdefcmd{bukhari}{5956}{وَكُنْتُ أَغْتَسِلُ أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ‏.‏\hadithno{5956}\hadithtrans{Aisha added:The Prophet (ﷺ) and I used to take a bath from one container (of water)}}
\hadithdefcmd{bukhari}{5957}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا اشْتَرَتْ نُمْرُقَةً فِيهَا تَصَاوِيرُ، فَقَامَ النَّبِيُّ صلى الله عليه وسلم بِالْبَابِ فَلَمْ يَدْخُلْ‏.‏ فَقُلْتُ أَتُوبُ إِلَى اللَّهِ مِمَّا أَذْنَبْتُ‏.‏ قَالَ ‏"‏ مَا هَذِهِ النُّمْرُقَةُ ‏"‏‏.‏ قُلْتُ لِتَجْلِسَ عَلَيْهَا وَتَوَسَّدَهَا‏.‏ قَالَ ‏"‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ، يُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ‏.‏ وَإِنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ الصُّورَةُ ‏"‏‏.‏\hadithno{5957}\hadithtrans{Narrated `Aisha:I purchased a cushion with pictures on it. The Prophet (came and) stood at the door but did not enter. I said (to him), "I repent to Allah for what (the guilt) I have done." He said, "What is this cushion?" I said, "It is for you to sit on and recline on." He said, "The makers of these pictures will be punished on the Day of Resurrection and it will be said to them, 'Make alive what you have created.' Moreover, the angels do not enter a house where there are pictures}}
\hadithdefcmd{bukhari}{5958}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ، عَنْ أَبِي طَلْحَةَ، صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ الصُّورَةُ ‏"‏‏.‏ قَالَ بُسْرٌ ثُمَّ اشْتَكَى زَيْدٌ فَعُدْنَاهُ، فَإِذَا عَلَى بَابِهِ سِتْرٌ فِيهِ صُورَةٌ فَقُلْتُ لِعُبَيْدِ اللَّهِ رَبِيبِ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَلَمْ يُخْبِرْنَا زَيْدٌ عَنِ الصُّوَرِ يَوْمَ الأَوَّلِ‏.‏ فَقَالَ عُبَيْدُ اللَّهِ أَلَمْ تَسْمَعْهُ حِينَ قَالَ إِلاَّ رَقْمًا فِي ثَوْبٍ‏.‏ وَقَالَ ابْنُ وَهْبٍ أَخْبَرَنَا عَمْرٌو ـ هُوَ ابْنُ الْحَارِثِ ـ حَدَّثَهُ بُكَيْرٌ، حَدَّثَهُ بُسْرٌ، حَدَّثَهُ زَيْدٌ، حَدَّثَهُ أَبُو طَلْحَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5958}\hadithtrans{Narrated Abu Talha:Allah's Messenger (ﷺ) said, "Angels (of mercy) do not enter a house where there are pictures.'" The subnarrator Busr added: "Then Zaid fell ill and we paid him a visit. Behold! There was, hanging at his door, a curtain decorated with a picture. I said to 'Ubaidullah Al-Khaulani, the step son of Maimuna, the wife of the Prophet (ﷺ) , "Didn't Zaid tell us about the picture the day before yesterday?" 'Ubaidullah said, "Didn't you hear him saying: 'except a design in a garment'?}}
\hadithdefcmd{bukhari}{5959}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ قِرَاَمٌ لِعَائِشَةَ سَتَرَتْ بِهِ جَانِبَ بَيْتِهَا، فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَمِيطِي عَنِّي، فَإِنَّهُ لاَ تَزَالُ تَصَاوِيرُهُ تَعْرِضُ لِي فِي صَلاَتِي ‏"‏‏.‏\hadithno{5959}\hadithtrans{Narrated Anas:Aisha had a thick curtain (having pictures on it) and she screened the side of her i house with it. The Prophet (ﷺ) said to her, "Remove it from my sight, for its pictures are still coming to my mind in my prayers}}
\hadithdefcmd{bukhari}{5960}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ ـ هُوَ ابْنُ مُحَمَّدٍ ـ عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ وَعَدَ النَّبِيَّ صلى الله عليه وسلم جِبْرِيلُ فَرَاثَ عَلَيْهِ حَتَّى اشْتَدَّ عَلَى النَّبِيِّ صلى الله عليه وسلم فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَلَقِيَهُ، فَشَكَا إِلَيْهِ مَا وَجَدَ، فَقَالَ لَهُ ‏ "‏ إِنَّا لاَ نَدْخُلُ بَيْتًا فِيهِ صُورَةٌ وَلاَ كَلْبٌ ‏"‏‏.‏\hadithno{5960}\hadithtrans{Narrated Salim's father:Once Gabriel promised to visit the Prophet (ﷺ) but he delayed and the Prophet (ﷺ) got worried about that. At last he came out and found Gabriel and complained to him of his grief (for his delay). Gabriel said to him, "We do not enter a place in which there is a picture or a dog}}
\hadithdefcmd{bukhari}{5961}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا أَخْبَرَتْهُ أَنَّهَا اشْتَرَتْ نُمْرُقَةً فِيهَا تَصَاوِيرُ، فَلَمَّا رَآهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَامَ عَلَى الْبَابِ فَلَمْ يَدْخُلْ، فَعَرَفَتْ فِي وَجْهِهِ الْكَرَاهِيَةَ قَالَتْ يَا رَسُولَ اللَّهِ أَتُوبُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ، مَاذَا أَذْنَبْتُ قَالَ ‏"‏ مَا بَالُ هَذِهِ النُّمْرُقَةِ ‏"‏‏.‏ فَقَالَتِ اشْتَرَيْتُهَا لِتَقْعُدَ عَلَيْهَا وَتَوَسَّدَهَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ، وَيُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ـ وَقَالَ ـ إِنَّ الْبَيْتَ الَّذِي فِيهِ الصُّوَرُ لاَ تَدْخُلُهُ الْمَلاَئِكَةُ ‏"‏‏.‏\hadithno{5961}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) I bought a cushion having pictures on it. When Allah's Messenger (ﷺ) saw it, he stopped at the gate and did not enter. I noticed the signs of hatred (for that) on his face! I said, "O Allah's Messenger (ﷺ)! I turn to Allah and His Apostle in repentance! What sin have I committed?" He said, "What about this cushion?" I said, 'I bought it for you to sit on and recline on." Allah's Messenger (ﷺ) said, "The makers of these pictures will be punished (severely) on the Day of Resurrection and it will be said to them, 'Make alive what you have created.'" He added, "Angels do not enter a house in which there are pictures}}
\hadithdefcmd{bukhari}{5962}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، أَنَّهُ اشْتَرَى غُلاَمًا حَجَّامًا فَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الدَّمِ، وَثَمَنِ الْكَلْبِ، وَكَسْبِ الْبَغِيِّ، وَلَعَنَ آكِلَ الرِّبَا وَمُوكِلَهُ وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ وَالْمُصَوِّرَ‏.‏\hadithno{5962}\hadithtrans{Narrated Abu Juhaifa:that he had bought a slave whose profession was cupping. The Prophet (ﷺ) forbade taking the price of blood and the price of a dog and the earnings of a prostitute, and cursed the one who took or gave (Riba') usury, and the lady who tattooed others or got herself tattooed, and the picture-maker}}
\hadithdefcmd{bukhari}{5963}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، قَالَ سَمِعْتُ النَّضْرَ بْنَ أَنَسِ بْنِ مَالِكٍ، يُحَدِّثُ قَتَادَةَ قَالَ كُنْتُ عِنْدَ ابْنِ عَبَّاسٍ وَهُمْ يَسْأَلُونَهُ وَلاَ يَذْكُرُ النَّبِيَّ صلى الله عليه وسلم حَتَّى سُئِلَ فَقَالَ سَمِعْتُ مُحَمَّدًا صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَوَّرَ صُورَةً فِي الدُّنْيَا كُلِّفَ يَوْمَ الْقِيَامَةِ أَنْ يَنْفُخَ فِيهَا الرُّوحَ، وَلَيْسَ بِنَافِخٍ ‏"‏‏.‏\hadithno{5963}\hadithtrans{Narrated Ibn `Abbas:I heard Muhammad saying, "Whoever makes a picture in this world will be asked to put life into it on the Day of Resurrection, but he will not be able to do so}}
\hadithdefcmd{bukhari}{5964}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو صَفْوَانَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ عَلَى حِمَارٍ، عَلَى إِكَافٍ عَلَيْهِ قَطِيفَةٌ فَدَكِيَّةٌ، وَأَرْدَفَ أُسَامَةَ وَرَاءَهُ‏.‏\hadithno{5964}\hadithtrans{Narrated Usama bin Zaid:Allah's Messenger (ﷺ) rode a donkey saddled with a saddle covered with a Fadakiyya velvet sheet, and he made me ride behind him}}
\hadithdefcmd{bukhari}{5965}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ اسْتَقْبَلَهُ أُغَيْلِمَةُ بَنِي عَبْدِ الْمُطَّلِبِ، فَحَمَلَ وَاحِدًا بَيْنَ يَدَيْهِ وَالآخَرَ خَلْفَهُ‏.‏\hadithno{5965}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) arrived at Mecca, the children of Bani `Abdul Muttalib received him. He then mounted one of them in front of him and the other behind him}}
\hadithdefcmd{bukhari}{5966}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، ذُكِرَ الأَشَرُّ الثَّلاَثَةُ عِنْدَ عِكْرِمَةَ فَقَالَ قَالَ ابْنُ عَبَّاسٍ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ حَمَلَ قُثَمَ بَيْنَ يَدَيْهِ، وَالْفَضْلَ خَلْفَهُ، أَوْ قُثَمَ خَلْفَهُ، وَالْفَضْلَ بَيْنَ يَدَيْهِ، فَأَيُّهُمْ شَرٌّ أَوْ أَيُّهُمْ خَيْرٌ‏.‏\hadithno{5966}\hadithtrans{Narrated Aiyub:The worst of three (persons riding one, animal) was mentioned in `Ikrima's presence `Ikrima said, "Ibn `Abbas said, '(In the year of the conquest of Mecca) the Prophet (ﷺ) came and mounted Qutham in front of him and Al-Fadl behind him, or Qutham behind him and Al-Fadl in front of him.' Now which of them was the worst off and which was the best?}}
\hadithdefcmd{bukhari}{5967}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ ـ رضى الله عنه ـ قَالَ بَيْنَا أَنَا رَدِيفُ النَّبِيِّ، صلى الله عليه وسلم لَيْسَ بَيْنِي وَبَيْنَهُ إِلاَّ أَخِرَةُ الرَّحْلِ فَقَالَ ‏"‏ يَا مُعَاذُ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ ثُمَّ سَارَ سَاعَةً ثُمَّ قَالَ ‏"‏ يَا مُعَاذُ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ ثُمَّ سَارَ سَاعَةً ثُمَّ قَالَ ‏"‏ يَا مُعَاذُ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ قَالَ ‏"‏ هَلْ تَدْرِي مَا حَقُّ اللَّهِ عَلَى عِبَادِهِ ‏"‏‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ حَقُّ اللَّهِ عَلَى عِبَادِهِ أَنْ يَعْبُدُوهُ وَلاَ يُشْرِكُوا بِهِ شَيْئًا ‏"‏‏.‏ ثُمَّ سَارَ سَاعَةً ثُمَّ قَالَ ‏"‏ يَا مُعَاذُ بْنَ جَبَلٍ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ فَقَالَ ‏"‏ هَلْ تَدْرِي مَا حَقُّ الْعِبَادِ عَلَى اللَّهِ إِذَا فَعَلُوهُ ‏"‏‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ حَقُّ الْعِبَادِ عَلَى اللَّهِ أَنْ لاَ يُعَذِّبَهُمْ ‏"‏‏.‏\hadithno{5967}\hadithtrans{Narrated Mu`adh bin Jabal:While I was riding behind the Prophet (ﷺ) and between me and him and between me and him there was only the back of the saddle, he said, "0 Mu`adh!" I replied, "Labbaik, 0 Allah's Messenger (ﷺ), and Sa`daik!" he said, "Do you know what is Allah's right upon his slave?" I said, "Allah and His Apostle know best" He said "Allah's right upon his slaves is that they should worship Him alone and not worship anything else besides Him." Then he proceeded for a while and then said, "O Mu`adh bin Jabal!" I replied, "Labbaik, O Allah's Messenger (ﷺ):, Sa`daik!' He said, "Do you know what is the right of the slaves upon Allah if they do that?" I replied, "Allah and His Apostle know best." He said, "The right of the slaves upon Allah is that He will not punish them (if they do that)}}
\hadithdefcmd{bukhari}{5968}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ صَبَّاحٍ، حَدَّثَنَا يَحْيَى بْنُ عَبَّادٍ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي يَحْيَى بْنُ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ أَقْبَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ خَيْبَرَ، وَإِنِّي لَرَدِيفُ أَبِي طَلْحَةَ وَهْوَ يَسِيرُ وَبَعْضُ نِسَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم رَدِيفُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ عَثَرَتِ النَّاقَةُ فَقُلْتُ الْمَرْأَةَ‏.‏ فَنَزَلْتُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا أُمُّكُمْ ‏"‏‏.‏ فَشَدَدْتُ الرَّحْلَ وَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا دَنَا أَوْ رَأَى الْمَدِينَةَ قَالَ ‏"‏ آيِبُونَ تَائِبُونَ، عَابِدُونَ لِرَبِّنَا، حَامِدُونَ ‏"‏‏.‏\hadithno{5968}\hadithtrans{Narrated Anas bin Malik:We were coming from Khaibar along with Allah's Messenger (ﷺ) while I was riding behind Abu Talha and he was proceeding. While one of the wives of Allah's Messenger (ﷺ) was riding behind Allah's Messenger (ﷺ), suddenly the foot of the camel Slipped and I said, "The woman!" and alighted (hurriedly). Allah's Apostle said, "She is your mother." Sol resaddled the she-camel and Allah's Messenger (ﷺ) mounted it. When he approached or saw Medina, he said, "Ayibun, ta'ibun, 'abidun, li-Rabbina hami-dun}}
\hadithdefcmd{bukhari}{5969}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّهُ أَبْصَرَ النَّبِيَّ صلى الله عليه وسلم يَضْطَجِعُ فِي الْمَسْجِدِ، رَافِعًا إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى‏.‏\hadithno{5969}\hadithtrans{Narrated `Abbad bin Tamim's uncle:I saw the Prophet (ﷺ) lying-down in the mosque and placing one leg on the other}}
