% Auto-generated chapter 27 for tirmidhi
% Hadiths in this chapter: 141

\hadithdefcmd{tirmidhi}{1897}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، أَخْبَرَنَا بَهْزُ بْنُ حَكِيمٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَنْ أَبَرُّ قَالَ ‏"‏ أُمَّكَ ‏"‏ ‏.‏ قَالَ قُلْتُ ثُمَّ مَنْ قَالَ ‏"‏ أُمَّكَ ‏"‏ ‏.‏ قَالَ قُلْتُ ثُمَّ مَنْ قَالَ ‏"‏ أُمَّكَ ‏"‏ ‏.‏ قَالَ قُلْتُ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ أَبَاكَ ثُمَّ الأَقْرَبَ فَالأَقْرَبَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عُمَرَ وَعَائِشَةَ وَأَبِي الدَّرْدَاءِ ‏.‏ قَالَ أَبُو عِيسَى وَبَهْزُ بْنُ حَكِيمٍ هُوَ ابْنُ مُعَاوِيَةَ بْنِ حَيْدَةَ الْقُشَيْرِيُّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ تَكَلَّمَ شُعْبَةُ فِي بَهْزِ بْنِ حَكِيمٍ وَهُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ وَرَوَى عَنْهُ مَعْمَرٌ وَالثَّوْرِيُّ وَحَمَّادُ بْنُ سَلَمَةَ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ ‏.‏\hadithno{1897}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father, from his grandfather who said:"I said: 'O Messenger of Allah! Who most deserves(my) reverence?' He said: 'Your mother.'" He said: "I said: 'Then who?' He said: 'Your mother.'" He said: "I said: 'Then who?' He said: 'Your mother.'" He said: "I said: 'Then who?' He said: 'Then your father, then the nearest relatives, then the nearest relatives}}
\hadithdefcmd{tirmidhi}{1898}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنِ الْمَسْعُودِيِّ، عَنِ الْوَلِيدِ بْنِ الْعَيْزَارِ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنِ ابْنِ مَسْعُودٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏"‏ الصَّلاَةُ لِمِيقَاتِهَا ‏"‏ ‏.‏ قُلْتُ ثُمَّ مَاذَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِرُّ الْوَالِدَيْنِ ‏"‏ ‏.‏ قُلْتُ ثُمَّ مَاذَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ ثُمَّ سَكَتَ عَنِّي رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَوِ اسْتَزَدْتُهُ لَزَادَنِي ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ رَوَاهُ الشَّيْبَانِيُّ وَشُعْبَةُ وَغَيْرُ وَاحِدٍ عَنِ الْوَلِيدِ بْنِ الْعَيْزَارِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ عَنِ ابْنِ مَسْعُودٍ ‏.‏ وَأَبُو عَمْرٍو الشَّيْبَانِيُّ اسْمُهُ سَعْدُ بْنُ إِيَاسٍ ‏.‏\hadithno{1898}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Mas'ud said:"I asked the Messenger of Allah: 'O Messenger of Allah! Which is the most virtuous of deeds?' He said: 'Salat during its appropriate time.' I said: 'Then what, O Messenger of Allah?' He said: 'Being dutiful to one's parents.' I said: 'Then what, O Messenger of Allah?' He said: 'Jihad in the cause of Allah.' Then the messenger of Allah was silent, and if I had asked him more, he would have told me more}}
\hadithdefcmd{tirmidhi}{1899}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رِضَا الرَّبِّ فِي رِضَا الْوَالِدِ وَسَخَطُ الرَّبِّ فِي سَخَطِ الْوَالِدِ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، نَحْوَهُ وَلَمْ يَرْفَعْهُ وَهَذَا أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَى أَصْحَابُ شُعْبَةَ عَنْ شُعْبَةَ عَنْ يَعْلَى بْنِ عَطَاءٍ عَنْ أَبِيهِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو مَوْقُوفًا وَلاَ نَعْلَمُ أَحَدًا رَفَعَهُ غَيْرَ خَالِدِ بْنِ الْحَارِثِ عَنْ شُعْبَةَ ‏.‏ وَخَالِدُ بْنُ الْحَارِثِ ثِقَةٌ مَأْمُونٌ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدَ بْنَ الْمُثَنَّى يَقُولُ مَا رَأَيْتُ بِالْبَصْرَةِ مِثْلَ خَالِدِ بْنِ الْحَارِثِ وَلاَ بِالْكُوفَةِ مِثْلَ عَبْدِ اللَّهِ بْنِ إِدْرِيسَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏.‏\hadithno{1899}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Amr narrated that:the Prophet said: "The Lord's pleasure is in the parent's pleasure, and the Lord's anger is in the parent's anger."(Hasan)}}
\hadithdefcmd{tirmidhi}{1900}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ الْهُجَيْمِيِّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ أَبِي الدَّرْدَاءِ، أَنَّ رَجُلاً، أَتَاهُ فَقَالَ إِنَّ لِي امْرَأَةً وَإِنَّ أُمِّي تَأْمُرُنِي بِطَلاَقِهَا ‏.‏ قَالَ أَبُو الدَّرْدَاءِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْوَالِدُ أَوْسَطُ أَبْوَابِ الْجَنَّةِ فَإِنْ شِئْتَ فَأَضِعْ ذَلِكَ الْبَابَ أَوِ احْفَظْهُ ‏"‏ ‏.‏ قَالَ وَقَالَ ابْنُ أَبِي عُمَرَ وَرُبَّمَا قَالَ سُفْيَانُ إِنَّ أُمِّي وَرُبَّمَا قَالَ أَبِي ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَأَبُو عَبْدِ الرَّحْمَنِ السُّلَمِيُّ اسْمُهُ عَبْدُ اللَّهِ بْنُ حَبِيبٍ ‏.‏\hadithno{1900}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu 'Abdur-Rahman As-Sulami narrated from Abu Ad Darda'.:He said that a man came and said : "I have a wife whom my mother has ordered me to divorce." So Abu Ad-Darda said: " I heard the Messenger of Allah saying: 'The father is the middle gate to Paradise. So if you wish, then neglect that door, or protect it}}
\hadithdefcmd{tirmidhi}{1901}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أُحَدِّثُكُمْ بِأَكْبَرِ الْكَبَائِرِ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ الإِشْرَاكُ بِاللَّهِ وَعُقُوقُ الْوَالِدَيْنِ ‏"‏ ‏.‏ قَالَ وَجَلَسَ وَكَانَ مُتَّكِئًا فَقَالَ ‏"‏ وَشَهَادَةُ الزُّورِ أَوْ قَوْلُ الزُّورِ ‏"‏ ‏.‏ فَمَا زَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُهَا حَتَّى قُلْنَا لَيْتَهُ سَكَتَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو بَكْرَةَ اسْمُهُ نُفَيْعُ بْنُ الْحَارِثِ ‏.‏\hadithno{1901}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdur-Rahman bin Abi Bakrah narrated from his father who said:" The messenger of Allah said: 'Shall I not tell you of the biggest of the major sins?' they said : 'Of course! O Messenger of Allah!' He said: 'To join partners with Allah, and disobeying one's parents.'"He said : " He sat up, and he had been reclining. He said: 'And false testimony, or false speech.' And the Messenger of Allah would not stop saying it until we said (to ourselves): 'I wish that he would stop}}
\hadithdefcmd{tirmidhi}{1902}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ الْهَادِ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مِنَ الْكَبَائِرِ أَنْ يَشْتُمَ الرَّجُلُ وَالِدَيْهِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَهَلْ يَشْتُمُ الرَّجُلُ وَالِدَيْهِ قَالَ ‏"‏ نَعَمْ يَسُبُّ أَبَا الرَّجُلِ فَيَشْتُمُ أَبَاهُ وَيَشْتُمُ أُمَّهُ فَيَسُبُّ أُمَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1902}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin 'Amr narrated that :the Messenger of Allah said: "It is among the greatest of sins that a man should curse his parents." They said: "O Messenger of Allah! Does a man curse his parents?" He said: "Yes. He verbally abuses the father of a man, who in turn, verbally abuses his father, and he (retaliates and) curses his mother , so he curses his mother}}
\hadithdefcmd{tirmidhi}{1903}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا حَيْوَةُ بْنُ شُرَيْحٍ، أَخْبَرَنِي الْوَلِيدُ بْنُ أَبِي الْوَلِيدِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَبَرَّ الْبِرِّ أَنْ يَصِلَ الرَّجُلُ أَهْلَ وُدِّ أَبِيهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي أَسِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا إِسْنَادٌ صَحِيحٌ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ ابْنِ عُمَرَ مِنْ غَيْرِ وَجْهٍ ‏.‏\hadithno{1903}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Umar narrated that :the Prophet said: "Among the most dutiful of deeds is that a man nurture relations with the people his father was friends with}}
\hadithdefcmd{tirmidhi}{1904}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ إِسْرَائِيلَ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ، وَهُوَ ابْنُ مَدُّويَهْ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، وَاللَّفْظُ، لِحَدِيثِ عُبَيْدِ اللَّهِ عَنْ أَبِي إِسْحَاقَ الْهَمْدَانِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَالَةُ بِمَنْزِلَةِ الأُمِّ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ طَوِيلَةٌ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{1904}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Bara' bin Azib narrated that :the Prophet said: "The maternal aunt holds the same status as the mother}}
\hadithdefcmd{tirmidhi}{1904p2}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ ذَنْبًا عَظِيمًا فَهَلْ لِي مِنْ تَوْبَةٍ قَالَ ‏"‏ هَلْ لَكَ مِنْ أُمٍّ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ هَلْ لَكَ مِنْ خَالَةٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَبِرَّهَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَالْبَرَاءِ بْنِ عَازِبٍ ‏.‏\hadithno{1904.2}\hadithtrans{(Another chain) From Ibn 'Umar:A man came to the Prophet (ﷺ) and said: "O Messenger of Allah! I have been afflicted by a tremendous sin. Is there any repentance for me?" He said: "Do you have your mother?" The man said: "No." He said: "Do you have any maternal aunts?" The man said: "Yes." He said: "Then be dutiful to them}}
\hadithdefcmd{tirmidhi}{1904p3}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ أَبِي بَكْرِ بْنِ حَفْصِ بْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ عَنِ ابْنِ عُمَرَ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ أَبِي مُعَاوِيَةَ ‏.‏ وَأَبُو بَكْرِ بْنُ حَفْصٍ هُوَ ابْنُ عُمَرَ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ ‏.‏\hadithno{1904.3}\hadithtrans{(Another chain) From Abu Bakr bin Hafs, from the Prophet (ﷺ), and it is similar, but he did not mention "from Ibn `Umar" in it. This is more correct than the Hadith of Abu Mu'awiyah, and Abu Bakr bin Hafs is Ibn 'Umar bin Sa'd bin Abi Waqqas (narrators in the chain of this Hadith)}}
\hadithdefcmd{tirmidhi}{1905}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي جَعْفَرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثُ دَعَوَاتٍ مُسْتَجَابَاتٌ لاَ شَكَّ فِيهِنَّ دَعْوَةُ الْمَظْلُومِ وَدَعْوَةُ الْمُسَافِرِ وَدَعْوَةُ الْوَالِدِ عَلَى وَلَدِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى الْحَجَّاجُ الصَّوَّافُ هَذَا الْحَدِيثَ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ نَحْوَ حَدِيثِ هِشَامٍ ‏.‏ وَأَبُو جَعْفَرٍ الَّذِي رَوَى عَنْ أَبِي هُرَيْرَةَ يُقَالُ لَهُ أَبُو جَعْفَرٍ الْمُؤَذِّنُ وَلاَ نَعْرِفُ اسْمَهُ وَقَدْ رَوَى عَنْهُ يَحْيَى بْنُ أَبِي كَثِيرٍ غَيْرَ حَدِيثٍ ‏.‏\hadithno{1905}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Harairah narrated that the Messenger of Allah said:"Three supplications are accepted , there is no doubt in them (about them being accepted): The supplication of the oppressed, the supplication of the traveler, and the supplication of his father against his son}}
\hadithdefcmd{tirmidhi}{1906}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، أَخْبَرَنَا جَرِيرٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَجْزِي وَلَدٌ وَالِدًا إِلاَّ أَنْ يَجِدَهُ مَمْلُوكًا فَيَشْتَرِيَهُ فَيُعْتِقَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سُهَيْلِ بْنِ أَبِي صَالِحٍ ‏.‏ وَقَدْ رَوَى سُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ هَذَا الْحَدِيثَ ‏.‏\hadithno{1906}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that:the Messenger of Allah said: "A son could not do enough for his father, unless he found him as a slave and purchased him to set him free}}
\hadithdefcmd{tirmidhi}{1907}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، قَالَ اشْتَكَى أَبُو الرَّدَّادِ اللَّيْثِيُّ فَعَادَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ فَقَالَ خَيْرُهُمْ وَأَوْصَلُهُمْ مَا عَلِمْتُ أَبَا مُحَمَّدٍ ‏.‏ فَقَالَ عَبْدُ الرَّحْمَنِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ أَنَا اللَّهُ وَأَنَا الرَّحْمَنُ خَلَقْتُ الرَّحِمَ وَشَقَقْتُ لَهَا مِنَ اسْمِي فَمَنْ وَصَلَهَا وَصَلْتُهُ وَمَنْ قَطَعَهَا بَتَتُّهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَابْنِ أَبِي أَوْفَى وَعَامِرِ بْنِ رَبِيعَةَ وَأَبِي هُرَيْرَةَ وَجُبَيْرِ بْنِ مُطْعِمٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سُفْيَانَ عَنِ الزُّهْرِيِّ حَدِيثٌ صَحِيحٌ ‏.‏ وَرَوَى مَعْمَرٌ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ رَدَّادٍ اللَّيْثِيِّ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَمَعْمَرٌ كَذَا يَقُولُ قَالَ مُحَمَّدٌ وَحَدِيثُ مَعْمَرٍ خَطَأٌ ‏.‏\hadithno{1907}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Salamah said:" Abu[Ar-Raddad] Al-Laithi complained(of an illness). So 'Abdur-Rahman bin 'Awf visited him. He said: 'The best of you, and the most apt to maintain good relations, as far as I know, is Abu Muhammad('Abdur-Rahman bin 'Awf). So 'Abdur-Rahman bin 'Awf' said: 'I heard the Messenger of Allah saying : "Allah, Most Blessed and Most High, said: 'I am Allah, and I am Ar-Rahman. I created the Rahim(womb), and named it after My Name. So whoever keeps good relations with it, I keep good relation with him, and whoever severs it, I am finished with him}}
\hadithdefcmd{tirmidhi}{1908}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا بَشِيرٌ أَبُو إِسْمَاعِيلَ، وَفِطْرُ بْنُ خَلِيفَةَ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ الْوَاصِلُ بِالْمُكَافِئِ وَلَكِنَّ الْوَاصِلَ الَّذِي إِذَا انْقَطَعَتْ رَحِمُهُ وَصَلَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ سَلْمَانَ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏\hadithno{1908}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Amr narrated that:the Prophet said: "Merely maintaining the ties of kinship is not adequate. But connecting the ties of kinship is when his ties to the womb are severed and he connects it}}
\hadithdefcmd{tirmidhi}{1909}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَنَصْرُ بْنُ عَلِيٍّ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ قَاطِعٌ ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي عُمَرَ قَالَ سُفْيَانُ يَعْنِي قَاطِعَ رَحِمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1909}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Muhammad bin Jubair bin Mut'im narrated from his father, that:the Messenger of Allah said: "The one who severs ties will not enter Paradise." Ibn Abi 'Umar said: "Sufyan said: 'Meaning: Ties of the womb}}
\hadithdefcmd{tirmidhi}{1910}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، قَالَ سَمِعْتُ ابْنَ أَبِي سُوَيْدٍ، يَقُولُ سَمِعْتُ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَقُولُ زَعَمَتِ الْمَرْأَةُ الصَّالِحَةُ خَوْلَةُ بِنْتُ حَكِيمٍ قَالَتْ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ وَهُوَ مُحْتَضِنٌ أَحَدَ ابْنَىِ ابْنَتِهِ وَهُوَ يَقُولُ ‏ "‏ إِنَّكُمْ لَتُبَخِّلُونَ وَتُجَبِّنُونَ وَتُجَهِّلُونَ وَإِنَّكُمْ لَمِنْ رَيْحَانِ اللَّهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَالأَشْعَثِ بْنِ قَيْسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُيَيْنَةَ عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِهِ ‏.‏ وَلاَ نَعْرِفُ لِعُمَرَ بْنِ عَبْدِ الْعَزِيزِ سَمَاعًا مِنْ خَوْلَةَ ‏.‏\hadithno{1910}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umar bin 'Abdul-'Aziz said:'a righteous woman, Khawlah bint Hakim said: "The Messenger of Allah came out during the middle of the day, while holding one of the sons of his daughter in his arms. He was saying: 'You are what makes them stingy, cowardly and ignorant. And you are but Raihanillah}}
\hadithdefcmd{tirmidhi}{1911}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَبْصَرَ الأَقْرَعُ بْنُ حَابِسٍ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يُقَبِّلُ الْحَسَنَ قَالَ ابْنُ أَبِي عُمَرَ الْحُسَيْنَ أَوِ الْحَسَنَ فَقَالَ إِنَّ لِي مِنَ الْوَلَدِ عَشَرَةً مَا قَبَّلْتُ أَحَدًا مِنْهُمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهُ مَنْ لاَ يَرْحَمْ لاَ يُرْحَمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ اسْمُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1911}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"Al-Aqra' bin Habis saw the prophet kissing Al-Hasan"- Ibn Abi 'Umar (one of the narrators) said:"Al-Hasan and Al-Husain." So he said: 'I have ten children and I do not kiss any one of them.' So the Messenger of Allah said: 'Whoever shows no mercy, he will be shown no mercy}}
\hadithdefcmd{tirmidhi}{1912}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَكُونُ لأَحَدِكُمْ ثَلاَثُ بَنَاتٍ أَوْ ثَلاَثُ أَخَوَاتٍ فَيُحْسِنُ إِلَيْهِنَّ إِلاَّ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَعُقْبَةَ بْنِ عَامِرٍ وَأَنَسٍ وَجَابِرٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو سَعِيدٍ الْخُدْرِيُّ اسْمُهُ سَعْدُ بْنُ مَالِكِ بْنِ سِنَانٍ وَسَعْدُ بْنُ أَبِي وَقَّاصٍ هُوَ سَعْدُ بْنُ مَالِكِ بْنِ وُهَيْبٍ ‏.‏ وَقَدْ زَادُوا فِي هَذَا الإِسْنَادِ رَجُلاً ‏.‏\hadithno{1912}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :the Messenger of Allah said: "There is no one who has three daughters, or three sisters, and he treats them well, except that he enters paradise}}
\hadithdefcmd{tirmidhi}{1913}{حَدَّثَنَا الْعَلاَءُ بْنُ مَسْلَمَةَ الْبَغْدَادِيُّ، حَدَّثَنَا عَبْدُ الْمَجِيدِ بْنُ عَبْدِ الْعَزِيزِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتُلِيَ بِشَيْءٍ مِنَ الْبَنَاتِ فَصَبَرَ عَلَيْهِنَّ كُنَّ لَهُ حِجَابًا مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1913}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated that the:Messenger of Allah said:"Whoever is tried with something from daughters, and he is patient with them, they will be a barrier from the Fire for him}}
\hadithdefcmd{tirmidhi}{1914}{حَدَّثَنَا مُحَمَّدُ بْنُ وَزِيرٍ الْوَاسِطِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، هُوَ الطَّنَافِسِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ الرَّاسِبِيُّ، عَنْ أَبِي بَكْرِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَنَسِ بْنِ مَالِكٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَالَ جَارِيَتَيْنِ دَخَلْتُ أَنَا وَهُوَ الْجَنَّةَ كَهَاتَيْنِ ‏"‏ ‏.‏ وَأَشَارَ بِأَصْبُعَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَى مُحَمَّدُ بْنُ عُبَيْدٍ عَنْ مُحَمَّدِ بْنِ عَبْدِ الْعَزِيزِ غَيْرَ حَدِيثٍ بِهَذَا الإِسْنَادِ وَقَالَ عَنْ أَبِي بَكْرِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَنَسٍ وَالصَّحِيحُ هُوَ عُبَيْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ أَنَسٍ ‏.‏\hadithno{1914}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Bakr bin 'Ubaidullah bin Anas bin Malik narrated [from Anas] that:the Messenger of Allah said: "Whoever raises two girls then I and he will enter Paradise like these two." And he indicated with his two fingers}}
\hadithdefcmd{tirmidhi}{1915}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَتِ امْرَأَةٌ مَعَهَا ابْنَتَانِ لَهَا فَسَأَلَتْ فَلَمْ تَجِدْ عِنْدِي شَيْئًا غَيْرَ تَمْرَةٍ فَأَعْطَيْتُهَا إِيَّاهَا فَقَسَمَتْهَا بَيْنَ ابْنَتَيْهَا وَلَمْ تَأْكُلْ مِنْهَا ثُمَّ قَامَتْ فَخَرَجَتْ فَدَخَلَ النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتُلِيَ بِشَيْءٍ مِنْ هَذِهِ الْبَنَاتِ كُنَّ لَهُ سِتْرًا مِنَ النَّارِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1915}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah said:"A woman came to me with two daughters. She was asking (for food) but I did not have anything with me except a date. So I gave it to her and she divided it between her two daughters without eating any of it herself. Then she got up to leave, and the Prophet entered, and I informed him about her. So the Prophet said: " Whoever is tested something from these daughters (and he/she passes the test), they will be a screen for them from the Fire}}
\hadithdefcmd{tirmidhi}{1916}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَيُّوبَ بْنِ بَشِيرٍ، عَنْ سَعِيدٍ الأَعْشَى، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ لَهُ ثَلاَثُ بَنَاتٍ أَوْ ثَلاَثُ أَخَوَاتٍ أَوِ ابْنَتَانِ أَوْ أُخْتَانِ فَأَحْسَنَ صُحْبَتَهُنَّ وَاتَّقَى اللَّهَ فِيهِنَّ فَلَهُ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{1916}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :the Messenger of Allah said: "Whoever has three daughters, or three sisters, or two daughters, or two sisters and he keeps good company with them and fears Allah regarding them, then Paradise is for him}}
\hadithdefcmd{tirmidhi}{1917}{حَدَّثَنَا سَعِيدُ بْنُ يَعْقُوبَ الطَّالْقَانِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ حَنَشٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَبَضَ يَتِيمًا بَيْنَ الْمُسْلِمِينَ إِلَى طَعَامِهِ وَشَرَابِهِ أَدْخَلَهُ اللَّهُ الْجَنَّةَ الْبَتَّةَ إِلاَّ أَنْ يَعْمَلَ ذَنْبًا لاَ يُغْفَرُ لَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ مُرَّةَ الْفِهْرِيِّ وَأَبِي هُرَيْرَةَ وَأَبِي أُمَامَةَ وَسَهْلِ بْنِ سَعْدٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَنَشٌ هُوَ حُسَيْنُ بْنُ قَيْسٍ وَهُوَ أَبُو عَلِيٍّ الرَّحَبِيُّ وَسُلَيْمَانُ التَّيْمِيُّ يَقُولُ حَنَشٌ وَهُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{1917}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas narrated that:the Prophet said: Whoever takes in an orphan among the Muslims to raise, to feed him and give him drink, Allah admits him into Paradise without a doubt, unless he has done a sin for which he is not forgiven}}
\hadithdefcmd{tirmidhi}{1918}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عِمْرَانَ أَبُو الْقَاسِمِ الْمَكِّيُّ الْقُرَشِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا وَكَافِلُ الْيَتِيمِ فِي الْجَنَّةِ كَهَاتَيْنِ ‏"‏ ‏.‏ وَأَشَارَ بِأُصْبُعَيْهِ يَعْنِي السَّبَّابَةَ وَالْوُسْطَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1918}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Sahl bin Sa'd narrated that:the Messenger of Allah said: " I and the sponsor of an orphan shall be in Paradise like these two."And he indicaed with his fingers, meaning his index and his middle finger}}
\hadithdefcmd{tirmidhi}{1919}{حَدَّثَنَا مُحَمَّدُ بْنُ مَرْزُوقٍ الْبَصْرِيُّ، حَدَّثَنَا عُبَيْدُ بْنُ وَاقِدٍ، عَنْ زَرْبِيٍّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ جَاءَ شَيْخٌ يُرِيدُ النَّبِيَّ صلى الله عليه وسلم فَأَبْطَأَ الْقَوْمُ عَنْهُ أَنْ يُوَسِّعُوا لَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَّا مَنْ لَمْ يَرْحَمْ صَغِيرَنَا وَيُوَقِّرْ كَبِيرَنَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَزَرْبِيٌّ لَهُ أَحَادِيثُ مَنَاكِيرُ عَنْ أَنَسِ بْنِ مَالِكٍ وَغَيْرِهِ ‏.‏\hadithno{1919}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik narrated that:"An older man came to talk to the Prophet, and the people were hesitant to make room for him. The Prophet said: ;He is not one of us who does not have mercy on our young and does not respect our elders}}
\hadithdefcmd{tirmidhi}{1920}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ أَبَانَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ مِنَّا مَنْ لَمْ يَرْحَمْ صَغِيرَنَا وَيَعْرِفْ شَرَفَ كَبِيرِنَا ‏"‏ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، نَحْوَهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ وَيَعْرِفْ حَقَّ كَبِيرِنَا ‏"‏ ‏.‏\hadithno{1920}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Amr bin Shu'aib narrated that his father, from his grandfather, who said that the Messenger of Allah said:'He is not one of us who does not have mercy upon our young, nor knows the honor of our elders}}
\hadithdefcmd{tirmidhi}{1921}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ أَبَانَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ شَرِيكٍ، عَنْ لَيْثٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ مِنَّا مَنْ لَمْ يَرْحَمْ صَغِيرَنَا وَيُوَقِّرْ كَبِيرَنَا وَيَأْمُرْ بِالْمَعْرُوفِ وَيَنْهَ عَنِ الْمُنْكَرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَحَدِيثُ مُحَمَّدِ بْنِ إِسْحَاقَ عَنْ عَمْرِو بْنِ شُعَيْبٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو مِنْ غَيْرِ هَذَا الْوَجْهِ أَيْضًا ‏.‏ - قَالَ بَعْضُ أَهْلِ الْعِلْمِ مَعْنَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لَيْسَ مِنَّا ‏"‏ ‏.‏ يَقُولُ لَيْسَ مِنْ سُنَّتِنَا يَقُولُ لَيْسَ مِنْ أَدَبِنَا ‏.‏ وَقَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ كَانَ سُفْيَانُ الثَّوْرِيُّ يُنْكِرُ هَذَا التَّفْسِيرَ لَيْسَ مِنَّا يَقُولُ لَيْسَ مِثْلَنَا ‏.‏\hadithno{1921}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that the Messenger of Allah said:" He is not one of us who does not have mercy upon our young, respect our elders, and command good and forbid evil}}
\hadithdefcmd{tirmidhi}{1922}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، حَدَّثَنَا قَيْسُ بْنُ أَبِي حَازِمٍ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لاَ يَرْحَمُ النَّاسَ لاَ يَرْحَمُهُ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَأَبِي سَعِيدٍ وَابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{1922}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jarir bin Abdullah narrated that the Messenger of Allah said:"Whoever does not show mercy to the people, Allah will not show mercy to him}}
\hadithdefcmd{tirmidhi}{1923}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، قَالَ كَتَبَ بِهِ إِلَىَّ مَنْصُورٌ وَقَرَأْتُهُ عَلَيْهِ سَمِعَ أَبَا عُثْمَانَ مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ عَنْ أَبِي هُرَيْرَةَ قَالَ سَمِعْتُ أَبَا الْقَاسِمِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُنْزَعُ الرَّحْمَةُ إِلاَّ مِنْ شَقِيٍّ ‏"‏ ‏.‏ قَالَ وَأَبُو عُثْمَانَ الَّذِي رَوَى عَنْ أَبِي هُرَيْرَةَ لاَ يُعْرَفُ اسْمُهُ وَيُقَالُ هُوَ وَالِدُ مُوسَى بْنِ أَبِي عُثْمَانَ الَّذِي رَوَى عَنْهُ أَبُو الزِّنَادِ وَقَدْ رَوَى أَبُو الزِّنَادِ عَنْ مُوسَى بْنِ أَبِي عُثْمَانَ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ حَدِيثٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1923}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that Abul- Qasim said:"Mercy is not removed (from anyone) except from a wicked one}}
\hadithdefcmd{tirmidhi}{1924}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي قَابُوسَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرَّاحِمُونَ يَرْحَمُهُمُ الرَّحْمَنُ ارْحَمُوا مَنْ فِي الأَرْضِ يَرْحَمْكُمْ مَنْ فِي السَّمَاءِ الرَّحِمُ شُجْنَةٌ مِنَ الرَّحْمَنِ فَمَنْ وَصَلَهَا وَصَلَهُ اللَّهُ وَمَنْ قَطَعَهَا قَطَعَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1924}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin 'Amr narrated that the Messenger of Allah said:"The merciful are shown mercy by Ar-Rahman. Be merciful on the earth, and you will be shown mercy from Who is above the heavens. The womb is named after Ar-Rahman, so whoever connects it, Allah connects him, and whoever severs it, Allah severs him}}
\hadithdefcmd{tirmidhi}{1925}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى إِقَامِ الصَّلاَةِ وَإِيتَاءِ الزَّكَاةِ وَالنُّصْحِ لِكُلِّ مُسْلِمٍ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1925}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jarir bin 'Abdullah narrated :" I pledged to the Prophet to establish the Salat, give the Zakat, and to give sincere advice to every Muslim}}
\hadithdefcmd{tirmidhi}{1926}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الدِّينُ النَّصِيحَةُ ‏"‏ ‏.‏ ثَلاَثَ مِرَارٍ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ لِمَنْ قَالَ ‏"‏ لِلَّهِ وَلِكِتَابِهِ وَلأَئِمَّةِ الْمُسْلِمِينَ وَعَامَّتِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَتَمِيمٍ الدَّارِيِّ وَجَرِيرٍ وَحَكِيمِ بْنِ أَبِي يَزِيدَ عَنْ أَبِيهِ وَثَوْبَانَ ‏.‏\hadithno{1926}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:the Messenger of Allah said: "The religion is An-Nasihah" three times. They said: "O Messenger of Allah! For Whom?" He said : "To Allah , His books, the A'immah of the Muslims, and their average people}}
\hadithdefcmd{tirmidhi}{1927}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ، حَدَّثَنِي أَبِي، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُسْلِمُ أَخُو الْمُسْلِمِ لاَ يَخُونُهُ وَلاَ يَكْذِبُهُ وَلاَ يَخْذُلُهُ كُلُّ الْمُسْلِمِ عَلَى الْمُسْلِمِ حَرَامٌ عِرْضُهُ وَمَالُهُ وَدَمُهُ التَّقْوَى هَا هُنَا بِحَسْبِ امْرِئٍ مِنَ الشَّرِّ أَنْ يَحْتَقِرَ أَخَاهُ الْمُسْلِمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي أَيُّوبَ ‏.‏\hadithno{1927}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:: "The Muslim is the brother to the Muslim, he does not cheat him, lie to him, nor deceive him. All of the Muslim is unlawful to another Muslim: His Honor, his wealth, and his blood. At-taqwa is here. It is enough evil for a man that he belittle his brother Muslim}}
\hadithdefcmd{tirmidhi}{1928}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُؤْمِنُ لِلْمُؤْمِنِ كَالْبُنْيَانِ يَشُدُّ بَعْضُهُ بَعْضًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1928}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Musa Al-Ash'arf narrated that the Messenger of Allah said:: The believer is to the believer like parts of a building, each one of them supporting the other}}
\hadithdefcmd{tirmidhi}{1929}{حَدَّثَنِي أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا يَحْيَى بْنُ عُبَيْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحَدَكُمْ مِرْآةُ أَخِيهِ فَإِنْ رَأَى بِهِ أَذًى فَلْيُمِطْهُ عَنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَيَحْيَى بْنُ عُبَيْدِ اللَّهِ ضَعَّفَهُ شُعْبَةُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏\hadithno{1929}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:: "Indeed (each) one of you is the reflection of his brother. So if he sees something harmful in him, then let him remove it from him}}
\hadithdefcmd{tirmidhi}{1930}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ، حَدَّثَنِي أَبِي، عَنِ الأَعْمَشِ، قَالَ حُدِّثْتُ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نَفَّسَ عَنْ مُسْلِمٍ كُرْبَةً مِنْ كُرَبِ الدُّنْيَا نَفَّسَ اللَّهُ عَنْهُ كُرْبَةً مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ وَمَنْ يَسَّرَ عَلَى مُعْسِرٍ فِي الدُّنْيَا يَسَّرَ اللَّهُ عَلَيْهِ فِي الدُّنْيَا وَالآخِرَةِ وَمَنْ سَتَرَ عَلَى مُسْلِمٍ فِي الدُّنْيَا سَتَرَ اللَّهُ عَلَيْهِ فِي الدُّنْيَا وَالآخِرَةِ وَاللَّهُ فِي عَوْنِ الْعَبْدِ مَا كَانَ الْعَبْدُ فِي عَوْنِ أَخِيهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَعُقْبَةَ بْنِ عَامِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى أَبُو عَوَانَةَ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرُوا فِيهِ حُدِّثْتُ عَنْ أَبِي صَالِحٍ ‏.‏\hadithno{1930}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:: "Whoever relieves a Muslim of a burden from the burdens of the world, Allah will relieve him of a burden from the burdens on the Day of Judgement. And whoever helps ease a difficulty in the world, Allah will grant him ease from a difficulty in the world and in the Hereafter. And whoever covers (the faults of) a Muslim, Allah will cover (his faults) for him in the world and the Hereafter. And Allah is engaged in helping the worshipper as long as the worshipper is engaged in helping his brother}}
\hadithdefcmd{tirmidhi}{1931}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ أَبِي بَكْرٍ النَّهْشَلِيِّ، عَنْ مَرْزُوقٍ أَبِي بَكْرٍ التَّيْمِيِّ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ رَدَّ عَنْ عِرْضِ أَخِيهِ رَدَّ اللَّهُ عَنْ وَجْهِهِ النَّارَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1931}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Ad-Darda narrated that the Messenger of Allah said:"Whoever protects his brother's honor, Allah protects his face from the Fire on the Day of Resurrection}}
\hadithdefcmd{tirmidhi}{1932}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، ح قَالَ وَحَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثٍ يَلْتَقِيَانِ فَيَصُدُّ هَذَا وَيَصُدُّ هَذَا وَخَيْرُهُمَا الَّذِي يَبْدَأُ بِالسَّلاَمِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَنَسٍ وَأَبِي هُرَيْرَةَ وَهِشَامِ بْنِ عَامِرٍ وَأَبِي هِنْدٍ الدَّارِيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1932}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Ayyub Al-Ansari narrated that the Messenger of Allah said:: It is not lawful for the Muslim to shun his brother for more than three (days); they come fare to fare and this one turns away, and that one turns away. The best of them is the one who initiates the Salam}}
\hadithdefcmd{tirmidhi}{1933}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ لَمَّا قَدِمَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ الْمَدِينَةَ آخَى النَّبِيُّ صلى الله عليه وسلم بَيْنَهُ وَبَيْنَ سَعْدِ بْنِ الرَّبِيعِ فَقَالَ لَهُ هَلُمَّ أُقَاسِمْكَ مَالِي نِصْفَيْنِ وَلِي امْرَأَتَانِ فَأُطَلِّقُ إِحْدَاهُمَا فَإِذَا انْقَضَتْ عِدَّتُهَا فَتَزَوَّجْهَا ‏.‏ فَقَالَ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ وَمَالِكَ دُلُّونِي عَلَى السُّوقِ ‏.‏ فَدَلُّوهُ عَلَى السُّوقِ فَمَا رَجَعَ يَوْمَئِذٍ إِلاَّ وَمَعَهُ شَيْءٌ مِنْ أَقِطٍ وَسَمْنٍ قَدِ اسْتَفْضَلَهُ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ وَعَلَيْهِ وَضَرٌ مِنْ صُفْرَةٍ فَقَالَ ‏"‏ مَهْيَمْ ‏"‏ ‏.‏ قَالَ تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ ‏.‏ قَالَ ‏"‏ فَمَا أَصْدَقْتَهَا ‏"‏ ‏.‏ قَالَ نَوَاةً ‏.‏ قَالَ حُمَيْدٌ أَوْ قَالَ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ فَقَالَ ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ وَزْنُ نَوَاةٍ مِنْ ذَهَبٍ وَزْنُ ثَلاَثَةِ دَرَاهِمَ وَثُلُثٍ ‏.‏ وَقَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ وَزْنُ نَوَاةٍ مِنْ ذَهَبٍ وَزْنُ خَمْسَةِ دَرَاهِمَ ‏.‏ سَمِعْتُ إِسْحَاقَ بْنَ مَنْصُورٍ يَذْكُرُ عَنْهُمَا هَذَا ‏.‏\hadithno{1933}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas said:: "When 'Abdur-Rahman bin 'Awf arrived in Al-Madinah, the Messenger of Allah established a bond of brotherhood between him and sa'd bin Ar-Rabi. So he said to him: "Come here, I will divide my wealth and give you half, and I have two wives, I will divorce one of them, and when she completes her waiting period you may marry her." He said: " May Allah bless you in your family and your wealth. Show me where the market is." So they showed him where the market was and he did not return that day except with some cottage cheese and cooking fat which he had earned as a profit. The Messenger of Allah saw him after that, and he had traces of yellow on him. So he said to him: "What is this?" He said: "I married a woman from the Ansar." He said : " What dowry did you give her?" He said: " A date-stone(of gold) - ( one of the narrators) Humaid said: "Or he said: - gold equal to the weight of a date-stone." So he said: 'Have a banquet, even if with only a sheep}}
\hadithdefcmd{tirmidhi}{1934}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ مَا الْغِيبَةُ قَالَ ‏"‏ ذِكْرُكَ أَخَاكَ بِمَا يَكْرَهُ ‏"‏ ‏.‏ قَالَ أَرَأَيْتَ إِنْ كَانَ فِيهِ مَا أَقُولُ قَالَ ‏"‏ إِنْ كَانَ فِيهِ مَا تَقُولُ فَقَدِ اغْتَبْتَهُ وَإِنْ لَمْ يَكُنْ فِيهِ مَا تَقُولُ فَقَدْ بَهَتَّهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَرْزَةَ وَابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1934}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that it was said:" O Messenger of Allah! What is backbiting?" He said : " Mentioning your brother with that which he does not like." He said " What if what I said about him is so?" He said: "If what you said about him is so, then you have backbitten him, and if it is not as you said, then you have slandered him}}
\hadithdefcmd{tirmidhi}{1935}{حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ الْعَطَّارُ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقَاطَعُوا وَلاَ تَدَابَرُوا وَلاَ تَبَاغَضُوا وَلاَ تَحَاسَدُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا وَلاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَالزُّبَيْرِ بْنِ الْعَوَّامِ وَابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{1935}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas narrated that the Messenger of Allah said:"Do not cut off one another, nor desert one another, nor hate one another, nor envy one another. Be you , O worshippers o Allah, brothers. It is not lawful for the Muslim to shun his brother for more than three(days)}}
\hadithdefcmd{tirmidhi}{1936}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ مَالاً فَهُوَ يُنْفِقُ مِنْهُ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ وَرَجُلٌ آتَاهُ اللَّهُ الْقُرْآنَ فَهُوَ يَقُومُ بِهِ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏\hadithno{1936}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Salim narrated from his father who said that the Messenger of Allah said:"There is to be no envy except for two: A man to whom Allah grants wealth and he spends from it during the hours of the night and the hours of the day. And a man to whom Allah grants (memorization of) the Quran so he stands with it (in prayer) during the hours of the night and the hours of the day}}
\hadithdefcmd{tirmidhi}{1937}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّيْطَانَ قَدْ يَئِسَ أَنْ يَعْبُدَهُ الْمُصَلُّونَ وَلَكِنْ فِي التَّحْرِيشِ بَيْنَهُمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَسُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ عَنْ أَبِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو سُفْيَانَ اسْمُهُ طَلْحَةُ بْنُ نَافِعٍ ‏.‏\hadithno{1937}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir narrated that the Messenger of Allah said:"Indeed Ash-Shaitan has despaired of getting those who perform Salat to worship him.But he is engaged in sowing hatred among them}}
\hadithdefcmd{tirmidhi}{1938}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ أُمِّ كُلْثُومٍ بِنْتِ عُقْبَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ بِالْكَاذِبِ مَنْ أَصْلَحَ بَيْنَ النَّاسِ فَقَالَ خَيْرًا أَوْ نَمَى خَيْرًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1938}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umm Kulthum bint 'Uqbah narrated that the Messenger of Allah said:"One who brings peace between people is not a liar, he says something good, or reports something good}}
\hadithdefcmd{tirmidhi}{1939}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، ح قَالَ وَحَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، وَأَبُو أَحْمَدَ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَحِلُّ الْكَذِبُ إِلاَّ فِي ثَلاَثٍ يُحَدِّثُ الرَّجُلُ امْرَأَتَهُ لِيُرْضِيَهَا وَالْكَذِبُ فِي الْحَرْبِ وَالْكَذِبُ لِيُصْلِحَ بَيْنَ النَّاسِ ‏"‏ ‏.‏ وَقَالَ مَحْمُودٌ فِي حَدِيثِهِ ‏"‏ لاَ يَصْلُحُ الْكَذِبُ إِلاَّ فِي ثَلاَثٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَسْمَاءَ إِلاَّ مِنْ حَدِيثِ ابْنِ خُثَيْمٍ ‏.‏ وَرَوَى دَاوُدُ بْنُ أَبِي هِنْدٍ، هَذَا الْحَدِيثَ عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ فِيهِ عَنْ أَسْمَاءَ ‏.‏ حَدَّثَنَا بِذَلِكَ مُحَمَّدُ بْنُ الْعَلاَءِ أَبُو كُرَيْبٍ حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ ‏.‏\hadithno{1939}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Asma bint Yazid narrated that the Messenger of Allah said:"it is not lawful to lie except in three cases: Something the man tells his wife to please her, to lie during war, and to lie in order to bring peace between the people}}
\hadithdefcmd{tirmidhi}{1940}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ لُؤْلُؤَةَ، عَنْ أَبِي صِرْمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ ضَارَّ ضَارَّ اللَّهُ بِهِ وَمَنْ شَاقَّ شَاقَّ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ ‏.‏\hadithno{1940}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Sirmah narrated that the Messenger of Allah said:"Whoever causes harm, Allah harms him, and whoever is harsh, Allah will be harsh with him}}
\hadithdefcmd{tirmidhi}{1941}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ الْعُكْلِيُّ، حَدَّثَنِي أَبُو سَلَمَةَ الْكِنْدِيُّ، حَدَّثَنَا فَرْقَدٌ السَّبَخِيُّ، عَنْ مُرَّةَ بْنِ شَرَاحِيلَ الْهَمْدَانِيِّ، وَهُوَ الطَّيِّبُ - عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَلْعُونٌ مَنْ ضَارَّ مُؤْمِنًا أَوْ مَكَرَ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{1941}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Bakr As-Siddiq narrated that the Messenger of Allah said:"Cursed are those who harm a believer, or plot to do so}}
\hadithdefcmd{tirmidhi}{1942}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرٍ، هُوَ ابْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ - عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا زَالَ جِبْرِيلُ يُوصِينِي بِالْجَارِ حَتَّى ظَنَنْتُ أَنَّهُ سَيُوَرِّثُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1942}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated that the Messenger of Allah said:"Jibril – may the Salawat of Allah be upon him – continued to recommend me about (treating) the neighbors so (kindly and politely), that I thought he would order me to make them heirs.”}}
\hadithdefcmd{tirmidhi}{1943}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ دَاوُدَ بْنِ شَابُورَ، وَبَشِيرٍ أَبِي إِسْمَاعِيلَ، عَنْ مُجَاهِدٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو، ذُبِحَتْ لَهُ شَاةٌ فِي أَهْلِهِ فَلَمَّا جَاءَ قَالَ أَهْدَيْتُمْ لِجَارِنَا الْيَهُودِيِّ أَهْدَيْتُمْ لِجَارِنَا الْيَهُودِيِّ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا زَالَ جِبْرِيلُ يُوصِينِي بِالْجَارِ حَتَّى ظَنَنْتُ أَنَّهُ سَيُوَرِّثُهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَالْمِقْدَادِ بْنِ الأَسْوَدِ وَعُقْبَةَ بْنِ عَامِرٍ وَأَبِي شُرَيْحٍ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ مُجَاهِدٍ عَنْ عَائِشَةَ وَأَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا ‏.‏\hadithno{1943}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mujahid narrated:"Abdullah bin Amr had a sheep slaughtered for his family, so when he came he said: 'Have you given some to our neighbor, the Jew? Have you given some to our neighbor, the Jew? I heard the Messenger of Allah saying: 'Jibril continued to advise me about (treating) the neighbors so (kindly and politely), that I thought he would order me (from Allah) to make them heirs}}
\hadithdefcmd{tirmidhi}{1944}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، عَنْ شُرَحْبِيلَ بْنِ شَرِيكٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ الأَصْحَابِ عِنْدَ اللَّهِ خَيْرُهُمْ لِصَاحِبِهِ وَخَيْرُ الْجِيرَانِ عِنْدَ اللَّهِ خَيْرُهُمْ لِجَارِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ اسْمُهُ عَبْدُ اللَّهِ بْنُ يَزِيدَ ‏.‏\hadithno{1944}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Amr narrated that the Messenger of Allah said :"The companion who is the best to Allah is the one who is best to his companion. And the neighbor that is the best to Allah is the one that is best to his neighbor}}
\hadithdefcmd{tirmidhi}{1945}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ وَاصِلٍ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِخْوَانُكُمْ جَعَلَهُمُ اللَّهُ فِتْيَةً تَحْتَ أَيْدِيكُمْ فَمَنْ كَانَ أَخُوهُ تَحْتَ يَدِهِ فَلْيُطْعِمْهُ مِنْ طَعَامِهِ وَلْيُلْبِسْهُ مِنْ لِبَاسِهِ وَلاَ يُكَلِّفْهُ مَا يَغْلِبُهُ فَإِنْ كَلَّفَهُ مَا يَغْلِبُهُ فَلْيُعِنْهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأُمِّ سَلَمَةَ وَابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1945}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Dharr narrated that the Messenger of Allah said :"Allah has made some of your brothers as slaves under your care. So whoever has his brother under his care, then let him feed him from his food, and let him clothe him from his clothes. And do not give him a duty that he cannot bear, and if you give him a duty he cannot bear, then assist him with it}}
\hadithdefcmd{tirmidhi}{1946}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ هَمَّامِ بْنِ يَحْيَى، عَنْ فَرْقَدٍ السَّبَخِيِّ، عَنْ مُرَّةَ الطَّيِّبِ، عَنْ أَبِي بَكْرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ سَيِّئُ الْمَلَكَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ تَكَلَّمَ أَيُّوبُ السَّخْتِيَانِيُّ وَغَيْرُ وَاحِدٍ فِي فَرْقَدٍ السَّبَخِيِّ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{1946}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Bakr As-Siddiq narrated that the Messenger of Allah said :"The one who treats his slaves badly will not enter paradise}}
\hadithdefcmd{tirmidhi}{1947}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ فُضَيْلِ بْنِ غَزْوَانَ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم نَبِيُّ التَّوْبَةِ ‏ "‏ مَنْ قَذَفَ مَمْلُوكَهُ بَرِيئًا مِمَّا قَالَ لَهُ أَقَامَ عَلَيْهِ الْحَدَّ يَوْمَ الْقِيَامَةِ إِلاَّ أَنْ يَكُونَ كَمَا قَالَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَابْنُ أَبِي نُعْمٍ هُوَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي نُعْمٍ الْبَجَلِيُّ يُكْنَى أَبَا الْحَكَمِ ‏.‏ وَفِي الْبَابِ عَنْ سُوَيْدِ بْنِ مُقَرِّنٍ وَعَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏\hadithno{1947}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that Abul-Qasim, the Prophet of Repentance, said :"If somebody slanders his slave (by accusing him of committing illegal sexual intercourse) and the slave is innocent from what he says, Allah will impose the punishment upon him on the Day of Resurrection, unless it is as he said about him}}
\hadithdefcmd{tirmidhi}{1948}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا مُؤَمَّلٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ كُنْتُ أَضْرِبُ مَمْلُوكًا لِي فَسَمِعْتُ قَائِلاً مِنْ خَلْفِي يَقُولُ ‏"‏ اعْلَمْ أَبَا مَسْعُودٍ اعْلَمْ أَبَا مَسْعُودٍ ‏"‏ ‏.‏ فَالْتَفَتُّ فَإِذَا أَنَا بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ لَلَّهُ أَقْدَرُ عَلَيْكَ مِنْكَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو مَسْعُودٍ فَمَا ضَرَبْتُ مَمْلُوكًا لِي بَعْدَ ذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِبْرَاهِيمُ التَّيْمِيُّ هُوَ إِبْرَاهِيمُ بْنُ يَزِيدَ بْنِ شَرِيكٍ ‏.‏\hadithno{1948}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Mas'ud [Al-Ansari] said:"I was beating a slave of mine and I heard someone behind me saying: 'Beware O Abu Mas'ud! Beware O Abu Mas'ud!' So I turned around and saw that it was the Messenger of Allah. He said: 'Allah has more power over you than you do over him." Abu Mas'ud said: "I have not beaten any slave of mine since then}}
\hadithdefcmd{tirmidhi}{1949}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ أَبِي هَانِئٍ الْخَوْلاَنِيِّ، عَنْ عَبَّاسٍ الْحَجَرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ كَمْ أَعْفُو عَنِ الْخَادِمِ فَصَمَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ يَا رَسُولَ اللَّهِ كَمْ أَعْفُو عَنِ الْخَادِمِ فَقَالَ ‏ "‏ كُلَّ يَوْمٍ سَبْعِينَ مَرَّةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَاهُ عَبْدُ اللَّهِ بْنُ وَهْبٍ عَنْ أَبِي هَانِئٍ الْخَوْلاَنِيِّ نَحْوًا مِنْ هَذَا ‏.‏ وَالْعَبَّاسُ هُوَ ابْنُ جُلَيْدٍ الْحَجَرِيُّ الْمِصْرِيُّ ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ أَبِي هَانِئٍ الْخَوْلاَنِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَرَوَى بَعْضُهُمْ، هَذَا الْحَدِيثَ عَنْ عَبْدِ اللَّهِ بْنِ وَهْبٍ، بِهَذَا الإِسْنَادِ وَقَالَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، ‏.‏\hadithno{1949}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin 'Umar narrated:"A man came to the Prophet and said: 'O Messenger of Allah! How many times should the servant be pardoned?' The Prophet was silent. Then he said: 'O Messenger of Allah! How many times should the servant be pardoned?' He said: ' Seventy times each day}}
\hadithdefcmd{tirmidhi}{1950}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سُفْيَانَ، عَنْ أَبِي هَارُونَ الْعَبْدِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا ضَرَبَ أَحَدُكُمْ خَادِمَهُ فَذَكَرَ اللَّهَ فَارْفَعُوا أَيْدِيَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو هَارُونَ الْعَبْدِيُّ اسْمُهُ عُمَارَةُ بْنُ جُوَيْنٍ ‏.‏ قَالَ قَالَ أَبُو بَكْرٍ الْعَطَّارُ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ ضَعَّفَ شُعْبَةُ أَبَا هَارُونَ الْعَبْدِيَّ ‏.‏ قَالَ يَحْيَى وَمَا زَالَ ابْنُ عَوْنٍ يَرْوِي عَنْ أَبِي هَارُونَ حَتَّى مَاتَ ‏.‏\hadithno{1950}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah said :"When one of you beats his servant then he (should) remember Allah and, withhold your hands}}
\hadithdefcmd{tirmidhi}{1951}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى، عَنْ نَاصِحٍ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يُؤَدِّبَ الرَّجُلُ وَلَدَهُ خَيْرٌ مِنْ أَنْ يَتَصَدَّقَ بِصَاعٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَنَاصِحٌ هُوَ ابْنُ الْعَلاَءِ كُوفِيٌّ لَيْسَ عِنْدَ أَهْلِ الْحَدِيثِ بِالْقَوِيِّ وَلاَ يُعْرَفُ هَذَا الْحَدِيثُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَنَاصِحٌ شَيْخٌ آخَرُ بَصْرِيٌّ يَرْوِي عَنْ عَمَّارِ بْنِ أَبِي عَمَّارٍ وَغَيْرِهِ هُوَ أَثْبَتُ مِنْ هَذَا ‏.‏\hadithno{1951}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin Sumurah narrated that the Messenger of Allah said :"That a man should discipline his son is better for him than to have given a Sa' in charity}}
\hadithdefcmd{tirmidhi}{1952}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَامِرُ بْنُ أَبِي عَامِرٍ الْخَزَّازُ، حَدَّثَنَا أَيُّوبُ بْنُ مُوسَى، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا نَحَلَ وَالِدٌ وَلَدًا مِنْ نَحْلٍ أَفْضَلَ مِنْ أَدَبٍ حَسَنٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَامِرِ بْنِ أَبِي عَامِرٍ الْخَزَّازِ وَهُوَ عَامِرُ بْنُ صَالِحِ بْنِ رُسْتُمَ الْخَزَّازُ وَأَيُّوبُ بْنُ مُوسَى هُوَ ابْنُ عَمْرِو بْنِ سَعِيدِ بْنِ الْعَاصِي ‏.‏ وَهَذَا عِنْدِي حَدِيثٌ مُرْسَلٌ ‏.‏\hadithno{1952}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ayyub bin Musa narrated from his father, from his grandfather, that the Messenger of Allah said :"There is no gift that a father gives his son more virtuous than good manners}}
\hadithdefcmd{tirmidhi}{1953}{حَدَّثَنَا يَحْيَى بْنُ أَكْثَمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْبَلُ الْهَدِيَّةَ وَيُثِيبُ عَلَيْهَا ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَنَسٍ وَابْنِ عُمَرَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ عِيسَى بْنِ يُونُسَ عَنْ هِشَامٍ ‏.‏\hadithno{1953}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Aishah narrated:"The Prophet would accept gifts and he would give something in return}}
\hadithdefcmd{tirmidhi}{1954}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا الرَّبِيعُ بْنُ مُسْلِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لاَ يَشْكُرِ النَّاسَ لاَ يَشْكُرِ اللَّهَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1954}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said :"Whoever is not grateful to the people, he is not grateful to Allah}}
\hadithdefcmd{tirmidhi}{1955}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ ابْنِ أَبِي لَيْلَى، ح وَحَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ الرُّؤَاسِيُّ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَمْ يَشْكُرِ النَّاسَ لَمْ يَشْكُرِ اللَّهَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَالأَشْعَثِ بْنِ قَيْسٍ وَالنُّعْمَانِ بْنِ بَشِيرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1955}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed narrated that the Messenger of Allah said :"Whoever is not grateful to the people, he is not grateful to Allah}}
\hadithdefcmd{tirmidhi}{1956}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ الْجُرَشِيُّ الْيَمَامِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا أَبُو زُمَيْلٍ، عَنْ مَالِكِ بْنِ مَرْثَدٍ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَبَسُّمُكَ فِي وَجْهِ أَخِيكَ لَكَ صَدَقَةٌ وَأَمْرُكَ بِالْمَعْرُوفِ وَنَهْيُكَ عَنِ الْمُنْكَرِ صَدَقَةٌ وَإِرْشَادُكَ الرَّجُلَ فِي أَرْضِ الضَّلاَلِ لَكَ صَدَقَةٌ وَبَصَرُكَ لِلرَّجُلِ الرَّدِيءِ الْبَصَرِ لَكَ صَدَقَةٌ وَإِمَاطَتُكَ الْحَجَرَ وَالشَّوْكَةَ وَالْعَظْمَ عَنِ الطَّرِيقِ لَكَ صَدَقَةٌ وَإِفْرَاغُكَ مِنْ دَلْوِكَ فِي دَلْوِ أَخِيكَ لَكَ صَدَقَةٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَجَابِرٍ وَحُذَيْفَةَ وَعَائِشَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو زُمَيْلٍ اسْمُهُ سِمَاكُ بْنُ الْوَلِيدِ الْحَنَفِيُّ ‏.‏\hadithno{1956}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Dharr narrated that the Messenger of Allah said :"Your smiling in the face of your brother is charity, commanding good and forbidding evil is charity, your giving directions to a man lost in the land is charity for you. Your seeing for a man with bad sight is a charity for you, your removal of a rock, a thorn or a bone from the road is charity for you. Your pouring what remains from your bucket into the bucket of your brother is charity for you}}
\hadithdefcmd{tirmidhi}{1957}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ بْنِ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ عَوْسَجَةَ، يَقُولُ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ مَنَحَ مَنِيحَةَ لَبَنٍ أَوْ وَرِقٍ أَوْ هَدَى زُقَاقًا كَانَ لَهُ مِثْلُ عِتْقِ رَقَبَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي إِسْحَاقَ عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَى مَنْصُورُ بْنُ الْمُعْتَمِرِ وَشُعْبَةُ عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ هَذَا الْحَدِيثَ ‏.‏ وَفِي الْبَابِ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ مَنْ مَنَحَ مَنِيحَةَ وَرِقٍ ‏"‏ ‏.‏ إِنَّمَا يَعْنِي بِهِ قَرْضَ الدَّرَاهِمِ قَوْلُهُ ‏"‏ أَوْ هَدَى زُقَاقًا ‏"‏ ‏.‏ يَعْنِي بِهِ هِدَايَةَ الطَّرِيقِ ‏.‏\hadithno{1957}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Bara bin Azib narrated that the Messenger of Allah said :"Whoever gives someone some milk or silver, or guides him through a strait, then he will have the reward similar to freeing a slave}}
\hadithdefcmd{tirmidhi}{1958}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا رَجُلٌ يَمْشِي فِي طَرِيقٍ إِذْ وَجَدَ غُصْنَ شَوْكٍ فَأَخَّرَهُ فَشَكَرَ اللَّهُ لَهُ فَغَفَرَ لَهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَرْزَةَ وَابْنِ عَبَّاسٍ وَأَبِي ذَرٍّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1958}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said :"When a man was walking on the road, he found a thorny branch and removed it. Allah appreciated his action by forgiving him}}
\hadithdefcmd{tirmidhi}{1959}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنِ ابْنِ أَبِي ذِئْبٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَطَاءٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ جَابِرِ بْنِ عَتِيكٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا حَدَّثَ الرَّجُلُ الْحَدِيثَ ثُمَّ الْتَفَتَ فَهِيَ أَمَانَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَإِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ ابْنِ أَبِي ذِئْبٍ ‏.‏\hadithno{1959}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Jabir bin Abdullah narrated that the Messenger of Allah said :"When a man narrates a narration, then he looks around, then it is a trust}}
\hadithdefcmd{tirmidhi}{1960}{حَدَّثَنَا أَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى الْبَصْرِيُّ حَدَّثَنَا حَاتِمُ بْنُ وَرْدَانَ، حَدَّثَنَا أَيُّوبُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُ لَيْسَ لِي مِنْ شَيْءٍ إِلاَّ مَا أَدْخَلَ عَلَىَّ الزُّبَيْرُ أَفَأُعْطِي قَالَ ‏ "‏ نَعَمْ وَلاَ تُوكِي فَيُوكَى عَلَيْكِ ‏"‏ ‏.‏ يَقُولُ لاَ تُحْصِي فَيُحْصَى عَلَيْكِ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ بِهَذَا الإِسْنَادِ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ رضى الله عنهما وَرَوَى غَيْرُ وَاحِدٍ هَذَا عَنْ أَيُّوبَ وَلَمْ يَذْكُرُوا فِيهِ عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ‏.‏\hadithno{1960}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Asma bint Abi Bakr said:" O the Messenger of Allah! I have nothing except what was given to me by (my husband) Az-Zubair, shall I give it (in charity)?'" It was said: "Do not hold (your wealth) so that Allah will hold against you}}
\hadithdefcmd{tirmidhi}{1961}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ الْوَرَّاقُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّخِيُّ قَرِيبٌ مِنَ اللَّهِ قَرِيبٌ مِنَ الْجَنَّةِ قَرِيبٌ مِنَ النَّاسِ بَعِيدٌ مِنَ النَّارِ وَالْبَخِيلُ بَعِيدٌ مِنَ اللَّهِ بَعِيدٌ مِنَ الْجَنَّةِ بَعِيدٌ مِنَ النَّاسِ قَرِيبٌ مِنَ النَّارِ وَلَجَاهِلٌ سَخِيٌّ أَحَبُّ إِلَى اللَّهِ عَزَّ وَجَلَّ مِنْ عَابِدٍ بَخِيلٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ عَنِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ إِلاَّ مِنْ حَدِيثِ سَعِيدِ بْنِ مُحَمَّدٍ ‏.‏ وَقَدْ خُولِفَ سَعِيدُ بْنُ مُحَمَّدٍ فِي رِوَايَةِ هَذَا الْحَدِيثِ عَنْ يَحْيَى بْنِ سَعِيدٍ إِنَّمَا يُرْوَى عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ عَائِشَةَ شَيْءٌ مُرْسَلٌ ‏.‏\hadithno{1961}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Prophet said:"Generosity is close to Allah, close to Paradise, close to the people and far from the Fire. Stinginess is far from Allah, far from Paradise, far from the people and close to the Fire. The ignorant generous person, is more beloved to Allah than the worshiping stingy person}}
\hadithdefcmd{tirmidhi}{1962}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ أَخْبَرَنَا أَبُو دَاوُدَ، حَدَّثَنَا صَدَقَةُ بْنُ مُوسَى، حَدَّثَنَا مَالِكُ بْنُ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ غَالِبٍ الْحُدَّانِيُّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَصْلَتَانِ لاَ تَجْتَمِعَانِ فِي مُؤْمِنٍ الْبُخْلُ وَسُوءُ الْخُلُقِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ صَدَقَةَ بْنِ مُوسَى ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1962}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah said:"Two traits are not combined in a believer: Stinginess and bad manners}}
\hadithdefcmd{tirmidhi}{1963}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا صَدَقَةُ بْنُ مُوسَى، عَنْ فَرْقَدٍ السَّبَخِيِّ، عَنْ مُرَّةَ الطَّيِّبِ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ خِبٌّ وَلاَ مَنَّانٌ وَلاَ بَخِيلٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1963}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Bakr As-Siddiq narrated that the Messenger of Allah said:"The swindler, the stingy person, and the Mannan shall not enter Paradise}}
\hadithdefcmd{tirmidhi}{1964}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ بِشْرِ بْنِ رَافِعٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُؤْمِنُ غِرٌّ كَرِيمٌ وَالْفَاجِرُ خِبٌّ لَئِيمٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1964}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"The believer is naively noble and the stingy person is deceitfully treacherous}}
\hadithdefcmd{tirmidhi}{1965}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ شُعْبَةَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نَفَقَةُ الرَّجُلِ عَلَى أَهْلِهِ صَدَقَةٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1965}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Mas'ud Al-Ansari narrated that the Messenger of Allah said:"A man's spending on his family is charity}}
\hadithdefcmd{tirmidhi}{1966}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْضَلُ الدِّينَارِ دِينَارٌ يُنْفِقُهُ الرَّجُلُ عَلَى عِيَالِهِ وَدِينَارٌ يُنْفِقُهُ الرَّجُلُ عَلَى دَابَّتِهِ فِي سَبِيلِ اللَّهِ وَدِينَارٌ يُنْفِقُهُ الرَّجُلُ عَلَى أَصْحَابِهِ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو قِلاَبَةَ بَدَأَ بِالْعِيَالِ ‏.‏ ثُمَّ قَالَ فَأَىُّ رَجُلٍ أَعْظَمُ أَجْرًا مِنْ رَجُلٍ يُنْفِقُ عَلَى عِيَالٍ لَهُ صِغَارٍ يُعِفُّهُمُ اللَّهُ بِهِ وَيُغْنِيهِمُ اللَّهُ بِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1966}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thawban narrated that the Messenger of Allah said:"The most virtuous of the Dinar is the Dinar spent by a man on his dependants, and the Dinar spent by a man on his beast in the Cause of Allah, and the Dinar spent by a man on his companions in the Cause of Allah." Abu Qilabah (one of the narrators) said: " He began with the dependants." Then he said: "And which man is greater in reward than a man who spends upon his depandants, having little ones by which Allah causes him to abstain (from the unlawful) and by which Allah enriches him}}
\hadithdefcmd{tirmidhi}{1967}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي شُرَيْحٍ الْعَدَوِيِّ، أَنَّهُ قَالَ أَبْصَرَتْ عَيْنَاىَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَمِعَتْهُ أُذُنَاىَ حِينَ تَكَلَّمَ بِهِ قَالَ ‏"‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ جَائِزَتَهُ ‏"‏ ‏.‏ قَالُوا وَمَا جَائِزَتُهُ قَالَ ‏"‏ يَوْمٌ وَلَيْلَةٌ وَالضِّيَافَةُ ثَلاَثَةُ أَيَّامٍ وَمَا كَانَ بَعْدَ ذَلِكَ فَهُوَ صَدَقَةٌ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا أَوْ لِيَسْكُتْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1967}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Shuraih Al-'Adawf said:"My eyes saw the Messenger of Allah, and my ears heard him speaking when he was speaking and he said: 'Whoever believes in Allah and the Last Day, then let him honor his guest with his reward.' They said: 'What is the reward?' He said: ' A day and a night.' He said: 'And hospitality is for three days, whatever is beyond that is charity. And whoever believes in Allah and the Last Day, then let him say what is good or keep silent}}
\hadithdefcmd{tirmidhi}{1968}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي شُرَيْحٍ الْكَعْبِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الضِّيَافَةُ ثَلاَثَةُ أَيَّامٍ وَجَائِزَتُهُ يَوْمٌ وَلَيْلَةٌ وَمَا أُنْفِقَ عَلَيْهِ بَعْدَ ذَلِكَ فَهُوَ صَدَقَةٌ وَلاَ يَحِلُّ لَهُ أَنْ يَثْوِيَ عِنْدَهُ حَتَّى يُحْرِجَهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي هُرَيْرَةَ ‏.‏ وَقَدْ رَوَاهُ مَالِكُ بْنُ أَنَسٍ وَاللَّيْثُ بْنُ سَعْدٍ عَنْ سَعِيدٍ الْمَقْبُرِيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو شُرَيْحٍ الْخُزَاعِيُّ هُوَ الْكَعْبِيُّ وَهُوَ الْعَدَوِيُّ اسْمُهُ خُوَيْلِدُ بْنُ عَمْرٍو ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ لاَ يَثْوِي عِنْدَهُ ‏"‏ ‏.‏ يَعْنِي الضَّيْفَ لاَ يُقِيمُ عِنْدَهُ حَتَّى يَشْتَدَّ عَلَى صَاحِبِ الْمَنْزِلِ وَالْحَرَجُ هُوَ الضِّيقُ إِنَّمَا قَوْلُهُ ‏"‏ حَتَّى يُحْرِجَهُ ‏"‏ ‏.‏ يَقُولُ حَتَّى يُضَيِّقَ عَلَيْهِ ‏.‏\hadithno{1968}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Shuraih Al-Kabi narrated that the Messenger of Allah said:: "Hospitality is for three days, and his reward is a day and a night, and whatever is spent on him after that is charity. And it is not lawful for him (the guest) to stay so long as to cause him harm}}
\hadithdefcmd{tirmidhi}{1969}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، يَرْفَعُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّاعِي عَلَى الأَرْمَلَةِ وَالْمِسْكِينِ كَالْمُجَاهِدِ فِي سَبِيلِ اللَّهِ أَوْ كَالَّذِي يَصُومُ النَّهَارَ وَيَقُومُ اللَّيْلَ ‏"‏ ‏.‏ حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ ذَلِكَ ‏.‏ وَهَذَا الْحَدِيثُ حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَأَبُو الْغَيْثِ اسْمُهُ سَالِمٌ مَوْلَى عَبْدِ اللَّهِ بْنِ مُطِيعٍ وَثَوْرُ بْنُ زَيْدٍ مَدَنِيٌّ وَثَوْرُ بْنُ يَزِيدَ شَامِيٌّ ‏.‏\hadithno{1969}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Safwan bin Sulaim narrated that the Prophet said:"The one who looks after a widow and a poor person is like the Mujahid in the cause of Allah, or like the one who fasts all the day and stands (in prayer) all the night}}
\hadithdefcmd{tirmidhi}{1970}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا الْمُنْكَدِرُ بْنُ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مَعْرُوفٍ صَدَقَةٌ وَإِنَّ مِنَ الْمَعْرُوفِ أَنْ تَلْقَى أَخَاكَ بِوَجْهٍ طَلْقٍ وَأَنْ تُفْرِغَ مِنْ دَلْوِكَ فِي إِنَاءِ أَخِيكَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي ذَرٍّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1970}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin Abdullah narrated that the Messenger of Allah said:"Every good is charity. Indeed among the good is to meet your brother with a smiling face, and to pour what is left in your bucket into the vessel of your brother}}
\hadithdefcmd{tirmidhi}{1971}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكُمْ بِالصِّدْقِ فَإِنَّ الصِّدْقَ يَهْدِي إِلَى الْبِرِّ وَإِنَّ الْبِرَّ يَهْدِي إِلَى الْجَنَّةِ وَمَا يَزَالُ الرَّجُلُ يَصْدُقُ وَيَتَحَرَّى الصِّدْقَ حَتَّى يُكْتَبَ عِنْدَ اللَّهِ صِدِّيقًا وَإِيَّاكُمْ وَالْكَذِبَ فَإِنَّ الْكَذِبَ يَهْدِي إِلَى الْفُجُورِ وَإِنَّ الْفُجُورَ يَهْدِي إِلَى النَّارِ وَمَا يَزَالُ الْعَبْدُ يَكْذِبُ وَيَتَحَرَّى الْكَذِبَ حَتَّى يُكْتَبَ عِنْدَ اللَّهِ كَذَّابًا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَعُمَرَ وَعَبْدِ اللَّهِ بْنِ الشِّخِّيرِ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1971}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Mas'ud narrated that the Messenger of Allah said:"Abide by truthfulness. For indeed truthfulness leads to righteousness. And indeed righteousness leads to Paradise. A man continues telling the truth and trying hard to tell the truth until he is recorded with Allah as a truthful person. Refrain from falsehood. For indeed falsehood leads to wickedness, and wickedness leads to the Fire. A slave (of Allah) continues lying and trying hard to lie, until he is recorded with Allah as a liar}}
\hadithdefcmd{tirmidhi}{1972}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، قَالَ قُلْتُ لِعَبْدِ الرَّحِيمِ بْنِ هَارُونَ الْغَسَّانِيِّ حَدَّثَكُمْ عَبْدُ الْعَزِيزِ بْنُ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَذَبَ الْعَبْدُ تَبَاعَدَ عَنْهُ الْمَلَكُ مِيلاً مِنْ نَتْنِ مَا جَاءَ بِهِ ‏"‏ ‏.‏ قَالَ يَحْيَى فَأَقَرَّ بِهِ عَبْدُ الرَّحِيمِ بْنُ هَارُونَ فَقَالَ نَعَمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ تَفَرَّدَ بِهِ عَبْدُ الرَّحِيمِ بْنُ هَارُونَ ‏.‏\hadithno{1972}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah said:"When the slave (of Allah) lies, the angel goes a mile away from him because of the stench of what he has done."Yahya said: "(I asked) 'Abdur-Rahim bin Harun if he approved of it,and he said 'Yes}}
\hadithdefcmd{tirmidhi}{1973}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ مَا كَانَ خُلُقٌ أَبْغَضَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْكَذِبِ وَلَقَدْ كَانَ الرَّجُلُ يُحَدِّثُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم بِالْكِذْبَةِ فَمَا يَزَالُ فِي نَفْسِهِ حَتَّى يَعْلَمَ أَنَّهُ قَدْ أَحْدَثَ مِنْهَا تَوْبَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1973}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"There was no behavior more hated to the Messenger of Allah than lying. A man would lie in narrating something in the presence of the Prophet, and he would not be content until he knew that he had repented}}
\hadithdefcmd{tirmidhi}{1974}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا كَانَ الْفُحْشُ فِي شَيْءٍ إِلاَّ شَانَهُ وَمَا كَانَ الْحَيَاءُ فِي شَيْءٍ إِلاَّ زَانَهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّزَّاقِ ‏.‏\hadithno{1974}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas narrated that the Messenger of Allah said:"Al-Fuhsh is not present in anything but it mars it, and Al-Haya' is not present in anything but it beautifies it}}
\hadithdefcmd{tirmidhi}{1975}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يُحَدِّثُ عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خِيَارُكُمْ أَحَاسِنُكُمْ أَخْلاَقًا ‏"‏ ‏.‏ وَلَمْ يَكُنِ النَّبِيُّ صلى الله عليه وسلم فَاحِشًا وَلاَ مُتَفَحِّشًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1975}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin 'Amr said; "The Messenger of Allah said:"The best of you are those best in conduct.' And the Prophet was not one who was obscene, nor one who uttered obscenities}}
\hadithdefcmd{tirmidhi}{1976}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلاَعَنُوا بِلَعْنَةِ اللَّهِ وَلاَ بِغَضَبِهِ وَلاَ بِالنَّارِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَابْنِ عُمَرَ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1976}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Samurah bin Jundab narrated that the Messenger of Allah said:"Do not curse yourselves with Allah's curse, nor with His anger, nor with the Fire}}
\hadithdefcmd{tirmidhi}{1977}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الأَزْدِيُّ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، عَنْ إِسْرَائِيلَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ الْمُؤْمِنُ بِالطَّعَّانِ وَلاَ اللَّعَّانِ وَلاَ الْفَاحِشِ وَلاَ الْبَذِيءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَقَدْ رُوِيَ عَنْ عَبْدِ اللَّهِ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{1977}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah narrated that the Messenger of Allah said:"The believer does not insult the honor of others, nor curse, nor commit Fahishah, nor is he foul}}
\hadithdefcmd{tirmidhi}{1978}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ الْبَصْرِيُّ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنْ رَجُلاً، لَعَنَ الرِّيحَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَلْعَنِ الرِّيحَ فَإِنَّهَا مَأْمُورَةٌ وَإِنَّهُ مَنْ لَعَنَ شَيْئًا لَيْسَ لَهُ بِأَهْلٍ رَجَعَتِ اللَّعْنَةُ عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْلَمُ أَحَدًا أَسْنَدَهُ غَيْرَ بِشْرِ بْنِ عُمَرَ ‏.‏\hadithno{1978}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas narrated that a man cursed the wind in the presence of the Prophet, so he said:"Do not curse the wind, for it is merely doing as ordered , and whoever curses something undeservingly, then the curse returns upon him}}
\hadithdefcmd{tirmidhi}{1979}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عَبْدِ الْمَلِكِ بْنِ عِيسَى الثَّقَفِيِّ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ تَعَلَّمُوا مِنْ أَنْسَابِكُمْ مَا تَصِلُونَ بِهِ أَرْحَامَكُمْ فَإِنَّ صِلَةَ الرَّحِمِ مَحَبَّةٌ فِي الأَهْلِ مَثْرَاةٌ فِي الْمَالِ مَنْسَأَةٌ فِي الأَثَرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ مَنْسَأَةٌ فِي الأَثَرِ ‏"‏ ‏.‏ يَعْنِي زِيَادَةً فِي الْعُمُرِ ‏.‏\hadithno{1979}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Learn enough about your lineage to facilitate keeping your ties of kinship. For indeed keeping the ties of kinship encourages affection among the relatives, increases the wealth, and increases the lifespan}}
\hadithdefcmd{tirmidhi}{1980}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا قَبِيصَةُ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادِ بْنِ أَنْعُمٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا دَعْوَةٌ أَسْرَعَ إِجَابَةً مِنْ دَعْوَةِ غَائِبٍ لِغَائِبٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالإِفْرِيقِيُّ يُضَعَّفُ فِي الْحَدِيثِ وَهُوَ عَبْدُ الرَّحْمَنِ بْنُ زِيَادِ بْنِ أَنْعُمٍ وَعَبْدُ اللَّهِ بْنُ يَزِيدَ هُوَ أَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ ‏.‏\hadithno{1980}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abudullah bin 'Amr narrated that the Messenger of Allah said:"No supplication is more readily responded to, than the supplication made for someone who is absent}}
\hadithdefcmd{tirmidhi}{1981}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْتَبَّانِ مَا قَالاَ فَعَلَى الْبَادِي مِنْهُمَا مَا لَمْ يَعْتَدِ الْمَظْلُومُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ سَعْدٍ وَابْنِ مَسْعُودٍ وَعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1981}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"(The burden of) what is said by the two who vilify each other is upon the one who initiated it, as long as the one who was wronged does not transgress}}
\hadithdefcmd{tirmidhi}{1982}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، قَالَ سَمِعْتُ الْمُغِيرَةَ بْنَ شُعْبَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا الأَمْوَاتَ فَتُؤْذُوا الأَحْيَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدِ اخْتَلَفَ أَصْحَابُ سُفْيَانَ فِي هَذَا الْحَدِيثِ فَرَوَى بَعْضُهُمْ مِثْلَ رِوَايَةِ الْحَفَرِيِّ وَرَوَى بَعْضُهُمْ عَنْ سُفْيَانَ عَنْ زِيَادِ بْنِ عِلاَقَةَ قَالَ سَمِعْتُ رَجُلاً يُحَدِّثُ عِنْدَ الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{1982}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Al-Mughirah bin Shu'bah narrated that the Messenger of Allah said:"Do not vilify the dead (and) by that harm the living}}
\hadithdefcmd{tirmidhi}{1983}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ زُبَيْدِ بْنِ الْحَارِثِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏ قَالَ زُبَيْدٌ قُلْتُ لأَبِي وَائِلٍ أَأَنْتَ سَمِعْتَهُ مِنْ عَبْدِ اللَّهِ قَالَ نَعَمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1983}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Mas'ud narrated that the Messenger of Allah said:"Verbally abusing the Muslim is disobedience and fighting him is disbelief." Zubaid said:"I said to Abu Wa'il: 'Did you hear it from 'Abdullah?' He said: 'Yes}}
\hadithdefcmd{tirmidhi}{1984}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ سَعْدٍ، عَنْ عَلِيٍّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ فِي الْجَنَّةِ غُرَفًا تُرَى ظُهُورُهَا مِنْ بُطُونِهَا وَبُطُونُهَا مِنْ ظُهُورِهَا ‏"‏ ‏.‏ فَقَامَ أَعْرَابِيٌّ فَقَالَ لِمَنْ هِيَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لِمَنْ أَطَابَ الْكَلاَمَ وَأَطْعَمَ الطَّعَامَ وَأَدَامَ الصِّيَامَ وَصَلَّى لِلَّهِ بِاللَّيْلِ وَالنَّاسُ نِيَامٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْحَدِيثِ فِي عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ هَذَا مِنْ قِبَلِ حِفْظِهِ وَهُوَ كُوفِيٌّ وَعَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ الْقُرَشِيُّ مَدَنِيٌّ وَهُوَ أَثْبَتُ مِنْ هَذَا وَكِلاَهُمَا كَانَا فِي عَصْرٍ وَاحِدٍ ‏.‏\hadithno{1984}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that the Messenger of Allah said:"Indeed in Paradise there are chambers, whose outside can be seen from their inside, and their inside can be seen from their outside." A Bedouin stood and said : 'Who are they for, O Messenger of Allah?" He said: "For those who speak well, feed others, fast regularly, and perform salat [for Allah] during the night while the people sleep}}
\hadithdefcmd{tirmidhi}{1985}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نِعِمَّا لأَحَدِهِمْ أَنْ يُطِيعَ رَبَّهُ وَيُؤَدِّيَ حَقَّ سَيِّدِهِ ‏"‏ يَعْنِي الْمَمْلُوكَ ‏.‏ وَقَالَ كَعْبٌ صَدَقَ اللَّهُ وَرَسُولُهُ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي مُوسَى وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1985}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"How wonderful it is for one of them that he obeys Allah and fulfills the rights of his master." Meaning the slave. And Ka'b said: "Allah and His Messenger spoke the truth}}
\hadithdefcmd{tirmidhi}{1986}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الْيَقْظَانِ، عَنْ زَاذَانَ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ عَلَى كُثْبَانِ الْمِسْكِ أُرَاهُ قَالَ يَوْمَ الْقِيَامَةِ عَبْدٌ أَدَّى حَقَّ اللَّهِ وَحَقَّ مَوَالِيهِ وَرَجُلٌ أَمَّ قَوْمًا وَهُمْ بِهِ رَاضُونَ وَرَجُلٌ يُنَادِي بِالصَّلَوَاتِ الْخَمْسِ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ سُفْيَانَ الثَّوْرِيِّ عَنْ أَبِي الْيَقْظَانِ إِلاَّ مِنْ حَدِيثِ وَكِيعٍ وَأَبُو الْيَقْظَانِ اسْمُهُ عُثْمَانُ بْنُ قَيْسٍ وَيُقَالُ ابْنُ عُمَيْرٍ وَهُوَ أَشْهَرُ ‏.‏\hadithno{1986}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah said:"There shall be upon dunes of musk- I think he said: On the Day of Judgment- a slave who fulfills Allah's right and the right of his patron (master), a man who leads a people (in prayer)) and they are pleased with him. And a man who calls for the five prayers during every day and night}}
\hadithdefcmd{tirmidhi}{1987}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اتَّقِ اللَّهَ حَيْثُمَا كُنْتَ وَأَتْبِعِ السَّيِّئَةَ الْحَسَنَةَ تَمْحُهَا وَخَالِقِ النَّاسَ بِخُلُقٍ حَسَنٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ، وَأَبُو نُعَيْمٍ عَنْ سُفْيَانَ، عَنْ حَبِيبٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ مَحْمُودٌ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ مَحْمُودٌ وَالصَّحِيحُ حَدِيثُ أَبِي ذَرٍّ ‏.‏\hadithno{1987}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Dharr said:"The Messenger of Allah said to me: 'Have Taqwa of Allah wherever you are, and follow an evil deed with a good one to wipe it out, and treat the people with good behavior}}
\hadithdefcmd{tirmidhi}{1988}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ وَالظَّنَّ فَإِنَّ الظَّنَّ أَكْذَبُ الْحَدِيثِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَسَمِعْتُ عَبْدَ بْنَ حُمَيْدٍ يَذْكُرُ عَنْ بَعْضِ أَصْحَابِ سُفْيَانَ قَالَ قَالَ سُفْيَانُ الظَّنُّ ظَنَّانِ فَظَنٌّ إِثْمٌ وَظَنٌّ لَيْسَ بِإِثْمٍ فَأَمَّا الظَّنُّ الَّذِي هُوَ إِثْمٌ فَالَّذِي يَظُنُّ ظَنًّا وَيَتَكَلَّمُ بِهِ وَأَمَّا الظَّنُّ الَّذِي لَيْسَ بِإِثْمٍ فَالَّذِي يَظُنُّ وَلاَ يَتَكَلَّمُ بِهِ ‏.‏\hadithno{1988}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Beware of Zann (suspicion), for indeed Zann is the falsest of speech}}
\hadithdefcmd{tirmidhi}{1989}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْوَضَّاحِ الْكُوفِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ، قَالَ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُخَالِطُنَا حَتَّى إِنْ كَانَ لَيَقُولُ لأَخٍ لِي صَغِيرٍ ‏ "‏ يَا أَبَا عُمَيْرٍ مَا فَعَلَ النُّغَيْرُ ‏"‏ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ، نَحْوَهُ ‏.‏ وَأَبُو التَّيَّاحِ اسْمُهُ يَزِيدُ بْنُ حُمَيْدٍ الضُّبَعِيُّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1989}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas narrated:" The Messenger of Allah used to mingle with us such that he said to my younger brother: 'O Abu 'Umair! What did the Nughair do?}}
\hadithdefcmd{tirmidhi}{1990}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ الْبَغْدَادِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ إِنَّكَ تُدَاعِبُنَا ‏.‏ قَالَ ‏ "‏ إِنِّي لاَ أَقُولُ إِلاَّ حَقًّا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صحيح‏\hadithno{1990}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated:"They said: 'O Messenger of Allah! You joke with us?' He said: 'Indeed I do not say except what is true.'" (Hasan)}}
\hadithdefcmd{tirmidhi}{1991}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، اسْتَحْمَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنِّي حَامِلُكَ عَلَى وَلَدِ النَّاقَةِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ مَا أَصْنَعُ بِوَلَدِ النَّاقَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَهَلْ تَلِدُ الإِبِلَ إِلاَّ النُّوقُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1991}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas narrated:"A man sought a mount from the Messenger of Allah who said: 'Indeed, I will let you ride on a she-camel's child.' So he said: 'O Messenger of Allah! What can ashe-camel's child do?' So the Messenger of Allah said: 'Are camels borne from other than she-camels?}}
\hadithdefcmd{tirmidhi}{1992}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ شَرِيكٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ يَا ذَا الأُذُنَيْنِ ‏"‏ ‏.‏ قَالَ مَحْمُودٌ قَالَ أَبُو أُسَامَةَ يَعْنِي مَازَحَهُ ‏.‏ وَهَذَا الْحَدِيثُ حَدِيثٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1992}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah said:"O possessor of two ears!" Mahmud said: "Abu Usamah said: 'He only meant it as a joke}}
\hadithdefcmd{tirmidhi}{1993}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ الْبَصْرِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، قَالَ حَدَّثَنِي سَلَمَةُ بْنُ وَرْدَانَ اللَّيْثِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَرَكَ الْكَذِبَ وَهُوَ بَاطِلٌ بُنِيَ لَهُ فِي رَبَضِ الْجَنَّةِ وَمَنْ تَرَكَ الْمِرَاءَ وَهُوَ مُحِقٌّ بُنِيَ لَهُ فِي وَسَطِهَا وَمَنْ حَسَّنَ خُلُقَهُ بُنِيَ لَهُ فِي أَعْلاَهَا ‏"‏ ‏.‏ وَهَذَا الْحَدِيثُ حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سَلَمَةَ بْنِ وَرْدَانَ عَنْ أَنَسِ بْنِ مَالِكٍ ‏.‏\hadithno{1993}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Batil; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah said:"Whoever avoids lying while he is doing so falsely, a house will be built for him on the skirts of Paradise. Whoever avoids arguing while he is in the right, a house will be built for him in its midst. And whoever has good character, a house will be built for him in its heights}}
\hadithdefcmd{tirmidhi}{1994}{حَدَّثَنَا فَضَالَةُ بْنُ الْفَضْلِ الْكُوفِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ ابْنِ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَفَى بِكَ إِثْمًا أَنْ لاَ تَزَالَ مُخَاصِمًا ‏"‏ ‏.‏ وَهَذَا الْحَدِيثُ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1994}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that the Messenger of Allah said:"It is enough sin for you that you never stop disputing}}
\hadithdefcmd{tirmidhi}{1995}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ الْبَغْدَادِيُّ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنِ اللَّيْثِ، وَهُوَ ابْنُ أَبِي سُلَيْمٍ عَنْ عَبْدِ الْمَلِكِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُمَارِ أَخَاكَ وَلاَ تُمَازِحْهُ وَلاَ تَعِدْهُ مَوْعِدَةً فَتُخْلِفَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَعَبْدُ الْمَلِكِ عِنْدِي هُوَ ابْنُ أَبِي بَشِيرٍ ‏.‏\hadithno{1995}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that the Messenger of Allah said:"Do not argue with your brother, do not joke with him, and do not make a promise, only to not fulfill it}}
\hadithdefcmd{tirmidhi}{1996}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتِ اسْتَأْذَنَ رَجُلٌ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا عِنْدَهُ فَقَالَ ‏"‏ بِئْسَ ابْنُ الْعَشِيرَةِ أَوْ أَخُو الْعَشِيرَةِ ‏"‏ ‏.‏ ثُمَّ أَذِنَ لَهُ فَأَلاَنَ لَهُ الْقَوْلَ فَلَمَّا خَرَجَ قُلْتُ لَهُ يَا رَسُولَ اللَّهِ قُلْتَ لَهُ مَا قُلْتَ ثُمَّ أَلَنْتَ لَهُ الْقَوْلَ ‏.‏ فَقَالَ ‏"‏ يَا عَائِشَةُ إِنَّ مِنْ شَرِّ النَّاسِ مَنْ تَرَكَهُ النَّاسُ أَوْ وَدَعَهُ النَّاسُ اتِّقَاءَ فُحْشِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1996}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aisha narrated:"A man sought permission to enter upon the Messenger of Allah while I was with him, so he said: 'What an evil son of his tribe, or brother of his tribe.' Then he admitted him and spoke with him. When he left, I said: 'O Messenger of Allah! You said what you said about him. Then you talked politely with him?' He said: 'O 'Aishah! Indeed among the evilest of people are those whom the people avoid, or who the people leave, fearing his filthy speech}}
\hadithdefcmd{tirmidhi}{1997}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا سُوَيْدُ بْنُ عَمْرٍو الْكَلْبِيُّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أُرَاهُ رَفَعَهُ قَالَ ‏ "‏ أَحْبِبْ حَبِيبَكَ هَوْنًا مَا عَسَى أَنْ يَكُونَ بَغِيضَكَ يَوْمًا مَا وَأَبْغِضْ بَغِيضَكَ هَوْنًا مَا عَسَى أَنْ يَكُونَ حَبِيبَكَ يَوْمًا مَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ بِهَذَا الإِسْنَادِ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَيُّوبَ بِإِسْنَادٍ غَيْرِ هَذَا رَوَاهُ الْحَسَنُ بْنُ أَبِي جَعْفَرٍ وَهُوَ حَدِيثٌ ضَعِيفٌ أَيْضًا بِإِسْنَادٍ لَهُ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم وَالصَّحِيحُ عَنْ عَلِيٍّ مَوْقُوفٌ قَوْلُهُ ‏.‏\hadithno{1997}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammad bin Sirin narrated from Abu Hurairah - and I think he (narrated it from the Prophet) who said:"Love your beloved moderately, perhaps he becomes hated to you someday. And hate whom you hate moderately, perhaps he becomes your beloved someday}}
\hadithdefcmd{tirmidhi}{1998}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ مِنْ كِبْرٍ وَلاَ يَدْخُلُ النَّارَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَسَلَمَةَ بْنِ الأَكْوَعِ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1998}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abdullah narrated that the Messenger of Allah said:"Whoever has a mustard seed's weight of pride (arrogance) in his heart, shall not be admitted into Paradise. And whoever has a mustard seed's weight of faith in his heart, shall not be admitted into the Fire}}
\hadithdefcmd{tirmidhi}{1999}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبَانَ بْنِ تَغْلِبَ، عَنْ فُضَيْلِ بْنِ عَمْرٍو، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَدْخُلُ الْجَنَّةَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ مِنْ كِبْرٍ وَلاَ يَدْخُلُ النَّارَ يَعْنِي مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏ قَالَ فَقَالَ لَهُ رَجُلٌ إِنَّهُ يُعْجِبُنِي أَنْ يَكُونَ ثَوْبِي حَسَنًا وَنَعْلِي حَسَنَةً ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ يُحِبُّ الْجَمَالَ وَلَكِنَّ الْكِبْرَ مَنْ بَطَرَ الْحَقَّ وَغَمَصَ النَّاسَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ فِي تَفْسِيرِ هَذَا الْحَدِيثِ ‏"‏ لاَ يَدْخُلُ النَّارَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏ إِنَّمَا مَعْنَاهُ لاَ يُخَلَّدُ فِي النَّارِ ‏.‏ وَهَكَذَا رُوِيَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يَخْرُجُ مِنَ النَّارِ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏ وَقَدْ فَسَّرَ غَيْرُ وَاحِدٍ مِنَ التَّابِعِينَ هَذِهِ الآيَةَ ‏:‏ ‏(‏رَبَّنَا إِنَّكَ مَنْ تُدْخِلِ النَّارَ فَقَدْ أَخْزَيْتَهُ ‏)‏ ‏.‏ فَقَالَ مَنْ تُخَلِّدُ فِي النَّارِ فَقَدْ أَخْزَيْتَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ\hadithno{1999}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah narrated:"The Messenger of Allah said: 'Whoever has a speck of pride (arrogance) in his heart, shall not be admitted into Paradise. And whoever has a speck of faith in his heart, shall not be admitted in to the Fire.'" He said: "So a man said to him: 'I like for my clothes to be nice, and my sandals to be nice?' So he said: 'Indeed Allah loves beauty. But pride is refusing the truth and belittling the people}}
\hadithdefcmd{tirmidhi}{2000}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عُمَرَ بْنِ رَاشِدٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ الرَّجُلُ يَذْهَبُ بِنَفْسِهِ حَتَّى يُكْتَبَ فِي الْجَبَّارِينَ فَيُصِيبُهُ مَا أَصَابَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2000}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Iylas bin Salamah bin Al-Akwa' narrated from his father that the Messenger of Allah said:"A man shall remain exalting himself until he is written among the tyrants, so that he suffers from their afflictions}}
\hadithdefcmd{tirmidhi}{2001}{حَدَّثَنَا عَلِيُّ بْنُ عِيسَى الْبَغْدَادِيُّ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْقَاسِمِ بْنِ عَبَّاسٍ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ تَقُولُونَ لِي فِيَّ التِّيهُ وَقَدْ رَكِبْتُ الْحِمَارَ وَلَبِسْتُ الشَّمْلَةَ وَقَدْ حَلَبْتُ الشَّاةَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ فَعَلَ هَذَا فَلَيْسَ فِيهِ مِنَ الْكِبْرِ شَيْءٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{2001}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jubair bin Mut'im narrated from his father who said:"They (meaning the people in general) told me that I was proud, while I rode a donkey, wore a cloak, and I milked the sheep. And the Messenger of Allah said to me: "Whoever does these, then there is no pride (arrogance) in him}}
\hadithdefcmd{tirmidhi}{2002}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ يَعْلَى بْنِ مَمْلَكٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا شَيْءٌ أَثْقَلُ فِي مِيزَانِ الْمُؤْمِنِ يَوْمَ الْقِيَامَةِ مِنْ خُلُقٍ حَسَنٍ وَإِنَّ اللَّهَ لَيَبْغَضُ الْفَاحِشَ الْبَذِيءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَأُسَامَةَ بْنِ شَرِيكٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2002}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Ad-Dardh narrated that the Messenger of Allah said:"Nothing is heavier on the believer's Scale on the Day of Judgment than good character. For indeed Allah, Most High, is angered by the shameless obscene person}}
\hadithdefcmd{tirmidhi}{2003}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا قَبِيصَةُ بْنُ اللَّيْثِ الْكُوفِيُّ، عَنْ مُطَرِّفٍ، عَنْ عَطَاءٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ شَيْءٍ يُوضَعُ فِي الْمِيزَانِ أَثْقَلُ مِنْ حُسْنِ الْخُلُقِ وَإِنَّ صَاحِبَ حُسْنِ الْخُلُقِ لَيَبْلُغُ بِهِ دَرَجَةَ صَاحِبِ الصَّوْمِ وَالصَّلاَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2003}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Ad-Dardh narrated that the Messenger of Allah said:"Nothing is placed on the Scale that is heavier than good character. Indeed the person with good character will have attained the rank of the person of fasting and prayer}}
\hadithdefcmd{tirmidhi}{2004}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنْ أَبِي هُرَيْرَةَ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْثَرِ مَا يُدْخِلُ النَّاسَ الْجَنَّةَ فَقَالَ ‏"‏ تَقْوَى اللَّهِ وَحُسْنُ الْخُلُقِ ‏"‏ ‏.‏ وَسُئِلَ عَنْ أَكْثَرِ مَا يُدْخِلُ النَّاسَ النَّارَ فَقَالَ ‏"‏ الْفَمُ وَالْفَرْجُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ وَعَبْدُ اللَّهِ بْنُ إِدْرِيسَ هُوَ ابْنُ يَزِيدَ بْنِ عَبْدِ الرَّحْمَنِ الأَوْدِيُّ ‏.‏\hadithno{2004}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah was asked about that for which people are admitted into Paradise the most, so he said:"Taqwa of Allah, and good character." And he was asked about that for which people are admitted into the Fire the most, and he said: " The mouth and the private parts}}
\hadithdefcmd{tirmidhi}{2005}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا أَبُو وَهْبٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، أَنَّهُ وَصَفَ حُسْنَ الْخُلُقِ فَقَالَ هُوَ بَسْطُ الْوَجْهِ وَبَذْلُ الْمَعْرُوفِ وَكَفُّ الأَذَى ‏.‏\hadithno{2005}\hadithgrade{Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Wahb narrated that :'Abdullah bin Al-Mubarak explained good character, and then he said: "It is a smiling face, doing one's best in good, and refraining from harm}}
\hadithdefcmd{tirmidhi}{2006}{حَدَّثَنَا بُنْدَارٌ، وَأَحْمَدُ بْنُ مَنِيعٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالُوا حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ الرَّجُلُ أَمُرُّ بِهِ فَلاَ يَقْرِينِي وَلاَ يُضَيِّفُنِي فَيَمُرُّ بِي أَفَأَجْزِيهِ قَالَ ‏"‏ لاَ أَقْرِهِ ‏"‏ ‏.‏ قَالَ وَرَآنِي رَثَّ الثِّيَابِ فَقَالَ ‏"‏ هَلْ لَكَ مِنْ مَالٍ ‏"‏ ‏.‏ قُلْتُ مِنْ كُلِّ الْمَالِ قَدْ أَعْطَانِي اللَّهُ مِنَ الإِبِلِ وَالْغَنَمِ ‏.‏ قَالَ ‏"‏ فَلْيُرَ عَلَيْكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَجَابِرٍ وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو الأَحْوَصِ اسْمُهُ عَوْفُ بْنُ مَالِكِ بْنِ نَضْلَةَ الْجُشَمِيُّ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ أَقْرِهِ ‏"‏ أَضِفْهُ وَالْقِرَى هُوَ الضِّيَافَةُ ‏.‏\hadithno{2006}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Al-Ahwas narrated from his father who said:"I said: 'O Messenger of Allah! I stayed with a man who did not entertain me nor behave hospitably with me. Then he came to stay with me, shall I reciprocate the same to him?' He (ﷺ said: 'No, entertain him." He said: 'He (ﷺ saw me wearing tattered clothes and said:'(Do you have any wealth?' I said: 'Allah has given me various kinds of wealth through camels and goats.' He said: 'Then let it be seen on you)}}
\hadithdefcmd{tirmidhi}{2007}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، مُحَمَّدُ بْنُ يَزِيدَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ اللَّهِ بْنِ جُمَيْعٍ، عَنْ أَبِي الطُّفَيْلِ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَكُونُوا إِمَّعَةً تَقُولُونَ إِنْ أَحْسَنَ النَّاسُ أَحْسَنَّا وَإِنْ ظَلَمُوا ظَلَمْنَا وَلَكِنْ وَطِّنُوا أَنْفُسَكُمْ إِنْ أَحْسَنَ النَّاسُ أَنْ تُحْسِنُوا وَإِنْ أَسَاءُوا فَلاَ تَظْلِمُوا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2007}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Hudhaifah narrated that the Messenger of Allah said:“Do not be a people without a will of your own, saying: 'If people treat us well, we will treat them well; and if they do wrong, we will do wrong,' but accustom yourselves to do good if people do good, and do not behave unjustly if they do evil.”}}
\hadithdefcmd{tirmidhi}{2008}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَالْحُسَيْنُ بْنُ أَبِي كَبْشَةَ الْبَصْرِيُّ، قَالاَ حَدَّثَنَا يُوسُفُ بْنُ يَعْقُوبَ السَّدُوسِيُّ، حَدَّثَنَا أَبُو سِنَانٍ الْقَسْمَلِيُّ، هُوَ الشَّامِيُّ عَنْ عُثْمَانَ بْنِ أَبِي سَوْدَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَادَ مَرِيضًا أَوْ زَارَ أَخًا لَهُ فِي اللَّهِ نَادَاهُ مُنَادٍ أَنْ طِبْتَ وَطَابَ مَمْشَاكَ وَتَبَوَّأْتَ مِنَ الْجَنَّةِ مَنْزِلاً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو سِنَانٍ اسْمُهُ عِيسَى بْنُ سِنَانٍ ‏.‏ وَقَدْ رَوَى حَمَّادُ بْنُ سَلَمَةَ عَنْ ثَابِتٍ عَنْ أَبِي رَافِعٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْئًا مِنْ هَذَا ‏.‏\hadithno{2008}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Whoever visits the sick, or visits his brother in Allah (faith), a caller calls out: 'May you have goodness and livelihood be good, and may you dwell in an adobe in Paradise}}
\hadithdefcmd{tirmidhi}{2009}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَعَبْدُ الرَّحِيمِ، وَمُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْحَيَاءُ مِنَ الإِيمَانِ وَالإِيمَانُ فِي الْجَنَّةِ وَالْبَذَاءُ مِنَ الْجَفَاءِ وَالْجَفَاءُ فِي النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي بَكْرَةَ وَأَبِي أُمَامَةَ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2009}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Al-Haya is from faith, and faith is in Paradise. Obscenity is from rudeness, and rudeness is in the Fire}}
\hadithdefcmd{tirmidhi}{2010}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا نُوحُ بْنُ قَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِمْرَانَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ الْمُزَنِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّمْتُ الْحَسَنُ وَالتُّؤَدَةُ وَالاِقْتِصَادُ جُزْءٌ مِنْ أَرْبَعَةٍ وَعِشْرِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا نُوحُ بْنُ قَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِمْرَانَ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ عَنْ عَاصِمٍ وَالصَّحِيحُ حَدِيثُ نَصْرِ بْنِ عَلِيٍّ ‏.‏\hadithno{2010}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Sarjis Al-Muzam narrated that the Messenger of Allah said:"Taking the good route is a part of the twenty-four parts of Prophethood}}
\hadithdefcmd{tirmidhi}{2011}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ قُرَّةَ بْنِ خَالِدٍ، عَنْ أَبِي جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لأَشَجِّ عَبْدِ الْقَيْسِ ‏ "‏ إِنَّ فِيكَ خَصْلَتَيْنِ يُحِبُّهُمَا اللَّهُ الْحِلْمُ وَالأَنَاةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنِ الأَشَجِّ الْعَصَرِيِّ ‏.‏\hadithno{2011}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah said to the Ashajj 'Abdul-Qais:"Indeed there are two traits in you that Allah loves: Forbearance, and deliberateness}}
\hadithdefcmd{tirmidhi}{2012}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدَنِيُّ، حَدَّثَنَا عَبْدُ الْمُهَيْمِنِ بْنُ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الأَنَاةُ مِنَ اللَّهِ وَالْعَجَلَةُ مِنَ الشَّيْطَانِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْحَدِيثِ فِي عَبْدِ الْمُهَيْمِنِ بْنِ عَبَّاسِ بْنِ سَهْلٍ وَضَعَّفَهُ مِنْ قِبَلِ حِفْظِهِ وَالأَشَجُّ بْنُ عَبْدِ الْقَيْسِ اسْمُهُ الْمُنْذِرُ بْنُ عَائِذٍ ‏.‏\hadithno{2012}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah-Muhaimin bin 'Abbas bin Sahl bin Sa'd As-Saidi narrated from his father, from his grandfather, who said that the Messenger of Allah said:"Deliberateness is from Allah, and haste is from the Ash-shaitan}}
\hadithdefcmd{tirmidhi}{2013}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ يَعْلَى بْنِ مَمْلَكٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أُعْطِيَ حَظَّهُ مِنَ الرِّفْقِ فَقَدْ أُعْطِيَ حَظَّهُ مِنَ الْخَيْرِ وَمَنْ حُرِمَ حَظَّهُ مِنَ الرِّفْقِ فَقَدْ حُرِمَ حَظَّهُ مِنَ الْخَيْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَجَرِيرِ بْنِ عَبْدِ اللَّهِ وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2013}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Ad-Darda narrated that the Messenger of Allah said:"Whoever was given his share of gentleness, then he has been given a share of good. And whoever has been prevented from his share of gentleness, then he has been prevented from his share of good}}
\hadithdefcmd{tirmidhi}{2014}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ زَكَرِيَّا بْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ مُعَاذَ بْنَ جَبَلٍ إِلَى الْيَمَنِ فَقَالَ ‏ "‏ اتَّقِ دَعْوَةَ الْمَظْلُومِ فَإِنَّهَا لَيْسَ بَيْنَهَا وَبَيْنَ اللَّهِ حِجَابٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عُمَرَ وَأَبِي سَعِيدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو مَعْبَدٍ اسْمُهُ نَافِذٌ ‏.‏\hadithno{2014}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn 'Abbas narrated:"The Messenger of Allah sent Mu'adh [bin Jabal] to Yemen, and said: 'Beware of the supplication of the oppressed; for indeed there is no barrier between it and Allah}}
\hadithdefcmd{tirmidhi}{2015}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ خَدَمْتُ النَّبِيَّ صلى الله عليه وسلم عَشْرَ سِنِينَ فَمَا قَالَ لِي أُفٍّ قَطُّ وَمَا قَالَ لِشَيْءٍ صَنَعْتُهُ لِمَ صَنَعْتَهُ وَلاَ لِشَيْءٍ تَرَكْتُهُ لِمَ تَرَكْتَهُ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَحْسَنِ النَّاسِ خُلُقًا وَلاَ مَسِسْتُ خَزًّا قَطُّ وَلاَ حَرِيرًا وَلاَ شَيْئًا كَانَ أَلْيَنَ مِنْ كَفِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ شَمَمْتُ مِسْكًا قَطُّ وَلاَ عِطْرًا كَانَ أَطْيَبَ مِنْ عَرَقِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَالْبَرَاءِ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2015}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Anas narrated:that "I served the Prophet for ten years. He never said Uff and never blamed me by saying: 'Why did you do so' or why did you not do so?' And the Messenger Of Allah had the best character among all of the people. I never touched Khazz nor silk, nor anything softer than the hand of the Messenger of Allah, nor have I smelled musk, or a fragrance sweeter than the sweat of the Messenger of Allah}}
\hadithdefcmd{tirmidhi}{2016}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ أَبَا عَبْدِ اللَّهِ الْجَدَلِيَّ، يَقُولُ سَأَلْتُ عَائِشَةَ عَنْ خُلُقِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ لَمْ يَكُنْ فَاحِشًا وَلاَ مُتَفَحِّشًا وَلاَ صَخَّابًا فِي الأَسْوَاقِ وَلاَ يَجْزِي بِالسَّيِّئَةِ السَّيِّئَةَ وَلَكِنْ يَعْفُو وَيَصْفَحُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو عَبْدِ اللَّهِ الْجَدَلِيُّ اسْمُهُ عَبْدُ بْنُ عَبْدٍ وَيُقَالُ عَبْدُ الرَّحْمَنِ بْنُ عَبْدٍ ‏.‏\hadithno{2016}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Abdullah Al-Jadali narrated:"I asked 'Aishah about the character of the Messenger of Allah. She said: 'He was not obscene, nor uttering obscenities, nor screaming in the markets, he would not return an evil with an evil, but rather he was pardoning and forgiving}}
\hadithdefcmd{tirmidhi}{2017}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا غِرْتُ عَلَى أَحَدٍ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم مَا غِرْتُ عَلَى خَدِيجَةَ وَمَا بِي أَنْ أَكُونَ أَدْرَكْتُهَا وَمَا ذَاكَ إِلاَّ لِكَثْرَةِ ذِكْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم لَهَا وَإِنْ كَانَ لَيَذْبَحُ الشَّاةَ فَيَتَتَبَّعُ بِهَا صَدَائِقَ خَدِيجَةَ فَيُهْدِيهَا لَهُنَّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{2017}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"I was not jealous of any wife of the Prophet as I was jealous of Khadijah, and it was not because I saw her. It was only because the Messenger of Allah mentioned her so much, and because whenever he would slaughter a sheep, he would look for Khadijah's friends to gift them some of it}}
\hadithdefcmd{tirmidhi}{2018}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ بْنِ خِرَاشٍ الْبَغْدَادِيُّ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا مُبَارَكُ بْنُ فَضَالَةَ، حَدَّثَنِي عَبْدُ رَبِّهِ بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ مِنْ أَحَبِّكُمْ إِلَىَّ وَأَقْرَبِكُمْ مِنِّي مَجْلِسًا يَوْمَ الْقِيَامَةِ أَحَاسِنَكُمْ أَخْلاَقًا وَإِنَّ أَبْغَضَكُمْ إِلَىَّ وَأَبْعَدَكُمْ مِنِّي مَجْلِسًا يَوْمَ الْقِيَامَةِ الثَّرْثَارُونَ وَالْمُتَشَدِّقُونَ وَالْمُتَفَيْهِقُونَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ قَدْ عَلِمْنَا الثَّرْثَارُونَ وَالْمُتَشَدِّقُونَ فَمَا الْمُتَفَيْهِقُونَ قَالَ ‏"‏ الْمُتَكَبِّرُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنِ الْمُبَارَكِ بْنِ فَضَالَةَ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ فِيهِ عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ وَهَذَا أَصَحُّ ‏.‏ وَالثَّرْثَارُ هُوَ الْكَثِيرُ الْكَلاَمِ وَالْمُتَشَدِّقُ الَّذِي يَتَطَاوَلُ عَلَى النَّاسِ فِي الْكَلاَمِ وَيَبْذُو عَلَيْهِمْ ‏.‏\hadithno{2018}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Jabir narrated that the Messenger of Allah said:"Indeed the most beloved among you to me, and the nearest to sit with me on the Day of Judgment is the best of you in character. And indeed, the most disliked among you to me, and the one sitting furthest from me on the Day of Judgement are the Thartharun, and the Mutashaddiqun and the Muthafaihiqun." They said: "O Messenger of Allah! We know about the Thartharun, and the Mutashaddiqun, but what about the Muthafaihiqun?"' He said:"The arrogant}}
\hadithdefcmd{tirmidhi}{2019}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ يَكُونُ الْمُؤْمِنُ لَعَّانًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى بَعْضُهُمْ بِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَنْبَغِي لِلْمُؤْمِنِ أَنْ يَكُونَ لَعَّانًا ‏"‏ ‏.‏ وَهَذَا الْحَدِيثُ مُفَسِّرٌ ‏.‏\hadithno{2019}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah said:"The believer is not one who curses others}}
\hadithdefcmd{tirmidhi}{2020}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ عَلِّمْنِي شَيْئًا وَلاَ تُكْثِرْ عَلَىَّ لَعَلِّي أَعِيهِ ‏.‏ قَالَ ‏"‏ لاَ تَغْضَبْ ‏"‏ ‏.‏ فَرَدَّدَ ذَلِكَ مِرَارًا كُلُّ ذَلِكَ يَقُولُ ‏"‏ لاَ تَغْضَبْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَسُلَيْمَانَ بْنِ صُرَدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو حَصِينٍ اسْمُهُ عُثْمَانُ بْنُ عَاصِمٍ الأَسَدِيُّ ‏.‏\hadithno{2020}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that a man came to the Messenger of Allah and said:"Teach me something that is not too much for me so that, perhaps, I may abide by it." He (S.A.W) said: "Do not get angry." He repeated that (the request) a number of times, each time he replied: 'Do not get angry}}
\hadithdefcmd{tirmidhi}{2021}{حَدَّثَنَا عَبَّاسٌ الدُّورِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، حَدَّثَنِي أَبُو مَرْحُومٍ عَبْدُ الرَّحِيمِ بْنُ مَيْمُونٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَظَمَ غَيْظًا وَهُوَ يَسْتَطِيعُ أَنْ يُنَفِّذَهُ دَعَاهُ اللَّهُ يَوْمَ الْقِيَامَةِ عَلَى رُءُوسِ الْخَلاَئِقِ حَتَّى يُخَيِّرَهُ فِي أَىِّ الْحُورِ شَاءَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2021}\hadithgrade{Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bim Mu'adh bin Anas Al-Juhani narrated that the Messenger of Allah said:"Whoever suppresses his rage while he is able to unleash it, Allah will call him before the heads (leaders) of creation on the Day of Judgement, so that he can inform Him of which of the Hur he would like}}
\hadithdefcmd{tirmidhi}{2022}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَزِيدُ بْنُ بَيَانٍ الْعُقَيْلِيُّ، حَدَّثَنَا أَبُو الرَّحَّالِ الأَنْصَارِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَكْرَمَ شَابٌّ شَيْخًا لِسِنِّهِ إِلاَّ قَيَّضَ اللَّهُ لَهُ مَنْ يُكْرِمُهُ عِنْدَ سِنِّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ هَذَا الشَّيْخِ يَزِيدَ بْنِ بَيَانٍ وَأَبُو الرِّجَالِ الأَنْصَارِيُّ آخَرُ ‏.‏\hadithno{2022}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah said:"No young person honors an elder due to his age, except that Allah appoints for him one who will honor him at that age}}
\hadithdefcmd{tirmidhi}{2023}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ تُفَتَّحُ أَبْوَابُ الْجَنَّةِ يَوْمَ الاِثْنَيْنِ وَالْخَمِيسِ فَيُغْفَرُ فِيهِمَا لِمَنْ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا إِلاَّ الْمُهْتَجِرَيْنِ يُقَالُ رُدُّوا هَذَيْنِ حَتَّى يَصْطَلِحَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُرْوَى فِي بَعْضِ الْحَدِيثِ ‏"‏ ذَرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا ‏"‏ ‏.‏ قَالَ وَمَعْنَى قَوْلِهِ ‏"‏ الْمُهْتَجِرَيْنِ ‏"‏ ‏.‏ يَعْنِي الْمُتَصَارِمَيْنِ ‏.‏ - وَهَذَا مِثْلُ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثَةِ أَيَّامٍ ‏"‏ ‏.‏\hadithno{2023}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.A.W) said:"The gates of Paradise are opened on Monday and Thursday. In them, (will enter) whoever has not associated anything with Allah will be forgiven, except for the two who shun each other, (about whom) it is said: 'Return these two until they make amends}}
\hadithdefcmd{tirmidhi}{2024}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ، أَنَّ نَاسًا، مِنَ الأَنْصَارِ سَأَلُوا النَّبِيَّ صلى الله عليه وسلم فَأَعْطَاهُمْ ثُمَّ سَأَلُوهُ فَأَعْطَاهُمْ ثُمَّ قَالَ ‏"‏ مَا يَكُونُ عِنْدِي مِنْ خَيْرٍ فَلَنْ أَدَّخِرَهُ عَنْكُمْ وَمَنْ يَسْتَغْنِ يُغْنِهِ اللَّهُ وَمَنْ يَسْتَعْفِفْ يُعِفَّهُ اللَّهُ وَمَنْ يَتَصَبَّرْ يُصَبِّرْهُ اللَّهُ وَمَا أُعْطِيَ أَحَدٌ شَيْئًا هُوَ خَيْرٌ وَأَوْسَعُ مِنَ الصَّبْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ مَالِكٍ هَذَا الْحَدِيثُ ‏"‏ فَلَنْ أَذْخَرَهُ عَنْكُمْ ‏"‏ ‏.‏ وَالْمَعْنَى فِيهِ وَاحِدٌ يَقُولُ لَنْ أَحْبِسَهُ عَنْكُمْ ‏.‏\hadithno{2024}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed narrated:"Some persons from the Ansar asked for (something) from the Messenger of Allah (s.a.w) and he gave them. They again asked him for (something), and he gave them. Then he said: 'whatever of good that I have, I would never hoard it from any of you. (Remember) whoever abstains from asking others, Allah will make him content, and whoever tries to make due, Allah will suffice him. And whoever remains patient, Allah will make him patient. Nobody can be given a blessing better and more encompassing than patience}}
\hadithdefcmd{tirmidhi}{2025}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ شَرِّ النَّاسِ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ ذَا الْوَجْهَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ وَعَمَّارٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2025}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Indeed among the worst of people to Allah, on the Day of Judgment, is the two faced person}}
\hadithdefcmd{tirmidhi}{2026}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، قَالَ مَرَّ رَجُلٌ عَلَى حُذَيْفَةَ بْنِ الْيَمَانِ فَقِيلَ لَهُ إِنَّ هَذَا يُبَلِّغُ الأُمَرَاءَ الْحَدِيثَ عَنِ النَّاسِ ‏.‏ فَقَالَ حُذَيْفَةُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ قَتَّاتٌ ‏"‏ ‏.‏ قَالَ سُفْيَانُ وَالْقَتَّاتُ النَّمَّامُ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2026}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Hammam bin Al-Harith said:"Aman passed by Hudhaifah bin Al-Yaman and it was said to him: "This person conveys news about the people to the leaders.' So Hudaifah said: 'The Messenger of Allah said: 'The Qatat shall not enter paradise.'" (Sahih)Sufyan said: "The Qatat is the Nammam}}
\hadithdefcmd{tirmidhi}{2027}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ أَبِي غَسَّانَ، مُحَمَّدِ بْنِ مُطَرِّفٍ عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحَيَاءُ وَالْعِيُّ شُعْبَتَانِ مِنَ الإِيمَانِ وَالْبَذَاءُ وَالْبَيَانُ شُعْبَتَانِ مِنَ النِّفَاقِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ أَبِي غَسَّانَ مُحَمَّدِ بْنِ مُطَرِّفٍ ‏.‏ قَالَ وَالْعِيُّ قِلَّةُ الْكَلاَمِ وَالْبَذَاءُ هُوَ الْفُحْشُ فِي الْكَلاَمِ وَالْبَيَانُ هُوَ كَثْرَةُ الْكَلاَمِ مِثْلُ هَؤُلاَءِ الْخُطَبَاءِ الَّذِينَ يَخْطُبُونَ فَيُوَسِّعُونَ فِي الْكَلاَمِ وَيَتَفَصَّحُونَ فِيهِ مِنْ مَدْحِ النَّاسِ فِيمَا لاَ يُرْضِي اللَّهَ ‏.‏\hadithno{2027}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Umamah narrated that the Messenger of Allah (s.A.W) said:"Al-Haya' and Al-'Iy are two branches of faith, and Al-Badha and Al-Bayan are two branches of Hypocrisy}}
\hadithdefcmd{tirmidhi}{2028}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلَيْنِ، قَدِمَا فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَطَبَا فَعَجِبَ النَّاسُ مِنْ كَلاَمِهِمَا فَالْتَفَتَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ مِنَ الْبَيَانِ سِحْرًا ‏"‏ أَوْ ‏"‏ إِنَّ بَعْضَ الْبَيَانِ سِحْرٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَمَّارٍ وَابْنِ مَسْعُودٍ وَعَبْدِ اللَّهِ بْنِ الشِّخِّيرِ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2028}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Umar narrated that two men arrived during the time of the Messenger of Allah delivering an address. The people were amazed by their speech, so the Messenger of Allah turned to us and said:"Indeed there is magic in eloquence'-or- 'Indeed some eloquence is magic}}
\hadithdefcmd{tirmidhi}{2029}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا نَقَصَتْ صَدَقَةٌ مِنْ مَالٍ وَمَا زَادَ اللَّهُ رَجُلاً بِعَفْوٍ إِلاَّ عِزًّا وَمَا تَوَاضَعَ أَحَدٌ لِلَّهِ إِلاَّ رَفَعَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَابْنِ عَبَّاسٍ وَأَبِي كَبْشَةَ الأَنْمَارِيِّ وَاسْمُهُ عُمَرُ بْنُ سَعْدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2029}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Charity does not diminish wealth, Allah does not increase a man in anything for his pardoning (others) but in honor, and none humbles himself for Allah but Allah raises him}}
\hadithdefcmd{tirmidhi}{2030}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الظُّلْمُ ظُلُمَاتٌ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَائِشَةَ وَأَبِي مُوسَى وَأَبِي هُرَيْرَةَ وَجَابِرٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عُمَرَ ‏.‏\hadithno{2030}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Umar narrated that Prophet said:"Oppression shall be darkness on the Day of Judgment}}
\hadithdefcmd{tirmidhi}{2031}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا عَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم طَعَامًا قَطُّ كَانَ إِذَا اشْتَهَاهُ أَكَلَهُ وَإِلاَّ تَرَكَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو حَازِمٍ هُوَ الأَشْجَعِيُّ الْكُوفِيُّ وَاسْمُهُ سَلْمَانُ مَوْلَى عَزَّةَ الأَشْجَعِيَّةِ ‏.‏\hadithno{2031}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah (s.a.w) never criticized any food. if he liked it, he would eat it, and if not, he would leave it}}
\hadithdefcmd{tirmidhi}{2032}{حَدَّثَنَا يَحْيَى بْنُ أَكْثَمَ، وَالْجَارُودُ بْنُ مُعَاذٍ، قَالاَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، حَدَّثَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، عَنْ أَوْفَى بْنِ دَلْهَمٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَعِدَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمِنْبَرَ فَنَادَى بِصَوْتٍ رَفِيعٍ فَقَالَ ‏ "‏ يَا مَعْشَرَ مَنْ قَدْ أَسْلَمَ بِلِسَانِهِ وَلَمْ يُفْضِ الإِيمَانُ إِلَى قَلْبِهِ لاَ تُؤْذُوا الْمُسْلِمِينَ وَلاَ تُعَيِّرُوهُمْ وَلاَ تَتَّبِعُوا عَوْرَاتِهِمْ فَإِنَّهُ مَنْ تَتَبَّعَ عَوْرَةَ أَخِيهِ الْمُسْلِمِ تَتَبَّعَ اللَّهُ عَوْرَتَهُ وَمَنْ تَتَبَّعَ اللَّهُ عَوْرَتَهُ يَفْضَحْهُ وَلَوْ فِي جَوْفِ رَحْلِهِ ‏"‏ قَالَ وَنَظَرَ ابْنُ عُمَرَ يَوْمًا إِلَى الْبَيْتِ أَوْ إِلَى الْكَعْبَةِ فَقَالَ مَا أَعْظَمَكِ وَأَعْظَمَ حُرْمَتَكِ وَالْمُؤْمِنُ أَعْظَمُ حُرْمَةً عِنْدَ اللَّهِ مِنْكِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْحُسَيْنِ بْنِ وَاقِدٍ ‏.‏ وَرَوَى إِسْحَاقُ بْنُ إِبْرَاهِيمَ السَّمَرْقَنْدِيُّ عَنْ حُسَيْنِ بْنِ وَاقِدٍ نَحْوَهُ وَرُوِيَ عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏\hadithno{2032}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Nafi' narrated that Ibn ‘Umar said:“The Messenger of Allah (s.a.w) ascended the Minbar and called out with a raised voice: ’O you who accepted Islam with his tongue, while faith has not reached his heart! Do not harm the Muslims, nor revile them, nor spy on them to expose their secrets. For indeed whoever tries to expose his Muslims brother’s secrets, Allah exposes his secrets wide open, even if he were in the depth of his house.’” He (Nafl’) said: ‘ One day Ibn ‘Umar looked at the House- or – the Ka’bah and said: ‘What is it that is more honored than you, and whose honor is more sacred than yours! And the believer’s honor is more sacred to Allah than yours.’”}}
\hadithdefcmd{tirmidhi}{2033}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حَلِيمَ إِلاَّ ذُو عَثْرَةٍ وَلاَ حَكِيمَ إِلاَّ ذُو تَجْرِبَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2033}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eed narrated that the Messenger of Allah (s.a.w) said:"There is no forbearance except for the one who stumbled, and there is no wisdom except for the one who has experience." (Dai'f)}}
\hadithdefcmd{tirmidhi}{2034}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أُعْطِيَ عَطَاءً فَوَجَدَ فَلْيَجْزِ بِهِ وَمَنْ لَمْ يَجِدْ فَلْيُثْنِ فَإِنَّ مَنْ أَثْنَى فَقَدْ شَكَرَ وَمَنْ كَتَمَ فَقَدْ كَفَرَ وَمَنْ تَحَلَّى بِمَا لَمْ يُعْطَهُ كَانَ كَلاَبِسِ ثَوْبَىْ زُورٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَفِي الْبَابِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَعَائِشَةَ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ وَمَنْ كَتَمَ فَقَدْ كَفَرَ ‏"‏ ‏.‏ يَقُولُ قَدْ كَفَرَ تِلْكَ النِّعْمَةَ ‏.‏\hadithno{2034}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated that the Prophet (s.a.w) said:"Whoever is given a gift, then if he finds something let him reciprocate. If he has nothing, then let him mention some praise. For whoever has mentioned some praise, then he has expressed his gratitude. And whoever refrains (from doing so) then he has committed Kufr. And whoever pretends to be satisfied by that which he was not given, he is like the one who wears a garment of falsehood}}
\hadithdefcmd{tirmidhi}{2035}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، بِمَكَّةَ وَإِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ قَالاَ حَدَّثَنَا الأَحْوَصُ بْنُ جَوَّابٍ، عَنْ سُعَيْرِ بْنِ الْخِمْسِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صُنِعَ إِلَيْهِ مَعْرُوفٌ فَقَالَ لِفَاعِلِهِ جَزَاكَ اللَّهُ خَيْرًا فَقَدْ أَبْلَغَ فِي الثَّنَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ جَيِّدٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أُسَامَةَ بْنِ زَيْدٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ وَسَأَلْتُ مُحَمَّدًا فَلَمْ يَعْرِفْهُ ‏.‏ حَدَّثَنِي عَبْدُ الرَّحِيمِ بْنُ حَازِمٍ الْبَلْخِيُّ قَالَ سَمِعْتُ الْمَكِّيَّ بْنَ إِبْرَاهِيمَ يَقُولُ كُنَّا عِنْدَ ابْنِ جُرَيْجٍ الْمَكِّيِّ فَجَاءَ سَائِلٌ فَسَأَلَهُ فَقَالَ ابْنُ جُرَيْجٍ لِخَازِنِهِ أَعْطِهِ دِينَارًا ‏.‏ فَقَالَ مَا عِنْدِي إِلاَّ دِينَارٌ إِنْ أَعْطَيْتُهُ لَجُعْتَ وَعِيَالَكَ ‏.‏ قَالَ فَغَضِبَ وَقَالَ أَعْطِهِ ‏.‏ قَالَ الْمَكِّيُّ فَنَحْنُ عِنْدَ ابْنِ جُرَيْجٍ إِذْ جَاءَهُ رَجُلٌ بِكِتَابٍ وَصُرَّةٍ وَقَدْ بَعَثَ إِلَيْهِ بَعْضُ إِخْوَانِهِ وَفِي الْكِتَابِ إِنِّي قَدْ بَعَثْتُ خَمْسِينَ دِينَارًا ‏.‏ قَالَ فَحَلَّ ابْنُ جُرَيْجٍ الصُّرَّةَ فَعَدَّهَا فَإِذَا هِيَ أَحَدٌ وَخَمْسُونَ دِينَارًا ‏.‏ قَالَ فَقَالَ ابْنُ جُرَيْجٍ لِخَازِنِهِ قَدْ أَعْطَيْتَ وَاحِدًا فَرَدَّهُ اللَّهُ عَلَيْكَ وَزَادَكَ خَمْسِينَ دِينَارًا ‏.‏\hadithno{2035}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Usamah bin Zaid narrated that the Messenger of Allah (s.a.w) said:"Whoever some good was done to him, and he says: 'May Allah reward you in goodness' then he has done the most that he can of praise}}
