% Auto-generated chapter 15 for muslim
% Hadiths in this chapter: 583

\hadithdefcmd{muslim}{2791}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْقُمُصَ وَلاَ الْعَمَائِمَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ إِلاَّ أَحَدٌ لاَ يَجِدُ النَّعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ تَلْبَسُوا مِنَ الثِّيَابِ شَيْئًا مَسَّهُ الزَّعْفَرَانُ وَلاَ الْوَرْسُ ‏"‏ ‏.‏\hadithno{2791}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that a person asked the Messenger of Allah (ﷺ) what a Muhrim should put on as dress. Thereupon the Messenger of Allah (ﷺ) said:Do not put on a shirt or a turban, or trousers or a cap, or leather stockings except one who does not find shoes; he may put on stockings but he should trim them below the ankles. And do not wear clothes to which saffron or wars is applied}}
\hadithdefcmd{muslim}{2792}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، - قَالَ يَحْيَى أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، - رضى الله عنه - قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم مَا يَلْبَسُ الْمُحْرِمُ قَالَ ‏ "‏ لاَ يَلْبَسُ الْمُحْرِمُ الْقَمِيصَ وَلاَ الْعِمَامَةَ وَلاَ الْبُرْنُسَ وَلاَ السَّرَاوِيلَ وَلاَ ثَوْبًا مَسَّهُ وَرْسٌ وَلاَ زَعْفَرَانٌ وَلاَ الْخُفَّيْنِ إِلاَّ أَنْ لاَ يَجِدَ نَعْلَيْنِ فَلْيَقْطَعْهُمَا حَتَّى يَكُونَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{2792}\hadithtrans{Salim reported on the authority of his father ('Abdullah b. 'Umar) that the Messenger of Allah (ﷺ) was asked what a Muhrim should wear, whereupon he said:A Muhrim should not wear a shirt, or a turban, or a cap, or trousers, or a cloth touched with wars or with saffron, nor (should he wear) stockings, but in case he does not find shoes, but (before wearing stockings) be should trim them (in such a way) that these should become lower than the ankles}}
\hadithdefcmd{muslim}{2793}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ، عُمَرَ - رضى الله عنهما - أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَلْبَسَ الْمُحْرِمُ ثَوْبًا مَصْبُوغًا بِزَعْفَرَانٍ أَوْ وَرْسٍ وَقَالَ ‏ "‏ مَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{2793}\hadithtrans{Ibn 'Umar reported that the Messenger of Allah (ﷺ) forbade the Muhrim to put on a cloth dyed in saffron or wars and he further said:One who does not find shoes (to wear) he may wear stockings, but (only) after trimming them below the ankles}}
\hadithdefcmd{muslim}{2794}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، جَمِيعًا عَنْ حَمَّادٍ، - قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَخْطُبُ يَقُولُ ‏ "‏ السَّرَاوِيلُ لِمَنْ لَمْ يَجِدِ الإِزَارَ وَالْخُفَّانِ لِمَنْ لَمْ يَجِدِ النَّعْلَيْنِ ‏"‏ ‏.‏ يَعْنِي الْمُحْرِمَ ‏.‏\hadithno{2794}\hadithtrans{Ibn 'Abbas (Allah be pleased with both of them) reported:I heard Allah's Messenger (ﷺ) say as he was delivering an address: So far as the trousers are concerned, one who does not find lower garment, he may wear them; as also socks, he may wear them who does not find shoes. It concerns the Muhrim}}
\hadithdefcmd{muslim}{2795}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ يَعْنِي ابْنَ جَعْفَرٍ، ح وَحَدَّثَنِي أَبُو غَسَّانَ الرَّازِيُّ، حَدَّثَنَا بَهْزٌ، قَالاَ جَمِيعًا حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، بِهَذَا الإِسْنَادِ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ بِعَرَفَاتٍ ‏.‏ فَذَكَرَ هَذَا الْحَدِيثَ ‏.‏\hadithno{2795}\hadithtrans{Amr b. Dinar narrated with the same chain of transmitters that he heard the Messenger of Allah (ﷺ) delivering sermon at 'Arafat, and he made a mention of this hadith (as quoted above)}}
\hadithdefcmd{muslim}{2796}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، كُلُّ هَؤُلاَءِ عَنْ عَمْرِو بْنِ دِينَارٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ أَحَدٌ مِنْهُمْ يَخْطُبُ بِعَرَفَاتٍ ‏.‏ غَيْرُ شُعْبَةَ وَحْدَهُ ‏.‏\hadithno{2796}\hadithtrans{This hadith has been narrated on the authority of 'Amr b. Dinar with the same chain of transmitters, but none of them (the narrators) made a mention that he (the Holy Prophet) was delivering address at 'Arafat except Shu'ba}}
\hadithdefcmd{muslim}{2797}{وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ وَمَنْ لَمْ يَجِدْ إِزَارًا فَلْيَلْبَسْ سَرَاوِيلَ ‏"‏ ‏.‏\hadithno{2797}\hadithtrans{Jabir (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who does not find shoes to wear may wear socks, and he who does not find lower garment to wear may put on trousers}}
\hadithdefcmd{muslim}{2798}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا عَطَاءُ بْنُ أَبِي رَبَاحٍ، عَنْ صَفْوَانَ، بْنِ يَعْلَى بْنِ أُمَيَّةَ عَنْ أَبِيهِ، - رضى الله عنه - قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ بِالْجِعْرَانَةِ عَلَيْهِ جُبَّةٌ وَعَلَيْهَا خَلُوقٌ - أَوْ قَالَ أَثَرُ صُفْرَةٍ - فَقَالَ كَيْفَ تَأْمُرُنِي أَنْ أَصْنَعَ فِي عُمْرَتِي قَالَ وَأُنْزِلَ عَلَى النَّبِيِّ صلى الله عليه وسلم الْوَحْىُ فَسُتِرَ بِثَوْبٍ وَكَانَ يَعْلَى يَقُولُ وَدِدْتُ أَنِّي أَرَى النَّبِيَّ صلى الله عليه وسلم وَقَدْ نَزَلَ عَلَيْهِ الْوَحْىُ - قَالَ - فَقَالَ أَيَسُرُّكَ أَنْ تَنْظُرَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَدْ أُنْزِلَ عَلَيْهِ الْوَحْىُ قَالَ فَرَفَعَ عُمَرُ طَرَفَ الثَّوْبِ فَنَظَرْتُ إِلَيْهِ لَهُ غَطِيطٌ - قَالَ وَأَحْسِبُهُ قَالَ - كَغَطِيطِ الْبَكْرِ - قَالَ - فَلَمَّا سُرِّيَ عَنْهُ قَالَ ‏ "‏ أَيْنَ السَّائِلُ عَنِ الْعُمْرَةِ اغْسِلْ عَنْكَ أَثَرَ الصُّفْرَةِ - أَوْ قَالَ أَثَرَ الْخَلُوقِ - وَاخْلَعْ عَنْكَ جُبَّتَكَ وَاصْنَعْ فِي عُمْرَتِكَ مَا أَنْتَ صَانِعٌ فِي حَجِّكَ ‏"‏ ‏.‏\hadithno{2798}\hadithtrans{Ya'la b. Umayya reported on the authority of his father (Allah be pleased with them) that a person came to the Messenger of Allah (ﷺ) as he was at Ji'rana and he (the person) had been putting on a cloak which was perfumed, or he (the narrator) said:There was a trace of yellowness on it. He said (to the Holy Prophet): What do you command me to do during my Umra? (It was at this juncture) that the revelation came to the Messenger of Allah (ﷺ) and he was covered with a cloth, and Ya'la said: Would that I see revelation coming to the Messenger of Allah (ﷺ). He (Hadrat 'Umar) said: Would it please you to see the Messenger of Allah (ﷺ) receiving the revelations 'Umar lifted a corner of the cloth and I looked at him and he was emitting a sound of snorting. He (the narrator) said: I thought it was the sound of a camel. When he was relieved of this he said: Where is he who asked about Umra? When the person came, the Prophet (ﷺ) said: Wash out the trace of yellowness, or he said: the trace of perfume and put off the cloak and do in your 'Umra what you do in your Hajj}}
\hadithdefcmd{muslim}{2799}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ، يَعْلَى عَنْ أَبِيهِ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ وَهُوَ بِالْجِعْرَانَةِ وَأَنَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم وَعَلَيْهِ مُقَطَّعَاتٌ - يَعْنِي جُبَّةً - وَهُوَ مُتَضَمِّخٌ بِالْخَلُوقِ فَقَالَ إِنِّي أَحْرَمْتُ بِالْعُمْرَةِ وَعَلَىَّ هَذَا وَأَنَا مُتَضَمِّخٌ بِالْخَلُوقِ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا كُنْتَ صَانِعًا فِي حَجِّكَ ‏"‏ ‏.‏ قَالَ أَنْزِعُ عَنِّي هَذِهِ الثِّيَابَ وَأَغْسِلُ عَنِّي هَذَا الْخَلُوقَ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا كُنْتَ صَانِعًا فِي حَجِّكَ فَاصْنَعْهُ فِي عُمْرَتِكَ ‏"‏ ‏.‏\hadithno{2799}\hadithtrans{Safwan b. Ya'la reported on the authority of his father (who said):A person came to the Messenger of Allah (ﷺ) as he was staying at Ji'rana and I (the narrator's father) was at that time in the apostle's (ﷺ) company and (the person) was donning a cloak having the marks of perfume on it, and he said: I am in a state of Ihram for the sake of Umra, and it (this cloak) is upon me and I am perfumed. The Apostle of Allah (ﷺ) said to him: What would you do in your Hajj? He said: I would take off the clothes and would wash from me this perfume. Thereupon the Messenger of Allah (ﷺ) said: What you do in your Hajj do it in your Umra}}
\hadithdefcmd{muslim}{2800}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، قَالاَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عِيسَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، أَنَّ صَفْوَانَ بْنَ يَعْلَى بْنِ أُمَيَّةَ، أَخْبَرَهُ أَنَّ يَعْلَى كَانَ يَقُولُ لِعُمَرَ بْنِ الْخَطَّابِ - رضى الله عنه - لَيْتَنِي أَرَى نَبِيَّ اللَّهِ صلى الله عليه وسلم حِينَ يُنْزَلُ عَلَيْهِ ‏.‏ فَلَمَّا كَانَ النَّبِيُّ صلى الله عليه وسلم بِالْجِعْرَانَةِ وَعَلَى النَّبِيِّ صلى الله عليه وسلم ثَوْبٌ قَدْ أُظِلَّ بِهِ عَلَيْهِ مَعَهُ نَاسٌ مِنْ أَصْحَابِهِ فِيهِمْ عُمَرُ إِذْ جَاءَهُ رَجُلٌ عَلَيْهِ جُبَّةُ صُوفٍ مُتَضَمِّخٌ بِطِيبٍ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ تَرَى فِي رَجُلٍ أَحْرَمَ بِعُمْرَةٍ فِي جُبَّةٍ بَعْدَ مَا تَضَمَّخَ بِطِيبٍ فَنَظَرَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم سَاعَةً ثُمَّ سَكَتَ فَجَاءَهُ الْوَحْىُ فَأَشَارَ عُمَرُ بِيَدِهِ إِلَى يَعْلَى بْنِ أُمَيَّةَ تَعَالَ ‏.‏ فَجَاءَ يَعْلَى فَأَدْخَلَ رَأْسَهُ فَإِذَا النَّبِيُّ صلى الله عليه وسلم مُحْمَرُّ الْوَجْهِ يَغِطُّ سَاعَةً ثُمَّ سُرِّيَ عَنْهُ فَقَالَ ‏"‏ أَيْنَ الَّذِي سَأَلَنِي عَنِ الْعُمْرَةِ آنِفًا ‏"‏ ‏.‏ فَالْتُمِسَ الرَّجُلُ فَجِيءَ بِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمَّا الطِّيبُ الَّذِي بِكَ فَاغْسِلْهُ ثَلاَثَ مَرَّاتٍ وَأَمَّا الْجُبَّةُ فَانْزِعْهَا ثُمَّ اصْنَعْ فِي عُمْرَتِكَ مَا تَصْنَعُ فِي حَجِّكَ ‏"‏ ‏.‏\hadithno{2800}\hadithtrans{Safwan b. Ya'la b. Umayya reported that Ya'la used to say to 'Umar b. Khattab (Allah be pleased with him):Would that I see revelation descending upon the Messenger of Allah (ﷺ). (Once) when the Messenger of Allah (ﷺ) was in Ji'rana and there was a cloth which provided shade over him, and there were his Companions with him. 'Umar being one of them, there came a person with a cloak of wool on him daubed with perfume and he said: Messenger of Allah, what about the person who entered upon the state of Ihram with a cloak after daubing it with perfume? The Apostle of Allah (ﷺ) looked at him for a short while, and then became quiet, and revelation began descending upon him, and 'Umar gestured (with his hand) to Ya'la b. Umayya to come. Ya'la came and he entered his head (beneath the cloth and saw) the Messenger of Allah (ﷺ) with his face red, and breathing heavily. Then he felt relieved (of that burden) and he said: Where is the man who was just asking me about Umra? The man was searched for and he was brought, and the Messenger of Allah (ﷺ) said: So far as the perfume is concerned, wash it three times, and remove the cloak too (as it was sewn) and do in 'Umra as you do in Hajj}}
\hadithdefcmd{muslim}{2801}{وَحَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، وَمُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرِ بْنِ حَازِمٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ قَيْسًا، يُحَدِّثُ عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ، يَعْلَى بْنِ أُمَيَّةَ عَنْ أَبِيهِ، رضى الله عنه أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ بِالْجِعْرَانَةِ قَدْ أَهَلَّ بِالْعُمْرَةِ وَهُوَ مُصَفِّرٌ لِحْيَتَهُ وَرَأْسَهُ وَعَلَيْهِ جُبَّةٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَحْرَمْتُ بِعُمْرَةٍ وَأَنَا كَمَا تَرَى ‏.‏ فَقَالَ ‏ "‏ انْزِعْ عَنْكَ الْجُبَّةَ وَاغْسِلْ عَنْكَ الصُّفْرَةَ وَمَا كُنْتَ صَانِعًا فِي حَجِّكَ فَاصْنَعْهُ فِي عُمْرَتِكَ ‏"‏ ‏.‏\hadithno{2801}\hadithtrans{Ya'la b. Umayya (Allah be pleased with him) reported that a person came to the Messenger of Allah (ﷺ) as he was staying at Ji'rana and he had put on Ihram for 'Umra and he had dyed his beard and his head with yellow colour and there was a cloak on him. He said:I put on Ihram for 'Umra and I am in this state as you see (with dyed beard and head and a cloak over me). He (the Holy Prophet) said: Take off the cloak and wash the yellowness and do in your 'Umra what you do in Hajj}}
\hadithdefcmd{muslim}{2802}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو عَلِيٍّ، عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ حَدَّثَنَا رَبَاحُ بْنُ أَبِي مَعْرُوفٍ، قَالَ سَمِعْتُ عَطَاءً، قَالَ أَخْبَرَنِي صَفْوَانُ بْنُ يَعْلَى، عَنْ أَبِيهِ، - رضى الله عنه - قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَاهُ رَجُلٌ عَلَيْهِ جُبَّةٌ بِهَا أَثَرٌ مِنْ خَلُوقٍ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَحْرَمْتُ بِعُمْرَةٍ فَكَيْفَ أَفْعَلُ فَسَكَتَ عَنْهُ فَلَمْ يَرْجِعْ إِلَيْهِ وَكَانَ عُمَرُ يَسْتُرُهُ إِذَا أُنْزِلَ عَلَيْهِ الْوَحْىُ يُظِلُّهُ فَقُلْتُ لِعُمَرَ - رضى الله عنه - إِنِّي أُحِبُّ إِذَا أُنْزِلَ عَلَيْهِ الْوَحْىُ أَنْ أُدْخِلَ رَأْسِي مَعَهُ فِي الثَّوْبِ ‏.‏ فَلَمَّا أُنْزِلَ عَلَيْهِ خَمَّرَهُ عُمَرُ - رضى الله عنه - بِالثَّوْبِ فَجِئْتُهُ فَأَدْخَلْتُ رَأْسِي مَعَهُ فِي الثَّوْبِ فَنَظَرْتُ إِلَيْهِ فَلَمَّا سُرِّيَ عَنْهُ قَالَ ‏"‏ أَيْنَ السَّائِلُ آنِفًا عَنِ الْعُمْرَةِ ‏"‏ ‏.‏ فَقَامَ إِلَيْهِ الرَّجُلُ فَقَالَ ‏"‏ انْزِعْ عَنْكَ جُبَّتَكَ وَاغْسِلْ أَثَرَ الْخَلُوقِ الَّذِي بِكَ وَافْعَلْ فِي عُمْرَتِكَ مَا كُنْتَ فَاعِلاً فِي حَجِّكَ ‏"‏ ‏.‏\hadithno{2802}\hadithtrans{Ya'la reported:We were with the Messenger of Allah (ﷺ) that a person came to him with a cloak on him having the traces of scent. He said, Messenger of Allah, I put on Ihram for 'Umra: what should I do? He (the Holy Prophet) kept quiet and did not make him any reply. And 'Umar screened him and it was (usual) with 'Umar that when the revelation descended upon him, he provided him shade (with the help of a piece of cloth). I (the person who came to the Holy Prophet) said: I said to 'Umar I wish to project my head into the cloth (to see how the Prophet receives revelation). So when the revelation began to descend upon him 'Umar wrapped him (the Holy Prophet) with cloth I came to him and projected my head with him into the cloth, and saw him (the Holy Prophet) (receiving the revelation). When he (the Holy Prophet) was relieved (of its burden), he said: Where is the inquirer who was just inquiring about 'Umra? That man came to him. Thereupon he (the Messenger of Allah) said: Take off the cloak from (your body) and wash the traces of perfume which were upon you, and do in 'Umra what you did in Hajj}}
\hadithdefcmd{muslim}{2803}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَخَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ، وَقُتَيْبَةُ، جَمِيعًا عَنْ حَمَّادٍ، - قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ وَقَّتَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ وَلأَهْلِ الشَّامِ الْجُحْفَةَ وَلأَهْلِ نَجْدٍ قَرْنَ الْمَنَازِلِ وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ ‏.‏ قَالَ ‏ "‏ فَهُنَّ لَهُنَّ وَلِمَنْ أَتَى عَلَيْهِنَّ مِنْ غَيْرِ أَهْلِهِنَّ مِمَّنْ أَرَادَ الْحَجَّ وَالْعُمْرَةَ فَمَنْ كَانَ دُونَهُنَّ فَمِنْ أَهْلِهِ وَكَذَا فَكَذَلِكَ حَتَّى أَهْلُ مَكَّةَ يُهِلُّونَ مِنْهَا ‏"‏ ‏.‏\hadithno{2803}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) specified Dhu'l-Hulaifa, for the people of Medina; Juhfa for the people of Syria; Qarn al-Manazil, for the people of Najd; Yalamlam for the people of Yemen (the Mawaqit) and those (Mawaqit) are also meant for those who live at these (places) and for those too who come from without towards them for the sake of Hajj or 'Umra. And those who live within them (within the bounds of these places) or in the suburbs of Mecca or within Mecca, they should enter upon the state of Ihram at these very places}}
\hadithdefcmd{muslim}{2804}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ، بْنُ طَاوُسٍ عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ وَلأَهْلِ الشَّامِ الْجُحْفَةَ وَلأَهْلِ نَجْدٍ قَرْنَ الْمَنَازِلِ وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ ‏.‏ وَقَالَ ‏ "‏ هُنَّ لَهُمْ وَلِكُلِّ آتٍ أَتَى عَلَيْهِنَّ مِنْ غَيْرِهِنَّ مِمَّنْ أَرَادَ الْحَجَّ وَالْعُمْرَةَ وَمَنْ كَانَ دُونَ ذَلِكَ فَمِنْ حَيْثُ أَنْشَأَ حَتَّى أَهْلُ مَكَّةَ مِنْ مَكَّةَ ‏"‏ ‏.‏\hadithno{2804}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) specified Dhu'l-Hulaifa for the people of Medina; Juhfa for the people of Syria, Qarn al-Manazil for the people of Najd, Yalamlam for the people of Yemen (as their respective Mawaqit), and he also said:These are (Mawaqit) of them too (who live there) and everyone who comes from outside (through) their (directions) for the sake of Hajj and 'Umra and for those who live within (those bounds their Miqat is that) from which they commenced (their journey), and for the people of Mecca, Mecca itself is (the Miqat)}}
\hadithdefcmd{muslim}{2805}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَأَهْلُ الشَّامِ مِنَ الْجُحْفَةِ وَأَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ وَبَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏\hadithno{2805}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) said:The people of Medina should enter upon the state of Ihram at Dhu'l-Hulaifa, and people of Syria at Juhfa, and people of Najd at Qarn (al-Manazil), and 'Abdullah (further) said: It has reached me that the Messenger of Allah (ﷺ) also caid: The people of Yemen should enter upon the state of Ihram at Yalamlam}}
\hadithdefcmd{muslim}{2806}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَيُهِلُّ أَهْلُ الشَّامِ مِنَ الْجُحْفَةِ وَيُهِلُّ أَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ - رضى الله عنهما - وَذُكِرَ لِي - وَلَمْ أَسْمَعْ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏\hadithno{2806}\hadithtrans{Salim reported on the authority of his father ('Abdullah b. 'Umar) that the Messenger of Allah (ﷺ) said:The people of Medina should enter upon the state of Ihram at Dhu'l-Hulaifa; the people of Syria at Juhfa, the people of Najd at Qarn (al-Manazil). Ibn 'Umar (Allah be pleased with them) said: It was mentioned to me but I did not myself bear it (directly) from the Messenger of Allah (ﷺ) having said this: The people of Yemen should enter upon the state of Ihram at Yalamlam}}
\hadithdefcmd{muslim}{2807}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، - رضى الله عنه - عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مُهَلُّ أَهْلِ الْمَدِينَةِ ذُو الْحُلَيْفَةِ وَمُهَلُّ أَهْلِ الشَّامِ مَهْيَعَةُ وَهِيَ الْجُحْفَةُ وَمُهَلُّ أَهْلِ نَجْدٍ قَرْنٌ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ - رضى الله عنهما - وَزَعَمُوا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم - وَلَمْ أَسْمَعْ ذَلِكَ مِنْهُ - قَالَ ‏"‏ وَمُهَلُّ أَهْلِ الْيَمَنِ يَلَمْلَمُ ‏"‏ ‏.‏\hadithno{2807}\hadithtrans{Salim b. 'Abdullah b. 'Umar b. al-Khattab (Allah be pleased with them) reported his father as saying:I heard the Messenger of Allah (ﷺ) as saying that the people of Medina should enter upon the state of Ihram at Dhu'l- Hulaifa, the people of Syria at Mahya'a and that is Juhfa, and the people of Najd at Qarn (al-Manazil). 'Abdullah b. 'Umar (Allah be pleased with them) said: (I did not hear it myself from him) but heard from them saying that the Messenger of Allah (ﷺ) had (also) said: The people of Yemen should enter upon the state of Ihram at Yalamlam}}
\hadithdefcmd{muslim}{2808}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، - رضى الله عنهما - يُسْأَلُ عَنِ الْمُهَلِّ، فَقَالَ سَمِعْتُ - ثُمَّ، انْتَهَى فَقَالَ أُرَاهُ يَعْنِي - النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{2808}\hadithtrans{Abu Zubair reported that he heard Jabir b. 'Abdullah (Allah be pleased with them) saying that as he was asked about (the places for entering upon the) state of ihram, he said:I heard (and he then carried the narration directly, I think to) the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2809}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَعَبْدُ بْنُ حُمَيْدٍ، كِلاَهُمَا عَنْ مُحَمَّدِ بْنِ بَكْرٍ، - قَالَ عَبْدٌ أَخْبَرَنَا مُحَمَّدٌ، - أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، - رضى الله عنهما - يُسْأَلُ عَنِ الْمُهَلِّ، فَقَالَ سَمِعْتُ - أَحْسِبُهُ، رَفَعَ إِلَى النَّبِيِّ صلى الله عليه وسلم - فَقَالَ ‏ "‏ مُهَلُّ أَهْلِ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَالطَّرِيقُ الآخَرُ الْجُحْفَةُ وَمُهَلُّ أَهْلِ الْعِرَاقِ مِنْ ذَاتِ عِرْقٍ وَمُهَلُّ أَهْلِ نَجْدٍ مِنْ قَرْنٍ وَمُهَلُّ أَهْلِ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏\hadithno{2809}\hadithtrans{Abu Zubair heard Jabir b. 'Abdullah (Allah be pleased with them) as saying as he was asked about (the place for entering upon the) state of Ihram:I heard (and I think he carried it directly to the Messenger of Allah) him saying: For the people of Medina Dhu'l-Hulaifa is the place for entering upon the state of Ihram, and for (the people coming through the other way, i.e. Syria) it is Juhfa; for the people of Iraq it is Dhat al-'Irq; for the people of Najd it is Qarn (al-Manazil) and for the people of Yemen it is Yalamlam}}
\hadithdefcmd{muslim}{2811}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، بْنِ عُمَرَ - رضى الله عنهما - أَنَّ تَلْبِيَةَ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ - رضى الله عنهما - يَزِيدُ فِيهَا لَبَّيْكَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ بِيَدَيْكَ لَبَّيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏.‏\hadithno{2811}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported that the Talbiya of the Messenger of Allah (ﷺ) was this:Here I am at Thy service. O Allah, here I am at Thy service, here I am at Thy service. There is no associate with Thee; here I am at Thy service. Verily all praise and grace is due to Thee, and the sovereignty (too). There is no associate with Thee. He (the narrator) further said that 'Abdullah b. 'Umar (Allah be pleased with them) made this addition to it: Here I am at Thy service; here I am at Thy service; ready to obey Thee, and good is in Thy Hand; here I am at Thy service; unto Thee is the petition, and deed (is also for Thee)}}
\hadithdefcmd{muslim}{2812}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، وَنَافِعٍ، مَوْلَى عَبْدِ اللَّهِ وَحَمْزَةَ بْنِ عَبْدِ اللَّهِ عَنْ عَبْدِ اللَّهِ، بْنِ عُمَرَ - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اسْتَوَتْ بِهِ رَاحِلَتُهُ قَائِمَةً عِنْدَ مَسْجِدِ ذِي الْحُلَيْفَةِ أَهَلَّ فَقَالَ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ قَالُوا وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ - رضى الله عنهما - يَقُولُ هَذِهِ تَلْبِيَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ نَافِعٌ كَانَ عَبْدُ اللَّهِ - رضى الله عنه - يَزِيدُ مَعَ هَذَا لَبَّيْكَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ بِيَدَيْكَ لَبَّيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏.‏\hadithno{2812}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) entered upon the state of Ihram near the mosque at Dhu'l-Hulaifa as his camel stood by it and he said:Here I am at Thy service, O Lord; here I am at Thy service: here I am at Thy service. There is no associate with Thee. Here I am at Thy service. All praise and grace is due to Thee and the sovereignty (too). There is no associate with Thee. They (the people) said that 'Abdullah b. 'Umar said that that was the Talbiya of the Messenger of Allah (ﷺ). Nafi' said: 'Abdullah (Allah be pleased with him) made this addition to it: Here I am at Thy service; here I am at Thy service; ready to obey Thee. The Good is in Thy Hand. Here I am at Thy service. Unto Thee is the petition and deed (is also for Thee)}}
\hadithdefcmd{muslim}{2813}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - قَالَ تَلَقَّفْتُ التَّلْبِيَةَ مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِهِمْ ‏.‏\hadithno{2813}\hadithtrans{Ibn 'Umar (Allah be pleased with him) reported:I immediately learnt Talbiya from the Messenger of Allah (ﷺ), and he then narrated the hadith}}
\hadithdefcmd{muslim}{2814}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ فَإِنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ أَخْبَرَنِي عَنْ أَبِيهِ، - رضى الله عنه - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ مُلَبِّدًا يَقُولُ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ لاَ يَزِيدُ عَلَى هَؤُلاَءِ الْكَلِمَاتِ ‏.‏ وَإِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ - رضى الله عنهما - كَانَ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْكَعُ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ ‏.‏ ثُمَّ إِذَا اسْتَوَتْ بِهِ النَّاقَةُ قَائِمَةً عِنْدَ مَسْجِدِ الْحُلَيْفَةِ أَهَلَّ بِهَؤُلاَءِ الْكَلِمَاتِ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ - رضى الله عنهما - يَقُولُ كَانَ عُمَرُ بْنُ الْخَطَّابِ - رضى الله عنه - يُهِلُّ بِإِهْلاَلِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ هَؤُلاَءِ الْكَلِمَاتِ وَيَقُولُ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ فِي يَدَيْكَ لَبَّيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏.‏\hadithno{2814}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported:I heard the Messenger of Allah (ﷺ) pronouncing Talbiya with compacted hair: Here I am at Thy service. O Allah: here I am at Thy service; here I am at Thy service. There is no associate with Thee; here I am at Thy service. Verily all praise and grace is due to Thee and the Sovereignty (too). There is no associate with Thee; and he did not make any addition to these words. 'Abdullah b. 'Umar (Allah be pleased with them) (further) said: The Messenger of Allah (ﷺ) used to offer two rak'ahs of prayer at Dhu'l-Hulaifa and then when his camel stood up with him on its back near the mosque at Dhu'l-Hulaifa, he pronounced these words (of Talbiya). And 'Abdullah b. 'Umar (Allah be pleased'with them) said that 'Umar b. Khattab (Allah be pleased with him) pronounced, the Talbiya of the Messenger of Allah (ﷺ) in these words of his (Prophet's words) and said: Here I am at Thy service, O Lord; here I am at Thy service, ready to obey Thee, and good is in Thy Hand, Here I am at Thy service. Unto Thee is the petition and deed (is also for Thee)}}
\hadithdefcmd{muslim}{2815}{وَحَدَّثَنِي عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ الْيَمَامِيُّ، حَدَّثَنَا عِكْرِمَةُ، - يَعْنِي ابْنَ عَمَّارٍ - حَدَّثَنَا أَبُو زُمَيْلٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ كَانَ الْمُشْرِكُونَ يَقُولُونَ لَبَّيْكَ لاَ شَرِيكَ لَكَ - قَالَ - فَيَقُولُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَيْلَكُمْ قَدْ قَدْ ‏"‏ ‏.‏ فَيَقُولُونَ إِلاَّ شَرِيكًا هُوَ لَكَ تَمْلِكُهُ وَمَا مَلَكَ ‏.‏ يَقُولُونَ هَذَا وَهُمْ يَطُوفُونَ بِالْبَيْتِ ‏.‏\hadithno{2815}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that the polytheists also pronounced (Talbiya) as:Here I am at Thy service, there is no associate with Thee. The Messenger of Allah (ﷺ) said: Woe be upon them, as they also said: But one associate with Thee, you possess mastery over him, but he does not possess mastery (over you). They used to say this and circumambulate the Ka'ba}}
\hadithdefcmd{muslim}{2816}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ، بْنِ عَبْدِ اللَّهِ أَنَّهُ سَمِعَ أَبَاهُ، - رضى الله عنه - يَقُولُ بَيْدَاؤُكُمْ هَذِهِ الَّتِي تَكْذِبُونَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهَا مَا أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ مِنْ عِنْدِ الْمَسْجِدِ يَعْنِي ذَا الْحُلَيْفَةِ ‏.‏\hadithno{2816}\hadithtrans{Salim b. 'Abdullah (Allah be pleased with them) reported that he heard his father saying:This place Baida' is for you that about which you attribute lie to the Messenger of Allah (ﷺ). And the Messenger of Allah (ﷺ) did not enter upon the state of Ihram but near the mosque at Dhu'l- Hulaifa}}
\hadithdefcmd{muslim}{2817}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ مُوسَى بْنِ، عُقْبَةَ عَنْ سَالِمٍ، قَالَ كَانَ ابْنُ عُمَرَ - رضى الله عنهما - إِذَا قِيلَ لَهُ الإِحْرَامُ مِنَ الْبَيْدَاءِ قَالَ الْبَيْدَاءُ الَّتِي تَكْذِبُونَ فِيهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ مِنْ عِنْدِ الشَّجَرَةِ حِينَ قَامَ بِهِ بَعِيرُهُ ‏.‏\hadithno{2817}\hadithtrans{Salim reported that when it was said to Ibn 'Umar (Allah be pleased with them) that the state of Ihram (commences from)a al-Baida' he said:Al-Baida', you attribute lie about it to the Messenger of Allah (ﷺ). And the Messenger of Allah (ﷺ) did not enter upon the state of Ihram but near the tree when his camel stood up with him}}
\hadithdefcmd{muslim}{2818}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ رضى الله عنهما يَا أَبَا عَبْدِ الرَّحْمَنِ رَأَيْتُكَ تَصْنَعُ أَرْبَعًا لَمْ أَرَ أَحَدًا مِنْ أَصْحَابِكَ يَصْنَعُهَا ‏.‏ قَالَ مَا هُنَّ يَا ابْنَ جُرَيْجٍ قَالَ رَأَيْتُكَ لاَ تَمَسُّ مِنَ الأَرْكَانِ إِلاَّ الْيَمَانِيَيْنِ وَرَأَيْتُكَ تَلْبَسُ النِّعَالَ السِّبْتِيَّةَ وَرَأَيْتُكَ تَصْبُغُ بِالصُّفْرَةِ وَرَأَيْتُكَ إِذَا كُنْتَ بِمَكَّةَ أَهَلَّ النَّاسُ إِذَا رَأَوُا الْهِلاَلَ وَلَمْ تُهْلِلْ أَنْتَ حَتَّى يَكُونَ يَوْمُ التَّرْوِيَةِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ أَمَّا الأَرْكَانُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمَسُّ إِلاَّ الْيَمَانِيَيْنِ وَأَمَّا النِّعَالُ السِّبْتِيَّةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْبَسُ النِّعَالَ الَّتِي لَيْسَ فِيهَا شَعَرٌ وَيَتَوَضَّأُ فِيهَا فَأَنَا أُحِبُّ أَنْ أَلْبَسَهَا وَأَمَّا الصُّفْرَةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْبَغُ بِهَا فَأَنَا أُحِبُّ أَنْ أَصْبَغَ بِهَا وَأَمَّا الإِهْلاَلُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ حَتَّى تَنْبَعِثَ بِهِ رَاحِلَتُهُ ‏.‏\hadithno{2818}\hadithtrans{Ubaid b. Juraij said to 'Ahdullah b. 'Umar (Allah be pleased with them):'Abd al-Rahman, I find you doing four things which I do not see anyone among your companions doing. He said: Son of Juraij, what are these? Thereupon he said: You (while circumambulating the Ka'ba) do not touch but the two pillars situated on the side of yaman (south), and I find you wearing the sandals of tanned leather, and I find you with dyed beard and head, and I also found that, when you were at Mecca, the people pronounced Talbiya as they saw the new moon (Dhu'l-Hijja), but you did not do it till the 8th of Dhu'l-Hijja. Upon this 'Abdullab b. 'Umar said: (So far as the touching of) the pillars is concerned, I did not see the Messenger of Allah (ﷺ) touching them but only those situated on the side of yaman. (So far as the wearing of) the shoes of tanned leather is concerned, I saw the Messenger of Allah (ﷺ) wearing shoes without hair on them, and he (wore them with wet feet) after performing ablution, and I like to wear them. So far as the yellowness is concerned, I saw the Messenger of Allah (ﷺ) dyeing (head, beard and cloth) with this colour and I love to dye (my head, beard or cloth) with this colour. And so far as the pronouncing of Talbiya is concerned, I did not see the Messenger of Allah (ﷺ) pronouncing it until his camel proceeded on (to Dhu'l-Hulaifa)}}
\hadithdefcmd{muslim}{2819}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أَبُو صَخْرٍ، عَنِ ابْنِ قُسَيْطٍ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، قَالَ حَجَجْتُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ - رضى الله عنهما - بَيْنَ حَجٍّ وَعُمْرَةٍ ثِنْتَىْ عَشْرَةَ مَرَّةً فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ لَقَدْ رَأَيْتُ مِنْكَ أَرْبَعَ خِصَالٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِهَذَا الْمَعْنَى إِلاَّ فِي قِصَّةِ الإِهْلاَلِ فَإِنَّهُ خَالَفَ رِوَايَةَ الْمَقْبُرِيِّ فَذَكَرَهُ بِمَعْنًى سِوَى ذِكْرِهِ إِيَّاهُ ‏.‏\hadithno{2819}\hadithtrans{Ubaid b. Juraij reported:I remained in the company of 'Abdullah b. 'Umar b. al-Khattab (Allah be pleased with them) its twelve Hajjs and 'Umras and I said to him: I saw four characteristics (peculiar in you), and the rest of the hadith is the same except the case of Talbiya. There he offered the narration given by al-Maqburi and he stated the facts excepting the one given above}}
\hadithdefcmd{muslim}{2820}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا وَضَعَ رِجْلَهُ فِي الْغَرْزِ وَانْبَعَثَتْ بِهِ رَاحِلَتُهُ قَائِمَةً أَهَلَّ مِنْ ذِي الْحُلَيْفَةِ ‏.‏\hadithno{2820}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) pronounced Talbiya in Dhu'l-Hulaifa as he put his feet in the stirrup and his camel stood up and proceeded}}
\hadithdefcmd{muslim}{2821}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي صَالِحُ بْنُ كَيْسَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - أَنَّهُ كَانَ يُخْبِرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَهَلَّ حِينَ اسْتَوَتْ بِهِ نَاقَتُهُ قَائِمَةً ‏.‏\hadithno{2821}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) pronounced Talbiya as his camel stood up}}
\hadithdefcmd{muslim}{2822}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّأَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ - رضى الله عنهما - قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ رَاحِلَتَهُ بِذِي الْحُلَيْفَةِ ثُمَّ يُهِلُّ حِينَ تَسْتَوِي بِهِ قَائِمَةً ‏\hadithno{2822}\hadithtrans{Abdullah b. 'Umar reported:I saw the Messenger of Allah (ﷺ) riding on his camel at Dhu'l-Hulaifa and pronouncing Talbiya as it stood up with him}}
\hadithdefcmd{muslim}{2823}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، وَأَحْمَدُ بْنُ عِيسَى، قَالَ أَحْمَدُ حَدَّثَنَا وَقَالَ، حَرْمَلَةُ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، - رضى الله عنهما - أَنَّهُ قَالَ بَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذِي الْحُلَيْفَةِ مَبْدَأَهُ وَصَلَّى فِي مَسْجِدِهَا ‏.‏\hadithno{2823}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) spent the night at Dhu'l-Hulaifa while commencing (the rites of) Pilgrimage and he observed prayer in the mosque}}
\hadithdefcmd{muslim}{2824}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لِحُرْمِهِ حِينَ أَحْرَمَ وَلِحِلِّهِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ ‏.‏\hadithno{2824}\hadithtrans{A'isha (Allah be pleased with her) reported:I applied perfume to the Messenger of Allah (ﷺ) before he entered upon the state of lhram and (concluding) before circumambulating the (sacred) House}}
\hadithdefcmd{muslim}{2825}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا أَفْلَحُ بْنُ حُمَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، - رضى الله عنها - زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِيَدِي لِحُرْمِهِ حِينَ أَحْرَمَ وَلِحِلِّهِ حِينَ أَحَلَّ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ‏.‏\hadithno{2825}\hadithtrans{A'isha (Allah be pleased with her), the wife of the Messenger of Allah (ﷺ), reported:I applied perfume to the Messenger of Allah (ﷺ) with my own hand before he entered upon the state of Ihram, and as he concluded it before circumambulating the House (for Tawaf-i-lfada)}}
\hadithdefcmd{muslim}{2826}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم لإِحْرَامِهِ قَبْلَ أَنْ يُحْرِمَ وَلِحِلِّهِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ ‏.‏\hadithno{2826}\hadithtrans{A'isha (Allah be pleased with her) reported:I used to apply perfume to the Messenger of Allah (ﷺ) before his entering upon the state of Ihram and at the conclusion of it, before circumambulating the House (for Tawaf Ifada)}}
\hadithdefcmd{muslim}{2827}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، قَالَ سَمِعْتُ الْقَاسِمَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لِحِلِّهِ وَلِحِرْمِهِ‏.‏\hadithno{2827}\hadithtrans{A'isha (Allah be pleased with her) said:I applied perfume to the Messenger of Allah (ﷺ) as he became free from Ihram and as he entered upon it}}
\hadithdefcmd{muslim}{2828}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عُمَرُ بْنُ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، أَنَّهُ سَمِعَ عُرْوَةَ، وَالْقَاسِمَ، يُخْبِرَانِ عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِيَدِي بِذَرِيرَةٍ فِي حَجَّةِ الْوَدَاعِ لِلْحِلِّ وَالإِحْرَامِ ‏.‏\hadithno{2828}\hadithtrans{A'isha (Allah be pleased with her) said:I applied perfume of Dharira to the Messenger of Allah (ﷺ) with my hand (on the occasion of) the Farewell Pilgrimage on freeing from the state of Ihram and entering upon it}}
\hadithdefcmd{muslim}{2829}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ، - حَدَّثَنَا عُثْمَانُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - بِأَىِّ شَىْءٍ طَيَّبْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ حِرْمِهِ قَالَتْ بِأَطْيَبِ الطِّيبِ‏.‏\hadithno{2829}\hadithtrans{Uthman b. 'Urwa reported on the authority of his father that he said:I asked 'A'isha with what thing she perfumed the Messenger of Allah (ﷺ) at the time of entering upon the state of Ihram. She said: With the best of perfume}}
\hadithdefcmd{muslim}{2830}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ عُثْمَانَ بْنِ عُرْوَةَ، قَالَ سَمِعْتُ عُرْوَةَ، يُحَدِّثُ عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِأَطْيَبِ مَا أَقْدِرُ عَلَيْهِ قَبْلَ أَنْ يُحْرِمَ ثُمَّ يُحْرِمُ ‏.‏\hadithno{2830}\hadithtrans{A'isha (Allah be pleased with her) reported:I applied the best perfume, which I could get, to the Messenger of Allah (ﷺ) before entering upon the state of Ihram (and after this) he put on the Ihram}}
\hadithdefcmd{muslim}{2831}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، عَنْ أَبِي الرِّجَالِ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لِحُرْمِهِ حِينَ أَحْرَمَ وَلِحِلِّهِ قَبْلَ أَنْ يُفِيضَ بِأَطْيَبِ مَا وَجَدْتُ ‏.‏\hadithno{2831}\hadithtrans{A'isha (Allah be pleased with her) reported:I applied the best available perfume I could find to the Messenger of Allah (ﷺ) before he entered upon the state of Ihram and after he was free from it}}
\hadithdefcmd{muslim}{2832}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَسَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو الرَّبِيعِ، وَخَلَفُ بْنُ هِشَامٍ، وَقُتَيْبَةُ، بْنُ سَعِيدٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفْرِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏ وَلَمْ يَقُلْ خَلَفٌ وَهُوَ مُحْرِمٌ ‏.‏ وَلَكِنَّهُ قَالَ وَذَاكَ طِيبُ إِحْرَامِهِ ‏.‏\hadithno{2832}\hadithtrans{A'isha (Allah be pleased with her) reported:I still seem to see the glistening of the perfume where the hair parted on Allah's Messenger's (ﷺ) head as he was in the state of Ihram, and Khalaf (one of the narrators) did not say: As he was in the state of Ihram, but said: That was the perfume of Ihram}}
\hadithdefcmd{muslim}{2833}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ لَكَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُهِلُّ ‏.‏\hadithno{2833}\hadithtrans{A'isha (Allah be pleased with her) reported:I still seem to see the glistening of the perfume where the hair parted on Allah's Messenger's (ﷺ) head and he was free from Ihram}}
\hadithdefcmd{muslim}{2834}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالُوا حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُلَبِّي‏.‏\hadithno{2834}\hadithtrans{A'isha (Allah be pleased with her) reported:I still seem to see the glistening of the perfume where the hair parted on Allah's Messenger's (ﷺ) head, while he was pronouncing Talbiya}}
\hadithdefcmd{muslim}{2835}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، وَعَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ لَكَأَنِّي أَنْظُرُ ‏.‏ بِمِثْلِ حَدِيثِ وَكِيعٍ ‏.‏\hadithno{2835}\hadithtrans{A'isha (Allah be pleased with her) reported:I still seem to see; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{2836}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ إِبْرَاهِيمَ، يُحَدِّثُ عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ كَأَنَّمَا أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2836}\hadithtrans{A'isha (Allah be pleased with her) said:I still seem to see the glistening of the perfume where the hair was parted on Allah's Messeinger's (ﷺ) head while he was in the state of Ihram}}
\hadithdefcmd{muslim}{2837}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ إِنْ كُنْتُ لأَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2837}\hadithtrans{A'isha (Allah be pleased with her) reported:I still seem to perceive the glistening of perfume where the hair was parted on Allah's Messenger's (ﷺ) head as he was in the state of Ihram}}
\hadithdefcmd{muslim}{2838}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، - وَهُوَ السَّلُولِيُّ - حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ، - وَهُوَ ابْنُ إِسْحَاقَ بْنِ أَبِي إِسْحَاقَ السَّبِيعِيُّ - عَنْ أَبِيهِ، عَنْ أَبِي، إِسْحَاقَ سَمِعَ ابْنَ الأَسْوَدِ، يَذْكُرُ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يُحْرِمَ يَتَطَيَّبُ بِأَطْيَبِ مَا يَجِدُ ثُمَّ أَرَى وَبِيصَ الدُّهْنِ فِي رَأْسِهِ وَلِحْيَتِهِ بَعْدَ ذَلِكَ ‏.‏\hadithno{2838}\hadithtrans{A'isha (Allah be pleased with her) reported that when the Messenger of Allah (ﷺ) intended to enter upon the state of Ihram he perfumed himself with the best of perfumes which he could find and after that I saw the glistening of oil on his head and beard}}
\hadithdefcmd{muslim}{2839}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، قَالَ قَالَتْ عَائِشَةُ رضى الله عنها كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الْمِسْكِ فِي مَفْرِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2839}\hadithtrans{A'isha (Allah be pleased with her) reported:I still seem to see the glistening of musk (in the parting of the head) of the Messenger of Allah (ﷺ) while he was in the state of Ihram}}
\hadithdefcmd{muslim}{2840}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ أَبُو عَاصِمٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{2840}\hadithtrans{This hadith has been narrated by 'Ubaidullah with the same chain of transmitters}}
\hadithdefcmd{muslim}{2841}{وَحَدَّثَنِي أَحْمَدُ بْنُ مَنِيعٍ، وَيَعْقُوبُ الدَّوْرَقِيُّ، قَالاَ حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا مَنْصُورٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ أُطَيِّبُ النَّبِيَّ صلى الله عليه وسلم قَبْلَ أَنْ يُحْرِمَ وَيَوْمَ النَّحْرِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ بِطِيبٍ فِيهِ مِسْكٌ ‏.‏\hadithno{2841}\hadithtrans{A'isha (Allah be pleased with her) reported:I used to perfume the Messenger of Allah (ﷺ) with a perfume containing musk before entering upon the state of Ihram and on the day of sacrifice (10th of Dhu'l-Hijja) and (at the conclusion of Ihram) before circumambulating the House (for Tawaf-i-Ifada)}}
\hadithdefcmd{muslim}{2842}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو كَامِلٍ جَمِيعًا عَنْ أَبِي عَوَانَةَ، - قَالَ سَعِيدٌ حَدَّثَنَا أَبُو عَوَانَةَ، - عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ - رضى الله عنهما - عَنِ الرَّجُلِ، يَتَطَيَّبُ ثُمَّ يُصْبِحُ مُحْرِمًا فَقَالَ مَا أُحِبُّ أَنْ أُصْبِحَ مُحْرِمًا أَنْضَخُ طِيبًا لأَنْ أَطَّلِيَ بِقَطِرَانٍ أَحَبُّ إِلَىَّ مِنْ أَنْ أَفْعَلَ ذَلِكَ ‏.‏ فَدَخَلْتُ عَلَى عَائِشَةَ - رضى الله عنها - فَأَخْبَرْتُهَا أَنَّ ابْنَ عُمَرَ قَالَ مَا أُحِبُّ أَنْ أُصْبِحَ مُحْرِمًا أَنْضَخُ طِيبًا لأَنْ أَطَّلِيَ بِقَطِرَانٍ أَحَبُّ إِلَىَّ مِنْ أَنْ أَفْعَلَ ذَلِكَ ‏.‏ فَقَالَتْ عَائِشَةُ أَنَا طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ إِحْرَامِهِ ثُمَّ طَافَ فِي نِسَائِهِ ثُمَّ أَصْبَحَ مُحْرِمًا ‏.‏\hadithno{2842}\hadithtrans{Muhammad b. al-Muntashir reported on the authority of his father:I asked 'Abdullah b. 'Umar (Allah be pleased with them) about a person who applied perfume and then (on the following) morning entered upon the state of lhram. Thereupon he said: I do not like to enter upon the state of Ihram shaking off the perfume. Rubbing of tar (upon my body) is dearer to me than doing this (i. e. the applying of perfume), I went to 'A'isha (Allah be pleased with her) and told her that Ibn 'Umar stated:" I do not like to enter upon the state of Ihram shaking off the perfume. Rubbing of tar (upon my body) is dearer to me than doing it (the applying of perfume)." Thereupon 'A'isha said: I applied perfume to the Messenger of Allah (ﷺ) at the time of his entering upon the state of Ihram. He then went round his wives and then put on Ihram in the morning}}
\hadithdefcmd{muslim}{2843}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم ثُمَّ يَطُوفُ عَلَى نِسَائِهِ ثُمَّ يُصْبِحُ مُحْرِمًا يَنْضَخُ طِيبًا ‏.‏\hadithno{2843}\hadithtrans{A'isha (Allah be pleased with her) reported:I used to apply perfume to the Messenger of Allah (ﷺ). He then went round his wives, and entered upon the state of Ihram in the morning and the perfume was shaken off}}
\hadithdefcmd{muslim}{2844}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ، الْمُنْتَشِرِ عَنْ أَبِيهِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، - رضى الله عنهما - يَقُولُ لأَنْ أُصْبِحَ مُطَّلِيًا بِقَطِرَانٍ أَحَبُّ إِلَىَّ مِنْ أَنْ أُصْبِحَ مُحْرِمًا أَنْضَخُ طِيبًا - قَالَ - فَدَخَلْتُ عَلَى عَائِشَةَ - رضى الله عنها - فَأَخْبَرْتُهَا بِقَوْلِهِ فَقَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَطَافَ فِي نِسَائِهِ ثُمَّ أَصْبَحَ مُحْرِمًا ‏.‏\hadithno{2844}\hadithtrans{Muhammad b. al-Muntashir reported on the authority of his father:I heard from Ibn 'Umar having said this:" It is dearer to me to rub tar (on my body) than to enter upon the state of Ihram (in a state) of shaking off the perfume." He (the narrator) said: I went to 'A'isha and told her about this statement of his (of Ibn 'Umar). Thereupon she said: I applied perfume to the Messenger of Allah (ﷺ) and he then went round his wives and then entered upon the state of Ihram in the morning}}
\hadithdefcmd{muslim}{2845}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ، عَبْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ اللَّيْثِيِّ، أَنَّهُ أَهْدَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِمَارًا وَحْشِيًّا وَهُوَ بِالأَبْوَاءِ - أَوْ بِوَدَّانَ - فَرَدَّهُ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ فَلَمَّا أَنْ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَا فِي وَجْهِي قَالَ ‏ "‏ إِنَّا لَمْ نَرُدَّهُ عَلَيْكَ إِلاَّ أَنَّا حُرُمٌ ‏"‏ ‏.‏\hadithno{2845}\hadithtrans{Al-Sa'b b. Jaththama al-Laithi reported that he presented a wild ass to Allah's Messenger (ﷺ) when he was at al-Abwa', or Waddan, and he refused to accept it. He (the narrator) said:When the Messenger of Allah (ﷺ) looked into my face (which had the mark of dejection as my present had been rejected by him) he (in order to console me) said: We have refused it only because we are in a state of Ihram}}
\hadithdefcmd{muslim}{2846}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، وَقُتَيْبَةُ، جَمِيعًا عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ أَهْدَيْتُ لَهُ حِمَارَ وَحْشٍ ‏.‏ كَمَا قَالَ مَالِكٌ ‏.‏ وَفِي حَدِيثِ اللَّيْثِ وَصَالِحٍ أَنَّ الصَّعْبَ بْنَ جَثَّامَةَ أَخْبَرَهُ ‏.‏\hadithno{2846}\hadithtrans{A hadith (pertaining to this topic), has been narrated on the authority of Zuhri (and the words are):" I presented to him (the Holy Prophet) a wild ass}}
\hadithdefcmd{muslim}{2847}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ قَالُوا حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ وَقَالَ أَهْدَيْتُ لَهُ مِنْ لَحْمِ حِمَارِ وَحْشٍ ‏.‏\hadithno{2847}\hadithtrans{It is narrated on the authority of Zuhri with the same chain of transmitters (the narrator having) said this:" I presented to him the flesh of a wild ass}}
\hadithdefcmd{muslim}{2848}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ أَهْدَى الصَّعْبُ بْنُ جَثَّامَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم حِمَارَ وَحْشٍ وَهُوَ مُحْرِمٌ فَرَدَّهُ عَلَيْهِ وَقَالَ ‏ "‏ لَوْلاَ أَنَّا مُحْرِمُونَ لَقَبِلْنَاهُ مِنْكَ ‏"‏ ‏.‏\hadithno{2848}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that al-Sa'b b. Jaththama presented to the Messenger of Allah (ﷺ) a wild ass as he was in a state of Ihram, and he returned it to him saying:If we were not in a state of Ihram, we would have accepted it from you}}
\hadithdefcmd{muslim}{2849}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ مَنْصُورًا، يُحَدِّثُ عَنِ الْحَكَمِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبٍ، جَمِيعًا عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - فِي رِوَايَةِ مَنْصُورٍ عَنِ الْحَكَمِ أَهْدَى الصَّعْبُ بْنُ جَثَّامَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم رِجْلَ حِمَارِ وَحْشٍ ‏.‏ وَفِي رِوَايَةِ شُعْبَةَ عَنِ الْحَكَمِ عَجُزَ حِمَارِ وَحْشٍ يَقْطُرُ دَمًا ‏.‏ وَفِي رِوَايَةِ شُعْبَةَ عَنْ حَبِيبٍ أُهْدِيَ لِلنَّبِيِّ صلى الله عليه وسلم شِقُّ حِمَارِ وَحْشٍ فَرَدَّهُ ‏.‏\hadithno{2849}\hadithtrans{The narration transmitted by Hakam (the words are):Al-Sa'b b. Jaththama presented to the Messenger of Allah (ﷺ) the leg of a wild ass. And in the narration transmitted by Shu'ba (the words are): (He presented to him) the rump of a wild ass as the blood was trickling from it. In the narration transmitted by Shu'ba on the authority of Habib (the words are): A part of a wild ass was presented to the Apostle (may peace he upon him) and he returned it to him (who presented it)}}
\hadithdefcmd{muslim}{2850}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ قَدِمَ زَيْدُ بْنُ أَرْقَمَ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ يَسْتَذْكِرُهُ كَيْفَ أَخْبَرْتَنِي عَنْ لَحْمِ صَيْدٍ أُهْدِيَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ حَرَامٌ قَالَ قَالَ أُهْدِيَ لَهُ عُضْوٌ مِنْ لَحْمِ صَيْدٍ فَرَدَّهُ ‏.‏ فَقَالَ ‏ "‏ إِنَّا لاَ نَأْكُلُهُ إِنَّا حُرُمٌ ‏"‏ ‏.‏\hadithno{2850}\hadithtrans{Tawus reported on the authority of Ibn 'Abbas (Allah be pleased with them) that Zaid b. Arqam went to him (Ibn 'Abbas) and said:Narrate how you informed me about the meat of the game presented to the Messenger of Allah (ﷺ) as he was in the state of Ihram. Thereupon he said: He was presented with a slice of the meat of game, but he returned it to him (who presented it) saying: We are not going to eat it, as we are in the state of Ihram}}
\hadithdefcmd{muslim}{2851}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ صَالِحِ بْنِ كَيْسَانَ، ح وَحَدَّثَنَا ابْنُ أَبِي، عُمَرَ - وَاللَّفْظُ لَهُ - حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا صَالِحُ بْنُ كَيْسَانَ، قَالَ سَمِعْتُ أَبَا مُحَمَّدٍ، مَوْلَى أَبِي قَتَادَةَ يَقُولُ سَمِعْتُ أَبَا قَتَادَةَ، يَقُولُ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كُنَّا بِالْقَاحَةِ فَمِنَّا الْمُحْرِمُ وَمِنَّا غَيْرُ الْمُحْرِمِ إِذْ بَصُرْتُ بِأَصْحَابِي يَتَرَاءَوْنَ شَيْئًا فَنَظَرْتُ فَإِذَا حِمَارُ وَحْشٍ ‏.‏ فَأَسْرَجْتُ فَرَسِي وَأَخَذْتُ رُمْحِي ثُمَّ رَكِبْتُ فَسَقَطَ مِنِّي سَوْطِي فَقُلْتُ لأَصْحَابِي وَكَانُوا مُحْرِمِينَ نَاوِلُونِي السَّوْطَ ‏.‏ فَقَالُوا وَاللَّهِ لاَ نُعِينُكَ عَلَيْهِ بِشَىْءٍ ‏.‏ فَنَزَلْتُ فَتَنَاوَلْتُهُ ثُمَّ رَكِبْتُ فَأَدْرَكْتُ الْحِمَارَ مِنْ خَلْفِهِ وَهُوَ وَرَاءَ أَكَمَةٍ فَطَعَنْتُهُ بِرُمْحِي فَعَقَرْتُهُ فَأَتَيْتُ بِهِ أَصْحَابِي فَقَالَ بَعْضُهُمْ كُلُوهُ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ تَأْكُلُوهُ ‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم أَمَامَنَا فَحَرَّكْتُ فَرَسِي فَأَدْرَكْتُهُ فَقَالَ ‏ "‏ هُوَ حَلاَلٌ فَكُلُوهُ ‏"‏ ‏.‏\hadithno{2851}\hadithtrans{Abu Qatada reported:We went with the Messenger of Allah (ﷺ) till we reached al-Qaha (a place three stages away from Medina). Some of us were in the state of Ihram and some of us were not. I saw my companions looking towards something, and as I saw I found It to be a wild ass. I saddled my horse and took up my spear and then mounted upon (the horse) and my whip, fell down. I said to my companions as they were in the state of Ihram to pick up the whip for me but they said: By Allah, we cannot help you in any (such) thing (i. e. hunting). So i dismounted (the horse) and picked it (whip) up and mounted again and caught the wild ass after chasing it. It was behind a hillock and I attacked it with my spear and killed it. Then I brought it to my companions. Some of them said: Eat it, while others said: Do not eat it. The Apostle of Allah (ﷺ) was in front of us. I moved my horse and came to him (and asked him), whereupon he said: It is permissible, so eat it}}
\hadithdefcmd{muslim}{2852}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ ح وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ أَبِي النَّضْرِ، عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ، - رضى الله عنه - أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِبَعْضِ طَرِيقِ مَكَّةَ تَخَلَّفَ مَعَ أَصْحَابٍ لَهُ مُحْرِمِينَ وَهُوَ غَيْرُ مُحْرِمٍ فَرَأَى حِمَارًا وَحْشِيًّا فَاسْتَوَى عَلَى فَرَسِهِ فَسَأَلَ أَصْحَابَهُ أَنْ يُنَاوِلُوهُ سَوْطَهُ فَأَبَوْا عَلَيْهِ فَسَأَلَهُمْ رُمْحَهُ فَأَبَوْا عَلَيْهِ فَأَخَذَهُ ثُمَّ شَدَّ عَلَى الْحِمَارِ فَقَتَلَهُ فَأَكَلَ مِنْهُ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَأَبَى بَعْضُهُمْ فَأَدْرَكُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلُوهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّمَا هِيَ طُعْمَةٌ أَطْعَمَكُمُوهَا اللَّهُ ‏"‏ ‏.‏\hadithno{2852}\hadithtrans{Abu Qatada (Allah be pleased with him) reported that while he was with the Messenger of Allah (ﷺ) on one of the highways of Mecca, he lagged behind him (the Holy Prophet) along with companions who were in the state of Ihram, whereas he was himself not Muhrim. He saw a wild ass. As he was mounting his horse he asked his companions to pick up for him his whip (which had dropped) but they refused to do so. He asked them to hand him over the spear, but they refused. He then himself took hold of it and chased the wild ass and killed it. Some of the Companions of the Messenger of Allah (way peace be upon him) ate (its meat), but some of them refused to do so. They overtook the Messenger of Allah (ﷺ) and asked him about it, and he said:It is a food which Allah provided you (so eat it)}}
\hadithdefcmd{muslim}{2853}{وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي قَتَادَةَ، - رضى الله عنه - فِي حِمَارِ الْوَحْشِ ‏.‏ مِثْلَ حَدِيثِ أَبِي النَّضْرِ غَيْرَ أَنَّ فِي حَدِيثِ زَيْدِ بْنِ أَسْلَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ هَلْ مَعَكُمْ مِنْ لَحْمِهِ شَىْءٌ ‏"‏ ‏.‏\hadithno{2853}\hadithtrans{This hadith pertaining to the wild ass is reported on the authority of Abu Qatada. The rest of the hadith is the same but with this (variation of words) that the Messenger of Allah (ﷺ) said:" Is there with you some of its flesh?}}
\hadithdefcmd{muslim}{2854}{وَحَدَّثَنَا صَالِحُ بْنُ مِسْمَارٍ السُّلَمِيُّ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، قَالَ انْطَلَقَ أَبِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ فَأَحْرَمَ أَصْحَابُهُ وَلَمْ يُحْرِمْ وَحُدِّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ عَدُوًّا بِغَيْقَةَ فَانْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ - فَبَيْنَمَا أَنَا مَعَ أَصْحَابِهِ يَضْحَكُ بَعْضُهُمْ إِلَى بَعْضٍ إِذْ نَظَرْتُ فَإِذَا أَنَا بِحِمَارِ وَحْشٍ فَحَمَلْتُ عَلَيْهِ فَطَعَنْتُهُ فَأَثْبَتُّهُ فَاسْتَعَنْتُهُمْ فَأَبَوْا أَنْ يُعِينُونِي فَأَكَلْنَا مِنْ لَحْمِهِ وَخَشِينَا أَنْ نُقْتَطَعَ فَانْطَلَقْتُ أَطْلُبُ رَسُولَ اللَّهِ صلى الله عليه وسلم أُرَفِّعُ فَرَسِي شَأْوًا وَأَسِيرُ شَأْوًا فَلَقِيتُ رَجُلاً مِنْ بَنِي غِفَارٍ فِي جَوْفِ اللَّيْلِ فَقُلْتُ أَيْنَ لَقِيتَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ تَرَكْتُهُ بِتِعْهِنَ وَهُوَ قَائِلٌ السُّقْيَا فَلَحِقْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَصْحَابَكَ يَقْرَءُونَ عَلَيْكَ السَّلاَمَ وَرَحْمَةَ اللَّهِ وَإِنَّهُمْ قَدْ خَشُوا أَنْ يُقْتَطَعُوا دُونَكَ انْتَظِرْهُمْ ‏.‏ فَانْتَظَرَهُمْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَصَدْتُ وَمَعِي مِنْهُ فَاضِلَةٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِلْقَوْمِ ‏ "‏ كُلُوا ‏"‏ ‏.‏ وَهُمْ مُحْرِمُونَ ‏.‏\hadithno{2854}\hadithtrans{Abdullah b. Abu Qatada reported:My father went with the Messenger of Allah (ﷺ) in the year of Hudaibiya. His Companions entered upon the state of Ihram whereas he did not, for it was conveyed to the Messenger of Allah (ﷺ) that the enemy (was hiding at) Ghaiqa. The Messenger of Allah (ﷺ) went forward. He (Abu Qatada) said: Meanwhile I was along with his Companions, some of them smiled (to one another) As I cast a glance I saw a wild ass. I attacked It with a spear and held it, and begged for their (i. e. of his companions) assistance, but they refused to help me and we ate its meat. But we were afraid lest we should be separated (from the Messenger of Allah). So I proceeded on (with a view to) seeking the Messenger of Allah (ﷺ). Some- times I'dashed my horse and sometimes I made it run at a leisurely pace (keeping pace with others). (In the meanwhile) I met a person from Banfu Ghifar in the middle of the night. I said to him: Where did you meet the messenger of Allah (ﷺ)? He said: I left him at Ta'bin and he intended to halt at Suqya to spend the afternoon. I met him and said: Messenger of Allah. your Companions convey salutations and benedictions of Allah to you and they fear that they may not be separated from you (and the enemy may do harm to you), so wait for them, and he (the Holy Prophet) waited for them. I said: Messenger of Allah, I killed a game and there is left with me (some of the meat). The Apostle of Allah (ﷺ) said to his people: Eat it. And they were in the state of Ihram}}
\hadithdefcmd{muslim}{2855}{حَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، - رضى الله عنه - قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَاجًّا وَخَرَجْنَا مَعَهُ - قَالَ - فَصَرَفَ مِنْ أَصْحَابِهِ فِيهِمْ أَبُو قَتَادَةَ فَقَالَ ‏"‏ خُذُوا سَاحِلَ الْبَحْرِ حَتَّى تَلْقَوْنِي ‏"‏ ‏.‏ قَالَ فَأَخَذُوا سَاحِلَ الْبَحْرِ ‏.‏ فَلَمَّا انْصَرَفُوا قِبَلَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحْرَمُوا كُلُّهُمْ إِلاَّ أَبَا قَتَادَةَ فَإِنَّهُ لَمْ يُحْرِمْ فَبَيْنَمَا هُمْ يَسِيرُونَ إِذْ رَأَوْا حُمُرَ وَحْشٍ فَحَمَلَ عَلَيْهَا أَبُو قَتَادَةَ فَعَقَرَ مِنْهَا أَتَانًا فَنَزَلُوا فَأَكَلُوا مِنْ لَحْمِهَا - قَالَ - فَقَالُوا أَكَلْنَا لَحْمًا وَنَحْنُ مُحْرِمُونَ - قَالَ - فَحَمَلُوا مَا بَقِيَ مِنْ لَحْمِ الأَتَانِ فَلَمَّا أَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم قَالُوا يَا رَسُولَ اللَّهِ إِنَّا كُنَّا أَحْرَمْنَا وَكَانَ أَبُو قَتَادَةَ لَمْ يُحْرِمْ فَرَأَيْنَا حُمُرَ وَحْشٍ فَحَمَلَ عَلَيْهَا أَبُو قَتَادَةَ فَعَقَرَ مِنْهَا أَتَانًا فَنَزَلْنَا فَأَكَلْنَا مِنْ لَحْمِهَا فَقُلْنَا نَأْكُلُ لَحْمَ صَيْدٍ وَنَحْنُ مُحْرِمُونَ ‏.‏ فَحَمَلْنَا مَا بَقِيَ مِنْ لَحْمِهَا ‏.‏ فَقَالَ ‏"‏ هَلْ مِنْكُمْ أَحَدٌ أَمَرَهُ أَوْ أَشَارَ إِلَيْهِ بِشَىْءٍ ‏"‏ ‏.‏ قَالَ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَكُلُوا مَا بَقِيَ مِنْ لَحْمِهَا ‏"‏ ‏.‏\hadithno{2855}\hadithtrans{Abdullah b. Abu Qatada reported on the authority of his father (Allah be pleased with him):The Messenger of Allah (ﷺ) set out for Pilgrimage and we also set out along with him. He (Abu Qatada) said: There proceeded on some of his Companions and Abu Qatada was (one of them). He (the Prophet) said: You proceed along the coastline till you meet me. He (Abu Qatada) said: So they proceeded ahead of the Prophet of Allah (ﷺ), all of them had entered upon the state of Ihram, except Abu Qatada; he had not put on ihram. As they went on they saw a wild ass, and Abu Qatada attacked it and cut off its hind legs. They got down and ate its meat. They said: We ate meat In the state of Ihram. They carried the meat that was left of it. As they came to the Messenger of Allah (way peace be upon him) they said: Messenger of Allah, we were in the state of Ihram whereas Abu Qatada was not. We saw a wild ass and Abu Qatada attacked it and cut off its hind legs. We got down and ate its meat and we thus ate the meat of a game while we were In the state of Ihram. We have (carried to you) what was left out of its meat. Thereupon he (the holy Prophet) said: Did anyone among you command him (to hunt) or point to him with anything (to do so)? They said: No. Thereupon he said: Then eat what is left out of its meat}}
\hadithdefcmd{muslim}{2856}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِي الْقَاسِمُ، بْنُ زَكَرِيَّاءَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ شَيْبَانَ، جَمِيعًا عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، بِهَذَا الإِسْنَادِ فِي رِوَايَةِ شَيْبَانَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمِنْكُمْ أَحَدٌ أَمَرَهُ أَنْ يَحْمِلَ عَلَيْهَا أَوْ أَشَارَ إِلَيْهَا ‏"‏ ‏.‏ وَفِي رِوَايَةِ شُعْبَةَ قَالَ ‏"‏ أَشَرْتُمْ أَوْ أَعَنْتُمْ ‏"‏ ‏.‏ أَوْ ‏"‏ أَصَدْتُمْ ‏"‏ ‏.‏ قَالَ شُعْبَةُ لاَ أَدْرِي قَالَ ‏"‏ أَعَنْتُمْ أَوْ أَصَدْتُمْ ‏"‏ ‏.‏\hadithno{2856}\hadithtrans{This hadith is narrated'on the authority of 'Uthman b. 'Abdullah b. Mauhab with the same chain of transmitters. And in the narration transmitted on the authority of Shaiban (the words are):" The Messenoer of Allah (ﷺ) said: Did any one of you command him to attack it or point towards it?" And in the narration transmitted by Shu'ba (the words are):" Did you point out or did you help or did you hunt?" Shu'ba said: I do not know whether he said:" Did you help or did you hunt?}}
\hadithdefcmd{muslim}{2857}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا مُعَاوِيَةُ، - وَهُوَ ابْنُ سَلاَّمٍ - أَخْبَرَنِي يَحْيَى، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، أَنَّ أَبَاهُ، - رضى الله عنه - أَخْبَرَهُ أَنَّهُ، غَزَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَزْوَةَ الْحُدَيْبِيَةِ قَالَ فَأَهَلُّوا بِعُمْرَةٍ غَيْرِي - قَالَ - فَاصْطَدْتُ حِمَارَ وَحْشٍ فَأَطْعَمْتُ أَصْحَابِي وَهُمْ مُحْرِمُونَ ثُمَّ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَنْبَأْتُهُ أَنَّ عِنْدَنَا مِنْ لَحْمِهِ فَاضِلَةً ‏.‏ فَقَالَ ‏ "‏ كُلُوهُ ‏"‏ وَهُمْ مُحْرِمُونَ ‏.‏\hadithno{2857}\hadithtrans{Abdullah b. Abu Qatada narrated on the authority of his father (Allah be pleased with him) that they went with the Messenger of Allah (ﷺ) on an expedition to Hudaibiya. He (further) said:They had entered upon the state of Ihram except I for 'Umra. He (again) said: I (Abu Qatada) hunted a wild ass and fed my companions in the state of their being Muhrim. 1 then came to the Messenger of Allah (ﷺ) and informed him that we had with us the meat that was left out of it. Thereupon he said: "Eat it," while they were in the state of Ihram}}
\hadithdefcmd{muslim}{2858}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ النُّمَيْرِيُّ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، - رضى الله عنه - أَنَّهُمْ خَرَجُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُمْ مُحْرِمُونَ وَأَبُو قَتَادَةَ مُحِلٌّ ‏.‏ وَسَاقَ الْحَدِيثَ وَفِيهِ فَقَالَ ‏ "‏ هَلْ مَعَكُمْ مِنْهُ شَىْءٌ ‏"‏ ‏.‏ قَالُوا مَعَنَا رِجْلُهُ ‏.‏ قَالَ فَأَخَذَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَكَلَهَا ‏.‏\hadithno{2858}\hadithtrans{Abdullah b. Abu Qatada reported on the authority of his father (Allah be pleased with him) that they went out with the Messenger of Allah (ﷺ) and they were Muhrim except Abu Qatada. The rest of the hadith Is the same (but with the exception of these words):" He (the Holy Prophet) said: 15 there any- thing out of it? They said: We have its leg with us. The Messenger of Allah (ﷺ) took it and ate it}}
\hadithdefcmd{muslim}{2859}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، ح وَحَدَّثَنَا قُتَيْبَةُ، وَإِسْحَاقُ، عَنْ جَرِيرٍ، كِلاَهُمَا عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، قَالَ كَانَ أَبُو قَتَادَةَ فِي نَفَرٍ مُحْرِمِينَ وَأَبُو قَتَادَةَ مُحِلٌّ وَاقْتَصَّ الْحَدِيثَ وَفِيهِ قَالَ ‏"‏ هَلْ أَشَارَ إِلَيْهِ إِنْسَانٌ مِنْكُمْ أَوْ أَمَرَهُ بِشَىْءٍ ‏"‏ ‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَكُلُوا ‏"‏ ‏.‏\hadithno{2859}\hadithtrans{Abdullah b. Abi Qatada reported that Abu Qatada was among the party of those who had entered upon the state of Ihram whereas he was not. The rest of the hadith is the same (and herein it is also narrated):" He (the Holy Prophet) said: Did any person among you point to him (to hunt) or command him (in any form)? They said: Messenger of Allah, not at all. Thereupon he said: Then eat it}}
\hadithdefcmd{muslim}{2860}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي مُحَمَّدُ، بْنُ الْمُنْكَدِرِ عَنْ مُعَاذِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عُثْمَانَ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ وَنَحْنُ حُرُمٌ فَأُهْدِيَ لَهُ طَيْرٌ وَطَلْحَةُ رَاقِدٌ فَمِنَّا مَنْ أَكَلَ وَمِنَّا مَنْ تَوَرَّعَ فَلَمَّا اسْتَيْقَظَ طَلْحَةُ وَفَّقَ مَنْ أَكَلَهُ وَقَالَ أَكَلْنَاهُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2860}\hadithtrans{Abd al-Rahman b. `Uthman Taimi reported on the authority of his father:While we were with Talha b. Ubaidullah and were in the state of Ihram we were presented a (cooked) bird. Talha was sleeping. Some of us ate it and some of us refrained from (eating) it. When Talha awoke he agreed with him who ate it, and said: We ate it along with the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2861}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ بْنَ مِقْسَمٍ، يَقُولُ سَمِعْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ، يَقُولُ سَمِعْتُ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَرْبَعٌ كُلُّهُنَّ فَاسِقٌ يُقْتَلْنَ فِي الْحِلِّ وَالْحَرَمِ الْحِدَأَةُ وَالْغُرَابُ وَالْفَارَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏ قَالَ فَقُلْتُ لِلْقَاسِمِ أَفَرَأَيْتَ الْحَيَّةَ قَالَ تُقْتَلُ بِصُغْرٍ لَهَا ‏.‏\hadithno{2861}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ) said:I heard Allah's Messenger (ﷺ) as saying: Four are the vicious (birds, beasts and reptiles) which should be killed in the state of Ihram or otherwise: kite (and vulture), crow, rat, and the voracious dog. I (one of the narrators, `Ubaidullah b. Miqsam) said to Qasim (the other narrator who heard it from `A'isha): What about the snake? He said: Let it be killed with disgrace}}
\hadithdefcmd{muslim}{2862}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ سَعِيدِ، بْنِ الْمُسَيَّبِ عَنْ عَائِشَةَ، - رضى الله عنها - عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ خَمْسٌ فَوَاسِقُ يُقْتَلْنَ فِي الْحِلِّ وَالْحَرَمِ الْحَيَّةُ وَالْغُرَابُ الأَبْقَعُ وَالْفَارَةُ وَالْكَلْبُ الْعَقُورُ وَالْحُدَيَّا ‏"‏ ‏.‏\hadithno{2862}\hadithtrans{A'isha (Allah be pleased with her) reported Allah'* Apostle (ﷺ) as saying:Five are the harmful things which should be killed in the state of Ihram or otherwise: snake, speckled crow. rat. voracious dog, and kite}}
\hadithdefcmd{muslim}{2863}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - حَدَّثَنَا هِشَامُ بْنُ، عُرْوَةَ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ فَوَاسِقُ يُقْتَلْنَ فِي الْحَرَمِ الْعَقْرَبُ وَالْفَارَةُ وَالْحُدَيَّا وَالْغُرَابُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2863}\hadithtrans{A'isha (Allah be pleased with her) reported Allah's Messenger (ﷺ) as saying:Five are the vicious beasts which should be killed even in the state of Ihram: scorpion, rat, kite, crow and voracious dog}}
\hadithdefcmd{muslim}{2864}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{2864}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{2865}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ فَوَاسِقُ يُقْتَلْنَ فِي الْحَرَمِ الْفَارَةُ وَالْعَقْرَبُ وَالْغُرَابُ وَالْحُدَيَّا وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2865}\hadithtrans{A'isha reported Allah's Mdssenger (ﷺ) having said this:Five are the vicious and harmful things which should be killed even within the precincts of Haram: rat, scorpion, crow. kite and voracious dog}}
\hadithdefcmd{muslim}{2866}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ قَالَتْ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ خَمْسِ فَوَاسِقَ فِي الْحِلِّ وَالْحَرَمِ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ يَزِيدَ بْنِ زُرَيْعٍ ‏.‏\hadithno{2866}\hadithtrans{This hadith has been narrated on the authority Zuhri with the same chain of transmitters that she (A'isha) reported:The Messenger of Allah (ﷺ) commanded to kill five harmful things in the state of lhram or otherwise. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2867}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ كُلُّهَا فَوَاسِقُ تُقْتَلُ فِي الْحَرَمِ الْغُرَابُ وَالْحِدَأَةُ وَالْكَلْبُ الْعَقُورُ وَالْعَقْرَبُ وَالْفَارَةُ ‏"‏ ‏.‏\hadithno{2867}\hadithtrans{IA'isha (Allah be pleased with her) reported Allah's Messenger (ﷺ) as saying:Five are the beasts 1618 harmful and vicious and these must be killed even within the precincts of the Ka'ba: crow, kite, voracio@s dog, kcorpion and rat}}
\hadithdefcmd{muslim}{2868}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ خَمْسٌ لاَ جُنَاحَ عَلَى مَنْ قَتَلَهُنَّ فِي الْحَرَمِ وَالإِحْرَامِ الْفَارَةُ وَالْعَقْرَبُ وَالْغُرَابُ وَالْحِدَأَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏ وَقَالَ ابْنُ أَبِي عُمَرَ فِي رِوَايَتِهِ ‏"‏ فِي الْحُرُمِ وَالإِحْرَامِ ‏"‏ ‏.‏\hadithno{2868}\hadithtrans{Salim reported on the authority of his father (Allah be pleased with them) that the Messenger of Allah (ﷺ) said:Five are the (beasts) which if one kills them in the precincts of the Ka'ba or in the state of lhram entail no sin: rat, scorpion, crow, kite and voracious dog. In another version the words are:" as a Muhrim and in the state of lhram}}
\hadithdefcmd{muslim}{2869}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، - رضى الله عنهما - قَالَ قَالَتْ حَفْصَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ كُلُّهَا فَاسِقٌ لاَ حَرَجَ عَلَى مَنْ قَتَلَهُنَّ الْعَقْرَبُ وَالْغُرَابُ وَالْحِدَأَةُ وَالْفَارَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2869}\hadithtrans{Hafsa, the wife of Allah's Apostle (ﷺ), reported Allah's Messenger (ﷺ) having said this:There are five beasts, all of them are vicious and harmful and there is no sin for one who kills them (and these are): scorpion, crow, kite, rat and voracious dog}}
\hadithdefcmd{muslim}{2870}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا زَيْدُ بْنُ جُبَيْرٍ، أَنَّ رَجُلاً، سَأَلَ ابْنَ عُمَرَ مَا يَقْتُلُ الْمُحْرِمُ مِنَ الدَّوَابِّ فَقَالَ أَخْبَرَتْنِي إِحْدَى نِسْوَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَمَرَ - أَوْ أُمِرَ - أَنْ تُقْتَلَ الْفَارَةُ وَالْعَقْرَبُ وَالْحِدَأَةُ وَالْكَلْبُ الْعَقُورُ وَالْغُرَابُ ‏.‏\hadithno{2870}\hadithtrans{Zaid b. Jubair reported:A person asked Ibn Umar which beast a Muhrim could kill. Thereupon he said: One of the wives of Allah's Apostle (ﷺ) told me: He (the Holy Prophet) commanded to kill rat, scorpion, kite, voracious dog and crow}}
\hadithdefcmd{muslim}{2871}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، قَالَ سَأَلَ رَجُلٌ ابْنَ عُمَرَ مَا يَقْتُلُ الرَّجُلُ مِنَ الدَّوَابِّ وَهُوَ مُحْرِمٌ قَالَ حَدَّثَتْنِي إِحْدَى نِسْوَةِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَأْمُرُ بِقَتْلِ الْكَلْبِ الْعَقُورِ وَالْفَارَةِ وَالْعَقْرَبِ وَالْحُدَيَّا وَالْغُرَابِ وَالْحَيَّةِ ‏.‏ قَالَ وَفِي الصَّلاَةِ أَيْضًا ‏.‏\hadithno{2871}\hadithtrans{Zaid b. Jubair reported:A person asked Ibn 'Umar which beast a Muhrim could kill, whereupon he said: One of the wives of Allahs Apostle (ﷺ) told me: He (the Holy Prophet) commanded to kill voracious dog, rat, scorpion, kite, crow, and snake (and this is allowed) likewise in prayer}}
\hadithdefcmd{muslim}{2872}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ لَيْسَ عَلَى الْمُحْرِمِ فِي قَتْلِهِنَّ جُنَاحٌ الْغُرَابُ وَالْحِدَأَةُ وَالْعَقْرَبُ وَالْفَارَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2872}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:Five are the beasts for killing which there is no sin for the Muhrim: crows, kites, scorpions, rats and wild dogs}}
\hadithdefcmd{muslim}{2873}{وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ قُلْتُ لِنَافِعٍ مَاذَا سَمِعْتَ ابْنَ عُمَرَ، يُحِلُّ لِلْحَرَامِ قَتْلَهُ مِنَ الدَّوَابِّ فَقَالَ لِي نَافِعٌ قَالَ عَبْدُ اللَّهِ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ لاَ جُنَاحَ عَلَى مَنْ قَتَلَهُنَّ فِي قَتْلِهِنَّ الْغُرَابُ وَالْحِدَأَةُ وَالْعَقْرَبُ وَالْفَارَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{2873}\hadithtrans{Ibn Juraij reported:I said to Nafi: What is that which you heard Ibn, Umar declaring permissible for a Muhrim to kill some of the beasts? Nafi, said to me that 'Abdullah had reported: I heard Allah's Messenger (ﷺ) as saying: Five are the beasts in killing which or their being killed, there is no sin: crow, kite, scorpion, rat and voracious dog}}
\hadithdefcmd{muslim}{2874}{وَحَدَّثَنَاهُ قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - جَمِيعًا عَنْ نَافِعٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ، بْنُ مُسْهِرٍ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي جَمِيعًا، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي أَبُو كَامِلٍ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ وَابْنِ جُرَيْجٍ وَلَمْ يَقُلْ أَحَدٌ مِنْهُمْ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ - رضى الله عنهما - سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم ‏.‏ إِلاَّ ابْنُ جُرَيْجٍ وَحْدَهُ وَقَدْ تَابَعَ ابْنَ جُرَيْجٍ عَلَى ذَلِكَ ابْنُ إِسْحَاقَ ‏.‏\hadithno{2874}\hadithtrans{The above hadith was reported with other chains from Nafi' on the authority of Ibn 'Umar, but there was difference in the wording in how the attributed the chain}}
\hadithdefcmd{muslim}{2875}{وَحَدَّثَنِيهِ فَضْلُ بْنُ سَهْلٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ نَافِعٍ، وَعُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَمْسٌ لاَ جُنَاحَ فِي قَتْلِ مَا قُتِلَ مِنْهُنَّ فِي الْحَرَمِ ‏"‏ ‏.‏ فَذَكَرَ بِمِثْلِهِ‏\hadithno{2875}\hadithtrans{(This hadith has been narrated on the authority of Ibn 'Umar through be upon him) as saying:Five (are the beasts) in killing which or their being killed in the precinct of the Ka'ba there is no sin." The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2876}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ عَبْدَ، اللَّهِ بْنَ عُمَرَ - رضى الله عنهما - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مَنْ قَتَلَهُنَّ وَهُوَ حَرَامٌ فَلاَ جُنَاحَ عَلَيْهِ فِيهِنَّ الْعَقْرَبُ وَالْفَارَةُ وَالْكَلْبُ الْعَقُورُ وَالْغُرَابُ وَالْحُدَيَّا ‏"‏ ‏.‏ وَاللَّفْظُ لِيَحْيَى بْنِ يَحْيَى ‏.‏\hadithno{2876}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported Allah's Messen- ger (ﷺ) as saying:Five (are the animals) which, it one kills them In the state of Ihram, entail no sin for one (who does it): scorpion, rat, voracious dog, crow and kite}}
\hadithdefcmd{muslim}{2877}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ أَيُّوبَ، ح وَحَدَّثَنِي أَبُو الرَّبِيعِ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، قَالَ سَمِعْتُ مُجَاهِدًا، يُحَدِّثُ عَنْ عَبْدِ الرَّحْمَنِ، بْنِ أَبِي لَيْلَى عَنْ كَعْبِ بْنِ عُجْرَةَ، - رضى الله عنه - قَالَ أَتَى عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم زَمَنَ الْحُدَيْبِيَةِ وَأَنَا أُوقِدُ تَحْتَ - قَالَ الْقْوَارِيرِيُّ قِدْرٍ لِي ‏.‏ وَقَالَ أَبُو الرَّبِيعِ بُرْمَةٍ لِي - وَالْقَمْلُ يَتَنَاثَرُ عَلَى وَجْهِي فَقَالَ ‏"‏ أَيُؤْذِيكَ هَوَامُّ رَأْسِكَ ‏"‏ ‏.‏ قَالَ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاحْلِقْ وَصُمْ ثَلاَثَةَ أَيَّامٍ أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ أَوِ انْسُكْ نَسِيكَةً ‏"‏ ‏.‏ قَالَ أَيُّوبُ فَلاَ أَدْرِي بِأَىِّ ذَلِكَ بَدَأَ ‏.‏\hadithno{2877}\hadithtrans{Ka'b b. 'Ujra (Allah be pleased with him) reported:The Messenger of Allah (ﷺ) came to me on the occasion of Hudaibiya and I was kindling fire under my cooking pot and lice were creeping on my face. Thereupon he (the Holy Prophet) said: Do the vermins harm your head? I said: Yes. He said: Get your head shaved and (in lieu of it) observe fasts for three days or feed six needy persons, or offer sacrifice (of an animal). Ayyub said: I do not know with what (type of expiation) did he commence (the statement)}}
\hadithdefcmd{muslim}{2878}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، عَنْ أَيُّوبَ، فِي هَذَا الإِسْنَادِ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{2878}\hadithtrans{This hadith is narrated on the authority of Ayyub}}
\hadithdefcmd{muslim}{2879}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، - رضى الله عنه - قَالَ فِيَّ أُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏ فَمَنْ كَانَ مِنْكُمْ مَرِيضًا أَوْ بِهِ أَذًى مِنْ رَأْسِهِ فَفِدْيَةٌ مِنْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ‏\}‏ قَالَ فَأَتَيْتُهُ فَقَالَ ‏"‏ ادْنُهْ ‏"‏ ‏.‏ فَدَنَوْتُ فَقَالَ ‏"‏ ادْنُهْ ‏"‏ ‏.‏ فَدَنَوْتُ ‏.‏ فَقَالَ صلى الله عليه وسلم ‏"‏ أَيُؤْذِيكَ هَوَامُّكَ ‏"‏ ‏.‏ قَالَ ابْنُ عَوْنٍ وَأَظُنُّهُ قَالَ نَعَمْ ‏.‏ قَالَ فَأَمَرَنِي بِفِدْيَةٍ مِنْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ مَا تَيَسَّرَ ‏.‏\hadithno{2879}\hadithtrans{Kalb b. Ujra (Allah be pleased with him) reported:It was I for whom this verse was revealed (to the Holy Prophet):" Whoever among you is sick or has an ail- ment of the head, he (may effect) a compensation by lasting or alms or a sacrifice" He said: I came to him (the Holy Prophet) and he said: Come Dear. So I went near. He (again) said: Come near. So I went near. Thereupon the Messenger of Allah (ﷺ) said: Do the vermins trouble you? Ibn Aun (one of the narrators) said: I think he (Ka'b b. Ujra) replied in the affirmative. He (the Holy Prophet) then commanded to do compensation by fasting or by giving sadaqa (feeding six needy persons) or by sacrifice (of a animal) that is available}}
\hadithdefcmd{muslim}{2880}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سَيْفٌ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ حَدَّثَنِي عَبْدُ، الرَّحْمَنِ بْنُ أَبِي لَيْلَى حَدَّثَنِي كَعْبُ بْنُ عُجْرَةَ، - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَفَ عَلَيْهِ وَرَأْسُهُ يَتَهَافَتُ قَمْلاً فَقَالَ ‏"‏ أَيُؤْذِيكَ هَوَامُّكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاحْلِقْ رَأْسَكَ ‏"‏ ‏.‏ قَالَ فَفِيَّ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ فَمَنْ كَانَ مِنْكُمْ مَرِيضًا أَوْ بِهِ أَذًى مِنْ رَأْسِهِ فَفِدْيَةٌ مِنْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ‏\}‏ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ أَوْ تَصَدَّقْ بِفَرَقٍ بَيْنَ سِتَّةِ مَسَاكِينَ أَوِ انْسُكْ مَا تَيَسَّرَ ‏"‏ ‏.‏\hadithno{2880}\hadithtrans{Ka'b b. 'Ujra (Allah be pleased with him) reported that the Messenger of Allah (may peace be, upon him) stood near him and lice were falling from his head. Thereupon he (the Holy Prophet) said:Do these vermins trouble you? I said: Yes. Thereupon he said: Then shave your head; and it was in connection with me that this verse was revealed:" Whoever among you is sick or has an ailment of the head, he (may effect) a compensation by fasting or alms or a sacrifice". He (the Holy Prophet, therefore) said to me: Observe fast for three days or give a quantity of alms enough to feed six needy persons or offer sacrifice (of an animal) that is available}}
\hadithdefcmd{muslim}{2881}{وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، وَأَيُّوبَ، وَحُمَيْدٍ، وَعَبْدِ، الْكَرِيمِ عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، - رضى الله عنه - أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِهِ وَهُوَ بِالْحُدَيْبِيَةِ قَبْلَ أَنْ يَدْخُلَ مَكَّةَ وَهُوَ مُحْرِمٌ وَهُوَ يُوقِدُ تَحْتَ قِدْرٍ وَالْقَمْلُ يَتَهَافَتُ عَلَى وَجْهِهِ فَقَالَ ‏"‏ أَيُؤْذِيكَ هَوَامُّكَ هَذِهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاحْلِقْ رَأْسَكَ وَأَطْعِمْ فَرَقًا بَيْنَ سِتَّةِ مَسَاكِينَ - وَالْفَرَقُ ثَلاَثَةُ آصُعٍ - أَوْ صُمْ ثَلاَثَةَ أَيَّامٍ أَوِ انْسُكْ نَسِيكَةً ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي نَجِيحٍ ‏"‏ أَوِ اذْبَحْ شَاةً ‏"‏ ‏.‏\hadithno{2881}\hadithtrans{Ka`b b. 'Ujra (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) happened to pass by him at Hudaibiya before entering Mecca in a state of Ihram and he (Ka'b) was kindling fire under the cooking pot and vermin were creeping on his (Ka`b's) face. Thereupon (the Holy Prophet) said:Do these vermin trouble you? He (Ka'b) said: Yes. The Messenger of Allah (way peace be upon him) said: Shave your head and give some quantity of food enough to feed six needy persons (faraq is equal to three sa's), or observe fast for three days or offer sacrifice of a sacrificial animal. Ibn Najih (one of the narrators) said:" Or sacrifice a goat}}
\hadithdefcmd{muslim}{2882}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِهِ زَمَنَ الْحُدَيْبِيَةِ فَقَالَ لَهُ ‏"‏ آذَاكَ هَوَامُّ رَأْسِكَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ احْلِقْ رَأْسَكَ ثُمَّ اذْبَحْ شَاةً نُسُكًا أَوْ صُمْ ثَلاَثَةَ أَيَّامٍ أَوْ أَطْعِمْ ثَلاَثَةَ آصُعٍ مِنْ تَمْرٍ عَلَى سِتَّةِ مَسَاكِينَ ‏"‏ ‏.‏\hadithno{2882}\hadithtrans{Ka'b b. Ujra (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) happened to pass by him during the period of Hudaibiya. Thereupon he (the Holy Prophet) said to him (Ka'b b. Ujra):Do these vermins trouble your head? He said: Yes. Thereupon he (the Holy Prophet) said: Shave your head. Then sacrifice a goat or observe fasts for three days or give three sits of dates to feed six needy persons}}
\hadithdefcmd{muslim}{2883}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْقِلٍ، قَالَ قَعَدْتُ إِلَى كَعْبٍ - رضى الله عنه - وَهُوَ فِي الْمَسْجِدِ فَسَأَلْتُهُ عَنْ هَذِهِ الآيَةِ ‏\{‏ فَفِدْيَةٌ مِنْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ‏\}‏ فَقَالَ كَعْبٌ رضى الله عنه نَزَلَتْ فِيَّ كَانَ بِي أَذًى مِنْ رَأْسِي فَحُمِلْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَالْقَمْلُ يَتَنَاثَرُ عَلَى وَجْهِي فَقَالَ ‏"‏ مَا كُنْتُ أُرَى أَنَّ الْجَهْدَ بَلَغَ مِنْكَ مَا أَرَى أَتَجِدُ شَاةً ‏"‏ ‏.‏ فَقُلْتُ لاَ فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ فَفِدْيَةٌ مِنْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ‏\}‏ قَالَ صَوْمُ ثَلاَثَةِ أَيَّامٍ أَوْ إِطْعَامُ سِتَّةِ مَسَاكِينَ نِصْفَ صَاعٍ طَعَامًا لِكُلِّ مِسْكِينٍ - قَالَ - فَنَزَلَتْ فِيَّ خَاصَّةً وَهْىَ لَكُمْ عَامَّةً ‏.‏\hadithno{2883}\hadithtrans{Abdullah b. Ma'qil said:I sat with Ka'b (Allah be pleased with him) and he was in the mosque. I asked him about this verse:" Compensation in (the form of) fasting, or Sadaqa or sacrifice." Ka'b (Allah be pleased with him) said: It was reveal- ed In my case. There was some trouble in my head. I was taken to the Messenger of Allah (ﷺ) and lice were creeping upon my face. Thereupon he said: I did not think that your trouble had become so unbearable as I see. Would you be able to afford (the sacrificing) of a goat? I (Ka'b) said: Then this verse was revealed:" Com- pensation (in the form of) fasting or alms or a sacrifice." He (the Holy Prophet) said: (It Implies) fasting for three days, or feeding six needy perscins, half sa' of food for every needy person. This verse was revealed particularly for me and (now) Its applica- tion is general for all of you}}
\hadithdefcmd{muslim}{2884}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَصْبَهَانِيِّ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مَعْقِلٍ، حَدَّثَنِي كَعْبُ بْنُ عُجْرَةَ، - رضى الله عنه - أَنَّهُ خَرَجَ مَعَ النَّبِيِّ صلى الله عليه وسلم مُحْرِمًا فَقَمِلَ رَأْسُهُ وَلِحْيَتُهُ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَأَرْسَلَ إِلَيْهِ فَدَعَا الْحَلاَّقَ فَحَلَقَ رَأْسَهُ ثُمَّ قَالَ لَهُ ‏"‏ هَلْ عِنْدَكَ نُسُكٌ ‏"‏ ‏.‏ قَالَ مَا أَقْدِرُ عَلَيْهِ ‏.‏ فَأَمَرَهُ أَنْ يَصُومَ ثَلاَثَةَ أَيَّامٍ أَوْ يُطْعِمَ سِتَّةَ مَسَاكِينَ لِكُلِّ مِسْكِينَيْنِ صَاعٌ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِيهِ خَاصَّةً ‏\{‏ فَمَنْ كَانَ مِنْكُمْ مَرِيضًا أَوْ بِهِ أَذًى مِنْ رَأْسِهِ‏\}‏ ثُمَّ كَانَتْ لِلْمُسْلِمِينَ عَامَّةً ‏.‏\hadithno{2884}\hadithtrans{Ka'b b. Ujra (Allah be pleased with him) reported that he went out with the Messenger of Allah (ﷺ) in the state of Ihram, and his (Ka'b's) head and beard were infested with lice. This was conveyed to the Messenger of Allah (ﷺ). He sent for him (Ka'b) and called a barber (who) shaved his head. He (the Holy Prophet) said. Is there any sacrificial animal with you? He (Kalb) said:I cannot afford it. He then commanded him to observe fasts for three days or feed six needy persons, one sa' for every two needy persons. And Allah the Exalted and Majestic revealed this (verse) particular with regard to him:" So whosoever among you is sick and has an ailment of the head.." ; then (its application) became general for the Muslims}}
\hadithdefcmd{muslim}{2885}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، وَعَطَاءٍ، عَنِ ابْنِ، عَبَّاسٍ - رضى الله عنهما - أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{2885}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) got himself cupped in the state of lhrim}}
\hadithdefcmd{muslim}{2886}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْمُعَلَّى بْنُ مَنْصُورٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنِ ابْنِ بُحَيْنَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ بِطَرِيقِ مَكَّةَ وَهُوَ مُحْرِمٌ وَسَطَ رَأْسِهِ ‏.‏\hadithno{2886}\hadithtrans{Ibn Buhaina reported that the Messenger of Allah (ﷺ) got himself cupped in the middle of his head on his way to Mecca}}
\hadithdefcmd{muslim}{2887}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ، عُيَيْنَةَ - قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - حَدَّثَنَا أَيُّوبُ بْنُ مُوسَى، عَنْ نُبَيْهِ بْنِ وَهْبٍ، قَالَ خَرَجْنَا مَعَ أَبَانِ بْنِ عُثْمَانَ حَتَّى إِذَا كُنَّا بِمَلَلٍ اشْتَكَى عُمَرُ بْنُ عُبَيْدِ اللَّهِ عَيْنَيْهِ فَلَمَّا كُنَّا بِالرَّوْحَاءِ اشْتَدَّ وَجَعُهُ فَأَرْسَلَ إِلَى أَبَانَ بْنِ عُثْمَانَ يَسْأَلُهُ فَأَرْسَلَ إِلَيْهِ أَنِ اضْمِدْهُمَا بِالصَّبِرِ فَإِنَّ عُثْمَانَ - رضى الله عنه - حَدَّثَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الرَّجُلِ إِذَا اشْتَكَى عَيْنَيْهِ وَهُوَ مُحْرِمٌ ضَمَّدَهُمَا بِالصَّبِرِ ‏.‏\hadithno{2887}\hadithtrans{Nubaih b. Wabb reported:We went with Aban b. Uthman (in a state of lhram). When we were at Malal the eyes of Umar b. Ubaidullah became sore and, when we reached Rauba' the pain grew intense. He (Nubaib b. Wahb) sent (one) to Aban b. Uthman to ask him (what to do). He sent him (the message) to apply aloes to them, for 'Uthman (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) applied aloes to the person whose eyes were sore and he was in the state of Ihram}}
\hadithdefcmd{muslim}{2888}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنِي أَبِي، حَدَّثَنَا أَيُّوبُ بْنُ مُوسَى، حَدَّثَنِي نُبَيْهُ بْنُ وَهْبٍ، أَنَّ عُمَرَ بْنَ عُبَيْدِ اللَّهِ بْنِ مَعْمَرٍ، رَمِدَتْ عَيْنُهُ فَأَرَادَ أَنْ يَكْحُلَهَا، فَنَهَاهُ أَبَانُ بْنُ عُثْمَانَ وَأَمَرَهُ أَنْ يُضَمِّدَهَا بِالصَّبِرِ وَحَدَّثَ عَنْ عُثْمَانَ بْنِ عَفَّانَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ فَعَلَ ذَلِكَ ‏.‏\hadithno{2888}\hadithtrans{Nubaih b Wahb reported that the eyes of Umar b. Ubaidnllah b. Ma'mar were swollen, and he decided to use antimony. Aban b. 'Uthman forbade him to do so and commanded him to apply aloes on them, and reported on the authority of 'Uthman b. Affan that the Messenger of Allah (ﷺ) had done that}}
\hadithdefcmd{muslim}{2889}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، - وَهَذَا حَدِيثُهُ - عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، وَالْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّهُمَا اخْتَلَفَا بِالأَبْوَاءِ فَقَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ ‏.‏ وَقَالَ الْمِسْوَرُ لاَ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ ‏.‏ فَأَرْسَلَنِي ابْنُ عَبَّاسٍ إِلَى أَبِي أَيُّوبَ الأَنْصَارِيِّ أَسْأَلُهُ عَنْ ذَلِكَ فَوَجَدْتُهُ يَغْتَسِلُ بَيْنَ الْقَرْنَيْنِ وَهُوَ يَسْتَتِرُ بِثَوْبٍ - قَالَ - فَسَلَّمْتُ عَلَيْهِ فَقَالَ مَنْ هَذَا فَقُلْتُ أَنَا عَبْدُ اللَّهِ بْنُ حُنَيْنٍ أَرْسَلَنِي إِلَيْكَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ أَسْأَلُكَ كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْسِلُ رَأْسَهُ وَهُوَ مُحْرِمٌ فَوَضَعَ أَبُو أَيُّوبَ - رضى الله عنه - يَدَهُ عَلَى الثَّوْبِ فَطَأْطَأَهُ حَتَّى بَدَا لِي رَأْسُهُ ثُمَّ قَالَ لإِنْسَانٍ يَصُبُّ اصْبُبْ ‏.‏ فَصَبَّ عَلَى رَأْسِهِ ثُمَّ حَرَّكَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ ثُمَّ قَالَ هَكَذَا رَأَيْتُهُ صلى الله عليه وسلم يَفْعَلُ ‏.‏\hadithno{2889}\hadithtrans{Ibrahim b. 'Abdullah narrated on the authorrity of his father that there cropped up a difference of opinion between Abdullah b. 'Abbas and al-Miswar b. Makhrama at a place (called) Abwa'. Abdullah b. 'Abbas contended that a Muhrim (is permitted) to wash his head, whereas Miswar contended that a Muhrim is not (permit- fed) to wash his head. So Ibn Abbas sent me (the father of Ibrabim) to Abu Ayyub al- Ansirl to ask him about it. (So I went to him) and found him taking bath behind two poles covered by a cloth. I gave him salutation, whereupon be asked:Who is this? I said: I am 'Abdullah b. Hunain. 'Abdullah b. 'Abbas has sent me to you to find out how the Messenger of Allah (ﷺ) washed his head in the state of Ihram. Abu Ayyub (Allah be pleased with him) placed his hand on the cloth and lowered it (a little) till his head became visible to me; and he said to the man who was pouring water upon him to pour water. He poured water on his head. He then moved his head with the help of his hands and moved them (the hands) forward and backward and then said: This is how I saw him (the Messenger of Allah) doing}}
\hadithdefcmd{muslim}{2890}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي زَيْدُ بْنُ أَسْلَمَ، بِهَذَا الإِسْنَادِ وَقَالَ فَأَمَرَّ أَبُو أَيُّوبَ بِيَدَيْهِ عَلَى رَأْسِهِ جَمِيعًا عَلَى جَمِيعِ رَأْسِهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ فَقَالَ الْمِسْوَرُ لاِبْنِ عَبَّاسٍ لاَ أُمَارِيكَ أَبَدًا ‏.‏\hadithno{2890}\hadithtrans{This hadith has been narrated on the authority of Zaid b. Aslam with the same chain of transmitters that Abu Ayyub rubbed his whole head with his hands and then moved them forward and backward. Miswar said to Ibn 'Abbas:I would never dispute with you (in future)}}
\hadithdefcmd{muslim}{2891}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ، جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - عَنِ النَّبِيِّ صلى الله عليه وسلم خَرَّ رَجُلٌ مِنْ بَعِيرِهِ فَوُقِصَ فَمَاتَ فَقَالَ ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْهِ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏\hadithno{2891}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that a person fell down from his camel (in a state of Ihram) and his neck was broken and he died. Thereupon Allah's Apostle. (ﷺ) said:Bathe him with water mixed with the leaves of the lote tree and shroud him in his two (pieces of) cloth (Ihbram), and do not cover his head for Allah will raise him on the Day of Resurrection Pronouncing Talbiya}}
\hadithdefcmd{muslim}{2894}{وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ أَقْبَلَ رَجُلٌ حَرَامًا مَعَ النَّبِيِّ صلى الله عليه وسلم فَخَرَّ مِنْ بَعِيرِهِ فَوُقِصَ وَقْصًا فَمَاتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَأَلْبِسُوهُ ثَوْبَيْهِ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّهُ يَأْتِي يَوْمَ الْقِيَامَةِ يُلَبِّي ‏"‏ ‏.‏\hadithno{2894}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that a person proceeded along with the Messenger of Allah (may peace he upon him) in the state of Ihram and fell down from his camel and his neck was broken, and he died. The Messenger of Allah (ﷺ) said:Bathe him with water mixed with lote (leaves) and shroud him in two (pieces of) cloth and do'not cover his head for he would come on the Day of Resurrection pronouncing Talbiya}}
\hadithdefcmd{muslim}{2895}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّ سَعِيدَ بْنَ جُبَيْرٍ، أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ أَقْبَلَ رَجُلٌ حَرَامٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏ وَزَادَ لَمْ يُسَمِّ سَعِيدُ بْنُ جُبَيْرٍ حَيْثُ خَرَّ ‏.‏\hadithno{2895}\hadithtrans{Sa'id b. Jubair reported on the authority of Ibn Abbas (Allah be pleased with him) that a person proceeded with the Messenger of Allah (ﷺ) in the state of Ihram. The rest of the hadith th is the same except that he (the Holy Prophet) (is reported to have) said:He would be raised on the Day of Resurrection pronouncing Talbiya. Sa'id b. Jubair did not name the place where he fell down}}
\hadithdefcmd{muslim}{2896}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ، جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّ رَجُلاً، أَوْقَصَتْهُ رَاحِلَتُهُ وَهُوَ مُحْرِمٌ فَمَاتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْهِ وَلاَ تُخَمِّرُوا رَأْسَهُ وَلاَ وَجْهَهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏ ‏.‏\hadithno{2896}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that there was a person in the state of Ihram whose camel broke his neck and he died. Thereupon the Mes- senger of Allah (ﷺ) said:Bathe him with water mixed (with the leaves of) lote tree and shroud him In his two (pieces of) cloth and cover neither his head nor his face, for he would be raised on the Day of Resurrection pronouncing Talbiya}}
\hadithdefcmd{muslim}{2897}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، حَدَّثَنَا سَعِيدُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما ح . وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ، بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما أَنَّ رَجُلاً، كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُحْرِمًا فَوَقَصَتْهُ نَاقَتُهُ فَمَاتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْهِ وَلاَ تُمِسُّوهُ بِطِيبٍ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّدًا ‏"‏ ‏.‏\hadithno{2897}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that when a person who was in the state of Ihram was in the company of the Messenger of Allah (ﷺ), his camel broke his neckand he died. Upon this the Messenger of Allah (ﷺ) said:Bathe him with water (mixed with the leaves) of the lute tree and shroud him in his two (pieces of) cloth and, neither perfume him nor cover his head, for he would be raised on the Day of Resurrection pronouncing Talbiya}}
\hadithdefcmd{muslim}{2898}{وَحَدَّثَنِي أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّ رَجُلاً، وَقَصَهُ بَعِيرُهُ وَهُوَ مُحْرِمٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُغْسَلَ بِمَاءٍ وَسِدْرٍ وَلاَ يُمَسَّ طِيبًا وَلاَ يُخَمَّرَ رَأْسُهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّدًا ‏.‏\hadithno{2898}\hadithtrans{Sa'id b. Jubair reported on the authority of Ibn 'Abbas (Allah be pleased with them) that a camel broke the neck of its owner while he was in the state of lhram and he was at that time in the company of the Messenger of Allah (ﷺ). Allah's Messenger (ﷺ) commanded that he should be bathed with water mixed with (leaves of the) lote (tree) and no perfume should be applied to him and his head should not be covered, for he would be raised on the Day of Resurrection pronouncing Talblya}}
\hadithdefcmd{muslim}{2899}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ نَافِعٍ قَالَ ابْنُ نَافِعٍ أَخْبَرَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا بِشْرٍ، يُحَدِّثُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، - رضى الله عنهما - يُحَدِّثُ أَنَّ رَجُلاً أَتَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ فَوَقَعَ مِنْ نَاقَتِهِ فَأَقْعَصَتْهُ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُغْسَلَ بِمَاءٍ وَسِدْرٍ وَأَنْ يُكَفَّنَ فِي ثَوْبَيْنِ وَلاَ يُمَسَّ طِيبًا خَارِجٌ رَأْسُهُ ‏.‏ قَالَ شُعْبَةُ ثُمَّ حَدَّثَنِي بِهِ بَعْدَ ذَلِكَ خَارِجٌ رَأْسُهُ وَوَجْهُهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّدًا ‏.‏\hadithno{2899}\hadithtrans{Sa'id b. Jubair heard Ibn 'Abbas (Allah be pleased with them) as saying:A person came to Allah's Apostle (ﷺ) while he was in the state of lhram. He fell down from his camel and broke his neck. Thereupon Allah's Apostle (ﷺ) commanded to bathe him with water (mixed with the leaves of) the lote (tree), and shroud him in two (pieces of) cloth and not to apply perfume (to him), keeping his head out (of the shroud). Shu'ba said: He then narrated to me after this (the words)" keeping his head out," his face out, for he would be raised on the Day of Resurrection pronouncing Talbiya}}
\hadithdefcmd{muslim}{2900}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، عَنْ زُهَيْرٍ، عَنْ أَبِي الزُّبَيْرِ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، يَقُولُ قَالَ ابْنُ عَبَّاسٍ - رضى الله عنهما - وَقَصَتْ رَجُلاً رَاحِلَتُهُ وَهُوَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَأَنْ يَكْشِفُوا وَجْهَهُ - حَسِبْتُهُ قَالَ - وَرَأْسَهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ وَهُوَ يُهِلُّ ‏.‏\hadithno{2900}\hadithtrans{Sa`id b. Jubair reported on the authority of Ibn `Abbas (Allah be pleased with them) that the camel of a person broke his neck as he was in the company of Allah's Messenger (ﷺ). The Messenger of Allah (ﷺ) commanded them (Companions) to wash him with water mixed (with the leaves of) the lote (tree) and to keep his face exposed; (he, the narrator) said:And his head (too), for he would be raised on the Day of Resurrection pronouncing Talbiya}}
\hadithdefcmd{muslim}{2901}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم رَجُلٌ فَوَقَصَتْهُ نَاقَتُهُ فَمَاتَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ وَلاَ تُقَرِّبُوهُ طِيبًا وَلاَ تُغَطُّوا وَجْهَهُ فَإِنَّهُ يُبْعَثُ يُلَبِّي ‏"‏ ‏.‏\hadithno{2901}\hadithtrans{Ibn 'Abbas (Allah be pleased with him) reported that there was a person in the company of Allah's Messenger (may peace' be upon him) whose camel broke his neck and he died. thereupon Allah's Apostle (ﷺ) said:Wash him, but do not apply perfume and do not cover his face, for he would be raised (on the Day of Resurrection) pronouncing Talbiya}}
\hadithdefcmd{muslim}{2902}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ضُبَاعَةَ بِنْتِ الزُّبَيْرِ فَقَالَ لَهَا ‏"‏ أَرَدْتِ الْحَجَّ ‏"‏ ‏.‏ قَالَتْ وَاللَّهِ مَا أَجِدُنِي إِلاَّ وَجِعَةً ‏.‏ فَقَالَ لَهَا ‏"‏ حُجِّي وَاشْتَرِطِي وَقُولِي اللَّهُمَّ مَحِلِّي حَيْثُ حَبَسْتَنِي ‏"‏ ‏.‏ وَكَانَتْ تَحْتَ الْمِقْدَادِ ‏.‏\hadithno{2902}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) went (into the house of) Duba`a bint Zubair and said to her:Did you intend to perform Hajj? She said: By Allah, (I intend to do so) but I often remain ill, whereupon he (the Holy Prophet) said to her: Perform Hajj but with condition, and say: O Allah, I shall be free from Ihram where you detain me. And she (Duba`a) was the wife of Miqdad}}
\hadithdefcmd{muslim}{2903}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى ضُبَاعَةَ بِنْتِ الزُّبَيْرِ بْنِ عَبْدِ الْمُطَّلِبِ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ الْحَجَّ وَأَنَا شَاكِيَةٌ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ حُجِّي وَاشْتَرِطِي أَنَّ مَحِلِّي حَيْثُ حَبَسْتَنِي ‏"‏ ‏.‏\hadithno{2903}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Apostle (ﷺ) went (to the house of) Duba'a bint al-Zubair b. Abd al-Muttalib. She said:Messenger of Allah, I intend to perform Hajj, but I am ill. Thereupon Allah's Apostle (ﷺ) said: Enter Into the state of Ihram on condition that you would abandon it when Allah would detain you}}
\hadithdefcmd{muslim}{2904}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - مِثْلَهُ ‏.‏\hadithno{2904}\hadithtrans{This hadith has been reported on the authority of A'isha through another chain of transmitters}}
\hadithdefcmd{muslim}{2905}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، وَأَبُو عَاصِمٍ وَمُحَمَّدُ بْنُ بَكْرٍ عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا مُحَمَّدُ بْنُ، بَكْرٍ أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ طَاوُسًا، وَعِكْرِمَةَ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّ ضُبَاعَةَ بِنْتَ الزُّبَيْرِ بْنِ عَبْدِ الْمُطَّلِبِ، - رضى الله عنها - أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي امْرَأَةٌ ثَقِيلَةٌ وَإِنِّي أُرِيدُ الْحَجَّ فَمَا تَأْمُرُنِي قَالَ ‏ "‏ أَهِلِّي بِالْحَجِّ وَاشْتَرِطِي أَنَّ مَحِلِّي حَيْثُ تَحْبِسُنِي ‏"‏ ‏.‏ قَالَ فَأَدْرَكَتْ ‏.‏\hadithno{2905}\hadithtrans{Ibn Abbas reported that Duba'a bint al-Zubair b. 'Abd al-Muttalib (Allah be pleased with her) came to Allah's Messenger (ﷺ) and said:I am an ailing woman but I intend to perform Hajj; what you command me (to do)? He (the Holy Prophet) said: Enter into the state of Ihram (uttering these words) of condition: I would be free from it when Thou wouldst detain me. 'He (the narrator) said: But she was able to complete (the Hajj without breaking down)}}
\hadithdefcmd{muslim}{2906}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا حَبِيبُ بْنُ يَزِيدَ، عَنْ عَمْرِو بْنِ هَرِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَعِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما أَنَّ ضُبَاعَةَ، أَرَادَتِ الْحَجَّ فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم أَنْ تَشْتَرِطَ فَفَعَلَتْ ذَلِكَ عَنْ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2906}\hadithtrans{Ibn `Abbas (Allah be pleased with him) reported that Duba`a intended to perform Hajj, and the Messenger of Allah (ﷺ) commanded her (to enter into the state of Ihram) with condition. She did it in compliance with the command of Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{2907}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَأَبُو أَيُّوبَ الْغَيْلاَنِيُّ وَأَحْمَدُ بْنُ خِرَاشٍ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو عَامِرٍ، - وَهُوَ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو - حَدَّثَنَا رَبَاحٌ، - وَهُوَ ابْنُ أَبِي مَعْرُوفٍ - عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِضُبَاعَةَ رضى الله عنها ‏ "‏ حُجِّي وَاشْتَرِطِي أَنَّ مَحِلِّي حَيْثُ تَحْبِسُنِي ‏"‏ ‏.‏ وَفِي رِوَايَةِ إِسْحَاقَ أَمَرَ ضُبَاعَةَ ‏.‏\hadithno{2907}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Abbas with a slight variation of words}}
\hadithdefcmd{muslim}{2908}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، وَزُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، كُلُّهُمْ عَنْ عَبْدَةَ، - قَالَ زُهَيْرٌ حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، - عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ نُفِسَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ بِمُحَمَّدِ بْنِ أَبِي بَكْرٍ بِالشَّجَرَةِ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا بَكْرٍ يَأْمُرُهَا أَنْ تَغْتَسِلَ وَتُهِلَّ ‏.‏\hadithno{2908}\hadithtrans{A'isha (Allah be pleased with her) reported that Asma' bint `Umais gave birth to Muhammad b Abu Bakr near Dhu'l-Hulaifa. The Messenger of Allah (ﷺ) commanded Abu Bakr to convey to her that she should take a bath and then enter into the state of Ihram}}
\hadithdefcmd{muslim}{2909}{حَدَّثَنَا أَبُو غَسَّانَ، مُحَمَّدُ بْنُ عَمْرٍو حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ يَحْيَى بْنِ، سَعِيدٍ عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهما - فِي حَدِيثِ أَسْمَاءَ بِنْتِ عُمَيْسٍ حِينَ نُفِسَتْ بِذِي الْحُلَيْفَةِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أَبَا بَكْرٍ - رضى الله عنه - فَأَمَرَهَا أَنْ تَغْتَسِلَ وَتُهِلَّ ‏.‏\hadithno{2909}\hadithtrans{Jabir b. `Abdullah (Allah be pleased with them) reported that when Asma' bint `Umais gave birth (to a child) in Dhu'l-Hulaifa. Allah's Messenger (ﷺ) commanded Abu Bakr (to convey to her) that she should take a bath and enter into the state of Ihram}}
\hadithdefcmd{muslim}{2910}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ فَأَهْلَلْنَا بِعُمْرَةٍ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُهِلَّ بِالْحَجِّ مَعَ الْعُمْرَةِ ثُمَّ لاَ يَحِلُّ حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ ‏.‏ قَالَتْ فَقَدِمْتُ مَكَّةَ وَأَنَا حَائِضٌ لَمْ أَطُفْ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَشَكَوْتُ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْقُضِي رَأْسَكِ وَامْتَشِطِي وَأَهِلِّي بِالْحَجِّ وَدَعِي الْعُمْرَةَ ‏"‏ ‏.‏ قَالَتْ فَفَعَلْتُ فَلَمَّا قَضَيْنَا الْحَجَّ أَرْسَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ إِلَى التَّنْعِيمِ فَاعْتَمَرْتُ فَقَالَ ‏"‏ هَذِهِ مَكَانَ عُمْرَتِكِ ‏"‏ ‏.‏ فَطَافَ الَّذِينَ أَهَلُّوا بِالْعُمْرَةِ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ حَلُّوا ثُمَّ طَافُوا طَوَافًا آخَرَ بَعْدَ أَنْ رَجَعُوا مِنْ مِنًى لِحَجِّهِمْ وَأَمَّا الَّذِينَ كَانُوا جَمَعُوا الْحَجَّ وَالْعُمْرَةَ فَإِنَّمَا طَافُوا طَوَافًا وَاحِدًا ‏.‏\hadithno{2910}\hadithtrans{A'isha (Allah be pleased with her) said:We went with the Messenger of Allah (ﷺ) during the year of the Farewell Pilgrimage. We entered into the state of Ihram for Umra. Then the Messenger of Allah (ﷺ) said: Who has the sacrificial animal with him, he should put on Ihram for Hajj along with Umra. and should not put it off till he has completed them (both Hajj and Umra). She said: When I came to Mecca. I was having menses, I neither circumambulated the House, nor ran between as-safa' and al-Marwa. I complained about it to the Messenger of Allah (ﷺ) and he said: Undo your hair, comb it, and pronounce Talbiya for Hajj, and give up Umra (for the time being), which I did. When we had performed the Hajj, the Messenger of Allah (way peace he upon him) sent me with Abd al-Rabman b. Abu Bakr to Tan'im saying: This is the place for your Umra. Those who had put on Ihram for Umra circumambulated the House, and ran between al-safa' and al-Marwa. They then put off Ihram and then made the last circuit after they had returned from Mina after performing their Hajj, but those who had combined the Hajj and the Umra made only one circuit (as they had combined Hajj and 'Umra)}}
\hadithdefcmd{muslim}{2911}{وَحَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ فَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِحَجٍّ حَتَّى قَدِمْنَا مَكَّةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحْرَمَ بِعُمْرَةٍ وَلَمْ يُهْدِ فَلْيَحْلِلْ وَمَنْ أَحْرَمَ بِعُمْرَةٍ وَأَهْدَى فَلاَ يَحِلُّ حَتَّى يَنْحَرَ هَدْيَهُ وَمَنْ أَهَلَّ بِحَجٍّ فَلْيُتِمَّ حَجَّهُ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ - رضى الله عنها - فَحِضْتُ فَلَمْ أَزَلْ حَائِضًا حَتَّى كَانَ يَوْمُ عَرَفَةَ وَلَمْ أُهْلِلْ إِلاَّ بِعُمْرَةٍ فَأَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَنْقُضَ رَأْسِي وَأَمْتَشِطَ وَأُهِلَّ بِحَجٍّ وَأَتْرُكَ الْعُمْرَةَ - قَالَتْ - فَفَعَلْتُ ذَلِكَ حَتَّى إِذَا قَضَيْتُ حَجَّتِي بَعَثَ مَعِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ وَأَمَرَنِي أَنْ أَعْتَمِرَ مِنَ التَّنْعِيمِ مَكَانَ عُمْرَتِي الَّتِي أَدْرَكَنِي الْحَجُّ وَلَمْ أَحْلِلْ مِنْهَا ‏.‏\hadithno{2911}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), said:We went out with the Messenger of Allah (ﷺ) during the year of the Farewell Pilgrimage. There were some amongst us who had put on IHram for Umra and there were some who had put on Ihram for Hajj. (We proceeded on till) we came to Mecca. The Messenger of Allah (ﷺ) said: He who put on Ihram for 'Umra but did not bring the sacrificial animal with him should put it off. and he who put on Ihram for Umra and he who had brought the sacrificial animal with him should not put it off until he had slaughtered the animal; and he who put on lhram for Hajj should complete it. A'isha (Allah be pleased with her) said: I was in the monthlyperiod, and I remained In this state till the day of 'Arafa, and I had entered into the state of Ihram for 'Umra. The Messenger of Allah (ﷺ) thus commanded me to undo my hair and comb them (again) and enter into the state of Ihram for Hajj, and abandon (the rites of 'Umra). She ('A'isha) said: I did so, and when I had completed my Pilgrimage, the Messenger of Allah (ﷺ) sent with me 'Abd al-Rabman b. Abu Bakr and commanded me to (resume the rites of) 'Umra at Tan'im. the place where (I abandoned) 'Umra and put on Ihram for Hajj (before completing Umra)}}
\hadithdefcmd{muslim}{2912}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ فَأَهْلَلْتُ بِعُمْرَةٍ وَلَمْ أَكُنْ سُقْتُ الْهَدْىَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُهْلِلْ بِالْحَجِّ مَعَ عُمْرَتِهِ ثُمَّ لاَ يَحِلَّ حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ ‏.‏ قَالَتْ فَحِضْتُ فَلَمَّا دَخَلَتْ لَيْلَةُ عَرَفَةَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ أَهْلَلْتُ بِعُمْرَةٍ فَكَيْفَ أَصْنَعُ بِحَجَّتِي قَالَ ‏"‏ انْقُضِي رَأْسَكِ وَامْتَشِطِي وَأَمْسِكِي عَنِ الْعُمْرَةِ وَأَهِلِّي بِالْحَجِّ ‏"‏ ‏.‏ قَالَتْ فَلَمَّا قَضَيْتُ حَجَّتِي أَمَرَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ فَأَرْدَفَنِي فَأَعْمَرَنِي مِنَ التَّنْعِيمِ مَكَانَ عُمْرَتِي الَّتِي أَمْسَكْتُ عَنْهَا ‏.‏\hadithno{2912}\hadithtrans{A'isha (Allah be pleased with her) reported:We went with the Messenger of Allah (ﷺ) during the year of the Farewell Pilgrimage. I put on Ihram for Umra and did not bring the sacrificial animal. The Apostle of Allah (ﷺ) said: He who has the sacrihcial animal with him should enter into the state of Ihram for Hajj along with 'Umra, and. he should not put the Ihram off till he has completed both of them. She (Hadrat A'isha) said: The monthly period began. When it was the night of Arafa, I said to the Messenger of Allah (ﷺ): I entered into the state of Ihram for 'Umra. but now how should I perform the Hajj? Thereupon he said: Undo your hair and comb them, and desist from performing Umra, and put on Ihram for Hajj She (A'isha, said: When I had completed my Hajj he commanded 'Abd al-Rahman b. Abu Bakr to carry me behind him (on boneback) in order to enable me to resume the rituals of Umra from Tan'im, the place where I abandoned its rituals}}
\hadithdefcmd{muslim}{2913}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَنْ أَرَادَ مِنْكُمْ أَنْ يُهِلَّ بِحَجٍّ وَعُمْرَةٍ فَلْيَفْعَلْ وَمَنْ أَرَادَ أَنْ يُهِلَّ بِحَجٍّ فَلْيُهِلَّ وَمَنْ أَرَادَ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهِلَّ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ رضى الله عنها فَأَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِحَجٍّ وَأَهَلَّ بِهِ نَاسٌ مَعَهُ وَأَهَلَّ نَاسٌ بِالْعُمْرَةِ وَالْحَجِّ وَأَهَلَّ نَاسٌ بِعُمْرَةٍ وَكُنْتُ فِيمَنْ أَهَلَّ بِالْعُمْرَةِ ‏.‏\hadithno{2913}\hadithtrans{A'isha (Allah be pleased with her) reported:'We went with the Messenger of Allah (ﷺ) (to Mecca). He said: He who intended among you to put on Ihram for Hajj and `Umra should do so. And he who intended to put on Ihram for Hajj may do so. And he who intended to put on Ihram for `Umra only may do so. `A'isha (Allah be pleased with her) said: The Messenger of Allah (ﷺ) put on Ihram for Hajj and some people did that along with him. And some people put on Ihram for `Umra and Hajj (both), and some persons put on Ihram for `Umra only, and I was among those who put on Ihram for `Umra (only)}}
\hadithdefcmd{muslim}{2914}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ مُوَافِينَ لِهِلاَلِ ذِي الْحِجَّةِ - قَالَتْ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَرَادَ مِنْكُمْ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهِلَّ فَلَوْلاَ أَنِّي أَهْدَيْتُ لأَهْلَلْتُ بِعُمْرَةٍ ‏"‏ ‏.‏ قَالَتْ فَكَانَ مِنَ الْقَوْمِ مَنْ أَهَلَّ بِعُمْرَةٍ وَمِنْهُمْ مَنْ أَهَلَّ بِالْحَجِّ - قَالَتْ - فَكُنْتُ أَنَا مِمَّنْ أَهَلَّ بِعُمْرَةٍ فَخَرَجْنَا حَتَّى قَدِمْنَا مَكَّةَ فَأَدْرَكَنِي يَوْمُ عَرَفَةَ وَأَنَا حَائِضٌ لَمْ أَحِلَّ مِنْ عُمْرَتِي فَشَكَوْتُ ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ دَعِي عُمْرَتَكِ وَانْقُضِي رَأْسَكِ وَامْتَشِطِي وَأَهِلِّي بِالْحَجِّ ‏"‏ ‏.‏ قَالَتْ فَفَعَلْتُ فَلَمَّا كَانَتْ لَيْلَةُ الْحَصْبَةِ - وَقَدْ قَضَى اللَّهُ حَجَّنَا - أَرْسَلَ مَعِي عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ فَأَرْدَفَنِي وَخَرَجَ بِي إِلَى التَّنْعِيمِ فَأَهْلَلْتُ بِعُمْرَةٍ فَقَضَى اللَّهُ حَجَّنَا وَعُمْرَتَنَا وَلَمْ يَكُنْ فِي ذَلِكَ هَدْىٌ وَلاَ صَدَقَةٌ وَلاَ صَوْمٌ ‏.‏\hadithno{2914}\hadithtrans{A'isha (Allah be pleased with her) reported:We went with the Messenger of Allah (ﷺ) (in his) Farewell Pilgrimage near the time of the appearance of the new moon of Dhul-Hijja. The Messenger of Allah (ﷺ) said: He who amongst you intends to put on Ihram for `Umra may do so; had I not brought sacrificial animals along with me, I would have put on Ihram for `Umra. She (further said). There were some persons who put on Ihram for `Umra, and some persons who put on Ihram for Hajj, and I was one of those who put on Ihram for `Umra. We went on till we reached Mecca, and on the day of `Arafa I found myself in a state of menses, but I did not put off the Ihram for `Umra. I told about (this state of mine) to the Messenger of Allah (ﷺ), whereupon he said: Abandon your `Umra, and undo the hair of your head and comb (them), and put on Ihram for Hajj. She (`A'isha) said: I did accordingly. When it was the night at Hasba and Allah enabled us to complete our Hajj, he (the Holy Prophet) sent with me `Abd al-Rahman b. Abu Bakr, and he mounted me behind him on his camel and took me to Tan`im and I put on Ihram for `Umra, and thus Allah enabled us to complete our Hajj and `Umra and (we were required to observe) neither sacrifice nor alms nor fasting}}
\hadithdefcmd{muslim}{2915}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مُوَافِينَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِهِلاَلِ ذِي الْحِجَّةِ لاَ نَرَى إِلاَّ الْحَجَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحَبَّ مِنْكُمْ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهِلَّ بِعُمْرَةٍ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ عَبْدَةَ ‏.‏\hadithno{2915}\hadithtrans{A'isha (Allah be pleased with her) said:We set out with the Messenger of Allah (ﷺ) just at the appearance of the new moon of Dhul- Hijja. We had no other intention but that of performing the Hajj, whereupon the Messenger of Allah (ﷺ) said: He who among you intends to put on Ihram for `Umra should do so for `Umra. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2916}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُوَافِينَ لِهِلاَلِ ذِي الْحِجَّةِ مِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِحَجَّةٍ وَعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِحَجَّةٍ فَكُنْتُ فِيمَنْ أَهَلَّ بِعُمْرَةٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِهِمَا وَقَالَ فِيهِ قَالَ عُرْوَةُ فِي ذَلِكَ إِنَّهُ قَضَى اللَّهُ حَجَّهَا وَعُمْرَتَهَا ‏.‏ قَالَ هِشَامٌ وَلَمْ يَكُنْ فِي ذَلِكَ هَدْىٌ وَلاَ صِيَامٌ وَلاَ صَدَقَةٌ ‏.‏\hadithno{2916}\hadithtrans{A'isha (Allah be pleased with her) reported:We went with the Messenger of Allah (ﷺ) at the appearance of the new moon of Dhu'l-Hijja. There were amongst us those who had put on Ihram for Umra, and those also who had put on Ihram both for Hajj and Umra, and still those who had put on Ihram for Hajj (alone). I was one of those who had put on Ihram for. Umra (only). 'Urwa (one of the narrators) said: Allah enabled her (A'isha) to complete both Hajj and Umra (according to the way as mentioned above). Hisham (one of the narrators) said: She had neither the sacrificial animal nor (was she required to) fast, nor (was she obliged to give) alms}}
\hadithdefcmd{muslim}{2917}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ فَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِحَجٍّ وَعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِالْحَجِّ وَأَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ فَأَمَّا مَنْ أَهَلَّ بِعُمْرَةٍ فَحَلَّ وَأَمَّا مَنْ أَهَلَّ بِحَجٍّ أَوْ جَمَعَ الْحَجَّ وَالْعُمْرَةَ فَلَمْ يَحِلُّوا حَتَّى كَانَ يَوْمُ النَّحْرِ ‏.‏\hadithno{2917}\hadithtrans{A'isha (Allah be pleased with her) said:We proceeded with the Messenger of Allah (ﷺ) during the year of the Farewell Pilgrimage. There were those amongst us who had put on Ihram for Umra, and those who had put on Ihram both for Hajj and" Umra, and those amongst us who had put on Ihram for Hajj (only), while the Messenger of Allah (ﷺ) had put on Ihram for Hajj (only). He who put on Ihram for Umra put it off (after performing Umra), and he who had put on Ihram for Hajj or for both Hajj and 'Umra did not put it off before the day of sacrifice (10th of Dhu'l-Hijja)}}
\hadithdefcmd{muslim}{2918}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ، عُيَيْنَةَ - قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم وَلاَ نُرَى إِلاَّ الْحَجَّ حَتَّى إِذَا كُنَّا بِسَرِفَ أَوْ قَرِيبًا مِنْهَا حِضْتُ فَدَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ أَنَفِسْتِ ‏"‏ ‏.‏ يَعْنِي الْحَيْضَةَ ‏.‏ - قَالَتْ - قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ إِنَّ هَذَا شَىْءٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ فَاقْضِي مَا يَقْضِي الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ حَتَّى تَغْتَسِلِي ‏"‏ ‏.‏ قَالَتْ وَضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نِسَائِهِ بِالْبَقَرِ ‏.‏\hadithno{2918}\hadithtrans{A'isha (Allah be pleased with her) said:We proceeded with the Messenger of Allah (ﷺ) with no other intention but that of performing the Hajj. As I was at Sarif or near it, I entered in the state of menses. The Apostle of Allah (ﷺ) came to me and I was weeping, whereupon he said: Are you in a state of menses? I said. Yes. whereupon he said: This is what Allah has ordained for all the daughters, of Adam. Do whatever the pilgrim does. except that you should not circumambulate the House till you have washed yourself (at the end of the menses period). And the Messenger of Allah (ﷺ) offered sacrifice of a cow on behalf of his wives}}
\hadithdefcmd{muslim}{2919}{حَدَّثَنِي سُلَيْمَانُ بْنُ عُبَيْدِ اللَّهِ أَبُو أَيُّوبَ الْغَيْلاَنِيُّ، حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ الْمَلِكِ، بْنُ عَمْرٍو حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ الْمَاجِشُونُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نَذْكُرُ إِلاَّ الْحَجَّ حَتَّى جِئْنَا سَرِفَ فَطَمِثْتُ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ مَا يُبْكِيكِ ‏"‏ ‏.‏ فَقُلْتُ وَاللَّهِ لَوَدِدْتُ أَنِّي لَمْ أَكُنْ خَرَجْتُ الْعَامَ قَالَ ‏"‏ مَا لَكِ لَعَلَّكِ نَفِسْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ هَذَا شَىْءٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ افْعَلِي مَا يَفْعَلُ الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ حَتَّى تَطْهُرِي ‏"‏ ‏.‏ قَالَتْ فَلَمَّا قَدِمْتُ مَكَّةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ اجْعَلُوهَا عُمْرَةً ‏"‏ ‏.‏ فَأَحَلَّ النَّاسُ إِلاَّ مَنْ كَانَ مَعَهُ الْهَدْىُ - قَالَتْ - فَكَانَ الْهَدْىُ مَعَ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَذَوِي الْيَسَارَةِ ثُمَّ أَهَلُّوا حِينَ رَاحُوا - قَالَتْ - فَلَمَّا كَانَ يَوْمُ النَّحْرِ طَهَرْتُ فَأَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَفَضْتُ - قَالَتْ - فَأُتِينَا بِلَحْمِ بَقَرٍ ‏.‏ فَقُلْتُ مَا هَذَا فَقَالُوا أَهْدَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نِسَائِهِ الْبَقَرَ ‏.‏ فَلَمَّا كَانَتْ لَيْلَةُ الْحَصْبَةِ قُلْتُ يَا رَسُولَ اللَّهِ يَرْجِعُ النَّاسُ بِحَجَّةٍ وَعُمْرَةٍ وَأَرْجِعُ بِحَجَّةٍ قَالَتْ فَأَمَرَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ فَأَرْدَفَنِي عَلَى جَمَلِهِ - قَالَتْ - فَإِنِّي لأَذْكُرُ وَأَنَا جَارِيَةٌ حَدِيثَةُ السِّنِّ أَنْعُسُ فَتُصِيبُ وَجْهِي مُؤْخِرَةُ الرَّحْلِ حَتَّى جِئْنَا إِلَى التَّنْعِيمِ فَأَهْلَلْتُ مِنْهَا بِعُمْرَةٍ جَزَاءً بِعُمْرَةِ النَّاسِ الَّتِي اعْتَمَرُوا ‏.‏\hadithno{2919}\hadithtrans{A'isha (Allah be pleased with her) reported:We went with the Messenger of Allah (ﷺ) with no other aim but that of Hajj till we came (to the place known as) Sarif; and there I entered in the state of menses. The Messenger of Allah (ﷺ) came to me while I was weeping. He said: What makes you weep? I said: Would that I had not come (for Pilgrimage) this year. He (the Holy Prophet) said: What has happened to you? You have perhaps entered the period of menses. I said: Yes. He said: This is what has been ordained for the daughters of Adam. Do what a pilgrim does except that you should not circumambulate the House, till you are purified (of the menses). She ('A'isha) said: When I came to Mecca, the Messenger of Allah (ﷺ) said to his companions: Make this (Ihram) the Ihram for 'Umra. So the people put off Ihram except those who had sacrificial animals with them. She ('A'isha) said: The Apostle of Allah (ﷺ) had the sacrificial animal with him, and so had Abu Bakr, 'Umar and other persons of means. They (those who had put off Ihram again) put on Ihram (for Hajj) when they marched (towards Mina), and it was the 8th of Dhu'l-Hijja. She ('A'isha) said: When it was the day of sacrifice (10th of Dhu'l-Hijja), I was purified, and the Messenger of Allah (ﷺ) commanded me and I did the circumambulation of Ifada. She said that the flesh of cow was sent to us. I said: What is it? They said: The Messenger of Allah (ﷺ) has offered a cow as sacrifice on behalf of his wives. When it was the night at Hasba, I said: Messenger of Allah, people are coming back from Hajj and Umra, where as I am coming back from Hajj (alone). She (A'isha) reported: He (the Holy Prophet) commanded" Abd al-Rahman b. Abu Bakr to mount me upon his camel behind him. She ('A'isha) said: I was very young and I well remember that I dozed off and my face touched the hind part of the haudaj (camel litter) till we came to Tan'im, and entered into the state of Ihram in lieu of Umra (which I for the time being abandoned) and which the people had performed}}
\hadithdefcmd{muslim}{2920}{وَحَدَّثَنِي أَبُو أَيُّوبَ الْغَيْلاَنِيُّ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ لَبَّيْنَا بِالْحَجِّ حَتَّى إِذَا كُنَّا بِسَرِفَ حِضْتُ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ الْمَاجِشُونِ ‏.‏ غَيْرَ أَنَّ حَمَّادًا لَيْسَ فِي حَدِيثِهِ فَكَانَ الْهَدْىُ مَعَ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَذَوِي الْيَسَارَةِ ثُمَّ أَهَلُّوا حِينَ رَاحُوا وَلاَ قَوْلُهَا وَأَنَا جَارِيَةٌ حَدِيثَةُ السِّنِّ أَنْعُسُ فَتُصِيبُ وَجْهِي مُؤْخِرَةُ الرَّحْلِ ‏.‏\hadithno{2920}\hadithtrans{A'isha (Allah be pleased with her) reported:We entered into the state of. Ihram for Hajj till we were at Sarif and I was in menses. The Messenger of Allah (ﷺ) came to me and I was weeping. The rest of the hadith is the same but (with this portion) that there were sacrificial animals with Allah's Apostle (ﷺ) and with Abu Bakr, Umar and with rich persons. And they pronounced Talbiya as they proceeded on. And there is no mention of this (too):" I was a girl of tender age and I dozed off and my face touched the bind part of the Haudaj}}
\hadithdefcmd{muslim}{2921}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي خَالِي، مَالِكُ بْنُ أَنَسٍ ح وَحَدَّثَنَا يَحْيَى، بْنُ يَحْيَى قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفْرَدَ الْحَجَّ ‏.‏\hadithno{2921}\hadithtrans{A'Isha reported that the Messenger of Allah (ﷺ) entered into the state of Ihram for Hajj Afrad}}
\hadithdefcmd{muslim}{2922}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، عَنْ أَفْلَحَ بْنِ حُمَيْدٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُهِلِّينَ بِالْحَجِّ فِي أَشْهُرِ الْحَجِّ وَفِي حُرُمِ الْحَجِّ وَلَيَالِي الْحَجِّ حَتَّى نَزَلْنَا بِسَرِفَ فَخَرَجَ إِلَى أَصْحَابِهِ فَقَالَ ‏"‏ مَنْ لَمْ يَكُنْ مَعَهُ مِنْكُمْ هَدْىٌ فَأَحَبَّ أَنْ يَجْعَلَهَا عُمْرَةً فَلْيَفْعَلْ وَمَنْ كَانَ مَعَهُ هَدْىٌ فَلاَ ‏"‏ ‏.‏ فَمِنْهُمُ الآخِذُ بِهَا وَالتَّارِكُ لَهَا مِمَّنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ فَأَمَّا رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَانَ مَعَهُ الْهَدْىُ وَمَعَ رِجَالٍ مِنْ أَصْحَابِهِ لَهُمْ قُوَّةٌ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ مَا يُبْكِيكِ ‏"‏ ‏.‏ قُلْتُ سَمِعْتُ كَلاَمَكَ مَعَ أَصْحَابِكَ فَسَمِعْتُ بِالْعُمْرَةِ فَمُنِعْتُ الْعُمْرَةَ ‏.‏ قَالَ ‏"‏ وَمَا لَكِ ‏"‏ ‏.‏ قُلْتُ لاَ أُصَلِّي ‏.‏ قَالَ ‏"‏ فَلاَ يَضُرُّكِ فَكُونِي فِي حَجِّكِ فَعَسَى اللَّهُ أَنْ يَرْزُقَكِيهَا وَإِنَّمَا أَنْتِ مِنْ بَنَاتِ آدَمَ كَتَبَ اللَّهُ عَلَيْكِ مَا كَتَبَ عَلَيْهِنَّ ‏"‏ ‏.‏ قَالَتْ فَخَرَجْتُ فِي حَجَّتِي حَتَّى نَزَلْنَا مِنًى فَتَطَهَّرْتُ ثُمَّ طُفْنَا بِالْبَيْتِ وَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُحَصَّبَ فَدَعَا عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ فَقَالَ ‏"‏ اخْرُجْ بِأُخْتِكَ مِنَ الْحَرَمِ فَلْتُهِلَّ بِعُمْرَةٍ ثُمَّ لْتَطُفْ بِالْبَيْتِ فَإِنِّي أَنْتَظِرُكُمَا هَا هُنَا ‏"‏ ‏.‏ قَالَتْ فَخَرَجْنَا فَأَهْلَلْتُ ثُمَّ طُفْتُ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ فَجِئْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي مَنْزِلِهِ مِنْ جَوْفِ اللَّيْلِ فَقَالَ ‏"‏ هَلْ فَرَغْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ فَآذَنَ فِي أَصْحَابِهِ بِالرَّحِيلِ فَخَرَجَ فَمَرَّ بِالْبَيْتِ فَطَافَ بِهِ قَبْلَ صَلاَةِ الصُّبْحِ ثُمَّ خَرَجَ إِلَى الْمَدِينَةِ ‏.‏\hadithno{2922}\hadithtrans{A'isha (Allah be pleased with her) reported:We proceeded with the Messenger of Allah (ﷺ) putting on the Ihram for Hajj during the months of Hajj and the night of Hajj till we encamped at Sarif. He (the Holy Prophet) went to his Companions and said: He who has no sacrificial animal with him, in his case I wish that he should perform Umra (with this Ihram), and he who has the sacrificial animal with him should not do it. So some of them performed Hajj whereas others who had no sacrificial animals with them did not do (Hajj, but performed only 'Umra). The Messenger of Allah (ﷺ) had a sacrificial animal with him and those too who could afford it (performed) Hajj). The Messenger of Allah (ﷺ) came to me (i. e. A'isha) while I was weeping, and he said: What makes you weep? I said: I heard your talk with Companions about Umra. He said: What has happened to you? I said: I do not observe prayer (due to the monthly period), whereupon he said: It would not harm you; you should perform (during this time) the rituals of Hajj (which you can do outside the House). Maybe Allah will compensate you for this. You are one among the daughters of Adam and Allah has ordained for you as He has ordained for them. So I proceeded on (with the rituals of Hajj) till we came to Mina. I washed myself and then circumambulated the House, and the Messenger of Allah (ﷺ) encamped at Muhassab and called, Abd al-Rahman b. Abu Bakr. and said: Take out your sister from the precincts of the Ka'ba in order to put on Ihram for Umra and circumambulate the House. and I shall wait for you here. She said: So I went out and put on Ihram and then circumambulated the House, and (ran) between al-Safa and al-Marwa, and then we came to the Messenger of Allah (ﷺ) and he was in his house in the middle of the night. He said: Have you completed your (rituals)? I said: Yes. He then announced to his Companions to march on. He came out, and went to the House and circumambulated it before the dawn prayer and then proceeded to Medina}}
\hadithdefcmd{muslim}{2923}{حَدَّثَنِي يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ الْمُهَلَّبِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ أُمِّ الْمُؤْمِنِينَ، عَائِشَةَ - رضى الله عنها - قَالَتْ مِنَّا مَنْ أَهَلَّ بِالْحَجِّ مُفْرِدًا وَمِنَّا مَنْ قَرَنَ وَمِنَّا مَنْ تَمَتَّعَ ‏.‏\hadithno{2923}\hadithtrans{A'isha (Allah be pleased with her) said:Some among us put on Ihram for Hajj alone (Hajj Mufrad) ; some of us for Hajj and Umra together (Qiran), and some of us for Tamattal (first for Umra and after completing it for Hajj)}}
\hadithdefcmd{muslim}{2924}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ، بْنُ عُمَرَ عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ جَاءَتْ عَائِشَةُ حَاجَّةً ‏.‏\hadithno{2924}\hadithtrans{AI-Qasim b. Muhammad reported that A'isha had come for Hajj}}
\hadithdefcmd{muslim}{2925}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ عَمْرَةَ، قَالَتْ سَمِعْتُ عَائِشَةَ، - رضى الله عنها - تَقُولُ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ وَلاَ نُرَى إِلاَّ أَنَّهُ الْحَجُّ حَتَّى إِذَا دَنَوْنَا مِنْ مَكَّةَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ إِذَا طَافَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ أَنْ يَحِلَّ ‏.‏ قَالَتْ عَائِشَةُ رضى الله عنها فَدُخِلَ عَلَيْنَا يَوْمَ النَّحْرِ بِلَحْمِ بَقَرٍ فَقُلْتُ مَا هَذَا فَقِيِلَ ذَبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَزْوَاجِهِ ‏.‏ قَالَ يَحْيَى فَذَكَرْتُ هَذَا الْحَدِيثَ لِلْقَاسِمِ بْنِ مُحَمَّدٍ فَقَالَ أَتَتْكَ وَاللَّهِ بِالْحَدِيثِ عَلَى وَجْهِهِ ‏.‏\hadithno{2925}\hadithtrans{Umra reported:I heard A'isha (Allah be pleased with her) as saying: We went out with the Messenger of Allah (ﷺ) five days before the end of Dhi Qa'dah, and we did see but that he intended to perform Hajj (only), but as we came near Mecca the Messenger of Allah (ﷺ) commanded that he who did not have the sacrificial animal with him should put off Ihram after circumambulating the House and running between al-Safa and aI-Marwa (and thus convert his Ihram from that of Hajj to 'Umra). 'A'isha (Allah be pleased with her) said: The flesh of cow was sent to us on the Day of Sacrifice (10th of Dhu'I-Hijja). I said. What is this? It was said: The Messenger of Allah (ﷺ) sacrificed (the cow) on behalf of his wives. Yahya said: I made a mention of this hadith (what has been stated by Umra) to Qasim b. Muhammad, whereupon be said: By Allah, she has rightly narrated it to you}}
\hadithdefcmd{muslim}{2926}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَتْنِي عَمْرَةُ، أَنَّهَا سَمِعَتْ عَائِشَةَ، رضى الله عنها ح. وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{2926}\hadithtrans{This hadlth has been narrated by Yahya through the same chain of transmitters}}
\hadithdefcmd{muslim}{2927}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ أَمِّ الْمُؤْمِنِينَ، ح وَعَنِ الْقَاسِمِ، عَنْ أُمِّ الْمُؤْمِنِينَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ يَصْدُرُ النَّاسُ بِنُسُكَيْنِ وَأَصْدُرُ بِنُسُكٍ وَاحِدٍ قَالَ ‏ "‏ انْتَظِرِي فَإِذَا طَهَرْتِ فَاخْرُجِي إِلَى التَّنْعِيمِ فَأَهِلِّي مِنْهُ ثُمَّ الْقَيْنَا عِنْدَ كَذَا وَكَذَا - قَالَ أَظُنُّهُ قَالَ غَدًا - وَلَكِنَّهَا عَلَى قَدْرِ نَصَبِكِ - أَوْ قَالَ - نَفَقَتِكِ ‏"‏ ‏.‏\hadithno{2927}\hadithtrans{AI-Qasim narrated from the Mother of the Believers (Hadrat 'A'isha) that she said:Messenger of Allah. the people return (from Mecca) having done two worships (both Hajj and Umra), but I am coming back with one (only). whereupon he said: You should wait and when the period of menses is over, you should go to Tan'im and put on lhram and then meet us at such and such time (and I think he said tomorrow) ; and (the reward of this Umra) is for you equal to your hardship or your spending}}
\hadithdefcmd{muslim}{2928}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنِ الْقَاسِمِ، وَإِبْرَاهِيمَ، - قَالَ لاَ أَعْرِفُ حَدِيثَ أَحَدِهِمَا مِنَ الآخَرِ - أَنَّ أُمَّ الْمُؤْمِنِينَ - رضى الله عنها - قَالَتْ يَا رَسُولَ اللَّهِ يَصْدُرُ النَّاسُ بِنُسُكَيْنِ ‏.‏ فَذَكَرَ الْحَدِيثَ ‏.‏\hadithno{2928}\hadithtrans{Ibn al-Muththanna reported on the authority of Ibn Abu'Adi who transmitted on the authority of Ibn'Aun who narrated from al-Qasim and Ibrahim having said:I cannot differentiate the hadith of one from the other (Qasim and Ibrahim) that the Mother of the Believers (Allah be pleased with her) said this: Messenger of Allah, people have come back with two acts of worship. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2929}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ زُهَيْرٌ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ نَرَى إِلاَّ أَنَّهُ الْحَجُّ فَلَمَّا قَدِمْنَا مَكَّةَ تَطَوَّفْنَا بِالْبَيْتِ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ أَنْ يَحِلَّ - قَالَتْ - فَحَلَّ مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ وَنِسَاؤُهُ لَمْ يَسُقْنَ الْهَدْىَ فَأَحْلَلْنَ ‏.‏ قَالَتْ عَائِشَةُ فَحِضْتُ فَلَمْ أَطُفْ بِالْبَيْتِ فَلَمَّا كَانَتْ لَيْلَةُ الْحَصْبَةِ - قَالَتْ - قُلْتُ يَا رَسُولَ اللَّهِ يَرْجِعُ النَّاسُ بِعُمْرَةٍ وَحَجَّةٍ وَأَرْجِعُ أَنَا بِحَجَّةٍ قَالَ ‏"‏ أَوَمَا كُنْتِ طُفْتِ لَيَالِيَ قَدِمْنَا مَكَّةَ ‏"‏ ‏.‏ قَالَتْ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَاذْهَبِي مَعَ أَخِيكِ إِلَى التَّنْعِيمِ فَأَهِلِّي بِعُمْرَةٍ ثُمَّ مَوْعِدُكِ مَكَانَ كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَتْ صَفِيَّةُ مَا أُرَانِي إِلاَّ حَابِسَتَكُمْ قَالَ ‏"‏ عَقْرَى حَلْقَى أَوَمَا كُنْتِ طُفْتِ يَوْمَ النَّحْرِ ‏"‏ ‏.‏ قَالَتْ بَلَى ‏.‏ قَالَ ‏"‏ لاَ بَأْسَ انْفِرِي ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَلَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ مُصْعِدٌ مِنْ مَكَّةَ وَأَنَا مُنْهَبِطَةٌ عَلَيْهَا أَوْ أَنَا مُصْعِدَةٌ وَهُوَ مُنْهَبِطٌ مِنْهَا ‏.‏ وَقَالَ إِسْحَاقُ مُتَهَبِّطَةٌ وَمُتَهَبِّطٌ ‏.‏\hadithno{2929}\hadithtrans{A'isha (Allah be pleased with her) reported:We went with the Messenger of Allah (ﷺ) and we did not see but that he (intended to perform) Hajj (only), but when we reached Mecca we circumambulated the House; and the Messenger of Allah (ﷺ) commanded that he who did not have with him a sacrificial animal should put off Ihram. She (A'isha) said: (And consequently) those who did not bring the sacrificial animals with them put off Ihram; and among his wives (too) who had not brought the sacrificial animals with them put off Ihram. A'isha said: I entered my period and could not (therefore) circumambulate the House. When it was the night of Hasba she said: Messenger of Allah, people are coming back (after having performed both) Hajj and'Umra, whereas I am coming back only with Hajj, whereupon he said: Did you not circumambulate (the Ka'ba) that very night we entered Mecca? She (A'isha) said: No, whereupon he said: Go along with your brother to Tan'im and put on the Ihram for Umra, and it is at such and such a place that you can meet (us). (In the meanwhile) Safiyya (the wife of the Holy Prophet) said: I think, I will detain you (since I have entered in the monthly) period and you shall have to wait for me for the farewell circuit). Thereupon he (the Holy Prophet) said: May you be wounded and your head shorn did you not circumambulate on the Day of Sacrifice (10th of Dhu'l-Hijja)? She said: Yes. The Prophet (ﷺ) said: There is no harm. You should go forward. 'A'isha said: The Messenger of Allah (ﷺ) was going upwards to the side of Mecca, whereas I was coming down from it, or I was going upward, whereas he was coming down. Isbiq said: She was climbing down, and he was climbing down}}
\hadithdefcmd{muslim}{2930}{وَحَدَّثَنَاهُ سُوَيْدُ بْنُ سَعِيدٍ، عَنْ عَلِيِّ بْنِ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نُلَبِّي لاَ نَذْكُرُ حَجًّا وَلاَ عُمْرَةً ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ مَنْصُورٍ ‏.‏\hadithno{2930}\hadithtrans{A'isha (Allah be pleased, with her) reported:We went out with the Messenger of Allah (ﷺ) pronouncing Talbiya having no explicit intention of Pilgrimage or 'Umra. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2931}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ غُنْدَرٍ، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، - حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ ذَكْوَانَ، مَوْلَى عَائِشَةَ عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَرْبَعٍ مَضَيْنَ مِنْ ذِي الْحِجَّةِ أَوْ خَمْسٍ فَدَخَلَ عَلَىَّ وَهُوَ غَضْبَانُ فَقُلْتُ مَنْ أَغْضَبَكَ يَا رَسُولَ اللَّهِ أَدْخَلَهُ اللَّهُ النَّارَ ‏.‏ قَالَ ‏ "‏ أَوَمَا شَعَرْتِ أَنِّي أَمَرْتُ النَّاسَ بِأَمْرٍ فَإِذَا هُمْ يَتَرَدَّدُونَ قَالَ الْحَكَمُ كَأَنَّهُمْ يَتَرَدَّدُونَ أَحْسِبُ - وَلَوْ أَنِّي اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا سُقْتُ الْهَدْىَ مَعِي حَتَّى أَشْتَرِيَهُ ثُمَّ أَحِلُّ كَمَا حَلُّوا ‏"‏ ‏.‏\hadithno{2931}\hadithtrans{A'isha (Allah be pleased with her) reported that the Messenger of Allah (ﷺ) came out on the 4th or 5th of Dhul'I-Hijja (for Pilgrimage to Mecca) and came to me, and he was very angry. I said:Messenger of Allah, who has annoyed you? May Allah cast him in fire I He said: Don't you know that I commanded the people to do an act, but they are hesitant. (Hakam said: I think that he said: They seem to be hesitant.) And if I were to know my affair before what I had to do subsequently, I would not have brought with me the sacrificial animals, and would have bought them (at Mecca) and would have put off lhram as others have done}}
\hadithdefcmd{muslim}{2932}{وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، سَمِعَ عَلِيَّ بْنَ، الْحُسَيْنِ عَنْ ذَكْوَانَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَدِمَ النَّبِيُّ صلى الله عليه وسلم لأَرْبَعٍ أَوْ خَمْسٍ مَضَيْنَ مِنْ ذِي الْحِجَّةِ ‏.‏ بِمِثْلِ حَدِيثِ غُنْدَرٍ وَلَمْ يَذْكُرِ الشَّكَّ مِنَ الْحَكَمِ فِي قَوْلِهِ يَتَرَدَّدُونَ ‏.‏\hadithno{2932}\hadithtrans{A'isha (Allah be pleased with her) reported that the Messenger of Allah (ﷺ) came out (for Pilgrimage) on The 4th or 5th of Dbu'l Hjjja. The rest of the hadith is the same, but he (the narrator) made no mention of the doubt of Hakam about his (the Prophet's) words:" They were reluctant}}
\hadithdefcmd{muslim}{2933}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا أَهَلَّتْ بِعُمْرَةٍ فَقَدِمَتْ وَلَمْ تَطُفْ بِالْبَيْتِ حَتَّى حَاضَتْ فَنَسَكَتِ الْمَنَاسِكَ كُلَّهَا ‏.‏ وَقَدْ أَهَلَّتْ بِالْحَجِّ ‏.‏ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم يَوْمَ النَّفْرِ ‏ "‏ يَسَعُكِ طَوَافُكِ لِحَجِّكِ وَعُمْرَتِكِ ‏"‏ ‏.‏ فَأَبَتْ فَبَعَثَ بِهَا مَعَ عَبْدِ الرَّحْمَنِ إِلَى التَّنْعِيمِ فَاعْتَمَرَتْ بَعْدَ الْحَجِّ ‏.‏\hadithno{2933}\hadithtrans{A'isha (Allah be pleased with her) reported that she put on Ihram for, Umra and arrived 'at Mecca) but did not circumambulate the House as she had entered in the period of menses, and then put on Ihram for Hajj and performed all the rituals concerning it (except circumambulating the House). The Apostle of Allah (ﷺ) said to her on the day of march (when pilgrims come to Mina):Your circumambulation would suffice both Hajj and Umra. She, however, felt reluctant. Thereupon the Prophet (ﷺ) sent her with 'Abd al-Rahman to Tan'im and she performed Umra (with separate rituals) after Hajj}}
\hadithdefcmd{muslim}{2934}{وَحَدَّثَنِي حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ نَافِعٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا حَاضَتْ بِسَرِفَ فَتَطَهَّرَتْ بِعَرَفَةَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُجْزِئُ عَنْكِ طَوَافُكِ بِالصَّفَا وَالْمَرْوَةِ عَنْ حَجِّكِ وَعُمْرَتِكِ ‏"‏ ‏.‏\hadithno{2934}\hadithtrans{A'isha (Allah be pleased with her) reported that she entered in the monthly period at Sarif, and took bath at 'Arafa (after the period was over). The messenger of Allah (ﷺ) said to her:Your circumambulation between al Safa and al-Marwa is enough for your Hajj and 'Umra}}
\hadithdefcmd{muslim}{2935}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا قُرَّةُ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جُبَيْرِ بْنِ شَيْبَةَ، حَدَّثَتْنَا صَفِيَّةُ بِنْتُ شَيْبَةَ، قَالَتْ قَالَتْ عَائِشَةُ رضى الله عنها يَا رَسُولَ اللَّهِ أَيَرْجِعُ النَّاسُ بِأَجْرَيْنِ وَأَرْجِعُ بِأَجْرٍ فَأَمَرَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ أَنْ يَنْطَلِقَ بِهَا إِلَى التَّنْعِيمِ ‏.‏ قَالَتْ فَأَرْدَفَنِي خَلْفَهُ عَلَى جَمَلٍ لَهُ - قَالَتْ - فَجَعَلْتُ أَرْفَعُ خِمَارِي أَحْسُرُهُ عَنْ عُنُقِي فَيَضْرِبُ رِجْلِي بِعِلَّةِ الرَّاحِلَةِ ‏.‏ قُلْتُ لَهُ وَهَلْ تَرَى مِنْ أَحَدٍ قَالَتْ فَأَهْلَلْتُ بِعُمْرَةٍ ثُمَّ أَقْبَلْنَا حَتَّى انْتَهَيْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ بِالْحَصْبَةِ ‏.‏\hadithno{2935}\hadithtrans{Safiyya bint Shaiba reported that 'A'isha (Allah be pleased with her) said:Messenger of Allah, the people are returning with two rewards whereas I am returning with one reward. Thereupon he commanded 'Abd al-Rahman b. Abu Bakr to take her to al-Tan'im. She ('A'isha) said: He seated me behind him on his camel. She (further) stated: I lifted my head covering and took it off from my neck. He struck my foot as if he was striking the camel. I said to him: Do you find anyone bere? She (further) said: I entered into the state of Ihram for 'Umra till we reached the Messenger of Allah (ﷺ) and he was at Hasba}}
\hadithdefcmd{muslim}{2936}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، أَخْبَرَهُ عَمْرُو بْنُ أَوْسٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ أَنْ يُرْدِفَ عَائِشَةَ فَيُعْمِرَهَا مِنَ التَّنْعِيمِ ‏.‏\hadithno{2936}\hadithtrans{Abd al-Rahman b. Abu Bakr reported that the Messenger of Allah (ﷺ) ordered him to mount A'isha behind him and enable her to (enter into the state of Ihram for 'Umra) at Tan'im}}
\hadithdefcmd{muslim}{2937}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، جَمِيعًا عَنِ اللَّيْثِ بْنِ سَعْدٍ، - قَالَ قُتَيْبَةُ حَدَّثَنَا لَيْثٌ، - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، - رضى الله عنه - أَنَّهُ قَالَ أَقْبَلْنَا مُهِلِّينَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِحَجٍّ مُفْرَدٍ وَأَقْبَلَتْ عَائِشَةُ - رضى الله عنها - بِعُمْرَةٍ حَتَّى إِذَا كُنَّا بِسَرِفَ عَرَكَتْ حَتَّى إِذَا قَدِمْنَا طُفْنَا بِالْكَعْبَةِ وَالصَّفَا وَالْمَرْوَةِ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَحِلَّ مِنَّا مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ - قَالَ - فَقُلْنَا حِلُّ مَاذَا قَالَ ‏"‏ الْحِلُّ كُلُّهُ ‏"‏ ‏.‏ فَوَاقَعْنَا النِّسَاءَ وَتَطَيَّبْنَا بِالطِّيبِ وَلَبِسْنَا ثِيَابَنَا وَلَيْسَ بَيْنَنَا وَبَيْنَ عَرَفَةَ إِلاَّ أَرْبَعُ لَيَالٍ ثُمَّ أَهْلَلْنَا يَوْمَ التَّرْوِيَةِ ثُمَّ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عَائِشَةَ - رضى الله عنها - فَوَجَدَهَا تَبْكِي فَقَالَ ‏"‏ مَا شَانُكِ ‏"‏ ‏.‏ قَالَتْ شَانِي أَنِّي قَدْ حِضْتُ وَقَدْ حَلَّ النَّاسُ وَلَمْ أَحْلِلْ وَلَمْ أَطُفْ بِالْبَيْتِ وَالنَّاسُ يَذْهَبُونَ إِلَى الْحَجِّ الآنَ ‏.‏ فَقَالَ ‏"‏ إِنَّ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ فَاغْتَسِلِي ثُمَّ أَهِلِّي بِالْحَجِّ ‏"‏ ‏.‏ فَفَعَلَتْ وَوَقَفَتِ الْمَوَاقِفَ حَتَّى إِذَا طَهَرَتْ طَافَتْ بِالْكَعْبَةِ وَالصَّفَا وَالْمَرْوَةِ ثُمَّ قَالَ ‏"‏ قَدْ حَلَلْتِ مِنْ حَجِّكِ وَعُمْرَتِكِ جَمِيعًا ‏"‏ ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أَجِدُ فِي نَفْسِي أَنِّي لَمْ أَطُفْ بِالْبَيْتِ حَتَّى حَجَجْتُ ‏.‏ قَالَ ‏"‏ فَاذْهَبْ بِهَا يَا عَبْدَ الرَّحْمَنِ فَأَعْمِرْهَا مِنَ التَّنْعِيمِ ‏"‏ ‏.‏ وَذَلِكَ لَيْلَةَ الْحَصْبَةِ ‏.‏\hadithno{2937}\hadithtrans{Jabir (Allah be pleased with him) said:We, in the state of lhram, came with the Messenger of Allah (ﷺ) for Hajj Mufrad (with the aim of Hajj only), and 'A'isha set out for Umra, and when we reached Sarif, she (Hadrat A'isha) entered in the state of monthly period; we proceeded on till we reached (Mecca) and circumambulated the Ka'ba and ran between (al-Safa) and al-Marwa; and the Messenger of Allah (ﷺ) commanded that one who amongst us had no sacrificial animal with him should put off Ihram. We said: What does this "putting off" imply? He said: Getting out completely from the state of lhram, (so we put off Ihram), and we turned to our wives and applied perfume and put on our clothes. and we were at a four night's distance from 'Arafa. And we again put on Ihram on the day of Tarwiya (8th of Dhu'l-Hijja). The Messenger of Allah (ﷺ) came to 'A'isha (Allah be pleased with her) and found her weeping, and said: What is the matter with you? She said: The matter is that I have entered in the monthly period, and the people had put off lhram, but I did not and I did not circumambulate the House, and the people are going for Hajj now (but I can't go), whereupon he said: It is the matter which Allah has ordained for the daughters of Adam, so now take a bath and put on Ihram for Hajj. She ('A'isha) did accordingly, and stayed at the places of staying till the monthly period was over. She then circumambulated the House, and (ran between) al-Safa and al-Marwa. He (the Holy Prophet) then said: Now both your Hajj and 'Umra are complete, whereupon she said: I feel in my mind that I did not circumambulate the House till I performed Hajj (I missed the circumambulation of 'Umra). Thereupon he (Allah's Apostle) said: 'Abd al-Rahman, take her to Tan'im (so as to enable her) to perform Umra (separately), and it was the night at Hasba}}
\hadithdefcmd{muslim}{2938}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ حَاتِمٍ حَدَّثَنَا وَقَالَ عَبْدٌ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، - رضى الله عنهما - يَقُولُ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى عَائِشَةَ - رضى الله عنها - وَهْىَ تَبْكِي ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ اللَّيْثِ إِلَى آخِرِهِ وَلَمْ يَذْكُرْ مَا قَبْلَ هَذَا مِنْ حَدِيثِ اللَّيْثِ ‏.‏\hadithno{2938}\hadithtrans{Jabir b. Abdullah is reported to have said that the Messenger of Allah (ﷺ) came to 'A'isha (Allah be pleased with her) and she was weeping. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2939}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، - يَعْنِي ابْنَ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ مَطَرٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَائِشَةَ، - رضى الله عنها - فِي حَجَّةِ النَّبِيِّ صلى الله عليه وسلم أَهَلَّتْ بِعُمْرَةٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ اللَّيْثِ وَزَادَ فِي الْحَدِيثِ قَالَ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً سَهْلاً إِذَا هَوِيَتِ الشَّىْءَ تَابَعَهَا عَلَيْهِ فَأَرْسَلَهَا مَعَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ فَأَهَلَّتْ بِعُمْرَةٍ مِنَ التَّنْعِيمِ ‏.‏ قَالَ مَطَرٌ قَالَ أَبُو الزُّبَيْرِ فَكَانَتْ عَائِشَةُ إِذَا حَجَّتْ صَنَعَتْ كَمَا صَنَعَتْ مَعَ نَبِيِّ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2939}\hadithtrans{Jabir b. 'Abdullah reported that A'isha (Allah be pleased with her) entered into the state of Ihram (separately) for 'Umra while the Prophet (ﷺ) was performing Hajj. The rest of the hadith is the same, but with this addition:The Messenger of Allah (ﷺ) was a person of gentle disposition, so when she (A'Isha) wished for a thing, he accepted it (provided it did not contravene the teachings of Islam). So he (in pursuance of her desire for a separate lhram for Umra) sent her with 'Abd al-Rahman b. Abu Bakr and she put on Ihram for 'Umra at al-Tan'im. Matar and Abu Zubair (the two narrators amongst the chain of transmitters) said: Whenever 'A'isha performed Hajj she did as she had done along with Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{2940}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، - رضى الله عنه - ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، - رضى الله عنه - قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُهِلِّينَ بِالْحَجِّ مَعَنَا النِّسَاءُ وَالْوِلْدَانُ فَلَمَّا قَدِمْنَا مَكَّةَ طُفْنَا بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ فَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ فَلْيَحْلِلْ ‏"‏ ‏.‏ قَالَ قُلْنَا أَىُّ الْحِلِّ قَالَ ‏"‏ الْحِلُّ كُلُّهُ ‏"‏ ‏.‏ قَالَ فَأَتَيْنَا النِّسَاءَ وَلَبِسْنَا الثِّيَابَ وَمَسِسْنَا الطِّيبَ فَلَمَّا كَانَ يَوْمُ التَّرْوِيَةِ أَهْلَلْنَا بِالْحَجِّ وَكَفَانَا الطَّوَافُ الأَوَّلُ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَشْتَرِكَ فِي الإِبِلِ وَالْبَقَرِ كُلُّ سَبْعَةٍ مِنَّا فِي بَدَنَةٍ ‏\hadithno{2940}\hadithtrans{Jabir (Allah be pleased with him) said.:We went with Allah's Messenger (ﷺ) in 'a state of Ihram for the Hajj. There were women and children with us. When we reached Mecca we circumambulated the House and (ran) between al-Safa and al-Marwa. The Messenger of Allah (ﷺ) said: He who has no sacrificial animal with him should put off lhram. We said: What kind of putting off? He said: Getting out of lhram completely. So we came to our wives, and put on our clothes and applied perfume. When it was the day of Tarwiya, we put on Ihram for Hajj. and the first circumambulation and (running) between al-Safa and al-Marwa sufficed us.. Allah's Messenger (ﷺ) commanded us to become seven partners (in the sacrifice) of a camel and a cow}}
\hadithdefcmd{muslim}{2941}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهما - قَالَ أَمَرَنَا النَّبِيُّ صلى الله عليه وسلم لَمَّا أَحْلَلْنَا أَنْ نُحْرِمَ إِذَا تَوَجَّهْنَا إِلَى مِنًى ‏.‏ قَالَ فَأَهْلَلْنَا مِنَ الأَبْطَحِ ‏.‏\hadithno{2941}\hadithtrans{Jabir b. Abdullah reported that the Messenger of Allah (ﷺ) ordered us to put on Ihram (again) as we proceeded towards Mina after we had put it off (i. e. 'on the 8th of Dhu'l-Hijja). So we pronounced Talbiya at al-Abtah}}
\hadithdefcmd{muslim}{2942}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنَا عَبْدُ، بْنُ حُمَيْدٍ أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ، بْنَ عَبْدِ اللَّهِ - رضى الله عنه - يَقُولُ لَمْ يَطُفِ النَّبِيُّ صلى الله عليه وسلم وَلاَ أَصْحَابُهُ بَيْنَ الصَّفَا وَالْمَرْوَةِ إِلاَّ طَوَافًا وَاحِدًا ‏.‏ زَادَ فِي حَدِيثِ مُحَمَّدِ بْنِ بَكْرٍ طَوَافَهُ الأَوَّلَ ‏.‏\hadithno{2942}\hadithtrans{Jabir b. Abdullah is reported to have said:Neither Allah's Apostle (ﷺ) nor his Companions (circumambulated the Ka'ba and) ran between al-Safa and al-Marwa but once (sufficing both for Hajj and 'Umra). But in the hadith transmitted by Muhammad b. Bakr there is an addition:" That is first circumambulation}}
\hadithdefcmd{muslim}{2943}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، - رضى الله عنهما - فِي نَاسٍ مَعِي قَالَ أَهْلَلْنَا أَصْحَابَ مُحَمَّدٍ صلى الله عليه وسلم بِالْحَجِّ خَالِصًا وَحْدَهُ - قَالَ عَطَاءٌ قَالَ جَابِرٌ - فَقَدِمَ النَّبِيُّ صلى الله عليه وسلم صُبْحَ رَابِعَةٍ مَضَتْ مِنْ ذِي الْحِجَّةِ فَأَمَرَنَا أَنْ نَحِلَّ ‏.‏ قَالَ عَطَاءٌ قَالَ ‏"‏ حِلُّوا وَأَصِيبُوا النِّسَاءَ ‏"‏ ‏.‏ قَالَ عَطَاءٌ وَلَمْ يَعْزِمْ عَلَيْهِمْ وَلَكِنْ أَحَلَّهُنَّ لَهُمْ ‏.‏ فَقُلْنَا لَمَّا لَمْ يَكُنْ بَيْنَنَا وَبَيْنَ عَرَفَةَ إِلاَّ خَمْسٌ أَمَرَنَا أَنْ نُفْضِيَ إِلَى نِسَائِنَا فَنَأْتِيَ عَرَفَةَ تَقْطُرُ مَذَاكِيرُنَا الْمَنِيَّ ‏.‏ قَالَ يَقُولُ جَابِرٌ بِيَدِهِ - كَأَنِّي أَنْظُرُ إِلَى قَوْلِهِ بِيَدِهِ يُحَرِّكُهَا - قَالَ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فِينَا فَقَالَ ‏"‏ قَدْ عَلِمْتُمْ أَنِّي أَتْقَاكُمْ لِلَّهِ وَأَصْدَقُكُمْ وَأَبَرُّكُمْ وَلَوْلاَ هَدْيِي لَحَلَلْتُ كَمَا تَحِلُّونَ وَلَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ لَمْ أَسُقِ الْهَدْىَ فَحِلُّوا ‏"‏ ‏.‏ فَحَلَلْنَا وَسَمِعْنَا وَأَطَعْنَا ‏.‏ قَالَ عَطَاءٌ قَالَ جَابِرٌ فَقَدِمَ عَلِيٌّ مِنْ سِعَايَتِهِ فَقَالَ ‏"‏ بِمَ أَهْلَلْتَ ‏"‏ ‏.‏ قَالَ بِمَا أَهَلَّ بِهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَهْدِ وَامْكُثْ حَرَامًا ‏"‏ ‏.‏ قَالَ وَأَهْدَى لَهُ عَلِيٌّ هَدْيًا فَقَالَ سُرَاقَةُ بْنُ مَالِكِ بْنِ جُعْشُمٍ يَا رَسُولَ اللَّهِ أَلِعَامِنَا هَذَا أَمْ لأَبَدٍ فَقَالَ ‏"‏ لأَبَدٍ ‏"‏ ‏.‏\hadithno{2943}\hadithtrans{Ata'reported:I, along with some people, heard Jabir b. 'Abdullah saying: We the Companions of Muhammad (ﷺ) put on Ihram for Hajj only. Ata' further said that Jabir stated: Allah's Apostle (ﷺ) came on the 4th of Dhu'l-Hijja and he commanded us to put off Ihram. 'Ata'said that he (Allah's Apostle) commanded them to put off Ihram and to go to their wives (for intercourse). 'Ata' said: It was not obligatory for them, but (intercourse) with them had become permissible. We said: When only five days had been left to reach 'Arafa, he (the Holy Prophet) commanded us to have intercourse with our wives. And we reached 'Arafa in a state as if we had just had intercourse (with them). He ('Ata') said: Jabir pointed with his hand and I (perceive) as if I am seeing his hand as it moved. In the (meantime) the Messenger of Allah (ﷺ) stood amongst us and said: You are well aware that I am the most God-fearing, most truthful and most pious amongst you. And if there were not sacrificial animals with me, I would also have put off Ihram as you have put off. And if I were to know this matter of mine what I have come to know later on, I would not have brought sacrificial animals with me. So they (the Companions) put off Ihram and we also put it off and listened to (the Holy Prophet) and obeyed (his command). Jabir said: 'Ali came with the revenue of the taxes (from Yemen). He (the Holy Prophet) said: For what (purpose) have you entered into the state of Ihram (whether you entered into the state purely for Hajj and, Umra jointly or Hajj and Umra separately)? He said: For the purpose for which the Messenger of Allah (ﷺ) had entered. (The Prophet had entered as a Qiran, i.e. Ihram covering both Umra and Hajj simultaneously.) Thereupon Allah's Messenger (ﷺ) said: Offer a sacrifice of animal, and retain Ihram. And 'Ali brought a sacrificial animal for him (for the Holy Prophet). Suraqa b. Malik b. Ju'shum said: Messenger of Allah, is it (this concession putting off Ihram of Hajj or Umra) meant for this year or is it forever? He said: It is forever}}
\hadithdefcmd{muslim}{2944}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنِي أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهما - قَالَ أَهْلَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ فَلَمَّا قَدِمْنَا مَكَّةَ أَمَرَنَا أَنْ نَحِلَّ وَنَجْعَلَهَا عُمْرَةً فَكَبُرَ ذَلِكَ عَلَيْنَا وَضَاقَتْ بِهِ صُدُورُنَا فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَمَا نَدْرِي أَشَىْءٌ بَلَغَهُ مِنَ السَّمَاءِ أَمْ شَىْءٌ مِنْ قِبَلِ النَّاسِ فَقَالَ ‏ "‏ أَيُّهَا النَّاسُ أَحِلُّوا فَلَوْلاَ الْهَدْىُ الَّذِي مَعِي فَعَلْتُ كَمَا فَعَلْتُمْ ‏"‏ ‏.‏ قَالَ فَأَحْلَلْنَا حَتَّى وَطِئْنَا النِّسَاءَ وَفَعَلْنَا مَا يَفْعَلُ الْحَلاَلُ حَتَّى إِذَا كَانَ يَوْمُ التَّرْوِيَةِ وَجَعَلْنَا مَكَّةَ بِظَهْرٍ أَهْلَلْنَا بِالْحَجِّ ‏.‏\hadithno{2944}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:We entered with the Messenger of Allah (ﷺ) in the state of Ihram for Hajj. When we came to Mecca he commanded us to put off Ihram and make it for 'Umra. We felt it (the command) hard for us, and our hearts were anguished on account of this and it (this reaction of the people) reached the Messenger of Allah (ﷺ). We do not know whether he received (this news) from the Heaven (through revelation) or from the people. (Whatever the case might be) he said; O people, put off Ihram. If there were not the sacrificial animals with me, I would have done as you do. So we put off the Ihram (after performing Umra), and we had intercourse with our wives and did everything which a non-Muhrim does (applying perfume, putting on clothes, etc.), and when It was the day of Tarwiya (8th of Dhu'l-Hijja) we turned our back to Mecca (in order to go to Mini, 'Arafat) and we put on lhram for Hajj}}
\hadithdefcmd{muslim}{2945}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مُوسَى بْنُ نَافِعٍ، قَالَ قَدِمْتُ مَكَّةَ مُتَمَتِّعًا بِعُمْرَةٍ قَبْلَ التَّرْوِيَةِ بِأَرْبَعَةِ أَيَّامٍ فَقَالَ النَّاسُ تَصِيرُ حَجَّتُكَ الآنَ مَكِّيَّةً فَدَخَلْتُ عَلَى عَطَاءِ بْنِ أَبِي رَبَاحٍ فَاسْتَفْتَيْتُهُ فَقَالَ عَطَاءٌ حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ - رضى الله عنهما - أَنَّهُ حَجَّ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ سَاقَ الْهَدْىَ مَعَهُ وَقَدْ أَهَلُّوا بِالْحَجِّ مُفْرَدًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحِلُّوا مِنْ إِحْرَامِكُمْ فَطُوفُوا بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ وَقَصِّرُوا وَأَقِيمُوا حَلاَلاً حَتَّى إِذَا كَانَ يَوْمُ التَّرْوِيَةِ فَأَهِلُّوا بِالْحَجِّ وَاجْعَلُوا الَّتِي قَدِمْتُمْ بِهَا مُتْعَةً ‏"‏ ‏.‏ قَالُوا كَيْفَ نَجْعَلُهَا مُتْعَةً وَقَدْ سَمَّيْنَا الْحَجَّ قَالَ ‏"‏ افْعَلُوا مَا آمُرُكُمْ بِهِ فَإِنِّي لَوْلاَ أَنِّي سُقْتُ الْهَدْىَ لَفَعَلْتُ مِثْلَ الَّذِي أَمَرْتُكُمْ بِهِ وَلَكِنْ لاَ يَحِلُّ مِنِّي حَرَامٌ حَتَّى يَبْلُغَ الْهَدْىُ مَحِلَّهُ ‏"‏ ‏.‏ فَفَعَلُوا ‏.‏\hadithno{2945}\hadithtrans{Musa b. Nafi reported:I came to Mecca as a Mutamattil for Umra (performing Umra first and then putting off Ihram and again entering into the state of Ihram for Hajj) four days before the day of Tarwiya (i. e. on the 4th of Dhu'l-Hijja). Thereupon the people said: Now yours is the Hajj of the Meccans. I went to 'Ata' b. Abi Rabah and asked his religious verdict. Ata' said: Jabir b. 'Abdullah al'Ansari (Allah be pleased with them) narrated to me that he performed Hajj with the Messenger of Allah (ﷺ) in the year when he took sacrificial animals with him (i.e. during the 10th year of Hijra known as the Farewell Pilgrimage) and they had put on Ihram for Hajj only (as Mufrid). The Messenger of Allah (ﷺ) said: Put off Ihram and circumambulate the House, and (run) between al-Safa and al-Marwa, and get your hair cut and stay as non-Muhrims. When it was the day of Tarwiya, then put on Ihram for Hajj and make lhram for Mut'a (you had put on Ihram for Hajj, but take it off after performing Umra and then again put on Ihram for Hajj). They said: How should we make it Mut'a although we entered upon lhram in the name of Hajj? He said: Do whatever I command you to do. Had I not brought sacrificial animals with me, I would have done as I have commanded you to do. But it is not permissible for me to put off Ihram till the sacrifice is offered. Then they also did accordingly}}
\hadithdefcmd{muslim}{2946}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرِ بْنِ رِبْعِيٍّ الْقَيْسِيُّ، حَدَّثَنَا أَبُو هِشَامٍ الْمُغِيرَةُ بْنُ سَلَمَةَ، الْمَخْزُومِيُّ عَنْ أَبِي عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهما - قَالَ قَدِمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُهِلِّينَ بِالْحَجِّ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَجْعَلَهَا عُمْرَةً وَنَحِلَّ - قَالَ - وَكَانَ مَعَهُ الْهَدْىُ فَلَمْ يَسْتَطِعْ أَنْ يَجْعَلَهَا عُمْرَةً ‏.‏\hadithno{2946}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:We set out with Allah's Messenger (ﷺ) as Muhrim for Hajj. The Messenger of Allah (ﷺ) commanded us to make this Ihram for Umra, and some put it off (after performing 'Umra), but the Prophet (ﷺ) had sacrificial animals with him, so he could not make it (this Ihram) as that of Umra}}
\hadithdefcmd{muslim}{2947}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَبِي نَضْرَةَ، قَالَ كَانَ ابْنُ عَبَّاسٍ يَأْمُرُ بِالْمُتْعَةِ وَكَانَ ابْنُ الزُّبَيْرِ يَنْهَى عَنْهَا قَالَ فَذَكَرْتُ ذَلِكَ لِجَابِرِ بْنِ عَبْدِ اللَّهِ فَقَالَ عَلَى يَدَىَّ دَارَ الْحَدِيثُ تَمَتَّعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَلَمَّا قَامَ عُمَرُ قَالَ إِنَّ اللَّهَ كَانَ يُحِلُّ لِرَسُولِهِ مَا شَاءَ بِمَا شَاءَ وَإِنَّ الْقُرْآنَ قَدْ نَزَلَ مَنَازِلَهُ فَأَتِمُّوا الْحَجَّ وَالْعُمْرَةَ لِلَّهِ كَمَا أَمَرَكُمُ اللَّهُ وَأَبِتُّوا نِكَاحَ هَذِهِ النِّسَاءِ فَلَنْ أُوتَى بِرَجُلٍ نَكَحَ امْرَأَةً إِلَى أَجَلٍ إِلاَّ رَجَمْتُهُ بِالْحِجَارَةِ ‏.‏\hadithno{2947}\hadithtrans{(Abu Nadra reported:Ibn 'Abbas commanded the performance of Mut'a putting ihram for 'Umra during the months of Dhul-Hijja and after completing it. then putting on Ihram for Hajj), but Ibn Zubair forbade to do it. I made a mention of it to Jabir b. Abdullih and he said: It is through me that this hadith has been circulated. We entered into the state of Ihram as Tamattu' with the Messenger of Allah (ﷺ). When 'Umar was Installed as Caliph, he said: Verily Allah made permissible for His Messenger (ﷺ) whatever He liked and as Re liked. And (every command) of the Holy Qur'an has been revealed for every occasion. So accomplish Hajj and Umra for Allah as Allah has commanded you; and confirm by (proper conditions) the marriage of those women (with whom you have performed Mut'a). And any person would come to me with a marriage of appointed duration (Mut'a), I would stone him (to death)}}
\hadithdefcmd{muslim}{2948}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، بِهَذَا الإِسْنَادِ وَقَالَ فِي الْحَدِيثِ فَافْصِلُوا حَجَّكُمْ مِنْ عُمْرَتِكُمْ فَإِنَّهُ أَتَمُّ لِحَجِّكُمْ وَأَتَمُّ لِعُمْرَتِكُمْ ‏.‏\hadithno{2948}\hadithtrans{Qatada narrated this hadith with the same chain of transmitters saying:(That 'Umar also said): Separate your Hajj from 'Umra, for that is the most complete Hajj, and complete your Umra}}
\hadithdefcmd{muslim}{2949}{وَحَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ، وَقُتَيْبَةُ، جَمِيعًا عَنْ حَمَّادٍ، - قَالَ خَلَفٌ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ أَيُّوبَ، قَالَ سَمِعْتُ مُجَاهِدًا، يُحَدِّثُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهما - قَالَ قَدِمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَقُولُ لَبَّيْكَ بِالْحَجِّ ‏.‏ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَجْعَلَهَا عُمْرَةً ‏.‏\hadithno{2949}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:We came with the Messenger of Allah (May peace be upon him) pronouncing Talbiya for Hajj, and the Messenger of Allah (May peace be upon him) commanded us to make (our Ihram) into that of Umra}}
\hadithdefcmd{muslim}{2950}{وَحَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، حَدَّثَنِي أَبِي، قَالَ أَتَيْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ فَسَأَلْتُهُ عَنْ حَجَّةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ حَاتِمِ بْنِ إِسْمَاعِيلَ وَزَادَ فِي الْحَدِيثِ وَكَانَتِ الْعَرَبُ يَدْفَعُ بِهِمْ أَبُو سَيَّارَةَ عَلَى حِمَارٍ عُرْىٍ فَلَمَّا أَجَازَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْمُزْدَلِفَةِ بِالْمَشْعَرِ الْحَرَامِ ‏.‏ لَمْ تَشُكَّ قُرَيْشٌ أَنَّهُ سَيَقْتَصِرُ عَلَيْهِ وَيَكُونُ مَنْزِلُهُ ثَمَّ فَأَجَازَ وَلَمْ يَعْرِضْ لَهُ حَتَّى أَتَى عَرَفَاتٍ فَنَزَلَ ‏.‏\hadithno{2950}\hadithtrans{Ja'far b. Muhammad narrated on the authority of his father thus:I came to Jabir b. Abdullah and asked him about the (Farewell) Pilgrimage of Allah's Messenger (ﷺ). The rest of the hadith is the same, but with the addition of this:" There was one Abu Sayyara among the Arabs, (of pre-Islamic period) who carried (people from Muzdalifa to Mini). As the Messenger of Allah (May peace be upon him) set out from Muzdalifa to al-Mash'ar al-Haram, the Quraish were certain that he would halt there and that would be his station. But he passed on (without staying) there. and paid no heed to it till he came to 'Arafat and there he stayed}}
\hadithdefcmd{muslim}{2951}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ حَاتِمٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ الْمَدَنِيُّ، - عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، قَالَ دَخَلْنَا عَلَى جَابِرِ بْنِ عَبْدِ اللَّهِ فَسَأَلَ عَنِ الْقَوْمِ، حَتَّى انْتَهَى إِلَىَّ فَقُلْتُ أَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ حُسَيْنٍ، ‏.‏ فَأَهْوَى بِيَدِهِ إِلَى رَأْسِي فَنَزَعَ زِرِّي الأَعْلَى ثُمَّ نَزَعَ زِرِّي الأَسْفَلَ ثُمَّ وَضَعَ كَفَّهُ بَيْنَ ثَدْيَىَّ وَأَنَا يَوْمَئِذٍ غُلاَمٌ شَابٌّ فَقَالَ مَرْحَبًا بِكَ يَا ابْنَ أَخِي سَلْ عَمَّا شِئْتَ ‏.‏ فَسَأَلْتُهُ وَهُوَ أَعْمَى وَحَضَرَ وَقْتُ الصَّلاَةِ فَقَامَ فِي نِسَاجَةٍ مُلْتَحِفًا بِهَا كُلَّمَا وَضَعَهَا عَلَى مَنْكِبِهِ رَجَعَ طَرَفَاهَا إِلَيْهِ مِنْ صِغَرِهَا وَرِدَاؤُهُ إِلَى جَنْبِهِ عَلَى الْمِشْجَبِ فَصَلَّى بِنَا فَقُلْتُ أَخْبِرْنِي عَنْ حَجَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ بِيَدِهِ فَعَقَدَ تِسْعًا فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَكَثَ تِسْعَ سِنِينَ لَمْ يَحُجَّ ثُمَّ أَذَّنَ فِي النَّاسِ فِي الْعَاشِرَةِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَاجٌّ فَقَدِمَ الْمَدِينَةَ بَشَرٌ كَثِيرٌ كُلُّهُمْ يَلْتَمِسُ أَنْ يَأْتَمَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَيَعْمَلَ مِثْلَ عَمَلِهِ فَخَرَجْنَا مَعَهُ حَتَّى أَتَيْنَا ذَا الْحُلَيْفَةِ فَوَلَدَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ أَصْنَعُ قَالَ ‏"‏ اغْتَسِلِي وَاسْتَثْفِرِي بِثَوْبٍ وَأَحْرِمِي ‏"‏ ‏.‏ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ ثُمَّ رَكِبَ الْقَصْوَاءَ حَتَّى إِذَا اسْتَوَتْ بِهِ نَاقَتُهُ عَلَى الْبَيْدَاءِ نَظَرْتُ إِلَى مَدِّ بَصَرِي بَيْنَ يَدَيْهِ مِنْ رَاكِبٍ وَمَاشٍ وَعَنْ يَمِينِهِ مِثْلَ ذَلِكَ وَعَنْ يَسَارِهِ مِثْلَ ذَلِكَ وَمِنْ خَلْفِهِ مِثْلَ ذَلِكَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا وَعَلَيْهِ يَنْزِلُ الْقُرْآنُ وَهُوَ يَعْرِفُ تَأْوِيلَهُ وَمَا عَمِلَ بِهِ مِنْ شَىْءٍ عَمِلْنَا بِهِ فَأَهَلَّ بِالتَّوْحِيدِ ‏"‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ وَأَهَلَّ النَّاسُ بِهَذَا الَّذِي يُهِلُّونَ بِهِ فَلَمْ يَرُدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَيْهِمْ شَيْئًا مِنْهُ وَلَزِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم تَلْبِيَتَهُ قَالَ جَابِرٌ - رضى الله عنه - لَسْنَا نَنْوِي إِلاَّ الْحَجَّ لَسْنَا نَعْرِفُ الْعُمْرَةَ حَتَّى إِذَا أَتَيْنَا الْبَيْتَ مَعَهُ اسْتَلَمَ الرُّكْنَ فَرَمَلَ ثَلاَثًا وَمَشَى أَرْبَعًا ثُمَّ نَفَذَ إِلَى مَقَامِ إِبْرَاهِيمَ - عَلَيْهِ السَّلاَمُ - فَقَرَأَ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى‏\}‏ فَجَعَلَ الْمَقَامَ بَيْنَهُ وَبَيْنَ الْبَيْتِ فَكَانَ أَبِي يَقُولُ وَلاَ أَعْلَمُهُ ذَكَرَهُ إِلاَّ عَنِ النَّبِيِّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الرَّكْعَتَيْنِ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ وَ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ‏\}‏ ثُمَّ رَجَعَ إِلَى الرُّكْنِ فَاسْتَلَمَهُ ثُمَّ خَرَجَ مِنَ الْبَابِ إِلَى الصَّفَا فَلَمَّا دَنَا مِنَ الصَّفَا قَرَأَ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ‏\}‏ ‏"‏ أَبْدَأُ بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏ فَبَدَأَ بِالصَّفَا فَرَقِيَ عَلَيْهِ حَتَّى رَأَى الْبَيْتَ فَاسْتَقْبَلَ الْقِبْلَةَ فَوَحَّدَ اللَّهَ وَكَبَّرَهُ وَقَالَ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كَلِّ شَىْءٍ قَدِيرٌ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ أَنْجَزَ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏ ‏.‏ ثُمَّ دَعَا بَيْنَ ذَلِكَ قَالَ مِثْلَ هَذَا ثَلاَثَ مَرَّاتٍ ثُمَّ نَزَلَ إِلَى الْمَرْوَةِ حَتَّى إِذَا انْصَبَّتْ قَدَمَاهُ فِي بَطْنِ الْوَادِي سَعَى حَتَّى إِذَا صَعِدَتَا مَشَى حَتَّى أَتَى الْمَرْوَةَ فَفَعَلَ عَلَى الْمَرْوَةِ كَمَا فَعَلَ عَلَى الصَّفَا حَتَّى إِذَا كَانَ آخِرُ طَوَافِهِ عَلَى الْمَرْوَةِ فَقَالَ ‏"‏ لَوْ أَنِّي اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ لَمْ أَسُقِ الْهَدْىَ وَجَعَلْتُهَا عُمْرَةً فَمَنْ كَانَ مِنْكُمْ لَيْسَ مَعَهُ هَدْىٌ فَلْيَحِلَّ وَلْيَجْعَلْهَا عُمْرَةً ‏"‏ ‏.‏ فَقَامَ سُرَاقَةُ بْنُ مَالِكِ بْنِ جُعْشُمٍ فَقَالَ يَا رَسُولَ اللَّهِ أَلِعَامِنَا هَذَا أَمْ لأَبَدٍ فَشَبَّكَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَصَابِعَهُ وَاحِدَةً فِي الأُخْرَى وَقَالَ ‏"‏ دَخَلَتِ الْعُمْرَةُ فِي الْحَجِّ - مَرَّتَيْنِ - لاَ بَلْ لأَبَدٍ أَبَدٍ ‏"‏ ‏.‏ وَقَدِمَ عَلِيٌّ مِنَ الْيَمَنِ بِبُدْنِ النَّبِيِّ صلى الله عليه وسلم فَوَجَدَ فَاطِمَةَ - رضى الله عنها - مِمَّنْ حَلَّ وَلَبِسَتْ ثِيَابًا صَبِيغًا وَاكْتَحَلَتْ فَأَنْكَرَ ذَلِكَ عَلَيْهَا فَقَالَتْ إِنَّ أَبِي أَمَرَنِي بِهَذَا ‏.‏ قَالَ فَكَانَ عَلِيٌّ يَقُولُ بِالْعِرَاقِ فَذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مُحَرِّشًا عَلَى فَاطِمَةَ لِلَّذِي صَنَعَتْ مُسْتَفْتِيًا لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِيمَا ذَكَرَتْ عَنْهُ فَأَخْبَرْتُهُ أَنِّي أَنْكَرْتُ ذَلِكَ عَلَيْهَا فَقَالَ ‏"‏ صَدَقَتْ صَدَقَتْ مَاذَا قُلْتَ حِينَ فَرَضْتَ الْحَجَّ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُمَّ إِنِّي أُهِلُّ بِمَا أَهَلَّ بِهِ رَسُولُكَ ‏.‏ قَالَ ‏"‏ فَإِنَّ مَعِيَ الْهَدْىَ فَلاَ تَحِلُّ ‏"‏ ‏.‏ قَالَ فَكَانَ جَمَاعَةُ الْهَدْىِ الَّذِي قَدِمَ بِهِ عَلِيٌّ مِنَ الْيَمَنِ وَالَّذِي أَتَى بِهِ النَّبِيُّ صلى الله عليه وسلم مِائَةً - قَالَ - فَحَلَّ النَّاسُ كُلُّهُمْ وَقَصَّرُوا إِلاَّ النَّبِيَّ صلى الله عليه وسلم وَمَنْ كَانَ مَعَهُ هَدْىٌ فَلَمَّا كَانَ يَوْمُ التَّرْوِيَةِ تَوَجَّهُوا إِلَى مِنًى فَأَهَلُّوا بِالْحَجِّ وَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى بِهَا الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ وَالْفَجْرَ ثُمَّ مَكَثَ قَلِيلاً حَتَّى طَلَعَتِ الشَّمْسُ وَأَمَرَ بِقُبَّةٍ مِنْ شَعَرٍ تُضْرَبُ لَهُ بِنَمِرَةَ فَسَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ تَشُكُّ قُرَيْشٌ إِلاَّ أَنَّهُ وَاقِفٌ عِنْدَ الْمَشْعَرِ الْحَرَامِ كَمَا كَانَتْ قُرَيْشٌ تَصْنَعُ فِي الْجَاهِلِيَّةِ فَأَجَازَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَتَى عَرَفَةَ فَوَجَدَ الْقُبَّةَ قَدْ ضُرِبَتْ لَهُ بِنَمِرَةَ فَنَزَلَ بِهَا حَتَّى إِذَا زَاغَتِ الشَّمْسُ أَمَرَ بِالْقَصْوَاءِ فَرُحِلَتْ لَهُ فَأَتَى بَطْنَ الْوَادِي فَخَطَبَ النَّاسَ وَقَالَ ‏"‏ إِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ حَرَامٌ عَلَيْكُمْ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا أَلاَ كُلُّ شَىْءٍ مِنْ أَمْرِ الْجَاهِلِيَّةِ تَحْتَ قَدَمَىَّ مَوْضُوعٌ وَدِمَاءُ الْجَاهِلِيَّةِ مَوْضُوعَةٌ وَإِنَّ أَوَّلَ دَمٍ أَضَعُ مِنْ دِمَائِنَا دَمُ ابْنِ رَبِيعَةَ بْنِ الْحَارِثِ كَانَ مُسْتَرْضِعًا فِي بَنِي سَعْدٍ فَقَتَلَتْهُ هُذَيْلٌ وَرِبَا الْجَاهِلِيَّةِ مَوْضُوعٌ وَأَوَّلُ رِبًا أَضَعُ رِبَانَا رِبَا عَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ فَإِنَّهُ مَوْضُوعٌ كُلُّهُ فَاتَّقُوا اللَّهَ فِي النِّسَاءِ فَإِنَّكُمْ أَخَذْتُمُوهُنَّ بِأَمَانِ اللَّهِ وَاسْتَحْلَلْتُمْ فُرُوجَهُنَّ بِكَلِمَةِ اللَّهِ وَلَكُمْ عَلَيْهِنَّ أَنْ لاَ يُوطِئْنَ فُرُشَكُمْ أَحَدًا تَكْرَهُونَهُ ‏.‏ فَإِنْ فَعَلْنَ ذَلِكَ فَاضْرِبُوهُنَّ ضَرْبًا غَيْرَ مُبَرِّحٍ وَلَهُنَّ عَلَيْكُمْ رِزْقُهُنَّ وَكِسْوَتُهُنَّ بِالْمَعْرُوفِ وَقَدْ تَرَكْتُ فِيكُمْ مَا لَنْ تَضِلُّوا بَعْدَهُ إِنِ اعْتَصَمْتُمْ بِهِ كِتَابَ اللَّهِ ‏.‏ وَأَنْتُمْ تُسْأَلُونَ عَنِّي فَمَا أَنْتُمْ قَائِلُونَ ‏"‏ ‏.‏ قَالُوا نَشْهَدُ أَنَّكَ قَدْ بَلَّغْتَ وَأَدَّيْتَ وَنَصَحْتَ ‏.‏ فَقَالَ بِإِصْبَعِهِ السَّبَّابَةِ يَرْفَعُهَا إِلَى السَّمَاءِ وَيَنْكُتُهَا إِلَى النَّاسِ ‏"‏ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ثُمَّ أَذَّنَ ثُمَّ أَقَامَ فَصَلَّى الظُّهْرَ ثُمَّ أَقَامَ فَصَلَّى الْعَصْرَ وَلَمْ يُصَلِّ بَيْنَهُمَا شَيْئًا ثُمَّ رَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَتَى الْمَوْقِفَ فَجَعَلَ بَطْنَ نَاقَتِهِ الْقَصْوَاءِ إِلَى الصَّخَرَاتِ وَجَعَلَ حَبْلَ الْمُشَاةِ بَيْنَ يَدَيْهِ وَاسْتَقْبَلَ الْقِبْلَةَ فَلَمْ يَزَلْ وَاقِفًا حَتَّى غَرَبَتِ الشَّمْسُ وَذَهَبَتِ الصُّفْرَةُ قَلِيلاً حَتَّى غَابَ الْقُرْصُ وَأَرْدَفَ أُسَامَةَ خَلْفَهُ وَدَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ شَنَقَ لِلْقَصْوَاءِ الزِّمَامَ حَتَّى إِنَّ رَأْسَهَا لَيُصِيبُ مَوْرِكَ رَحْلِهِ وَيَقُولُ بِيَدِهِ الْيُمْنَى ‏"‏ أَيُّهَا النَّاسُ السَّكِينَةَ السَّكِينَةَ ‏"‏ ‏.‏ كُلَّمَا أَتَى حَبْلاً مِنَ الْحِبَالِ أَرْخَى لَهَا قَلِيلاً حَتَّى تَصْعَدَ حَتَّى أَتَى الْمُزْدَلِفَةَ فَصَلَّى بِهَا الْمَغْرِبَ وَالْعِشَاءَ بِأَذَانٍ وَاحِدٍ وَإِقَامَتَيْنِ وَلَمْ يُسَبِّحْ بَيْنَهُمَا شَيْئًا ثُمَّ اضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى طَلَعَ الْفَجْرُ وَصَلَّى الْفَجْرَ - حِينَ تَبَيَّنَ لَهُ الصُّبْحُ - بِأَذَانٍ وَإِقَامَةٍ ثُمَّ رَكِبَ الْقَصْوَاءَ حَتَّى أَتَى الْمَشْعَرَ الْحَرَامَ فَاسْتَقْبَلَ الْقِبْلَةَ فَدَعَاهُ وَكَبَّرَهُ وَهَلَّلَهُ وَوَحَّدَهُ فَلَمْ يَزَلْ وَاقِفًا حَتَّى أَسْفَرَ جِدًّا فَدَفَعَ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ وَأَرْدَفَ الْفَضْلَ بْنَ عَبَّاسٍ وَكَانَ رَجُلاً حَسَنَ الشَّعْرِ أَبْيَضَ وَسِيمًا فَلَمَّا دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَرَّتْ بِهِ ظُعُنٌ يَجْرِينَ فَطَفِقَ الْفَضْلُ يَنْظُرُ إِلَيْهِنَّ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ عَلَى وَجْهِ الْفَضْلِ فَحَوَّلَ الْفَضْلُ وَجْهَهُ إِلَى الشِّقِّ الآخَرِ يَنْظُرُ فَحَوَّلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ مِنَ الشِّقِّ الآخَرِ عَلَى وَجْهِ الْفَضْلِ يَصْرِفُ وَجْهَهُ مِنَ الشِّقِّ الآخَرِ يَنْظُرُ حَتَّى أَتَى بَطْنَ مُحَسِّرٍ فَحَرَّكَ قَلِيلاً ثُمَّ سَلَكَ الطَّرِيقَ الْوُسْطَى الَّتِي تَخْرُجُ عَلَى الْجَمْرَةِ الْكُبْرَى حَتَّى أَتَى الْجَمْرَةَ الَّتِي عِنْدَ الشَّجَرَةِ فَرَمَاهَا بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ مِنْهَا مِثْلِ حَصَى الْخَذْفِ رَمَى مِنْ بَطْنِ الْوَادِي ثُمَّ انْصَرَفَ إِلَى الْمَنْحَرِ فَنَحَرَ ثَلاَثًا وَسِتِّينَ بِيَدِهِ ثُمَّ أَعْطَى عَلِيًّا فَنَحَرَ مَا غَبَرَ وَأَشْرَكَهُ فِي هَدْيِهِ ثُمَّ أَمَرَ مِنْ كُلِّ بَدَنَةٍ بِبَضْعَةٍ فَجُعِلَتْ فِي قِدْرٍ فَطُبِخَتْ فَأَكَلاَ مِنْ لَحْمِهَا وَشَرِبَا مِنْ مَرَقِهَا ثُمَّ رَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَفَاضَ إِلَى الْبَيْتِ فَصَلَّى بِمَكَّةَ الظُّهْرَ فَأَتَى بَنِي عَبْدِ الْمُطَّلِبِ يَسْقُونَ عَلَى زَمْزَمَ فَقَالَ ‏"‏ انْزِعُوا بَنِي عَبْدِ الْمُطَّلِبِ فَلَوْلاَ أَنْ يَغْلِبَكُمُ النَّاسُ عَلَى سِقَايَتِكُمْ لَنَزَعْتُ مَعَكُمْ ‏"‏ ‏.‏ فَنَاوَلُوهُ دَلْوًا فَشَرِبَ مِنْهُ ‏.‏\hadithno{2951}\hadithtrans{Ja'far b Muhammad reported on the authority of his father:We went to Jabir b. Abdullah and he began inquiring about the people (who had gone to see him) till it was my turn. I said: I am Muhammad b. 'Ali b. Husain. He placed his hand upon my head and opened my upper button and then the lower one and then placed his palm on my chest (in order to bless me), and I was, during those days, a young boy, and he said: You are welcome, my nephew. Ask whatever you want to ask. And I asked him but as he was blind (he could not respond to me immediately), and the time for prayer came. He stood up covering himself in his mantle. And whenever he placed its ends upon his shoulders they slipped down on account of being short (in size). Another mantle was, however, lying on the clothes rack near by. And he led us in the prayer. I said to him: Tell me about the Hajj of Allah's Messenger (May peace be upon him). And he pointed with his hand nine, and then stated: The Messenger of Allah (ﷺ) stayed in (Medina) for nine years but did not perform Hajj, then he made a public announcement in the tenth year to the effect that Allah's Messenger (ﷺ) was about to perform the Hajj. A large number of persons came to Medina and all of them were anxious to follow the Messenger of Allah (May peace be upon him) and do according to his doing. We set out with him till we reached Dhu'l-Hulaifa. Asma' daughter of Umais gave birth to Muhammad b. Abu Bakr. She sent message to the Messenger of Allah (May peace be upon him) asking him: What should 1 do? He (the Holy Prophet) said: Take a bath, bandage your private parts and put on Ihram. The Messenger of Allah (May peace be upon him) then prayed in the mosque and then mounted al-Qaswa (his she-camel) and it stood erect with him on its back at al-Baida'. And I saw as far as I could see in front of me but riders and pedestrians, and also on my right and on my left and behind me like this. And the Messenger of Allah (ﷺ) was prominent among us and the (revelation) of the Holy Qur'an was descending upon him. And it is he who knows (its true) significance. And whatever he did, we also did that. He pronounced the Oneness of Allah (saying):" Labbaik,0 Allah, Labbaik, Labbaik. Thou hast no partner, praise and grace is Thine and the Sovereignty too; Thou hast no partner." And the people also pronounced this Talbiya which they pronounce (today). The Messenger of Allah (May peace be upon him) did not reject anything out of it. But the Messenger of Allah (May peace. be upon him) adhered to his own Talbiya. Jabir (Allah be pleased with him) said: We did not have any other intention but that of Hajj only, being unaware of the Umra (at that season), but when we came with him to the House, he touched the pillar and (made seven circuits) running three of them and walking four. And then going to the Station of Ibrahim, he recited:" And adopt the Station of Ibrahim as a place of prayer." And this Station was between him and the House. My father said (and I do not know whether he had made a mention of it but that was from Allah's Apostle [May peace be upon him] that he recited in two rak'ahs:" say: He is Allah One," and say:" Say: 0 unbelievers." He then returned to the pillar (Hajar Aswad) and kissed it. He then went out of the gate to al-Safa' and as he reached near it he recited:" Al-Safa' and al-Marwa are among the signs appointed by Allah," (adding: ) I begin with what Allah (has commanded me) to begin. He first mounted al-Safa' till he saw the House, and facing Qibla he declared the Oneness of Allah and glorified Him, and said:" There is no god but Allah, One, there is no partner with Him. His is the Sovereignty. to Him praise is due. and He is Powerful over everything. There is no god but Allah alone, Who fulfilled His promise, helped His servant and routed the confederates alone." He then made supplication in the course of that saying such words three times. He then descended and walked towards al-Marwa, and when his feet came down in the bottom of the valley, he ran, and when he began to ascend he walked till he reached al-Marwa. There he did as he had done at al-Safa'. And when it was his last running at al-Marwa he said: If I had known beforehand what I have come to know afterwards, I would not have brought sacrificial animals and would have performed an 'Umra. So, he who among you has not the sacrificial animals with him should put off Ihram and treat it as an Umra. Suraqa b. Malik b. Ju'sham got up and said: Messenger of Allah, does it apply to the present year, or does it apply forever? Thereupon the Messenger of Allah (May peace be upon him) intertwined the fingers (of one hand) into another and said twice: The 'Umra has become incorporated in the Hajj (adding):" No, but for ever and ever." 'All came from the Yemen with the sacrificial animals for the Prophet (May peace be upon him) and found Fatimah (Allah be pleased with her) to be one among those who had put off Ihram and had put on dyed clothes and had applied antimony. He (Hadrat'Ali) showed disapproval to it, whereupon she said: My father has commanded me to do this. He (the narrator) said that 'Ali used to say in Iraq: I went to the Messenger of Allah (ﷺ) showing annoyance at Fatimah for what she had done, and asked the (verdict) of Allah's Messenger (ﷺ) regarding what she had narrated from him, and told him that I was angry with her, whereupon he said: She has told the truth, she has told the truth. (The Prophet then asked 'Ali): What did you say when you undertook to go for Hajj? I ('Ali) said: 0 Allah, I am putting on Ihram for the same purpose as Thy Messenger has put it on. He said: I have with me sacrificial animals, so do not put off the Ihram. He (Jabir) said: The total number of those sacrificial animals brought by 'Ali from the Yemen and of those brought by the Apostle (ﷺ) was one hundred. Then all the people except the Apostle (ﷺ) and those who had with them sacrificial animals, put off Ihram, and got their hair clipped; when it was the day of Tarwiya (8th of Dhu'l-Hijja) they went to Mina and put on the Ihram for Hajj and the Messenger of Ailah (ﷺ) rode and led the noon, afternoon, sunset 'Isha' and dawn prayers. He then waited a little till the sun rose, and commanded that a tent of hair should be pitched at Namira. The Messenger of Allah (ﷺ) then set out and the Quraish did not doubt that he would halt at al-Mash'ar al-Haram (the sacred site) as the Quraish used to do in the pre-Islamic period. The Messenger of Allah (ﷺ), however, passed on till he came to 'Arafa and he found that the tent had been pitched for him at Namira. There he got down till the sun had passed the meridian; he commanded that al-Qaswa should be brought and saddled for him. Then he came to the bottom of the valley, and addressed the people saying: Verily your blood, your property are as sacred and inviolable as the sacredness of this day of yours, in this month of yours, in this town of yours. Behold! Everything pertaining to the Days of Ignorance is under my feet completely abolished. Abolished are also the blood-revenges of the Days of Ignorance. The first claim of ours on blood-revenge which I abolish is that of the son of Rabi'a b. al-Harith, who was nursed among the tribe of Sa'd and killed by Hudhail. And the usury of she pre-Islamic period is abolished, and the first of our usury I abolish is that of 'Abbas b. 'Abd al-Muttalib, for it is all abolished. Fear Allah concerning women! Verily you have taken them on the security of Allah, and intercourse with them has been made lawful unto you by words of Allah. You too have right over them, and that they should not allow anyone to sit on your bed whom you do not like. But if they do that, you can chastise them but not severely. Their rights upon you are that you should provide them with food and clothing in a fitting manner. I have left among you the Book of Allah, and if you hold fast to it, you would never go astray. And you would be asked about me (on the Day of Resurrection), (now tell me) what would you say? They (the audience) said: We will bear witness that you have conveyed (the message), discharged (the ministry of Prophethood) and given wise (sincere) counsel. He (the narrator) said: He (the Holy Prophet) then raised his forefinger towards the sky and pointing it at the people (said):" O Allah, be witness. 0 Allah, be witness," saying it thrice. (Bilal then) pronounced Adhan and later on Iqama and he (the Holy Prophet) led the noon prayer. He (Bilal) then uttered Iqama and he (the Holy Prophet) led the afternoon prayer and he observed no other prayer in between the two. The Messenger of Allah (ﷺ) then mounted his camel and came to the place of stay, making his she-camel al-Qaswa, turn towards the side where there we are rocks, having the path taken by those who went on foot in front of him, and faced the Qibla. He kept standing there till the sun set, and the yellow light had somewhat gone, and the disc of the sun had disappeared. He made Usama sit behind him, and he pulled the nosestring of Qaswa so forcefully that its head touched the saddle (in order to keep her under perfect control), and he pointed out to the people with his right hand to be moderate (in speed), and whenever he happened to pass over an elevated tract of sand, he slightly loosened it (the nose-string of his camel) till she climbed up and this is how he reached al-Muzdalifa. There he led the evening and 'Isha prayers with one Adhan and two Iqamas and did not glorify (Allah) in between them (i. e. he did not observe supererogatory rak'ahs between Maghrib and 'Isha' prayers). The Messenger of Allah (ﷺ) then lay down till dawn and offered the dawn prayer with an Adhan and Iqama when the morning light was clear. He again mounted al-Qaswa, and when he came to al-Mash'ar al-Haram, he faced towards Qibla, supplicated Him, Glorified Him, and pronounced His Uniqueness (La ilaha illa Allah) and Oneness, and kept standing till the daylight was very clear. He then went quickly before the sun rose, and seated behind him was al-Fadl b. 'Abbas and he was a man having beautiful hair and fair complexion and handsome face. As the Messenger of Allah (May peace be upon him) was moving on, there was also going a group of women (side by side with them). Al-Fadl began to look at them. The Messenger of Allah (ﷺ) placed his hand on the face of Fadl who then turned his face to the other side, and began to see, and the Messenger of Allah (ﷺ) turned his hand to the other side and placed it on the face of al-Fadl. He again turned his face to the other side till he came to the bottom of Muhassir. 1680 He urged her (al-Qaswa) a little, and, following the middle road, which comes out at the greatest jamra, he came to the jamra which is near the tree. At this be threw seven small pebbles, saying Allah-o-Akbar while throwing every one of them in a manner in which the small pebbles are thrown (with the help of fingers) and this he did in the bottom of the valley. He then went to the place of sacrifice, and sacrificed sixty-three (camels) with his own hand. Then he gave the remaining number to 'All who sacrificed them, and he shared him in his sacrifice. He then commanded that a piece of flesh from each animal sacrificed should be put in a pot, and when it was cooked, both of them (the Prophet and Hadrat 'All) took some meat out of it and drank its soup. The Messenger of Allah (May peace be upon him) again rode and came to the House, and offered the Zuhr prayer at Mecca. He came to the tribe of Abd al-Muttalib, who were supplying water at Zamzam, and said: Draw water. O Bani 'Abd al-Muttalib; were it not that people would usurp this right of supplying water from you, I would have drawn it along with you. So they handed him a basket and he drank from it}}
\hadithdefcmd{muslim}{2952}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنْ جَعْفَرٍ، حَدَّثَنِي أَبِي، عَنْ جَابِرٍ، فِي حَدِيثِهِ ذَلِكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نَحَرْتُ هَا هُنَا وَمِنًى كُلُّهَا مَنْحَرٌ فَانْحَرُوا فِي رِحَالِكُمْ وَوَقَفْتُ هَا هُنَا وَعَرَفَةُ كُلُّهَا مَوْقِفٌ وَوَقَفْتُ هَا هُنَا وَجَمْعٌ كُلُّهَا مَوْقِفٌ ‏"‏ ‏.‏\hadithno{2952}\hadithtrans{Jabir reported Allah's Messenger (May peace be upon him) as saying:I have sacrificed (the animals) here, and the whole of Mini is a place for sacrifice; so sacrifice your animals at your places. 1 have stayed here (near these rocks), and the whole of Arafat is a place for stay. And I have stayed here (at Muzdalifa near Mash'ar al-Haram and the whole of Muzdalifa) is a place for stay (i. e. one is permitted to spend night in any part of it, as one likes)}}
\hadithdefcmd{muslim}{2953}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ جَعْفَرِ بْنِ، مُحَمَّدٍ عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا قَدِمَ مَكَّةَ أَتَى الْحَجَرَ فَاسْتَلَمَهُ ثُمَّ مَشَى عَلَى يَمِينِهِ فَرَمَلَ ثَلاَثًا وَمَشَى أَرْبَعًا ‏\hadithno{2953}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported that when Allah's Messenger (ﷺ) proceeded to Mecca, he came to it (the Black Stone). he kissed it. and moved to his right. and moved quickly in three circuits, and walked in four circuits}}
\hadithdefcmd{muslim}{2954}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ قُرَيْشٌ وَمَنْ دَانَ دِينَهَا يَقِفُونَ بِالْمُزْدَلِفَةِ وَكَانُوا يُسَمَّوْنَ الْحُمْسَ وَكَانَ سَائِرُ الْعَرَبِ يَقِفُونَ بِعَرَفَةَ فَلَمَّا جَاءَ الإِسْلاَمُ أَمَرَ اللَّهُ عَزَّ وَجَلَّ نَبِيَّهُ صلى الله عليه وسلم أَنْ يَأْتِيَ عَرَفَاتٍ فَيَقِفَ بِهَا ثُمَّ يُفِيضَ مِنْهَا فَذَلِكَ قَوْلُهُ عَزَّ وَجَلَّ ‏\{‏ ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ‏\}‏\hadithno{2954}\hadithtrans{A'isha (Allah be pleased with her) reported that the Quraish (of the pre-Islamic days) and those who followed their religions practices stayed at Muzdalifa, and they named themselves as Hums, whereas all other Arabs stayed at 'Arafa. With the advent of Islam, Allah, the Exalted and Glorious, commanded His Apostle (ﷺ) to come to 'Arafat and stay there, and then hurry from there, and this is the significance of the words of Allah:" Then hasten on from where the people hasten on}}
\hadithdefcmd{muslim}{2955}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، قَالَ كَانَتِ الْعَرَبُ تَطُوفُ بِالْبَيْتِ عُرَاةً إِلاَّ الْحُمْسَ وَالْحُمْسُ قُرَيْشٌ وَمَا وَلَدَتْ كَانُوا يَطُوفُونَ عُرَاةً إِلاَّ أَنْ تُعْطِيَهُمُ الْحُمْسُ ثِيَابًا فَيُعْطِي الرِّجَالُ الرِّجَالَ وَالنِّسَاءُ النِّسَاءَ وَكَانَتِ الْحُمْسُ لاَ يَخْرُجُونَ مِنَ الْمُزْدَلِفَةِ وَكَانَ النَّاسُ كُلُّهُمْ يَبْلُغُونَ عَرَفَاتٍ ‏.‏ قَالَ هِشَامٌ فَحَدَّثَنِي أَبِي عَنْ عَائِشَةَ - رضى الله عنها - قَالَتِ الْحُمْسُ هُمُ الَّذِينَ أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِيهِمْ ‏\{‏ ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ‏\}‏ قَالَتْ كَانَ النَّاسُ يُفِيضُونَ مِنْ عَرَفَاتٍ وَكَانَ الْحُمْسُ يُفِيضُونَ مِنَ الْمُزْدَلِفَةِ يَقُولُونَ لاَ نُفِيضُ إِلاَّ مِنَ الْحَرَمِ فَلَمَّا نَزَلَتْ ‏\{‏ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ‏\}‏ رَجَعُوا إِلَى عَرَفَاتٍ ‏.‏\hadithno{2955}\hadithtrans{Hisham narrated on the authority of his father that the Arabs with the exception of Hums who were Quraish, and their descendants, circumambulated the House naked. They kept circumambulating In this state of nudity unless the Hums supplied to them the clothes. The male provided (clothes) to the male and the female provided clothes to the female. And the Hums did not get out of Muzdalifa, whereas the people (other than the Quraish) went t o 'Arafat. Hisham said on the authority of his father who related from 'A'isha (Allah be pleased with her) who said:Hums are those about whom Allah, the Exalted and Glorious, revealed this verse:" Then hasten to where the people hasten." She (further) said: The people hastened on from 'Arafat, whereas Hums hastened from Muzdalifa, and said: We'do not hasten but from Haram. But when this (verse) was revealed:" Hasten on from that (place) where the people hasten on," they (the Quraish) then went to 'Arafat}}
\hadithdefcmd{muslim}{2956}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ عَمْرٍو، سَمِعَ مُحَمَّدَ بْنَ جُبَيْرِ بْنِ مُطْعِمٍ، يُحَدِّثُ عَنْ أَبِيهِ، جُبَيْرِ بْنِ مُطْعِمٍ قَالَ أَضْلَلْتُ بَعِيرًا لِي فَذَهَبْتُ أَطْلُبُهُ يَوْمَ عَرَفَةَ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَاقِفًا مَعَ النَّاسِ بِعَرَفَةَ فَقُلْتُ وَاللَّهِ إِنَّ هَذَا لَمِنَ الْحُمْسِ فَمَا شَأْنُهُ هَا هُنَا وَكَانَتْ قُرَيْشٌ تُعَدُّ مِنَ الْحُمْسِ ‏.‏\hadithno{2956}\hadithtrans{Jubair. b. Mut'im reported:I lost my camel and went in search of it on the day of 'Arafa, and I saw the Messenger of Allah (ﷺ) staying along with people in 'Ara'fit. Thereupon I said: By Allah, he is among the Hums (Quraish) ; what has happened to him that he has come to this (place)? The Quraish were counted among Hums}}
\hadithdefcmd{muslim}{2957}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُنِيخٌ بِالْبَطْحَاءِ فَقَالَ لِي ‏"‏ أَحَجَجْتَ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ ‏"‏ بِمَ أَهْلَلْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ لَبَّيْكَ بِإِهْلاَلٍ كَإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ فَقَدْ أَحْسَنْتَ طُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ وَأَحِلَّ ‏"‏ ‏.‏ قَالَ فَطُفْتُ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ أَتَيْتُ امْرَأَةً مِنْ بَنِي قَيْسٍ فَفَلَتْ رَأْسِي ثُمَّ أَهْلَلْتُ بِالْحَجِّ ‏.‏ قَالَ فَكُنْتُ أُفْتِي بِهِ النَّاسَ حَتَّى كَانَ فِي خِلاَفَةِ عُمَرَ - رضى الله عنه - فَقَالَ لَهُ رَجُلٌ يَا أَبَا مُوسَى - أَوْ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ - رُوَيْدَكَ بَعْضَ فُتْيَاكَ فَإِنَّكَ لاَ تَدْرِي مَا أَحْدَثَ أَمِيرُ الْمُؤْمِنِينَ فِي النُّسُكِ بَعْدَكَ ‏.‏ فَقَالَ يَا أَيُّهَا النَّاسُ مَنْ كُنَّا أَفْتَيْنَاهُ فُتْيَا فَلْيَتَّئِدْ فَإِنَّ أَمِيرَ الْمُؤْمِنِينَ قَادِمٌ عَلَيْكُمْ فَبِهِ فَائْتَمُّوا ‏.‏ قَالَ فَقَدِمَ عُمَرُ - رضى الله عنه - فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ إِنْ نَأْخُذْ بِكِتَابِ اللَّهِ فَإِنَّ كِتَابَ اللَّهِ يَأْمُرُ بِالتَّمَامِ وَإِنْ نَأْخُذْ بِسُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَحِلَّ حَتَّى بَلَغَ الْهَدْىُ مَحِلَّهُ ‏.‏\hadithno{2957}\hadithtrans{Abu Musa (Allah be pleased with him) said:I came to the Messenger of Allah (ﷺ) as he was encamping at Batha. He said to me: Did you intend to perform Hajj? I said: Yes. He again said: With what intention have you entered into the state of Ihram (for Ifrad, Qiran or Tamattu'). I said: I pronounced Talbiya (I have entered into the state of Ihram ) with that very aim with which the Messenger of Allah (ﷺ) is pronouncing Talbiya. He (the Holy Prophet) said; You have done well. Then circumambulate the House and run between al-Safa' and al-Marwa' and put off Ihram (as you have not brought the sacrificial animals along with you). So I circumambulated the House, and ran between al-Safa' and al-Marwa' and then came to a woman of the tribe of Qais and she rid my head of the lice. I again put on Ihram for Hajj. and continued giving religious verdict (according to this practice) till during the Caliphate of Umar (Allah be pleased with him) when a person said to him: Abu Musa, or Abdullah b. Qais, exercise restraint in delivering some religious verdict of yours, for you do not know what has been introduced after you by the Commander of the Believers in the rites (of Hajj). Thereupon he said: 0 people, whom we gave the religious verdict (concerning putting off Ihram ) they should wait, for the Commander of the Believers is about to come to you, and you should follow him. Umar (Allah be pleased with him) then came and I made a mention of it to him. whereupon he said: If we abide by the Book of Allah (we find) the Book of Allah has commanded us to complete the (. Hajj and 'Umra), and if we abide by the Sunnah of Allah's Messenger (ﷺ), we find that Allah's Messenger (ﷺ) did not put off Ihram till the sacrificial animal was brought to its end (till it was sacrificed)}}
\hadithdefcmd{muslim}{2958}{وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2958}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2959}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا سُفْيَانُ، عَنْ قَيْسٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى، - رضى الله عنه - قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُنِيخٌ بِالْبَطْحَاءِ فَقَالَ ‏"‏ بِمَ أَهْلَلْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ أَهْلَلْتُ بِإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ هَلْ سُقْتَ مِنْ هَدْىٍ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَطُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ حِلَّ ‏"‏ ‏.‏ فَطُفْتُ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ أَتَيْتُ امْرَأَةً مِنْ قَوْمِي فَمَشَطَتْنِي وَغَسَلَتْ رَأْسِي فَكُنْتُ أُفْتِي النَّاسَ بِذَلِكَ فِي إِمَارَةِ أَبِي بَكْرٍ وَإِمَارَةِ عُمَرَ فَإِنِّي لَقَائِمٌ بِالْمَوْسِمِ إِذْ جَاءَنِي رَجُلٌ فَقَالَ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثَ أَمِيرُ الْمُؤْمِنِينَ فِي شَأْنِ النُّسُكِ ‏.‏ فَقُلْتُ أَيُّهَا النَّاسُ مَنْ كُنَّا أَفْتَيْنَاهُ بِشَىْءٍ فَلْيَتَّئِدْ فَهَذَا أَمِيرُ الْمُؤْمِنِينَ قَادِمٌ عَلَيْكُمْ فَبِهِ فَائْتَمُّوا فَلَمَّا قَدِمَ قُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَا هَذَا الَّذِي أَحْدَثْتَ فِي شَأْنِ النُّسُكِ قَالَ إِنْ نَأْخُذْ بِكِتَابِ اللَّهِ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَالَ ‏\{‏ وَأَتِمُّوا الْحَجَّ وَالْعُمْرَةَ لِلَّهِ‏\}‏ وَإِنْ نَأْخُذْ بِسُنَّةِ نَبِيِّنَا عَلَيْهِ الصَّلاَةُ وَالسَّلاَمُ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَحِلَّ حَتَّى نَحَرَ الْهَدْىَ ‏.‏\hadithno{2959}\hadithtrans{Abu Musa (Allah be pleased with him) reported:I came to the Messenger of Allah (ﷺ) and he was encamping at Batha. He (the Holy Prophet) said: With what purpose have you entered into the state of Ihram? I said: I have entered into the state of Ihram in accordance with the Ihram of Allah's Apostle (ﷺ). He said: Have you brought sacrificial animals along with you? I said: No. whereupon he said: Then circumambulate the House and run between al-Safa' and al-Marwa and put off Ihram. So I circumambulated the House, ran between al-Safa' and al-Marwa, and then came to a woman of my tribe. She combed and washed my head. I used to give religious verdict (according to the above mentioned command of the Holy Prophet) during the Caliphate of Abu Bakr and also during that of 'Umar. And it was during the Hajj season that a person came to me and said: You (perhaps) do not know what the Commander of the Believers has introduced in the rites (of Hajj). I said: 0 people, those whom we have given religious verdict about a certain thing should wait, for the Commander of the Believers is about to arrive among you, so follow him. When the Commander of the Believers arrived, I said: What is this that you have introduced in the rites (of Hajj)? -where upon he said: If we abide by the Book of Allah (we find) that there Allah, Exalted and Majestic, has said: Complete Hajj and 'Umra for Allah." And if we abide by the Sunnah of our Apostle (ﷺ) (we find) that the Messenger of Allah (May peace be upon him) did not put off Ihram till he had sacrificed the animals}}
\hadithdefcmd{muslim}{2960}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا جَعْفَرُ بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عُمَيْسٍ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى، - رضى الله عنه - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعَثَنِي إِلَى الْيَمَنِ قَالَ فَوَافَقْتُهُ فِي الْعَامِ الَّذِي حَجَّ فِيهِ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا مُوسَى كَيْفَ قُلْتَ حِينَ أَحْرَمْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ لَبَّيْكَ إِهْلاَلاً كَإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏"‏ هَلْ سُقْتَ هَدْيًا ‏"‏ ‏.‏ فَقُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَانْطَلِقْ فَطُفْ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏ ثُمَّ أَحِلَّ ‏"‏ ‏.‏ ثُمَّ سَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ شُعْبَةَ وَسُفْيَانَ ‏.‏\hadithno{2960}\hadithtrans{Abu Musa (Allah be pleased with him) reported:The Messenger of Allah (May peace be upon im) had sent me to Yemen and I came back In the year in which he (the Holy Prophet) performed the (Farewell) Pilgrimage. Allah's Messenger (may peace be upon, him) said to me: Abu Musa, what did you ' say when you entered into the state of Ihram? I said: At thy beck and call; my (Ihram) is that of the Ihram of Allah's Apostle (May peace be upon him). He said: Have you brought the sacrificial animals? I said: No. Thereupon he said: Go and circumambulate the House, and (run) between al-Safa' and al-Marwa and then put off Ihram. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2961}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي مُوسَى، عَنْ أَبِي مُوسَى، أَنَّهُ كَانَ يُفْتِي بِالْمُتْعَةِ فَقَالَ لَهُ رَجُلٌ رُوَيْدَكَ بِبَعْضِ فُتْيَاكَ فَإِنَّكَ لاَ تَدْرِي مَا أَحْدَثَ أَمِيرُ الْمُؤْمِنِينَ فِي النُّسُكِ بَعْدُ حَتَّى لَقِيَهُ بَعْدُ فَسَأَلَهُ فَقَالَ عُمَرُ قَدْ عَلِمْتُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ فَعَلَهُ وَأَصْحَابُهُ وَلَكِنْ كَرِهْتُ أَنْ يَظَلُّوا مُعْرِسِينَ بِهِنَّ فِي الأَرَاكِ ثُمَّ يَرُوحُونَ فِي الْحَجِّ تَقْطُرُ رُءُوسُهُمْ ‏.‏\hadithno{2961}\hadithtrans{Abu Musa, (Allah be pleased with him) reported that he used to deliver religious verdict in favor of Hajj Tamattu'. A person said to him:Exercise restraint in delivering some of your religious verdicts, for you do not know what the Commander of Believers has introduced in the rites (of Hajj) after you (when you were away in Yemen). He (Abu Musa, ) met him (Hadrat Umar) subsequently and asked him (about it), whereupon 'Umar said: I know that Allah's Apostle (May peace be upon him) and also his Companions did that (observed Tamattu'), but I do not approve that the married persons should have intercourse with their wives under the shade of the trees, and then set out for Hajj with water trickling down from their heads}}
\hadithdefcmd{muslim}{2962}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ شَقِيقٍ كَانَ عُثْمَانُ يَنْهَى عَنِ الْمُتْعَةِ، وَكَانَ، عَلِيٌّ يَأْمُرُ بِهَا فَقَالَ عُثْمَانُ لِعَلِيٍّ كَلِمَةً ثُمَّ قَالَ عَلِيٌّ لَقَدْ عَلِمْتَ أَنَّا قَدْ تَمَتَّعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَجَلْ وَلَكِنَّا كُنَّا خَائِفِينَ ‏.‏\hadithno{2962}\hadithtrans{Abdullah b. Shaqiq reported that 'Uthman (Allah be pleased with him) used to forbid Tamattu', whereas 'Ali (Allah be pleased with him) ordered to do it. 'Uthman said a word to 'Ali, but 'Ali said:You know that we used to perform Tamattu' with the Messenger of Allah (ﷺ), whereupon he said: It is right, but we entertained fear}}
\hadithdefcmd{muslim}{2963}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - أَخْبَرَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{2963}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2964}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ اجْتَمَعَ عَلِيٌّ وَعُثْمَانُ - رضى الله عنهما - بِعُسْفَانَ فَكَانَ عُثْمَانُ يَنْهَى عَنِ الْمُتْعَةِ أَوِ الْعُمْرَةِ فَقَالَ عَلِيٌّ مَا تُرِيدُ إِلَى أَمْرٍ فَعَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم تَنْهَى عَنْهُ فَقَالَ عُثْمَانُ دَعْنَا مِنْكَ ‏.‏ فَقَالَ إِنِّي لاَ أَسْتَطِيعُ أَنْ أَدَعَكَ فَلَمَّا أَنْ رَأَى عَلِيٌّ ذَلِكَ أَهَلَّ بِهِمَا جَمِيعًا ‏.‏\hadithno{2964}\hadithtrans{Sa'id b. al-Musayyab reported that 'Ali and 'Uthman (Allah be pleased with them) met at 'Usfan; and Uthman used to forbid (people) from performing Tamattu' and 'Umra (during the period of Hajj), whereupon 'Ali said:What is your opinion about a matter which the Messenger of Allah (ﷺ) did but you forbid it? Thereupon Uthman said: You leave us alone, whereupon he ('Ali) said: I cannot leave you alone. When 'Ali saw this, he put on Ihram for both of them together (both for Hajj and 'Umra)}}
\hadithdefcmd{muslim}{2965}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، - رضى الله عنه - قَالَ كَانَتِ الْمُتْعَةُ فِي الْحَجِّ لأَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم خَاصَّةً ‏.‏\hadithno{2965}\hadithtrans{Abu Dharr (Allah be pleased with him) said that Tamattu' in Hajj was a special (concession) only for the Companions of Muhammad (ﷺ)}}
\hadithdefcmd{muslim}{2966}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ عَيَّاشٍ الْعَامِرِيِّ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، - رضى الله عنه - قَالَ كَانَتْ لَنَا رُخْصَةً ‏.‏ يَعْنِي الْمُتْعَةَ فِي الْحَجِّ ‏.‏\hadithno{2966}\hadithtrans{Abu Dharr (Allah be pleased with him) reported:Tamattu' in Hajj was a special concession for us}}
\hadithdefcmd{muslim}{2967}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ فُضَيْلٍ، عَنْ زُبَيْدٍ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ أَبُو ذَرٍّ رضى الله عنه لاَ تَصْلُحُ الْمُتْعَتَانِ إِلاَّ لَنَا خَاصَّةً ‏.‏ يَعْنِي مُتْعَةَ النِّسَاءِ وَمُتْعَةَ الْحَجِّ ‏.‏\hadithno{2967}\hadithtrans{Abu Dharr (Allah be pleased with him) said:Two are the Mut'as which were not permissible but only for us, i. e. temporary marriage with women and Tamattu' in Hajj}}
\hadithdefcmd{muslim}{2968}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ بَيَانٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الشَّعْثَاءِ، قَالَ أَتَيْتُ إِبْرَاهِيمَ النَّخَعِيَّ وَإِبْرَاهِيمَ التَّيْمِيَّ فَقُلْتُ إِنِّي أَهُمُّ أَنْ أَجْمَعَ الْعُمْرَةَ وَالْحَجَّ الْعَامَ ‏.‏ فَقَالَ إِبْرَاهِيمُ النَّخَعِيُّ لَكِنْ أَبُوكَ لَمْ يَكُنْ لِيَهُمَّ بِذَلِكَ ‏.‏ قَالَ قُتَيْبَةُ حَدَّثَنَا جَرِيرٌ عَنْ بَيَانٍ عَنْ إِبْرَاهِيمَ التَّيْمِيِّ عَنْ أَبِيهِ أَنَّهُ مَرَّ بِأَبِي ذَرٍّ - رضى الله عنه - بِالرَّبَذَةِ فَذَكَرَ لَهُ ذَلِكَ فَقَالَ إِنَّمَا كَانَتْ لَنَا خَاصَّةً دُونَكُمْ ‏.‏\hadithno{2968}\hadithtrans{Abd al-Rahman b. Abi al-Sha'tha' reported:I came to Ibrahim al-Nakha'I and Ibrahim Taimi and said: I intend to combine 'Umra and Hajj this year, whereupon Ibrahim al-Nakha'i said: But your father did not make such intention. Ibrahim narrated on the authority of, his father that he passed by Abu Dharr (Allah be pleased with him) at Rabdha, and made a mention of that, whereupon he said: It was a special concession for us and not for you}}
\hadithdefcmd{muslim}{2969}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ الْفَزَارِيِّ، - قَالَ سَعِيدٌ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، - أَخْبَرَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ غُنَيْمِ بْنِ قَيْسٍ، قَالَ سَأَلْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ - رضى الله عنه - عَنِ الْمُتْعَةِ، فَقَالَ فَعَلْنَاهَا وَهَذَا يَوْمَئِذٍ كَافِرٌ بِالْعُرُشِ ‏.‏ يَعْنِي بُيُوتَ مَكَّةَ ‏.‏\hadithno{2969}\hadithtrans{Ghunaim b. Qais said:I asked Sa'd b. Abu Waqqas (Allah be pleased with him) about Mut'a, whereupon he said: We did that, and it was the day when he was an unbeliever living in (one of the) houses of Mecca}}
\hadithdefcmd{muslim}{2970}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ وَقَالَ فِي رِوَايَتِهِ يَعْنِي مُعَاوِيَةَ ‏.‏\hadithno{2970}\hadithtrans{This hadith has been narrated on the authority of Sulaiman Taimi with the same chain of transmitters and in his narration (he) refers to Mu'awiya}}
\hadithdefcmd{muslim}{2971}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنِي مُحَمَّدُ، بْنُ أَبِي خَلَفٍ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شُعْبَةُ، جَمِيعًا عَنْ سُلَيْمَانَ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِهِمَا وَفِي حَدِيثِ سُفْيَانَ الْمُتْعَةُ فِي الْحَجِّ ‏.‏\hadithno{2971}\hadithtrans{This hadith has been transmitted on the authority of Sulaiman (but with a slight modification of words)}}
\hadithdefcmd{muslim}{2972}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ أَبِي، الْعَلاَءِ عَنْ مُطَرِّفٍ، قَالَ قَالَ لِي عِمْرَانُ بْنُ حُصَيْنٍ إِنِّي لأُحَدِّثُكَ بِالْحَدِيثِ الْيَوْمَ يَنْفَعُكَ اللَّهُ بِهِ بَعْدَ الْيَوْمِ وَاعْلَمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَعْمَرَ طَائِفَةً مِنْ أَهْلِهِ فِي الْعَشْرِ فَلَمْ تَنْزِلْ آيَةٌ تَنْسَخُ ذَلِكَ وَلَمْ يَنْهَ عَنْهُ حَتَّى مَضَى لِوَجْهِهِ ارْتَأَى كُلُّ امْرِئٍ بَعْدُ مَا شَاءَ أَنْ يَرْتَئِيَ ‏.‏\hadithno{2972}\hadithtrans{Mutarrif reported:'Imran b. Husain said to me: Should I not narrate to you a hadith today by which Allah will benefit you subsequently-and bear in mind that Allah's Messenger (ﷺ) made some members of his family perform 'Umra within ten days of Dhu'l-Hijja. No verse was revealed to abrogate that, and he (the Holy Prophet) did not refrain from doing it till he died. So after him everyone said as he liked, (but it would be his. personal opinion and not the verdict of the Shari'ah)}}
\hadithdefcmd{muslim}{2973}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ حَاتِمٍ، كِلاَهُمَا عَنْ وَكِيعٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الْجُرَيْرِيِّ، فِي هَذَا الإِسْنَادِ وَقَالَ ابْنُ حَاتِمٍ فِي رِوَايَتِهِ ارْتَأَى رَجُلٌ بِرَأْيِهِ مَا شَاءَ ‏.‏ يَعْنِي عُمَرَ ‏.‏\hadithno{2973}\hadithtrans{This hadith been narrated on the authority of Jurairi with the same chain of transmitters, and Ibn Hatim said in his narration:" A person said according to his personal opinion, and it was Umar}}
\hadithdefcmd{muslim}{2974}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ مُطَرِّفٍ، قَالَ قَالَ لِي عِمْرَانُ بْنُ حُصَيْنٍ أُحَدِّثُكَ حَدِيثًا عَسَى اللَّهُ أَنْ يَنْفَعَكَ بِهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ بَيْنَ حَجَّةٍ وَعُمْرَةٍ ثُمَّ لَمْ يَنْهَ عَنْهُ حَتَّى مَاتَ وَلَمْ يَنْزِلْ فِيهِ قُرْآنٌ يُحَرِّمُهُ وَقَدْ كَانَ يُسَلَّمُ عَلَىَّ حَتَّى اكْتَوَيْتُ فَتُرِكْتُ ثُمَّ تَرَكْتُ الْكَىَّ فَعَادَ ‏.‏\hadithno{2974}\hadithtrans{Imran b. Husain reported:I am narrating to you a hadith by which Allah will benefit you (and the hadith is) that Allah's Messenger (ﷺ) combined Hajj and 'Umra, and he did not forbid (this combination) till he died. (Moreover) nothing was revealed in the Holy Qur'an which forbade it. And I was always blessed till I was branded and then it (blessing) was abandoned. I then abandoned branding and it (the blessing was restored)}}
\hadithdefcmd{muslim}{2975}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، قَالَ سَمِعْتُ مُطَرِّفًا، قَالَ قَالَ لِي عِمْرَانُ بْنُ حُصَيْنٍ ‏.‏ بِمِثْلِ حَدِيثِ مُعَاذٍ ‏.‏\hadithno{2975}\hadithtrans{This hadith has been narrated on the authority of Mutarrif with the same chain of transmitters}}
\hadithdefcmd{muslim}{2976}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، قَالَ بَعَثَ إِلَىَّ عِمْرَانُ بْنُ حُصَيْنٍ فِي مَرَضِهِ الَّذِي تُوُفِّيَ فِيهِ فَقَالَ إِنِّي كُنْتُ مُحَدِّثَكَ بِأَحَادِيثَ لَعَلَّ اللَّهَ أَنْ يَنْفَعَكَ بِهَا بَعْدِي فَإِنْ عِشْتُ فَاكْتُمْ عَنِّي وَإِنْ مُتُّ فَحَدِّثْ بِهَا إِنْ شِئْتَ إِنَّهُ قَدْ سُلِّمَ عَلَىَّ وَاعْلَمْ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَدْ جَمَعَ بَيْنَ حَجٍّ وَعُمْرَةٍ ثُمَّ لَمْ يَنْزِلْ فِيهَا كِتَابُ اللَّهِ وَلَمْ يَنْهَ عَنْهَا نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ رَجُلٌ فِيهَا بِرَأْيِهِ مَا شَاءَ ‏.‏\hadithno{2976}\hadithtrans{Mutarrif reported:'Imran b. Husain sent for me during his illness of which he died, and said: I am narrating to you some ahadith which may benefit you after me. If I live you conceal (the fact that these have been transmitted by me), and if I die, then you narrate them if you like (and these are): I am blessed, and bear in mind that the Messenger of Allah (ﷺ) combined Hajj and Umra. Then no verse was revealed in regard to it in the Book of Allah (which abrogated it) and the Messenger of Allah (ﷺ) did not forbid (from doing it). And whatever a person (, Umar) said was out of his personal opinion}}
\hadithdefcmd{muslim}{2977}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، - رضى الله عنه - قَالَ اعْلَمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ بَيْنَ حَجٍّ وَعُمْرَةٍ ثُمَّ لَمْ يَنْزِلْ فِيهَا كِتَابٌ وَلَمْ يَنْهَنَا عَنْهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فِيهَا رَجُلٌ بِرَأْيِهِ مَا شَاءَ‏.‏\hadithno{2977}\hadithtrans{Imran b. al-Husain (Allah be pleased with him) said:Know well that Allah's Messenger (ﷺ) combined 'Hajj and 'Umra, and nothing was revealed in the Book (to abrogate it), and the Messenger of Allah (ﷺ) too did not forbid us from (combining) them. And whatever a person said was out of his personal opinion}}
\hadithdefcmd{muslim}{2980}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، وَمُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، قَالاَ حَدَّثَنَا بِشْرُ، بْنُ الْمُفَضَّلِ حَدَّثَنَا عِمْرَانُ بْنُ مُسْلِمٍ، عَنْ أَبِي رَجَاءٍ، قَالَ قَالَ عِمْرَانُ بْنُ حُصَيْنٍ نَزَلَتْ آيَةُ الْمُتْعَةِ فِي كِتَابِ اللَّهِ - يَعْنِي مُتْعَةَ الْحَجِّ - وَأَمَرَنَا بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ لَمْ تَنْزِلْ آيَةٌ تَنْسَخُ آيَةَ مُتْعَةِ الْحَجِّ وَلَمْ يَنْهَ عَنْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى مَاتَ ‏.‏ قَالَ رَجُلٌ بِرَأْيِهِ بَعْدُ مَا شَاءَ ‏.‏\hadithno{2980}\hadithtrans{Imran b. Husain said:There was revealed the verse of Tamattu' in Hajj in the Book of Allah and the Messenger of Allah (ﷺ) commanded us to perform it. and then no verse was revealed abrogating the Tamattu' (form of Hajj), and the Messenger of Allah (ﷺ) did not forbid to do it till he died. So whatever a person said was his personal opinion}}
\hadithdefcmd{muslim}{2981}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عِمْرَانَ الْقَصِيرِ، حَدَّثَنَا أَبُو رَجَاءٍ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ وَفَعَلْنَاهَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ يَقُلْ وَأَمَرَنَا بِهَا ‏.‏\hadithno{2981}\hadithtrans{A hadith like this is transmitted on the authority of Imran b. Husain, but with this variation that he ('Imran) said:We did that (Tamattu') in the company of Allah's Messenger (ﷺ) and he did not say anything but he (the Holy Prophet) commanded us to do it}}
\hadithdefcmd{muslim}{2982}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، - رضى الله عنهما - قَالَ تَمَتَّعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ بِالْعُمْرَةِ إِلَى الْحَجِّ وَأَهْدَى فَسَاقَ مَعَهُ الْهَدْىَ مِنْ ذِي الْحُلَيْفَةِ وَبَدَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَهَلَّ بِالْعُمْرَةِ ثُمَّ أَهَلَّ بِالْحَجِّ وَتَمَتَّعَ النَّاسُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْعُمْرَةِ إِلَى الْحَجِّ فَكَانَ مِنَ النَّاسِ مَنْ أَهْدَى فَسَاقَ الْهَدْىَ وَمِنْهُمْ مَنْ لَمْ يُهْدِ فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ قَالَ لِلنَّاسِ ‏ "‏ مَنْ كَانَ مِنْكُمْ أَهْدَى فَإِنَّهُ لاَ يَحِلُّ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى يَقْضِيَ حَجَّهُ وَمَنْ لَمْ يَكُنْ مِنْكُمْ أَهْدَى فَلْيَطُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ وَلْيُقَصِّرْ وَلْيَحْلِلْ ثُمَّ لْيُهِلَّ بِالْحَجِّ وَلْيُهْدِ فَمَنْ لَمْ يَجِدْ هَدْيًا فَلْيَصُمْ ثَلاَثَةَ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةً إِذَا رَجَعَ إِلَى أَهْلِهِ ‏"‏ ‏.‏ وَطَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ قَدِمَ مَكَّةَ فَاسْتَلَمَ الرُّكْنَ أَوَّلَ شَىْءٍ ثُمَّ خَبَّ ثَلاَثَةَ أَطْوَافٍ مِنَ السَّبْعِ وَمَشَى أَرْبَعَةَ أَطْوَافٍ ثُمَّ رَكَعَ - حِينَ قَضَى طَوَافَهُ بِالْبَيْتِ عِنْدَ الْمَقَامِ - رَكْعَتَيْنِ ثُمَّ سَلَّمَ فَانْصَرَفَ فَأَتَى الصَّفَا فَطَافَ بِالصَّفَا وَالْمَرْوَةِ سَبْعَةَ أَطْوَافٍ ثُمَّ لَمْ يَحْلِلْ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى قَضَى حَجَّهُ وَنَحَرَ هَدْيَهُ يَوْمَ النَّحْرِ وَأَفَاضَ فَطَافَ بِالْبَيْتِ ثُمَّ حَلَّ مِنْ كُلِّ شَىْءٍ حَرُمَ مِنْهُ وَفَعَلَ مِثْلَ مَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ أَهْدَى وَسَاقَ الْهَدْىَ مِنَ النَّاسِ ‏.‏\hadithno{2982}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported:Allah's Messenger (ﷺ) observed Tamattu' in Hajjat-ul-Wada'. He first put on Ihram for 'Umra and then for Hajj. and then offered animal sacrifice. So he drove the sacrificial animals with him from Dhu'l-Hulaifa. Allah's Messenger (ﷺ) commenced Ihram of Umra and thus pronounced Talbiya for 'Umra. and then (put on Ihram for Hajj) and pronounced Talbiya for Hajj. And the people performed Tamattu' in the company of Allah's Messenger (ﷺ). They put on Ihram for Umra (first) and then for Hajj. Some of them had sacrificial animals which they had brought with them, whereas some of them had none to sacrifice. So when Allah's Messenger (ﷺ) came to Mecca, he said to the people: He who amongst you has brought sacrificial animals along with him must not treat as lawful anything which has become unlawful for him till he has completed the Hajj; and he, who amongst you has not brought the sacrificial animals should circumambulate the House, and run between al-Safa' and al-Marwa and clip (his hair) and put off the Ihram, and then again put on the Ihram for Hajj and offer sacrifice of animals. But he who does not find the sacrificial animal, he should observe fast for three days during the Hajj and for seven days when he returns to his family. Allah's Messenger (ﷺ) circumambulated (the House) when he came to Mecca: he first kissed the corner (of the Ka'ba containing the Black Stone), then ran in three circuits out of seven and walked in four circuits. And then when he had finished the circumambulation of the House he observed two rak'ahs of prayer at the Station (of Ibrahim), and then pronounced Salaam (for concluding the rak'ahs), and departed and came to al-Safa' and ran seven times between al-Safa' and al-Marwa. After that he did not treat anything as lawful which had become unlawful till he had completed his Hajj and sacrificed his animal on the day of sacrifice (10th of Dhu'l-Hijja). and then went back quickly (to Mecca) and performed circumambulation of the House (known as tawaf ifada) after which all that was unlawful for him became lawful; and those who had brought the sacrificial animals along with them did as Allah's Messenger (ﷺ) had done}}
\hadithdefcmd{muslim}{2983}{وَحَدَّثَنِيهِ عَبْدُ الْمَلِكِ بْنُ شُعَيْبٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي تَمَتُّعِهِ بِالْحَجِّ إِلَى الْعُمْرَةِ وَتَمَتُّعِ النَّاسِ مَعَهُ بِمِثْلِ الَّذِي أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ عَنْ عَبْدِ اللَّهِ - رضى الله عنه - عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2983}\hadithtrans{This hadith has been narrated on the authority of 'A'isha. The wife of Allah's Messenger (ﷺ), concerning his Tamattu' of Hajj and 'Umra and performing of Tamattu' by people in his company}}
\hadithdefcmd{muslim}{2984}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ حَفْصَةَ، - رضى الله عنهم - زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ يَا رَسُولَ اللَّهِ مَا شَأْنُ النَّاسِ حَلُّوا وَلَمْ تَحْلِلْ أَنْتَ مِنْ عُمْرَتِكَ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي وَقَلَّدْتُ هَدْيِي فَلاَ أَحِلُّ حَتَّى أَنْحَرَ ‏"‏ ‏.‏\hadithno{2984}\hadithtrans{Hafsa (Allah be pleased with her), the wife of Allah's Apostle (ﷺ), said:Messenger of Allah. what about people who have put off Ihram whereas you have not put it off after your 'Umra? He said: I have stuck my hair and have driven my sacrificial animal, and would not, therefore, put off Ihram until I have sacrificed the animal}}
\hadithdefcmd{muslim}{2985}{وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، - رضى الله عنهم - قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَا لَكَ لَمْ تَحِلَّ بِنَحْوِهِ ‏.‏\hadithno{2985}\hadithtrans{Hafsa (Allah be pleased with her) reported:I said: Messenger of Allah what is the matter with you that you have not put off Ihram? The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2986}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، - رضى الله عنهم - قَالَتْ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم مَا شَأْنُ النَّاسِ حَلُّوا وَلَمْ تَحِلَّ مِنْ عُمْرَتِكَ قَالَ ‏ "‏ إِنِّي قَلَّدْتُ هَدْيِي وَلَبَّدْتُ رَأْسِي فَلاَ أَحِلُّ حَتَّى أَحِلَّ مِنَ الْحَجِّ ‏"‏ ‏.‏\hadithno{2986}\hadithtrans{Hafsa (Allah be pleased with her) reported:I said to Allah's Messenger (ﷺ): What is the matter with people that they have put off Ihram, whereas you have not put it off after your Umra'? He said: I have driven my sacrificial animal and stuck my hair, and it is not permissible for me to put off Ihram unless I have completed the Hajj}}
\hadithdefcmd{muslim}{2987}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ حَفْصَةَ، - رضى الله عنها - قَالَتْ يَا رَسُولَ اللَّهِ ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ ‏ "‏ فَلاَ أَحِلُّ حَتَّى أَنْحَرَ ‏"‏ ‏.‏\hadithno{2987}\hadithtrans{Hafsa (Allah be pleased with her) said:Messenger of Allah; the rest of the hadith is the same and (the concluding words of the Holy Prophet):" I won't put off Ihram until I have sacrificed the animal}}
\hadithdefcmd{muslim}{2988}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا هِشَامُ بْنُ سُلَيْمَانَ الْمَخْزُومِيُّ، وَعَبْدُ الْمَجِيدِ، عَنِ ابْنِ جُرَيْجٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ حَدَّثَتْنِي حَفْصَةُ، - رضى الله عنها - أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ أَزْوَاجَهُ أَنْ يَحْلِلْنَ عَامَ حَجَّةِ الْوَدَاعِ ‏.‏ قَالَتْ حَفْصَةُ فَقُلْتُ مَا يَمْنَعُكَ أَنْ تَحِلَّ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي وَقَلَّدْتُ هَدْيِي فَلاَ أَحِلُّ حَتَّى أَنْحَرَ هَدْيِي ‏"‏ ‏.‏\hadithno{2988}\hadithtrans{Hafsa (Allah be pleased with her) said that Allah's Apostle (ﷺ) commanded his wives that they should put off Ihram during the year of Hajj (at-ul-Wada'). whereupon she (Hafsa) said:What hinders you that you have not put off Ihram? Thereupon he said: I have stuck my hair and driven my sacrificial animal along with men and it is not permissible to put off Ihram (under this condition until I have sacrificed the animal)}}
\hadithdefcmd{muslim}{2989}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، - رضى الله عنهما - خَرَجَ فِي الْفِتْنَةِ مُعْتَمِرًا وَقَالَ إِنْ صُدِدْتُ عَنِ الْبَيْتِ صَنَعْنَا كَمَا صَنَعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ فَأَهَلَّ بِعُمْرَةٍ وَسَارَ حَتَّى إِذَا ظَهَرَ عَلَى الْبَيْدَاءِ الْتَفَتَ إِلَى أَصْحَابِهِ فَقَالَ مَا أَمْرُهُمَا إِلاَّ وَاحِدٌ أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ الْحَجَّ مَعَ الْعُمْرَةِ ‏.‏ فَخَرَجَ حَتَّى إِذَا جَاءَ الْبَيْتَ طَافَ بِهِ سَبْعًا وَبَيْنَ الصَّفَا وَالْمَرْوَةِ سَبْعًا لَمْ يَزِدْ عَلَيْهِ وَرَأَى أَنَّهُ مُجْزِئٌ عَنْهُ وَأَهْدَى ‏.‏\hadithno{2989}\hadithtrans{Nafi' reported that 'Abdullah b. Umar (Allah be pleased with them) set out for Umra during the turmoil, and he said:If I am detained (from going to) the House, we would do the same as we did with Allah's Messenger (ﷺ). So he went out and put on Ihram for 'Umra and moved on until he reached al-Baida'. He turned towards his Companions and said: There is one command for both of them. and 1 call you as my witness (and say) that verify I have- made Hajj with 'Umra compulsory for me. He proceeded until, when he came to the House, he circumambulated it seven times and ran between al-Safa' and al-Marwa seven times, and made no addition to it and thought it to be sufficient for him and offered sacrifice}}
\hadithdefcmd{muslim}{2990}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، كَلَّمَا عَبْدَ اللَّهِ حِينَ نَزَلَ الْحَجَّاجُ لِقِتَالِ ابْنِ الزُّبَيْرِ قَالاَ لاَ يَضُرُّكَ أَنْ لاَ تَحُجَّ الْعَامَ فَإِنَّا نَخْشَى أَنْ يَكُونَ بَيْنَ النَّاسِ قِتَالٌ يُحَالُ بَيْنَكَ وَبَيْنَ الْبَيْتِ قَالَ فَإِنْ حِيلَ بَيْنِي وَبَيْنَهُ فَعَلْتُ كَمَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَعَهُ حِينَ حَالَتْ كُفَّارُ قُرَيْشٍ بَيْنَهُ وَبَيْنَ الْبَيْتِ أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ عُمْرَةً ‏.‏ فَانْطَلَقَ حَتَّى أَتَى ذَا الْحُلَيْفَةِ فَلَبَّى بِالْعُمْرَةِ ثُمَّ قَالَ إِنْ خُلِّيَ سَبِيلِي قَضَيْتُ عُمْرَتِي وَإِنْ حِيلَ بَيْنِي وَبَيْنَهُ فَعَلْتُ كَمَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَعَهُ ‏.‏ ثُمَّ تَلاَ ‏\{‏ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏ ثُمَّ سَارَ حَتَّى إِذَا كَانَ بِظَهْرِ الْبَيْدَاءِ قَالَ مَا أَمْرُهُمَا إِلاَّ وَاحِدٌ إِنْ حِيلَ بَيْنِي وَبَيْنَ الْعُمْرَةِ حِيلَ بَيْنِي وَبَيْنَ الْحَجِّ أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ حَجَّةً مَعَ عُمْرَةٍ ‏.‏ فَانْطَلَقَ حَتَّى ابْتَاعَ بِقُدَيْدٍ هَدْيًا ثُمَّ طَافَ لَهُمَا طَوَا��ًا وَاحِدًا بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ لَمْ يَحِلَّ مِنْهُمَا حَتَّى حَلَّ مِنْهُمَا بِحَجَّةٍ يَوْمَ النَّحْرِ ‏.‏\hadithno{2990}\hadithtrans{Nafi' reported that 'Abdullah b. 'Abdullah and Salim b. Abdullah said to 'Abdullah (b. 'Umar) at the time when Hajjaj came to fight against Ibn Zubair:There would be no harm if you do not (proceed) for Hajj this year, for we fear that there would be fight among people which would cause obstruction between you and the House, whereupon he said: If there would be obstruction between me and that (Ka'ba), I would do as Allah's Messenger (ﷺ) did. I was with him (the Holy Prophet) when the infidels of Quraish caused obstructions between him (the Holy Prophet) and the House. I call you as my witness (to the fact) that I have made 'Umra essential for me. He proceeded until he came to Dhu'l-Hulaifa and pronounced Talbiya for Umra, and said: If the way Is clear forme, I would then complete my 'Umra but If there is some obstruction between me and that (the Ka'ba). I would then do what Allah's Messenger (ﷺ) had done (at the occasion of Hudaibiya), and I was with him (the Holy Prophet). and then recited:" Verily in the Messenger of Allah, there is a model pattern for you" (xxxiii. 21). He then moved on until he came to the rear side of al-Baida' and said: There is one command for both of them automatically) (Hajj and Umra). If I am detained (in the performance) of 'Umra, I am ( automatically detained (in the performance) of Hajj (too). I call you as witness that Hajj along with 'Umra I had made essential for me. (I am performing Hajj and 'Umra as Qiran.) He then bought sacrificial animals at Qudaid and then circumambulated the House and ran between al-Safa' and al-Marwa once (covering both Hajj and Umra), and did not put off Ihram until on the Day of Sacrifice in the month of Dhu'l-Hijja}}
\hadithdefcmd{muslim}{2991}{وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، قَالَ أَرَادَ ابْنُ عُمَرَ الْحَجَّ حِينَ نَزَلَ الْحَجَّاجُ بِابْنِ الزُّبَيْرِ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِمِثْلِ هَذِهِ الْقِصَّةِ وَقَالَ فِي آخِرِ الْحَدِيثِ وَكَانَ يَقُولُ مَنْ جَمَعَ بَيْنَ الْحَجِّ وَالْعُمْرَةِ كَفَاهُ طَوَافٌ وَاحِدٌ وَلَمْ يَحِلَّ حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏.‏\hadithno{2991}\hadithtrans{Nafi' reported that Ibn Umar intended to go to Hajj (during the year) when Hajjaj attacked Ibn Zubair, and he narrated the account as (narrated above), and he used to say at the end of the hadith:He who combines Hajj with Umra, for him one single circumambulation is sufficient, and he did not put off Ihram until he had completed both of them}}
\hadithdefcmd{muslim}{2992}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، أَرَادَ الْحَجَّ عَامَ نَزَلَ الْحَجَّاجُ بِابْنِ الزُّبَيْرِ فَقِيلَ لَهُ إِنَّ النَّاسَ كَائِنٌ بَيْنَهُمْ قِتَالٌ وَإِنَّا نَخَافُ أَنْ يَصُدُّوكَ فَقَالَ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ أَصْنَعُ كَمَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنِّي أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ عُمْرَةً ‏.‏ ثُمَّ خَرَجَ حَتَّى كَانَ بِظَاهِرِ الْبَيْدَاءِ قَالَ مَا شَأْنُ الْحَجِّ وَالْعُمْرَةِ إِلاَّ وَاحِدٌ اشْهَدُوا - قَالَ ابْنُ رُمْحٍ أُشْهِدُكُمْ - أَنِّي قَدْ أَوْجَبْتُ حَجًّا مَعَ عُمْرَتِي ‏.‏ وَأَهْدَى هَدْيًا اشْتَرَاهُ بِقُدَيْدٍ ثُمَّ انْطَلَقَ يُهِلُّ بِهِمَا جَمِيعًا حَتَّى قَدِمَ مَكَّةَ فَطَافَ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ وَلَمْ يَزِدْ عَلَى ذَلِكَ وَلَمْ يَنْحَرْ وَلَمْ يَحْلِقْ وَلَمْ يُقَصِّرْ وَلَمْ يَحْلِلْ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى كَانَ يَوْمُ النَّحْرِ فَنَحَرَ وَحَلَقَ وَرَأَى أَنْ قَدْ قَضَى طَوَافَ الْحَجِّ وَالْعُمْرَةِ بِطَوَافِهِ الأَوَّلِ ‏.‏ وَقَالَ ابْنُ عُمَرَ كَذَلِكَ فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2992}\hadithtrans{Nafi' reported that Ibn Umar intended to go for Hajj during the year when Hajjaj attacked Ibn Zubair. It was said to him:There is a state of war between people and we fear that they would detain you, whereupon he ('Abdullah b. Umar) said:" Verily in the Messenger of Allah there is a model pattern for you." I would do as Allah's Messenger (ﷺ) did. I call you as witness that I have undertaken to perform 'Umra. He then set out until, when he reached the rear side of al-Baida', he said: There is one command both for Hajj and Umra. so bear witness. Ibn Rumh said: I call you as witness that I have undertaken to perform my Hajjalong with my Umra (i. e. I am performing both of them as Qiran), and he offered the sacrifice of animals which he had bought at Qudaid. He then proceeded pronouncing Talbiya for both of them together until he reached Mecca, He circumambulated the House. and (ran) between al-Safa' and al-Marwa and made no addition to it. He neither sacrificed the animal, nor got his head shaved, nor got his hair clipped, nor did he make anything lawful which was unlawful (due to Ihram) until it was the Day of Sacrifice (10th of Dhu'l-Hijja). He then offered sacrifice, and got his hair cut, and saw that circumambulation of Hajj and 'Umra was complete with the first circumambulation. Ibn 'Umar said: This is how Allah's Messenger (ﷺ) had done}}
\hadithdefcmd{muslim}{2993}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ، حَرْبٍ حَدَّثَنِي إِسْمَاعِيلُ، كِلاَهُمَا عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ‏.‏ بِهَذِهِ الْقِصَّةِ ‏.‏ وَلَمْ يَذْكُرِ النَّبِيَّ صلى الله عليه وسلم إِلاَّ فِي أَوَّلِ الْحَدِيثِ حِينَ قِيلَ لَهُ يَصُدُّوكَ عَنِ الْبَيْتِ ‏.‏ قَالَ إِذًا أَفْعَلَ كَمَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَلَمْ يَذْكُرْ فِي آخِرِ الْحَدِيثِ هَكَذَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ كَمَا ذَكَرَهُ اللَّيْثُ ‏.‏\hadithno{2993}\hadithtrans{This hadith has been narrated from Ibn Umar through another chain of transmitters except with (this variation) that Allah's Apostle (ﷺ) was mentioned in the first part of the hadith,. i. e. when it was said to him:They would bar you (from going) to the House. He said: In that, case I would do what Allah's Messenger (ﷺ) had done. He did not mention at the end of this hadith (i. e. these words):" This is how the Messenger of Allah (ﷺ) had done," as it Is narrated by al-Laith}}
\hadithdefcmd{muslim}{2994}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَعَبْدُ اللَّهِ بْنُ عَوْنٍ الْهِلاَلِيُّ، قَالاَ حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، الْمُهَلَّبِيُّ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - فِي رِوَايَةِ يَحْيَى - قَالَ أَهْلَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ مُفْرَدًا وَفِي رِوَايَةِ ابْنِ عَوْنٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهَلَّ بِالْحَجِّ مُفْرَدًا ‏.‏\hadithno{2994}\hadithtrans{Nafi' thus reported on the authority of Ibn Umar:We entered into the state of Ihram with Allah's Messenger (ﷺ) for Hajj Mufrad and in the narration of Ibn 'Aun (the words are):" Allah's Messenger (ﷺ) entered into the state of Ihram (with the intention) of Hajj Mufrad}}
\hadithdefcmd{muslim}{2995}{وَحَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا حُمَيْدٌ، عَنْ بَكْرٍ، عَنْ أَنَسٍ، - رضى الله عنه - قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يُلَبِّي بِالْحَجِّ وَالْعُمْرَةِ جَمِيعًا ‏.‏ قَالَ بَكْرٌ فَحَدَّثْتُ بِذَلِكَ ابْنَ عُمَرَ فَقَالَ لَبَّى بِالْحَجِّ وَحْدَهُ ‏.‏ فَلَقِيتُ أَنَسًا فَحَدَّثْتُهُ بِقَوْلِ ابْنِ عُمَرَ فَقَالَ أَنَسٌ مَا تَعُدُّونَنَا إِلاَّ صِبْيَانًا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَبَّيْكَ عُمْرَةً وَحَجًّا ‏"‏ ‏.‏\hadithno{2995}\hadithtrans{Anas (Allah be pleased with him) said:I heard Allah's Apostle (way peace be upon him) pronouncing Talbiya for both Hajj and Umra. Bakr (one of the narrators) said: I narrated it to Ibn 'Umar, whereupon he said: He (the Holy Prophet) pronounced the Talbiya for Hajj alone. I met Anas and narrated to him the words of Ibn 'Umar, whereupon he said: You treat us not but only as children. I heard Allah's Messenger (ﷺ) pronouncing Talbiya both for 'Umra and Hajj}}
\hadithdefcmd{muslim}{2996}{وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا حَبِيبُ، بْنُ الشَّهِيدِ عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، حَدَّثَنَا أَنَسٌ، رضى الله عنه أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم جَمَعَ بَيْنَهُمَا بَيْنَ الْحَجِّ وَالْعُمْرَةِ قَالَ فَسَأَلْتُ ابْنَ عُمَرَ فَقَالَ أَهْلَلْنَا بِالْحَجِّ ‏.‏ فَرَجَعْتُ إِلَى أَنَسٍ فَأَخْبَرْتُهُ مَا قَالَ ابْنُ عُمَرَ فَقَالَ كَأَنَّمَا كُنَّا صِبْيَانًا ‏.‏\hadithno{2996}\hadithtrans{Bakr b. 'Abdullah reported:Anas (Allah be pleased with him) had narrated to us that he saw Allah's Apostle (ﷺ) combining Hajj and 'Umra. He (Bakr) said: I asked (about it) from Ibn 'Umar, whereupon he said: We entered into the state of Ihram for Hajj (only). I came to Anas and told him what Ibn Umar had said, whereupon he remarked: (You are treating us) as if we were children}}
\hadithdefcmd{muslim}{2997}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْثَرٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ وَبَرَةَ، قَالَ كُنْتُ جَالِسًا عِنْدَ ابْنِ عُمَرَ فَجَاءَهُ رَجُلٌ فَقَالَ أَيَصْلُحُ لِي أَنْ أَطُوفَ بِالْبَيْتِ قَبْلَ أَنْ آتِيَ الْمَوْقِفَ ‏.‏ فَقَالَ نَعَمْ ‏.‏ فَقَالَ فَإِنَّ ابْنَ عَبَّاسٍ يَقُولُ لاَ تَطُفْ بِالْبَيْتِ حَتَّى تَأْتِيَ الْمَوْقِفَ ‏.‏ فَقَالَ ابْنُ عُمَرَ فَقَدْ حَجَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ قَبْلَ أَنْ يَأْتِيَ الْمَوْقِفَ فَبِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَقُّ أَنْ تَأْخُذَ أَوْ بِقَوْلِ ابْنِ عَبَّاسٍ إِنْ كُنْتَ صَادِقًا\hadithno{2997}\hadithtrans{Wabara reported:While I was sitting in the company of Ibn 'Umar, a person came to him and said: Is it right for me to circumambulate the House before I come to stay (at 'Arafat)? Ibn 'Umar said: Yes. whereupon he said: Ibn Abbas, however, says: Do not circumambulate the House until you come to stay at 'Arafat. Thereupon Ibn 'Umar said: Allah's Messenger (ﷺ) Performed the Hajj and circumambulated the House before coming to stay (at 'Arafat). If you say the Truth, is it more rightful to follow the saying of the Prophet (ﷺ) or the words of Ibn Abbas?}}
\hadithdefcmd{muslim}{2998}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ بَيَانٍ، عَنْ وَبَرَةَ، قَالَ سَأَلَ رَجُلٌ ابْنَ عُمَرَ - رضى الله عنهما - أَطُوفُ بِالْبَيْتِ وَقَدْ أَحْرَمْتُ بِالْحَجِّ فَقَالَ وَمَا يَمْنَعُكَ قَالَ إِنِّي رَأَيْتُ ابْنَ فُلاَنٍ يَكْرَهُهُ وَأَنْتَ أَحَبُّ إِلَيْنَا مِنْهُ رَأَيْنَاهُ قَدْ فَتَنَتْهُ الدُّنْيَا ‏.‏ فَقَالَ وَأَيُّنَا - أَوْ أَيُّكُمْ - لَمْ تَفْتِنْهُ الدُّنْيَا ثُمَّ قَالَ رَأَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم أَحْرَمَ بِالْحَجِّ وَطَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ فَسُنَّةُ اللَّهِ وَسُنَّةُ رَسُولِهِ صلى الله عليه وسلم أَحَقُّ أَنْ تَتَّبِعَ مِنْ سُنَّةِ فُلاَنٍ إِنْ كُنْتَ صَادِقًا ‏.‏\hadithno{2998}\hadithtrans{Wabara reported:A person asked Ibn Umar (Allah be pleased with him): May I circumambulate the House, whereas I have entered-into the state of Ihram for Hajj? Thereupon he said: What prevents you from doing it? He said: I saw the son of so and so showing disapproval of it, and you are dearer to us as compared with him. And we see that he is allured by the world, whereupon he said: Who amongst you and us is not allured by the world? And said (further) ': 'We saw that Allah's Messenger (ﷺ) put on Ihram for Hajj and circumambulated the House and run between al Safa' and al-Marwa. And the way prescribed by Allah and that prescribed by His Apostle (ﷺ) deserve more to be followed than the way shown by so and so, if you speak the truth}}
\hadithdefcmd{muslim}{2999}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَأَلْنَا ابْنَ عُمَرَ عَنْ رَجُلٍ، قَدِمَ بِعُمْرَةٍ فَطَافَ بِالْبَيْتِ وَلَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ أَيَأْتِي امْرَأَتَهُ فَقَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ سَبْعًا وَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ ‏.‏\hadithno{2999}\hadithtrans{Amr b. Dinar said:We asked Ibn Umar about a person who came for Umra and circumambulated the House, but he did not run between al-Safa' and al-Marwa, whether he is allowed to (put off Ihram) and have intercourse with his wife. He replied: Allah's Messenger (ﷺ) circumambulated the House seven times and offered two rak'ahs of prayer after staying (at 'Arafat), and ran between al-Safa and al-Marwa seven times." Verily there is in Allah's Messenger a model pattern for you" (xxxill)}}
\hadithdefcmd{muslim}{3000}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، عَنْ حَمَّادِ بْنِ زَيْدٍ، ح وَحَدَّثَنَا عَبْدُ، بْنُ حُمَيْدٍ أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، جَمِيعًا عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ، عُمَرَ - رضى الله عنهما - عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{3000}\hadithtrans{This hadith is narrated by another chain of transmitters}}
\hadithdefcmd{muslim}{3001}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ رَجُلاً، مِنْ أَهْلِ الْعِرَاقِ قَالَ لَهُ سَلْ لِي عُرْوَةَ بْنَ الزُّبَيْرِ عَنْ رَجُلٍ يُهِلُّ بِالْحَجِّ فَإِذَا طَافَ بِالْبَيْتِ أَيَحِلُّ أَمْ لاَ فَإِنْ قَالَ لَكَ لاَ يَحِلُّ ‏.‏ فَقُلْ لَهُ إِنَّ رَجُلاً يَقُولُ ذَلِكَ - قَالَ - فَسَأَلْتُهُ فَقَالَ لاَ يَحِلُّ مَنْ أَهَلَّ بِالْحَجِّ إِلاَّ بِالْحَجِّ ‏.‏ قُلْتُ فَإِنَّ رَجُلاً كَانَ يَقُولُ ذَلِكَ ‏.‏ قَالَ بِئْسَ مَا قَالَ فَتَصَدَّانِي الرَّجُلُ فَسَأَلَنِي فَحَدَّثْتُهُ فَقَالَ فَقُلْ لَهُ فَإِنَّ رَجُلاً كَانَ يُخْبِرُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ فَعَلَ ذَلِكَ وَمَا شَأْنُ أَسْمَاءَ وَالزُّبَيْرِ فَعَلاَ ذَلِكَ ‏.‏ قَالَ فَجِئْتُهُ فَذَكَرْتُ لَهُ ذَلِكَ فَقَالَ مَنْ هَذَا فَقُلْتُ لاَ أَدْرِي ‏.‏ قَالَ فَمَا بَالُهُ لاَ يَأْتِينِي بِنَفْسِهِ يَسْأَلُنِي أَظُنُّهُ عِرَاقِيًّا ‏.‏ قُلْتُ لاَ أَدْرِي ‏.‏ قَالَ فَإِنَّهُ قَدْ كَذَبَ قَدْ حَجَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَتْنِي عَائِشَةُ - رضى الله عنها - أَنَّ أَوَّلَ شَىْءٍ بَدَأَ بِهِ حِينَ قَدِمَ مَكَّةَ أَنَّهُ تَوَضَّأَ ثُمَّ طَافَ بِالْبَيْتِ ثُمَّ حَجَّ أَبُو بَكْرٍ فَكَانَ أَوَّلَ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ ثُمَّ لَمْ يَكُنْ غَيْرُهُ ثُمَّ عُمَرُ مِثْلُ ذَلِكَ ثُمَّ حَجَّ عُثْمَانُ فَرَأَيْتُهُ أَوَّلُ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ ثُمَّ لَمْ يَكُنْ غَيْرُهُ ثُمَّ مُعَاوِيَةُ وَعَبْدُ اللَّهِ بْنُ عُمَرَ ثُمَّ حَجَجْتُ مَعَ أَبِي الزُّبَيْرِ بْنِ الْعَوَّامِ فَكَانَ أَوَّلَ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ ثُمَّ لَمْ يَكُنْ غَيْرُهُ ثُمَّ رَأَيْتُ الْمُهَاجِرِينَ وَالأَنْصَارَ يَفْعَلُونَ ذَلِكَ ثُمَّ لَمْ يَكُنْ غَيْرُهُ ثُمَّ آخِرُ مَنْ رَأَيْتُ فَعَلَ ذَلِكَ ابْنُ عُمَرَ ثُمَّ لَمْ يَنْقُضْهَا بِعُمْرَةٍ وَهَذَا ابْنُ عُمَرَ عِنْدَهُمْ أَفَلاَ يَسْأَلُونَهُ وَلاَ أَحَدٌ مِمَّنْ مَضَى مَا كَانُوا يَبْدَءُونَ بِشَىْءٍ حِينَ يَضَعُونَ أَقْدَامَهُمْ أَوَّلَ مِنَ الطَّوَافِ بِالْبَيْتِ ثُمَّ لاَ يَحِلُّونَ وَقَدْ رَأَيْتُ أُمِّي وَخَالَتِي حِينَ تَقْدَمَانِ لاَ تَبْدَآنِ بِشَىْءٍ أَوَّلَ مِنَ الْبَيْتِ تَطُوفَانِ بِهِ ثُمَّ لاَ تَحِلاَّنِ وَقَدْ أَخْبَرَتْنِي أُمِّي أَنَّهَا أَقْبَلَتْ هِيَ وَأُخْتُهَا وَالزُّبَيْرُ وَفُلاَنٌ وَفُلاَنٌ بِعُمْرَةٍ قَطُّ فَلَمَّا مَسَحُوا الرُّكْنَ حَلُّوا وَقَدْ كَذَبَ فِيمَا ذَكَرَ مِنْ ذَلِكَ ‏.‏\hadithno{3001}\hadithtrans{Muhammad b. 'Abd al-Rahman reported:A person from Iraq said to him to inquire from 'Urwa b. Zubair for him whether a person who puts on Ihram for Hajj is allowed to put it off or not as he circumambulates the House. And if he says:" No, it can't be put off," then tell him that there is a person who makes such an assertion. He (Muhammad b. 'Abd al-Rahman) then said: I asked him ( Urwa b. Zubair), where- upon he said: The person who has entered into the state of Ihram for Hajj cannot get out of it unless he has, completed the Hajj I (further) said (to him): (What) if a person makes that assertion? Thereupon he said: It is indeed unfortunate that he makes such an assertion. That person ('Iraqi) then met me and he asked me and I narrated to him (the reply of 'Urwa), whereupon he (the Iraqi) said: Tell him ('Urwa) that a person had informed him that Allah's Messenger (ﷺ) had done that; and why is it that Asma' and Zubair have done like this? He (Muhammad b. 'Abd al-Rahman) said: I went to him and made a mention of that to him, whereupon he ('Urwa) said: Who is he (the 'Iraqi)? I said: I do not know, whereupon he said: What is the matter that he does not come to me himself and ask me? I suppose he is an 'Iraqi. I said: I do not know, whereupon he said: He has told a lie. Allah's Messenger (ﷺ) performed Hajj, and 'A'isha (Allah be pleased with her) has told me that the first thing with which he commenced (the rituals) when he arrived at Mecca was that he performed ablution and then circumambulated the Ka'ba. Then Abu Bakr performed Hajj and the first thing with which he commenced (the Hajj) as the circumambulation of the Ka'ba and nothing besides it. So did 'Umar. Then 'Uthman performed Hajj and I saw that the first thing with which he commenced the Hajj was the circumambulation of the Ka'ba and nothing besides it. Then Mu'awiya and Abdullah b. 'Umar did that. Then I performed Hajj with my father Zubair b. al-'Awwam, and the first thing with which he commenced (Hajj) was the circumambulation of the House. He then did nothing besides it. I then saw the emigrants (Muhajirin) and the helpers (Ansar) doing like this and nothing besides it. And the last one whom I saw doing like this was Ibn 'Umar. And he did not break it (the Hajj) after performing 'Umra. And Ibn 'Umar is with them. Why don't they ask him (to testify it)? And none amongst those who had passed away commenced (the rituals of Hajj) but by circumambulating the Ka'ba on their (first arrival) and they did not put off Ihram (without completing the Hajj), and I saw my mother and my aunt commencing (their Hajj) with the circumambulation of the House, and they did not put off Ihram. My mother informed me that she came and her sister, and Zubair and so and so for 'Umra, and when they had kissed the corner (the Black Stone, after Sa'i and circumambulation), they put off Ihram. And he (the 'Iraqi) has told a lie in this matter}}
\hadithdefcmd{muslim}{3002}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي مَنْصُورُ، بْنُ عَبْدِ الرَّحْمَنِ عَنْ أُمِّهِ، صَفِيَّةَ بِنْتِ شَيْبَةَ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، - رضى الله عنهما - قَالَتْ خَرَجْنَا مُحْرِمِينَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيَقُمْ عَلَى إِحْرَامِهِ وَمَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ فَلْيَحْلِلْ ‏"‏ ‏.‏ فَلَمْ يَكُنْ مَعِي هَدْىٌ فَحَلَلْتُ وَكَانَ مَعَ الزُّبَيْرِ هَدْىٌ فَلَمْ يَحْلِلْ ‏.‏ قَالَتْ فَلَبِسْتُ ثِيَابِي ثُمَّ خَرَجْتُ فَجَلَسْتُ إِلَى الزُّبَيْرِ فَقَالَ قُومِي عَنِّي ‏.‏ فَقُلْتُ أَتَخْشَى أَنْ أَثِبَ عَلَيْكَ\hadithno{3002}\hadithtrans{Asma bint Abu Bakr (Allah be pleased with both of them) reported:We set out (to Mecca) in a state of Ihram. Allah's Messenger (ﷺ) said: He who has the sacrificial animal with him should remain in the state of Ihram, but he who has not the sacrificial animal with him should put off Ihram. As I had not the sacrificial animal with me, I put off Ihram. And since Zubair (her husband) - had the sacrificial animal with him, he did not put off Ihram. She (Asma) said: I put on my clothes and then went out and sat by Zabair, whereupon he said: Go away from me, whereupon I said: Do you fear that I would jump upon you?}}
\hadithdefcmd{muslim}{3003}{وَحَدَّثَنِي عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا أَبُو هِشَامٍ الْمُغِيرَةُ بْنُ سَلَمَةَ، الْمَخْزُومِيُّ حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مَنْصُورُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، - رضى الله عنهما - قَالَتْ قَدِمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُهِلِّينَ بِالْحَجِّ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ ابْنِ جُرَيْجٍ غَيْرَ أَنَّهُ قَالَ فَقَالَ اسْتَرْخِي عَنِّي اسْتَرْخِي عَنِّي ‏.‏ فَقُلْتُ أَتَخْشَى أَنْ أَثِبَ عَلَيْكَ\hadithno{3003}\hadithtrans{Asma bint Abu Bakr (Allah be pleased with th (m) said:We came for Hajj in the state of Ihram with Allah's Messenger (ﷺ). The rest of the hadith is the same except (for the words) that he (Zubair) said: Keep away from me, keep away from me, whereupon I said: Do you fear that I will jump upon you?}}
\hadithdefcmd{muslim}{3004}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ أَبِي الأَسْوَدِ، أَنَّ عَبْدَ اللَّهِ، مَوْلَى أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ - رضى الله عنهما - حَدَّثَهُ أَنَّهُ، كَانَ يَسْمَعُ أَسْمَاءَ كُلَّمَا مَرَّتْ بِالْحَجُونِ تَقُولُ صَلَّى اللَّهُ عَلَى رَسُولِهِ وَسَلَّمَ لَقَدْ نَزَلْنَا مَعَهُ هَا هُنَا وَنَحْنُ يَوْمَئِذٍ خِفَافُ الْحَقَائِبِ قَلِيلٌ ظَهْرُنَا قَلِيلَةٌ أَزْوَادُنَا فَاعْتَمَرْتُ أَنَا وَأُخْتِي عَائِشَةُ وَالزُّبَيْرُ وَفُلاَنٌ وَفُلاَنٌ فَلَمَّا مَسَحْنَا الْبَيْتَ أَحْلَلْنَا ثُمَّ أَهْلَلْنَا مِنَ الْعَشِيِّ بِالْحَجِّ ‏.‏ قَالَ هَارُونُ فِي رِوَايَتِهِ أَنَّ مَوْلَى أَسْمَاءَ ‏.‏ وَلَمْ يُسَمِّ عَبْدَ اللَّهِ ‏.‏\hadithno{3004}\hadithtrans{Abdullah, the freed slave of Asma' bint Abu Bakr (Allah be pleased with them), narrated that he used to hear Asma, ' whenever she passed by Hajun, saying (these words):" May there be peace and blessing of Allah upon His Messenger." We used to stay here along with him with light burdens. Few were our rides, and small were our provisions. I performed 'Umra and so did my sister 'A'isha, and Zubair and so and so. And as we touched the House (performed circumambulation and Sa'i) we put off Ihram, and then again put on Ihram in the afternoon for Hajj. Harun (one of the narrators) in one of the narrations said: The freed slave of Asma' and he did not mention 'Abdullah}}
\hadithdefcmd{muslim}{3005}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ مُسْلِمٍ الْقُرِّيِّ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ - رضى الله عنهما - عَنْ مُتْعَةِ الْحَجِّ، فَرَخَّصَ فِيهَا وَكَانَ ابْنُ الزُّبَيْرِ يَنْهَى عَنْهَا فَقَالَ هَذِهِ أُمُّ ابْنِ الزُّبَيْرِ تُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِيهَا فَادْخُلُوا عَلَيْهَا فَاسْأَلُوهَا قَالَ فَدَخَلْنَا عَلَيْهَا فَإِذَا امْرَأَةٌ ضَخْمَةٌ عَمْيَاءُ فَقَالَتْ قَدْ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهَا ‏.‏\hadithno{3005}\hadithtrans{Muslim al-Qurri reported:I asked Ibn Abbas (Allah be pleased with them) about Tamattu' in Hajj and he permitted it, whereas Ibn Zubair had forbidden it. He (Ibn 'Abbas) said: This is the mother of Ibn Zubair who states that Allah's Messenger (ﷺ) had permitted it, so you better go to her and ask her about it. He (Muslim al-Qurri said): So we went to her and she was a bulky blind lady and she said: Verily Allah's Messenger (ﷺ) permitted it}}
\hadithdefcmd{muslim}{3006}{وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، ح وَحَدَّثَنَاهُ ابْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - جَمِيعًا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ فَأَمَّا عَبْدُ الرَّحْمَنِ فَفِي حَدِيثِهِ الْمُتْعَةُ وَلَمْ يَقُلْ مُتْعَةُ الْحَجِّ ‏.‏ وَأَمَّا ابْنُ جَعْفَرٍ فَقَالَ قَالَ شُعْبَةُ قَالَ مُسْلِمٌ لاَ أَدْرِي مُتْعَةُ الْحَجِّ أَوْ مُتْعَةُ النِّسَاءِ ‏.‏\hadithno{3006}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters, but with a slight variation of words}}
\hadithdefcmd{muslim}{3007}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُسْلِمٌ الْقُرِّيُّ، سَمِعَ ابْنَ عَبَّاسٍ، - رضى الله عنهما - يَقُولُ أَهَلَّ النَّبِيُّ صلى الله عليه وسلم بِعُمْرَةٍ وَأَهَلَّ أَصْحَابُهُ بِحَجٍّ فَلَمْ يَحِلَّ النَّبِيُّ صلى الله عليه وسلم وَلاَ مَنْ سَاقَ الْهَدْىَ مِنْ أَصْحَابِهِ وَحَلَّ بَقِيَّتُهُمْ فَكَانَ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ فِيمَنْ سَاقَ الْهَدْىَ فَلَمْ يَحِلَّ ‏.‏\hadithno{3007}\hadithtrans{Muslim al-Qurri heardlbn 'Abbas (Allah be pleased with them) saying that Allah's Apostle (ﷺ) entered into the state of Ihram for Umra and his Companions for Hajj. Neither Allah's Apostle (ﷺ) nor those among his Companions who had brought sacrificial animals with them put off Ihram, whereas the rest (of the pilgrims) did so. Talha b. Ubaidullah was one of those who had brought the sacrificial animals along with them so he did not put off Ihram}}
\hadithdefcmd{muslim}{3008}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ وَكَانَ مِمَّنْ لَمْ يَكُنْ مَعَهُ الْهَدْىُ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ وَرَجُلٌ آخَرُ فَأَحَلاَّ ‏.‏\hadithno{3008}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters but with this variation (of words):" Talha and another person also were among those who had not brought the sacrificial animals with them and so they put off Ihram}}
\hadithdefcmd{muslim}{3009}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ كَانُوا يَرَوْنَ أَنَّ الْعُمْرَةَ فِي أَشْهُرِ الْحَجِّ مِنْ أَفْجَرِ الْفُجُورِ فِي الأَرْضِ وَيَجْعَلُونَ الْمُحَرَّمَ صَفَرً وَيَقُولُونَ إِذَا بَرَأَ الدَّبَرْ وَعَفَا الأَثَرْ وَانْسَلَخَ صَفَرْ حَلَّتِ الْعُمْرَةُ لِمَنِ اعْتَمَرْ ‏.‏ فَقَدِمَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ صَبِيحَةَ رَابِعَةٍ مُهِلِّينَ بِالْحَجِّ فَأَمَرَهُمْ أَنْ يَجْعَلُوهَا عُمْرَةً فَتَعَاظَمَ ذَلِكَ عِنْدَهُمْ فَقَالُوا يَا رَسُولَ اللَّهِ أَىُّ الْحِلِّ قَالَ ‏ "‏ الْحِلُّ كُلُّهُ ‏"‏ ‏.‏\hadithno{3009}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that they (the Arabs of pre-Islamic days) looked upon Umra during the months of Hajj as the greatest of sins on the earth. So they intercalated the month of Muharram for Safar and said:When the backs of their camels would become all right and traces (if the pilgrims) would be effaced (from the paths) and the month of Safar would be over, then Umra would be permissible for one who wants to perform it. When Allah's Apostle (ﷺ) and his Companions came in the state of Ihram for performing Hajj on the fourth (of Dhu'l-Hijja) he (Allah's Apostle) commanded them to change their state of Ihram (from Hajj) to that of 'Umra. It was something inconceivable for them. So they said: Messenger of Allah, is it a complete freedom (of the obligation) of Ihram? Thereupon he said: It is a complete freedom (from Ihram)}}
\hadithdefcmd{muslim}{3010}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَيُّوبَ، عَنْ أَبِي الْعَالِيَةِ، الْبَرَّاءِ أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، - رضى الله عنهما - يَقُولُ أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ فَقَدِمَ لأَرْبَعٍ مَضَيْنَ مِنْ ذِي الْحِجَّةِ فَصَلَّى الصُّبْحَ وَقَالَ لَمَّا صَلَّى الصُّبْحَ ‏ "‏ مَنْ شَاءَ أَنْ يَجْعَلَهَا عُمْرَةً فَلْيَجْعَلْهَا عُمْرَةً ‏"‏ ‏.‏\hadithno{3010}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) 'is reported to have said:The Messenger of Allah (ﷺ) put on Ihigm for Hajj. When four days of Dhu'l-Hijja were over, he led the dawn prayer, and when the prayer was complete, he said: He who wants to change it to Umra may do so}}
\hadithdefcmd{muslim}{3011}{وَحَدَّثَنَاهُ إِبْرَاهِيمُ بْنُ دِينَارٍ، حَدَّثَنَا رَوْحٌ، ح وَحَدَّثَنَا أَبُو دَاوُدَ الْمُبَارَكِيُّ، حَدَّثَنَا أَبُو شِهَابٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ، كُلُّهُمْ عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ أَمَّا رَوْحٌ وَيَحْيَى بْنُ كَثِيرٍ فَقَالاَ كَمَا قَالَ نَصْرٌ أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ ‏.‏ وَأَمَّا أَبُو شِهَابٍ فَفِي رِوَايَتِهِ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نُهِلُّ بِالْحَجِّ ‏.‏ وَفِي حَدِيثِهِمْ جَمِيعًا فَصَلَّى الصُّبْحَ بِالْبَطْحَاءِ ‏.‏ خَلاَ الْجَهْضَمِيَّ فَإِنَّهُ لَمْ يَقُلْهُ ‏.‏\hadithno{3011}\hadithtrans{Rauh and Yahya b. Kathir narrated as Nasr reported that the Messenger of Allah (ﷺ) entered into the state of Ihram for Hajj. And in the narration of Abu Shihab (the words are):We went out with the Messenger of Allah (ﷺ) pronouncing Talbiya for Hajj, And in an the ahadith (narrated in this connection the words are): He led the morning prayer at al-Batha', except al- jahdami who did not make mention of it}}
\hadithdefcmd{muslim}{3012}{وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفَضْلِ السَّدُوسِيُّ، حَدَّثَنَا وُهَيْبٌ، أَخْبَرَنَا أَيُّوبُ، عَنْ أَبِي الْعَالِيَةِ الْبَرَّاءِ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ لأَرْبَعٍ خَلَوْنَ مِنَ الْعَشْرِ وَهُمْ يُلَبُّونَ بِالْحَجِّ فَأَمَرَهُمْ أَنْ يَجْعَلُوهَا عُمْرَةً ‏.‏\hadithno{3012}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported:Allah's Messenger (ﷺ) came along with his Companions when four days had passed out of ten days (of Dhu'l-Hijja) and they were pronouncing Talbiya for Hajj, and he (the Holy Prophet) commanded them to change (this Ihram) into that of 'Umra}}
\hadithdefcmd{muslim}{3013}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الصُّبْحَ بِذِي طَوًى وَقَدِمَ لأَرْبَعٍ مَضَيْنَ مِنْ ذِي الْحِجَّةِ وَأَمَرَ أَصْحَابَهُ أَنْ يُحَوِّلُوا إِحْرَامَهُمْ بِعُمْرَةٍ إِلاَّ مَنْ كَانَ مَعَهُ الْهَدْىُ ‏.‏\hadithno{3013}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that Allah's Messenger (ﷺ) observed the morning prayer at Dhu Tawa (a valley near Mecca) and arrived (in Mecca) when four days of Dhul-Hijja had passed and he commanded his Companions that they should change their Ihram (of Hajj) to that of Umra, except those who had brought sacrificial animals with them}}
\hadithdefcmd{muslim}{3014}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَذِهِ عُمْرَةٌ اسْتَمْتَعْنَا بِهَا فَمَنْ لَمْ يَكُنْ عِنْدَهُ الْهَدْىُ فَلْيَحِلَّ الْحِلَّ كُلَّهُ فَإِنَّ الْعُمْرَةَ قَدْ دَخَلَتْ فِي الْحَجِّ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3014}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:This is the 'Umra of which we have taken advantage. So he who has not the sacrificial animal with him should get out of the state of Ihram completely, for 'Umra has been incorporated in Hajj until the Day of Resurrection}}
\hadithdefcmd{muslim}{3015}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا جَمْرَةَ الضُّبَعِيَّ، قَالَ تَمَتَّعْتُ فَنَهَانِي نَاسٌ عَنْ ذَلِكَ، فَأَتَيْتُ ابْنَ عَبَّاسٍ فَسَأَلْتُهُ عَنْ ذَلِكَ، فَأَمَرَنِي بِهَا ‏.‏ - قَالَ - ثُمَّ انْطَلَقْتُ إِلَى الْبَيْتِ فَنِمْتُ فَأَتَانِي آتٍ فِي مَنَامِي فَقَالَ عُمْرَةٌ مُتَقَبَّلَةٌ وَحَجٌّ مَبْرُورٌ - قَالَ - فَأَتَيْتُ ابْنَ عَبَّاسٍ فَأَخْبَرْتُهُ بِالَّذِي رَأَيْتُ فَقَالَ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ سُنَّةُ أَبِي الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{3015}\hadithtrans{Abu Jam at al-Dubu'i reported:I performed Tamattu' but the people dis- couraged me to do so. I came to Ibn 'Abbas and asked him about it. He ordered me to do so. I came to the House (Ka'ba) and slept. I saw a visitant in the dream who said: 'Umra is acceptable and so is the Hajj performed for God's sake. I came to Ibn Abbas and informed him about that Which I saw in the dream whereupon he said: Allah is the Greatest, Allah is the Greatest This is the Sunnah of Abu'l-Qasim (the Holy Pro- phet) (ﷺ)}}
\hadithdefcmd{muslim}{3016}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنِ ابْنِ أَبِي عَدِيٍّ، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، - عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ بِذِي الْحُلَيْفَةِ ثُمَّ دَعَا بِنَاقَتِهِ فَأَشْعَرَهَا فِي صَفْحَةِ سَنَامِهَا الأَيْمَنِ وَسَلَتَ الدَّمَ وَقَلَّدَهَا نَعْلَيْنِ ثُمَّ رَكِبَ رَاحِلَتَهُ فَلَمَّا اسْتَوَتْ بِهِ عَلَى الْبَيْدَاءِ أَهَلَّ بِالْحَجِّ ‏.‏\hadithno{3016}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that Allah's Messenger (ﷺ) observed the Zuhr prayer at Dhu'l-Hulaifa; then called for his she-camel and marked it on the right side of its bump, removed the blood from it, and tied two sandals round its neck. He then mounted his camel, and when it brought him up to al-Baida', he pronounced Talbiya for the Pilgrimage}}
\hadithdefcmd{muslim}{3017}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، فِي هَذَا الإِسْنَادِ ‏.‏ بِمَعْنَى حَدِيثِ شُعْبَةَ غَيْرَ أَنَّهُ قَالَ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم لَمَّا أَتَى ذَا الْحُلَيْفَةِ ‏.‏ وَلَمْ يَقُلْ صَلَّى بِهَا الظُّهْرَ ‏.‏\hadithno{3017}\hadithtrans{This hadith has been narrated on the authority of Qatada with the same chain of transmitters but with this variation (of words):" When Allah's Apostle (ﷺ) came to Dhu'l-Hulaifa" and he made no mention (of the fact) that he led the Zuhr prayer}}
\hadithdefcmd{muslim}{3018}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا حَسَّانَ الأَعْرَجَ، قَالَ قَالَ رَجُلٌ مِنْ بَنِي الْهُجَيْمِ لاِبْنِ عَبَّاسٍ مَا هَذِهِ الْفُتْيَا الَّتِي قَدْ تَشَغَّفَتْ أَوْ تَشَغَّبَتْ بِالنَّاسِ أَنَّ مَنْ طَافَ بِالْبَيْتِ فَقَدْ حَلَّ فَقَالَ سُنَّةُ نَبِيِّكُمْ صلى الله عليه وسلم وَإِنْ رَغِمْتُمْ ‏.‏\hadithno{3018}\hadithtrans{Abu Hassan al-A'raj reported that a person from Bani Hujaim said to Ibn 'Abbas (Allah be pleased with them):What is this religious verdict of yours which has engaged the attention of the people or which has become a matter of dispute among them that he who circumambulated the House can be free from Ihram? Thereupon he said: That is the Sunnah of your Apostle (ﷺ), even though you may not approve of it}}
\hadithdefcmd{muslim}{3019}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ، قَالَ قِيلَ لاِبْنِ عَبَّاسٍ إِنَّ هَذَا الأَمْرَ قَدْ تَفَشَّغَ بِالنَّاسِ مَنْ طَافَ بِالْبَيْتِ فَقَدْ حَلَّ الطَّوَافُ عُمْرَةٌ ‏.‏ فَقَالَ سُنَّةُ نَبِيِّكُمْ صلى الله عليه وسلم وَإِنْ رَغِمْتُمْ ‏.‏\hadithno{3019}\hadithtrans{Abu Hassan reported:It was said to Ibn 'Abbas (Allah be pleased with them) that this affair had engaged the attention of the people that he who circumambu- lates the House was permitted to circumambulate for Umra (even though he was in a state of Ihram for Hajj), whereupon he said: That is the Sunnah of your Apostle (ﷺ), even though you may not approve of it}}
\hadithdefcmd{muslim}{3020}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، قَالَ كَانَ ابْنُ عَبَّاسٍ يَقُولُ لاَ يَطُوفُ بِالْبَيْتِ حَاجٌّ وَلاَ غَيْرُ حَاجٍّ إِلاَّ حَلَّ ‏.‏ قُلْتُ لِعَطَاءٍ مِنْ أَيْنَ يَقُولُ ذَلِكَ قَالَ مِنْ قَوْلِ اللَّهِ تَعَالَى ‏\{‏ ثُمَّ مَحِلُّهَا إِلَى الْبَيْتِ الْعَتِيقِ‏\}‏ قَالَ قُلْتُ فَإِنَّ ذَلِكَ بَعْدَ الْمُعَرَّفِ ‏.‏ فَقَالَ كَانَ ابْنُ عَبَّاسٍ يَقُولُ هُوَ بَعْدَ الْمُعَرَّفِ وَقَبْلَهُ ‏.‏ وَكَانَ يَأْخُذُ ذَلِكَ مِنْ أَمْرِ النَّبِيِّ صلى الله عليه وسلم حِينَ أَمَرَهُمْ أَنْ يَحِلُّوا فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{3020}\hadithtrans{Ata' said:Ibn 'Abbas (Allah be pleased with them) used to say that a pilgrim or non-pilgrim (one performing 'Umar) who circumambulates the House is free from the responsibility of Ihram. I (Ibn Juraij, one of the narrators) said to 'Ata': On what authority does he (Ibn Abbas) say this? He said: On the authority uf Allah's words:" Then their place of sacrifice is the Ancient House" (al-Qur'an, xxii. 33). I said: It concerns the time after staying at 'Arafat, whereupon he said: Ibn 'Abbas (Allah be pleased with them) had stated (that the place of sacrifice is the Ancient House) ; it way be after staying at 'Arafat or before (staying there). And he (Ibn Abbas) made this deduction I from the command of Allah's Apostle (ﷺ) when he had ordered to put off Ihram on the occasion of the Farewell Pilgrimage}}
\hadithdefcmd{muslim}{3021}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ حُجَيْرٍ، عَنْ طَاوُسٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ قَالَ لِي مُعَاوِيَةُ أَعَلِمْتَ أَنِّي قَصَّرْتُ مِنْ رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم عِنْدَ الْمَرْوَةِ بِمِشْقَصٍ فَقُلْتُ لَهُ لاَ أَعْلَمُ هَذَا إِلاَّ حُجَّةً عَلَيْكَ ‏.‏\hadithno{3021}\hadithtrans{Ibn Abbas reported that Mu'awiya had said to them:Do you know that I clipped some hair from the head of Allah's Messenger (ﷺ) at al- Marwa with the help of a clipper? I said: I do not know it except as it verdict against you}}
\hadithdefcmd{muslim}{3022}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي الْحَسَنُ، بْنُ مُسْلِمٍ عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، أَخْبَرَهُ قَالَ قَصَّرْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِشْقَصٍ وَهُوَ عَلَى الْمَرْوَةِ أَوْ رَأَيْتُهُ يُقَصَّرُ عَنْهُ بِمِشْقَصٍ وَهُوَ عَلَى الْمَرْوَةِ ‏.‏\hadithno{3022}\hadithtrans{Ibn Abbis (Allah be pleased with him) reported that Mu'awiya b. Abu Safyin had told him:I clipped the hair (from the head of) Allah's Messenger (may peace he upon him) with a clipper while he was at al-Marwa, or I saw him getting his hair clipped with a clipper as he was at al-Marwa}}
\hadithdefcmd{muslim}{3024}{وَحَدَّثَنَا حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، عَنْ دَاوُدَ، عَنْ أَبِي نَضْرَةَ، عَنْ جَابِرٍ، وَعَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنهما - قَالاَ قَدِمْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم وَنَحْنُ نَصْرُخُ بِالْحَجِّ صُرَاخًا ‏.‏\hadithno{3024}\hadithtrans{jibir and Abil Salld al-Khudri (Allah be pleased with them) reported:We went with Allah's Apostle (ﷺ) and we were pronouncing Talbiya for Hajj loudly}}
\hadithdefcmd{muslim}{3025}{حَدَّثَنِي حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنْ عَاصِمٍ، عَنْ أَبِي نَضْرَةَ، قَالَ كُنْتُ عِنْدَ جَابِرِ بْنِ عَبْدِ اللَّهِ فَأَتَاهُ آتٍ فَقَالَ إِنَّ ابْنَ عَبَّاسٍ وَابْنَ الزُّبَيْرِ اخْتَلَفَا فِي الْمُتْعَتَيْنِ فَقَالَ جَابِرٌ فَعَلْنَاهُمَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ نَهَانَا عَنْهُمَا عُمَرُ فَلَمْ نَعُدْ لَهُمَا ‏\hadithno{3025}\hadithtrans{Abd Nadra reported:While I was in the company of Jibir, a person came and said: There is difference of opinion amomg Ibn Abbas and Ibn Zubair about two Mut'as (benefits, Tamattul in Hajj and temporary marriage with women), whereupon jibir said: We have been doing this during the lifetime of Allah's Messenger (way peace be upon him), and then 'Umar forbade us to do so, and we never resorted to them}}
\hadithdefcmd{muslim}{3026}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنِي سَلِيمُ بْنُ حَيَّانَ، عَنْ مَرْوَانَ الأَصْفَرِ، عَنْ أَنَسٍ، - رضى الله عنه - أَنَّ عَلِيًّا، قَدِمَ مِنَ الْيَمَنِ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِمَ أَهْلَلْتَ ‏"‏ ‏.‏ فَقَالَ أَهْلَلْتُ بِإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ لَوْلاَ أَنَّ مَعِيَ الْهَدْىَ لأَحْلَلْتُ ‏"‏ ‏.‏\hadithno{3026}\hadithtrans{Anas (Allah be pleased with him) reported that 'Ali (Allah be pleased with him) came from the Yemen, and the Apostle (ﷺ) said:With (what intention) have you put on Ihram? He said: I have put on Ibram in accordance with the intention with which Allah's Apostle (ﷺ) has put on Ibram, whereupon he (the Holy Prophet) said: Had there not been the sacrificial animals with me, I would have put off Ihram (after performing 'Umra)}}
\hadithdefcmd{muslim}{3027}{وَحَدَّثَنِيهِ حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، ح وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمٍ، حَدَّثَنَا بَهْزٌ، قَالاَ حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي رِوَايَةِ بَهْزٍ ‏ "‏ لَحَلَلْتُ‏"‏ ‏.‏\hadithno{3027}\hadithtrans{This hadith is narrated by Salim b. Hayyin with the same chain of transmitters, but with a slight variation of words}}
\hadithdefcmd{muslim}{3030}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ سَعِيدٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - حَدَّثَنِي الزُّهْرِيُّ، عَنْ حَنْظَلَةَ الأَسْلَمِيِّ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، - رضى الله عنه - يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَيُهِلَّنَّ ابْنُ مَرْيَمَ بِفَجِّ الرَّوْحَاءِ حَاجًّا أَوْ مُعْتَمِرًا أَوْ لَيَثْنِيَنَّهُمَا ‏"‏ ‏.‏ وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ قَالَ ‏"‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ ‏"‏ ‏.‏\hadithno{3030}\hadithtrans{Hanzala al-Aslami reported:I heard Abu Huraira (Allah be pleased with him) as narrating from Allah's Apostle (ﷺ) who said: By Him in Whose Hand is my life. Ibn Maryam (Jesus Christ) would certainly pronounce Talbiya for Hajj or for Umra or for both (simultaneously as a Qiran) In the valley of Rauha}}
\hadithdefcmd{muslim}{3031}{وَحَدَّثَنِيهِ حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ حَنْظَلَةَ بْنِ عَلِيٍّ الأَسْلَمِيِّ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، - رضى الله عنه - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِهِمَا ‏.‏\hadithno{3031}\hadithtrans{Hanzala b. 'Ali al-Aslaml reported that he had heard Abu Huraira (Allah be pleased with him) as saying that Allah's Messenger (ﷺ) had said:By Him In Whose Hand is my life; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{3032}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسًا، - رضى الله عنه - أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اعْتَمَرَ أَرْبَعَ عُمَرٍ كُلُّهُنَّ فِي ذِي الْقَعْدَةِ إِلاَّ الَّتِي مَعَ حَجَّتِهِ عُمْرَةً مِنَ الْحُدَيْبِيَةِ أَوْ زَمَنَ الْحُدَيْبِيَةِ فِي ذِي الْقَعْدَةِ وَعُمْرَةً مِنَ الْعَامِ الْمُقْبِلِ فِي ذِي الْقَعْدَةِ وَعُمْرَةً مِنْ جِعْرَانَةَ حَيْثُ قَسَمَ غَنَائِمَ حُنَيْنٍ فِي ذِي الْقَعْدَةِ وَعُمْرَةً مَعَ حَجَّتِهِ‏.‏\hadithno{3032}\hadithtrans{Qatida saia. that Anas (Allah be pleased with him) had informed him that Allah's Messenger (ﷺ) performed four 'Umras, all during the month of Dhu'l-Qa'da except the one he performed along with Hajj (and these are) the Umra that he performed from al-Hudaibiya or during the time of (the truce of) Hudaibiya in the month of Dhu'l-Qa'da then the Umra of the next year in the month of Dhu'l-Qa'da, then the Umra for which b'e had started from ji'rana, the place where he distributed the spoils of (the battle of) Hunain in the month of Dhu'l-Qa'da, and then the 'Umra that he performed along with his Hajj (on the occasion of the Farewell Pilgrimage)}}
\hadithdefcmd{muslim}{3033}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، قَالَ سَأَلْتُ أَنَسًا كَمْ حَجَّ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ حَجَّةً وَاحِدَةً وَاعْتَمَرَ أَرْبَعَ عُمَرٍ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ هَدَّابٍ ‏.‏\hadithno{3033}\hadithtrans{Qatada said:I asked Anas (Allah be pleased with him) as to how many Pilgrimages had been performed by Allah's Messenger (ﷺ), and he replied: One Hajj and four `Umras were performed by him. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{3034}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، أَخْبَرَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَأَلْتُ زَيْدَ بْنَ أَرْقَمَ كَمْ غَزَوْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَبْعَ عَشْرَةَ ‏.‏ قَالَ وَحَدَّثَنِي زَيْدُ بْنُ أَرْقَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَزَا تِسْعَ عَشْرَةَ وَأَنَّهُ حَجَّ بَعْدَ مَا هَاجَرَ حَجَّةً وَاحِدَةً حَجَّةَ الْوَدَاعِ ‏.‏ قَالَ أَبُو إِسْحَاقَ وَبِمَكَّةَ أُخْرَى ‏.‏\hadithno{3034}\hadithtrans{Abu lshaq said:I asked Zaid b. Arqam: In how many military expeditions have you participated with Allah's Messenger (ﷺ)? He said: In seventeen (expeditions). He (Abu Ishaq) said: Zaid b. Arqam reported to me that Allah's Messenger (ﷺ) had led nineteen expeditions. And he performed Hajj only once after Migration, and that was the Farewell Pilgrimage. Abu Ishaq also said: The second (Hajj) he performed at Mecca (before his Migration to Medina)}}
\hadithdefcmd{muslim}{3035}{وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ عَطَاءً، يُخْبِرُ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، قَالَ كُنْتُ أَنَا وَابْنُ، عُمَرَ مُسْتَنِدَيْنِ إِلَى حُجْرَةِ عَائِشَةَ وَإِنَّا لَنَسْمَعُ ضَرْبَهَا بِالسِّوَاكِ تَسْتَنُّ - قَالَ - فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ أَعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم فِي رَجَبٍ قَالَ نَعَمْ ‏.‏ فَقُلْتُ لِعَائِشَةَ أَىْ أُمَّتَاهُ أَلاَ تَسْمَعِينَ مَا يَقُولُ أَبُو عَبْدِ الرَّحْمَنِ قَالَتْ وَمَا يَقُولُ قُلْتُ يَقُولُ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم فِي رَجَبٍ ‏.‏ فَقَالَتْ يَغْفِرُ اللَّهُ لأَبِي عَبْدِ الرَّحْمَنِ لَعَمْرِي مَا اعْتَمَرَ فِي رَجَبٍ وَمَا اعْتَمَرَ مِنْ عُمْرَةٍ إِلاَّ وَإِنَّهُ لَمَعَهُ ‏.‏ قَالَ وَابْنُ عُمَرَ يَسْمَعُ فَمَا قَالَ لاَ وَلاَ نَعَمْ ‏.‏ سَكَتَ ‏.‏\hadithno{3035}\hadithtrans{Ataa reported that 'Urwa b. Zubair (Allah be pleased with him) had informed him (this):I and Ibn 'Umar were reclining against the (wall) of the apartment of A'isha and we were listening to the sound produced by the brushing of her teeth. I said Abu Abd al-Rahman (the kunya of 'Abdullah b. Umar), did Allah's Apostle (ﷺ) perform 'Umra in the month of Rijab? He said: Yes. I said to 'A'isha: Mother, are you listening to what Abu Abd al-Rabman is saying? She said: What is he Saying? I said: He is saying that Allah's Apostle (ﷺ) performed 'Umra during the month of Rajab, whereupon she said: May Allah grant pardon to Abu Abd al-Rahman I By my life he (the Holy Prophet) did not perform 'Umra during the month of Rajab. And never was there an Umra performed by him (the Holy Prophet) in which he ('Abdullah b. 'Umar) did not join him. Ibn 'Umar heard this and said nothing to affirm It or to deny it, but kept quiet}}
\hadithdefcmd{muslim}{3036}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، قَالَ دَخَلْتُ أَنَا وَعُرْوَةُ بْنُ الزُّبَيْرِ الْمَسْجِدَ، فَإِذَا عَبْدُ اللَّهِ بْنُ عُمَرَ جَالِسٌ إِلَى حُجْرَةِ عَائِشَةَ وَالنَّاسُ يُصَلُّونَ الضُّحَى فِي الْمَسْجِدِ فَسَأَلْنَاهُ عَنْ صَلاَتِهِمْ فَقَالَ بِدْعَةٌ ‏.‏ فَقَالَ لَهُ عُرْوَةُ يَا أَبَا عَبْدِ الرَّحْمَنِ كَمِ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ أَرْبَعَ عُمَرٍ إِحْدَاهُنَّ فِي رَجَبٍ ‏.‏ فَكَرِهْنَا أَنْ نُكَذِّبَهُ وَنَرُدَّ عَلَيْهِ وَسَمِعْنَا اسْتِنَانَ عَائِشَةَ فِي الْحُجْرَةِ ‏.‏ فَقَالَ عُرْوَةُ أَلاَ تَسْمَعِينَ يَا أُمَّ الْمُؤْمِنِينَ إِلَى مَا يَقُولُ أَبُو عَبْدِ الرَّحْمَنِ فَقَالَتْ وَمَا يَقُولُ قَالَ يَقُولُ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم أَرْبَعَ عُمَرٍ إِحْدَاهُنَّ فِي رَجَبٍ ‏.‏ فَقَالَتْ يَرْحَمُ اللَّهُ أَبَا عَبْدِ الرَّحْمَنِ مَا اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ وَهُوَ مَعَهُ وَمَا اعْتَمَرَ فِي رَجَبٍ قَطُّ ‏.‏\hadithno{3036}\hadithtrans{Mujahid reported:I and 'Urwah b. Zubair entered the mosque and found 'Abdullah b. 'Umar sitting near the apartment of A'ishah and the people were observing the forenoon prayer (when the sun had sufficiently risen). We asked him about their prayer, and he said: It is bid'a (innovation), Urwah said to him: O Abu Abd al-Rahman, how many 'umrahs did Allah's Messenger (ﷺ) perform? He said: Four 'umrahs, one he performed during the month of Rajab. We were reluctant either to believe him or reject him. We heard the noise of brushing of her teeth by 'A'ishah in her apartment. 'Urwah said: Mother of the Faithful, are you not hearing what Abi 'Abd al-Rahman is saying? She said: What is he saying? Thereupon he ('Urwah) said: He (Ibn 'Umar) states that Allah's Apostle (ﷺ) performed four 'umrahs and one of them during the month of Rajab. Thereupon she remarked: May Allah have mercy upon Abu 'Abd al-Rahman. Never did Allah's Messenger (ﷺ) perform 'Umrah in which he did not accompany him, and he (Allah's Apostle) never performed 'Umrah during the month of Rajab}}
\hadithdefcmd{muslim}{3037}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يُحَدِّثُنَا قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاِمْرَأَةٍ مِنَ الأَنْصَارِ سَمَّاهَا ابْنُ عَبَّاسٍ فَنَسِيتُ اسْمَهَا ‏"‏ مَا مَنَعَكِ أَنْ تَحُجِّي مَعَنَا ‏"‏ ‏.‏ قَالَتْ لَمْ يَكُنْ لَنَا إِلاَّ نَاضِحَانِ فَحَجَّ أَبُو وَلَدِهَا وَابْنُهَا عَلَى نَاضِحٍ وَتَرَكَ لَنَا نَاضِحًا نَنْضِحُ عَلَيْهِ قَالَ ‏"‏ فَإِذَا جَاءَ رَمَضَانُ فَاعْتَمِرِي فَإِنَّ عُمْرَةً فِيهِ تَعْدِلُ حَجَّةً ‏"‏ ‏.‏\hadithno{3037}\hadithtrans{Ataa reported:I heard Ibn Abbas (Allah be pleased with him) narrating to us that Allah's Messenger (ﷺ) said to a woman of the Ansar (Ibn Abbas had mentioned her name but I have forgotten it): 'What has prevented you that you do not perform Hajj along with us? She said: We have only two camels for carrying water. One of the camels has been taken by my husband and my son for performing Hajj and one has been left for us for carrying water, whereupon he (the Holy Prophet) said: So when the month of Ramadan come, perform Umra, for'Umra in this (month) is equal to Hajj (in reward)}}
\hadithdefcmd{muslim}{3040}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْرُجُ مِنْ طَرِيقِ الشَّجَرَةِ وَيَدْخُلُ مِنْ طَرِيقِ الْمُعَرَّسِ وَإِذَا دَخَلَ مَكَّةَ دَخَلَ مِنَ الثَّنِيَّةِ الْعُلْيَا وَيَخْرُجُ مِنَ الثَّنِيَّةِ السُّفْلَى ‏.‏\hadithno{3040}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) used to come out (of Medina) by way of al-Shajarah and entered it by the way of al-Mu'arras and whenever he entered Mecca, he entered it from the upper side and went out of it from the lower side}}
\hadithdefcmd{muslim}{3041}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ وَقَالَ فِي رِوَايَةِ زُهَيْرٍ الْعُلْيَا الَّتِي بِالْبَطْحَاءِ ‏.‏\hadithno{3041}\hadithtrans{This hadith has been narrated on the authority of 'Ubaidullah with the same chain of transmitters and in the narration transmitted by Zubair (it is mentioned) that the upper side is that'which is at al-Batha}}
\hadithdefcmd{muslim}{3042}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا سُفْيَانُ، - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا جَاءَ إِلَى مَكَّةَ دَخَلَهَا مِنْ أَعْلاَهَا وَخَرَجَ مِنْ أَسْفَلِهَا ‏.‏\hadithno{3042}\hadithtrans{A'isha (Allah be pleased with her) reported that when Allah's Messenger may peace be upon him) came to Mecca he entered from its upper side and came out from its lower side}}
\hadithdefcmd{muslim}{3043}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَامَ الْفَتْحِ مِنْ كَدَاءٍ مِنْ أَعْلَى مَكَّةَ ‏.‏ قَالَ هِشَامٌ فَكَانَ أَبِي يَدْخُلُ مِنْهُمَا كِلَيْهِمَا وَكَانَ أَبِي أَكْثَرَ مَا يَدْخُلُ مِنْ كَدَاءٍ ‏.‏\hadithno{3043}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) entered Mecca during the year of Victory from Kada I. e. from the upper side. Hisham said.. My father entered It from both the Fides, but generally he entered from Kada}}
\hadithdefcmd{muslim}{3044}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَاتَ بِذِي طَوًى حَتَّى أَصْبَحَ ثُمَّ دَخَلَ مَكَّةَ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ يَفْعَلُ ذَلِكَ ‏.‏ وَفِي رِوَايَةِ ابْنِ سَعِيدٍ حَتَّى صَلَّى الصُّبْحَ ‏.‏ قَالَ يَحْيَى أَوْ قَالَ حَتَّى أَصْبَحَ ‏.‏\hadithno{3044}\hadithtrans{Ibn Umar (Allah be pleased with him) reported that Allah's Messenger may peace be upon him) spent the night at Dhi Tuwa till it was dawn and then entered Mecca. 'Abdullah (b. 'Umar) himself did like it. And in the narration transmitted by Ibn Sa'ld (the words are):Until he obrerved the dawn prayer. Yahya (another narrator) said: Until it was dawn}}
\hadithdefcmd{muslim}{3045}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ لاَ يَقْدَمُ مَكَّةَ إِلاَّ بَاتَ بِذِي طَوًى حَتَّى يُصْبِحَ وَيَغْتَسِلَ ثُمَّ يَدْخُلُ مَكَّةَ نَهَارًا وَيَذْكُرُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ فَعَلَهُ ‏.‏\hadithno{3045}\hadithtrans{Nafi' reported that Ibn Umar (Allah be pleased with them) did not enter Mecca without spending the night at Dhi Tawu until it was dawn, when he took a bath, and then entered Mecca in the morning, and made a mention that Allah's Apostle (ﷺ) did that}}
\hadithdefcmd{muslim}{3046}{وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، حَدَّثَنِي أَنَسٌ، - يَعْنِي ابْنَ عِيَاضٍ - عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَنْزِلُ بِذِي طَوًى وَيَبِيتُ بِهِ حَتَّى يُصَلِّيَ الصُّبْحَ حِينَ يَقْدَمُ مَكَّةَ وَمُصَلَّى رَسُولِ اللَّهِ صلى الله عليه وسلم ذَلِكَ عَلَى أَكَمَةٍ غَلِيظَةٍ لَيْسَ فِي الْمَسْجِدِ الَّذِي بُنِيَ ثَمَّ وَلَكِنْ أَسْفَلَ مِنْ ذَلِكَ عَلَى أَكَمَةٍ غَلِيظَةٍ ‏.‏\hadithno{3046}\hadithtrans{Abdullah (b. 'Umar) reported that whenever Allah's Messenger (ﷺ) entered Mecca, he got down at Dhi Tuwa and spend the night there until he observed the dawn prayer. And Allah's Messenger (ﷺ) observed this prayer on a rough hillock, and not in the mosque which had been then built there, but to the lower side of it (the mosque) on a hillock}}
\hadithdefcmd{muslim}{3047}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، حَدَّثَنِي أَنَسٌ، - يَعْنِي ابْنَ عِيَاضٍ - عَنْ مُوسَى، بْنِ عُقْبَةَ عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَقْبَلَ فُرْضَتَىِ الْجَبَلِ الَّذِي بَيْنَهُ وَبَيْنَ الْجَبَلِ الطَّوِيلِ نَحْوَ الْكَعْبَةِ يَجْعَلُ الْمَسْجِدَ الَّذِي بُنِيَ ثَمَّ يَسَارَ الْمَسْجِدِ الَّذِي بِطَرَفِ الأَكَمَةِ وَمُصَلَّى رَسُولِ اللَّهِ صلى الله عليه وسلم أَسْفَلَ مِنْهُ عَلَى الأَكَمَةِ السَّوْدَاءِ يَدَعُ مِنَ الأَكَمَةِ عَشْرَ أَذْرُعٍ أَوْ نَحْوَهَا ثُمَّ يُصَلِّي مُسْتَقْبِلَ الْفُرْضَتَيْنِ مِنَ الْجَبَلِ الطَّوِيلِ الَّذِي بَيْنَكَ وَبَيْنَ الْكَعْبَةِ صلى الله عليه وسلم ‏.‏\hadithno{3047}\hadithtrans{Nafi' reported that Abdullah (b. 'Umar) informed him that Allah's Messenger (ﷺ) turned his face to the two hillocks which intervened between him and the long mountain by the side of the Ka'ba, and the mosque which had been built there was thus on the left of the hillock. Allah's Messenger's (ﷺ) place of prayer was lower than the black hillock, at a distance of ten cubits or near it. He (ﷺ) would then observe prayer facing these two hillocks of the long mountain that is intervening between you and the Ka'ba}}
\hadithdefcmd{muslim}{3048}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا طَافَ بِالْبَيْتِ الطَّوَافَ الأَوَّلَ خَبَّ ثَلاَثًا وَمَشَى أَرْبَعًا وَكَانَ يَسْعَى بِبَطْنِ الْمَسِيلِ إِذَا طَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَكَانَ ابْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{3048}\hadithtrans{Nafi' reported on the authority of Ibn Umar (Allah be pleased with them) that when Allah's Messenger (ﷺ) circumambulated the House, while observing the first circumambulation, he walked swiftly in three (circuits), and walked in four circuits, and ran in the bottom of the valley as he moved between al-Safa and al-Marwa. Ibn 'Umar (Allah be pleased with them) also used to do like this}}
\hadithdefcmd{muslim}{3049}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ مُوسَى بْنِ، عُقْبَةَ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا طَافَ فِي الْحَجِّ وَالْعُمْرَةِ أَوَّلَ مَا يَقْدَمُ فَإِنَّهُ يَسْعَى ثَلاَثَةَ أَطْوَافٍ بِالْبَيْتِ ثُمَّ يَمْشِي أَرْبَعَةً ثُمَّ يُصَلِّي سَجْدَتَيْنِ ثُمَّ يَطُوفُ بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏\hadithno{3049}\hadithtrans{Ibn'Umar (Allah be pleased with them) reported that when Allah's messenger (ﷺ) circumambulated in Hajj and Umra he walked swiftly in the first three circuit about the House, and then walked in four circuits, and then observed two rak'ahs of prayer, and then ran between al-Safa and al-Marwa}}
\hadithdefcmd{muslim}{3050}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالَ حَرْمَلَةُ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ يَقْدَمُ مَكَّةَ إِذَا اسْتَلَمَ الرُّكْنَ الأَسْوَدَ أَوَّلَ مَا يَطُوفُ حِينَ يَقْدَمُ يَخُبُّ ثَلاَثَةَ أَطْوَافٍ مِنَ السَّبْعِ ‏.‏\hadithno{3050}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported:I saw that when Allah's Messenger (ﷺ) came to Mecca and kissed the Black Stone, (in the first circumambulation) he moved quickly in three circuits out of seven circuits}}
\hadithdefcmd{muslim}{3051}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ أَبَانٍ الْجُعْفِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - قَالَ رَمَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْحَجَرِ إِلَى الْحَجَرِ ثَلاَثًا وَمَشَى أَرْبَعًا ‏.‏\hadithno{3051}\hadithtrans{Nafi' reported on the authority of Ibn Umar (Allah be pleased with them) that Allah's Messenger (ﷺ) walked swiftly from stone to stone in three circuits and walked (normally) in four}}
\hadithdefcmd{muslim}{3052}{وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا سُلَيْمُ بْنُ أَخْضَرَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، رَمَلَ مِنَ الْحَجَرِ إِلَى الْحَجَرِ وَذَكَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَهُ ‏.‏\hadithno{3052}\hadithtrans{Nafi' reported that Ibn Umar (Allah he pleased with them) walked swiftly from stone to stone, and stated that Allah's Messenger (ﷺ) did like this}}
\hadithdefcmd{muslim}{3053}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ عَنْ أَبِيهِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ - رضى الله عنهما - أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَلَ مِنَ الْحَجَرِ الأَسْوَدِ حَتَّى انْتَهَى إِلَيْهِ ثَلاَثَةَ أَطْوَافٍ ‏.‏\hadithno{3053}\hadithtrans{jabir b. Abdullah (Allah be pleased with them) reported:I saw Allah's Messenger (ﷺ) walking swiftly from the Black Stone till he completed three circuits up to it}}
\hadithdefcmd{muslim}{3054}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، وَابْنُ، جُرَيْجٍ عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَلَ الثَّلاَثَةَ أَطْوَافٍ مِنَ الْحَجَرِ إِلَى الْحَجَرِ ‏.‏\hadithno{3054}\hadithtrans{Jabir b." Abdullah (Allah be pleased with them) reported that Allah's Messenger (ﷺ) walked swiftly in three circuitsfrom stone to stone}}
\hadithdefcmd{muslim}{3055}{حَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ أَبِي الطُّفَيْلِ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ أَرَأَيْتَ هَذَا الرَّمَلَ بِالْبَيْتِ ثَلاَثَةَ أَطْوَافٍ وَمَشْىَ أَرْبَعَةِ أَطْوَافٍ أَسُنَّةٌ هُوَ فَإِنَّ قَوْمَكَ يَزْعُمُونَ أَنَّهُ سُنَّةٌ ‏.‏ قَالَ فَقَالَ صَدَقُوا وَكَذَبُوا ‏.‏ قَالَ قُلْتُ مَا قَوْلُكَ صَدَقُوا وَكَذَبُوا قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدِمَ مَكَّةَ فَقَالَ الْمُشْرِكُونَ إِنَّ مُحَمَّدًا وَأَصْحَابَهُ لاَ يَسْتَطِيعُونَ أَنْ يَطُوفُوا بِالْبَيْتِ مِنَ الْهُزَالِ وَكَانُوا يَحْسُدُونَهُ ‏.‏ قَالَ فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَرْمُلُوا ثَلاَثًا وَيَمْشُوا أَرْبَعًا ‏.‏ قَالَ قُلْتُ لَهُ أَخْبِرْنِي عَنِ الطَّوَافِ بَيْنَ الصَّفَا وَالْمَرْوَةِ رَاكِبًا أَسُنَّةٌ هُوَ فَإِنَّ قَوْمَكَ يَزْعُمُونَ أَنَّهُ سُنَّةٌ ‏.‏ قَالَ صَدَقُوا وَكَذَبُوا ‏.‏ قَالَ قُلْتُ وَمَا قَوْلُكَ صَدَقُوا وَكَذَبُوا قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَثُرَ عَلَيْهِ النَّاسُ يَقُولُونَ هَذَا مُحَمَّدٌ هَذَا مُحَمَّدٌ ‏.‏ حَتَّى خَرَجَ الْعَوَاتِقُ مِنَ الْبُيُوتِ ‏.‏ قَالَ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُضْرَبُ النَّاسُ بَيْنَ يَدَيْهِ فَلَمَّا كَثُرَ عَلَيْهِ رَكِبَ وَالْمَشْىُ وَالسَّعْىُ أَفْضَلُ ‏.‏\hadithno{3055}\hadithtrans{Abu Tufail reported:I said to Ibn `Abbas (Allah be pleased with them): Do you think that walking swiftly round the House in three circuits, and just walking in four circuits is the Sunnah (of the Holy Prophet), for your people say that it is Sunnah? Thereupon he (Ibn `Abbas) said: They have told the truth and the lie (too). I said: What do your words "They have told the truth and the lie (too)" imply? Thereupon he said: Allah's Messenger (ﷺ) came to Mecca and the polytheists said that Muhammad and his Companions had emaciated and would, therefore, be unable to circumambulate the House; and they felt jealous of him (the Holy Prophet). (It was due to this) that Allah's Messenger (ﷺ) commanded them to walk swiftly in three (circuits) and walk (normally) in four. I said to him: Inform me if it is Sunnah to observe Tawaf between al-Safa and al-Marwa while riding, for your people look upon it as Sunnah. He (Ibn `Abbas) said: They have told the truth and the lie too. I said: What do your words "They have told the truth and the lie too" imply? He said: When Allah's Messenger (ﷺ) had come to Mecca, there was such a large gathering of people around him that even the virgins had come out of their houses (to catch a glimpse of his face). And they were saying: He is Muhammad; He is Muhammad. Allah's Messenger (ﷺ) (was so gentle and kind) that the people were not beaten back (to make way) in front of him. When there was a throng (of people) around him, he rode (the she-camel). However, walking and trotting are better}}
\hadithdefcmd{muslim}{3056}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَزِيدُ، أَخْبَرَنَا الْجُرَيْرِيُّ، بِهَذَا الإِسْنَادِ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ وَكَانَ أَهْلُ مَكَّةَ قَوْمَ حَسَدٍ ‏.‏ وَلَمْ يَقُلْ يَحْسُدُونَهُ ‏.‏\hadithno{3056}\hadithtrans{This hadith has been narrated on the authority of jurairi with the same chain of transmitters but with a slight variation of words (and this is) that he (the narrator) did not say:" They felt jealous of him. but said: The people of Mecca, were jealous people}}
\hadithdefcmd{muslim}{3057}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي حُسَيْنٍ، عَنْ أَبِي الطُّفَيْلِ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ إِنَّ قَوْمَكَ يَزْعُمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَلَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ وَهْىَ سُنَّةٌ ‏.‏ قَالَ صَدَقُوا وَكَذَبُوا ‏.‏\hadithno{3057}\hadithtrans{Abu Tufail reported:I said to Ibn 'Abbas (Allah be pleased with them): People are of the view that Allah's Messenger (ﷺ) moved quickly round the House and between al-Safa and al-Marwa, and (thus) it is Sunnah. He said: They told the truth and they told the lie}}
\hadithdefcmd{muslim}{3058}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا زُهَيْرٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ، سَعِيدِ بْنِ الأَبْجَرِ عَنْ أَبِي الطُّفَيْلِ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ أُرَانِي قَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَصِفْهُ لِي ‏.‏ قَالَ قُلْتُ رَأَيْتُهُ عِنْدَ الْمَرْوَةِ عَلَى نَاقَةٍ وَقَدْ كَثُرَ النَّاسُ عَلَيْهِ ‏.‏ قَالَ فَقَالَ ابْنُ عَبَّاسٍ ذَاكَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنَّهُمْ كَانُوا لاَ يُدَعُّونَ عَنْهُ وَلاَ يُكْهَرُونَ ‏.‏\hadithno{3058}\hadithtrans{Abu Tufail reported; I. said to Ibn 'Abbas (Allah be pleased with them):I think that I saw Allah's Messenger (ﷺ). He (Ibn 'Abbis) said' Give a description of him to me. I said: I saw him near al-Marwa on the back of a she- camel, and people had thronged around him. Thereupon Ibn'Abbis said: It was Allah's Messenger (ﷺ) for they (the Compainions of the Holy Prophet) were neither pushed aside from him, nor were they turned away}}
\hadithdefcmd{muslim}{3059}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ مَكَّةَ وَقَدْ وَهَنَتْهُمْ حُمَّى يَثْرِبَ ‏.‏ قَالَ الْمُشْرِكُونَ إِنَّهُ يَقْدَمُ عَلَيْكُمْ غَدًا قَوْمٌ قَدْ وَهَنَتْهُمُ الْحُمَّى وَلَقُوا مِنْهَا شِدَّةً ‏.‏ فَجَلَسُوا مِمَّا يَلِي الْحِجْرَ وَأَمَرَهُمُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَرْمُلُوا ثَلاَثَةَ أَشْوَاطٍ وَيَمْشُوا مَا بَيْنَ الرُّكْنَيْنِ لِيَرَى الْمُشْرِكُونَ جَلَدَهُمْ فَقَالَ الْمُشْرِكُونَ هَؤُلاَءِ الَّذِينَ زَعَمْتُمْ أَنَّ الْحُمَّى قَدْ وَهَنَتْهُمْ هَؤُلاَءِ أَجْلَدُ مِنْ كَذَا وَكَذَا ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَلَمْ يَمْنَعْهُ أَنْ يَأْمُرَهُمْ أَنْ يَرْمُلُوا الأَشْوَاطَ كُلَّهَا إِلاَّ الإِبْقَاءُ عَلَيْهِمْ ‏.‏\hadithno{3059}\hadithtrans{Ibn 'Abbas (At lab be pleased with them) reported:Allah's Messenger (ﷺ) and his Companions came to Mecca and the fever in Medina had weakened them. Thereupon the polytheists (of Mecca) said: There would come to you a people whom the fever has made weak and they have suffered severely from it. They sat in Hatim. Thereupon Allah's Apostle (ﷺ) commanded them to walk quickly ift three circuits and walk (in four) between the two corners. so that the polytheists should. see their endurance. The polytheists then said (to one anothery You were under the impression that fever had emaciated them. whereas they are stronger than so and so. Ibn Abbas said: He (the Holy Prophet) did not command them (the Muslims) to walk quickly in all the circuits out of kindness to them}}
\hadithdefcmd{muslim}{3060}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، وَأَحْمَدُ بْنُ عَبْدَةَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ ابْنُ عَبْدَةَ حَدَّثَنَا سُفْيَانُ، - عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّمَا سَعَى رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَمَلَ بِالْبَيْتِ لِيُرِيَ الْمُشْرِكِينَ قُوَّتَهُ ‏.‏\hadithno{3060}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:Allah. 's Messenger (peace be upon him) observed Sa'i and walked quickly round the House with a view to showing his strength to the polytheists}}
\hadithdefcmd{muslim}{3061}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ مِنَ الْبَيْتِ إِلاَّ الرُّكْنَيْنِ الْيَمَانِيَيْنِ ‏.‏\hadithno{3061}\hadithtrans{Ahdullah b. Umar (reported) that he had not seen Allah's Messenger (way peace he upon him) touching anything in the House, except the two Yamani corners}}
\hadithdefcmd{muslim}{3062}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالَ أَبُو الطَّاهِرِ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُ مِنْ أَرْكَانِ الْبَيْتِ إِلاَّ الرُّكْنَ الأَسْوَدَ وَالَّذِي يَلِيهِ مِنْ نَحْوِ دُورِ الْجُمَحِيِّينَ ‏.‏\hadithno{3062}\hadithtrans{Salim reported on the authority of his father (Allah he pleased with him) that Allah'\& Messenger (tinny peace be upon him) did not touch any of the corners of the House. except that of Black Corner (in which the Black Stone is embedded and that (portion) near it, towards the houses of the tribe of jumuhi}}
\hadithdefcmd{muslim}{3063}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، ذَكَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَسْتَلِمُ إِلاَّ الْحَجَرَ وَالرُّكْنَ الْيَمَانِيَ\hadithno{3063}\hadithtrans{Nafi' reported on the authority of 'Abdullah (Allah be pleased with him) that Allah's Messenger (way peace be upon him) did not touch but the Stone and the Yamani corner}}
\hadithdefcmd{muslim}{3064}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَزُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، جَمِيعًا عَنْ يَحْيَى، الْقَطَّانِ - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا يَحْيَى، - عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ مَا تَرَكْتُ اسْتِلاَمَ هَذَيْنِ الرُّكْنَيْنِ - الْيَمَانِيَ وَالْحَجَرَ مُذْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُهُمَا فِي شِدَّةٍ وَلاَ رَخَاءٍ ‏.‏\hadithno{3064}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported:I have not abandoned touching of Yamani corners (and kissing of) the Stone since I saw Allah's messneger (ﷺ) touching them both In hardship and ease}}
\hadithdefcmd{muslim}{3065}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ جَمِيعًا عَنْ أَبِي خَالِدٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، - عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، قَالَ رَأَيْتُ ابْنَ عُمَرَ يَسْتَلِمُ الْحَجَرَ بِيَدِهِ ثُمَّ قَبَّلَ يَدَهُ وَقَالَ مَا تَرَكْتُهُ مُنْذُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ ‏.‏\hadithno{3065}\hadithtrans{NAfi' (Allah be pleased with him) reported:I saw'lbn 'Umar (Allah be pleased with them) touching the Stone with his hand and then kissing his hand. and he said: I have never abandoned it since I saw Allah's Messenger (way peace be upon him) doing It}}
\hadithdefcmd{muslim}{3066}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو بْنُ الْحَارِثِ، أَنَّ قَتَادَةَ بْنَ، دِعَامَةَ حَدَّثَهُ أَنَّ أَبَا الطُّفَيْلِ الْبَكْرِيَّ حَدَّثَهُ أَنَّهُ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُ غَيْرَ الرُّكْنَيْنِ الْيَمَانِيَيْنِ ‏.‏\hadithno{3066}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) is reported to have said that he did not see Allah's Messenger (ﷺ) touching other than the Yamani corners}}
\hadithdefcmd{muslim}{3067}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، وَعَمْرٌو، ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، أَنَّحَدَّثَهُ قَالَ قَبَّلَ عُمَرُ بْنُ الْخَطَّابِ الْحَجَرَ ثُمَّ قَالَ أَمَ وَاللَّهِ لَقَدْ عَلِمْتُ أَنَّكَ حَجَرٌ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقَبِّلُكَ مَا قَبَّلْتُكَ ‏.‏ زَادَ هَارُونُ فِي رِوَايَتِهِ قَالَ عَمْرٌو وَحَدَّثَنِي بِمِثْلِهَا زَيْدُ بْنُ أَسْلَمَ عَنْ أَبِيهِ أَسْلَمَ ‏.‏\hadithno{3067}\hadithtrans{Salim narrated on the authority of his father (Allah be pleased with him) that 'Umar b. al-Khattib (Allah be pleased with him) kissed (the Black Stone) and then said:By Allah, I know that you are a stone and if I were not to see Allah's Messenger (ﷺ) kissing you, I would not have kissed you. Harun said in his narration: A hadith like this has been transmitted to me by Zaid b. Aslam on the authority of his father Aslam}}
\hadithdefcmd{muslim}{3068}{وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، قَبَّلَ الْحَجَرَ وَقَالَ إِنِّي لأُقَبِّلُكَ وَإِنِّي لأَعْلَمُ أَنَّكَ حَجَرٌ وَلَكِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقَبِّلُكَ ‏.‏\hadithno{3068}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that Umar (Allah be pleased with him) kissed the Stone and said:I am kissing you, whereas I know that you are a stone, but I saw Allah's Messenger (ﷺ) kissing you (that Is why I kiss you)}}
\hadithdefcmd{muslim}{3069}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَالْمُقَدَّمِيُّ، وَأَبُو كَامِلٍ وَقُتَيْبَةُ بْنُ سَعِيدٍ كُلُّهُمْ عَنْ حَمَّادٍ، - قَالَ خَلَفٌ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ رَأَيْتُ الأَصْلَعَ - يَعْنِي عُمَرَ بْنَ الْخَطَّابِ - يُقَبِّلُ الْحَجَرَ وَيَقُولُ وَاللَّهِ إِنِّي لأُقَبِّلُكَ وَإِنِّي أَعْلَمُ أَنَّكَ حَجَرٌ وَأَنَّكَ لاَ تَضُرُّ وَلاَ تَنْفَعُ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَبَّلَكَ مَا قَبَّلْتُكَ ‏.‏ وَفِي رِوَايَةِ الْمُقَدَّمِيِّ وَأَبِي كَامِلٍ رَأَيْتُ الأُصَيْلِعَ ‏.‏\hadithno{3069}\hadithtrans{Abdullah b. Sarjis reported:I saw the bald one, i. e. 'Umar b. Khattib (Allah be pleased with him). kissing the Stone and saying: By Allah. I am kissing with full consciousness of the fact that you are a stone and that you can neither do any harm nor good; and if I had not seen Allah's Messenger (ﷺ) kissing you. I would not have kissed you. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{3070}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ وَابْنُ نُمَيْرٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، - قَالَ يَحْيَى أَخْبَرَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَابِسِ، بْنِ رَبِيعَةَ قَالَ رَأَيْتُ عُمَرَ يُقَبِّلُ الْحَجَرَ وَيَقُولُ إِنِّي لأُقَبِّلُكَ وَأَعْلَمُ أَنَّكَ حَجَرٌ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقَبِّلُكَ لَمْ أُقَبِّلْكَ ‏.‏\hadithno{3070}\hadithtrans{Abis b. Rabi'a reported:I saw 'Umar (Allah'be pleased with him) kissing the Stone and saying: I am kissing you and I know that you are a stone. And if I had not seen Allah's Messenger (ﷺ) kissing you, I would not have kissed you}}
\hadithdefcmd{muslim}{3071}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنْ وَكِيعٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا وَكِيعٌ، - عَنْ سُفْيَانَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الأَعْلَى، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ رَأَيْتُ عُمَرَ قَبَّلَ الْحَجَرَ وَالْتَزَمَهُ وَقَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِكَ حَفِيًّا ‏.‏\hadithno{3071}\hadithtrans{Suwaid b. Ghafala reported:I saw Umar (Allah be pleased with him) kissing the Stone and clinging to it and saying: I saw Allah's Messenger (ﷺ) having great love for you}}
\hadithdefcmd{muslim}{3072}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، بِهَذَا الإِسْنَادِ قَالَ وَلَكِنِّي رَأَيْتُ أَبَا الْقَاسِمِ صلى الله عليه وسلم بِكَ حَفِيًّا ‏.‏ وَلَمْ يَقُلْ وَالْتَزَمَهُ ‏.‏\hadithno{3072}\hadithtrans{This hadith has been narrated on the authority of Sufyan with the same chain of transmitters (and the words are):" That he ('Umar) said: But I saw Abu'l-Qasim (way peace be upon him) having great love for you." And he did not mention about clinging to it}}
\hadithdefcmd{muslim}{3073}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ فِي حَجَّةِ الْوَدَاعِ عَلَى بَعِيرٍ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ ‏.‏\hadithno{3073}\hadithtrans{Ibn 'Abbas (Allah be pleased with him) reported that Allah's Messenger (ﷺ) circumambulated the House on the occasion of the Farewell Pilgrimage on the back of his camel and touched the Corner (of Black Stone) with a stick}}
\hadithdefcmd{muslim}{3074}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي، الزُّبَيْرِ عَنْ جَابِرٍ، قَالَ طَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْبَيْتِ فِي حَجَّةِ الْوَدَاعِ عَلَى رَاحِلَتِهِ يَسْتَلِمُ الْحَجَرَ بِمِحْجَنِهِ لأَنْ يَرَاهُ النَّاسُ وَلِيُشْرِفَ وَلِيَسْأَلُوهُ فَإِنَّ النَّاسَ غَشُوهُ‏.‏\hadithno{3074}\hadithtrans{Jabir (Allah be pleased with him) reported that Allah's Messenger (ﷺ) circumambulated the House on the back of his riding camel on the occasion of the Farewell Pilgrimage and touched the Stone with his stick so that the people should see him, and he should be conspicuous, and they should be able to ask him (questions pertaining to religion) as the people had crowded round him}}
\hadithdefcmd{muslim}{3075}{وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ بَكْرٍ - قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ طَافَ النَّبِيُّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ عَلَى رَاحِلَتِهِ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ لِيَرَاهُ النَّاسُ وَلِيُشْرِفَ وَلِيَسْأَلُوهُ فَإِنَّ النَّاسَ غَشُوهُ ‏.‏ وَلَمْ يَذْكُرِ ابْنُ خَشْرَمٍ وَلِيَسْأَلُوهُ فَقَطْ ‏.‏\hadithno{3075}\hadithtrans{jabir b. 'Abdullah (Allah be pleased with them) reported that Allah's Apostle (ﷺ) circumambulated the House (and ran) between al-Safa and al-Marwa on the back of his she-camel, at the occasion of the Farewell Pilgrimage. so that the people should see him and he should be conspicuous, and they should be able to ask him (questions pertaining to religion), and the people had crowded round him. In the hadith transmitted on the authority of Ibn Khashram no mention Is made of:" So that they should ask him}}
\hadithdefcmd{muslim}{3076}{حَدَّثَنِي الْحَكَمُ بْنُ مُوسَى الْقَنْطَرِيُّ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ طَافَ النَّبِيُّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ حَوْلَ الْكَعْبَةِ عَلَى بَعِيرِهِ يَسْتَلِمُ الرُّكْنَ كَرَاهِيَةَ أَنْ يُضْرَبَ عَنْهُ النَّاسُ ‏.‏\hadithno{3076}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Apostle (ﷺ) circumambulated the Ka'ba on the back of his camel on the occasion of the Farewell Pilgrimage and touched the corner and he did not like that the people should be pushed away from him}}
\hadithdefcmd{muslim}{3077}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، حَدَّثَنَا مَعْرُوفُ بْنُ خَرَّبُوذَ، قَالَ سَمِعْتُ أَبَا الطُّفَيْلِ، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَطُوفُ بِالْبَيْتِ وَيَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ مَعَهُ وَيُقَبِّلُ الْمِحْجَنَ ‏.‏\hadithno{3077}\hadithtrans{Abu Tufail reported:I saw Allah's Messenger (ﷺ) circumambulating the House. and touching the corner with a stick that he had with him, and then kissing the stick}}
\hadithdefcmd{muslim}{3078}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّهَا قَالَتْ شَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِّي أَشْتَكِي فَقَالَ ‏"‏ طُوفِي مِنْ وَرَاءِ النَّاسِ وَأَنْتِ رَاكِبَةٌ ‏"‏ ‏.‏ قَالَتْ فَطُفْتُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حِينَئِذٍ يُصَلِّي إِلَى جَنْبِ الْبَيْتِ وَهُوَ يَقْرَأُ بِـ ‏\{‏ الطُّورِ * وَكِتَابٍ مَسْطُورٍ‏\}‏ ‏.‏\hadithno{3078}\hadithtrans{Umm Salama reported:I made a complaint to Allah's Messenger (ﷺ) of my ailment, whereupon be said: Circumambulate behind the people while riding. She said: So I circumambulated and Allah's Messenger (ﷺ) was at that time praying towards the side of the House and he was reciting al-Tur and a Book Inscribed (i. e. Sura Iii. of the Qur'un)}}
\hadithdefcmd{muslim}{3079}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَ قُلْتُ لَهَا إِنِّي لأَظُنُّ رَجُلاً لَوْ لَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ مَا ضَرَّهُ ‏.‏ قَالَتْ لِمَ قُلْتُ لأَنَّ اللَّهَ تَعَالَى يَقُولُ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏ فَقَالَتْ مَا أَتَمَّ اللَّهُ حَجَّ امْرِئٍ وَلاَ عُمْرَتَهُ لَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَلَوْ كَانَ كَمَا تَقُولُ لَكَانَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا ‏.‏ وَهَلْ تَدْرِي فِيمَا كَانَ ذَاكَ إِنَّمَا كَانَ ذَاكَ أَنَّ الأَنْصَارَ كَانُوا يُهِلُّونَ فِي الْجَاهِلِيَّةِ لِصَنَمَيْنِ عَلَى شَطِّ الْبَحْرِ يُقَالُ لَهُمَا إِسَافٌ وَنَائِلَةٌ ‏.‏ ثُمَّ يَجِيئُونَ فَيَطُوفُونَ بَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ يَحْلِقُونَ ‏.‏ فَلَمَّا جَاءَ الإِسْلاَمُ كَرِهُوا أَنْ يَطُوفُوا بَيْنَهُمَا لِلَّذِي كَانُوا يَصْنَعُونَ فِي الْجَاهِلِيَّةِ قَالَتْ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ‏ \{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ‏\}‏ إِلَى آخِرِهَا - قَالَتْ - فَطَافُوا ‏.‏\hadithno{3079}\hadithtrans{Hisham b. 'Urwa reported on the authority of his father who narrated from 'A'isha. He said to 'A'isha:I think if a person does not run between al- Safa' and al-Marwa, It does not do any harm to him (so far as Hajj is concerned). She said: Why (do you think so)? I said: For Allah says:" Verily al-Safa' and al-Marwa are among the Signs of Allah" (ii. 158) (to the end of the verse), whereupon she said: Allah does not complete the Hajj of a person or his Umra if he does not observe Sa'i between al-Safa' and al-marwa; and if it were so as you state, then (the wording would have been (fala janah an la yatufu biha) [" There is no harm for him if he does not circumambulate between them']. Do you know in what context (this verse was revealed)? (It was revealed in this context) that the Ansar in the Days of Ignorance pronounced the Talbiya for two idols. (fixedl on the bank of the river which were called Isaf and Na'ila. The people went there, and then circumambulated between al-Safa' and al-Marwa and then got their heads shaved. With the advent of Islam they (the Muslims) did not like to circumambulate between them as they used to do during the Days of Ignorance. It was on account of this that Allah. the Exalted and Majestic, revealed:" Verily al-Safe and al-Marwa are among the Signs of Allah" to the end of the verse. She said: Then people began to observe Sa'i}}
\hadithdefcmd{muslim}{3080}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، أَخْبَرَنِي أَبِي قَالَ، قُلْتُ لِعَائِشَةَ مَا أَرَى عَلَىَّ جُنَاحًا أَنْ لاَ أَتَطَوَّفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏ قَالَتْ لِمَ قُلْتُ لأَنَّ اللَّهَ عَزَّ وَجَلَّ يَقُولُ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ‏\}‏ الآيَةَ ‏.‏ فَقَالَتْ لَوْ كَانَ كَمَا تَقُولُ لَكَانَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا ‏.‏ إِنَّمَا أُنْزِلَ هَذَا فِي أُنَاسٍ مِنَ الأَنْصَارِ كَانُوا إِذَا أَهَلُّوا أَهَلُّوا لِمَنَاةَ فِي الْجَاهِلِيَّةِ فَلاَ يَحِلُّ لَهُمْ أَنْ يَطَّوَّفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ فَلَمَّا قَدِمُوا مَعَ النَّبِيِّ صلى الله عليه وسلم لِلْحَجِّ ذَكَرُوا ذَلِكَ لَهُ فَأَنْزَلَ اللَّهُ تَعَالَى هَذِهِ الآيَةَ فَلَعَمْرِي مَا أَتَمَّ اللَّهُ حَجَّ مَنْ لَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏\hadithno{3080}\hadithtrans{Hisham b. 'Urwa narrated on the authority of his father who reported:I said to 'A'isha: I do not see any harm to me if I do not circumambulate betweez al-Safa' and al-Marwa. She said: On what ground do you say so? (I said: ) Since Allah, the Exalted and Majestic, says:" Verily al-Safa' and al-Marwa are among the Signs of Allah." It (your assertion) were (correct), it would have been said like this:" There is no harm for him, that he should not circumambulate between them." It (this verse) has been revealed about the people of Ansar. Whenever they pronounced the Talbiya, they pronounced it in the name of al-Manat during the Days of Ignorance; so they (thought) that it was not permissible for them (for the Muslims) to circumambulate between and al-Marwa. When they (the Muslims) came with Allah's Apostle (may peace he upon him) for Hajj, they mentioned it to him. So Allah, the Exalted and Majestic, revealed this verse. By my life, Allah will not complete the Hajj of one who has not circumambulated between al-Safa and al-Marwa}}
\hadithdefcmd{muslim}{3081}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ، - قَالَ سَمِعْتُ الزُّهْرِيَّ، يُحَدِّثُ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ قُلْتُ لِعَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم مَا أَرَى عَلَى أَحَدٍ لَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ شَيْئًا وَمَا أُبَالِي أَنْ لاَ أَطُوفَ بَيْنَهُمَا ‏.‏ قَالَتْ بِئْسَ مَا قُلْتَ يَا ابْنَ أُخْتِي طَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَطَافَ الْمُسْلِمُونَ فَكَانَتْ سُنَّةً وَإِنَّمَا كَانَ مَنْ أَهَلَّ لِمَنَاةَ الطَّاغِيَةِ الَّتِي بِالْمُشَلَّلِ لاَ يَطُوفُونَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَلَمَّا كَانَ الإِسْلاَمُ سَأَلْنَا النَّبِيَّ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏ وَلَوْ كَانَتْ كَمَا تَقُولُ لَكَانَتْ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا ‏.‏ قَالَ الزُّهْرِيُّ فَذَكَرْتُ ذَلِكَ لأَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ فَأَعْجَبَهُ ذَلِكَ ‏.‏ وَقَالَ إِنَّ هَذَا الْعِلْمُ ‏.‏ وَلَقَدْ سَمِعْتُ رِجَالاً مِنْ أَهْلِ الْعِلْمِ يَقُولُونَ إِنَّمَا كَانَ مَنْ لاَ يَطُوفُ بَيْنَ الصَّفَا وَالْمَرْوَةِ مِنَ الْعَرَبِ يَقُولُونَ إِنَّ طَوَافَنَا بَيْنَ هَذَيْنِ الْحَجَرَيْنِ مِنْ أَمْرِ الْجَاهِلِيَّةِ ‏.‏ وَقَالَ آخَرُونَ مِنَ الأَنْصَارِ إِنَّمَا أُمِرْنَا بِالطَّوَافِ بِالْبَيْتِ وَلَمْ نُؤْمَرْ بِهِ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ‏\}‏ ‏.‏ قَالَ أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ فَأُرَاهَا قَدْ نَزَلَتْ فِي هَؤُلاَءِ وَهَؤُلاَءِ ‏.‏\hadithno{3081}\hadithtrans{Urwa b. Zabair reported:I said to 'A'isha, the wife of Allah's Apostle (ﷺ): I do not see any (fault) in one who does not circumambl" te between al-Safa' and al-Marwa, and I do not mind if I do not circumambulate between them, whereupon she said: O, the son of my sister, what you say is wrong. Allah's Messenger (ﷺ) observed Sa'i and so did the Muslims. So it is a Sunnah (of the Prophet). And it was a common practice (with the pagan Arabs) that those who pronounced Talbiya for the wretched al-Manat, situated at Mushalla, did not observe Sa'i between al-Safa' and al-Marwa. With the advent of Islam, we asked Allah's Apostle (ﷺ) about this practice, and (it was on this occasion) that Allah, the Exalted and Majestic, revealed this verse:" Verily al-Safa' and al-Marwa are among the Signs of Allah" ; so he who performed Hajj or 'Umra it is no sin on him if he circumambulates them. And if it were as you state, (then the wording would have been):" There is no harm for him, that he should not circumambulate round them." Zuhri said: I made a mention of that to Abu Bakr b. 'Abd al- Rahman b. al-Harith b. Hisham; he was impressed by that and said: This is what is called knowledge. And I have heard many a scholar saying: Many of the Arabs who did not circumambulate between al-Safa' and al-Marwa caid: Our circumambulation between these two hills is an act of ignorance; whereas others among the Ansar said: We have been commanded to circumambulate the House, and not Commanded to run between al-Safa' and al-Marwa. So Allah, the Exalted and Majestic, revealed thia verse:" Verily al-Safa' and al-Marwa are among the Signs of Allah." Abu Bakr b. 'Abd al-Rahman said: I think that this (verse) has been revealed for such and such (persons)}}
\hadithdefcmd{muslim}{3082}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ ابْنِ، شِهَابٍ أَنَّهُ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، قَالَ سَأَلْتُ عَائِشَةَ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِهِ وَقَالَ فِي الْحَدِيثِ فَلَمَّا سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نَتَحَرَّجُ أَنْ نَطُوفَ بِالصَّفَا وَالْمَرْوَةِ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏ قَالَتْ عَائِشَةُ قَدْ سَنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم الطَّوَافَ بَيْنَهُمَا فَلَيْسَ لأَحَدٍ أَنْ يَتْرُكَ الطَّوَافَ بِهِمَا\hadithno{3082}\hadithtrans{Urwa b. Zubair reported:I asked 'A'isha (Allah be pleased with her) ; the rest of the hadith is the same. And in this hadith (these words are also found):" When they (the Companions of the Holy Prophet) asked Allah's Messenger (ﷺ) about this, they said: Messenger of Allah, we felt reluctant to circumambulate between al-Safa' and al-Marwa. Then Allah, the Exalted and Majestic, revealed this verse:" Verily al-Safa' and al-Marwa are among the Signs of. Allah so he who perform Hajj or Umra it is no sin on him if he should circumambulate between them. 'A'isha (Allah be pleased with her) said: Allah's Messenger (ﷺ) laid down this Sa'i between them as Sunnah (of the Holy Prophet). So it is not advisable for anyone to abandon this Sa'i between them}}
\hadithdefcmd{muslim}{3083}{وَحَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ الأَنْصَارَ كَانُوا قَبْلَ أَنْ يُسْلِمُوا هُمْ وَغَسَّانُ يُهِلُّونَ لِمَنَاةَ فَتَحَرَّجُوا أَنْ يَطُوفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ وَكَانَ ذَلِكَ سُنَّةً فِي آبَائِهِمْ مَنْ أَحْرَمَ لِمَنَاةَ لَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَإِنَّهُمْ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ حِينَ أَسْلَمُوا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِي ذَلِكَ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا وَمَنْ تَطَوَّعَ خَيْرًا فَإِنَّ اللَّهَ شَاكِرٌ عَلِيمٌ‏\}‏\hadithno{3083}\hadithtrans{Urwa b. Zabair narrated on the authority of 'A'isha (Allah be pleased with her) who informed him that the Ansar and the people of the tribe of Ghassan before embracing Islam pronounced Talbiya for Manat, and so they avoided circumambulating between al-Safa' and al-Marwa, and it was a common practice with their forefather, that he who put on Ihram for Manat did not circumambulate between al-Safa' and al-Marwa. And when they embraced Islam, they asked Allah's Messenger (ﷺ) about it, and then Allah, the Exalted and Majestic, revealed this verse:" Verily al-Safa' and al-Marwa are among the Signs of Allah" ; so he who performs Hajj or Umra, for him there is no harm if he should circumambulate between them, and he who does good spontaneously-surely Allah is Bountiful in rewarding and Knowing}}
\hadithdefcmd{muslim}{3084}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ، عَنْ أَنَسٍ، قَالَ كَانَتِ الأَنْصَارُ يَكْرَهُونَ أَنْ يَطُوفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى نَزَلَتْ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏\hadithno{3084}\hadithtrans{Anas (Allah be pleased with him) reported that the Ansar felt reluctant that they should circumambulate between al-Safa' and al-Marwa until it was revealed:" Verily al-Safa' and al-Marwa are among the Signs of Allah" ; so whoever performs Hajj or 'Umra, for him there is no harm that he should circumambulate between them}}
\hadithdefcmd{muslim}{3085}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ لَمْ يَطُفِ النَّبِيُّ صلى الله عليه وسلم وَلاَ أَصْحَابُهُ بَيْنَ الصَّفَا وَالْمَرْوَةِ إِلاَّ طَوَافًا وَاحِدًا ‏.‏\hadithno{3085}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Apostle (ﷺ) and his Companions did not observe Sa'i between al-Safa' and al-Marwa but only one Sa'i}}
\hadithdefcmd{muslim}{3086}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَقَالَ إِلاَّ طَوَافًا وَاحِدًا طَوَافَهُ الأَوَّلَ ‏.‏\hadithno{3086}\hadithtrans{Ibn Juraij reported on the same authority a hadith like that, and said:But one Tawaf and that was the first Tawaf}}
\hadithdefcmd{muslim}{3088}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، كِلاَهُمَا عَنْ عِيسَى بْنِ يُونُسَ، - قَالَ ابْنُ خَشْرَمٍ أَخْبَرَنَا عِيسَى، - عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَخْبَرَنِي ابْنُ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَرْدَفَ الْفَضْلَ مِنْ جَمْعٍ قَالَ فَأَخْبَرَنِي ابْنُ عَبَّاسٍ أَنَّ الْفَضْلَ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَزَلْ يُلَبِّي حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ\hadithno{3088}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that Allah's Apostle (ﷺ) made al-Fadl sit behind him (on the camel back) from the place (where the two prayers) are combined (Muzdalifa). Ibn Abbas (Allah be pleased with them) also informed that Allah's Apostle (ﷺ) did not stop pronouncing Talbiya till he threw pebbles at Jamrat al-'Aqaba}}
\hadithdefcmd{muslim}{3089}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنِي اللَّيْثُ، عَنْ أَبِي، الزُّبَيْرِ عَنْ أَبِي مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، وَكَانَ، رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ فِي عَشِيَّةِ عَرَفَةَ وَغَدَاةِ جَمْعٍ لِلنَّاسِ حِينَ دَفَعُوا ‏"‏ عَلَيْكُمْ بِالسَّكِينَةِ ‏"‏ ‏.‏ وَهْوَ كَافٌّ نَاقَتَهُ حَتَّى دَخَلَ مُحَسِّرًا - وَهُوَ مِنْ مِنًى - قَالَ ‏"‏ عَلَيْكُمْ بِحَصَى الْخَذْفِ الَّذِي يُرْمَى بِهِ الْجَمْرَةُ ‏"‏ ‏.‏ وَقَالَ لَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم يُلَبِّي حَتَّى رَمَى الْجَمْرَةَ\hadithno{3089}\hadithtrans{Ibn 'Abbas narrated from al-Fadl b. Abbas (Allah be pleased with them) who sat behind Allah's Messenger (ﷺ) that he (the Holy Prophet) said to the people on the evening of 'Arafa and on the morning to the gathering of people (at Muzdalifa) as they were pushing on to proceed slowly. And he himself drove his she-camel with restraint until he entered Muhassir (it is a place in Mina), and further told them to take up pebbles which were to be thrown at Jamra. And Allah's Messenger (ﷺ) continued pronouncing Talbiya till he stoned the Jamra}}
\hadithdefcmd{muslim}{3090}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ فِي الْحَدِيثِ وَلَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم يُلَبِّي حَتَّى رَمَى الْجَمْرَةَ ‏.‏ وَزَادَ فِي حَدِيثِهِ وَالنَّبِيُّ صلى الله عليه وسلم يُشِيرُ بِيَدِهِ كَمَا يَخْذِفُ الإِنْسَانُ ‏\hadithno{3090}\hadithtrans{This hadith has been narrated on the authority of Abd Zubair with the same chain of transmitters but with this variation that in the hadith no mention is made of (this) that Allah's Messenger (ﷺ) continued pronouncing Talbiya till he stoned the Jamra, and he made this addition in his hadith:" The Apostle (ﷺ) pointed with his hand how a person should catch hold of pebbles (in order to throw them)}}
\hadithdefcmd{muslim}{3091}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ حُصَيْنٍ، عَنْ كَثِيرِ بْنِ مُدْرِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ قَالَ عَبْدُ اللَّهِ وَنَحْنُ بِجَمْعٍ سَمِعْتُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ يَقُولُ فِي هَذَا الْمَقَامِ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ ‏"‏ ‏.‏\hadithno{3091}\hadithtrans{Abdullah narrated to us as we had gathered (at Muzdalifa):I have heard from one upon whom Surah al-Baqara was revealed (the Holy Prophet) pronouncing Talbiya at this place}}
\hadithdefcmd{muslim}{3094}{وَحَدَّثَنِيهِ يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ، حَدَّثَنَا زِيَادٌ، - يَعْنِي الْبَكَّائِيَّ - عَنْ حُصَيْنٍ، عَنْ كَثِيرِ بْنِ مُدْرِكٍ الأَشْجَعِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، وَالأَسْوَدِ بْنِ يَزِيدَ، قَالاَ سَمِعْنَا عَبْدَ، اللَّهِ بْنَ مَسْعُودٍ يَقُولُ بِجَمْعٍ سَمِعْتُ الَّذِي، أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ هَا هُنَا يَقُولُ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ ‏"‏ ‏.‏ ثُمَّ لَبَّى وَلَبَّيْنَا مَعَهُ ‏.‏\hadithno{3094}\hadithtrans{Abd al-Rahman b. Yazid and al-Aswad b. Yazid reported:We heard 'Abdullah b. Mas'ud saying to the gathering of people (at Muzdalifa) that he had heard Talbiya from him, upon whom Surah al-Baqara was revealed, at this very place. And so he ('Abdullah b. Mas'ud) pronounced Talbiya and we also pronounced it with him}}
\hadithdefcmd{muslim}{3095}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا سَعِيدُ بْنُ يَحْيَى الأُمَوِيُّ، حَدَّثَنِي أَبِي قَالاَ، جَمِيعًا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ، أَبِي سَلَمَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ غَدَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ مِنًى إِلَى عَرَفَاتٍ مِنَّا الْمُلَبِّي وَمِنَّا الْمُكَبِّرُ ‏. ‏\hadithno{3095}\hadithtrans{Abdullah b. 'Umar reported on the authority of his father (Allah be pleased with them). He said:As we proceeded in the morning along with AUbs Messenger (ﷺ) from Mina to 'Arafat, some of us prounced Talbiya, and some pronounced Takbir (Allah-o-Akbar)}}
\hadithdefcmd{muslim}{3096}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، وَيَعْقُوبُ الدَّوْرَقِيُّ، قَالُوا أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنْ عُمَرَ بْنِ حُسَيْنٍ، عَنْ عَبْدِ اللَّهِ بْنِ، أَبِي سَلَمَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَدَاةِ عَرَفَةَ فَمِنَّا الْمُكَبِّرُ وَمِنَّا الْمُهَلِّلُ فَأَمَّا نَحْنُ فَنُكَبِّرُ قَالَ قُلْتُ وَاللَّهِ لَعَجَبًا مِنْكُمْ كَيْفَ لَمْ تَقُولُوا لَهُ مَاذَا رَأَيْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُ\hadithno{3096}\hadithtrans{Abdullah b. 'Umar reported on the authority of his father (Allah be pleased with them):We were along with Allah's Messenger (way peace he upon him) in the morning of 'Arafa (9th of Dhu'l-Hijja). Some of us pronounced Takbir and some of us Tahlil La ilaha ill-Allah). And to those of us who pronounced Takbir, I said: By Allah, how strange it is that you did not care to ask him: What did you see Allah's Messenger (ﷺ) doing (on this occasion)?}}
\hadithdefcmd{muslim}{3097}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الثَّقَفِيِّ، أَنَّهُ سَأَلَ أَنَسَ بْنَ مَالِكٍ وَهُمَا غَادِيَانِ مِنْ مِنًى إِلَى عَرَفَةَ كَيْفَ كُنْتُمْ تَصْنَعُونَ فِي هَذَا الْيَوْمِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ كَانَ يُهِلُّ الْمُهِلُّ مِنَّا فَلاَ يُنْكَرُ عَلَيْهِ وَيُكَبِّرُ الْمُكَبِّرُ مِنَّا فَلاَ يُنْكَرُ عَلَيْهِ ‏.‏\hadithno{3097}\hadithtrans{Muhammad b. Abu Bakr al-Thaqafi asked Anas b. Malik (Allah be pleased with him), while on their way from Mina to 'Arafa in the morning:What did you do on this day in the company of Allah's Messenger (ﷺ)? Thereupon he said: One of us pronounced Tahlil, and he met with no disapproval, and one of us pronounced Takbir, and he also met with no disapproval}}
\hadithdefcmd{muslim}{3098}{وَحَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ غَدَاةَ عَرَفَةَ مَا تَقُولُ فِي التَّلْبِيَةِ هَذَا الْيَوْمَ قَالَ سِرْتُ هَذَا الْمَسِيرَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَأَصْحَابِهِ فَمِنَّا الْمُكَبِّرُ وَمِنَّا الْمُهَلِّلُ وَلاَ يَعِيبُ أَحَدُنَا عَلَى صَاحِبِهِ ‏.‏\hadithno{3098}\hadithtrans{Muhammad b. Abu Bakr reported:I said to Anas b. Malik in the morning of 'Arafa: What do you say as to pronouncing Talbiya on this day? He said: I travelled with Allah's Apostle (may peace he upon him) and his Companions in this journey. Some of us pronounced Takbir and some of us pronounced Tahlil, and none of us found fault with his companion}}
\hadithdefcmd{muslim}{3099}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ سَمِعَهُ يَقُولُ دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَةَ حَتَّى إِذَا كَانَ بِالشِّعْبِ نَزَلَ فَبَالَ ثُمَّ تَوَضَّأَ وَلَمْ يُسْبِغِ الْوُضُوءَ فَقُلْتُ لَهُ الصَّلاَةَ ‏.‏ قَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ فَرَكِبَ فَلَمَّا جَاءَ الْمُزْدَلِفَةَ نَزَلَ فَتَوَضَّأَ فَأَسْبَغَ الْوُضُوءَ ثُمَّ أُقِيمَتِ الصَّلاَةُ فَصَلَّى الْمَغْرِبَ ثُمَّ أَنَاخَ كُلُّ إِنْسَانٍ بَعِيرَهُ فِي مَنْزِلِهِ ثُمَّ أُقِيمَتِ الْعِشَاءُ فَصَلاَّهَا وَلَمْ يُصَلِّ بَيْنَهُمَا شَيْئًا\hadithno{3099}\hadithtrans{Kuraib, the freed slave of Ibn Abbas, narrated from Usama b. Zaid (Allah be pleased with him) that he had heard him saying:Allah's Messenger (ﷺ) proceeded from 'Arafa, and as he approached the creek of a hill, he got down (from his camel) and urinated, and then performed a light ablution. I said to him: Prayer, whereupon he said: The prayer awaits you (at Muzdalifa). So he rode again, and as he came to Muzdalifa, he got down and performed ablution well. Then Iqima was pronounced for prayer, and he 'observed the sunset prayer. Then every person made his camel kneel down there, and then Iqama was pronounced for 'Isha' prayer and he observed it, and he (the Holy Prophet) did not observe any prayer (either Sunan or Nawifil) in between them (He observed the Fard of sunset and 'Isha' prayers successively)}}
\hadithdefcmd{muslim}{3100}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، مَوْلَى الزُّبَيْرِ عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ الدَّفْعَةِ مِنْ عَرَفَاتٍ إِلَى بَعْضِ تِلْكَ الشِّعَابِ لِحَاجَتِهِ فَصَبَبْتُ عَلَيْهِ مِنَ الْمَاءِ فَقُلْتُ أَتُصَلِّي فَقَالَ ‏ "‏ الْمُصَلَّى أَمَامَكَ ‏"‏ ‏.‏\hadithno{3100}\hadithtrans{Usama b. Zaid (Allah be pleased with him) reported:Allah's Messenger (ﷺ) on his way back from 'Arafat got down in one of these creeks (to answer the call of nature), and after he had done that I poured water (over his hands) and said: Are you going to pray? Thereupon he said: The place of prayer is ahead of you}}
\hadithdefcmd{muslim}{3101}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ قَالَ سَمِعْتُ أُسَامَةَ بْنَ زَيْدٍ، يَقُولُ أَفَاضَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَاتٍ فَلَمَّا انْتَهَى إِلَى الشِّعْبِ نَزَلَ فَبَالَ - وَلَمْ يَقُلْ أُسَامَةُ أَرَاقَ الْمَاءَ - قَالَ فَدَعَا بِمَاءٍ فَتَوَضَّأَ وُضُوءًا لَيْسَ بِالْبَالِغِ - قَالَ - فَقُلْتُ يَا رَسُولَ اللَّهِ الصَّلاَةَ ‏.‏ قَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ قَالَ ثُمَّ سَارَ حَتَّى بَلَغَ جَمْعًا فَصَلَّى الْمَغْرِبَ وَالْعِشَاءَ ‏.‏\hadithno{3101}\hadithtrans{Usama b. Zaid (Allah be pleased with him) narrated:AHah's Messenger (ﷺ) was on his way back from 'Arafat and as he reached the creek (of a hillock) he got down and urinated (Usama did not say that he poured water), but said: He (the Holy Prophet) called for water and performed ablution, but it was not a thorough one. I said: Messenger of Allah, the prayer! Thereupon he said: Prayer awaits you ahead (at Muzdalifa). He then proceeded, until he reached Muzdalifa and observed sunset and 'Isha' prayers (together) there}}
\hadithdefcmd{muslim}{3102}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا زُهَيْرٌ أَبُو خَيْثَمَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُقْبَةَ، أَخْبَرَنِي كُرَيْبٌ، أَنَّهُ سَأَلَ أُسَامَةَ بْنَ زَيْدٍ كَيْفَ صَنَعْتُمْ حِينَ رَدِفْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَشِيَّةَ عَرَفَةَ فَقَالَ جِئْنَا الشِّعْبَ الَّذِي يُنِيخُ النَّاسُ فِيهِ لِلْمَغْرِبِ فَأَنَاخَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاقَتَهُ وَبَالَ - وَمَا قَالَ أَهَرَاقَ الْمَاءَ - ثُمَّ دَعَا بِالْوَضُوءِ فَتَوَضَّأَ وُضُوءًا لَيْسَ بِالْبَالِغِ فَقُلْتُ يَا رَسُولَ اللَّهِ الصَّلاَةَ ‏.‏ فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ فَرَكِبَ حَتَّى جِئْنَا الْمُزْدَلِفَةَ فَأَقَامَ الْمَغْرِبَ ثُمَّ أَنَاخَ النَّاسُ فِي مَنَازِلِهِمْ وَلَمْ يَحُلُّوا حَتَّى أَقَامَ الْعِشَاءَ الآخِرَةَ فَصَلَّى ثُمَّ حَلُّوا قُلْتُ فَكَيْفَ فَعَلْتُمْ حِينَ أَصْبَحْتُمْ قَالَ رَدِفَهُ الْفَضْلُ بْنُ عَبَّاسٍ وَانْطَلَقْتُ أَنَا فِي سُبَّاقِ قُرَيْشٍ عَلَى رِجْلَىَّ ‏.‏\hadithno{3102}\hadithtrans{Kuraib reported that he asked Usama b. Zaid (Allah be pleased with him) What did you do in the evening of 'Arafa as you rode behind Allah's Messenger (ﷺ)? He said:We came to a valley where people generally halted their (camels) for the sunset prayer. Allah's Messenger (ﷺ) halted his camel and urinated (and he did not say that he had poured water). He then called for water and performed light ablution. I said: Messenger of Allah, the prayer! Thereupon he said: Prayer awaits you (at Muzdalifa). and he rode on until we came to Muzdalifa. Then he offered the sunset prayer. and the people halted their camels at their places, and did not untie them until Iqama was pronounced for the 'Isha' prayer and he observed the prayer, and then they untied (their camels). I said: What did you do in the morning? He said: Al-Fadl b. Abbas (Allah be pleased with them) sat behind him (the Holy Prophet) in the morning, whereas I proceeded on foot with the Quraish who had gone ahead}}
\hadithdefcmd{muslim}{3103}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا أَتَى النَّقْبَ الَّذِي يَنْزِلُهُ الأُمَرَاءُ نَزَلَ فَبَالَ - وَلَمْ يَقُلْ أَهْرَاقَ - ثُمَّ دَعَا بِوَضُوءٍ فَتَوَضَّأَ وُضُوءًا خَفِيفًا فَقُلْتُ يَا رَسُولَ اللَّهِ الصَّلاَةَ ‏.‏ فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏\hadithno{3103}\hadithtrans{Usama b. Zaid (Allah be pleased with him) reported that when Allah's Messenger (may peace jbe upod him) came to the valley where the rich (people of Mecca) used to get down. he got down. and urinated (and he did not mention about pouring water) ; he then called for water and performed a light ablution. I said:Messenger of Allah, the prayer I Thereupon he said: Prayer awaits you ahead}}
\hadithdefcmd{muslim}{3104}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءٍ، مَوْلَى سِبَاعٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ كَانَ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ أَفَاضَ مِنْ عَرَفَةَ فَلَمَّا جَاءَ الشِّعْبَ أَنَاخَ رَاحِلَتَهُ ثُمَّ ذَهَبَ إِلَى الْغَائِطِ فَلَمَّا رَجَعَ صَبَبْتُ عَلَيْهِ مِنَ الإِدَاوَةِ فَتَوَضَّأَ ثُمَّ رَكِبَ ثُمَّ أَتَى الْمُزْدَلِفَةَ فَجَمَعَ بِهَا بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{3104}\hadithtrans{Usama b. Zaid (Allah be pleased with him) reported that he sat behind Allah's Messenger (ﷺ) on his ride as he came back from 'Arafa. And as he came to the valley, he halted his camel, and then went to the wilderness (to urinate). And when he came back, I poured water on him from the jug and he performed ablution, and then rode on until he came to Muzdalifa and there he combined the sunset and 'Isha' prayers}}
\hadithdefcmd{muslim}{3105}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفَاضَ مِنْ عَرَفَةَ وَأُسَامَةُ رِدْفُهُ قَالَ أُسَامَةُ فَمَازَالَ يَسِيرُ عَلَى هَيْئَتِهِ حَتَّى أَتَى جَمْعًا ‏.‏\hadithno{3105}\hadithtrans{Ibn Abbas (Allah be pleased with him) reported that Allah's Messenger (may peace be upon, him) came back from 'Arafa and Usama (Allah be pleased with him) was seated behind him. Usama said that he (the Holy Prophet) continued the journey in this very state until he came to Muzdalifa}}
\hadithdefcmd{muslim}{3106}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، جَمِيعًا عَنْ حَمَّادِ بْنِ زَيْدٍ، - قَالَ أَبُو الرَّبِيعِ حَدَّثَنَا حَمَّادٌ، - حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، قَالَ سُئِلَ أُسَامَةُ وَأَنَا شَاهِدٌ، أَوْ قَالَ سَأَلْتُ أُسَامَةَ بْنَ زَيْدٍ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرْدَفَهُ مِنْ عَرَفَاتٍ قُلْتُ كَيْفَ كَانَ يَسِيرُ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أَفَاضَ مِنْ عَرَفَةَ قَالَ كَانَ يَسِيرُ الْعَنَقَ فَإِذَا وَجَدَ فَجْوَةً نَصَّ ‏.‏\hadithno{3106}\hadithtrans{Hisham (Allah be pleased with him) reported from his father:Usama (Allah be pleased with him) was asked in my presence or I asked Usama b. Zaid andhe rode behind Allah's Messenger (ﷺ) as he came back from 'Arafat. I said (to him): How did Allah's Messenger (ﷺ) journey as he came back from 'Arafat? Thereupon he said: He made it (his riding camel) walk at a slow speed, and when he found an open space, he made it walk briskly}}
\hadithdefcmd{muslim}{3107}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَحُمَيْدُ، بْنُ عَبْدِ الرَّحْمَنِ عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ وَزَادَ فِي حَدِيثِ حُمَيْدٍ قَالَ هِشَامٌ وَالنَّصُّ فَوْقَ الْعَنَقِ ‏.‏\hadithno{3107}\hadithtrans{This hadith has been narrated on the authority of 'Urwa with the same chain of transmitters. and in the hadith narrated by Humaid there is an addition (of these words):" Hisham said: Al-nass (speed of camel) is faster than al-'anaq}}
\hadithdefcmd{muslim}{3110}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ، عَبْدِ اللَّهِ عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ جَمِيعًا ‏.‏\hadithno{3110}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) observed the sunset and 'Isha' prayers together at Muzdalifa}}
\hadithdefcmd{muslim}{3111}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّأَخْبَرَهُ أَنَّ أَبَاهُ قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ لَيْسَ بَيْنَهُمَا سَجْدَةٌ وَصَلَّى الْمَغْرِبَ ثَلاَثَ رَكَعَاتٍ وَصَلَّى الْعِشَاءَ رَكْعَتَيْنِ ‏.‏ فَكَانَ عَبْدُ اللَّهِ يُصَلِّي بِجَمْعٍ كَذَلِكَ حَتَّى لَحِقَ بِاللَّهِ تَعَالَى ‏.‏\hadithno{3111}\hadithtrans{Ubaidullah b. 'Abdullah b. 'Umar reported on the authority of his father (Allah be pleased with them) that Allah's Messenger (ﷺ) combined the sunset and 'Isha', prayers at Muzdalifa and there was no prostration (i. e. any rak'ahs of Sunan or Nawafil prayers) in between them. He observed three rak'ahs of the sunset prayer and two rak'ahs of the 'Isha' prayer, and 'Abdullah (b. 'Umar) observed the prayers in this very manner (at Muzdalifa) until he met his Lord}}
\hadithdefcmd{muslim}{3112}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، وَسَلَمَةَ بْنِ كُهَيْلٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّهُ صَلَّى الْمَغْرِبَ بِجَمْعٍ وَالْعِشَاءَ بِإِقَامَةٍ ثُمَّ حَدَّثَ عَنِ ابْنِ عُمَرَ أَنَّهُ صَلَّى مِثْلَ ذَلِكَ وَحَدَّثَ ابْنُ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَنَعَ مِثْلَ ذَلِكَ ‏.‏\hadithno{3112}\hadithtrans{Sa'id b. Jubair reported that he observed the sunset and 'Isha' prayers at Muzdalifa with (one) iqama. He narrated on the authority of Ibn 'Umar (Allah be pleased with them) that he observed prayers like this and Ibn 'Umar (Allah be pleased with them) narrated that Allah's Apostle (ﷺ) did like this}}
\hadithdefcmd{muslim}{3113}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَقَالَ صَلاَّهُمَا بِإِقَامَةٍ وَاحِدَةٍ ‏.‏\hadithno{3113}\hadithtrans{Shu'ba reported this hadith with the same chain of transmitters and said:He (the Holy Prophet) observed the two prayers (together) with one iqama}}
\hadithdefcmd{muslim}{3114}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا الثَّوْرِيُّ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ صَلَّى الْمَغْرِبَ ثَلاَثًا وَالْعِشَاءَ رَكْعَتَيْنِ بِإِقَامَةٍ وَاحِدَةٍ ‏.‏\hadithno{3114}\hadithtrans{Ibn 'Umar rep rte that Allah's Messenger (ﷺ) combined the sunset and 'Isha ' prayers at Muzdalifa. He observed three rak'ahs of the sunset prayer and two rak'ahs of the 'Isha' prayer with one Iqama}}
\hadithdefcmd{muslim}{3115}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي، خَالِدٍ عَنْ أَبِي إِسْحَاقَ، قَالَ قَالَ سَعِيدُ بْنُ جُبَيْرٍ أَفَضْنَا مَعَ ابْنِ عُمَرَ حَتَّى أَتَيْنَا جَمْعًا فَصَلَّى بِنَا الْمَغْرِبَ وَالْعِشَاءَ بِإِقَامَةٍ وَاحِدَةٍ ثُمَّ انْصَرَفَ فَقَالَ هَكَذَا صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي هَذَا الْمَكَانِ ‏.‏\hadithno{3115}\hadithtrans{Sa'id b. Jubair reported:We came back along with Ibn 'Umar till we reached Muzdalifa. There he led us in the sunset and 'Isha' prayers with one iqama and we then proceeded and he said: This is how Allah's Messenger (ﷺ) led us in prayer at this place}}
\hadithdefcmd{muslim}{3116}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، - قَالَ يَحْيَى أَخْبَرَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى صَلاَةً إِلاَّ لِمِيقَاتِهَا إِلاَّ صَلاَتَيْنِ صَلاَةَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ وَصَلَّى الْفَجْرَ يَوْمَئِذٍ قَبْلَ مِيقَاتِهَا ‏.‏\hadithno{3116}\hadithtrans{A'bdullah (b. 'Umar) reported:I have never seen Allah's Messenger, (ﷺ) but observing the prayers at their appointed times except two prayers, sunset and 'Isha, ' at Muzdalifa (where he deferred the sunset prayer to combine it with 'Isha' and he observed the dawn prayer before its stipulated time on that day (10th of Dhu'l-Hijja)}}
\hadithdefcmd{muslim}{3117}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ جَرِيرٍ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَقَالَ قَبْلَ وَقْتِهَا بِغَلَسٍ ‏.‏\hadithno{3117}\hadithtrans{This hadith has been transmitted by Al-A`mash with a slight variation of words, i.e. he said before its time when it was still dark}}
\hadithdefcmd{muslim}{3118}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا أَفْلَحُ، - يَعْنِي ابْنَ حُمَيْدٍ - عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتِ اسْتَأْذَنَتْ سَوْدَةُ رَسُولَ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْمُزْدَلِفَةِ تَدْفَعُ قَبْلَهُ وَقَبْلَ حَطْمَةِ النَّاسِ وَكَانَتِ امْرَأَةً ثَبِطَةً - يَقُولُ الْقَاسِمُ وَالثَّبِطَةُ الثَّقِيلَةُ - قَالَ فَأَذِنَ لَهَا فَخَرَجَتْ قَبْلَ دَفْعِهِ وَحَبَسَنَا حَتَّى أَصْبَحْنَا فَدَفَعْنَا بِدَفْعِهِ وَلأَنْ أَكُونَ اسْتَأْذَنْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا اسْتَأْذَنَتْهُ سَوْدَةُ فَأَكُونَ أَدْفَعُ بِإِذْنِهِ أَحَبُّ إِلَىَّ مِنْ مَفْرُوحٍ بِهِ ‏.‏\hadithno{3118}\hadithtrans{A'isha (Allah be pleased with her) reported:Sauda (the wife of the Holy Prophet) who was bulky sought the permission of Allah's Messenger (ﷺ) on the night of Muzdalifa to move from (that place) ahead of him and before the multitude (set forth). He (Allah's Apostle) gave her the permission. So she set forth before his (Holy Prophet's) departure. But we stayed there until it was dawn and we moved on, when he departed. And if I were to seek the permission of Allah's Messenger. (ﷺ) as Sauda had sought permission, I could have also gone with his permission and it would have been better for me than that for which I was happy}}
\hadithdefcmd{muslim}{3119}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، جَمِيعًا عَنِ الثَّقَفِيِّ، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الْوَهَّابِ، - حَدَّثَنَا أَيُّوبُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ سَوْدَةُ امْرَأَةً ضَخْمَةً ثَبِطَةً فَاسْتَأْذَنَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ تُفِيضَ مِنْ جَمْعٍ بِلَيْلٍ فَأَذِنَ لَهَا فَقَالَتْ عَائِشَةُ فَلَيْتَنِي كُنْتُ اسْتَأْذَنْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا اسْتَأْذَنَتْهُ سَوْدَةُ وَكَانَتْ عَائِشَةُ لاَ تُفِيضُ إِلاَّ مَعَ الإِمَامِ ‏.‏\hadithno{3119}\hadithtrans{A'isha (Allah be pleased with her) reported that (hadrat) Sauda was a bulky lady, so she sought permission from Allah's Messenger (ﷺ) to proceed from Muzdalifa (to Mina) in the (latter part of the) night. He granted her permission. 'A'isha said:I wish I had also sought permission from Allah's Messenger (ﷺ) as Sauda had. sought permission from him. 'A'isha did not proceed but with the Imam}}
\hadithdefcmd{muslim}{3120}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ وَدِدْتُ أَنِّي كُنْتُ اسْتَأْذَنْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا اسْتَأْذَنَتْهُ سَوْدَةُ فَأُصَلِّي الصُّبْحَ بِمِنًى فَأَرْمِي الْجَمْرَةَ قَبْلَ أَنْ يَأْتِيَ النَّاسُ ‏.‏ فَقِيلَ لِعَائِشَةَ فَكَانَتْ سَوْدَةُ اسْتَأْذَنَتْهُ قَالَتْ نَعَمْ إِنَّهَا كَانَتِ امْرَأَةً ثَقِيلَةً ثَبِطَةً فَاسْتَأْذَنَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَذِنَ لَهَا ‏.‏\hadithno{3120}\hadithtrans{A'isha said:I wish I had sought permission from Allah's Messenger (ﷺ) as Sauda had sought, and observed the dawn prayer at Mina and stoned at al-Jamra before the people had come there. It was said to 'A'isha (Allah be pleased with her): Did Sauda seek permission from him (the Holy Prophet)? She said: Yes. She was a bulky lady and so she sought permission from Allah's Messenger (ﷺ) (to proceed to mina from Muzdalifa ahead of him), and he granted her permission}}
\hadithdefcmd{muslim}{3121}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، كِلاَهُمَا عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏\hadithno{3121}\hadithtrans{A hadith like this has been narrated by 'Abd al-Rahman b. al-Qasim with the same chain of transmitters}}
\hadithdefcmd{muslim}{3122}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي عَبْدُ اللَّهِ، مَوْلَى أَسْمَاءَ قَالَ قَالَتْ لِي أَسْمَاءُ وَهْىَ عِنْدَ دَارِ الْمُزْدَلِفَةِ هَلْ غَابَ الْقَمَرُ قُلْتُ لاَ ‏.‏ فَصَلَّتْ سَاعَةً ثُمَّ قَالَتْ يَا بُنَىَّ هَلْ غَابَ الْقَمَرُ قُلْتُ نَعَمْ ‏.‏ قَالَتِ ارْحَلْ بِي ‏.‏ فَارْتَحَلْنَا حَتَّى رَمَتِ الْجَمْرَةَ ثُمَّ صَلَّتْ فِي مَنْزِلِهَا فَقُلْتُ لَهَا أَىْ هَنْتَاهْ لَقَدْ غَلَّسْنَا ‏.‏ قَالَتْ كَلاَّ أَىْ بُنَىَّ إِنَّ النَّبِيَّ صلى الله عليه وسلم أَذِنَ لِلظُّعُنِ ‏.‏\hadithno{3122}\hadithtrans{Abdullah, the freed slave of (Hadrat) Asma', reported:Asma' (Allah be pleased with her), as she was in the house at Muzdalifa, asked me whether the moon had set. I said: No. She prayed for some time, and again said: My son has the moon set? I said: Yes. And she said: Set forth along with me, and so we set forth until (we reached Mini) and the stoned at al-Jamra. She then prayed in her place. I said to her: Respected lady, we set forth (in the very early part of dawn) when it was dark, whereupon she said: My son, there is no harm in it; Allah's Apostle (ﷺ) had granted permission to women}}
\hadithdefcmd{muslim}{3123}{وَحَدَّثَنِيهِ عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ وَفِي رِوَايَتِهِ قَالَتْ لاَ أَىْ بُنَىَّ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم أَذِنَ لِظُعُنِهِ ‏.‏\hadithno{3123}\hadithtrans{This hadith has been narrated by Ibn Juraij with the same chain of transmitters, and In his narration (the words are):" She (Asma') said: My son, Allah's Apostle (ﷺ) granted permission to women}}
\hadithdefcmd{muslim}{3124}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنِي عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَنَّ ابْنَ شَوَّالٍ، أَخْبَرَهُ أَنَّهُ، دَخَلَ عَلَى أُمِّ حَبِيبَةَ فَأَخْبَرَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ بِهَا مِنْ جَمْعٍ بِلَيْلٍ ‏.‏\hadithno{3124}\hadithtrans{Ibn Shawwal (the freed slave of Umm Habiba) reported that he went to Umm Habiba (the wife of Allah's Apostle) who informed him that Allah's Apostle (ﷺ) sent her from Muzdalifa during the night}}
\hadithdefcmd{muslim}{3125}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَالِمِ بْنِ شَوَّالٍ، عَنْ أُمِّ، حَبِيبَةَ قَالَتْ كُنَّا نَفْعَلُهُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم نُغَلِّسُ مِنْ جَمْعٍ إِلَى مِنًى ‏.‏ وَفِي رِوَايَةِ النَّاقِدِ نُغَلِّسُ مِنْ مُزْدَلِفَةَ ‏.‏\hadithno{3125}\hadithtrans{It is narrated from Umm Habiba:We used to set forth from Muzdalifa to Mina, (very early in the dawn) when it was dark. And in the narration of Naqid (the words are):" We set from Muzdalifa in the darkness (of the dawn)}}
\hadithdefcmd{muslim}{3126}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، جَمِيعًا عَنْ حَمَّادٍ، - قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الثَّقَلِ - أَوْ قَالَ فِي الضَّعَفَةِ - مِنْ جَمْعٍ بِلَيْلٍ ‏.‏\hadithno{3126}\hadithtrans{Ibn 'Abbas reported:Allah's Messenger (ﷺ) sent me from Muzdalifa ahead (of the caravan) along with the luggage or with the weak ones during (the latter part of the) night}}
\hadithdefcmd{muslim}{3127}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي، يَزِيدَ أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ أَنَا مِمَّنْ، قَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ضَعَفَةِ أَهْلِهِ ‏.‏\hadithno{3127}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported:I was among those (i. e. women and children) whom Allah's Messenger (ﷺ) sent forth with the weak members of his family}}
\hadithdefcmd{muslim}{3128}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا عَمْرٌو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ فِيمَنْ قَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ضَعَفَةِ أَهْلِهِ ‏.‏\hadithno{3128}\hadithtrans{This hadith has been transmitted by Ibn 'Abbas (Allah be pleased with them) with a slight variation of words}}
\hadithdefcmd{muslim}{3129}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَنَّ ابْنَ عَبَّاسٍ، قَالَ بَعَثَ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَحَرٍ مِنْ جَمْعٍ فِي ثَقَلِ نَبِيِّ اللَّهِ صلى الله عليه وسلم ‏.‏ قُلْتُ أَبَلَغَكَ أَنَّ ابْنَ عَبَّاسٍ قَالَ بَعَثَ بِي بِلَيْلٍ طَوِيلٍ قَالَ لاَ إِلاَّ كَذَلِكَ بِسَحَرٍ ‏.‏ قُلْتُ لَهُ فَقَالَ ابْنُ عَبَّاسٍ رَمَيْنَا الْجَمْرَةَ قَبْلَ الْفَجْرِ ‏.‏ وَأَيْنَ صَلَّى الْفَجْرَ قَالَ لاَ إِلاَّ كَذَلِكَ ‏.‏\hadithno{3129}\hadithtrans{Ata' reported from Ibn Abbas (Allah be pleased with them):Allah's Messenger (ﷺ) sent me from Muzdalifa along with his luggage (in the very early part of @he dawn). I (Ibn Juraij, one of the narrators) said (to 'Ati'): Has this (news) reached you that Ibn 'Abbas (Allah be pleased with them) had said:" He (Allah's Messenger) had sent me in the latter part of the night"? Thereupon he said: No, it was the dawn. I (again) said to him: (Did you hear) Ibn 'Abbas (Allah be pleased with them) having said this (too):" We stoned al-Jamra before the dawn prayer"? So where did he observe the dawn prayer? He said: No. But he said only so much (as described above)}}
\hadithdefcmd{muslim}{3130}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ كَانَ يُقَدِّمُ ضَعَفَةَ أَهْلِهِ فَيَقِفُونَ عِنْدَ الْمَشْعَرِ الْحَرَامِ بِالْمُزْدَلِفَةِ بِاللَّيْلِ فَيَذْكُرُونَ اللَّهَ مَا بَدَا لَهُمْ ثُمَّ يَدْفَعُونَ قَبْلَ أَنْ يَقِفَ الإِمَامُ وَقَبْلَ أَنْ يَدْفَعَ فَمِنْهُمْ مَنْ يَقْدَمُ مِنًى لِصَلاَةِ الْفَجْرِ وَمِنْهُمْ مَنْ يَقْدَمُ بَعْدَ ذَلِكَ فَإِذَا قَدِمُوا رَمَوُا الْجَمْرَةَ وَكَانَ ابْنُ عُمَرَ يَقُولُ أَرْخَصَ فِي أُولَئِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3130}\hadithtrans{Salim b. 'Abdullah reported that 'Abdullah b. 'Umar (Allah be pleased with them) used to send ahead of him the weak members of his household to stay during the night at Mash'ar al-Haram at Muzdalifa. They remembered Allah so long as they could afford, and then they proceeded before the stay of the Imam, and before his return. So some of them reached Mina for the dawn prayer and some of them reached there after that; and as they reached there, they stoned al-Jamra; and Ibn 'Umar (Allah be pleased with them) used to say:Allah's Messenger (ﷺ) has granted this concession to them}}
\hadithdefcmd{muslim}{3131}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ رَمَى عَبْدُ اللَّهِ بْنُ مَسْعُودٍ جَمْرَةَ الْعَقَبَةِ مِنْ بَطْنِ الْوَادِي بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ ‏.‏ قَالَ فَقِيلَ لَهُ إِنَّ أُنَاسًا يَرْمُونَهَا مِنْ فَوْقِهَا ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ هَذَا وَالَّذِي لاَ إِلَهَ غَيْرُهُ مَقَامُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ\hadithno{3131}\hadithtrans{Abd al-Rahman b. Yazid reported that 'Abdullah b. Mas'ud (Allah be pleased with them) threw seven pebbles at Jamrat al-'Aqaba from the heart of the valley. He pronounced Takbir with every pebble. It was said to him that people fling stones from the upper side (of the valley), whereupon 'Abdullah b. Mas'ud (Allah he pleased with them) said:By him, besides Whom there is no other god, that is the place (of flinging stones) of one upon whom Surah al-Baqara was revealed (the Holy Prophet)}}
\hadithdefcmd{muslim}{3132}{وَحَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، أَخْبَرَنَا ابْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ الْحَجَّاجَ بْنَ يُوسُفَ، يَقُولُ وَهُوَ يَخْطُبُ عَلَى الْمِنْبَرِ أَلِّفُوا الْقُرْآنَ كَمَا أَلَّفَهُ جِبْرِيلُ السُّورَةُ الَّتِي يُذْكَرُ فِيهَا الْبَقَرَةُ وَالسُّورَةُ الَّتِي يُذْكَرُ فِيهَا النِّسَاءُ وَالسُّورَةُ الَّتِي يُذْكَرُ فِيهَا آلُ عِمْرَانَ ‏.‏ قَالَ فَلَقِيتُ إِبْرَاهِيمَ فَأَخْبَرْتُهُ بِقَوْلِهِ فَسَبَّهُ وَقَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ أَنَّهُ كَانَ مَعَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ فَأَتَى جَمْرَةَ الْعَقَبَةِ فَاسْتَبْطَنَ الْوَادِيَ فَاسْتَعْرَضَهَا فَرَمَاهَا مِنْ بَطْنِ الْوَادِي بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ - قَالَ - فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّ النَّاسَ يَرْمُونَهَا مِنْ فَوْقِهَا ‏.‏ فَقَالَ هَذَا وَالَّذِي لاَ إِلَهَ غَيْرُهُ مَقَامُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏\hadithno{3132}\hadithtrans{A'mash reported:I heard Hajjaj b. Yusuf saying as he was delivering sermon on the pulpit: Observe the order of the (Holy) Qur'an which has been observed by Gabriel. (Thus state the surahs in this manner)" one in which mention has been made of al-Baqara,"" one in which mention has been made of women (Surah al-Nisa')" and then the surah in which mention has been made of the Family of 'Imrin. He (the (narrator) said: I met Ibrahim and informed him about these words of his (the statement of Hajjaj b. Yusuf). He cursed him and said: Abd al-Rahman b. Yazid has narrated to me that when he was in the company of 'Abdullah b. Mas'udd (Allah be pleased with them) he came to Jamrat al-'Aqaba and then entered the heart of the valley and faced towards it (the Jamra) and then flung seven pebbles at it from the heart of the valley pronouncing Takbir with every pebble. I said: Abu 'Abd al-Rahman, people fling pebbles at it (Jamra) from the upper side, whereupon he said: By Him besides Whom there is no god, that is the place (of flinging pebbles of one) upon whom Surah al-Baqara was revealed;}}
\hadithdefcmd{muslim}{3133}{وَحَدَّثَنِي يَعْقُوبُ الدَّوْرَقِيُّ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ الْحَجَّاجَ، يَقُولُ لاَ تَقُولُوا سُورَةُ الْبَقَرَةِ ‏.‏ وَاقْتَصَّا الْحَدِيثَ بِمِثْلِ حَدِيثِ ابْنِ مُسْهِرٍ ‏.‏\hadithno{3133}\hadithtrans{A'mash reported:I heard Hajjaj saying I Do not say Surah al-Baqara. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{3134}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ يَزِيدَ أَنَّهُ حَجَّ مَعَ عَبْدِ اللَّهِ قَالَ فَرَمَى الْجَمْرَةَ بِسَبْعِ حَصَيَاتٍ وَجَعَلَ الْبَيْتَ عَنْ يَسَارِهِ وَمِنًى عَنْ يَمِينِهِ وَقَالَ هَذَا مَقَامُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏\hadithno{3134}\hadithtrans{Abd al-Rahman b. Yazid reported that he performed Hajj along with 'Abdullah (Allah be pleased with him) and he flung seven pebbles at al-Jamra (from a position) that the House was on his left and Mina was on his right and said:That is the place (of flinging pebbles of one) upon whom Surah al-Baqara was revealed}}
\hadithdefcmd{muslim}{3135}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ فَلَمَّا أَتَى جَمْرَةَ الْعَقَبَةِ ‏.‏\hadithno{3135}\hadithtrans{This hadith nas been narrated on the authority of Shu'ba with the same chain of transmitters except with this variation of (words):As he came to Jamrat al-'Aqaba}}
\hadithdefcmd{muslim}{3136}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الْمُحَيَّاةِ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا يَحْيَى بْنُ يَعْلَى أَبُو الْمُحَيَّاةِ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ يَزِيدَ قَالَ قِيلَ لِعَبْدِ اللَّهِ إِنَّ نَاسًا يَرْمُونَ الْجَمْرَةَ مِنْ فَوْقِ الْعَقَبَةِ - قَالَ - فَرَمَاهَا عَبْدُ اللَّهِ مِنْ بَطْنِ الْوَادِي ثُمَّ قَالَ مِنْ هَا هُنَا وَالَّذِي لاَ إِلَهَ غَيْرُهُ رَمَاهَا الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏\hadithno{3136}\hadithtrans{Abd al-Rahman b. Yazid reported:It was said to 'Abdullah (Allah be pleased with bird) that people threw pebbles at the Jamra from the upper side of 'Aqaba, whereas he threw stones at it from the heart of the valley, whereupon he said: By Him besides Whom there is no god, it is at this very place that one upon whom was revealed Surah al-Baqara threw stones at it}}
\hadithdefcmd{muslim}{3137}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، جَمِيعًا عَنْ عِيسَى بْنِ يُونُسَ، - قَالَ ابْنُ خَشْرَمٍ أَخْبَرَنَا عِيسَى، - عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَرْمِي عَلَى رَاحِلَتِهِ يَوْمَ النَّحْرِ وَيَقُولُ ‏ "‏ لِتَأْخُذُوا مَنَاسِكَكُمْ فَإِنِّي لاَ أَدْرِي لَعَلِّي لاَ أَحُجُّ بَعْدَ حَجَّتِي هَذِهِ ‏"‏ ‏.‏\hadithno{3137}\hadithtrans{Jabir (Allah be pleased with him) reported:I saw Allah's Apostle (ﷺ) flinging pebbles while riding his camel on the Day of Nahr, and he was saying: Learn your rituals (by seeing me performing them), for I do not know whether I would be performing Hajj after this Hajj of mine}}
\hadithdefcmd{muslim}{3138}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ زَيْدِ بْنِ أَبِي، أُنَيْسَةَ عَنْ يَحْيَى بْنِ حُصَيْنٍ، عَنْ جَدَّتِهِ أُمِّ الْحُصَيْنِ، قَالَ سَمِعْتُهَا تَقُولُ، حَجَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَجَّةَ الْوَدَاعِ فَرَأَيْتُهُ حِينَ رَمَى جَمْرَةَ الْعَقَبَةِ وَانْصَرَفَ وَهُوَ عَلَى رَاحِلَتِهِ وَمَعَهُ بِلاَلٌ وَأُسَامَةُ أَحَدُهُمَا يَقُودُ بِهِ رَاحِلَتَهُ وَالآخَرُ رَافِعٌ ثَوْبَهُ عَلَى رَأْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الشَّمْسِ - قَالَتْ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَوْلاً كَثِيرًا ثُمَّ سَمِعْتُهُ يَقُولُ ‏ "‏ إِنْ أُمِّرَ عَلَيْكُمْ عَبْدٌ مُجَدَّعٌ - حَسِبْتُهَا قَالَتْ - أَسْوَدُ يَقُودُكُمْ بِكِتَابِ اللَّهِ تَعَالَى فَاسْمَعُوا لَهُ وَأَطِيعُوا ‏"‏ ‏.‏\hadithno{3138}\hadithtrans{Umm al-Husain (Allah be pleased with her) reported:I performed Hajj along with Allah's Messenger (ﷺ) on the occasion of the Farewell Pilgrimage and saw him when he flung pebbles at Jamrat al-'Aqaba and returned while he was riding the camel, and Bilal and Usama were with him. One of them was leading his camel, while the other was raising his cloth over the head of Allah's Messenger (ﷺ) to protect him from the sun. She (further) said: Allah's Messenger (ﷺ) said so many things, and I heard him saying: If a slave having some limb of his missing and having dark complexion is appointed to govern you according to the Book of Allah the Exalted. listen to him and obey him}}
\hadithdefcmd{muslim}{3139}{وَحَدَّثَنِي أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، عَنْ زَيْدِ، بْنِ أَبِي أُنَيْسَةَ عَنْ يَحْيَى بْنِ الْحُصَيْنِ، عَنْ أُمِّ الْحُصَيْنِ، جَدَّتِهِ قَالَتْ حَجَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَجَّةَ الْوَدَاعِ فَرَأَيْتُ أُسَامَةَ وَبِلاَلاً وَأَحَدُهُمَا آخِذٌ بِخِطَامِ نَاقَةِ النَّبِيِّ صلى الله عليه وسلم وَالآخَرُ رَافِعٌ ثَوْبَهُ يَسْتُرُهُ مِنَ الْحَرِّ حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ ‏.‏ قَالَ مُسْلِمٌ وَاسْمُ أَبِي عَبْدِ الرَّحِيمِ خَالِدُ بْنُ أَبِي يَزِيدَ وَهُوَ خَالُ مُحَمَّدِ بْنِ سَلَمَةَ رَوَى عَنْهُ وَكِيعٌ وَحَجَّاجٌ الأَعْوَرُ ‏.‏\hadithno{3139}\hadithtrans{Umm al-Husain (Allah be pleased with her) reported:I performed Hajj along with Allah's Messenger (ﷺ) on the occasion of the Farewell Pilgrimage and saw Usama and Bilal (too), one of whom had caught hold of the lose string of the she-camel of Allah's Apostle (ﷺ) while the other one was raising his cloth (over his head) protecting him from the heat, till he flung pebbles at Jamrat al-'Aqaba}}
\hadithdefcmd{muslim}{3140}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ حَاتِمٍ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنَا أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم رَمَى الْجَمْرَةَ بِمِثْلِ حَصَى الْخَذْفِ ‏.‏\hadithno{3140}\hadithtrans{Jabir b. 'Abdullah reported:I saw Allah's Apostle (ﷺ) throwing stones (at Jamrat al 'Aqaba) like pelting of small pebbles}}
\hadithdefcmd{muslim}{3141}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، وَابْنُ، إِدْرِيسَ عَنِ ابْنِ، جُرَيْجٍ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ رَمَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْجَمْرَةَ يَوْمَ النَّحْرِ ضُحًى وَأَمَّا بَعْدُ فَإِذَا زَالَتِ الشَّمْسُ ‏.‏\hadithno{3141}\hadithtrans{Jabir (Allah be pleased with him) reported that Allah's Messenger (ﷺ) flung pebbles at jamra on the Day of Nahr after sunrise, and after that (i. e. on the 11th, 12th and 13th of Dhu'l-Hijja when the sun had declined)}}
\hadithdefcmd{muslim}{3142}{وَحَدَّثَنَاهُ عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{3142}\hadithtrans{Jabir b. Abdullah reported a hadith like this from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{3143}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، - وَهُوَ ابْنُ عُبَيْدِ اللَّهِ الْجَزَرِيُّ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الاِسْتِجْمَارُ تَوٌّ وَرَمْىُ الْجِمَارِ تَوٌّ وَالسَّعْىُ بَيْنَ الصَّفَا وَالْمَرْوَةِ تَوٌّ وَالطَّوَافُ تَوٌّ وَإِذَا اسْتَجْمَرَ أَحَدُكُمْ فَلْيَسْتَجْمِرْ بِتَوٍّ ‏"‏ ‏.‏\hadithno{3143}\hadithtrans{Jabir (b. Abdullab) (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Odd number of stones are to be used for cleaning (the private parts after answering the call of nature), and casting of pebbles at the Jamras is to be done by odd numbers (seven), and (the number) of circuits between al-Safa' and al-Marwa is also odd (seven), and the number of circuits (around the Ka'ba) is also odd (seven). Whenever any one of you is required to use stones (for cleaning the private parts) he should use odd number of stones (three, five or seven)}}
\hadithdefcmd{muslim}{3144}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ، قَالَ حَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَحَلَقَ طَائِفَةٌ مِنْ أَصْحَابِهِ وَقَصَّرَ بَعْضُهُمْ ‏.‏ قَالَ عَبْدُ اللَّهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ - مَرَّةً أَوْ مَرَّتَيْنِ ثُمَّ قَالَ - وَالْمُقَصِّرِينَ ‏"‏ ‏.‏\hadithno{3144}\hadithtrans{Abdullah reported that Allah's Messenger (ﷺ) got his head shaved (after slaughtering the sacrificial animal on the 10th of Dhu'l-Hijja), and so did a group of Companions, while some of them got their hair clipped. Abdullah said:Allah's Messenger (may peace'be upon him) observed once or twice:" May Allah have mercy upon those who get their heads shaved." And he also said:" Upon those too who got their hair clipped}}
\hadithdefcmd{muslim}{3145}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اللَّهُمَّ ارْحَمِ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ اللَّهُمَّ ارْحَمِ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏ ‏.‏\hadithno{3145}\hadithtrans{Abdullah b. Umar (Allah be pleased with him) reported Allah's Messenger (ﷺ) as having observed:O Allah, have mercy upon those who get their heads shaved. They (the Companions) said: Messenger of Allah, (what about those) who have got their hair clipped? He said: O Allah, have mercy upon those who have got their heads shaved. They (again) said: Allah's Messenger, (what about those) who have got their hair clipped? Thereupon he said: (O Allah, have mercy upon those) who have got their hair clipped}}
\hadithdefcmd{muslim}{3146}{أَخْبَرَنَا أَبُو إِسْحَاقَ، إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ سُفْيَانَ عَنْ مُسْلِمِ بْنِ الْحَجَّاجِ، قَالَ حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏ ‏.‏\hadithno{3146}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) said:May Allah have mercy upon those who have got their heads shaved. They said: Messenger of Allah, (what about) those who got their hair clipped? He said: May Allah have mercy upon those who have got their heads shaved. They said: Messenger of Allah, (what about those who have got their hair clipped)? He said: May Allah have mercy upon those who got their hair shaved. They said: Messenger of Allah, (what about) those who got their hair clipped? He said: (O Allah, have mercy upon) those who got their hair clipped}}
\hadithdefcmd{muslim}{3147}{وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، بِهَذَا الإِسْنَادِ وَقَالَ فِي الْحَدِيثِ فَلَمَّا كَانَتِ الرَّابِعَةُ قَالَ ‏ "‏ وَالْمُقَصِّرِينَ ‏"‏ ‏.‏\hadithno{3147}\hadithtrans{Ubaidullah reported this hadith with the same chain of transmitters and (it is said) that it was on the fourth turn that he (the Holy Prophet) said:(May Allah have mercy upon) those who got their hair clipped}}
\hadithdefcmd{muslim}{3148}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ وَأَبُو كُرَيْبٍ جَمِيعًا عَنِ ابْنِ فُضَيْلٍ، - قَالَ زُهَيْرٌ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، - حَدَّثَنَا عُمَارَةُ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي، هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ اغْفِرْ لِلْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَلِلْمُقَصِّرِينَ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِلْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَلِلْمُقَصِّرِينَ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِلْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَلِلْمُقَصِّرِينَ قَالَ ‏"‏ وَلِلْمُقَصِّرِينَ ‏"‏‏.‏\hadithno{3148}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as having said:O Allah, grant pardon to those who got their heads shaved. They (Companions of the Holy Prophet) said: Messenger of Allah, (what about those) who get their hair cut? He said: O Allah, grant pardon to those who get their heads shaved. They said: Messenger of Allah, (what about those) who got their hair clipped? He said: O Allah, grant pardon to those who get their heads shaved. They said: Messenger of Allah, (what about those) who get their hair clipped? He said: (O Allah, grant pardon to) those who get their hair clipped}}
\hadithdefcmd{muslim}{3149}{وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحٌ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ أَبِي زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ.‏\hadithno{3149}\hadithtrans{A hadith like this is narrated on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{3150}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَأَبُو دَاوُدَ الطَّيَالِسِيُّ عَنْ شُعْبَةَ، عَنْ يَحْيَى بْنِ الْحُصَيْنِ، عَنْ جَدَّتِهِ، أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ دَعَا لِلْمُحَلِّقِينَ ثَلاَثًا وَلِلْمُقَصِّرِينَ مَرَّةً ‏.‏ وَلَمْ يَقُلْ وَكِيعٌ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{3150}\hadithtrans{Yahya b. al-Husain reported on the authority of his grandfather that Allah's Apostle (ﷺ) invoked blessing on the occasion of the Farewell Pilgrimage three times for those who got their heads shaved and once for those who got their hair clipped. In the narration transmitted by Waki' there is no mention of the Farewell Pilgrimage}}
\hadithdefcmd{muslim}{3151}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - كِلاَهُمَا عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَلَقَ رَأْسَهُ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{3151}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) got his head shaved on the occasion of the Farewell Pilgrimage}}
\hadithdefcmd{muslim}{3152}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى مِنًى فَأَتَى الْجَمْرَةَ فَرَمَاهَا ثُمَّ أَتَى مَنْزِلَهُ بِمِنًى وَنَحَرَ ثُمَّ قَالَ لِلْحَلاَّقِ ‏ "‏ خُذْ ‏"‏ ‏.‏ وَأَشَارَ إِلَى جَانِبِهِ الأَيْمَنِ ثُمَّ الأَيْسَرِ ثُمَّ جَعَلَ يُعْطِيهِ النَّاسَ ‏.‏\hadithno{3152}\hadithtrans{Anas b. Malik (Allah be pleased wish him) reported that Allah's Messenger (ﷺ) came to Mina; he went to the Jamra and threw pebbles at it, after which he went to his lodging in Mina, and sacrificed the animal. He then called for a barber and, turning his right side to him, let him shave him; after which he tiimed his left side. He then gave (these hair) to the people}}
\hadithdefcmd{muslim}{3153}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَأَبُو كُرَيْبٍ قَالُوا أَخْبَرَنَا حَفْصُ بْنُ، غِيَاثٍ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ أَمَّا أَبُو بَكْرٍ فَقَالَ فِي رِوَايَتِهِ لِلْحَلاَّقِ ‏"‏ هَا ‏"‏ ‏.‏ وَأَشَارَ بِيَدِهِ إِلَى الْجَانِبِ الأَيْمَنِ هَكَذَا فَقَسَمَ شَعَرَهُ بَيْنَ مَنْ يَلِيهِ - قَالَ - ثُمَّ أَشَارَ إِلَى الْحَلاَّقِ وَإِلَى الْجَانِبِ الأَيْسَرِ فَحَلَقَهُ فَأَعْطَاهُ أُمَّ سُلَيْمٍ ‏.‏ وَأَمَّا فِي رِوَايَةِ أَبِي كُرَيْبٍ قَالَ فَبَدَأَ بِالشِّقِّ الأَيْمَنِ فَوَزَّعَهُ الشَّعَرَةَ وَالشَّعَرَتَيْنِ بَيْنَ النَّاسِ ثُمَّ قَالَ بِالأَيْسَرِ فَصَنَعَ بِهِ مِثْلَ ذَلِكَ ثُمَّ قَالَ ‏"‏ هَا هُنَا أَبُو طَلْحَةَ ‏"‏ ‏.‏ فَدَفَعَهُ إِلَى أَبِي طَلْحَةَ ‏.‏\hadithno{3153}\hadithtrans{Abu Bakr reported:(He called for) the barber and, pointing towards the right side of his head, said: (Start from) here, and then distributed his hair among those who were near him. He then pointed to the barber (to shave) the left side and he shaved it, and he gave (these hair) to Umm Sulaim (Allah be pleased with her). And in the narration of Abu Kuraib (the words are):" He started from the right half (of his head), and he distributed a hair or two among the people. and then (asked the barber) to shave the left side and he did similarly, and he (the Holy Prophet) said: Here is Abu Talha and he gave these (hair) to Abu Talha}}
\hadithdefcmd{muslim}{3154}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ أَنَسِ، بْنِ مَالِكٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَى جَمْرَةَ الْعَقَبَةِ ثُمَّ انْصَرَفَ إِلَى الْبُدْنِ فَنَحَرَهَا وَالْحَجَّامُ جَالِسٌ وَقَالَ بِيَدِهِ عَنْ رَأْسِهِ فَحَلَقَ شِقَّهُ الأَيْمَنَ فَقَسَمَهُ فِيمَنْ يَلِيهِ ثُمَّ قَالَ ‏"‏ احْلِقِ الشِّقَّ الآخَرَ ‏"‏ ‏.‏ فَقَالَ ‏"‏ أَيْنَ أَبُو طَلْحَةَ ‏"‏ ‏.‏ فَأَعْطَاهُ إِيَّاهُ ‏.‏\hadithno{3154}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported that Allah's Messenger (ﷺ) threw stones at Jamrat al-'Aqaba. He then want to his sacrificial animal and sacrificed it, and there was sitting the barber, and he pointed with his hand towards his head, and he shaved the right half of it, and he (the Holy Prophet) distributed them (the hair) among those who were near him. And he again said:Shave the other half, and said: Where is Abu Talha and gave it (the hair) to him}}
\hadithdefcmd{muslim}{3155}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، سَمِعْتُ هِشَامَ بْنَ حَسَّانَ، يُخْبِرُ عَنِ ابْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا رَمَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْجَمْرَةَ وَنَحَرَ نُسُكَهُ وَحَلَقَ نَاوَلَ الْحَالِقَ شِقَّهُ الأَيْمَنَ فَحَلَقَهُ ثُمَّ دَعَا أَبَا طَلْحَةَ الأَنْصَارِيَّ فَأَعْطَاهُ إِيَّاهُ ثُمَّ نَاوَلَهُ الشِّقَّ الأَيْسَرَ فَقَالَ ‏"‏ احْلِقْ ‏"‏ ‏.‏ فَحَلَقَهُ فَأَعْطَاهُ أَبَا طَلْحَةَ فَقَالَ ‏"‏ اقْسِمْهُ بَيْنَ النَّاسِ ‏"‏‏.‏\hadithno{3155}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported:When Allah's Messenger (ﷺ) had thrown pebbles at the Jamra and had sacrificed the animal, he turned (the right side) of his head towards the barber, and i. e shaved it. He then called Abu Talha al-Ansari and gave it to him. He then turned his left side and asked him (the barber) to shave. And he (the barber) shaved. and gave it to Abu Talha and told him to distribute it amongst the people}}
\hadithdefcmd{muslim}{3156}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عِيسَى بْنِ، طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ وَقَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ بِمِنًى لِلنَّاسِ يَسْأَلُونَهُ فَجَاءَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ لَمْ أَشْعُرْ فَحَلَقْتُ قَبْلَ أَنْ أَنْحَرَ ‏.‏ فَقَالَ ‏"‏ اذْبَحْ وَلاَ حَرَجَ ‏"‏ ‏.‏ ثُمَّ جَاءَهُ رَجُلٌ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ لَمْ أَشْعُرْ فَنَحَرْتُ قَبْلَ أَنْ أَرْمِيَ فَقَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ فَمَا سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ شَىْءٍ قُدِّمَ وَلاَ أُخِّرَ إِلاَّ قَالَ ‏"‏ افْعَلْ وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3156}\hadithtrans{Abdullah b. 'Amr b. al-'As said that Allah's Messenger (ﷺ) stopped during the Farewell Pilgrimage at Mina for people who had something to ask. A man came and said:Messenger of Allah, being ignorant. I shaved before sacrificing, whereupon he (the Holy Prophet) said: Now sacrifice (the animal) and there is no harm (for you). Then another man came and he said: Messenger of Allah, being ignorant, I sacrificed before throwing the pebbles, whereupon he (the Holy Prophet) said: (Now) throw the pebbles, and there is no harm (for you). Allah's Messenger (ﷺ) was not asked about anything which had been done before or after (its proper time) but he said: Do it, and no harm is there (for you)}}
\hadithdefcmd{muslim}{3157}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عِيسَى بْنُ طَلْحَةَ التَّيْمِيُّ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، يَقُولُ وَقَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رَاحِلَتِهِ فَطَفِقَ نَاسٌ يَسْأَلُونَهُ فَيَقُولُ الْقَائِلُ مِنْهُمْ يَا رَسُولَ اللَّهِ إِنِّي لَمْ أَكُنْ أَشْعُرُ أَنَّ الرَّمْىَ قَبْلَ النَّحْرِ فَنَحَرْتُ قَبْلَ الرَّمْىِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ وَطَفِقَ آخَرُ يَقُولُ إِنِّي لَمْ أَشْعُرْ أَنَّ النَّحْرَ قَبْلَ الْحَلْقِ فَحَلَقْتُ قَبْلَ أَنْ أَنْحَرَ ‏.‏ فَيَقُولُ ‏"‏ انْحَرْ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ فَمَا سَمِعْتُهُ يُسْأَلُ يَوْمَئِذٍ عَنْ أَمْرٍ مِمَّا يَنْسَى الْمَرْءُ وَيَجْهَلُ مِنْ تَقْدِيمِ بَعْضِ الأُمُورِ قَبْلَ بَعْضٍ وَأَشْبَاهِهَا إِلاَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ افْعَلُوا ذَلِكَ وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3157}\hadithtrans{Abdullah b. 'Amr b. al-'As (Allah be pleased with them) reported:Allah's Messenger (ﷺ) stopped while riding his camel and the people began to ask him. One of the inquirers said: Messenger of Allah, I did not know that pebbles should be thrown before sacrificing the animal, and by mistake I sacrificed the animal before throwing pebbles, whereupon Allah's Messenger (ﷺ) said: (Now) throw pebbles and there is no harm in it. Then another (person) came saying: I did not know that the animal was to be sacrificed before shaving, but I got myself shaved before sacrificing the animal, whereupon he (the Holy Prophet) said: Sacrifice the animal (now) and there is no harm in it. He (the narrator) said: I did not hear that anything was asked on that day (shout a matter) which a person forgot and could not observe the sequence or anything like it either due to forgetfulness or ignorance, but Allah's Messenger (ﷺ) said (about that): Do it; there is no harm in it}}
\hadithdefcmd{muslim}{3158}{حَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، بِمِثْلِ حَدِيثِ يُونُسَ عَنِ الزُّهْرِيِّ، إِلَى آخِرِهِ ‏.‏\hadithno{3158}\hadithtrans{This hadith has been narrated on the authority of Zuhri}}
\hadithdefcmd{muslim}{3159}{وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ سَمِعْتُ ابْنَ شِهَابٍ، يَقُولُ حَدَّثَنِي عِيسَى بْنُ طَلْحَةَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَيْنَا هُوَ يَخْطُبُ يَوْمَ النَّحْرِ فَقَامَ إِلَيْهِ رَجُلٌ فَقَالَ مَا كُنْتُ أَحْسِبُ يَا رَسُولَ اللَّهِ أَنَّ كَذَا وَكَذَا قَبْلَ كَذَا وَكَذَا ثُمَّ جَاءَ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ كُنْتُ أَحْسِبُ أَنَّ كَذَا قَبْلَ كَذَا وَكَذَا لِهَؤُلاَءِ الثَّلاَثِ قَالَ ‏ "‏ افْعَلْ وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3159}\hadithtrans{Abdullah b. Amr b. al-'As (Allah be pleased with them) reported:As Allah's Apostle. (ﷺ) was delivering sermon on the Day of Nahr, a man stood up before him and said: Messenger of Allah, I did not know that such and such (rite was to be performed) before such and such (rite). Then another man came and said: Messenger of Allah, I thought that such and such (rite) should precede such and such (rite), and then another man came and said: Messenger of Allah, I had thought that such and such was before such and such, and such and such (is the sequence) of the three (rites, viz. throwing of pebbles, sacrificing of animal and shaving of one's head). He said to all these three: Do now (if you have not observed the cequence) ; there is no harm in it}}
\hadithdefcmd{muslim}{3160}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، ح وَحَدَّثَنِي سَعِيدُ بْنُ يَحْيَى الأُمَوِيُّ، حَدَّثَنِي أَبِي جَمِيعًا، عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ أَمَّا رِوَايَةُ ابْنِ بَكْرٍ فَكَرِوَايَةِ عِيسَى إِلاَّ قَوْلَهُ لِهَؤُلاَءِ الثَّلاَثِ ‏.‏ فَإِنَّهُ لَمْ يَذْكُرْ ذَلِكَ وَأَمَّا يَحْيَى الأُمَوِيُّ فَفِي رِوَايَتِهِ حَلَقْتُ قَبْلَ أَنْ أَنْحَرَ نَحَرْتُ قَبْلَ أَنْ أَرْمِيَ ‏.‏ وَأَشْبَاهَ ذَلِكَ ‏.‏\hadithno{3160}\hadithtrans{This hadith has been narrated on the authority of Ibn Juraij with the same chain of transmitters. And the narration of Ibn Bakr is like one transmitted by 'Isa but with this (variation):" There are not these words in it: To all these three rites (throwing of pebbles sacrificing of animal and shaving of one's head)." And so far as the narration of Yahya al-Umawi (the words are): I got (my head) shaved before I sacrificed the animal, and I sacrified the animal before throwing pebbles, and like that}}
\hadithdefcmd{muslim}{3161}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ فَقَالَ حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ ‏.‏ قَالَ ‏"‏ فَاذْبَحْ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ ذَبَحْتُ قَبْلَ أَنْ أَرْمِيَ ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3161}\hadithtrans{Adullah b. 'Amr (b. al-'As) (Allah be pleased with him) reported that a person came to Allah's Apostle (ﷺ) and said:I got (my head) shaved before sacrificing the, animal, whereupon be (the Holy Prophet) said: Sacrifice the animal (now) ; there is no harm in it. He (the person said): I sacripced the animal before throwingpebbles. whereupon he said: Throw pebbles (now) ; there is no harm in it}}
\hadithdefcmd{muslim}{3162}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ عَبْدِ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى نَاقَةٍ بِمِنًى فَجَاءَهُ رَجُلٌ ‏.‏ بِمَعْنَى حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{3162}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters (and the words are):I saw Allah's Messenger (ﷺ) on the back of the camel at Mina, and a person came to him," and the rest of the hadith Is like that transmitted by Ibn 'Uyaina}}
\hadithdefcmd{muslim}{3163}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ قُهْزَاذَ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ، الْمُبَارَكِ أَخْبَرَنَا مُحَمَّدُ بْنُ أَبِي حَفْصَةَ، عَنِ الزُّهْرِيِّ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ، عَمْرِو بْنِ الْعَاصِ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَتَاهُ رَجُلٌ يَوْمَ النَّحْرِ وَهُوَ وَاقِفٌ عِنْدَ الْجَمْرَةِ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي حَلَقْتُ قَبْلَ أَنْ أَرْمِيَ ‏.‏ فَقَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ وَأَتَاهُ آخَرُ فَقَالَ إِنِّي ذَبَحْتُ قَبْلَ أَنْ أَرْمِيَ ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏ وَأَتَاهُ آخَرُ فَقَالَ إِنِّي أَفَضْتُ إِلَى الْبَيْتِ قَبْلَ أَنْ أَرْمِيَ ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ فَمَا رَأَيْتُهُ سُئِلَ يَوْمَئِذٍ عَنْ شَىْءٍ إِلاَّ قَالَ ‏"‏ افْعَلُوا وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3163}\hadithtrans{Abdullah b. 'Amr b. al-As (Allah be pleased with them) said:As Allah's Messenger (may peace be'upon him) was standing near the jamra, a person came to him on the Day of Nahr and said: Messenger of Allah, I got (my head shaved) before throwing pebbles, whereupon he (the Holy Prophet) said: Throw pebbles (now) ; there is no harm in it. Another man (then) came and said: I have sacrificed before throwing the stones. He said: Throw stones (now) and there is no harm. Another came to him and said: I have observed the circumambulation of Ifada of the House before throwing pebbles. He said: Throw pebbles (now) ; there is no harm in it, He (the narrator) said: I did not see that he (the Holy Prophet) was asked about anything on that day, but he said: Do, and there is no harm in it}}
\hadithdefcmd{muslim}{3164}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قِيلَ لَهُ فِي الذَّبْحِ وَالْحَلْقِ وَالرَّمْىِ وَالتَّقْدِيمِ وَالتَّأْخِيرِ فَقَالَ ‏ "‏ لاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3164}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that it was said to Allah's Apostle (ﷺ) about sacrificing of animals, shaving of one's head, throwing of pebbles, and (the order of) precedence and succession, and he said:There is no harm in it}}
\hadithdefcmd{muslim}{3165}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفَاضَ يَوْمَ النَّحْرِ ثُمَّ رَجَعَ فَصَلَّى الظُّهْرَ بِمِنًى ‏.‏ قَالَ نَافِعٌ فَكَانَ ابْنُ عُمَرَ يُفِيضُ يَوْمَ النَّحْرِ ثُمَّ يَرْجِعُ فَيُصَلِّي الظُّهْرَ بِمِنًى وَيَذْكُرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم فَعَلَهُ ‏.‏\hadithno{3165}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) observed the circumambulation of Ifada on the Day of Nabr (10th of Dhu'l-Hijja), and then came back and observed the noon prayer at Mina. Nafi' (one of the narrators) said that Ibn Umar used to observe the circumambulation of Ifada on the Day of Nahr, and then return and observe the noon prayer at Mina, and mentioned that Allah's Apostle (ﷺ) did that}}
\hadithdefcmd{muslim}{3166}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ قُلْتُ أَخْبِرْنِي عَنْ شَىْءٍ، عَقَلْتَهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَيْنَ صَلَّى الظُّهْرَ يَوْمَ التَّرْوِيَةِ قَالَ بِمِنًى ‏.‏ قُلْتُ فَأَيْنَ صَلَّى الْعَصْرَ يَوْمَ النَّفْرِ قَالَ بِالأَبْطَحِ - ثُمَّ قَالَ - افْعَلْ مَا يَفْعَلُ أُمَرَاؤُكَ ‏.‏\hadithno{3166}\hadithtrans{Abd al-'Aziz b. Rufai' (Allah be pleased with him) said:I asked Anas b. Malik to tell me about something he knew about Allah's Messenger (ﷺ), viz. where he observed the noon prayer on Yaum al-Tarwiya. He said: At Mina. I said: Where did he observe the afternoon prayer on the Yaum an-Nafr? and he said: It was at al-Abtah. He then said: Do as your rulers do}}
\hadithdefcmd{muslim}{3167}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ كَانُوا يَنْزِلُونَ الأَبْطَحَ\hadithno{3167}\hadithtrans{Ibn 'Umar (Allah be pleased with him) reported that Allah's Messenger (ﷺ) and Abu Bakr and 'Umar observed halt at al-Abtah}}
\hadithdefcmd{muslim}{3168}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا صَخْرُ بْنُ جُوَيْرِيَةَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يَرَى التَّحْصِيبَ سُنَّةً وَكَانَ يُصَلِّي الظُّهْرَ يَوْمَ النَّفْرِ بِالْحَصْبَةِ ‏.‏ قَالَ نَافِعٌ قَدْ حَصَّبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْخُلَفَاءُ بَعْدَهُ ‏.‏\hadithno{3168}\hadithtrans{Nafi' reported that Ibn 'Umar regarded halt at Muhassab as Sunnah (of the Holy Prophet) and observed the noon prayer on Yaum al-Nafr at that place. Nafi' said:Allah's Messenger (ﷺ) halted at Muhassab and the Caliphs did the same after him}}
\hadithdefcmd{muslim}{3169}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ نُزُولُ الأَبْطَحِ لَيْسَ بِسُنَّةٍ إِنَّمَا نَزَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَنَّهُ كَانَ أَسْمَحَ لِخُرُوجِهِ إِذَا خَرَجَ ‏.‏\hadithno{3169}\hadithtrans{A'isha (Allah be pleased with her) reported.:Halt at al-Abtah is not the Sunnah. Allah's Messenger (ﷺ) halted there simply because it was easier for him to depart from there, when he left}}
\hadithdefcmd{muslim}{3170}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، ح وَحَدَّثَنِيهِ أَبُو الرَّبِيعِ، الزَّهْرَانِيُّ حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح وَحَدَّثَنَاهُ أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حَبِيبٌ الْمُعَلِّمُ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3170}\hadithtrans{This hadith is narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{3171}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، أَنَّ أَبَا بَكْرٍ، وَعُمَرَ، وَابْنَ، عُمَرَ كَانُوا يَنْزِلُونَ الأَبْطَحَ ‏.‏ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ، أَنَّهَا لَمْ تَكُنْ تَفْعَلُ ذَلِكَ وَقَالَتْ إِنَّمَا نَزَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَنَّهُ كَانَ مَنْزِلاً أَسْمَحَ لِخُرُوجِهِ ‏.‏\hadithno{3171}\hadithtrans{Salim reported that Abu Bakr, 'Umar and Ibn Umar used to halt at Abtah. 'Urwa narrated from 'A'isha (Allah be pleased with her) that he did not observe this practice and said:Allah's Messenger (ﷺ) halted there, for it is a place from where it was easy to depart}}
\hadithdefcmd{muslim}{3172}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، وَأَحْمَدُ بْنُ، عَبْدَةَ - وَاللَّفْظُ لأَبِي بَكْرٍ - حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَيْسَ التَّحْصِيبُ بِشَىْءٍ إِنَّمَا هُوَ مَنْزِلٌ نَزَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3172}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported:Halt at Muhassab is not something (significant from the point of view of the Shari'ah). It is a place of halt where Allah's Messenger (way peace be upon him) halted}}
\hadithdefcmd{muslim}{3173}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ جَمِيعًا عَنِ ابْنِ، عُيَيْنَةَ قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ قَالَ أَبُو رَافِعٍ لَمْ يَأْمُرْنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَنْزِلَ الأَبْطَحَ حِينَ خَرَجَ مِنْ مِنًى وَلَكِنِّي جِئْتُ فَضَرَبْتُ فِيهِ قُبَّتَهُ فَجَاءَ فَنَزَلَ ‏.‏ قَالَ أَبُو بَكْرٍ فِي رِوَايَةِ صَالِحٍ قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ ‏.‏ وَفِي رِوَايَةِ قُتَيْبَةَ قَالَ عَنْ أَبِي رَافِعٍ وَكَانَ عَلَى ثَقَلِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3173}\hadithtrans{Abu Rafi' reported:Allah's Messenger (ﷺ) did not command me to observe halt at al-Abtah when be departed from Mina, but I came and set up his (the Holy Prcphet's) tent (of my own accord) ; and he (Allah's Apostle) came and observed halt. This hadith is narrated through another chain of transmitters from Abu Rafi' who was (in charge) of the luggage of Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{3174}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ نَنْزِلُ غَدًا إِنْ شَاءَ اللَّهُ بِخَيْفِ بَنِي كِنَانَةَ حَيْثُ تَقَاسَمُوا عَلَى الْكُفْرِ ‏"‏ ‏.‏\hadithno{3174}\hadithtrans{Abu Huraira (Allah be pleated with him) reported that Allah's Messenger (ﷺ) said:God willing, we will get down tomorrow, at Khaif of Banu Kinanah, the place where they had taken an oath on unbelief}}
\hadithdefcmd{muslim}{3175}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنِي الأَوْزَاعِيُّ، حَدَّثَنِي الزُّهْرِيُّ، حَدَّثَنِي أَبُو سَلَمَةَ، حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ بِمِنًى ‏ "‏ نَحْنُ نَازِلُونَ غَدًا بِخَيْفِ بَنِي كِنَانَةَ حَيْثُ تَقَاسَمُوا عَلَى الْكُفْرِ ‏"‏ ‏.‏ وَذَلِكَ إِنَّ قُرَيْشًا وَبَنِي كِنَانَةَ تَحَالَفَتْ عَلَى بَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ أَنْ لاَ يُنَاكِحُوهُمْ وَلاَ يُبَايِعُوهُمْ حَتَّى يُسْلِمُوا إِلَيْهِمْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَعْنِي بِذَلِكَ الْمُحَصَّبَ ‏.‏\hadithno{3175}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:Allah's Messenger (ﷺ) said to us as we were at Mina: We would observe halt tomorrow at-Khaif of Banu Kinanah, where (the polytheists) had taken an oath on unbelief, and that was that the Quraish and Banu Kinanah had, pledged against Banu Hashim and Banu Muttalib that they would neither marry nor do any transaction with them unless they deliver Allah's Messenger (way peace be upon him) to them. And (this pledge was) taken at this (place) Muhassab}}
\hadithdefcmd{muslim}{3176}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْزِلُنَا - إِنْ شَاءَ اللَّهُ إِذَا فَتَحَ اللَّهُ - الْخَيْفُ حَيْثُ تَقَاسَمُوا عَلَى الْكُفْرِ ‏"‏ ‏.‏\hadithno{3176}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:God willing, when Allah has granted us victory, our halt tomorrow will be at Khaif, where they (the unbelievers of Mecca) had taken an oath on unbelief}}
\hadithdefcmd{muslim}{3177}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ح. وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ الْعَبَّاسَ بْنَ عَبْدِ الْمُطَّلِبِ، اسْتَأْذَنَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيتَ بِمَكَّةَ لَيَالِيَ مِنًى مِنْ أَجْلِ سِقَايَتِهِ فَأَذِنَ لَهُ ‏.‏\hadithno{3177}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that al-'A'bbas b. Abd al-Muttalib (Allah be pleased with him) sought permission from Allah's Messenger (ﷺ) to spend in Mecca the nights (which be was required to spend) at Mina on account of his office of supplier of water, and he (the Holy Prophet) granted him permission}}
\hadithdefcmd{muslim}{3178}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ، حَاتِمٍ وَعَبْدُ بْنُ حُمَيْدٍ جَمِيعًا عَنْ مُحَمَّدِ بْنِ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، كِلاَهُمَا عَنْ عُبَيْدِ اللَّهِ، بْنِ عُمَرَ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3178}\hadithtrans{A hadith like this has been narrated by 'Ubaidullah b. Umar with the the same chain of transmitters}}
\hadithdefcmd{muslim}{3179}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمِنْهَالِ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، قَالَ كُنْتُ جَالِسًا مَعَ ابْنِ عَبَّاسٍ عِنْدَ الْكَعْبَةِ فَأَتَاهُ أَعْرَابِيٌّ فَقَالَ مَا لِي أَرَى بَنِي عَمِّكُمْ يَسْقُونَ الْعَسَلَ وَاللَّبَنَ وَأَنْتُمْ تَسْقُونَ النَّبِيذَ أَمِنْ حَاجَةٍ بِكُمْ أَمْ مِنْ بُخْلٍ فَقَالَ ابْنُ عَبَّاسٍ الْحَمْدُ لِلَّهِ مَا بِنَا مِنْ حَاجَةٍ وَلاَ بُخْلٍ قَدِمَ النَّبِيُّ صلى الله عليه وسلم عَلَى رَاحِلَتِهِ وَخَلْفَهُ أُسَامَةُ فَاسْتَسْقَى فَأَتَيْنَاهُ بِإِنَاءٍ مِنْ نَبِيذٍ فَشَرِبَ وَسَقَى فَضْلَهُ أُسَامَةَ وَقَالَ ‏ "‏ أَحْسَنْتُمْ وَأَجْمَلْتُمْ كَذَا فَاصْنَعُوا ‏"‏ ‏.‏ فَلاَ نُرِيدُ تَغْيِيرَ مَا أَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3179}\hadithtrans{Bakr b. 'Abdullah al-Muzani said:While I was sitting along with Ibn 'Abbas (Allah be pleased with him) near the Ka'ba, there came a bedouin to him and said: What is the matter that I see that the progeny of your uncle supply honey and milk (as drink to the travellers), whereas you supply al-nabidh (water sweetened with dates)? Is it due to your poverty or due to your close-fistedness? Thereupon Ibn 'Abbas said: Allah be praised, it is neither due to poverty nor due to close-fistedness (but due to the fact) that Allah's Apostle (ﷺ) came here riding his she-came, and there was sitting behind him Usama. He asked for water, and we gave him a cup full of nabidh and he drank it, and gave the remaining (part) to Usama; and he (the Holy Prophet) said: You have done Food, You have done well. So continue doing like it So we do not like to change what Allah's Messenger (ﷺ) had commanded us to do}}
\hadithdefcmd{muslim}{3180}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ، الرَّحْمَنِ بْنِ أَبِي لَيْلَى عَنْ عَلِيٍّ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَقُومَ عَلَى بُدْنِهِ وَأَنْ أَتَصَدَّقَ بِلَحْمِهَا وَجُلُودِهَا وَأَجِلَّتِهَا وَأَنْ لاَ أُعْطِيَ الْجَزَّارَ مِنْهَا قَالَ ‏ "‏ نَحْنُ نُعْطِيهِ مِنْ عِنْدِنَا ‏"‏ ‏.‏\hadithno{3180}\hadithtrans{All (Allah be pleased with him) reperted:Allah's Messenger (ﷺ) put me in charge of his sacrificial animals, that I should give their flesh. skins and saddle cloths as sadaqa, but not to give anything to the butcher, saying: We would pay him ourselves}}
\hadithdefcmd{muslim}{3181}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3181}\hadithtrans{This hadith has been narrated on the authority of Abd al-Karim al-Jazari with the same chain of transmitters}}
\hadithdefcmd{muslim}{3182}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا سُفْيَانُ، وَقَالَ، إِسْحَاقُ بْنُ إِبْرَاهِيمَ أَخْبَرَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي كِلاَهُمَا، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي، لَيْلَى عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَيْسَ فِي حَدِيثِهِمَا أَجْرُ الْجَازِرِ ‏.‏\hadithno{3182}\hadithtrans{This hadith has been narrated on the authority of 'Ali (Allah be pleased with him) with another chain of transmitters, but there is no mention of the wages of the butcher in it}}
\hadithdefcmd{muslim}{3183}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، وَمُحَمَّدُ بْنُ مَرْزُوقٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، أَنَّ مُجَاهِدًا، أَخْبَرَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ أَخْبَرَهُ ‏.‏ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم أَمَرَهُ أَنْ يَقُومَ عَلَى بُدْنِهِ وَأَمَرَهُ أَنْ يَقْسِمَ بُدْنَهُ كُلَّهَا لُحُومَهَا وَجُلُودَهَا وَجِلاَلَهَا فِي الْمَسَاكِينِ وَلاَ يُعْطِيَ فِي جِزَارَتِهَا مِنْهَا شَيْئًا ‏.‏\hadithno{3183}\hadithtrans{Ali b. Abi Talib (Allah be pleased with him) reported:Allah's Apostle (ﷺ) put him in charge of his sacrificial animals, and commanded him to distribute the whole of their meat, hides, and saddle cloths to the poor, and not to give to the butcher anything out of them}}
\hadithdefcmd{muslim}{3184}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ، الْكَرِيمِ بْنُ مَالِكٍ الْجَزَرِيُّ أَنَّ مُجَاهِدًا، أَخْبَرَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ بِمِثْلِهِ ‏.‏\hadithno{3184}\hadithtrans{A hadith like this has been narrated on the authority of Hadrat 'Ali (Allah be pleased with him)}}
\hadithdefcmd{muslim}{3185}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ قَالَ نَحَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ الْبَدَنَةَ عَنْ سَبْعَةٍ وَالْبَقَرَةَ عَنْ سَبْعَةٍ ‏.‏\hadithno{3185}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with him) reported:In the year of Hudaibiya (6 H ), we, along with Allah's Messenger (way peace be upon him), sacrificed a camel for seven persons and a cow for seven persons}}
\hadithdefcmd{muslim}{3186}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، ح. وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُهِلِّينَ بِالْحَجِّ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَشْتَرِكَ فِي الإِبِلِ وَالْبَقَرِ كُلُّ سَبْعَةٍ مِنَّا فِي بَدَنَةٍ ‏.‏\hadithno{3186}\hadithtrans{Jabir (Allah be pleased with him) reported:We set out in the state of Ihram for Hajj along, with Allah's Messenger (ﷺ). He commanded us that seven persons should join in a camel and a cow for offering sacrifice}}
\hadithdefcmd{muslim}{3187}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ حَجَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَحَرْنَا الْبَعِيرَ عَنْ سَبْعَةٍ وَالْبَقَرَةَ عَنْ سَبْعَةٍ ‏.‏\hadithno{3187}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with him) reported:We performed Hajj along with Allah's Messenger (ﷺ), and we sacrificed a camel on behalf of seven persons, and a cow on behalf of seven persons}}
\hadithdefcmd{muslim}{3188}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ اشْتَرَكْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الْحَجِّ وَالْعُمْرَةِ كُلُّ سَبْعَةٍ فِي بَدَنَةٍ فَقَالَ رَجُلٌ لِجَابِرٍ أَيُشْتَرَكُ فِي الْبَدَنَةِ مَا يُشْتَرَكُ فِي الْجَزُورِ قَالَ مَا هِيَ إِلاَّ مِنَ الْبُدْنِ ‏.‏ وَحَضَرَ جَابِرٌ الْحُدَيْبِيَةَ قَالَ نَحَرْنَا يَوْمَئِذٍ سَبْعِينَ بَدَنَةً اشْتَرَكْنَا كُلُّ سَبْعَةٍ فِي بَدَنَةٍ ‏.‏\hadithno{3188}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:We joined Allah's Apostle (may pea, @. e be upon him) in Hajj and Umra and seven persons shared in the sacrifice of an animal. A person said to Jabir (Allah be pleased with him): Can seven persons share in the sacrifice of al-Badnah (a camel) as he shares in al- Jazur (a cow)? He, (Jabir) said: It (al-Jazur) is nothing but one among the budun. Jabir was present at Hudaibiya and he said: We sacrificed on that day seventy camel, and seven men shared in each sacrifice (of camel)}}
\hadithdefcmd{muslim}{3189}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنَا أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ عَنْ حَجَّةِ النَّبِيِّ، صلى الله عليه وسلم قَالَ فَأَمَرَنَا إِذَا أَحْلَلْنَا أَنْ نُهْدِيَ وَيَجْتَمِعَ النَّفَرُ مِنَّا فِي الْهَدِيَّةِ وَذَلِكَ حِينَ أَمَرَهُمْ أَنْ يَحِلُّوا مِنْ ‏.‏ حَجِّهِمْ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{3189}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them), describing the Hajj of Allah's Apostle (ﷺ) said:He (the Holy Prophet) commanded us as we had entered into the state of Ihram to sacrifice the animals (as a rite of Hajj) and a group (of person; amongst us, i. e. seven) shared in the sacrifice of one (camel or cow), and it happened at that time when he commanded them to put off Ihram for Hajj (after performing 'Umra)}}
\hadithdefcmd{muslim}{3190}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ، عَبْدِ اللَّهِ قَالَ كُنَّا نَتَمَتَّعُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْعُمْرَةِ فَنَذْبَحُ الْبَقَرَةَ عَنْ سَبْعَةٍ نَشْتَرِكُ فِيهَا ‏.‏\hadithno{3190}\hadithtrans{Jaibir b. 'Abdullah (Allah be pleased with them) reported:We performed Hajj Tamattu' along with Allah's Messenger (ﷺ) and we slaughtered a cow on behalf of seven persons sharing in it}}
\hadithdefcmd{muslim}{3191}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ ذَبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ عَائِشَةَ بَقَرَةً يَوْمَ النَّحْرِ ‏.‏\hadithno{3191}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) sacrificed a cow on behalf of 'A'isha on the Day of Nahr (10th of Dhu'l-Hijja)}}
\hadithdefcmd{muslim}{3192}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنِي سَعِيدُ، بْنُ يَحْيَى الأُمَوِيُّ حَدَّثَنِي أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ، اللَّهِ يَقُولُ نَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نِسَائِهِ ‏.‏ وَفِي حَدِيثِ ابْنِ بَكْرٍ عَنْ عَائِشَةَ بَقَرَةً فِي حَجَّتِهِ ‏.‏\hadithno{3192}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported that Allah's Messenger (ﷺ) sacrificed (animals) on behalf of his wives, and in the hadith transmitted by Ibn Abu Bakr (the words are):" A cow on behalf of 'A'isha on the occasion of the Hajj}}
\hadithdefcmd{muslim}{3193}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ يُونُسَ، عَنْ زِيَادِ بْنِ جُبَيْرٍ، أَنَّ ابْنَ عُمَرَ، أَتَى عَلَى رَجُلٍ وَهُوَ يَنْحَرُ بَدَنَتَهُ بَارِكَةً فَقَالَ ابْعَثْهَا قِيَامًا مُقَيَّدَةً سُنَّةَ نَبِيِّكُمْ صلى الله عليه وسلم ‏.‏\hadithno{3193}\hadithtrans{Ziyad b. Jubair reported that Ibn 'Umar came upon a person who was slaughtering (sacrificing) his camel and had made him kneel down. So he told him to make it stand up festered (and then sacrifice it) according to the Sunnah of the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{3194}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُهْدِي مِنَ الْمَدِينَةِ فَأَفْتِلُ قَلاَئِدَ هَدْيِهِ ثُمَّ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُ الْمُحْرِمُ ‏.‏\hadithno{3194}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) sent the sacrificial animals from Medina. I wove garlands for his sacrificial animals (and then he hung them round their necks), and he would not avoid doing anything which the Muhrim avoids}}
\hadithdefcmd{muslim}{3195}{وَحَدَّثَنِيهِ حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3195}\hadithtrans{A hadith like this has been transmitted on the authority of Ibn Shihab}}
\hadithdefcmd{muslim}{3196}{وَحَدَّثَنَاهُ سَعِيدُ بْنُ مَنْصُورٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح. وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَخَلَفُ بْنُ هِشَامٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالُوا أَخْبَرَنَا حَمَّادُ، بْنُ زَيْدٍ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَنْظُرُ إِلَىَّ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{3196}\hadithtrans{A'isha narrated (in another hadith narrated through another chain of transmitters) these words:"As if I am seeing myself weaving the garlands for the sacrificial animals of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3197}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَائِشَةَ، تَقُولُ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ هَاتَيْنِ ثُمَّ لاَ يَعْتَزِلُ شَيْئًا وَلاَ يَتْرُكُهُ\hadithno{3197}\hadithtrans{Abd al-Rahman b. al-Qasim reported on the authority of his father that he heard 'A'isha (Allah be pleased with her) saying:I used to weave garlands for the sacrificial animals of Allah's Messenger (ﷺ) with these hands of mine, but he (Allah's Apostle) neither avoided anything nor gave up anything (which a Muhrim should avoid or give up)}}
\hadithdefcmd{muslim}{3198}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا أَفْلَحُ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ فَتَلْتُ قَلاَئِدَ بُدْنِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ ثُمَّ أَشْعَرَهَا وَقَلَّدَهَا ثُمَّ بَعَثَ بِهَا إِلَى الْبَيْتِ وَأَقَامَ بِالْمَدِينَةِ فَمَا حَرُمَ عَلَيْهِ شَىْءٌ كَانَ لَهُ حِلاًّ ‏.‏\hadithno{3198}\hadithtrans{A'isha reported:I wove the garlands for the sacrificial animals of Allah's Messenger (ﷺ) with my own bands, and then he (the Holy Prophet) marked them, and garlanded them, and then sent them to the House, and stayed at Medina and nothing was forbidden to him which was lawful for him (before)}}
\hadithdefcmd{muslim}{3199}{وَحَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ ابْنُ حُجْرٍ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنِ الْقَاسِمِ، وَأَبِي، قِلاَبَةَ عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَبْعَثُ بِالْهَدْىِ أَفْتِلُ قَلاَئِدَهَا بِيَدَىَّ ثُمَّ لاَ يُمْسِكُ عَنْ شَىْءٍ لاَ يُمْسِكُ عَنْهُ الْحَلاَلُ ‏.‏\hadithno{3199}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) sent the sacrificial animals and I wove garlands for them with my own 'hands, and he did not refrain from doing anything which he did not avoid in the state of non-Muhrim}}
\hadithdefcmd{muslim}{3200}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا حُسَيْنُ بْنُ الْحَسَنِ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الْقَاسِمِ، عَنْ أُمِّ الْمُؤْمِنِينَ، قَالَتْ أَنَا فَتَلْتُ، تِلْكَ الْقَلاَئِدَ مِنْ عِهْنٍ كَانَ عِنْدَنَا فَأَصْبَحَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَلاَلاً يَأْتِي مَا يَأْتِي الْحَلاَلُ مِنْ أَهْلِهِ أَوْ يَأْتِي مَا يَأْتِي الرَّجُلُ مِنْ أَهْلِهِ ‏.‏\hadithno{3200}\hadithtrans{Al-Qasim reported the Mother of the Faithful (Hadrat 'A'isha Siddiqa) (Allah be pleased with her) as saying:I used to weave these garlands from the multicoloured wool which was with us. The Messenger of Allah (ﷺ) was in the state of non Muhrim among us, and he would do all that was lawful for a lion-Muhrim with his wife}}
\hadithdefcmd{muslim}{3201}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي أَفْتِلُ الْقَلاَئِدَ لِهَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْغَنَمِ فَيَبْعَثُ بِهِ ثُمَّ يُقِيمُ فِينَا حَلاَلاً ‏.‏\hadithno{3201}\hadithtrans{A'isha (Allah be pleased with her) reported:I recall how I wove garlands for the sacrificial animals (the goats) of Allah's Messenger (ﷺ). He sent them and then stayed with us as a non-Muhrim}}
\hadithdefcmd{muslim}{3202}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ رُبَّمَا فَتَلْتُ الْقَلاَئِدَ لِهَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيُقَلِّدُ هَدْيَهُ ثُمَّ يَبْعَثُ بِهِ ثُمَّ يُقِيمُ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُ الْمُحْرِمُ ‏.‏\hadithno{3202}\hadithtrans{A'isha (Allah, be pleased, with her) reported:I often wove garlands for the sacrificial animals of Allah's Messenger (ﷺ), and he garlanded his sacrificial animals, and then he sent them and stayed in the ouse) avoiding nothing which a Muhrim avoids}}
\hadithdefcmd{muslim}{3203}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ أَهْدَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَرَّةً إِلَى الْبَيْتِ غَنَمًا فَقَلَّدَهَا ‏.‏\hadithno{3203}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (may peace be upon, him) sent some goats as sacrificial animals to the House and He garlanded them}}
\hadithdefcmd{muslim}{3204}{وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنِي أَبِي، حَدَّثَنِي مُحَمَّدُ بْنُ جُحَادَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنَّا نُقَلِّدُ الشَّاءَ فَنُرْسِلُ بِهَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم حَلاَلٌ لَمْ يَحْرُمْ عَلَيْهِ مِنْهُ شَىْءٌ ‏.‏\hadithno{3204}\hadithtrans{A'isha (Allah be pleased with her) reported:We used to garland the goats and send them (to Mecca), and Allah's Messenger (ﷺ) stayed back in Medina as a non-Muhrim ard nothing was forbidden for him (which is forbidden for a Muhrim)}}
\hadithdefcmd{muslim}{3205}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، بِنْتِ عَبْدِ الرَّحْمَنِ أَنَّهَا أَخْبَرَتْهُ أَنَّ ابْنَ زِيَادٍ كَتَبَ إِلَى عَائِشَةَ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ قَالَ مَنْ أَهْدَى هَدْيًا حَرُمَ عَلَيْهِ مَا يَحْرُمُ عَلَى الْحَاجِّ حَتَّى يُنْحَرَ الْهَدْىُ وَقَدْ بَعَثْتُ بِهَدْيِي فَاكْتُبِي إِلَىَّ بِأَمْرِكِ ‏.‏ قَالَتْ عَمْرَةُ قَالَتْ عَائِشَةُ لَيْسَ كَمَا قَالَ ابْنُ عَبَّاسٍ أَنَا فَتَلْتُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ ثُمَّ قَلَّدَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ ثُمَّ بَعَثَ بِهَا مَعَ أَبِي فَلَمْ يَحْرُمْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم شَىْءٌ أَحَلَّهُ اللَّهُ لَهُ حَتَّى نُحِرَ الْهَدْىُ ‏.‏\hadithno{3205}\hadithtrans{Amra daughter of Abd al-Rahman reported that Ibn Ziyad had written to 'A'isha (Allah be pleased with him) that 'Abdullah b. Abbas (Allah be pleased with them) bad said that he who sent a sacrificial animal (to Mecca) for him was forbidden what is forbidden for a pilgrim (in the state of Ihram) until the animal is sacrificed I have myself sent my sacrificial animal (to Mecca), so write to me your opinion. Amra reported 'A'isha (Allah be pleased with her) as saying:It is not as Ibn 'Abbas (Allah be pleased with them) had asserted, for I wove the garlands for the sacrificial animals of Allah's Messenger (ﷺ) with my own hands. Allah's Messenger (ﷺ) then garlanded them with his own hands, and then sent them with my father, and nothing was forbidden for Allah's Messenger (ﷺ) which had been made lawful for him by Allah until the animals were sacrificed}}
\hadithdefcmd{muslim}{3206}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، قَالَ سَمِعْتُ عَائِشَةَ، وَهْىَ مِنْ وَرَاءِ الْحِجَابِ تُصَفِّقُ وَتَقُولُ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ ثُمَّ يَبْعَثُ بِهَا وَمَا يُمْسِكُ عَنْ شَىْءٍ مِمَّا يُمْسِكُ عَنْهُ الْمُحْرِمُ حَتَّى يُنْحَرَ هَدْيُهُ\hadithno{3206}\hadithtrans{Masruq reported:I heard 'A'isha (Allah be pleased with her) clapping her hands behind the curtain and saying: I used to weave garlands for the sacrificial animals of Allah's Messenger (ﷺ) with my own hands, and then he (the Holy Prophet) sent them (to Mecca), and he did not avoid doing anything which a Muhritn avoids until his animal was sacrificed}}
\hadithdefcmd{muslim}{3207}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا دَاوُدُ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، كِلاَهُمَا عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، بِمِثْلِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3207}\hadithtrans{A hadith like this has been narrated on the authority of 'A'isha (Allah be pleased with her) through another chain of transmitters}}
\hadithdefcmd{muslim}{3208}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّهَا بَدَنَةٌ ‏.‏ فَقَالَ ‏"‏ ارْكَبْهَا وَيْلَكَ ‏"‏ ‏.‏ فِي الثَّانِيَةِ أَوْ فِي الثَّالِثَةِ ‏.‏\hadithno{3208}\hadithtrans{Abu Huraira (Allah be pleased with him) rerorted that Allah's Messenger (ﷺ) saw a person who was driving a sacrificial camel (and told him to ride on it. Thereupon he said:Messenger of Allah, it is a sacrificial camel. He told him again to ride on it; (when he received the same reply) he said: Woe to you, (he uttered these words on the second or the third reply)}}
\hadithdefcmd{muslim}{3209}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، بِهَذَا الإِسْنَادِ وَقَالَ بَيْنَمَا رَجُلٌ يَسُوقُ بَدَنَةً مُقَلَّدَةً ‏.‏\hadithno{3209}\hadithtrans{This hadith has been narrated by A'raj with the same chain of transmitters (and the words are):" Whereas the person was driving a sacrificial camel which was garlanded}}
\hadithdefcmd{muslim}{3210}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ بَيْنَمَا رَجُلٌ يَسُوقُ بَدَنَةً مُقَلَّدَةً قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَيْلَكَ ارْكَبْهَا ‏"‏ ‏.‏ فَقَالَ بَدَنَةٌ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَيْلَكَ ارْكَبْهَا وَيْلَكَ ارْكَبْهَا ‏"‏ ‏.‏\hadithno{3210}\hadithtrans{Hammam b. Munabbih reported:It is one out of these (narrations) that Abu Huraira (Allah be pleased with him) narrated to us from Muhammad the Messenger of Allah (ﷺ), and he narrated to us traditions out of which is that he said: When there was a person who was driving a garlanded sacrificial camel, Allah's Messenger (ﷺ) said to him: Woe to you; ride on it. He said: Messenger of Allah, it is a sacrificial animal, whereupon Allah's Messenger (ﷺ) said: Woe to you, ride on it; woe to you, ride on it}}
\hadithdefcmd{muslim}{3211}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَسُرَيْجُ بْنُ يُونُسَ، قَالاَ حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حُمَيْدٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ وَأَظُنُّنِي قَدْ سَمِعْتُهُ مِنْ، أَنَسٍ ح. وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا هُشَيْمٌ، عَنْ حُمَيْدٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَجُلٍ يَسُوقُ بَدَنَةً فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ فَقَالَ إِنَّهَا بَدَنَةٌ ‏.‏ قَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا ‏.‏\hadithno{3211}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) happened to pass by a person who was driving a sacrificial camel, whereupon he (the Holy Prophet) said:Ride on It. He said: It is a sacrificial camel. Thereupon he (the Holy Prophet) said twice or thrice: Ride on it}}
\hadithdefcmd{muslim}{3212}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ أَنَسٍ، قَالَ سَمِعْتُهُ يَقُولُ مُرَّ عَلَى النَّبِيِّ صلى الله عليه وسلم بِبَدَنَةٍ أَوْ هَدِيَّةٍ فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ إِنَّهَا بَدَنَةٌ أَوْ هَدِيَّةٌ ‏.‏ فَقَالَ ‏"‏ وَإِنْ ‏"‏ ‏.‏\hadithno{3212}\hadithtrans{Anas reported:Someone happened to pass by Allah's Apostle (ﷺ) with a sacrificial camel, or a sacrificial animal, whereupon he said: Ride on it. He said: It is a sacrificial camel, or animal, whereupon he said: (Ride) even if (it is a sacrificial camel)}}
\hadithdefcmd{muslim}{3213}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، حَدَّثَنِي بُكَيْرُ بْنُ الأَخْنَسِ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ مُرَّ عَلَى النَّبِيِّ صلى الله عليه وسلم بِبَدَنَةٍ ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{3213}\hadithtrans{Anas (Allah be pleased with him) reported:There happened to pass (a person) with a sacrificial camel by Allah's Apostle (ﷺ) and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{3214}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، سُئِلَ عَنْ رُكُوبِ الْهَدْىِ، فَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ ارْكَبْهَا بِالْمَعْرُوفِ إِذَا أُلْجِئْتَ إِلَيْهَا حَتَّى تَجِدَ ظَهْرًا ‏"‏ ‏.‏\hadithno{3214}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported that he was asked about riding on a sacrificial animal, and he said:I heard Allah's Messenger (ﷺ) as saying: Ride on it gently, when you have need for it, until you find (another) mount}}
\hadithdefcmd{muslim}{3215}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، قَالَ سَأَلْتُ جَابِرًا عَنْ رُكُوبِ الْهَدْىِ، فَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ ارْكَبْهَا بِالْمَعْرُوفِ حَتَّى تَجِدَ ظَهْرًا ‏"‏ ‏.‏\hadithno{3215}\hadithtrans{Abu Zubair reported:I asked Jabir (Allah be pleased with him) about riding on the sacrificial animal, to which he replied: I heard Allah's Apostle (ﷺ) as saying: Ride on them gently until you find another mount}}
\hadithdefcmd{muslim}{3216}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ أَبِي التَّيَّاحِ الضُّبَعِيِّ، حَدَّثَنِي مُوسَى بْنُ سَلَمَةَ الْهُذَلِيُّ، قَالَ انْطَلَقْتُ أَنَا وَسِنَانُ بْنُ سَلَمَةَ، مُعْتَمِرَيْنِ قَالَ وَانْطَلَقَ سِنَانٌ مَعَهُ بِبَدَنَةٍ يَسُوقُهَا فَأَزْحَفَتْ عَلَيْهِ بِالطَّرِيقِ فَعَيِيَ بِشَأْنِهَا إِنْ هِيَ أُبْدِعَتْ كَيْفَ يَأْتِي بِهَا ‏.‏ فَقَالَ لَئِنْ قَدِمْتُ الْبَلَدَ لأَسْتَحْفِيَنَّ عَنْ ذَلِكَ ‏.‏ قَالَ فَأَضْحَيْتُ فَلَمَّا نَزَلْنَا الْبَطْحَاءَ قَالَ انْطَلِقْ إِلَى ابْنِ عَبَّاسٍ نَتَحَدَّثْ إِلَيْهِ ‏.‏ قَالَ فَذَكَرَ لَهُ شَأْنَ بَدَنَتِهِ ‏.‏ فَقَالَ عَلَى الْخَبِيرِ سَقَطْتَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِسِتَّ عَشْرَةَ بَدَنَةً مَعَ رَجُلٍ وَأَمَّرَهُ فِيهَا - قَالَ - فَمَضَى ثُمَّ رَجَعَ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ أَصْنَعُ بِمَا أُبْدِعَ عَلَىَّ مِنْهَا قَالَ ‏ "‏ انْحَرْهَا ثُمَّ اصْبُغْ نَعْلَيْهَا فِي دَمِهَا ثُمَّ اجْعَلْهُ عَلَى صَفْحَتِهَا وَلاَ تَأْكُلْ مِنْهَا أَنْتَ وَلاَ أَحَدٌ مِنْ أَهْلِ رُفْقَتِكَ ‏"‏ ‏.‏\hadithno{3216}\hadithtrans{Musa b. Salama al-Hudhali reported:I and Sinan b. Salama proceeded (to Mecca to perform Umra. Sinan had a sacrificial camel with him which he was driving. The camel stopped in the way being completely exhausted and this state of it made him (Sinan) helpless. (He thought) if it stops proceeding further how he would be able to take it, along with him and said: I would definitely find out (the religious verdict) about it. I moved on in the morning and as we encamped at al-Batha', (Sinan) said: Come (along with me) to Ibn 'Abbis (Allah be pleased with them) so that we should narrate to him (this incident), and he (Sinan) reported to him the incident of the sacrificial camel. He (Ibn Abbas) said: You have referred (the matter) to the well informed person. (Now listen) Allah's Messenger (ﷺ) sent sixteen sacrificial camels with a man whom he put in change of them. He set out and came back and said: Messenger of Allah, what should I do with those who are completely exhausted and become powerless to move on, whereupon he said: Slaughter them, and dye their hoofs in their blood, and put them on the sides of their humps, but neither you nor anyone among those who are with you must eat any part of them}}
\hadithdefcmd{muslim}{3217}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَلِيُّ بْنُ حُجْرٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَبِي التَّيَّاحِ، عَنْ مُوسَى بْنِ سَلَمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ بِثَمَانَ عَشْرَةَ بَدَنَةً مَعَ رَجُلٍ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ عَبْدِ الْوَارِثِ وَلَمْ يَذْكُرْ أَوَّلَ الْحَدِيثِ ‏.‏\hadithno{3217}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that Allah's Messenger (ﷺ) sent eighteen sacrificial camels with a person. The rest of the hadith is the same, and the first part (of the above-mentioned hadith) is not mentioned}}
\hadithdefcmd{muslim}{3218}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ سِنَانِ بْنِ سَلَمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ ذُؤَيْبًا أَبَا قَبِيصَةَ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَبْعَثُ مَعَهُ بِالْبُدْنِ ثُمَّ يَقُولُ ‏ "‏ إِنْ عَطِبَ مِنْهَا شَىْءٌ فَخَشِيتَ عَلَيْهِ مَوْتًا فَانْحَرْهَا ثُمَّ اغْمِسْ نَعْلَهَا فِي دَمِهَا ثُمَّ اضْرِبْ بِهِ صَفْحَتَهَا وَلاَ تَطْعَمْهَا أَنْتَ وَلاَ أَحَدٌ مِنْ أَهْلِ رُفْقَتِكَ ‏"‏ ‏.‏\hadithno{3218}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that Dhuwaib, father of Qabisa (Allah be pleased with him) narrated to him that Allah's Messenger (ﷺ) sent under his charge the sacrificial camels, and said:If any of these is completely exhausted and you apprehend its death, then slaughter it, then dip its hoofs in its blood and imprint it on its hump; but neither you nor any one of your comrades should eat it}}
\hadithdefcmd{muslim}{3219}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّاسُ يَنْصَرِفُونَ فِي كُلِّ وَجْهٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْفِرَنَّ أَحَدٌ حَتَّى يَكُونَ آخِرُ عَهْدِهِ بِالْبَيْتِ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ يَنْصَرِفُونَ كُلَّ وَجْهٍ ‏.‏ وَلَمْ يَقُلْ فِي ‏.‏\hadithno{3219}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that the people used to return through every path, whereupon Allah's Messenger (way peace be upon him) said:None amongst you should depart until he performs the last circumambulation round the House. Zuhair said (the words are): [ARABIC: YANSWARIFUWN KULLA WAJH] and the word [arabic: FIY] was not mentioned}}
\hadithdefcmd{muslim}{3220}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لِسَعِيدٍ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُمِرَ النَّاسُ أَنْ يَكُونَ، آخِرُ عَهْدِهِمْ بِالْبَيْتِ إِلاَّ أَنَّهُ خُفِّفَ عَنِ الْمَرْأَةِ الْحَائِضِ ‏.‏\hadithno{3220}\hadithtrans{Ibn Abbas reported:The people were commanded (by the Holy Prophet) to perform the last circumambulation round the House, but menstruating women were exempted}}
\hadithdefcmd{muslim}{3221}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي الْحَسَنُ، بْنُ مُسْلِمٍ عَنْ طَاوُسٍ، قَالَ كُنْتُ مَعَ ابْنِ عَبَّاسٍ إِذْ قَالَ زَيْدُ بْنُ ثَابِتٍ تُفْتِي أَنْ تَصْدُرَ الْحَائِضُ، قَبْلَ أَنْ يَكُونَ آخِرُ عَهْدِهَا بِالْبَيْتِ ‏.‏ فَقَالَ لَهُ ابْنُ عَبَّاسٍ إِمَّا لاَ فَسَلْ فُلاَنَةَ الأَنْصَارِيَّةَ هَلْ أَمَرَهَا بِذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ فَرَجَعَ زَيْدُ بْنُ ثَابِتٍ إِلَى ابْنِ عَبَّاسٍ يَضْحَكُ وَهُوَ يَقُولُ مَا أَرَاكَ إِلاَّ قَدْ صَدَقْتَ ‏.‏\hadithno{3221}\hadithtrans{Tawus reported:I was in the company of Ibn Abbas (Allah be pleased with them) when Zaid b. Thabit said: Do you give religious verdict that the woman who is in menses is allowed to go without performing the last circumambulation of the House? Ibn 'Abbas (Allah be pleased with them) said to him: Ask such and such woman of the Ansar, if you do not (believe my religious verdict) whether Allah's Messenger (ﷺ) had coimmanded her this. Zaid b Thabit (went to that lady and after getting this verdict attested by her) came back to Ibn Abbas (Allah be pleased with them) smilingly and said: I did not find you but telling the truth}}
\hadithdefcmd{muslim}{3230}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْكَعْبَةَ هُوَ وَأُسَامَةُ وَبِلاَلٌ وَعُثْمَانُ بْنُ طَلْحَةَ الْحَجَبِيُّ فَأَغْلَقَهَا عَلَيْهِ ثُمَّ مَكَثَ فِيهَا ‏.‏ قَالَ ابْنُ عُمَرَ فَسَأَلْتُ بِلاَلاً حِينَ خَرَجَ مَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ جَعَلَ عَمُودَيْنِ عَنْ يَسَارِهِ وَعَمُودًا عَنْ يَمِينِهِ وَثَلاَثَةَ أَعْمِدَةٍ وَرَاءَهُ - وَكَانَ الْبَيْتُ يَوْمَئِذٍ عَلَى سِتَّةِ أَعْمِدَةٍ - ثُمَّ صَلَّى ‏.‏\hadithno{3230}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that Allah's Messenger (may peace, be upon him) entered the Ka'ba. Usama, Bilal and 'Uthman b. Talha, the keeper (of the Ka'ba), were along with him. He closed the door and stayed in it for some time. Ibn 'Umar (Allah be pleased with them) said:I asked Bilal as he came out what Allah's Messenger (ﷺ) had done there. He said: He prayed there in (such a position) that two pillars were on his left side, one pillar on his right, and three pillars were behind him, and the House at that time was resting on six pillars}}
\hadithdefcmd{muslim}{3231}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ كُلُّهُمْ عَنْ حَمَّادِ بْنِ زَيْدٍ، - قَالَ أَبُو كَامِلٍ - حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ فَنَزَلَ بِفِنَاءِ الْكَعْبَةِ وَأَرْسَلَ إِلَى عُثْمَانَ بْنِ طَلْحَةَ فَجَاءَ بِالْمِفْتَحِ فَفَتَحَ الْبَابَ - قَالَ - ثُمَّ دَخَلَ النَّبِيُّ صلى الله عليه وسلم وَبِلاَلٌ وَأُسَامَةُ بْنُ زَيْدٍ وَعُثْمَانُ بْنُ طَلْحَةَ وَأَمَرَ بِالْبَابِ فَأُغْلِقَ فَلَبِثُوا فِيهِ مَلِيًّا ثُمَّ فَتَحَ الْبَابَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ فَبَادَرْتُ النَّاسَ فَتَلَقَّيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم خَارِجًا وَبِلاَلٌ عَلَى إِثْرِهِ فَقُلْتُ لِبِلاَلٍ هَلْ صَلَّى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏ قُلْتُ أَيْنَ قَالَ بَيْنَ الْعَمُودَيْنِ تِلْقَاءَ وَجْهِهِ ‏.‏ قَالَ وَنَسِيتُ أَنْ أَسْأَلَهُ كَمْ صَلَّى\hadithno{3231}\hadithtrans{Ibn Umar (Allah be pleased with them) reported:Allah's Messenger (ﷺ) came on the Day of Victory, and got down in the courtyard of the Ka'ba and he sent (a message) for 'Uthman b. Talha (Allah be pleased with them). He came with the key and opened the door. Allah's Apostle (ﷺ) then entered therein and Bilal, Usama b. Zaid, and 'Uthman b. Talha (along with him), and then commanded the door to be closed. They stayed there for a considerable time, and then the door was opened, and Abdullah said: I was the first to meet Allah's Messenger. (ﷺ). outside (the Ka'ba), and Bilal was close behind him. I said to Bilal: Did Allah's Messenger (ﷺ) observe prayer therein? He said: Yes. I said: Where? He said: Between the two pillars in front of his face. He said: I forgot to ask him as to the number of rakahs he prayed}}
\hadithdefcmd{muslim}{3232}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ نَافِعٍ، عَنِ ابْنِ، عُمَرَ قَالَ أَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ عَلَى نَاقَةٍ لأُسَامَةَ بْنِ زَيْدٍ حَتَّى أَنَاخَ بِفِنَاءِ الْكَعْبَةِ ثُمَّ دَعَا عُثْمَانَ بْنَ طَلْحَةَ فَقَالَ ‏ "‏ ائْتِنِي بِالْمِفْتَاحِ ‏"‏ ‏.‏ فَذَهَبَ إِلَى أُمِّهِ فَأَبَتْ أَنْ تُعْطِيَهُ فَقَالَ وَاللَّهِ لَتُعْطِينِيهِ أَوْ لَيَخْرُجَنَّ هَذَا السَّيْفُ مِنْ صُلْبِي - قَالَ - فَأَعْطَتْهُ إِيَّاهُ ‏.‏ فَجَاءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَدَفَعَهُ إِلَيْهِ فَفَتَحَ الْبَابَ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ حَمَّادِ بْنِ زَيْدٍ ‏.‏\hadithno{3232}\hadithtrans{lbn Umar (Allah be pleased with them) reported:Allah's Messenger (ﷺ) came daring the year of Victory on the she-camel of Usama b. Zaid until he made her kneel down in the courtyard of the Ka'ba (and got down). He then sent for 'Uthman b. Talha and said: Bring me the key. He went to his mother and she refused to give that to him. He said: By Allah, give that to him or this sword would be thrust into my side. So she gave that to him, and he came with that to Allah's Apostle (ﷺ) and gave that to him, and he opened the door. The rest of the hadith is the same as the above one}}
\hadithdefcmd{muslim}{3233}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْتَ وَمَعَهُ أُسَامَةُ وَبِلاَلٌ وَعُثْمَانُ بْنُ طَلْحَةَ فَأَجَافُوا عَلَيْهِمُ الْبَابَ طَوِيلاً ثُمَّ فُتِحَ فَكُنْتُ أَوَّلَ مَنْ دَخَلَ فَلَقِيتُ بِلاَلاً فَقُلْتُ أَيْنَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ بَيْنَ الْعَمُودَيْنِ الْمُقَدَّمَيْنِ ‏.‏ فَنَسِيتُ أَنْ أَسْأَلَهُ كَمْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم\hadithno{3233}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported:Allah's Messenger, (ﷺ) entered the House, and Usama, Bilal and Uthman b. Talha were with him, and they kept the door closed for a considerable time. Then it was opened and I was the first to enter the House and meet Bilal, and I said: Where did Allah's Messenger (ﷺ) observe prayer? He said: Between these two front pillars. I, however, forgot to ask him the number of rak'ahs that he observed}}
\hadithdefcmd{muslim}{3234}{وَحَدَّثَنِي حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا عَبْدُ اللَّهِ، بْنُ عَوْنٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ انْتَهَى إِلَى الْكَعْبَةِ وَقَدْ دَخَلَهَا النَّبِيُّ صلى الله عليه وسلم وَبِلاَلٌ وَأُسَامَةُ وَأَجَافَ عَلَيْهِمْ عُثْمَانُ بْنُ طَلْحَةَ الْبَابَ قَالَ فَمَكَثُوا فِيهِ مَلِيًّا ثُمَّ فُتِحَ الْبَابُ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم وَرَقِيتُ الدَّرَجَةَ فَدَخَلْتُ الْبَيْتَ فَقُلْتُ أَيْنَ صَلَّى النَّبِيُّ صلى الله عليه وسلم قَالُوا هَا هُنَا ‏.‏ قَالَ وَنَسِيتُ أَنْ أَسْأَلَهُمْ كَمْ صَلَّى\hadithno{3234}\hadithtrans{Abdullah b. Umar reported that he reached the Ka'ba and Allah's Apostle (ﷺ) had entered therein, and Bilal and Usama too. 'Uthman b. Talha closed the door to them, and they stayed there for a considerable time, and then the door was opend and Allah's Apostle (ﷺ) came out, and I went upstairs and entered the House and said:Where did Allah's Apostle (ﷺ) observe prayer? They said: At this very place. I, however, forgot to ask them about the (number of) rak'ahs that he observed}}
\hadithdefcmd{muslim}{3235}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ، شِهَابٍ عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْتَ هُوَ وَأُسَامَةُ بْنُ زَيْدٍ وَبِلاَلٌ وَعُثْمَانُ بْنُ طَلْحَةَ فَأَغْلَقُوا عَلَيْهِمْ فَلَمَّا فَتَحُوا كُنْتُ فِي أَوَّلِ مَنْ وَلَجَ فَلَقِيتُ بِلاَلاً فَسَأَلْتُهُ هَلْ صَلَّى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ صَلَّى بَيْنَ الْعَمُودَيْنِ الْيَمَانِيَيْنِ.‏\hadithno{3235}\hadithtrans{Salim narrated on the authority of his father (Allah be pleased with him) that Allah's Messenger (ﷺ) entered the House along with Usama b. Zaid, Bilal and Uthman b. Talha. They closed the door from within, and, as they opened it, I was the first to get into it and meet Bilal, and I asked him:Did Allah's Messenger (ﷺ) observe prayer in it? He said: Yes, he observed prayer between these two Yemenite pillars (pillars situated towards the side of Yemen)}}
\hadithdefcmd{muslim}{3236}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْكَعْبَةَ هُوَ وَأُسَامَةُ بْنُ زَيْدٍ وَبِلاَلٌ وَعُثْمَانُ بْنُ طَلْحَةَ وَلَمْ يَدْخُلْهَا مَعَهُمْ أَحَدٌ ثُمَّ أُغْلِقَتْ عَلَيْهِمْ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَأَخْبَرَنِي بِلاَلٌ أَوْ عُثْمَانُ بْنُ طَلْحَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي جَوْفِ الْكَعْبَةِ بَيْنَ الْعَمُودَيْنِ الْيَمَانِيَيْنِ.‏\hadithno{3236}\hadithtrans{Salim b. Abdullah reported his father (Allah be pleased with him) saying:I saw Allah's Messenger (ﷺ) entering the Ka'ba, and Usama b. Zaid, Bilal and 'Uthman b. Talha were along with him, but none (else) entered therein along with them. Then the door was closed for them from within. 'Abdullah b. Umar (Allah be pleased with them) said: Bilal and Uthman b. Talha informed me that Allah's Messenger (ﷺ) observed prayer in the interior of the Ka'ba between the two Yemenite pillars}}
\hadithdefcmd{muslim}{3237}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنِ ابْنِ بَكْرٍ، قَالَ عَبْدٌ أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ قُلْتُ لِعَطَاءٍ أَسَمِعْتَ ابْنَ عَبَّاسٍ يَقُولُ إِنَّمَا أُمِرْتُمْ بِالطَّوَافِ وَلَمْ تُؤْمَرُوا بِدُخُولِهِ ‏.‏ قَالَ لَمْ يَكُنْ يَنْهَى عَنْ دُخُولِهِ وَلَكِنِّي سَمِعْتُهُ يَقُولُ أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا دَخَلَ الْبَيْتَ دَعَا فِي نَوَاحِيهِ كُلِّهَا وَلَمْ يُصَلِّ فِيهِ حَتَّى خَرَجَ فَلَمَّا خَرَجَ رَكَعَ فِي قُبُلِ الْبَيْتِ رَكْعَتَيْنِ ‏.‏ وَقَالَ ‏ "‏ هَذِهِ الْقِبْلَةُ ‏"‏ ‏.‏ قُلْتُ لَهُ مَا نَوَاحِيهَا أَفِي زَوَايَاهَا قَالَ بَلْ فِي كُلِّ قِبْلَةٍ مِنَ الْبَيْتِ ‏.‏\hadithno{3237}\hadithtrans{Ibn Juraij reported:I said to 'Ata': Have you heard Ibn 'Abbas saying: You have been commanded to observe circumambulation, and not commanded to enter it (the Ka'ba)? He ('Ata') said: He (Ibn Abbas) (at the same time) did not forbid entrance into it. I, however, heard him saying: Usama b. Zaid informed me that when Allah's Apostle (ﷺ) entered the House, he supplicated in all sides of it; and he did not observe prayer therein till he came out, and as he came out he observed two rak'ahs in front of the House, and said: This is your Qibla. I said to him: What is meant by its sides? Does that mean its corners? He said: (In all sides and nooks of the House) there is Qibla}}
\hadithdefcmd{muslim}{3238}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا عَطَاءٌ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ الْكَعْبَةَ وَفِيهَا سِتُّ سَوَارٍ فَقَامَ عِنْدَ سَارِيَةٍ فَدَعَا وَلَمْ يُصَلِّ ‏.‏\hadithno{3238}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that Allah's Apostle (ﷺ) entered the Ka'ba, and in it there were six pillars, and he stood near a pillar and made supplication, but did not observe the prayer}}
\hadithdefcmd{muslim}{3239}{وَحَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنِي هُشَيْمٌ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَدَخَلَ النَّبِيُّ صلى الله عليه وسلم الْبَيْتَ فِي عُمْرَتِهِ قَالَ لاَ ‏.‏\hadithno{3239}\hadithtrans{Isma'il b. Abu Khalid reported:I asked Abdullah b. Abu Aufa (Allah be pleased with him), a Companion of Allah's Messenger (ﷺ), whether Allah's Apostle (ﷺ) had entered the House, while performing 'Umra, He said: NO}}
\hadithdefcmd{muslim}{3240}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ حَدَاثَةُ عَهْدِ قَوْمِكِ بِالْكُفْرِ لَنَقَضْتُ الْكَعْبَةَ وَلَجَعَلْتُهَا عَلَى أَسَاسِ إِبْرَاهِيمَ فَإِنَّ قُرَيْشًا حِينَ بَنَتِ الْبَيْتَ اسْتَقْصَرَتْ وَلَجَعَلْتُ لَهَا خَلْفًا ‏"‏ ‏.‏\hadithno{3240}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger may peace be upon him) said to me: Had your people not been unbelievers in the recent past (had they not quite recently accepted Islam), I would have demolished the Ka'ba and would have rebuilt it on the foundation (laid) by Ibrahim; for when the Quraish had built the Ka'ba, they reduced its (area), and I would also have built (a door) in the rear}}
\hadithdefcmd{muslim}{3241}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{3241}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{3242}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ، اللَّهِ أَنَّ عَبْدَ اللَّهِ بْنَ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، أَخْبَرَ عَبْدَ اللَّهِ بْنَ عُمَرَ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلَمْ تَرَىْ أَنَّ قَوْمَكِ حِينَ بَنَوُا الْكَعْبَةَ اقْتَصَرُوا عَنْ قَوَاعِدِ إِبْرَاهِيمَ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ تَرُدُّهَا عَلَى قَوَاعِدِ إِبْرَاهِيمَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْلاَ حِدْثَانُ قَوْمِكِ بِالْكُفْرِ لَفَعَلْتُ ‏"‏ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لَئِنْ كَانَتْ عَائِشَةُ سَمِعَتْ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أُرَى رَسُولَ اللَّهِ صلى الله عليه وسلم تَرَكَ اسْتِلاَمَ الرُّكْنَيْنِ اللَّذَيْنِ يَلِيَانِ الْحِجْرَ إِلاَّ أَنَّ الْبَيْتَ لَمْ يُتَمَّمْ عَلَى قَوَاعِدِ إِبْرَاهِيمَ ‏.‏\hadithno{3242}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), reported Allah's Messenger (ﷺ) as having said this:Didn't you see that when your people built the Ka'ba, they reduced (its area with the result that it no longer remains) on the foundations (laid) by Ibrahim. I said: Messenger of Allah, why don't you rebuild it on the foundations (laid by) Ibrahim? Thereupon Allah's Messenger (ﷺ) said: Had your people not been new converts to Islam, I would have done that. 'Abdullah b. 'Umar (Allah be pleased with them) said: If 'A'isha (Allah be pleased with her) had heard it from Allah's Messenger (may peace be up (vn him), I would not have seen Allah's Messenger (ﷺ) abandoning the touching of the two corners situated near al-Hijr, but (for the fact) that it was not completed on the foundations (laid) by Ibrihim}}
\hadithdefcmd{muslim}{3243}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مَخْرَمَةَ، ح وَحَدَّثَنِي هَارُونُ، بْنُ سَعِيدٍ الأَيْلِيُّ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ نَافِعًا، مَوْلَى ابْنِ عُمَرَ يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي بَكْرِ بْنِ أَبِي قُحَافَةَ، يُحَدِّثُ عَبْدَ اللَّهِ بْنَ عُمَرَ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَوْلاَ أَنَّ قَوْمَكِ حَدِيثُو عَهْدٍ بِجَاهِلِيَّةٍ - أَوْ قَالَ بِكُفْرٍ - لأَنْفَقْتُ كَنْزَ الْكَعْبَةِ فِي سَبِيلِ اللَّهِ وَلَجَعَلْتُ بَابَهَا بِالأَرْضِ وَلأَدْخَلْتُ فِيهَا مِنَ الْحِجْرِ ‏"‏ ‏.‏\hadithno{3243}\hadithtrans{A'isha (Allah be pleased with her), wife of Allah's Apostle (ﷺ), heard Allah's Messenger (ﷺ) as saying:If your people, had not been recent converts to Islam, I would have spent the treasure of the Ka'ba in the way of Allah and would have constructed its door just on the level of the ground and would have encompassed in it the space of Hijr}}
\hadithdefcmd{muslim}{3244}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنِي ابْنُ مَهْدِيٍّ، حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، عَنْ سَعِيدٍ، - يَعْنِي ابْنَ مِينَاءَ - قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، يَقُولُ حَدَّثَتْنِي خَالَتِي، - يَعْنِي عَائِشَةَ - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَائِشَةُ لَوْلاَ أَنَّ قَوْمَكِ حَدِيثُو عَهْدٍ بِشِرْكٍ لَهَدَمْتُ الْكَعْبَةَ فَأَلْزَقْتُهَا بِالأَرْضِ وَجَعَلْتُ لَهَا بَابَيْنِ بَابًا شَرْقِيًّا وَبَابًا غَرْبِيًّا وَزِدْتُ فِيهَا سِتَّةَ أَذْرُعٍ مِنَ الْحِجْرِ فَإِنَّ قُرَيْشًا اقْتَصَرَتْهَا حَيْثُ بَنَتِ الْكَعْبَةَ ‏"‏ ‏.‏\hadithno{3244}\hadithtrans{Abdullah b. Zubair (Allah be pleased with him) reported on the authority of his mother's sister ('A'isha) saying that Allah's Messenger (ﷺ) said:'A'isha, if your people had not been recently polytheists (and new converts to Islam), I would have demolished the Ka'ba, and would have brought it to the level of the ground and would have constructed two doors, one facing the east and the other one to the west, and would have added to it six cubits of area from Hijr, for the Quraish had reduced it when they rebuilt it}}
\hadithdefcmd{muslim}{3245}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، أَخْبَرَنِي ابْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، قَالَ لَمَّا احْتَرَقَ الْبَيْتُ زَمَنَ يَزِيدَ بْنِ مُعَاوِيَةَ حِينَ غَزَاهَا أَهْلُ الشَّامِ فَكَانَ مِنْ أَمْرِهِ مَا كَانَ تَرَكَهُ ابْنُ الزُّبَيْرِ حَتَّى قَدِمَ النَّاسُ الْمَوْسِمَ يُرِيدُ أَنْ يُجَرِّئَهُمْ - أَوْ يُحَرِّبَهُمْ - عَلَى أَهْلِ الشَّامِ فَلَمَّا صَدَرَ النَّاسُ قَالَ يَا أَيُّهَا النَّاسُ أَشِيرُوا عَلَىَّ فِي الْكَعْبَةِ أَنْقُضُهَا ثُمَّ أَبْنِي بِنَاءَهَا أَوْ أُصْلِحُ مَا وَهَى مِنْهَا قَالَ ابْنُ عَبَّاسٍ فَإِنِّي قَدْ فُرِقَ لِي رَأْىٌ فِيهَا أَرَى أَنْ تُصْلِحَ مَا وَهَى مِنْهَا وَتَدَعَ بَيْتًا أَسْلَمَ النَّاسُ عَلَيْهِ وَأَحْجَارًا أَسْلَمَ النَّاسُ عَلَيْهَا وَبُعِثَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم ‏.‏ فَقَالَ ابْنُ الزُّبَيْرِ لَوْ كَانَ أَحَدُكُمُ احْتَرَقَ بَيْتُهُ مَا رَضِيَ حَتَّى يُجِدَّهُ فَكَيْفَ بَيْتُ رَبِّكُمْ إِنِّي مُسْتَخِيرٌ رَبِّي ثَلاَثًا ثُمَّ عَازِمٌ عَلَى أَمْرِي فَلَمَّا مَضَى الثَّلاَثُ أَجْمَعَ رَأْيَهُ عَلَى أَنْ يَنْقُضَهَا فَتَحَامَاهُ النَّاسُ أَنْ يَنْزِلَ بِأَوَّلِ النَّاسِ يَصْعَدُ فِيهِ أَمْرٌ مِنَ السَّمَاءِ حَتَّى صَعِدَهُ رَجُلٌ فَأَلْقَى مِنْهُ حِجَارَةً فَلَمَّا لَمْ يَرَهُ النَّاسُ أَصَابَهُ شَىْءٌ تَتَابَعُوا فَنَقَضُوهُ حَتَّى بَلَغُوا بِهِ الأَرْضَ فَجَعَلَ ابْنُ الزُّبَيْرِ أَعْمِدَةً فَسَتَّرَ عَلَيْهَا السُّتُورَ حَتَّى ارْتَفَعَ بِنَاؤُهُ ‏.‏ وَقَالَ ابْنُ الزُّبَيْرِ إِنِّي سَمِعْتُ عَائِشَةَ تَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنَّ النَّاسَ حَدِيثٌ عَهْدُهُمْ بِكُفْرٍ وَلَيْسَ عِنْدِي مِنَ النَّفَقَةِ مَا يُقَوِّي عَلَى بِنَائِهِ لَكُنْتُ أَدْخَلْتُ فِيهِ مِنَ الْحِجْرِ خَمْسَ أَذْرُعٍ وَلَجَعَلْتُ لَهَا بَابًا يَدْخُلُ النَّاسُ مِنْهُ وَبَابًا يَخْرُجُونَ مِنْهُ ‏"‏ ‏.‏ قَالَ فَأَنَا الْيَوْمَ أَجِدُ مَا أُنْفِقُ وَلَسْتُ أَخَافُ النَّاسَ - قَالَ - فَزَادَ فِيهِ خَمْسَ أَذْرُعٍ مِنَ الْحِجْرِ حَتَّى أَبْدَى أُسًّا نَظَرَ النَّاسُ إِلَيْهِ فَبَنَى عَلَيْهِ الْبِنَاءَ وَكَانَ طُولُ الْكَعْبَةِ ثَمَانِيَ عَشْرَةَ ذِرَاعًا فَلَمَّا زَادَ فِيهِ اسْتَقْصَرَهُ فَزَادَ فِي طُولِهِ عَشَرَ أَذْرُعٍ وَجَعَلَ لَهُ بَابَيْنِ أَحَدُهُمَا يُدْخَلُ مِنْهُ وَالآخَرُ يُخْرَجُ مِنْهُ ‏.‏ فَلَمَّا قُتِلَ ابْنُ الزُّبَيْرِ كَتَبَ الْحَجَّاجُ إِلَى عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ يُخْبِرُهُ بِذَلِكَ وَيُخْبِرُهُ أَنَّ ابْنَ الزُّبَيْرِ قَدْ وَضَعَ الْبِنَاءَ عَلَى أُسٍّ نَظَرَ إِلَيْهِ الْعُدُولُ مِنْ أَهْلِ مَكَّةَ ‏.‏ فَكَتَبَ إِلَيْهِ عَبْدُ الْمَلِكِ إِنَّا لَسْنَا مِنْ تَلْطِيخِ ابْنِ الزُّبَيْرِ فِي شَىْءٍ أَمَّا مَا زَادَ فِي طُولِهِ فَأَقِرَّهُ وَأَمَّا مَا زَادَ فِيهِ مِنَ الْحِجْرِ فَرُدَّهُ إِلَى بِنَائِهِ وَسُدَّ الْبَابَ الَّذِي فَتَحَهُ ‏.‏ فَنَقَضَهُ وَأَعَادَهُ إِلَى بِنَائِهِ ‏.‏\hadithno{3245}\hadithtrans{Ata' reported:The House was burnt during the time of Yazid b. Muawiya when the people of Syria had fought (in Mecca). And it happened with it (the Ka'ba) what was (in store for it). Ibn Zubair (Allah be pleased with him) felt it (in the same state) until the people came in the season (of Hajj). (The idea behind was) that he wanted to exhort them or incite them (to war) against the people of Syria. When the people had arrived he said to them: O people, advise me about the Ka'ba. Should I demolish it and then build it from its very foundation, or should I repair whatever has been damaged of it? Ibn 'Abbas said: An idea has occurred to me according to which I think that you should only repair (the portion which has been) damaged, and leave the House (in that very state in which) people embraced Islam (and leave those very stones in the same state) when people embraced Islam, and over which Allah's Apostle (ﷺ) had raised it. Thereupon Ibn Zubair said: It the house of any one of you is burnt, he would not be contented until he had reconstructed it, then what about the House of your Lord (which is far more Important than your house)? I would seek good advice from my Lord thrice and then I would make up (my mind) about this affair. After seeking good advice thrice, he made up his mind to demolish it. The people apprehended that calamity might fall from heaven on those persons who would be first to climb (over the building for the purpose of demolishing it), till one (took up courage, and ascended the roof), and threw down one of its stones. When the people saw no calamity befalling him, they followed him, demolished it until it was razed to the ground. Then Ibn Zubair erected pillars and hung cartains on them (in order to provide facilities to the people for observing the time of its construction). And the walls were raised; and Ibn Zubair said: I heard 'A'isha (Allah be pleased with her) say that Allah's Apostle (ﷺ) had observed: If the people had Rot recently (abandoned) unbelief, find I had means enough to reconstruct it, which I had not, I would have definitely excompassed in it five cubits of area from Hijr. And I would also have constructed a door for the people to enter, and a door for their exit. I today have (the means to spend) and I entertain no fearfrom the side of people (that they would protest against this change). So he added five cubits of area from the side of Hatim to it that there appeared (the old) foundation (upon which Hadrat Ibrahim had built the Ka'ba). and the people saw that and it was upon this foundation that the wall was raised. The length of the Ka'ba was eighteen cubits. when addition was made to it (which was in its breadth), then naturally the length appears to be) small (as compared with its breadth). Then addition of ten cubits (of area) was made in its length (also). Two doors were also constructed, one of which (was meant) for entrance and the other one for exit. When Ibn Zubair (Allah be pleased with him) was killed, Hajjaj wrote to 'Abd al-Malik (b. Marwan) informing him about it, and telling him that Ibn Zubair (Allah be pleased with him) had built (the Ka'ba) on those very foundations (which were laid by Ibrahim) and which reliable persons among the Meccans had seen. 'Abd al-Malik wrote to him: We are not concerned with the censuring of Ibn Zubair in anything. Keep intact the addition made by him in the side of length, and whatever he has added frem the side of Hijr revert to (its previous) foundation, and wall up the door which he had opened. Thus Hajjaj at the command of Abd al-Malik) demolished it (that portion) and rebuilt it on (its previous) foundations}}
\hadithdefcmd{muslim}{3246}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ عَبْدَ، اللَّهِ بْنَ عُبَيْدِ بْنِ عُمَيْرٍ وَالْوَلِيدَ بْنَ عَطَاءٍ يُحَدِّثَانِ عَنِ الْحَارِثِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي رَبِيعَةَ، قَالَ عَبْدُ اللَّهِ بْنُ عُبَيْدٍ وَفَدَ الْحَارِثُ بْنُ عَبْدِ اللَّهِ عَلَى عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ فِي خِلاَفَتِهِ فَقَالَ عَبْدُ الْمَلِكِ مَا أَظُنُّ أَبَا خُبَيْبٍ - يَعْنِي ابْنَ الزُّبَيْرِ - سَمِعَ مِنْ عَائِشَةَ مَا كَانَ يَزْعُمُ أَنَّهُ سَمِعَهُ مِنْهَا ‏.‏ قَالَ الْحَارِثُ بَلَى أَنَا سَمِعْتُهُ مِنْهَا ‏.‏ قَالَ سَمِعْتَهَا تَقُولُ مَاذَا قَالَ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ قَوْمَكِ اسْتَقْصَرُوا مِنْ بُنْيَانِ الْبَيْتِ وَلَوْلاَ حَدَاثَةُ عَهْدِهِمْ بِالشِّرْكِ أَعَدْتُ مَا تَرَكُوا مِنْهُ فَإِنْ بَدَا لِقَوْمِكِ مِنْ بَعْدِي أَنْ يَبْنُوهُ فَهَلُمِّي لأُرِيَكِ مَا تَرَكُوا مِنْهُ ‏"‏ ‏.‏ فَأَرَاهَا قَرِيبًا مِنْ سَبْعَةِ أَذْرُعٍ ‏.‏ هَذَا حَدِيثُ عَبْدِ اللَّهِ بْنِ عُبَيْدٍ وَزَادَ عَلَيْهِ الْوَلِيدُ بْنُ عَطَاءٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَلَجَعَلْتُ لَهَا بَابَيْنِ مَوْضُوعَيْنِ فِي الأَرْضِ شَرْقِيًّا وَغَرْبِيًّا وَهَلْ تَدْرِينَ لِمَ كَانَ قَوْمُكِ رَفَعُوا بَابَهَا ‏"‏ ‏.‏ قَالَتْ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ تَعَزُّزًا أَنْ لاَ يَدْخُلَهَا إِلاَّ مَنْ أَرَادُوا فَكَانَ الرَّجُلُ إِذَا هُوَ أَرَادَ أَنْ يَدْخُلَهَا يَدْعُونَهُ يَرْتَقِي حَتَّى إِذَا كَادَ أَنْ يَدْخُلَ دَفَعُوهُ فَسَقَطَ ‏"‏ ‏.‏ قَالَ عَبْدُ الْمَلِكِ لِلْحَارِثِ أَنْتَ سَمِعْتَهَا تَقُولُ هَذَا قَالَ نَعَمْ‏.‏ قَالَ فَنَكَتَ سَاعَةً بِعَصَاهُ ثُمَّ قَالَ وَدِدْتُ أَنِّي تَرَكْتُهُ وَمَا تَحَمَّلَ\hadithno{3246}\hadithtrans{Abdullah b. 'Ubaid reported that Harith b. 'Abdullah led a deputation to 'Abd al-Malik b. Marwan during his caliphate. 'Abd al-Malik said:I do riot think that Abu Khubaib (i. e. Ibn Zabair) had heard from 'A'isha (Allah be pleased with her) (about the intended wish of the Prophet [may peace be upon him) In regard to the alteration of the Ka'ba). Harith said: Yes, I myself did hear from her. He ('Abd al-Malik) said: Well, tell me what you heard from her. He stated that she (Hadrat 'A'isha) had said that Allah's Messenger (ﷺ) remarked: Verily your people have reduced (the area) of the House from its (original foundations, and if they had not recently abandoned polytheism (and embraced Islam) I would have reversed it to (those foundations) which they had left out of it. nd if your people would take initiative after me in rebuilding it, then come along with me so that I should show you what they have left out of it. He showed her about fifteen cubits of area from the side of Hatim (that they had separated). This is the narration transmitted by 'Abdullah b. Ubaid. Walid b. 'Ata' has, however, made this addition to it:" Allah's Apostle (ﷺ) said: I would have made two doors on the level of the ground (facing) the east and the west. Do you know why your people raised the level of its door (i. e. the door of the Ka'ba)? She said: No. He said: (They did it) out of vanity so that (they might be in a position) to grant admittance to him only whom they wished. When a person intended to get into it, they let him climb (the stairs), and as he was about to enter, they pushed him and he fell down." 'Abd al-Malik said to Harith; Did you yourself hear her saying this? He said: Yes. He (Harith) said that he ('Abd al-Malik) scratched the ground with his staff for some time and then said: I wish I had left his (Ibn Zubair's) work there}}
\hadithdefcmd{muslim}{3247}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ، حَدَّثَنَا أَبُو عَاصِمٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، كِلاَهُمَا عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ ابْنِ بَكْرٍ ‏.‏\hadithno{3247}\hadithtrans{This hadith has been narrated on the authority of Juraij with the same chain of transmitters}}
\hadithdefcmd{muslim}{3248}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ السَّهْمِيُّ، حَدَّثَنَا حَاتِمُ بْنُ أَبِي، صَغِيرَةَ عَنْ أَبِي قَزَعَةَ، أَنَّ عَبْدَ الْمَلِكِ بْنَ مَرْوَانَ، بَيْنَمَا هُوَ يَطُوفُ بِالْبَيْتِ إِذْ قَالَ قَاتَلَ اللَّهُ ابْنَ الزُّبَيْرِ حَيْثُ يَكْذِبُ عَلَى أُمِّ الْمُؤْمِنِينَ يَقُولُ سَمِعْتُهَا تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَائِشَةُ لَوْلاَ حِدْثَانُ قَوْمِكِ بِالْكُفْرِ لَنَقَضْتُ الْبَيْتَ حَتَّى أَزِيدَ فِيهِ مِنَ الْحِجْرِ فَإِنَّ قَوْمَكِ قَصَّرُوا فِي الْبِنَاءِ ‏"‏ ‏.‏ فَقَالَ الْحَارِثُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي رَبِيعَةَ لاَ تَقُلْ هَذَا يَا أَمِيرَ الْمُؤْمِنِينَ فَأَنَا سَمِعْتُ أُمَّ الْمُؤْمِنِينَ تُحَدِّثُ هَذَا ‏.‏ قَالَ لَوْ كُنْتُ سَمِعْتُهُ قَبْلَ أَنْ أَهْدِمَهُ لَتَرَكْتُهُ عَلَى مَا بَنَى ابْنُ الزُّبَيْرِ ‏.‏\hadithno{3248}\hadithtrans{Abu Qaza'ah reported that while Abd al-Malik b. Marwan was circumambulating the Ka'ba he said:May Allah ruin Ibn Zubair that he lies in attributing to the Mother of the Faithful, as he says: I heard her stating that Allah's Messenger (may'peace be upon him) had said: 'A'isha, if your people had not been new converts to Islam, I would have demolished the House and would have added (in it area) from the Hijr for your people have reduced the area from its foundations. Harith b. 'Abdullah b. Abu Rabi'a (Allah be pleased with him) said: Commander of the Faithful, don't say that, for I heard the Mother of the Faithful saying this, whereupon he said: If I had heard this before demolishing it, I would have left it in the state in which Ibn Zabair had built it}}
\hadithdefcmd{muslim}{3249}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا أَشْعَثُ بْنُ أَبِي الشَّعْثَاءِ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْجَدْرِ أَمِنَ الْبَيْتِ هُوَ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قُلْتُ فَلِمَ لَمْ يُدْخِلُوهُ فِي الْبَيْتِ قَالَ ‏"‏ إِنَّ قَوْمَكِ قَصَّرَتْ بِهِمُ النَّفَقَةُ ‏"‏ ‏.‏ قُلْتُ فَمَا شَأْنُ بَابِهِ مُرْتَفِعًا قَالَ ‏"‏ فَعَلَ ذَلِكِ قَوْمُكِ لِيُدْخِلُوا مَنْ شَاءُوا وَيَمْنَعُوا مَنْ شَاءُوا وَلَوْلاَ أَنَّ قَوْمَكِ حَدِيثٌ عَهْدُهُمْ فِي الْجَاهِلِيَّةِ فَأَخَافَ أَنْ تُنْكِرَ قُلُوبُهُمْ لَنَظَرْتُ أَنْ أُدْخِلَ الْجَدْرَ فِي الْبَيْتِ وَأَنْ أُلْزِقَ بَابَهُ بِالأَرْضِ ‏"‏ ‏.‏\hadithno{3249}\hadithtrans{A'isha (Allah be pleased with her) reported:I asked Allah's Messenger (ﷺ) about the wall, circumpassing the House (i. e. whether the wall on the side of Hijr was included in the Ka'ba). He said, Yes. I said: Then why did they not include it in the House? He said: 'Your people ran short of the means (to do so). I said: Why is it that the level of its door is raised high? He said: Your people did it so that they should admit one whom they liked, and forbid him whom they disliked, and if your people were not new converts to faith, and I did not apprehend that their hearts would feel agitated at this. I would have definitely included (the area of) this wall-in the House and would have brought the door to the level of the ground}}
\hadithdefcmd{muslim}{3250}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ مُوسَى - حَدَّثَنَا شَيْبَانُ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْحِجْرِ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ أَبِي الأَحْوَصِ وَقَالَ فِيهِ فَقُلْتُ فَمَا شَأْنُ بَابِهِ مُرْتَفِعًا لاَ يُصْعَدُ إِلَيْهِ إِلاَّ بِسُلَّمٍ وَقَالَ ‏ "‏ مَخَافَةَ أَنْ تَنْفِرَ قُلُوبُهُمْ ‏"‏ ‏.‏\hadithno{3250}\hadithtrans{A'isha reported:I asked Allah's Messenger (ﷺ) about Hijr, and the rest of the hadith is the same. I also said: Why is it that the door has been made on a higher level, and one cannot (get into it) but with the help of a ladder? The rest of the hadith is the same as reported above and the concluding words are: (I do not change it) out of the apprehension that their hearts may disapprove of it}}
\hadithdefcmd{muslim}{3251}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ، يَسَارٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ كَانَ الْفَضْلُ بْنُ عَبَّاسٍ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَتْهُ امْرَأَةٌ مِنْ خَثْعَمَ تَسْتَفْتِيهِ فَجَعَلَ الْفَضْلُ يَنْظُرُ إِلَيْهَا وَتَنْظُرُ إِلَيْهِ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْرِفُ وَجْهَ الْفَضْلِ إِلَى الشِّقِّ الآخَرِ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ عَلَى عِبَادِهِ فِي الْحَجِّ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَطِيعُ أَنْ يَثْبُتَ عَلَى الرَّاحِلَةِ أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ وَذَلِكَ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{3251}\hadithtrans{Abdullah b. 'Abbas reported that while al-Fadl b. Abbas had been riding behind Allah's Messenger (ﷺ) a women of the tribe of Khath'am came to him (to the Holy Proppet) asking for a religious verdict. Fadl looked at her and she looked at him. Allah's Messenger (ﷺ) turned the face of al-Fadl to the other side. She said:Messenger of Allah, there is an obligation from Allah upon His servants in regard to Hajj. (But) my father is an aged man; he is incapable of riding safely. May I perform Hajj on his behalf? He said: Yes. It was during the Farewell Pilgrimage}}
\hadithdefcmd{muslim}{3252}{حَدَّثَنِي عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ، أَنَّ امْرَأَةً، مِنْ خَثْعَمَ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبِي شَيْخٌ كَبِيرٌ عَلَيْهِ فَرِيضَةُ اللَّهِ فِي الْحَجِّ وَهُوَ لاَ يَسْتَطِيعُ أَنْ يَسْتَوِيَ عَلَى ظَهْرِ بَعِيرِهِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ فَحُجِّي عَنْهُ ‏"‏ ‏.‏\hadithno{3252}\hadithtrans{Fadl reported that a woman of Banu Khath'am said:Messenger of Allah, my father is very old. There is an old obligation of Hajj upon him from Allah, but he is not capable of sitting on the back of the camel. Thereupon Allah's Apostle (ﷺ) said: Perform Hajj on his behalf}}
\hadithdefcmd{muslim}{3253}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ، عُيَيْنَةَ - قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم لَقِيَ رَكْبًا بِالرَّوْحَاءِ فَقَالَ ‏"‏ مَنِ الْقَوْمُ ‏"‏ ‏.‏ قَالُوا الْمُسْلِمُونَ ‏.‏ فَقَالُوا مَنْ أَنْتَ قَالَ ‏"‏ رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَرَفَعَتْ إِلَيْهِ امْرَأَةٌ صَبِيًّا فَقَالَتْ أَلِهَذَا حَجٌّ قَالَ ‏"‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{3253}\hadithtrans{Ibn Abbas reported that Allah's Apostle (ﷺ) met some riders at al-Rauha and asked who they were. They replied that they were Muslims. They said:Who art thou? He said: (I am) Messengef of Allah. A woman (then) lifted up a boy to him and said: Would this child be credited with having performed the Hajj? Thereupon he said: Yes, and you will have a reward}}
\hadithdefcmd{muslim}{3254}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ، عُقْبَةَ عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَفَعَتِ امْرَأَةٌ صَبِيًّا لَهَا فَقَالَتْ يَا رَسُولَ اللَّهِ أَلِهَذَا حَجٌّ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{3254}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:A woman lifted up her child and said: Messenger of Allah, would the child be credited with having performed the Hajj? Thereupon he said: Yes, and there would be a reward for you}}
\hadithdefcmd{muslim}{3255}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، أَنَّ امْرَأَةً، رَفَعَتْ صَبِيًّا فَقَالَتْ يَا رَسُولَ اللَّهِ أَلِهَذَا حَجٌّ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{3255}\hadithtrans{Karaib reported:A woman lifted a child and said: Messenger of Allah, would he be credited with Hajj? He said: Yes. and for you there would be a reward}}
\hadithdefcmd{muslim}{3256}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، بِمِثْلِهِ ‏.‏\hadithno{3256}\hadithtrans{A hadith like this has been narrated on the authority of Ibn 'Abbas through another chain of transmitters}}
\hadithdefcmd{muslim}{3257}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا الرَّبِيعُ بْنُ مُسْلِمٍ الْقُرَشِيُّ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَيُّهَا النَّاسُ قَدْ فَرَضَ اللَّهُ عَلَيْكُمُ الْحَجَّ فَحُجُّوا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَكُلَّ عَامٍ يَا رَسُولَ اللَّهِ فَسَكَتَ حَتَّى قَالَهَا ثَلاَثًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ قُلْتُ نَعَمْ لَوَجَبَتْ وَلَمَا اسْتَطَعْتُمْ - ثُمَّ قَالَ - ذَرُونِي مَا تَرَكْتُكُمْ فَإِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ بِكَثْرَةِ سُؤَالِهِمْ وَاخْتِلاَفِهِمْ عَلَى أَنْبِيَائِهِمْ فَإِذَا أَمَرْتُكُمْ بِشَىْءٍ فَأْتُوا مِنْهُ مَا اسْتَطَعْتُمْ وَإِذَا نَهَيْتُكُمْ عَنْ شَىْءٍ فَدَعُوهُ ‏"‏ ‏.‏\hadithno{3257}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:Allah's Messenger (ﷺ) addressed us and said: O people, Allah has made Hajj obligatory for you; so perform Hajj. Thereupon a person said: Messenger of Allah, (is it to be performed) every year? He (the Holy Prophet) kept quiet, and he repeated (these words) thrice, whereupon Allah's Messenger (ﷺ) said: If I were to say" Yes," it would become obligatory (for you to perform it every year) and you would not be able to do it. Then he said: Leave me with what I have left to you, for those who were before you were desroyed because of excessive questioning, and their opposition to their apostles. So when I command you to do anything, do it as much as it lies in your power and when I forbid you to do anything, then abandon it}}
\hadithdefcmd{muslim}{3258}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُسَافِرِ الْمَرْأَةُ ثَلاَثًا إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ ‏"‏ ‏.‏\hadithno{3258}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:A woman should not set out on three (days' journey) except when she has a Mahram with her}}
\hadithdefcmd{muslim}{3259}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي جَمِيعًا، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ فِي رِوَايَةِ أَبِي بَكْرٍ فَوْقَ ثَلاَثٍ ‏.‏ وَقَالَ ابْنُ نُمَيْرٍ فِي رِوَايَتِهِ عَنْ أَبِيهِ، ‏ "‏ ثَلاَثَةً إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ ‏"‏ ‏.‏\hadithno{3259}\hadithtrans{This hadith has been narrated on the same authority by Ubaidullah. And in the narration of Abu Bakr (the words are):" More than three (days)." Ibn Numair narrated on the authority of his father, (and the words are):" Three (days) except (when) she has a Mahram with her}}
\hadithdefcmd{muslim}{3260}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُسَافِرُ مَسِيرَةَ ثَلاَثِ لَيَالٍ إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ ‏"‏ ‏.‏\hadithno{3260}\hadithtrans{Abdullah b. Umar (Allah -be pleased with them) reported Allah's Apostle (ﷺ) as saying:It is not lawful for a woman who believes in Allah and the Hereafter to travel for more than three nights journey except when there is a Mahram with her}}
\hadithdefcmd{muslim}{3261}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، جَمِيعًا عَنْ مُعَاذِ بْنِ هِشَامٍ، - قَالَ أَبُو غَسَّانَ حَدَّثَنَا مُعَاذٌ، - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُسَافِرِ امْرَأَةٌ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ مَعَ ذِي مَحْرَمٍ ‏"‏ ‏.‏\hadithno{3261}\hadithtrans{Abu Sa'id Khudri (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:A woman should not set out on a journey extending beyond three nights but with a Mahram}}
\hadithdefcmd{muslim}{3263}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، جَمِيعًا عَنْ جَرِيرٍ، - قَالَ قُتَيْبَةُ حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْمَلِكِ، - وَهُوَ ابْنُ عُمَيْرٍ - عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ سَمِعْتُ مِنْهُ، حَدِيثًا فَأَعْجَبَنِي فَقُلْتُ لَهُ أَنْتَ سَمِعْتَ هَذَا، مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَأَقُولُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَمْ أَسْمَعْ قَالَ سَمِعْتُهُ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَشُدُّوا الرِّحَالَ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِي هَذَا وَالْمَسْجِدِ الْحَرَامِ وَالْمَسْجِدِ الأَقْصَى ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ لاَ تُسَافِرِ الْمَرْأَةُ يَوْمَيْنِ مِنَ الدَّهْرِ إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ مِنْهَا أَوْ زَوْجُهَا ‏"‏ ‏.‏\hadithno{3263}\hadithtrans{Qaza'ah reported:I heard a hadith from Abu Sa'id (Allah be pleased with him) and it impressed me (very much), so I said to him: Did you hear it (yourself) from Allah's Messenger (ﷺ)? Thereupon he said: (Can) I speak of anything about Allah's Messenger (ﷺ) which I did not bear? He said: I heard Allah's Messenger (ﷺ) saying: Do not set out on a journey (for religious devotion) but for the three mosques-for this mosque of mine (at Medina) the Sacred Mosque (at Mecca), and the Mosque al-Aqsa (Bait al-Maqdis), and I heard him saying also: A woman should not travel for two days duration, but only when there is a Mahram with her or her husband}}
\hadithdefcmd{muslim}{3264}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ، عُمَيْرٍ قَالَ سَمِعْتُ قَزَعَةَ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ سَمِعْتُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْبَعًا فَأَعْجَبْنَنِي وَآنَقْنَنِي نَهَى أَنْ تُسَافِرَ الْمَرْأَةُ مَسِيرَةَ يَوْمَيْنِ إِلاَّ وَمَعَهَا زَوْجُهَا أَوْ ذُو مَحْرَمٍ ‏.‏ وَاقْتَصَّ بَاقِيَ الْحَدِيثِ ‏.‏\hadithno{3264}\hadithtrans{Qaza'ah reported:I heard Abu Sa'id al-Khudri (Allah be pleased with him) saying: I heard four things from Allah's Messenger (ﷺ) which impressed me and captivated me (and one out of these is this), that he forbade a woman to undertake journey extending over two days but with her husband, or with a Mahram; and he then narrated the rest of the hadith}}
\hadithdefcmd{muslim}{3265}{وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ أَكْثَرَ مِنْ ثَلاَثٍ إِلاَّ مَعَ ذِي مَحْرَمٍ ‏"‏ ‏.‏\hadithno{3265}\hadithtrans{This hadith has been narrated on the authority of Qatada with the same chain of transmitters and he said:" More than three (days) except in the company of a Mahram}}
\hadithdefcmd{muslim}{3266}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ مُسْلِمَةٍ تُسَافِرُ مَسِيرَةَ لَيْلَةٍ إِلاَّ وَمَعَهَا رَجُلٌ ذُو حُرْمَةٍ مِنْهَا ‏"‏ ‏.‏\hadithno{3266}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:It is not lawful for a Muslim woman to travel a night's journey except when there is a Mahram with her}}
\hadithdefcmd{muslim}{3267}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، حَدَّثَنَا سَعِيدُ، بْنُ أَبِي سَعِيدٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُسَافِرُ مَسِيرَةَ يَوْمٍ إِلاَّ مَعَ ذِي مَحْرَمٍ ‏"‏ ‏.‏\hadithno{3267}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:It is not lawful for a woman who believes in Allah and the Hereafter to undertake a day's journey except in the company of a Mahram}}
\hadithdefcmd{muslim}{3268}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُسَافِرُ مَسِيرَةَ يَوْمٍ وَلَيْلَةٍ إِلاَّ مَعَ ذِي مَحْرَمٍ عَلَيْهَا ‏"‏ ‏.‏\hadithno{3268}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:It is not lawful for a woman believing in Allah and the Hereafter to undertake journey extending over a day and a night except when there is a Mahram with her}}
\hadithdefcmd{muslim}{3269}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - حَدَّثَنَا سُهَيْلُ بْنُ، أَبِي صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ أَنْ تُسَافِرَ ثَلاَثًا إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ مِنْهَا ‏"‏ ‏.‏\hadithno{3269}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:It is not lawful for a woman to undertake three (days, ) journey except when there is a Mahram with her}}
\hadithdefcmd{muslim}{3270}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ جَمِيعًا - عَنْ أَبِي مُعَاوِيَةَ، قَالَ أَبُو كُرَيْبٍ حَدَّثَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُسَافِرَ سَفَرًا يَكُونُ ثَلاَثَةَ أَيَّامٍ فَصَاعِدًا إِلاَّ وَمَعَهَا أَبُوهَا أَوِ ابْنُهَا أَوْ زَوْجُهَا أَوْ أَخُوهَا أَوْ ذُو مَحْرَمٍ مِنْهَا ‏"‏ ‏.‏\hadithno{3270}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:It is not lawful for a woman believing in Allah and the Hereafter to undertake journey extending over three days or more, except when she is in the company of her father, or her son, or her husband, or her brother, or any other Mahram}}
\hadithdefcmd{muslim}{3271}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3271}\hadithtrans{A hadith like this has been narrated by A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{3272}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، كِلاَهُمَا عَنْ سُفْيَانَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ أَبِي مَعْبَدٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ يَقُولُ ‏"‏ لاَ يَخْلُوَنَّ رَجُلٌ بِامْرَأَةٍ إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ وَلاَ تُسَافِرِ الْمَرْأَةُ إِلاَّ مَعَ ذِي مَحْرَمٍ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ امْرَأَتِي خَرَجَتْ حَاجَّةً وَإِنِّي اكْتُتِبْتُ فِي غَزْوَةِ كَذَا وَكَذَا ‏.‏ قَالَ ‏"‏ انْطَلِقْ فَحُجَّ مَعَ امْرَأَتِكَ ‏"‏ ‏.‏\hadithno{3272}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported:I heard Allah's Messenger (ﷺ) delivering a sermon and making this observation:" No person should be alone with a woman except when there is a Mahram with her, and the woman should not undertake journey except with a Mahram." A person stood up and said: Allah's Messenger, my wife has set out for pilgrimage, whereas I am enlisted to fight in such and such battle, whereupon he said:" You go and perform Hajj with your wife}}
\hadithdefcmd{muslim}{3273}{وَحَدَّثَنَاهُ أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3273}\hadithtrans{A hadith like this has been narrated by 'Amr on the authority of the same chain of transmitters}}
\hadithdefcmd{muslim}{3274}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا هِشَامٌ، - يَعْنِي ابْنَ سُلَيْمَانَ - الْمَخْزُومِيُّ عَنِ ابْنِ، جُرَيْجٍ بِهَذَا الإِسْنَادِ نَحْوَهُ وَلَمْ يَذْكُرْ ‏ "‏ لاَ يَخْلُوَنَّ رَجُلٌ بِامْرَأَةٍ إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ ‏"‏ ‏.‏\hadithno{3274}\hadithtrans{Ibn Juraij narrated this hadith with the same chain of transmitters, but he made no mention of it:" No person (man) should be alone with a woman except when there is a Mahram with her}}
\hadithdefcmd{muslim}{3275}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّ عَلِيًّا الأَزْدِيَّ، أَخْبَرَهُ أَنَّ ابْنَ عُمَرَ عَلَّمَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اسْتَوَى عَلَى بَعِيرِهِ خَارِجًا إِلَى سَفَرٍ كَبَّرَ ثَلاَثًا ثُمَّ قَالَ ‏"‏ سُبْحَانَ الَّذِي سَخَّرَ لَنَا هَذَا وَمَا كُنَّا لَهُ مُقْرِنِينَ وَإِنَّا إِلَى رَبِّنَا لَمُنْقَلِبُونَ اللَّهُمَّ إِنَّا نَسْأَلُكَ فِي سَفَرِنَا هَذَا الْبِرَّ وَالتَّقْوَى وَمِنَ الْعَمَلِ مَا تَرْضَى اللَّهُمَّ هَوِّنْ عَلَيْنَا سَفَرَنَا هَذَا وَاطْوِ عَنَّا بُعْدَهُ اللَّهُمَّ أَنْتَ الصَّاحِبُ فِي السَّفَرِ وَالْخَلِيفَةُ فِي الأَهْلِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمَنْظَرِ وَسُوءِ الْمُنْقَلَبِ فِي الْمَالِ وَالأَهْلِ ‏"‏ ‏.‏ وَإِذَا رَجَعَ قَالَهُنَّ ‏.‏ وَزَادَ فِيهِنَّ ‏"‏ آيِبُونَ تَائِبُونَ عَابِدُونَ لِرَبِّنَا حَامِدُونَ ‏"‏ ‏.‏\hadithno{3275}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that whenever Allah's Messenger (ﷺ) mounted his camel while setting out on a journey, he glorified Allah (uttered Allah-o-Akbar) thrice, and then said:Hallowed is He Who subdued for us this (ride) and we were not ourselves powerful enough to use It as a ride, and we are going to return to our Lord. O Allah, we seek virtue and piety from Thee in this journey of ours and the act which pleaseth Thee. O Allah, lighten this journey of ours, and make its distance easy for us. O Allah, Thou art (our) companion during the journey, and guardian of (our) family. O Allah, I seek refuge with Thee from hardships of the journey, gloominess of the sights, and finding of evil changes in property and family on return. And he (the Holy Prophet) uttered (these words), and made this addition to them: We are returning, repentant, worshipping our Lord. and praising Him}}
\hadithdefcmd{muslim}{3276}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عَبْدِ، اللَّهِ بْنِ سَرْجِسَ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَافَرَ يَتَعَوَّذُ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ وَالْحَوْرِ بَعْدَ الْكَوْرِ وَدَعْوَةِ الْمَظْلُومِ وَسُوءِ الْمَنْظَرِ فِي الأَهْلِ وَالْمَالِ‏.‏\hadithno{3276}\hadithtrans{Abdullah b. Sarjis (Allah be pleased with him) reported that when Allah's Messenger (ﷺ) set forth on a journey, he sought refuge (with Allah) from the hardships of the travelling, and finding of evil changes on return, and disgrace after honour, and the curse of the oppressed and a gloomy sad scene in family and property}}
\hadithdefcmd{muslim}{3277}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، ح وَحَدَّثَنِي حَامِدُ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، كِلاَهُمَا عَنْ عَاصِمٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِ عَبْدِ الْوَاحِدِ فِي الْمَالِ وَالأَهْلِ ‏.‏ وَفِي رِوَايَةِ مُحَمَّدِ بْنِ خَازِمٍ قَالَ يَبْدَأُ بِالأَهْلِ إِذَا رَجَعَ ‏.‏ وَفِي رِوَايَتِهِمَا جَمِيعًا ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ ‏"‏ ‏.‏\hadithno{3277}\hadithtrans{A hadlth like this has been narrated on the authority of Asim With the same chain of transmitters except (this difference) that the hadith transmitted by 'Abd al-Wahid (one of the narrators) the (word)" property" precedes the family, and in the hadith transmitted by Mahammad b. Khazim (the word)" family" precedes (theword" Property" ), on returning home, in the narrations of both the narrators (these words are found):" O Allah I seek refuge with Thee from the hardships of the journey}}
\hadithdefcmd{muslim}{3278}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ح . وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَفَلَ مِنَ الْجُيُوشِ أَوِ السَّرَايَا أَوِ الْحَجِّ أَوِ الْعُمْرَةِ إِذَا أَوْفَى عَلَى ثَنِيَّةٍ أَوْ فَدْفَدٍ كَبَّرَ ثَلاَثًا ثُمَّ قَالَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ آيِبُونَ تَائِبُونَ عَابِدُونَ سَاجِدُونَ لِرَبِّنَا حَامِدُونَ صَدَقَ اللَّهُ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏ ‏.‏\hadithno{3278}\hadithtrans{Abdullah b. 'Umar reported that whenever Allah's Messenger (ﷺ) came back from the battle or from expeditions or from Hajj or Umra and as he reached the top of the hillock or upon the elevated hard ground, he uttered Allah-o- Akbar thrice, and then said:There is no god but Allah. He is One, there is no partner with Him, His is the sovereignty and His is the praise and He is Potent over everything. (We are) returning, repenting, worshipping, prostrating before our Lord, and we praise Him Allah fulfilled His promise and helped His servant, and routed the confederates alone}}
\hadithdefcmd{muslim}{3279}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَعْنٌ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ إِلاَّ حَدِيثَ أَيُّوبَ فَإِنَّ فِيهِ التَّكْبِيرَ مَرَّتَيْنِ ‏.‏\hadithno{3279}\hadithtrans{This hadith has been narrated on the authority of Ibn Umar through another chain of transmitters (but with one alteration) that here Allah-o-Akbar is mentioned twice}}
\hadithdefcmd{muslim}{3280}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، قَالَ قَالَ أَنَسُ بْنُ مَالِكٍ أَقْبَلْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم أَنَا وَأَبُو طَلْحَةَ ‏.‏ وَصَفِيَّةُ رَدِيفَتُهُ عَلَى نَاقَتِهِ حَتَّى إِذَا كُنَّا بِظَهْرِ الْمَدِينَةِ قَالَ ‏ "‏ آيِبُونَ تَائِبُونَ عَابِدُونَ لِرَبِّنَا حَامِدُونَ ‏"‏ ‏.‏ فَلَمْ يَزَلْ يَقُولُ ذَلِكَ حَتَّى قَدِمْنَا الْمَدِينَةَ ‏.‏\hadithno{3280}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported:I and Abu Talha (both) came back along with Allah's Apostle (ﷺ). Safiyyah (the wife of the Holy Prophet) rode behind him on his camel and as we came to the out- skirts of Medina he said: (We are those) who return, who repent, who worship our Lord, who praise (Him), and he went on uttering this until we entered Medina}}
\hadithdefcmd{muslim}{3281}{وَحَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{3281}\hadithtrans{A hadith like this has been narrated by Anas b. Malik (Allah be pleased with him) through another chain of transmitters}}
\hadithdefcmd{muslim}{3282}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَاخَ بِالْبَطْحَاءِ الَّتِي بِذِي الْحُلَيْفَةِ فَصَلَّى بِهَا ‏.‏ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{3282}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) made (his camel) kneel down (i, e. halt at the stony ground of Dhu'l-Hulaifa) and prayed there, and so did Abdullah b. Umar (Allah be pleased with them)}}
\hadithdefcmd{muslim}{3283}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ الْمِصْرِيُّ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ يُنِيخُ بِالْبَطْحَاءِ الَّتِي بِذِي الْحُلَيْفَةِ الَّتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنِيخُ بِهَا وَيُصَلِّي بِهَا ‏.‏\hadithno{3283}\hadithtrans{Nafi' reported that 'Abdullah b. Umar (Allah be pleased with them) used to halt his camel in the stony ground at Dhu'l-Hulaifa, where Allah's Messenger (ﷺ) used to make a halt (and pray)}}
\hadithdefcmd{muslim}{3284}{وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، حَدَّثَنِي أَنَسٌ، - يَعْنِي أَبَا ضَمْرَةَ - عَنْ مُوسَى، بْنِ عُقْبَةَ عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا صَدَرَ مِنَ الْحَجِّ أَوِ الْعُمْرَةِ أَنَاخَ بِالْبَطْحَاءِ الَّتِي بِذِي الْحُلَيْفَةِ الَّتِي كَانَ يُنِيخُ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3284}\hadithtrans{Nafi' reported that when 'Abdullah b. 'Umar returned from Hajj or 'Umra he made his camel kneel down (i. e. halted) in the stony ground of Dhu'l-Hulaifa where Allah's Messenger (ﷺ) had made his camel halt}}
\hadithdefcmd{muslim}{3285}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنْ مُوسَى، - وَهُوَ ابْنُ عُقْبَةَ - عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ فِي مُعَرَّسِهِ بِذِي الْحُلَيْفَةِ فَقِيلَ لَهُ إِنَّكَ بِبَطْحَاءَ مُبَارَكَةٍ ‏.‏\hadithno{3285}\hadithtrans{Salim (b. Abdullah b. 'Umar) reported on the authority of his father (Allah be pleased with them) that Allah's Apostle (ﷺ) was visited by (someone, i. e. an angel) during the fag end of the night at Dhu'l-Hulaifa, and it was said to him:Verily it is a blessed stony-ground}}
\hadithdefcmd{muslim}{3286}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارِ بْنِ الرَّيَّانِ، وَسُرَيْجُ بْنُ يُونُسَ، - وَاللَّفْظُ لِسُرَيْجٍ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ وَهُوَ فِي مُعَرَّسِهِ مِنْ ذِي الْحُلَيْفَةِ فِي بَطْنِ الْوَادِي فَقِيلَ إِنَّكَ بِبَطْحَاءَ مُبَارَكَةٍ ‏.‏ قَالَ مُوسَى وَقَدْ أَنَاخَ بِنَا سَالِمٌ بِالْمُنَاخِ مِنَ الْمَسْجِدِ الَّذِي كَانَ عَبْدُ اللَّهِ يُنِيخُ بِهِ يَتَحَرَّى مُعَرَّسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ أَسْفَلُ مِنَ الْمَسْجِدِ الَّذِي بِبَطْنِ الْوَادِي بَيْنَهُ وَبَيْنَ الْقِبْلَةِ وَسَطًا مِنْ ذَلِكَ ‏.‏\hadithno{3286}\hadithtrans{Salim b. Abdullah b. Umar reported on the authority of his father (Allah be pleased with them) that Allah's Apostle (ﷺ) came to Dhu'l- Hulaifa in the heart of the valley at the fag end of the night, and it was said to him:It is a blessed stony ground. Musa (one of the narrators) said: Salim made his came) halt at the mosque where 'Abdullah made his camel halt as seeking the place of stay of Allah's Messenger (ﷺ). It is, in fact, situated at a lower plain than the mosque, which stands in the heart of the valley, and it is between it (the mosque) (and Qibla) that that place (where Allah's Apostle used to get down for rest and prayer) is situated}}
\hadithdefcmd{muslim}{3287}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، ح . وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَعَثَنِي أَبُو بَكْرٍ الصِّدِّيقُ فِي الْحَجَّةِ الَّتِي أَمَّرَهُ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ حَجَّةِ الْوَدَاعِ فِي رَهْطٍ يُؤَذِّنُونَ فِي النَّاسِ يَوْمَ النَّحْرِ لاَ يَحُجُّ بَعْدَ الْعَامِ مُشْرِكٌ وَلاَ يَطُوفُ بِالْبَيْتِ عُرْيَانٌ ‏.‏ قَالَ ابْنُ شِهَابٍ فَكَانَ حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ يَقُولُ يَوْمُ النَّحْرِ يَوْمُ الْحَجِّ الأَكْبَرِ ‏.‏ مِنْ أَجْلِ حَدِيثِ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3287}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:Abu Bakr Siddiq (Allah be pleased with him) sent me during Hajj before the Farewell Pilgrimage for which Allah's Messenger (ﷺ) had appointed him an Amir, among a group of people whom he had ordered to make announcement to the people on the Day of Nahr:" After this year no polytheist may perform the Pilgrimage and no naked person may circumambulate the House." Ibn Shihab stated that Humaid b. Abd al-Rahman said that according to this narration of Abu Huraira (Allah be pleased with him) the day of Hajj al-Akbar (Great Hajj) is this Day of Nahr (10th of Dhu'l-Hijja)}}
\hadithdefcmd{muslim}{3288}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ يُونُسَ بْنَ يُوسُفَ، يَقُولُ عَنِ ابْنِ الْمُسَيَّبِ، قَالَ قَالَتْ عَائِشَةُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ يَوْمٍ أَكْثَرَ مِنْ أَنْ يُعْتِقَ اللَّهُ فِيهِ عَبْدًا مِنَ النَّارِ مِنْ يَوْمِ عَرَفَةَ وَإِنَّهُ لَيَدْنُو ثُمَّ يُبَاهِي بِهِمُ الْمَلاَئِكَةَ فَيَقُولُ مَا أَرَادَ هَؤُلاَءِ ‏"‏‏.‏\hadithno{3288}\hadithtrans{A'isha (Allah be pleased with her) reported Allah's Messenger (ﷺ) as saying:There is no day when God sets free more servants from Hell than the Day of 'Arafa. He draws near, then praises them to the angels, saying: What do these want?}}
\hadithdefcmd{muslim}{3289}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَةُ إِلَى الْعُمْرَةِ كَفَّارَةٌ لِمَا بَيْنَهُمَا وَالْحَجُّ الْمَبْرُورُ لَيْسَ لَهُ جَزَاءٌ إِلاَّ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{3289}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:An Umra is an expiation for the sins committed between it and the next, and Hajj which is accepted will receive no other reward than Paradise}}
\hadithdefcmd{muslim}{3290}{وَحَدَّثَنَاهُ سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الأُمَوِيُّ، حَدَّثَنَا عَبْدُ، الْعَزِيزِ بْنُ الْمُخْتَارِ عَنْ سُهَيْلٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، جَمِيعًا عَنْ سُفْيَانَ، كُلُّ هَؤُلاَءِ عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏بِمِثْلِ حَدِيثِ مَالِكٍ ‏.‏\hadithno{3290}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira (Allah be pleased with him) through another chain of transmitters}}
\hadithdefcmd{muslim}{3291}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ، زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَتَى هَذَا الْبَيْتَ فَلَمْ يَرْفُثْ وَلَمْ يَفْسُقْ رَجَعَ كَمَا وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏\hadithno{3291}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who came to this House (Ka'ba) (with the intention of performing Pilgrimage), and neither spoke indecently nor did he act wickedly. would return (free from sin) as on the (very first day) his mother bore him}}
\hadithdefcmd{muslim}{3292}{وَحَدَّثَنَاهُ سَعِيدُ بْنُ مَنْصُورٍ، عَنْ أَبِي عَوَانَةَ، وَأَبِي الأَحْوَصِ، ح وَحَدَّثَنَا أَبُو بَكْرِ، بْنُ أَبِي شَيْبَةَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كُلُّ هَؤُلاَءِ عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِهِمْ جَمِيعًا ‏ "‏ مَنْ حَجَّ فَلَمْ يَرْفُثْ وَلَمْ يَفْسُقْ ‏"‏ ‏.‏\hadithno{3292}\hadithtrans{This hadith has been narrated on the authority of Mainsur with the same chain of transmitters (and the words are):" He who performed Pilgrimage but neither spoke indecently nor acted wickedly}}
\hadithdefcmd{muslim}{3293}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ سَيَّارٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{3293}\hadithtrans{A hadith like this has been narrated on the authority of Abu Huraira (Allah be pleased with him)}}
\hadithdefcmd{muslim}{3294}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا يُونُسُ، بْنُ يَزِيدَ عَنِ ابْنِ شِهَابٍ، أَنَّ عَلِيَّ بْنَ حُسَيْنٍ، أَخْبَرَهُ أَنَّ عَمْرَو بْنَ عُثْمَانَ بْنِ عَفَّانَ أَخْبَرَهُ عَنْ أُسَامَةَ بْنِ زَيْدِ بْنِ حَارِثَةَ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَتَنْزِلُ فِي دَارِكَ بِمَكَّةَ فَقَالَ ‏ "‏ وَهَلْ تَرَكَ لَنَا عَقِيلٌ مِنْ رِبَاعٍ أَوْ دُورٍ ‏"‏ ‏.‏ وَكَانَ عَقِيلٌ وَرِثَ أَبَا طَالِبٍ هُوَ وَطَالِبٌ وَلَمْ يَرِثْهُ جَعْفَرٌ وَلاَ عَلِيٌّ شَيْئًا لأَنَّهُمَا كَانَا مُسْلِمَيْنِ وَكَانَ عَقِيلٌ وَطَالِبٌ كَافِرَيْنِ ‏.‏\hadithno{3294}\hadithtrans{Usama b. Zaid b. Haritha (Allah be pleased with him) said to Allah's Messenger (ﷺ):Will you stay in your house at Mecca (which you abandoned at the time of migration)? Thereupon he said: Has 'Aqil left for as any land or house? And 'Aqil and Talib became the Inheritors of Abu Talib's (property), and neither Ja'far nor 'Ali inherited anything from him, for both (Ja'far and 'Ali) were Muslims whereas 'Aqil and Talib were non-Muslims}}
\hadithdefcmd{muslim}{3295}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، وَابْنُ أَبِي عُمَرَ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ عَبْدِ، الرَّزَّاقِ - قَالَ ابْنُ مِهْرَانَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قُلْتُ يَا رَسُولَ اللَّهِ أَيْنَ تَنْزِلُ غَدًا وَذَلِكَ فِي حَجَّتِهِ حِينَ دَنَوْنَا مِنْ مَكَّةَ ‏.‏ فَقَالَ ‏ "‏ وَهَلْ تَرَكَ لَنَا عَقِيلٌ مَنْزِلاً ‏"‏ ‏.‏\hadithno{3295}\hadithtrans{Usama b. Zaid (Allah be pleased with him) said:Allah's Messenger, God willing, where will you stay tomorrow? And it was at the time of the Conquest (of Mecca). Thereupon he (the Holy Prophet) said: Has 'Aqil left any accommodation for us?}}
\hadithdefcmd{muslim}{3296}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حَفْصَةَ، وَزَمْعَةُ، بْنُ صَالِحٍ قَالاَ حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ، بْنِ زَيْدٍ أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَيْنَ تَنْزِلُ غَدًا إِنْ شَاءَ اللَّهُ وَذَلِكَ زَمَنَ الْفَتْحِ ‏.‏ قَالَ ‏ "‏ وَهَلْ تَرَكَ لَنَا عَقِيلٌ مِنْ مَنْزِلٍ ‏"‏ ‏.‏\hadithno{3296}\hadithtrans{Narrated Usama b. Zaid :Usama b. Zaid (Allah be pleased with him) said: Allah's Messenger, God willing, where will you stay tomorrow? Thereupon he (the Holy Prophet) said: Has 'Aqil left any accommodation for us?}}
\hadithdefcmd{muslim}{3297}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، أَنَّهُ سَمِعَ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَسْأَلُ السَّائِبَ بْنَ يَزِيدَ يَقُولُ هَلْ سَمِعْتَ فِي الإِقَامَةِ، بِمَكَّةَ شَيْئًا فَقَالَ السَّائِبُ سَمِعْتُ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لِلْمُهَاجِرِ إِقَامَةُ ثَلاَثٍ بَعْدَ الصَّدَرِ بِمَكَّةَ ‏"‏ ‏.‏ كَأَنَّهُ يَقُولُ لاَ يَزِيدُ عَلَيْهَا ‏.‏\hadithno{3297}\hadithtrans{Al-'Ali' b. al-Hadrami reported Allah's Messenger (may peace he upon as saying:For a Mahijir, it is only three (days') stay at Mecca, after completing (the Hajj or 'Umra) that is allowed, and it seemed as if he was saying that he should not (stay) beyond this (period)}}
\hadithdefcmd{muslim}{3298}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، قَالَ سَمِعْتُ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَقُولُ لِجُلَسَائِهِ مَا سَمِعْتُمْ فِي، سُكْنَى مَكَّةَ فَقَالَ السَّائِبُ بْنُ يَزِيدَ سَمِعْتُ الْعَلاَءَ، - أَوْ قَالَ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ - قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُقِيمُ الْمُهَاجِرُ بِمَكَّةَ بَعْدَ قَضَاءِ نُسُكِهِ ثَلاَثًا ‏"‏ ‏.‏\hadithno{3298}\hadithtrans{Al-'Ala' b. al-Hadrami reported Allah's Messenger (ﷺ) as saying:The Muhijir should stay at Mecca after performing the rituals (of Hajj) but for three (days) only}}
\hadithdefcmd{muslim}{3299}{وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، أَنَّهُ سَمِعَ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَسْأَلُ السَّائِبَ بْنَ يَزِيدَ فَقَالَ السَّائِبُ سَمِعْتُ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ ثَلاَثُ لَيَالٍ يَمْكُثُهُنَّ الْمُهَاجِرُ بِمَكَّةَ بَعْدَ الصَّدَرِ ‏"‏ ‏.‏\hadithno{3299}\hadithtrans{Al-'Ala' b. al-Hadrami reported Allah's Messenger (ﷺ) as saying:It is only for three nights that a Muhajir should stay at Mecca after the completion of the rituals of Hajj}}
\hadithdefcmd{muslim}{3300}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، وَأَمْلاَهُ، عَلَيْنَا إِمْلاَءً أَخْبَرَنِي إِسْمَاعِيلُ بْنُ مُحَمَّدِ بْنِ سَعْدٍ، أَنَّ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَخْبَرَهُ أَنَّ السَّائِبَ بْنَ يَزِيدَ أَخْبَرَهُ أَنَّ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ أَخْبَرَهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَكْثُ الْمُهَاجِرِ بِمَكَّةَ بَعْدَ قَضَاءِ نُسُكِهِ ثَلاَثٌ ‏"‏ ‏.‏\hadithno{3300}\hadithtrans{Al-" Ala' b. al-Hadrami reported Allah's Messenger (ﷺ) as saying:The stay at Mecca after the completion of his rituals (of Hajj) is only for three days}}
\hadithdefcmd{muslim}{3301}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3301}\hadithtrans{Ibn Juraij narrated this hadith with the same chain of transmitters}}
\hadithdefcmd{muslim}{3302}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ فَتْحِ مَكَّةَ ‏"‏ لاَ هِجْرَةَ وَلَكِنْ جِهَادٌ وَنِيَّةٌ وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏ ‏.‏ وَقَالَ يَوْمَ الْفَتْحِ فَتْحِ مَكَّةَ ‏"‏ إِنَّ هَذَا الْبَلَدَ حَرَّمَهُ اللَّهُ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ فَهُوَ حَرَامٌ بِحُرْمَةِ اللَّهِ إِلَى يَوْمِ الْقِيَامَةِ وَإِنَّهُ لَمْ يَحِلَّ الْقِتَالُ فِيهِ لأَحَدٍ قَبْلِي وَلَمْ يَحِلَّ لِي إِلاَّ سَاعَةً مِنْ نَهَارٍ فَهُوَ حَرَامٌ بِحُرْمَةِ اللَّهِ إِلَى يَوْمِ الْقِيَامَةِ لاَ يُعْضَدُ شَوْكُهُ وَلاَ يُنَفَّرُ صَيْدُهُ وَلاَ يَلْتَقِطُ إِلاَّ مَنْ عَرَّفَهَا وَلاَ يُخْتَلَى خَلاَهَا ‏"‏ ‏.‏ فَقَالَ الْعَبَّاسُ يَا رَسُولَ اللَّهِ إِلاَّ الإِذْخِرَ فَإِنَّهُ لِقَيْنِهِمْ وَلِبُيُوتِهِمْ ‏.‏ فَقَالَ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏ ‏.‏\hadithno{3302}\hadithtrans{Ibn 'Abbas (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying on the Day of Victory over Mecca:There is no Hijra (emigration) but only Jihad and good intention; and when you are called to battle, then go forth. He also said on the Day of Victory over Mecca: Allah made this town sacred on the day He created the earth and the heavens; so it is -sacred by the sacred- ness conferred on it by Allah until the Day of Resurrection and fighting in it was not lawful to anyone before me, and it was made lawful for me only during an hour on one day, for it is sacred by the sacredness conferred on it by Allah until the Day of Resurrection. Its thorns are not to be cut, its game is not to be molested, and the things dropped are to be picked up only by one who makes a public announcement of it, and its fresh herbage is not to be cut. Abbas (Allah be pleased with him) said: Messenger of Allah, exception may be made in case of rush, for it is useful for their blacksmiths and for their houses. He (the Holy Prophet) conceding the suggestion of 'Abbas) said: Except rush}}
\hadithdefcmd{muslim}{3303}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا مُفَضَّلٌ، عَنْ مَنْصُورٍ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ وَلَمْ يَذْكُرْ ‏"‏ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ ‏"‏ ‏.‏ وَقَالَ بَدَلَ الْقِتَالِ ‏"‏ الْقَتْلَ ‏"‏ ‏.‏ وَقَالَ ‏"‏ لاَ يَلْتَقِطُ لُقَطَتَهُ إِلاَّ مَنْ عَرَّفَهَا ‏"‏ ‏.‏\hadithno{3303}\hadithtrans{A hadith like this has been narrated on the authority of Mansur, but he did not mention:" On that very day He created the heavens and the earth," and he (the narrator) substituted the word" fighting" (qital) for" killing" (qatl), and further said:" No one is to pick up the dropped thing except one who makes a public announcement of it}}
\hadithdefcmd{muslim}{3304}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي شُرَيْحٍ الْعَدَوِيِّ، أَنَّهُ قَالَ لِعَمْرِو بْنِ سَعِيدٍ وَهُوَ يَبْعَثُ الْبُعُوثَ إِلَى مَكَّةَ ائْذَنْ لِي أَيُّهَا الأَمِيرُ أُحَدِّثْكَ قَوْلاً قَامَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الْغَدَ مِنْ يَوْمِ الْفَتْحِ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي وَأَبْصَرَتْهُ عَيْنَاىَ حِينَ تَكَلَّمَ بِهِ أَنَّهُ حَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ إِنَّ مَكَّةَ حَرَّمَهَا اللَّهُ وَلَمْ يُحَرِّمْهَا النَّاسُ فَلاَ يَحِلُّ لاِمْرِئٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَسْفِكَ بِهَا دَمًا وَلاَ يَعْضِدَ بِهَا شَجَرَةً فَإِنْ أَحَدٌ تَرَخَّصَ بِقِتَالِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهَا فَقُولُوا لَهُ إِنَّ اللَّهَ أَذِنَ لِرَسُولِهِ وَلَمْ يَأْذَنْ لَكُمْ وَإِنَّمَا أَذِنَ لِي فِيهَا سَاعَةً مِنْ نَهَارٍ وَقَدْ عَادَتْ حُرْمَتُهَا الْيَوْمَ كَحُرْمَتِهَا بِالأَمْسِ وَلْيُبَلِّغِ الشَّاهِدُ الْغَائِبَ ‏"‏ ‏.‏ فَقِيلَ لأَبِي شُرَيْحٍ مَا قَالَ لَكَ عَمْرٌو قَالَ أَنَا أَعْلَمُ بِذَلِكَ مِنْكَ يَا أَبَا شُرَيْحٍ إِنَّ الْحَرَمَ لاَ يُعِيذُ عَاصِيًا وَلاَ فَارًّا بِدَمٍ وَلاَ فَارًّا بِخَرْبَةٍ ‏.‏\hadithno{3304}\hadithtrans{Abu Shuraih al-'Adawi reported that he said to Amr b. Sa'id when he was sending troops to Mecca:Let me tell you something. O Commander, which Allah's Messenger (ﷺ) said on the day following, the Conquest which my ears heard and my heart has retained, and my eyes saw as he spoke it. He praised Allah and extolled Him and then said: Allah, not men, has made Mecca sacred; so it is not permissible for any person believing in Allah and the Last Day to shed blood in it, or lop a tree in it. If anyone seeks a concession on the basis of fighting of Allah's Messenger (ﷺ), tell him that Allah permitted His Messenger, but not you, and He gave him permission only for an hour on one day, and its sacredness was restored on the very day like that of yesterday. Let him who is present convey the information to him who is absent. It was said to Abu Shuraih: What did Amr say to you? He said: I am better informed of that than you, Abu Shuraih, but the sacred territory does not grant protection to one who is disobedient, or one who runs away after shedding blood, or one who runs away after committing}}
\hadithdefcmd{muslim}{3305}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، جَمِيعًا عَنِ الْوَلِيدِ، - قَالَ زُهَيْرٌ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، - حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ، - هُوَ ابْنُ عَبْدِ الرَّحْمَنِ - حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ لَمَّا فَتَحَ اللَّهُ عَزَّ وَجَلَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَكَّةَ قَامَ فِي النَّاسِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ حَبَسَ عَنْ مَكَّةَ الْفِيلَ وَسَلَّطَ عَلَيْهَا رَسُولَهُ وَالْمُؤْمِنِينَ وَإِنَّهَا لَنْ تَحِلَّ لأَحَدٍ كَانَ قَبْلِي وَإِنَّهَا أُحِلَّتْ لِي سَاعَةً مِنْ نَهَارٍ وَإِنَّهَا لَنْ تَحِلَّ لأَحَدٍ بَعْدِي فَلاَ يُنَفَّرُ صَيْدُهَا وَلاَ يُخْتَلَى شَوْكُهَا وَلاَ تَحِلُّ سَاقِطَتُهَا إِلاَّ لِمُنْشِدٍ وَمَنْ قُتِلَ لَهُ قَتِيلٌ فَهُوَ بِخَيْرِ النَّظَرَيْنِ إِمَّا أَنْ يُفْدَى وَإِمَّا أَنْ يُقْتَلَ ‏"‏ ‏.‏ فَقَالَ الْعَبَّاسُ إِلاَّ الإِذْخِرَ يَا رَسُولَ اللَّهِ فَإِنَّا نَجْعَلُهُ فِي قُبُورِنَا وَبُيُوتِنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏ ‏.‏ فَقَامَ أَبُو شَاهٍ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ فَقَالَ اكْتُبُوا لِي يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏ ‏.‏ قَالَ الْوَلِيدُ فَقُلْتُ لِلأَوْزَاعِيِّ مَا قَوْلُهُ اكْتُبُوا لِي يَا رَسُولَ اللَّهِ قَالَ هَذِهِ الْخُطْبَةَ الَّتِي سَمِعَهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3305}\hadithtrans{Abu Huraira, (Allah be pleased with him) reported. When Allah, the Exalted and Majestic, granted Allah's Messenger (ﷺ) victory over Mecca, he stood before people and praised and extolled Allah and then said:Verily Allah held back the elephants from Mecca and gave the domination of it to His Messenger and believers, and it (this territory) was not violable to anyone before me and it was made violable to me for an hour of a day, and it shall not be violable to anyone after me. So neither molest the game, nor weed out thorns from it. And it is not lawful for anyone to pick up a thing dropped but one who makes public announcement of it. And it a relative of anyone is killed he is entitled to opt for one of two things. Either he should be paid blood-money or he can take life as (a just retribution). 'Abbas (Allah be pleased with him) said: Allah's Messenger, but Idhkhir (a kind of herbage), for we use it for our graves and for our houses, whereupon Allah's Messenger (ﷺ) said: With the exception of Idhkhir. A person known as Abu Shah, one of the people of Yemen, stood up and said: Messenger of Allah, (kindly) write it for me. Thereupon Allah's Messenger (ﷺ) said I Write it for Abu Shah. Walid said: I asked al-Auzai': What did his saying mean:" Write it for me, Messenger of Allah"? He said: This very address that he had heard from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3306}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ يَحْيَى، أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّ خُزَاعَةَ قَتَلُوا رَجُلاً مِنْ بَنِي لَيْثٍ عَامَ فَتْحِ مَكَّةَ بِقَتِيلٍ مِنْهُمْ قَتَلُوهُ فَأُخْبِرَ بِذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَكِبَ رَاحِلَتَهُ فَخَطَبَ فَقَالَ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ حَبَسَ عَنْ مَكَّةَ الْفِيلَ وَسَلَّطَ عَلَيْهَا رَسُولَهُ وَالْمُؤْمِنِينَ أَلاَ وَإِنَّهَا لَمْ تَحِلَّ لأَحَدٍ قَبْلِي وَلَنْ تَحِلَّ لأَحَدٍ بَعْدِي أَلاَ وَإِنَّهَا أُحِلَّتْ لِي سَاعَةً مِنَ النَّهَارِ أَلاَ وَإِنَّهَا سَاعَتِي هَذِهِ حَرَامٌ لاَ يُخْبَطُ شَوْكُهَا وَلاَ يُعْضَدُ شَجَرُهَا وَلاَ يَلْتَقِطُ سَاقِطَتَهَا إِلاَّ مُنْشِدٌ وَمَنْ قُتِلَ لَهُ قَتِيلٌ فَهُوَ بِخَيْرِ النَّظَرَيْنِ إِمَّا أَنْ يُعْطَى - يَعْنِي الدِّيَةَ - وَإِمَّا أَنْ يُقَادَ أَهْلُ الْقَتِيلِ ‏"‏ ‏.‏ قَالَ فَجَاءَ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ يُقَالُ لَهُ أَبُو شَاهٍ فَقَالَ اكْتُبْ لِي يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنْ قُرَيْشٍ إِلاَّ الإِذْخِرَ فَإِنَّا نَجْعَلُهُ فِي بُيُوتِنَا وَقُبُورِنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏ ‏.‏\hadithno{3306}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:The people of the Khuza'ah tribe killed a man of the tribe of Laith in the Year of Victory as a retaliation for one whom they had killed (whom the people of the tribe of Laith had killed). It was reported to Allah's Messenger (ﷺ). He mounted his camel and delivered this address: Verily Allah, the Exalted and Majestic, held back the Ele- phants from Mecca, and gave its domination to His Messenger and believers. Behold, it was not violable for anyone before me and it will not be violable for anyone after me. Behold, it was made violable for me for an hour of a day; and at this very hour it has again been made inviolable (for me as well as for others). So its thorns are not to be cut, its trees are not to be lopped, and (no one is allowed to) pick up a thing dropped, but the one who makes an announcement of it. And one whose fellow is killed is allowed to opt between two alternatives: either he should receive blood-money or get the life of the (murderer) in return. He (the narrator said): A person from the Yemen, who was called Abu Shah, came to him and said: Messenger of Allah, write it down for me, whereupon he (Allah's Messenger) said: Write it down for Abu Shah. One of the persons from among the Quraish also said: Except Idhkhir, for we use it in our houses ant our graves. Thereupon Allah's Messenger (ﷺ) said: Except Idhkhir}}
\hadithdefcmd{muslim}{3307}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا ابْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لأَحَدِكُمْ أَنْ يَحْمِلَ بِمَكَّةَ السِّلاَحَ‏"‏ ‏.‏\hadithno{3307}\hadithtrans{Jabir (Allah be pleased with him) reported:I heard Allah's Apostle (ﷺ) say: It is not permissible for any one of you to carry weapons in Mecca}}
\hadithdefcmd{muslim}{3308}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، وَيَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، أَمَّا الْقَعْنَبِيُّ فَقَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ وَأَمَّا قُتَيْبَةُ فَقَالَ حَدَّثَنَا مَالِكٌ وَقَالَ يَحْيَى - وَاللَّفْظُ لَهُ - قُلْتُ لِمَالِكٍ أَحَدَّثَكَ ابْنُ شِهَابٍ عَنْ أَنَسِ بْنِ مَالِكٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ عَامَ الْفَتْحِ وَعَلَى رَأْسِهِ مِغْفَرٌ فَلَمَّا نَزَعَهُ جَاءَهُ رَجُلٌ فَقَالَ ابْنُ خَطَلٍ مُتَعَلِّقٌ بِأَسْتَارِ الْكَعْبَةِ ‏.‏ فَقَالَ ‏ "‏ اقْتُلُوهُ ‏"‏ ‏.‏ فَقَالَ مَالِكٌ نَعَمْ ‏.‏\hadithno{3308}\hadithtrans{Anas b. Malik (Allah be pleased with them) reported that Allah's Apostle (ﷺ) entered Mecca in the Year of Victory with a helmet on his head; and when he took it off, a man came to him and said:Ibn Khatal is hanging on to the curtains of the Ka'ba, whereupon he said: Kill him. Malik (one of the narrators) attested this statement having been made}}
\hadithdefcmd{muslim}{3309}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ، قُتَيْبَةُ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمَّارٍ الدُّهْنِيُّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ مَكَّةَ - وَقَالَ قُتَيْبَةُ دَخَلَ يَوْمَ فَتْحِ مَكَّةَ - وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ بِغَيْرِ إِحْرَامٍ ‏.‏ وَفِي رِوَايَةِ قُتَيْبَةَ قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ عَنْ جَابِرٍ ‏.‏\hadithno{3309}\hadithtrans{Jabir b. 'Abdullah al-Ansari (Allah be pleased with them) reported that Allah's Messenger (ﷺ) entered Mecca and Qutaiba (another narrator) stated that he entered Mecca in the Year of Victory, wearing a black turban, but not wearing the Ihram}}
\hadithdefcmd{muslim}{3310}{حَدَّثَنَا عَلِيُّ بْنُ حَكِيمٍ الأَوْدِيُّ، أَخْبَرَنَا شَرِيكٌ، عَنْ عَمَّارٍ الدُّهْنِيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ يَوْمَ فَتْحِ مَكَّةَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{3310}\hadithtrans{Jabir b. Abdullah reported that Allah's Apostle (ﷺ) entered on the day of Victory of Mecca wearing a black turban on his head}}
\hadithdefcmd{muslim}{3311}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالاَ أَخْبَرَنَا وَكِيعٌ، عَنْ مُسَاوِرٍ، الْوَرَّاقِ عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ النَّاسَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{3311}\hadithtrans{Amr b. Huraith reported on the authority of his father that Allah's Messenger (ﷺ) addressed the people (on the day of the Victory of Mecca) with a black turban on his head}}
\hadithdefcmd{muslim}{3312}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَالْحَسَنُ الْحُلْوَانِيُّ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مُسَاوِرٍ الْوَرَّاقِ، قَالَ حَدَّثَنِي وَفِي، رِوَايَةِ الْحُلْوَانِيِّ قَالَ سَمِعْتُ جَعْفَرَ بْنَ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِيهِ، قَالَ كَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ قَدْ أَرْخَى طَرَفَيْهَا بَيْنَ كَتِفَيْهِ ‏.‏ وَلَمْ يَقُلْ أَبُو بَكْرٍ عَلَى الْمِنْبَرِ ‏.‏\hadithno{3312}\hadithtrans{Ja'far b. 'Amr b. Huraith reported his father as saying:As if I am seeing Allah's Messenger (ﷺ) on the pulpit with a black turban on his head, and its two ends hanging between his shoulders. Abu Bakr (another narrator) did not make mention of:" Upon the pulpit}}
\hadithdefcmd{muslim}{3313}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ الدَّرَاوَرْدِيَّ - عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ عَبْدِ اللَّهِ بْنِ زَيْدِ بْنِ عَاصِمٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ وَدَعَا لأَهْلِهَا وَإِنِّي حَرَّمْتُ الْمَدِينَةَ كَمَا حَرَّمَ إِبْرَاهِيمُ مَكَّةَ وَإِنِّي دَعَوْتُ فِي صَاعِهَا وَمُدِّهَا بِمِثْلَىْ مَا دَعَا بِهِ إِبْرَاهِيمُ لأَهْلِ مَكَّةَ ‏"‏ ‏.‏\hadithno{3313}\hadithtrans{Abdullah b. Zaid b. 'Asim (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Verily Ibrahim declared Mecca sacred and supplicated (for blessings to be showered) upon its inhabitants, and I declare Medina to be sacred as lbrahim had declared Mecca to be sacred. I have supplicated (Allah for His blessings to be showered) in its sa' and its mudd (two standards of weight and measurement) twice as did Ibrahim for the inhabitants of Mecca}}
\hadithdefcmd{muslim}{3314}{وَحَدَّثَنِيهِ أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ يَعْنِي ابْنَ الْمُخْتَارِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، ح وَحَدَّثَنَاهُ إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، كُلُّهُمْ عَنْ عَمْرِو بْنِ يَحْيَى، - هُوَ الْمَازِنِيُّ - بِهَذَا الإِسْنَادِ أَمَّا حَدِيثُ وُهَيْبٍ فَكَرِوَايَةِ الدَّرَاوَرْدِيِّ ‏"‏ بِمِثْلَىْ مَا دَعَا بِهِ إِبْرَاهِيمُ ‏"‏ ‏.‏ وَأَمَّا سُلَيْمَانُ بْنُ بِلاَلٍ وَعَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ فَفِي رِوَايَتِهِمَا ‏"‏ مِثْلَ مَا دَعَا بِهِ إِبْرَاهِيمُ ‏"‏‏.‏\hadithno{3314}\hadithtrans{This hadith has been narrated through another chain of transmitters with a slight variation of words}}
\hadithdefcmd{muslim}{3315}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - يَعْنِي ابْنَ مُضَرَ - عَنِ ابْنِ الْهَادِ، عَنْ أَبِي، بَكْرِ بْنِ مُحَمَّدٍ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عُثْمَانَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ وَإِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا ‏"‏ ‏.‏ يُرِيدُ الْمَدِينَةَ ‏.‏\hadithno{3315}\hadithtrans{Rafi' b. Khadij reported Allah's Messenger (ﷺ) as saying:Ibrahim declared Mecca as sacred and I declare sacred the area between its two stony grounds (lava lands by which he meant Medina)}}
\hadithdefcmd{muslim}{3316}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ عُتْبَةَ بْنِ مُسْلِمٍ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، خَطَبَ النَّاسَ فَذَكَرَ مَكَّةَ وَأَهْلَهَا وَحُرْمَتَهَا وَلَمْ يَذْكُرِ الْمَدِينَةَ وَأَهْلَهَا وَحُرْمَتَهَا فَنَادَاهُ رَافِعُ بْنُ خَدِيجٍ فَقَالَ مَا لِي أَسْمَعُكَ ذَكَرْتَ مَكَّةَ وَأَهْلَهَا وَحُرْمَتَهَا وَلَمْ تَذْكُرِ الْمَدِينَةَ وَأَهْلَهَا وَحُرْمَتَهَا وَقَدْ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا بَيْنَ لاَبَتَيْهَا وَذَلِكَ عِنْدَنَا فِي أَدِيمٍ خَوْلاَنِيٍّ إِنْ شِئْتَ أَقْرَأْتُكَهُ ‏.‏ قَالَ فَسَكَتَ مَرْوَانُ ثُمَّ قَالَ قَدْ سَمِعْتُ بَعْضَ ذَلِكَ ‏.‏\hadithno{3316}\hadithtrans{Nafi' b. Jubair reported that Marwan b. al-Hakam (Allah be pleased with him) addressed people and made mention of Mecca and its inhabitants and its sacredness, but he made no mention of Medina, its inhabitants and its sacredness. Rafi' b. Khadij called to him and said:What is this that I hear you making mention of Mecca and its inhabitants and its sacredness, but you did not make mention of Medina and its inhabitants and its sacredness, while the Messenger of Allah (ﷺ) has also declared sacred (the area) between its two lava lands (Medina)? And (we have record of this) with us written on Khaulani parchment. If you like, I can read it out to you. Thereupon Marwan became silent, and then Said: I too have heard some part of it}}
\hadithdefcmd{muslim}{3317}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، كِلاَهُمَا عَنْ أَبِي أَحْمَدَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَسْدِيُّ، - حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ وَإِنِّي حَرَّمْتُ الْمَدِينَةَ مَا بَيْنَ لاَبَتَيْهَا لاَ يُقْطَعُ عِضَاهُهَا وَلاَ يُصَادُ صَيْدُهَا ‏"‏ ‏.‏\hadithno{3317}\hadithtrans{Jabir (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:Ibrahim declared Mecca as sacred; I declare Medina, that between the two mountains, as inviolable. No tree should be lopped and no game is to be molested}}
\hadithdefcmd{muslim}{3318}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، حَدَّثَنِي عَامِرُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَىِ الْمَدِينَةِ أَنْ يُقْطَعَ عِضَاهُهَا أَوْ يُقْتَلَ صَيْدُهَا - وَقَالَ - الْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ لاَ يَدَعُهَا أَحَدٌ رَغْبَةً عَنْهَا إِلاَّ أَبْدَلَ اللَّهُ فِيهَا مَنْ هُوَ خَيْرٌ مِنْهُ وَلاَ يَثْبُتُ أَحَدٌ عَلَى لأْوَائِهَا وَجَهْدِهَا إِلاَّ كُنْتُ لَهُ شَفِيعًا أَوْ شَهِيدًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3318}\hadithtrans{Amir b. Sa'd reported on the authority of his father (Allah be pleased with him) that Allah's Messenger (ﷺ) said:I have declared sacred the territory between the two lava plains of Medina, so its trees should not be cut down, or its game killed; and he also said: Medina is best for them if they knew. No one leaves it through dislike of it without Allah putting in it someone better than he in place of him; and no one will stay there in spite of its hardships and distress without my being an intercessor or witness on behalf of him on the Day of Resurrection}}
\hadithdefcmd{muslim}{3319}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ الأَنْصَارِيُّ، أَخْبَرَنِي عَامِرُ بْنُ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏.‏ ثُمَّ ذَكَرَ مِثْلَ حَدِيثِ ابْنِ نُمَيْرٍ وَزَادَ فِي الْحَدِيثِ ‏ "‏ وَلاَ يُرِيدُ أَحَدٌ أَهْلَ الْمَدِينَةِ بِسُوءٍ إِلاَّ أَذَابَهُ اللَّهُ فِي النَّارِ ذَوْبَ الرَّصَاصِ أَوْ ذَوْبَ الْمِلْحِ فِي الْمَاءِ ‏"‏ ‏.‏\hadithno{3319}\hadithtrans{Amir b. Sa'd b. Abu Waqqas reported on the authority of his father (Allah be pleased with him) that Allah's Messenger (ﷺ) said, and then the (above-mentioned) hadith was narrated with this addition:" None should nurse ill-will towards the people of Medina, or Allah will melt him in fire like the melting of lead or the dissolution of salt in water}}
\hadithdefcmd{muslim}{3320}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنِ الْعَقَدِيِّ، - قَالَ عَبْدٌ أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدٍ، عَنْ عَامِرِ بْنِ، سَعْدٍ أَنَّ سَعْدًا، رَكِبَ إِلَى قَصْرِهِ بِالْعَقِيقِ فَوَجَدَ عَبْدًا يَقْطَعُ شَجَرًا أَوْ يَخْبِطُهُ فَسَلَبَهُ فَلَمَّا رَجَعَ سَعْدٌ جَاءَهُ أَهْلُ الْعَبْدِ فَكَلَّمُوهُ أَنْ يَرُدَّ عَلَى غُلاَمِهِمْ أَوْ عَلَيْهِمْ مَا أَخَذَ مِنْ غُلاَمِهِمْ فَقَالَ مَعَاذَ اللَّهِ أَنْ أَرُدَّ شَيْئًا نَفَّلَنِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَأَبَى أَنْ يَرُدَّ عَلَيْهِمْ ‏.‏\hadithno{3320}\hadithtrans{Amir b. Sa'd reported that Sa'd rode to his castle in al-'Aqiq and found a slave cutting down the trees, or beating off their leaves, so he stripped him off his belongings. When Sa'd returned, there came to him the masters of the slave and negotiated with him asking him to return to their slave or to them what he had taken from their slave, whereupon he said:God forbid that I should return anything which Allah's Messenger (ﷺ) has given me as spoil, and refused to return anything to them}}
\hadithdefcmd{muslim}{3321}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ جَمِيعًا عَنْ إِسْمَاعِيلَ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، - أَخْبَرَنِي عَمْرُو بْنُ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَبِي طَلْحَةَ ‏"‏ الْتَمِسْ لِي غُلاَمًا مِنْ غِلْمَانِكُمْ يَخْدُمُنِي ‏"‏ ‏.‏ فَخَرَجَ بِي أَبُو طَلْحَةَ يُرْدِفُنِي وَرَاءَهُ فَكُنْتُ أَخْدُمُ رَسُولَ اللَّهِ صلى الله عليه وسلم كُلَّمَا نَزَلَ وَقَالَ فِي الْحَدِيثِ ثُمَّ أَقْبَلَ حَتَّى إِذَا بَدَا لَهُ أُحُدٌ قَالَ ‏"‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏ ‏.‏ فَلَمَّا أَشْرَفَ عَلَى الْمَدِينَةِ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أُحَرِّمُ مَا بَيْنَ جَبَلَيْهَا مِثْلَ مَا حَرَّمَ بِهِ إِبْرَاهِيمُ مَكَّةَ اللَّهُمَّ بَارِكْ لَهُمْ فِي مُدِّهِمْ وَصَاعِهِمْ ‏"‏ ‏.‏\hadithno{3321}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported that Allah's Messenger (ﷺ) said to Abu Talha (Allah be pleased with him):Find for me a servant from amongst your boys to serve me. Abu Talha went out along with me and made me sit behind him. And I used to serve Allah's Messenger (ﷺ) whenever he got down from the camel. And in one hadith he said: He proceeded and when (the mountain of) Uhud was within sight, he said: This is the mountain which loves us and we love it. And as he came close to Medina he said: O Allah, I declare (the area) between the two mountains of it (Medina) sacred just as Ibrahim declared Mecca as sacred. O Allah, bless them (the people of Medina) in their mudd and sa}}
\hadithdefcmd{muslim}{3322}{وَحَدَّثَنَاهُ سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ - عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ إِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا ‏"‏ ‏.‏\hadithno{3322}\hadithtrans{Anas b. Malik reported a hadith like this from Allah's Apostle (ﷺ) except with this variation that he said:" I declare sacred the area between its two lava mountains}}
\hadithdefcmd{muslim}{3323}{وَحَدَّثَنَاهُ حَامِدُ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عَاصِمٌ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ أَحَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ قَالَ نَعَمْ مَا بَيْنَ كَذَا إِلَى كَذَا فَمَنْ أَحْدَثَ فِيهَا حَدَثًا - قَالَ - ثُمَّ قَالَ لِي هَذِهِ شَدِيدَةٌ ‏ "‏ مَنْ أَحْدَثَ فِيهَا حَدَثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يَقْبَلُ اللَّهُ مِنْهُ يَوْمَ الْقِيَامَةِ صَرْفًا وَلاَ عَدْلاً ‏"‏ ‏.‏ قَالَ فَقَالَ ابْنُ أَنَسٍ أَوْ آوَى مُحْدِثًا ‏.‏\hadithno{3323}\hadithtrans{Asim reported:I asked Anas b. Malik whether Allah's Messenger (ﷺ) had declared Medina as sacred. He said: Yes. (the area) between so and so. He who made any innovation in it, and further said to me: It is something serious to make any innovation in it (and he who does it) there is upon him the curse of Allah, and that of the angels and of all the people, Allah will not accept from him on the Day of Resurrection either obligatory acts or the surpererogatory acts. Ibn Anas said: Or he accommodates an innovator}}
\hadithdefcmd{muslim}{3324}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عَاصِمٌ الأَحْوَلُ، قَالَ سَأَلْتُ أَنَسًا أَحَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ قَالَ نَعَمْ هِيَ حَرَامٌ لاَ يُخْتَلَى خَلاَهَا فَمَنْ فَعَلَ ذَلِكَ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ ‏.‏\hadithno{3324}\hadithtrans{Asim reported:I asked Anas (Allah be pleased with him) whether Allah's Messenger (ﷺ) had declared Medina as sacred. He said: Yes, it is sacred, so its tree is not to be cut; and he who did that let the curse of Allah and that of the angels and of all people be upon him}}
\hadithdefcmd{muslim}{3325}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ إِسْحَاقَ بْنِ عَبْدِ، اللَّهِ بْنِ أَبِي طَلْحَةَ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَهُمْ فِي مِكْيَالِهِمْ وَبَارِكْ لَهُمْ فِي صَاعِهِمْ وَبَارِكْ لَهُمْ فِي مُدِّهِمْ ‏"‏ ‏.‏\hadithno{3325}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported that Allah's Messenger (ﷺ) said:Allah bless them in their measurements, bless them in their sa's and bless them in their mudd}}
\hadithdefcmd{muslim}{3326}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَإِبْرَاهِيمُ بْنُ مُحَمَّدٍ السَّامِيُّ، قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ يُونُسَ، يُحَدِّثُ عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اجْعَلْ بِالْمَدِينَةِ ضِعْفَىْ مَا بِمَكَّةَ مِنَ الْبَرَكَةِ ‏"‏ ‏.‏\hadithno{3326}\hadithtrans{Anas b. Malik (Allah he pleased with him) reported that Allah's Messenger (ﷺ) said:O Allah, increase in Medina twice the blessings (Thou showered) on Mecca}}
\hadithdefcmd{muslim}{3327}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، - قَالَ أَبُو كُرَيْبٍ حَدَّثَنَا أَبُو مُعَاوِيَةَ، - حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ خَطَبَنَا عَلِيُّ بْنُ أَبِي طَالِبٍ فَقَالَ مَنْ زَعَمَ أَنَّ عِنْدَنَا، شَيْئًا نَقْرَأُهُ إِلاَّ كِتَابَ اللَّهِ وَهَذِهِ الصَّحِيفَةَ - قَالَ وَصِحِيفَةٌ مُعَلَّقَةٌ فِي قِرَابِ سَيْفِهِ - فَقَدْ كَذَبَ فِيهَا أَسْنَانُ الإِبِلِ وَأَشْيَاءُ مِنَ الْجِرَاحَاتِ وَفِيهَا قَالَ النَّبِيُّ صلى الله تعالى عليه وسلم ‏"‏ الْمَدِينَةُ حَرَمٌ مَا بَيْنَ عَيْرٍ إِلَى ثَوْرٍ فَمَنْ أَحْدَثَ فِيهَا حَدَثًا أَوْ آوَى مُحْدِثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يَقْبَلُ اللَّهُ مِنْهُ يَوْمَ الْقِيَامَةِ صَرْفًا وَلاَ عَدْلاً وَذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ يَسْعَى بِهَا أَدْنَاهُمْ وَمَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ أَوِ انْتَمَى إِلَى غَيْرِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يَقْبَلُ اللَّهُ مِنْهُ يَوْمَ الْقِيَامَةِ صَرْفًا وَلاَ عَدْلاً ‏"‏ ‏.‏ وَانْتَهَى حَدِيثُ أَبِي بَكْرٍ وَزُهَيْرٍ عِنْدَ قَوْلِهِ ‏"‏ يَسْعَى بِهَا أَدْنَاهُمْ ‏"‏ ‏.‏ وَلَمْ يَذْكُرَا مَا بَعْدَهُ وَلَيْسَ فِي حَدِيثِهِمَا مُعَلَّقَةٌ فِي قِرَابِ سَيْفِهِ ‏.‏\hadithno{3327}\hadithtrans{Ibrahim al-Taimi reported on the authority of his father:'Ali b. Abi Talib (Allah be pleased with him) addressed us and said: He who thought that we have besides the Holy Qur'an anything else that we recite, he told a lie. And this document which is hanging by the sheath of the sword contains but the ages of the camels, and the nature of the wounds. He (Hadrat 'Ali) reported Allah's Apostle (ﷺ) as saying: Medina is sacred from 'Air to Thaur; So if anyone makes an innovation or accommodates an innovator, the curse of Allah, the angels, and all persons will fall upon him, and Allah will not accept any obligatory or supererogatory act as recompense from them. And the protection granted by the Muslims is one and must be respected by the humblest of them. If anyone makes a false claim to paternity, or being a client of other than his own masters, there is upon him the curse of Allah, the angels, and all the people. Allah will not accept from him any recompense in the form of obligatory acts or supererogatory acts. The hadith transmitted on the authority of Abu Bakr and Zabair ends with (these words): The humblest among them should respect it; and what follows after it is not mentioned there, and in the hadith transmitted by them (these words are) not found: (The document was hanging) on the sheath of his sword}}
\hadithdefcmd{muslim}{3328}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ، الأَشَجُّ حَدَّثَنَا وَكِيعٌ، جَمِيعًا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ أَبِي كُرَيْبٍ عَنْ أَبِي، مُعَاوِيَةَ إِلَى آخِرِهِ وَزَادَ فِي الْحَدِيثِ ‏"‏ فَمَنْ أَخْفَرَ مُسْلِمًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ يَوْمَ الْقِيَامَةِ صَرْفٌ وَلاَ عَدْلٌ ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِهِمَا ‏"‏ مَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ ‏"‏ ‏.‏ وَلَيْسَ فِي رِوَايَةِ وَكِيعٍ ذِكْرُ يَوْمِ الْقِيَامَةِ ‏.‏\hadithno{3328}\hadithtrans{A hadith like this has been narrated on the authority of A'mash with the same chain of transmitters (but at the end) these words are added:" He who violated the covenant with a Muslim, there is upon him the curse of Allah, of angels and of all people. Neither an obligatory act nor a supererogatory act would be accepted from him as recompense on the Day of Resurrection; and in the hadith transmitted by two other narrators these words are not found:" He who claimed false paternity." And in the hadith transmitted by Waki' there is no mention of the Day of Resurrection}}
\hadithdefcmd{muslim}{3329}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَمُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ ابْنِ مُسْهِرٍ وَوَكِيعٍ إِلاَّ قَوْلَهُ ‏ "‏ مَنْ تَوَلَّى غَيْرَ مَوَالِيهِ ‏"‏ وَذِكْرَ اللَّعْنَةِ لَهُ ‏.‏\hadithno{3329}\hadithtrans{A hadith like this has been narrated with the same chain of transmitters by A'mash with a slight variation of words}}
\hadithdefcmd{muslim}{3330}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَدِينَةُ حَرَمٌ فَمَنْ أَحْدَثَ فِيهَا حَدَثًا أَوْ آوَى مُحْدِثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ يَوْمَ الْقِيَامَةِ عَدْلٌ وَلاَ صَرْفٌ ‏"‏ ‏.‏\hadithno{3330}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:Medina is a sacred territory, so he who made any innovation in it. or gave protection to an innovator, there is upon him the curse of Allah, that of the angels and that of all the people. There would not be accepted on the Day of Resurrection either obligatory acts or supererogatory acts from him}}
\hadithdefcmd{muslim}{3331}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ النَّضْرِ بْنِ أَبِي النَّضْرِ، حَدَّثَنِي أَبُو النَّضْرِ، حَدَّثَنِي عُبَيْدُ اللَّهِ، الأَشْجَعِيُّ عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَلَمْ يَقُلْ ‏"‏ يَوْمَ الْقِيَامَةِ ‏"‏ وَزَادَ ‏"‏ وَذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ يَسْعَى بِهَا أَدْنَاهُمْ فَمَنْ أَخْفَرَ مُسْلِمًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ يَوْمَ الْقِيَامَةِ عَدْلٌ وَلاَ صَرْفٌ ‏"‏ ‏.‏\hadithno{3331}\hadithtrans{A hadith like this has been narrated on the authority of A'mash with the same chain of transmitters, but no mention has been made of the Day of Resurrection. But this addition is made:" The protection granted by Muslims is one and must be respected by the humblest of them. And he who broke the covenant made by a Muslim, there is a curse of Allah, of his angels, and of the whole people upon him, and neither an obligatory act nor a supererogatory act would be accepted from him as recompense on the Day of Resurrection}}
\hadithdefcmd{muslim}{3332}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ لَوْ رَأَيْتُ الظِّبَاءَ تَرْتَعُ بِالْمَدِينَةِ مَا ذَعَرْتُهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا بَيْنَ لاَبَتَيْهَا حَرَامٌ ‏"‏ ‏.‏\hadithno{3332}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:If I were to see deer grazing in Medina, I would have never molested them, for Allah's Messenger (ﷺ) has stated: There is between the two lava mountains a sacred territory}}
\hadithdefcmd{muslim}{3333}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ إِسْحَاقُ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا بَيْنَ لاَبَتَىِ الْمَدِينَةِ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَلَوْ وَجَدْتُ الظِّبَاءَ مَا بَيْنَ لاَبَتَيْهَا مَا ذَعَرْتُهَا ‏.‏ وَجَعَلَ اثْنَىْ عَشَرَ مِيلاً حَوْلَ الْمَدِينَةِ حِمًى ‏.‏\hadithno{3333}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) declared sacred the territory between two lava mountains of Medina. Abu Huraira said:If I were to find deer in the territory between the two mountains, I would not molest them, and he (the Holy Prophet) declared twelve miles of suburb around Medina as a prohibited pasture}}
\hadithdefcmd{muslim}{3334}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، - فِيمَا قُرِئَ عَلَيْهِ - عَنْ سُهَيْلِ بْنِ، أَبِي صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ كَانَ النَّاسُ إِذَا رَأَوْا أَوَّلَ الثَّمَرِ جَاءُوا بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَإِذَا أَخَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَنَا فِي ثَمَرِنَا وَبَارِكْ لَنَا فِي مَدِينَتِنَا وَبَارِكْ لَنَا فِي صَاعِنَا وَبَارِكْ لَنَا فِي مُدِّنَا اللَّهُمَّ إِنَّ إِبْرَاهِيمَ عَبْدُكَ وَخَلِيلُكَ وَنَبِيُّكَ وَإِنِّي عَبْدُكَ وَنَبِيُّكَ وَإِنَّهُ دَعَاكَ لِمَكَّةَ وَإِنِّي أَدْعُوكَ لِلْمَدِينَةِ بِمِثْلِ مَا دَعَاكَ لِمَكَّةَ وَمِثْلِهِ مَعَهُ ‏"‏ ‏.‏ قَالَ ثُمَّ يَدْعُو أَصْغَرَ وَلِيدٍ لَهُ فَيُعْطِيهِ ذَلِكَ الثَّمَرَ‏.‏\hadithno{3334}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that when the people saw the first fruit (of the season or of plantation) they brought it to Allah's Apostle (ﷺ). When he received it he said:O Allah, bless us in our fruits; and bless us in our city; and bless us in our sa's and bless us in our mudd. O Allah, Ibrahim was Thy servant, Thy friend, and Thy apostle; and I am Thy servant and Thy apostle. He (Ibrahim) made supplication to Thee for (the showering of blessings upon) Mecca, and I am making supplication to Thee for Medina just as he made supplication to Thee for Mecca, and the like of it in addition. He would then call to him the youngest child and give him these fruits}}
\hadithdefcmd{muslim}{3335}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الْمَدَنِيُّ، عَنْ سُهَيْلِ بْنِ أَبِي، صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُؤْتَى بِأَوَّلِ الثَّمَرِ فَيَقُولُ ‏ "‏ اللَّهُمَّ بَارِكْ لَنَا فِي مَدِينَتِنَا وَفِي ثِمَارِنَا وَفِي مُدِّنَا وَفِي صَاعِنَا بَرَكَةً مَعَ بَرَكَةٍ ‏"‏ ‏.‏ ثُمَّ يُعْطِيهِ أَصْغَرَ مَنْ يَحْضُرُهُ مِنَ الْوِلْدَانِ ‏.‏\hadithno{3335}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) was given the first fruit and he said:O Allah, shower blessings upon us in our city, and in our fruits, in our mudd and in our sa's, blessings upon blessings, and he would then give that to the youngest of the children present there}}
\hadithdefcmd{muslim}{3336}{حَدَّثَنَا حَمَّادُ بْنُ إِسْمَاعِيلَ ابْنِ عُلَيَّةَ، حَدَّثَنَا أَبِي، عَنْ وُهَيْبٍ، عَنْ يَحْيَى بْنِ أَبِي، إِسْحَاقَ أَنَّهُ حَدَّثَ عَنْ أَبِي سَعِيدٍ، مَوْلَى الْمَهْرِيِّ أَنَّهُ أَصَابَهُمْ بِالْمَدِينَةِ جَهْدٌ وَشِدَّةٌ وَأَنَّهُ أَتَى أَبَا سَعِيدٍ الْخُدْرِيَّ فَقَالَ لَهُ إِنِّي كَثِيرُ الْعِيَالِ وَقَدْ أَصَابَتْنَا شِدَّةٌ فَأَرَدْتُ أَنْ أَنْقُلَ عِيَالِي إِلَى بَعْضِ الرِّيفِ ‏.‏ فَقَالَ أَبُو سَعِيدٍ لاَ تَفْعَلِ الْزَمِ الْمَدِينَةَ فَإِنَّا خَرَجْنَا مَعَ نَبِيِّ اللَّهِ صلى الله عليه وسلم - أَظُنُّ أَنَّهُ قَالَ - حَتَّى قَدِمْنَا عُسْفَانَ فَأَقَامَ بِهَا لَيَالِيَ فَقَالَ النَّاسُ وَاللَّهِ مَا نَحْنُ هَا هُنَا فِي شَىْءٍ وَإِنَّ عِيَالَنَا لَخُلُوفٌ مَا نَأْمَنُ عَلَيْهِمْ ‏.‏ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَا هَذَا الَّذِي بَلَغَنِي مِنْ حَدِيثِكُمْ - مَا أَدْرِي كَيْفَ قَالَ - وَالَّذِي أَحْلِفُ بِهِ أَوْ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ هَمَمْتُ أَوْ إِنْ شِئْتُمْ - لاَ أَدْرِي أَيَّتَهُمَا قَالَ - لآمُرَنَّ بِنَاقَتِي تُرْحَلُ ثُمَّ لاَ أَحُلُّ لَهَا عُقْدَةً حَتَّى أَقْدَمَ الْمَدِينَةَ - وَقَالَ - اللَّهُمَّ إِنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ فَجَعَلَهَا حَرَمًا وَإِنِّي حَرَّمْتُ الْمَدِينَةَ حَرَامًا مَا بَيْنَ مَأْزِمَيْهَا أَنْ لاَ يُهَرَاقَ فِيهَا دَمٌ وَلاَ يُحْمَلَ فِيهَا سِلاَحٌ لِقِتَالٍ وَلاَ يُخْبَطَ فِيهَا شَجَرَةٌ إِلاَّ لِعَلْفٍ اللَّهُمَّ بَارِكْ لَنَا فِي مَدِينَتِنَا اللَّهُمَّ بَارِكْ لَنَا فِي صَاعِنَا اللَّهُمَّ بَارِكْ لَنَا فِي مُدِّنَا اللَّهُمَّ بَارِكْ لَنَا فِي صَاعِنَا اللَّهُمَّ بَارِكْ لَنَا فِي مُدِّنَا اللَّهُمَّ بَارِكْ لَنَا فِي مَدِينَتِنَا اللَّهُمَّ اجْعَلْ مَعَ الْبَرَكَةِ بَرَكَتَيْنِ وَالَّذِي نَفْسِي بِيَدِهِ مَا مِنَ الْمَدِينَةِ شِعْبٌ وَلاَ نَقْبٌ إِلاَّ عَلَيْهِ مَلَكَانِ يَحْرُسَانِهَا حَتَّى تَقْدَمُوا إِلَيْهَا - ثُمَّ قَالَ لِلنَّاسِ - ارْتَحِلُوا ‏"‏ ‏.‏ فَارْتَحَلْنَا فَأَقْبَلْنَا إِلَى الْمَدِينَةِ فَوَالَّذِي نَحْلِفُ بِهِ أَوْ يُحْلَفُ بِهِ - الشَّكُّ مِنْ حَمَّادٍ - مَا وَضَعْنَا رِحَالَنَا حِينَ دَخَلْنَا الْمَدِينَةَ حَتَّى أَغَارَ عَلَيْنَا بَنُو عَبْدِ اللَّهِ بْنِ غَطَفَانَ وَمَا يَهِيجُهُمْ قَبْلَ ذَلِكَ شَىْءٌ ‏.‏\hadithno{3336}\hadithtrans{Abu Sa'id Maula al-Mahri reported that they were hard pressed by the distress and hardship of Medina, and he come to AbU Sa'Id al-Khudri and said to him:I have a large family (to support) and we are enduring hardships; I have, therefore, made up my mind to take my family to some fertile land. Thereupon Abu Sa'id said: Don't do that, stick to Medina, for we have come out with Allah's Apostle (ﷺ), and (I think that he also said) until we reached 'Usfan, and he (the Prophet along with his Companions) stayed there for some nights. There the people said: By Allah, we are lying here idle, whereas our children are unprotected behind us, and we do not feel secure about them. This (apprehension of theirs) reached Allah's Apostle (ﷺ), whereupon he said: What is this matter concerning you that has reached me? (I do not retain how he said it, whether he said like this: ) By Him (in the name of Whom) I take oath, (or he said like this: ) By Him in Whose Hand is my life, I made up my mind or if you like (I do not retain what word did he actually say), I should command my camel to proceed and not to let it halt until it comes to Medina and then said: Ibrahim declared Mecca as the sacred territory and it became sacred, and I declare Medina as the sacred territory-the area between the two mountains ('Air and Uhud). Thus no blood is to be shed within its (bounds) and no weapon is to be carried for fighting, and the leaves of the trees there should not be beaten off except for fodder. O Allah, bless us in our city; O Allah, bless us in our sil; O Allah, bless us in our mudd; O Allah, bless us in our sa; O Allah, bless us in our mudd. O Allah, bless us in our city. O Allah, bless with this blessing two more blessings. By Him in Whose Hand is my life, there is no ravine or mountain path of Medina which is not protected by two angels until you reach there. (He then said to the people: ) Proceed, and we, therefore, proceeded and we came to Medina By Him (in Whose name) we take oath and (in Whose name) oath is taken (Hammad is in doubt about it), we had hardly put down our camel saddles on arriving at Medina that we were attacked by the people of the tribe of 'Abdullah b. Ghatafan but none dared to do it before}}
\hadithdefcmd{muslim}{3337}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنَا أَبُو سَعِيدٍ، مَوْلَى الْمَهْرِيِّ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَنَا فِي صَاعِنَا وَمُدِّنَا وَاجْعَلْ مَعَ الْبَرَكَةِ بَرَكَتَيْنِ‏"‏\hadithno{3337}\hadithtrans{Abu Sa'id al-Kbudri (Allah be pleased with him) reported that Allah's Messenger (ﷺ) said:O Allah, bless us in our sa' and mud and shower with its blessings two other blessings (multiply blessings showerted upon it)}}
\hadithdefcmd{muslim}{3338}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا شَيْبَانُ، ح وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَرْبٌ، - يَعْنِي ابْنَ شَدَّادٍ - كِلاَهُمَا عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{3338}\hadithtrans{A hadith like this has been narrated by Yabya b. Abu Kathir with the same chain of transmitters}}
\hadithdefcmd{muslim}{3339}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي سَعِيدٍ، مَوْلَى الْمَهْرِيِّ أَنَّهُ جَاءَ أَبَا سَعِيدٍ الْخُدْرِيَّ لَيَالِيَ الْحَرَّةِ فَاسْتَشَارَهُ فِي الْجَلاَءِ مِنَ الْمَدِينَةِ وَشَكَا إِلَيْهِ أَسْعَارَهَا وَكَثْرَةَ عِيَالِهِ وَأَخْبَرَهُ أَنْ لاَ صَبْرَ لَهُ عَلَى جَهْدِ الْمَدِينَةِ وَلأْوَائِهَا ‏.‏ فَقَالَ لَهُ وَيْحَكَ لاَ آمُرُكَ بِذَلِكَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَصْبِرُ أَحَدٌ عَلَى لأْوَائِهَا فَيَمُوتَ إِلاَّ كُنْتُ لَهُ شَفِيعًا أَوْ شَهِيدًا يَوْمَ الْقِيَامَةِ إِذَا كَانَ مُسْلِمًا ‏"‏ ‏.‏\hadithno{3339}\hadithtrans{Abu Sa'id Maula al-Mahri reported that he came to Abu Sa'id al-Khudri during the nights (of the turmoil) of al-Barrah, and sought his advice about leaving Medina, and complained of the high prices prevailing therein and his large family, and informed him that he could not stand the hardships of Medina and its rugged surrounding. He said to him:Woe to you; I will not advise you to do it, for I heard Allah's Messenger (ﷺ) as saying: No one will endure hardships of Medina without my being an intercessor or a witness on his behalf on the Day of Resurrectiar), if he is a Muslim}}
\hadithdefcmd{muslim}{3340}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي أُسَامَةَ، - وَاللَّفْظُ لأَبِي بَكْرٍ وَابْنِ نُمَيْرٍ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، حَدَّثَنِي سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ عَبْدَ الرَّحْمَنِ، حَدَّثَهُ عَنْ أَبِيهِ أَبِي، سَعِيدٍ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنِّي حَرَّمْتُ مَا بَيْنَ لاَبَتَىِ الْمَدِينَةِ كَمَا حَرَّمَ إِبْرَاهِيمُ مَكَّةَ ‏"‏ ‏.‏ قَالَ ثُمَّ كَانَ أَبُو سَعِيدٍ يَأْخُذُ - وَقَالَ أَبُو بَكْرٍ يَجِدُ - أَحَدَنَا فِي يَدِهِ الطَّيْرُ فَيَفُكُّهُ مِنْ يَدِهِ ثُمَّ يُرْسِلُهُ ‏.‏\hadithno{3340}\hadithtrans{Abd al-Rahman reported on the authority of his father Abu Sa'id (Allah be pleased with him) that he heard Allah's Messenger (ﷺ) as saying:I have declared sacred what is between the two lava grounds of Medina just as Ibrahim (peace be upon him) declared Mecca as sacred. He (the narrator) then said: Abu Sa'id caught hold of (Abu Bakr, another narrator, used the word" found" ) a bird in his hand and then released it from his hand and set it free}}
\hadithdefcmd{muslim}{3341}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، عَنْ يُسَيْرِ، بْنِ عَمْرٍو عَنْ سَهْلِ بْنِ حُنَيْفٍ، قَالَ أَهْوَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ إِلَى الْمَدِينَةِ فَقَالَ ‏ "‏ إِنَّهَا حَرَمٌ آمِنٌ ‏"‏ ‏.‏\hadithno{3341}\hadithtrans{Sahl b. Hunif reported that Allah's Messenger (ﷺ) pointed with his hands towards Medina and said:That is a sacred territory and a place of safety}}
\hadithdefcmd{muslim}{3342}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَدِمْنَا الْمَدِينَةَ وَهْىَ وَبِيئَةٌ فَاشْتَكَى أَبُو بَكْرٍ وَاشْتَكَى بِلاَلٌ فَلَمَّا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم شَكْوَى أَصْحَابِهِ قَالَ ‏ "‏ اللَّهُمَّ حَبِّبْ إِلَيْنَا الْمَدِينَةَ كَمَا حَبَّبْتَ مَكَّةَ أَوْ أَشَدَّ وَصَحِّحْهَا وَبَارِكْ لَنَا فِي صَاعِهَا وَمُدِّهَا وَحَوِّلْ حُمَّاهَا إِلَى الْجُحْفَةِ ‏"‏ ‏.‏\hadithno{3342}\hadithtrans{A'isha (Allah be pleased with her) reported:When we came to Medina, and it was an unhealthy, uncogenial place, Abu Bakr fell sick and Bilal also fell sick; and when Allah's Messenger (ﷺ) saw the illness of his Companions he said: O Allah, make Medina as congenial to us as you made Mecca congenial or more than that; make it conducive to health, and bleesus in its sa' and in its mudd, and transfer its fever to al-juhfa}}
\hadithdefcmd{muslim}{3343}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، وَابْنُ، نُمَيْرٍ عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏\hadithno{3343}\hadithtrans{This hadith has been narrated by Hisham b. 'Urwa with the same chain of transmitters}}
\hadithdefcmd{muslim}{3344}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا عِيسَى بْنُ حَفْصِ بْنِ عَاصِمٍ، حَدَّثَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَبَرَ عَلَى لأْوَائِهَا كُنْتُ لَهُ شَفِيعًا أَوْ شَهِيدًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3344}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who patiently endures the hardships of it (of this city of Medina), I would be an intercessor or a withness on his behalf on the Day of Resurrection}}
\hadithdefcmd{muslim}{3345}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ قَطَنِ بْنِ وَهْبِ بْنِ عُوَيْمِرِ بْنِ، الأَجْدَعِ عَنْ يُحَنِّسَ، مَوْلَى الزُّبَيْرِ أَخْبَرَهُ أَنَّهُ، كَانَ جَالِسًا عِنْدَ عَبْدِ اللَّهِ بْنِ عُمَرَ فِي الْفِتْنَةِ فَأَتَتْهُ مَوْلاَةٌ لَهُ تُسَلِّمُ عَلَيْهِ فَقَالَتْ إِنِّي أَرَدْتُ الْخُرُوجَ يَا أَبَا عَبْدِ الرَّحْمَنِ اشْتَدَّ عَلَيْنَا الزَّمَانُ ‏.‏ فَقَالَ لَهَا عَبْدُ اللَّهِ اقْعُدِي لَكَاعِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَصْبِرُ عَلَى لأْوَائِهَا وَشِدَّتِهَا أَحَدٌ إِلاَّ كُنْتُ لَهُ شَهِيدًا أَوْ شَفِيعًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3345}\hadithtrans{Yuhannis, the freed slave of Zubair, narrated that when he was sitting with Abdullah b. 'Umar (Allah be pleased with him) during the days of turmoil, his freed slave-girl came to him. After saluting him she said:Abu Abd al-Rahmin, I have decided to leave (Medina) for the time is hard for us, whereupon Abdullah said to her: Stay here, foolish lady, for I have heard Allah's Messenger (ﷺ) as saying: For one who shows endurance on the hardships and rigour of it (of Medina) I would be an intercessor or a witness on his behalf on the Day of Resurrection}}
\hadithdefcmd{muslim}{3346}{وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، عَنْ قَطَنٍ الْخُزَاعِيِّ، عَنْ يُحَنِّسَ، مَوْلَى مُصْعَبٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَبَرَ عَلَى لأْوَائِهَا وَشِدَّتِهَا كُنْتُ لَهُ شَهِيدًا أَوْ شَفِيعًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ يَعْنِي الْمَدِينَةَ ‏.‏\hadithno{3346}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) said:I heard Allah's Messenger (ﷺ) as saying: He who patiently endured the hardships and rigours of (this city, i. e. Medina), I would be his witness and intercessor on the Day of Resurrection}}
\hadithdefcmd{muslim}{3347}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَصْبِرُ عَلَى لأْوَاءِ الْمَدِينَةِ وَشِدَّتِهَا أَحَدٌ مِنْ أُمَّتِي إِلاَّ كُنْتُ لَهُ شَفِيعًا يَوْمَ الْقِيَامَةِ أَوْ شَهِيدًا ‏"‏ ‏.‏\hadithno{3347}\hadithtrans{Abu Huraira (Allah be pleased with him) reported the Messenger of Allah (ﷺ) as saying:For one among my Ummah who shows endurance against the hardships and rigours of Medina, I would be an intercessor or a witness on his behalf on the Day of Resurrection}}
\hadithdefcmd{muslim}{3348}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي هَارُونَ، مُوسَى بْنِ أَبِي عِيسَى أَنَّهُ سَمِعَ أَبَا عَبْدِ اللَّهِ الْقَرَّاظَ، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{3348}\hadithtrans{A hadith like this has been narrated on the authority of Abu Huraira (Allah be pleased with him) through another chain of transmitters}}
\hadithdefcmd{muslim}{3349}{وَحَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ صَالِحِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَصْبِرُ أَحَدٌ عَلَى لأْوَاءِ الْمَدِينَةِ ‏"‏ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{3349}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:None who shows endurance on the hardships of Medina,... (the rest of the hadith is the same)}}
\hadithdefcmd{muslim}{3350}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَى أَنْقَابِ الْمَدِينَةِ مَلاَئِكَةٌ لاَ يَدْخُلُهَا الطَّاعُونُ وَلاَ الدَّجَّالُ ‏"‏ ‏.‏\hadithno{3350}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:There are at the approaches of Medina angels so that plague and the Dajjal shall not penetrate into it}}
\hadithdefcmd{muslim}{3351}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، أَخْبَرَنِي الْعَلاَءُ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَأْتِي الْمَسِيحُ مِنْ قِبَلِ الْمَشْرِقِ هِمَّتُهُ الْمَدِينَةُ حَتَّى يَنْزِلَ دُبُرَ أُحُدٍ ثُمَّ تَصْرِفُ الْمَلاَئِكَةُ وَجْهَهُ قِبَلَ الشَّامِ وَهُنَالِكَ يَهْلِكُ ‏"‏ ‏.‏\hadithno{3351}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Dajjal will come from the eastern side with the intention of attacking Medina until he will get down behind Uhud. Then the angels will turn his face towards Syria and there he will perish}}
\hadithdefcmd{muslim}{3352}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ يَدْعُو الرَّجُلُ ابْنَ عَمِّهِ وَقَرِيبَهُ هَلُمَّ إِلَى الرَّخَاءِ هَلُمَّ إِلَى الرَّخَاءِ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَخْرُجُ مِنْهُمْ أَحَدٌ رَغْبَةً عَنْهَا إِلاَّ أَخْلَفَ اللَّهُ فِيهَا خَيْرًا مِنْهُ أَلاَ إِنَّ الْمَدِينَةَ كَالْكِيرِ تُخْرِجُ الْخَبِيثَ ‏.‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَنْفِيَ الْمَدِينَةُ شِرَارَهَا كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ ‏"‏ ‏.‏\hadithno{3352}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:A time will come for the people (of Medina) when a man will invite his cousin and any other near relation: Come (and settle) at (a place) where living is cheap, come to where there is plenty, but Medina will be better for them; would they know it! By Him in Whose Hand is my life, none amongst them would go out (of the city) with a dislike for it, but Allah would make his successor in it someone better than be. Behold. Medina is like furnace which eliminates from it the impurities. And the Last Hour will not come until Medina banishes its evils just as a furnace eliminates the impurities of iron}}
\hadithdefcmd{muslim}{3353}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، - فِيمَا قُرِئَ عَلَيْهِ - عَنْ يَحْيَى بْنِ، سَعِيدٍ قَالَ سَمِعْتُ أَبَا الْحُبَابِ، سَعِيدَ بْنَ يَسَارٍ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ بِقَرْيَةٍ تَأْكُلُ الْقُرَى يَقُولُونَ يَثْرِبَ وَهْىَ الْمَدِينَةُ تَنْفِي النَّاسَ كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ ‏"‏ ‏.‏\hadithno{3353}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (way peace be upon him) as saying:I have been commanded (to migrate) to a town (Medina) which would overpower other towns. They (the people) call it Yathrib; its correct name is (in fact) Medina. It eliminates (bad) people just as a furnace removes the alloy of iron}}
\hadithdefcmd{muslim}{3354}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، جَمِيعًا عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ وَقَالاَ ‏ "‏ كَمَا يَنْفِي الْكِيرُ الْخَبَثَ "‏ ‏.‏ لَمْ يَذْكُرَا الْحَدِيدَ\hadithno{3354}\hadithtrans{This hadith has been narrated by Yabya b. Sa'id with the same chain of transmitters (and the words are):" Just as a furance removes impurity," but no mention is made of iron}}
\hadithdefcmd{muslim}{3355}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ، بْنِ عَبْدِ اللَّهِ أَنَّ أَعْرَابِيًّا، بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَصَابَ الأَعْرَابِيَّ وَعَكٌ بِالْمَدِينَةِ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى فَخَرَجَ الأَعْرَابِيُّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الْمَدِينَةُ كَالْكِيرِ تَنْفِي خَبَثَهَا وَيَنْصَعُ طَيِّبُهَا ‏"‏ ‏.‏\hadithno{3355}\hadithtrans{Jabir b. `Abdullah (Allah be pleased with them) reported that a desert Arab swore allegiance to Allah's Messenger (ﷺ). He suffered from a severe fever in Medina (and) so he came to Allah's Messenger (ﷺ) saying:Muhammad, cancel my oath of allegiance. But Allah's Messenger (ﷺ) refused it. He again came and said: Cancel my oath of allegiance. But he (the Holy Prophet) refused it. He again came to him and said: Cancel my oath of allegiance, but he refused. The desert Arab, however, went away (cancelling the allegiance himself). Thereupon Allah's Messenger (ﷺ) said: Medina is like a furnace which drives away its impurity and purifies what is good}}
\hadithdefcmd{muslim}{3356}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، - وَهُوَ الْعَنْبَرِيُّ - حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - سَمِعَ عَبْدَ اللَّهِ بْنَ يَزِيدَ، عَنْ زَيْدِ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهَا طَيْبَةُ - يَعْنِي الْمَدِينَةَ - وَإِنَّهَا تَنْفِي الْخَبَثَ كَمَا تَنْفِي النَّارُ خَبَثَ الْفِضَّةِ‏"‏ ‏.‏\hadithno{3356}\hadithtrans{Zaid b. Thabit reported Allah's Apostle (ﷺ) as saying:It is Taiba, thereby meaning Medina. It drives away impurity just as fire removes the impurity of silver}}
\hadithdefcmd{muslim}{3357}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَهَنَّادُ بْنُ السَّرِيِّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالُوا حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ تَعَالَى سَمَّى الْمَدِينَةَ طَابَةَ ‏"‏ ‏.‏\hadithno{3357}\hadithtrans{Jabir b. Samura (Allah be pleased with him) reported that he heard Allah's Messenger (ﷺ) say:Allah named Medina as Tabba}}
\hadithdefcmd{muslim}{3358}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَإِبْرَاهِيمُ بْنُ دِينَارٍ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، كِلاَهُمَا عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، بْنِ يُحَنِّسَ عَنْ أَبِي عَبْدِ اللَّهِ الْقَرَّاظِ، أَنَّهُ قَالَ أَشْهَدُ عَلَى أَبِي هُرَيْرَةَ أَنَّهُ قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ مَنْ أَرَادَ أَهْلَ هَذِهِ الْبَلْدَةِ بِسُوءٍ - يَعْنِي الْمَدِينَةَ - أَذَابَهُ اللَّهُ كَمَا يَذُوبُ الْمِلْحُ فِي الْمَاءِ ‏"‏ ‏.‏\hadithno{3358}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Abul-Qasim (Muhammad, may peace be upon him) said:He who intends to do harm to the people of this city (that is, Medina), Allah would efface him as salt is dissolved in water}}
\hadithdefcmd{muslim}{3359}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَإِبْرَاهِيمُ بْنُ دِينَارٍ، قَالاَ حَدَّثَنَا حَجَّاجٌ، ح وَحَدَّثَنِيهِ مُحَمَّدُ، بْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ يَحْيَى بْنِ عُمَارَةَ، أَنَّهُ سَمِعَ الْقَرَّاظَ، - وَكَانَ مِنْ أَصْحَابِ أَبِي هُرَيْرَةَ - يَزْعُمُ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَرَادَ أَهْلَهَا بِسُوءٍ - يُرِيدُ الْمَدِينَةَ - أَذَابَهُ اللَّهُ كَمَا يَذُوبُ الْمِلْحُ فِي الْمَاءِ ‏"‏ ‏.‏ قَالَ ابْنُ حَاتِمٍ فِي حَدِيثِ ابْنِ يُحَنِّسَ بَدَلَ قَوْلِهِ بِسُوءٍ شَرًّا‏.‏\hadithno{3359}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who intends to do harm to its people (he meant Medina), Allah would efface him as salt is dissolved in water. Ibn Hatim (one of the narrators) substituted the word" harm" for" mischief}}
\hadithdefcmd{muslim}{3360}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي هَارُونَ، مُوسَى بْنِ أَبِي عِيسَى ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا الدَّرَاوَرْدِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، جَمِيعًا سَمِعَا أَبَا عَبْدِ اللَّهِ، الْقَرَّاظَ سَمِعَ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{3360}\hadithtrans{This hadith is narrated on the authority of Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{3361}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ عُمَرَ بْنِ نُبَيْهٍ، أَخْبَرَنِي دِينَارٌ الْقَرَّاظُ، قَالَ سَمِعْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَرَادَ أَهْلَ الْمَدِينَةِ بِسُوءٍ أَذَابَهُ اللَّهُ كَمَا يَذُوبُ الْمِلْحُ فِي الْمَاءِ ‏"‏ ‏.‏\hadithno{3361}\hadithtrans{Sa'd b. Abu Waqqas reported Allah's Messenger (ﷺ) as saying:He who intends to do harm to the people of Medina, Allah would efface him just as water dissolves salt}}
\hadithdefcmd{muslim}{3362}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ عُمَرَ بْنِ نُبَيْهٍ، الْكَعْبِيِّ عَنْ أَبِي عَبْدِ اللَّهِ الْقَرَّاظِ، أَنَّهُ سَمِعَ سَعْدَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ بِدَهْمٍ أَوْ بِسُوءٍ ‏"‏ ‏.‏\hadithno{3362}\hadithtrans{Sa'd b. Malik heard Allah's Messenger (ﷺ) saying like this except (this variation) that he said:" Sudden attack or harm}}
\hadithdefcmd{muslim}{3363}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ أَبِي عَبْدِ اللَّهِ الْقَرَّاظِ، قَالَ سَمِعْتُهُ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، وَسَعْدًا، يَقُولاَنِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَارِكْ لأَهْلِ الْمَدِينَةِ فِي مُدِّهِمْ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ وَفِيهِ ‏"‏ مَنْ أَرَادَ أَهْلَهَا بِسُوءٍ أَذَابَهُ اللَّهُ كَمَا يَذُوبُ الْمِلْحُ فِي الْمَاءِ ‏"‏ ‏.‏\hadithno{3363}\hadithtrans{Abu Huraira and Sa'd reported Allah's Messenger (way peace be upon him) as saying:O Allah, bless the people of Medina in their mudd, the rest of the hadith being the same, and in It (this is also mentioned):" He wo intends to do harm to its people, Allah would efface him just as salt it dissolved in water}}
\hadithdefcmd{muslim}{3364}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ سُفْيَانَ بْنِ أَبِي زُهَيْرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُفْتَحُ الشَّامُ فَيَخْرُجُ مِنَ الْمَدِينَةِ قَوْمٌ بِأَهْلِيهِمْ يَبُسُّونَ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ ثُمَّ يُفْتَحُ الْيَمَنُ فَيَخْرُجُ مِنَ الْمَدِينَةِ قَوْمٌ بِأَهْلِيهِمْ يَبُسُّونَ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ ثُمَّ يُفْتَحُ الْعِرَاقُ فَيَخْرُجُ مِنَ الْمَدِينَةِ قَوْمٌ بِأَهْلِيهِمْ يَبُسُّونَ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ ‏"‏ ‏.‏\hadithno{3364}\hadithtrans{Sufyan b. Abd Zuhair reported Allah's Messenger (ﷺ) as saying:Syria will be conquered and some people will go out of Medina along with their families driving their camels. and Medina is better for them if they were to know it. Then Yemen will be conquered and some people will go out of Medina along with their families driving their camels, and Medina is better for them if they were to know it. Then Iraq will be conquered and some people will go out of it along with their families driving their camels, and Medina is better for them if they were to know it}}
\hadithdefcmd{muslim}{3365}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي هِشَامُ، بْنُ عُرْوَةَ عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ سُفْيَانَ بْنِ أَبِي زُهَيْرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يُفْتَحُ الْيَمَنُ فَيَأْتِي قَوْمٌ يَبُسُّونَ فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ ثُمَّ يُفْتَحُ الشَّامُ فَيَأْتِي قَوْمٌ يَبُسُّونَ فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ ثُمَّ يُفْتَحُ الْعِرَاقُ فَيَأْتِي قَوْمٌ يَبُسُّونَ فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ ‏"‏ ‏.‏\hadithno{3365}\hadithtrans{Sufyan b. Abu Zuhair heard Allah's Messenger (ﷺ) say:Yemen will be conquered and some people will go away (to that country) driving their camels and carrying their families on them and those who are under their authority, while Medina is better for them if they were to know it. Then Syria will be conquered and some people will go away driving their camels along with them and carrying their families with them and those who are under their authority, while Medina is better for theni if they were to know it. Thtn lraq will be conquered and some people will go away (to that country) driving their camels and carrying their families with them and those who are under their authority. while Medina is better for them if they were to know it}}
\hadithdefcmd{muslim}{3366}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو صَفْوَانَ، عَنْ يُونُسَ بْنِ يَزِيدَ، ح وَحَدَّثَنِي حَرْمَلَةُ، بْنُ يَحْيَى - وَاللَّفْظُ لَهُ - أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ، الْمُسَيَّبِ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْمَدِينَةِ ‏ "‏ لَيَتْرُكَنَّهَا أَهْلُهَا عَلَى خَيْرِ مَا كَانَتْ مُذَلَّلَةً لِلْعَوَافِي ‏"‏ ‏.‏ يَعْنِي السِّبَاعَ وَالطَّيْرَ ‏.‏ قَالَ مُسْلِمٌ أَبُو صَفْوَانَ هَذَا هُوَ عَبْدُ اللَّهِ بْنُ عَبْدِ الْمَلِكِ يَتِيمُ ابْنُ جُرَيْجٍ عَشْرَ سِنِينَ كَانَ فِي حَجْرِهِ ‏.‏\hadithno{3366}\hadithtrans{Salid b. Musayyib heard Abu Huraira (Allah be pleased with him) say that 'Allah's Messenger (ﷺ) said about Medina:Its inhabitants will abandon it, whereas it is good for them and it will become the haunt of beasts and birds. (Imam Muslim said that Abu Safwan, one of the narrators whose name was 'Abdullah b. 'Abd al-Malik, was an orphan and I bn juraij took him under his care for ten years)}}
\hadithdefcmd{muslim}{3367}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَتْرُكُونَ الْمَدِينَةَ عَلَى خَيْرِ مَا كَانَتْ لاَ يَغْشَاهَا إِلاَّ الْعَوَافِي - يُرِيدُ عَوَافِيَ السِّبَاعِ وَالطَّيْرِ - ثُمَّ يَخْرُجُ رَاعِيَانِ مِنْ مُزَيْنَةَ يُرِيدَانِ الْمَدِينَةَ يَنْعِقَانِ بِغَنَمِهِمَا فَيَجِدَانِهَا وَحْشًا حَتَّى إِذَا بَلَغَا ثَنِيَّةَ الْوَدَاعِ خَرَّا عَلَى وُجُوهِهِمَا ‏"‏ ‏.‏\hadithno{3367}\hadithtrans{Abu Huraira (Allah be pleased with him) heard Allah's Messenger (ﷺ) say:They (the residents of) Medina will abandon Medina whereas it is good for them and it will be haunted by beasts and birds, and two shepherds will come out from Muzainah intending (to go) towards Medina and tending their herd, and will find nothing but wilderness there until when they will reach the mountain path of Wada, they will fall down on their faces}}
\hadithdefcmd{muslim}{3368}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي، بَكْرٍ عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ الْمَازِنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{3368}\hadithtrans{AbduUah b. Zaid al-Mazini (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:That which is between my house" and my pulpit is a garden from the gardens of Paradise}}
\hadithdefcmd{muslim}{3369}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الْمَدَنِيُّ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ الأَنْصَارِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا بَيْنَ مِنْبَرِي وَبَيْتِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{3369}\hadithtrans{Abdullah b. Zaid al-Ansari heard Allah's Messenger (ﷺ) as saying:That which exists between my pulpit and my house is a garden from the gardens of Paradise}}
\hadithdefcmd{muslim}{3370}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ، اللَّهِ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ، بْنِ عَاصِمٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ وَمِنْبَرِي عَلَى حَوْضِي ‏"‏ ‏.‏\hadithno{3370}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:That which exists between my house and my pulpit is a garden from the gardens of Paradise, and my pulpit is upon my cistern}}
\hadithdefcmd{muslim}{3371}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ عَبَّاسِ بْنِ سَهْلٍ السَّاعِدِيِّ، عَنْ أَبِي حُمَيْدٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ ‏.‏ وَسَاقَ الْحَدِيثَ وَفِيهِ ثُمَّ أَقْبَلْنَا حَتَّى قَدِمْنَا وَادِيَ الْقُرَى فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي مُسْرِعٌ فَمَنْ شَاءَ مِنْكُمْ فَلْيُسْرِعْ مَعِي وَمَنْ شَاءَ فَلْيَمْكُثْ ‏"‏ ‏.‏ فَخَرَجْنَا حَتَّى أَشْرَفْنَا عَلَى الْمَدِينَةِ فَقَالَ ‏"‏ هَذِهِ طَابَةُ وَهَذَا أُحُدٌ وَهُوَ جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏ ‏.‏\hadithno{3371}\hadithtrans{Abu Humaid (Allah be pleased with him) reported:We went out along with Allah's Messenger (ﷺ) in the expedition of Tabuk, and Abu Humaid further related: We proceeded until we reached the valley of Qura; and Allah's Messenger (ﷺ) said: I am going forth, so he among you who wants to move fast with me may do so; and he who likes to go slowly may do so. We proceeded until Medina was within our sight, and he said: This is Tabah (another name of Medina); this is Uhud, the mountain which loves us and we love it}}
\hadithdefcmd{muslim}{3372}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ، بْنُ مَالِكٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أُحُدًا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏ ‏.‏\hadithno{3372}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported Allah's Messenger (way peace be upon him) as saying:Uhud is a mountain which loves us and which we love}}
\hadithdefcmd{muslim}{3373}{وَحَدَّثَنِيهِ عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنِي حَرَمِيُّ بْنُ عُمَارَةَ، حَدَّثَنَا قُرَّةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ نَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أُحُدٍ فَقَالَ ‏ "‏ إِنَّ أُحُدًا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏ ‏.‏\hadithno{3373}\hadithtrans{This hadith is narrated by Anas b. Malik (Allah be pleased with him) with another chain of transmitters (and the words are):" Allah's Messenger (ﷺ) cast a glance at Uhud and said: Uhud is a mountain which loves us and we love it}}
\hadithdefcmd{muslim}{3374}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِعَمْرٍو - قَالاَ حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ إِلاَّ الْمَسْجِدَ الْحَرَامَ‏"‏ ‏.‏\hadithno{3374}\hadithtrans{Abu Huraira (Allah be pleased with him) narrated It directly from Allah's Apostle' (ﷺ) having said this:A prayer in my mosque is a thousand times more excellent than a prayer in any other mosque, except Masjid al-Haram (Mosque of the Ka'ba)}}
\hadithdefcmd{muslim}{3375}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا خَيْرٌ مِنْ أَلْفِ صَلاَةٍ فِي غَيْرِهِ مِنَ الْمَسَاجِدِ إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏.‏\hadithno{3375}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Prayer in my mosque is more excellent than a thousand prayers observed in other mosques except the Masjid al- Haram}}
\hadithdefcmd{muslim}{3376}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عِيسَى بْنُ الْمُنْذِرِ الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ، حَرْبٍ حَدَّثَنَا الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَأَبِي عَبْدِ اللَّهِ الأَغَرِّ، مَوْلَى الْجُهَنِيِّينَ - وَكَانَ مِنْ أَصْحَابِ أَبِي هُرَيْرَةَ - أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ يَقُولُ صَلاَةٌ فِي مَسْجِدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ الْمَسْجِدَ الْحَرَامَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم آخِرُ الأَنْبِيَاءِ وَإِنَّ مَسْجِدَهُ آخِرُ الْمَسَاجِدِ ‏.‏ قَالَ أَبُو سَلَمَةَ وَأَبُو عَبْدِ اللَّهِ لَمْ نَشُكَّ أَنَّ أَبَا هُرَيْرَةَ كَانَ يَقُولُ عَنْ حَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَنَعَنَا ذَلِكَ أَنْ نَسْتَثْبِتَ أَبَا هُرَيْرَةَ عَنْ ذَلِكَ الْحَدِيثِ حَتَّى إِذَا تُوُفِّيَ أَبُو هُرَيْرَةَ تَذَاكَرْنَا ذَلِكَ وَتَلاَوَمْنَا أَنْ لاَ نَكُونَ كَلَّمْنَا أَبَا هُرَيْرَةَ فِي ذَلِكَ حَتَّى يُسْنِدَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم إِنْ كَانَ سَمِعَهُ مِنْهُ فَبَيْنَا نَحْنُ عَلَى ذَلِكَ جَالَسَنَا عَبْدُ اللَّهِ بْنُ إِبْرَاهِيمَ بْنِ قَارِظٍ فَذَكَرْنَا ذَلِكَ الْحَدِيثَ وَالَّذِي فَرَّطْنَا فِيهِ مِنْ نَصِّ أَبِي هُرَيْرَةَ عَنْهُ فَقَالَ لَنَا عَبْدُ اللَّهِ بْنُ إِبْرَاهِيمَ أَشْهَدُ أَنِّي سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَإِنِّي آخِرُ الأَنْبِيَاءِ وَإِنَّ مَسْجِدِي آخِرُ الْمَسَاجِدِ ‏"‏ ‏.‏\hadithno{3376}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:Prayer in the mosque of Allah's Messenger (ﷺ) is more excellent than a thousand prayers in other mosques except the Masjid al-Haram, for Allah's Messenger (ﷺ) is the last of the Apostles, and his mosque is the last of the mosques. Abu Salama and Abu Abdullah (two of the narrators in this chain of narrations said: We had no doubt that what Abu Haraira (Allah be pleased with him) had said was from Allah's Messenger (ﷺ), and so we did not like to get an attestation from Abu Huraira about this hadith until Abu Huraira (Allah be pleased with him) died. We discussed it (the issue of getting attestation from Abu Huraira) amongst ourselves and blamed one another as to why we did not talk about it to Abu Huraira regarding it so that he could attribute its transmission to Allah's Messenger (ﷺ) in case he had heard It from him. While we were discussing it as we sat with 'Abdullah b. Ibrahlm b. Qariz; we made a mention of this hadith, and our omission (in getting its attestation) about its direct transmission by Abu Huraira from him (the Holy Proohet) ; thereupon Abdullah b. Ibrahim said to us: I bear witness to the fact that I heard Abu Huraira (Allah be pleased with him) say that Allah's Messenger (ﷺ) said: I am the last of the Apostles and my mosque is the last of the mosques}}
\hadithdefcmd{muslim}{3377}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ الثَّقَفِيِّ، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الْوَهَّابِ، - قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ سَأَلْتُ أَبَا صَالِحٍ هَلْ سَمِعْتَ أَبَا هُرَيْرَةَ، يَذْكُرُ فَضْلَ الصَّلاَةِ فِي مَسْجِدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لاَ وَلَكِنْ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ إِبْرَاهِيمَ بْنِ قَارِظٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا خَيْرٌ مِنْ أَلْفِ صَلاَةٍ - أَوْ كَأَلْفِ صَلاَةٍ - فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ أَنْ يَكُونَ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏\hadithno{3377}\hadithtrans{Yahya b. Sa'id (Allah be pleased with him) reported:I said to Abu Salih: Did you hear Abu Huraira (Allah be pleased with him) making a mention of the excellence of prayer in the mosque of Allah's Messenger (ﷺ)? He said: No (I did not hear directly from Abu Huraira), but I heard Abdullah b. Ibrahlm b. Qariz; say that' he had heard from Abu Huraira (Allah be pleased with him) that Allah's Messenger (ﷺ) had said: Prayer in this mosque of mine is better than a thousand prayers. or. is like one thousand prayers observed in other mosques besides It, except that it be in al-Masjid al-Haram}}
\hadithdefcmd{muslim}{3378}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالُوا حَدَّثَنَا يَحْيَى، الْقَطَّانُ عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{3378}\hadithtrans{This hadith has been narrated by Yabya b. Sa'id with the same chain of transmitters}}
\hadithdefcmd{muslim}{3379}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏.‏\hadithno{3379}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:Prayer in this mosque of mine is better than a thousand prayers (observed in other mosque.) besides it, except that of Masjid al-Haram}}
\hadithdefcmd{muslim}{3380}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ ح وَحَدَّثَنَاهُ ابْنُ، نُمَيْرٍ حَدَّثَنَا أَبِي ح، وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{3380}\hadithtrans{A hadith like this has been narrated on the authority of Ubaidullah with the same chain of transmitters}}
\hadithdefcmd{muslim}{3381}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مُوسَى الْجُهَنِيِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِمِثْلِهِ ‏.‏\hadithno{3381}\hadithtrans{Ibn 'Umar reported:I heard Allah's Messenger (ﷺ) saying like this}}
\hadithdefcmd{muslim}{3382}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{3382}\hadithtrans{Ibn Umar narrated from Allah's Apostle (ﷺ) a hadlth like this}}
\hadithdefcmd{muslim}{3383}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، جَمِيعًا عَنِ اللَّيْثِ بْنِ سَعْدٍ، - قَالَ قُتَيْبَةُ حَدَّثَنَا لَيْثٌ، - عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ إِنَّ امْرَأَةً اشْتَكَتْ شَكْوَى فَقَالَتْ إِنْ شَفَانِي اللَّهُ لأَخْرُجَنَّ فَلأُصَلِّيَنَّ فِي بَيْتِ الْمَقْدِسِ ‏.‏ فَبَرَأَتْ ثُمَّ تَجَهَّزَتْ تُرِيدُ الْخُرُوجَ فَجَاءَتْ مَيْمُونَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم تُسَلِّمُ عَلَيْهَا فَأَخْبَرَتْهَا ذَلِكَ فَقَالَتِ اجْلِسِي فَكُلِي مَا صَنَعْتِ وَصَلِّي فِي مَسْجِدِ الرَّسُولِ صلى الله عليه وسلم فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ صَلاَةٌ فِيهِ أَفْضَلُ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ مَسْجِدَ الْكَعْبَةِ ‏"‏ ‏.‏\hadithno{3383}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that a woman fell ill and she said:In case Allah cures me I will certainly go and observe prayer in Bait al-Maqdis. She recovered and so she made preparations to go out (to that place). She came to Maimuna. the wife of Allah's Apostle (ﷺ). and after greeting her she informed her about it, whereupon she said: Stay here. and eat the provision (which you had made) and observe prayer In the mosque of the Messenger (ﷺ). for I heard Allah's Messenger (ﷺ) say: Prayer In it is better than a thousand prayers observed in other mosques except the mosque of the Ka'ba}}
\hadithdefcmd{muslim}{3384}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ، - عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ لاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِي هَذَا وَمَسْجِدِ الْحَرَامِ وَمَسْجِدِ الأَقْصَى ‏"‏ ‏.‏\hadithno{3384}\hadithtrans{Abu Hurairah (Allah be pleased with him) reported it directly from Allah's Apostle (ﷺ) that he said:Do not undertake a journey to visit any Mosque, but three: this Mosque of mine, the Mosque of al-Haram and the Mosque of Aqsa (Bait al-Maqdis)}}
\hadithdefcmd{muslim}{3385}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ تُشَدُّ الرِّحَالُ إِلَى ثَلاَثَةِ مَسَاجِدَ ‏"‏ ‏.‏\hadithno{3385}\hadithtrans{This hadith has been narrated on the authority of Zuhri (but with this change of words) that he (Allah's Apostle) said:" Undertake journey to three mosques}}
\hadithdefcmd{muslim}{3386}{وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، أَنَّ عِمْرَانَ بْنَ أَبِي أَنَسٍ، حَدَّثَهُ أَنَّ سَلْمَانَ الأَغَرَّ حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يُخْبِرُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا يُسَافَرُ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِ الْكَعْبَةِ وَمَسْجِدِي وَمَسْجِدِ إِيلِيَاءَ ‏"‏ ‏.‏\hadithno{3386}\hadithtrans{Abu Haraira (Allah be pleased with him) reported Allah's Messenger (way peace be upon him) as saying:One should undertake journey to three mosques: the mosque of the Ka'ba, my mosque, and the mosque of Elia (Bait al-Maqdis)}}
\hadithdefcmd{muslim}{3387}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حُمَيْدٍ الْخَرَّاطِ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، قَالَ مَرَّ بِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَ قُلْتُ لَهُ كَيْفَ سَمِعْتَ أَبَاكَ يَذْكُرُ فِي الْمَسْجِدِ الَّذِي أُسِّسَ عَلَى التَّقْوَى قَالَ قَالَ أَبِي دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَيْتِ بَعْضِ نِسَائِهِ فَقُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الْمَسْجِدَيْنِ الَّذِي أُسِّسَ عَلَى التَّقْوَى قَالَ فَأَخَذَ كَفًّا مِنْ حَصْبَاءَ فَضَرَبَ بِهِ الأَرْضَ ثُمَّ قَالَ ‏ "‏ هُوَ مَسْجِدُكُمْ هَذَا ‏"‏ ‏.‏ - لِمَسْجِدِ الْمَدِينَةِ - قَالَ فَقُلْتُ أَشْهَدُ أَنِّي سَمِعْتُ أَبَاكَ هَكَذَا يَذْكُرُهُ ‏\hadithno{3387}\hadithtrans{Abu Salama b. Abd al-Rabman reported:'Abd al-Rabman b. Abu Sa'id al-Khudri (Allah be pleased with him) happened to pass by me and I said to him. How did you hear your father making mention of the mosque founded on Piety? He said: My father said: I went to Allah's Messenger (ﷺ) as he was in the house of one of his wives, and said: Messenger of Allah, which of the two mosques is founded on piety? Thereupon he took a handful of pebbles and threw them on the ground and then said: This is the very mosque of yours (mosque at Medina). He (the narrator) said: I bear witness that I heard your father making mention of it}}
\hadithdefcmd{muslim}{3388}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَسَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، قَالَ سَعِيدٌ أَخْبَرَنَا وَقَالَ أَبُو بَكْرٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ حُمَيْدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ وَلَمْ يَذْكُرْ عَبْدَ الرَّحْمَنِ بْنَ أَبِي سَعِيدٍ فِي الإِسْنَادِ ‏.‏\hadithno{3388}\hadithtrans{Abu Sa'id reported from Allah's Apostle (ﷺ) a hadlth like this, but in the chain of transmitters no mention was made of Abd al- Rahman b. Abu Sa'id}}
\hadithdefcmd{muslim}{3389}{حَدَّثَنَا أَبُو جَعْفَرٍ، أَحْمَدُ بْنُ مَنِيعٍ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَزُورُ قُبَاءً رَاكِبًا وَمَاشِيًا‏.‏\hadithno{3389}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) visited (the mosque) at Quba' riding and on foot}}
\hadithdefcmd{muslim}{3390}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ، اللَّهِ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ، عُمَرَ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْتِي مَسْجِدَ قُبَاءٍ رَاكِبًا وَمَاشِيًا فَيُصَلِّي فِيهِ رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو بَكْرٍ فِي رِوَايَتِهِ قَالَ ابْنُ نُمَيْرٍ فَيُصَلِّي فِيهِ رَكْعَتَيْنِ ‏\hadithno{3390}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) came to the mosque at Quba' riding and on foot, and he observed two rak'ahs of (Nafl prayer) in it}}
\hadithdefcmd{muslim}{3391}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا عُبَيْدُ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ، عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْتِي قُبَاءً رَاكِبًا وَمَاشِيًا ‏.‏\hadithno{3391}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) came to Quba' riding as well as on foot}}
\hadithdefcmd{muslim}{3392}{وَحَدَّثَنِي أَبُو مَعْنٍ الرَّقَاشِيُّ، زَيْدُ بْنُ يَزِيدَ الثَّقَفِيُّ - بَصْرِيٌّ ثِقَةٌ - حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - عَنِ ابْنِ عَجْلاَنَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ يَحْيَى الْقَطَّانِ ‏\hadithno{3392}\hadithtrans{This hadith has been reported on the authority of Ibn Umar (Allah be pleased with them) with another chain of transmitters}}
\hadithdefcmd{muslim}{3393}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ، اللَّهِ بْنِ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْتِي قُبَاءً رَاكِبًا وَمَاشِيًا ‏.‏\hadithno{3393}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) used to come to Quba' riding and on foot}}
\hadithdefcmd{muslim}{3394}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ، جَعْفَرٍ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْتِي قُبَاءً رَاكِبًا وَمَاشِيًا ‏.‏\hadithno{3394}\hadithtrans{Ibn 'Umar had narrated this hadith through another chain of transmitters}}
\hadithdefcmd{muslim}{3395}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّ ابْنَ، عُمَرَ كَانَ يَأْتِي قُبَاءً كُلَّ سَبْتٍ وَكَانَ يَقُولُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَأْتِيهِ كُلَّ سَبْتٍ ‏.‏\hadithno{3395}\hadithtrans{Ibn Umar used to come to Quba' on every Saturday and he said:I saw Allah's Apostle (ﷺ) coming (to this place) on every Saturday}}
\hadithdefcmd{muslim}{3396}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ، عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْتِي قُبَاءً يَعْنِي كُلَّ سَبْتٍ كَانَ يَأْتِيهِ رَاكِبًا وَمَاشِيًا ‏.‏ قَالَ ابْنُ دِينَارٍ وَكَانَ ابْنُ عُمَرَ يَفْعَلُهُ ‏.‏\hadithno{3396}\hadithtrans{Abdullah b. 'Umar reported that Allah's Messenger (ﷺ) used to come to Quba', i. e. (he came) on every Saturday, and he used to come riding or on foot. Ibn Dinar (another narrator) said that Ibn Umar used to do like this}}
\hadithdefcmd{muslim}{3397}{وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ هَاشِمٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ ابْنِ دِينَارٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَذْكُرْ كُلَّ سَبْتٍ ‏.‏\hadithno{3397}\hadithtrans{This hadlth has been narrated on the authority of Ibn Dinar, but he made no mention of:" Every Saturday}}
