% Auto-generated chapter 65 for bukhari
% Hadiths in this chapter: 499

\hadithdefcmd{bukhari}{4474}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى، قَالَ كُنْتُ أُصَلِّي فِي الْمَسْجِدِ فَدَعَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ أُجِبْهُ، فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ أُصَلِّي‏.‏ فَقَالَ ‏"‏ أَلَمْ يَقُلِ اللَّهُ ‏\{‏اسْتَجِيبُوا لِلَّهِ وَلِلرَّسُولِ إِذَا دَعَاكُمْ‏\}‏ ثُمَّ قَالَ لِي لأُعَلِّمَنَّكَ سُورَةً هِيَ أَعْظَمُ السُّوَرِ فِي الْقُرْآنِ قَبْلَ أَنْ تَخْرُجَ مِنَ الْمَسْجِدِ ‏"‏‏.‏ ثُمَّ أَخَذَ بِيَدِي، فَلَمَّا أَرَادَ أَنْ يَخْرُجَ قُلْتُ لَهُ أَلَمْ تَقُلْ ‏"‏ لأُعَلِّمَنَّكَ سُورَةً هِيَ أَعْظَمُ سُورَةٍ فِي الْقُرْآنِ ‏"‏‏.‏ قَالَ ‏"‏ ‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ هِيَ السَّبْعُ الْمَثَانِي وَالْقُرْآنُ الْعَظِيمُ الَّذِي أُوتِيتُهُ ‏"‏‏.‏\hadithno{4474}\hadithtrans{Narrated Abu Sa`id bin Al-Mu'alla:While I was praying in the Mosque, Allah's Messenger (ﷺ) called me but I did not respond to him. Later I said, "O Allah's Messenger (ﷺ)! I was praying." He said, "Didn't Allah say'--"Give your response to Allah (by obeying Him) and to His Apostle when he calls you." (8.24) He then said to me, "I will teach you a Sura which is the greatest Sura in the Qur'an, before you leave the Mosque." Then he got hold of my hand, and when he intended to leave (the Mosque), I said to him, "Didn't you say to me, 'I will teach you a Sura which is the greatest Sura in the Qur'an?' He said, "Al-Hamdu-Li l-lah Rabbi-l-`alamin (i.e. Praise be to Allah, the Lord of the worlds) which is Al-Sab'a Al-Mathani (i.e. seven repeatedly recited Verses) and the Grand Qur'an which has been given to me}}
\hadithdefcmd{bukhari}{4475}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا قَالَ الإِمَامُ ‏\{‏غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ‏\}‏ فَقُولُوا آمِينَ‏.‏ فَمَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{4475}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the Imam says: 'Ghair-il-Maghdubi `alaihim Walad-Dallin (i.e. not the path of those who earn Your Anger, nor the path of those who went astray (1.7)), then you must say, 'Ameen', for if one's utterance of 'Ameen' coincides with that of the angels, then his past sins will be forgiven}}
\hadithdefcmd{bukhari}{4476}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ حَدَّثَنَا سَعِيدٌ عَنْ قَتَادَةَ عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يَجْتَمِعُ الْمُؤْمِنُونَ يَوْمَ الْقِيَامَةِ فَيَقُولُونَ لَوِ اسْتَشْفَعْنَا إِلَى رَبِّنَا فَيَأْتُونَ آدَمَ فَيَقُولُونَ أَنْتَ أَبُو النَّاسِ، خَلَقَكَ اللَّهُ بِيَدِهِ وَأَسْجَدَ لَكَ مَلاَئِكَتَهُ، وَعَلَّمَكَ أَسْمَاءَ كُلِّ شَىْءٍ، فَاشْفَعْ لَنَا عِنْدَ رَبِّكَ حَتَّى يُرِيحَنَا مِنْ مَكَانِنَا هَذَا‏.‏ فَيَقُولُ لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ ذَنْبَهُ فَيَسْتَحِي ـ ائْتُوا نُوحًا فَإِنَّهُ أَوَّلُ رَسُولٍ بَعَثَهُ اللَّهُ إِلَى أَهْلِ الأَرْضِ‏.‏ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ‏.‏ وَيَذْكُرُ سُؤَالَهُ رَبَّهُ مَا لَيْسَ لَهُ بِهِ عِلْمٌ فَيَسْتَحِي، فَيَقُولُ ائْتُوا خَلِيلَ الرَّحْمَنِ‏.‏ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ، ائْتُوا مُوسَى عَبْدًا كَلَّمَهُ اللَّهُ وَأَعْطَاهُ التَّوْرَاةَ‏.‏ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ‏.‏ وَيَذْكُرُ قَتْلَ النَّفْسِ بِغَيْرِ نَفْسٍ فَيَسْتَحِي مِنْ رَبِّهِ فَيَقُولُ ائْتُوا عِيسَى عَبْدَ اللَّهِ وَرَسُولَهُ، وَكَلِمَةَ اللَّهِ وَرُوحَهُ‏.‏ فَيَقُولُ لَسْتُ هُنَاكُمْ، ائْتُوا مُحَمَّدًا صلى الله عليه وسلم عَبْدًا غَفَرَ اللَّهُ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ‏.‏ فَيَأْتُونِي فَأَنْطَلِقُ حَتَّى أَسْتَأْذِنَ عَلَى رَبِّي فَيُؤْذَنُ ‏\{‏لِي‏\}‏ فَإِذَا رَأَيْتُ رَبِّي وَقَعْتُ سَاجِدًا، فَيَدَعُنِي مَا شَاءَ اللَّهُ ثُمَّ يُقَالُ ارْفَعْ رَأْسَكَ، وَسَلْ تُعْطَهْ، وَقُلْ يُسْمَعْ، وَاشْفَعْ تُشَفَّعْ‏.‏ فَأَرْفَعُ رَأْسِي فَأَحْمَدُهُ بِتَحْمِيدٍ يُعَلِّمُنِيهِ، ثُمَّ أَشْفَعُ، فَيَحُدُّ لِي حَدًّا، فَأُدْخِلُهُمُ الْجَنَّةَ، ثُمَّ أَعُودُ إِلَيْهِ، فَإِذَا رَأَيْتُ رَبِّي ـ مِثْلَهُ ـ ثُمَّ أَشْفَعُ، فَيَحُدُّ لِي حَدًّا، فَأُدْخِلُهُمُ الْجَنَّةَ ‏\{‏ثُمَّ أَعُودُ الثَّالِثَةَ‏\}‏ ثُمَّ أَعُودُ الرَّابِعَةَ فَأَقُولُ مَا بَقِيَ فِي النَّارِ إِلاَّ مَنْ حَبَسَهُ الْقُرْآنُ وَوَجَبَ عَلَيْهِ الْخُلُودُ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ ‏"‏ إِلاَّ مَنْ حَبَسَهُ الْقُرْآنُ ‏"‏‏.‏ يَعْنِي قَوْلَ اللَّهِ تَعَالَى ‏\{‏خَالِدِينَ فِيهَا‏\}‏‏.‏\hadithno{4476}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "On the Day of Resurrection the Believers will assemble and say, 'Let us ask somebody to intercede for us with our Lord.' So they will go to Adam and say, 'You are the father of all the people, and Allah created you with His Own Hands, and ordered the angels to prostrate to you, and taught you the names of all things; so please intercede for us with your Lord, so that He may relieve us from this place of ours.' Adam will say, 'I am not fit for this (i.e. intercession for you).' Then Adam will remember his sin and feel ashamed thereof. He will say, 'Go to Noah, for he was the first Apostle, Allah sent to the inhabitants of the earth.' They will go to him and Noah will say, 'I am not fit for this undertaking.' He will remember his appeal to his Lord to do what he had no knowledge of, then he will feel ashamed thereof and will say, 'Go to the Khalil-ur-Rahman (i.e. Abraham).' They will go to him and he will say, 'I am not fit for this undertaking. Go to Moses, the slave to whom Allah spoke (directly) and gave him the Torah .' So they will go to him and he will say, 'I am not fit for this undertaking.' and he will mention (his) killing a person who was not a killer, and so he will feel ashamed thereof before his Lord, and he will say, 'Go to Jesus, Allah's Slave, His Apostle and Allah's Word and a Spirit coming from Him. Jesus will say, 'I am not fit for this undertaking, go to Muhammad the Slave of Allah whose past and future sins were forgiven by Allah.' So they will come to me and I will proceed till I will ask my Lord's Permission and I will be given permission. When I see my Lord, I will fall down in Prostration and He will let me remain in that state as long as He wishes and then I will be addressed.' (Muhammad!) Raise your head. Ask, and your request will be granted; say, and your saying will be listened to; intercede, and your intercession will be accepted.' I will raise my head and praise Allah with a saying (i.e. invocation) He will teach me, and then I will intercede. He will fix a limit for me (to intercede for) whom I will admit into Paradise. Then I will come back again to Allah, and when I see my Lord, the same thing will happen to me. And then I will intercede and Allah will fix a limit for me to intercede whom I will let into Paradise, then I will come back for the third time; and then I will come back for the fourth time, and will say, 'None remains in Hell but those whom the Qur'an has imprisoned (in Hell) and who have been destined to an eternal stay in Hell.' " (The compiler) Abu `Abdullah said: 'But those whom the Qur'an has imprisoned in Hell,' refers to the Statement of Allah: "They will dwell therein forever}}
\hadithdefcmd{bukhari}{4477}{حَدَّثَنِي عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ عَبْدِ اللَّهِ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم أَىُّ الذَّنْبِ أَعْظَمُ عِنْدَ اللَّهِ قَالَ ‏"‏ أَنْ تَجْعَلَ لِلَّهِ نِدًّا وَهْوَ خَلَقَكَ ‏"‏‏.‏ قُلْتُ إِنَّ ذَلِكَ لَعَظِيمٌ، قُلْتُ ثُمَّ أَىُّ قَالَ ‏"‏ وَأَنْ تَقْتُلَ وَلَدَكَ تَخَافُ أَنْ يَطْعَمَ مَعَكَ ‏"‏‏.‏ قُلْتُ ثُمَّ أَىُّ قَالَ ‏"‏ أَنْ تُزَانِيَ حَلِيلَةَ جَارِكَ ‏"‏‏.‏\hadithno{4477}\hadithtrans{Narrated `Abdullah:I asked the Prophet, "What is the greatest sin in the Sight of Allah?" He said, "That you set up a rival unto Allah though He Alone created you." I said, "That is indeed a great sin." Then asked, "What is next?" He said, "To kill your son lest he should share your food with you." I asked, "What is next?" He said, "To commit illegal sexual intercourse with the wife of your neighbor}}
\hadithdefcmd{bukhari}{4478}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَمْرِو بْنِ حُرَيْثٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْكَمْأَةُ مِنَ الْمَنِّ، وَمَاؤُهَا شِفَاءٌ لِلْعَيْنِ ‏"‏‏.‏\hadithno{4478}\hadithtrans{Narrated Sa`id bin Zaid:Allah's Messenger (ﷺ) said, "The Kam'a (i.e. a kind of edible fungus) is like the Manna (in that it is obtained without effort) and its water is a (medicine) cure for eye trouble}}
\hadithdefcmd{bukhari}{4479}{حَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ قِيلَ لِبَنِي إِسْرَائِيلَ ‏\{‏ادْخُلُوا الْبَابَ سُجَّدًا وَقُولُوا حِطَّةٌ‏\}‏ فَدَخَلُوا يَزْحَفُونَ عَلَى أَسْتَاهِهِمْ، فَبَدَّلُوا وَقَالُوا حِطَّةٌ، حَبَّةٌ فِي شَعَرَةٍ ‏"‏‏.‏\hadithno{4479}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "It was said to the children of Israel, 'Enter the gate (of the town), prostrate (in humility) and say: Hittatun (i.e. repentance) i.e. O Allah! Forgive our sins.' But they entered by dragging themselves on their buttocks, so they did something different (from what they had been ordered to do) and said, 'Hittatun,' but added, "A grain in a hair}}
\hadithdefcmd{bukhari}{4480}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ عَبْدَ اللَّهِ بْنَ بَكْرٍ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ سَمِعَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ، بِقُدُومِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي أَرْضٍ يَخْتَرِفُ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنِّي سَائِلُكَ عَنْ ثَلاَثٍ لاَ يَعْلَمُهُنَّ إِلاَّ نَبِيٌّ فَمَا أَوَّلُ أَشْرَاطِ السَّاعَةِ وَمَا أَوَّلُ طَعَامِ أَهْلِ الْجَنَّةِ وَمَا يَنْزِعُ الْوَلَدُ إِلَى أَبِيهِ أَوْ إِلَى أُمِّهِ قَالَ ‏"‏ أَخْبَرَنِي بِهِنَّ جِبْرِيلُ آنِفًا ‏"‏‏.‏ قَالَ جِبْرِيلُ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قَالَ ذَاكَ عَدُوُّ الْيَهُودِ مِنَ الْمَلاَئِكَةِ‏.‏ فَقَرَأَ هَذِهِ الآيَةَ ‏\{‏مَنْ كَانَ عَدُوًّا لِجِبْرِيلَ فَإِنَّهُ نَزَّلَهُ عَلَى قَلْبِكَ‏\}‏ أَمَّا أَوَّلُ أَشْرَاطِ السَّاعَةِ فَنَارٌ تَحْشُرُ النَّاسَ مِنَ الْمَشْرِقِ إِلَى الْمَغْرِبِ، وَأَمَّا أَوَّلُ طَعَامِ أَهْلِ الْجَنَّةِ فَزِيَادَةُ كَبِدِ حُوتٍ، وَإِذَا سَبَقَ مَاءُ الرَّجُلِ مَاءَ الْمَرْأَةِ نَزَعَ الْوَلَدَ، وَإِذَا سَبَقَ مَاءُ الْمَرْأَةِ نَزَعَتْ ‏"‏‏.‏ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَشْهَدُ أَنَّكَ رَسُولُ اللَّهِ‏.‏ يَا رَسُولَ اللَّهِ إِنَّ الْيَهُودَ قَوْمٌ بُهُتٌ، وَإِنَّهُمْ إِنْ يَعْلَمُوا بِإِسْلاَمِي قَبْلَ أَنْ تَسْأَلَهُمْ يَبْهَتُونِي‏.‏ فَجَاءَتِ الْيَهُودُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَىُّ رَجُلٍ عَبْدُ اللَّهِ فِيكُمْ ‏"‏‏.‏ قَالُوا خَيْرُنَا وَابْنُ خَيْرِنَا، وَسَيِّدُنَا وَابْنُ سَيِّدِنَا‏.‏ قَالَ ‏"‏ أَرَأَيْتُمْ إِنْ أَسْلَمَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ‏"‏‏.‏ فَقَالُوا أَعَاذَهُ اللَّهُ مِنْ ذَلِكَ‏.‏ فَخَرَجَ عَبْدُ اللَّهِ فَقَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ‏.‏ فَقَالُوا شَرُّنَا وَابْنُ شَرِّنَا‏.‏ وَانْتَقَصُوهُ‏.‏ قَالَ فَهَذَا الَّذِي كُنْتُ أَخَافُ يَا رَسُولَ اللَّهِ‏.‏\hadithno{4480}\hadithtrans{Narrated Anas:`Abdullah bin Salam heard the news of the arrival of Allah's Messenger (ﷺ) (at Medina) while he was on a farm collecting its fruits. So he came to the Prophet (ﷺ) and said, "I will ask you about three things which nobody knows unless he be a prophet. Firstly, what is the first portent of the Hour? What is the first meal of the people of Paradise? And what makes a baby look like its father or mother?'. The Prophet (ﷺ) said, "Just now Gabriel has informed me about that." `Abdullah said, "Gabriel?" The Prophet (ﷺ) said, "Yes." `Abdullah said, "He, among the angels is the enemy of the Jews." On that the Prophet (ﷺ) recited this Holy Verse:-- "Whoever is an enemy to Gabriel (let him die in his fury!) for he has brought it (i.e. Qur'an) down to your heart by Allah's permission." (2.97) Then he added, "As for the first portent of the Hour, it will be a fire that will collect the people from the East to West. And as for the first meal of the people of Paradise, it will be the caudate (i.e. extra) lobe of the fish liver. And if a man's discharge preceded that of the woman, then the child resembles the father, and if the woman's discharge preceded that of the man, then the child resembles the mother." On hearing that, `Abdullah said, "I testify that None has the right to be worshipped but Allah, and that you are the Messenger of Allah. O Allah's Messenger (ﷺ); the Jews are liars, and if they should come to know that I have embraced Islam, they would accuse me of being a liar." In the meantime some Jews came (to the Prophet) and he asked them, "What is `Abdullah's status amongst you?" They replied, "He is the best amongst us, and he is our chief and the son of our chief." The Prophet (ﷺ) said, "What would you think if `Abdullah bin Salam embraced Islam?" They replied, "May Allah protect him from this!" Then `Abdullah came out and said, "I testify that None has the right to be worshipped but Allah and that Muhammad is the Messenger of Allah." The Jews then said, "Abdullah is the worst of us and the son of the worst of us," and disparaged him. On that `Abdullah said, "O Allah's Messenger (ﷺ)! This is what I was afraid of}}
\hadithdefcmd{bukhari}{4481}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ عُمَرُ ـ رضى الله عنه ـ أَقْرَؤُنَا أُبَىٌّ، وَأَقْضَانَا عَلِيٌّ، وَإِنَّا لَنَدَعُ مِنْ قَوْلِ أُبَىٍّ، وَذَاكَ أَنَّ أُبَيًّا يَقُولُ لاَ أَدَعُ شَيْئًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ قَالَ اللَّهُ تَعَالَى ‏\{‏مَا نَنْسَخْ مِنْ آيَةٍ أَوْ نَنْسَأْهَا‏\}‏\hadithno{4481}\hadithtrans{Narrated Ibn `Abbas:`Umar said, "Our best Qur'an reciter is Ubai and our best judge is `Ali; and in spite of this, we leave some of the statements of Ubai because Ubai says, 'I do not leave anything that I have heard from Allah's Messenger (ﷺ) while Allah said: "Whatever verse (Revelations) do We abrogate or cause to be forgotten but We bring a better one or similar to it}}
\hadithdefcmd{bukhari}{4482}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنَا نَافِعُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ كَذَّبَنِي ابْنُ آدَمَ وَلَمْ يَكُنْ لَهُ ذَلِكَ، وَشَتَمَنِي وَلَمْ يَكُنْ لَهُ ذَلِكَ، فَأَمَّا تَكْذِيبُهُ إِيَّاىَ فَزَعَمَ أَنِّي لاَ أَقْدِرُ أَنْ أُعِيدَهُ كَمَا كَانَ، وَأَمَّا شَتْمُهُ إِيَّاىَ فَقَوْلُهُ لِي وَلَدٌ، فَسُبْحَانِي أَنْ أَتَّخِذَ صَاحِبَةً أَوْ وَلَدًا ‏"‏‏.‏\hadithno{4482}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Allah said, 'The son of Adam tells a lie against Me though he has no right to do so, and he abuses Me though he has no right to do so. As for his telling a lie against Me, it is that he claims that I cannot recreate him as I created him before; and as for his abusing Me, it is his statement that I have offspring. No! Glorified be Me! I am far from taking a wife or offspring}}
\hadithdefcmd{bukhari}{4483}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ عُمَرُ وَافَقْتُ اللَّهَ فِي ثَلاَثٍ ـ أَوْ وَافَقَنِي رَبِّي فِي ثَلاَثٍ ـ قُلْتُ يَا رَسُولَ اللَّهِ، لَوِ اتَّخَذْتَ مَقَامَ إِبْرَاهِيمَ مُصَلًّى وَقُلْتُ يَا رَسُولَ اللَّهِ يَدْخُلُ عَلَيْكَ الْبَرُّ وَالْفَاجِرُ، فَلَوْ أَمَرْتَ أُمَّهَاتِ الْمُؤْمِنِينَ بِالْحِجَابِ فَأَنْزَلَ اللَّهُ آيَةَ الْحِجَابِ قَالَ وَبَلَغَنِي مُعَاتَبَةُ النَّبِيِّ صلى الله عليه وسلم بَعْضَ نِسَائِهِ، فَدَخَلْتُ عَلَيْهِنَّ قُلْتُ إِنِ انْتَهَيْتُنَّ أَوْ لَيُبَدِّلَنَّ اللَّهُ رَسُولَهُ صلى الله عليه وسلم خَيْرًا مِنْكُنَّ‏.‏ حَتَّى أَتَيْتُ إِحْدَى نِسَائِهِ، قَالَتْ يَا عُمَرُ، أَمَا فِي رَسُولِ اللَّهِ صلى الله عليه وسلم مَا يَعِظُ نِسَاءَهُ حَتَّى تَعِظَهُنَّ أَنْتَ فَأَنْزَلَ اللَّهُ ‏\{‏عَسَى رَبُّهُ إِنْ طَلَّقَكُنَّ أَنْ يُبَدِّلَهُ أَزْوَاجًا خَيْرًا مِنْكُنَّ مُسْلِمَاتٍ‏\}‏ الآيَةَ‏.‏ وَقَالَ ابْنُ أَبِي مَرْيَمَ أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ حَدَّثَنِي حُمَيْدٌ سَمِعْتُ أَنَسًا عَنْ عُمَرَ\hadithno{4483}\hadithtrans{Narrated Anas:`Umar said, "I agreed with Allah in three things," or said, "My Lord agreed with me in three things. I said, 'O Allah's Messenger (ﷺ)! Would that you took the station of Abraham as a place of prayer.' I also said, 'O Allah's Messenger (ﷺ)! Good and bad persons visit you! Would that you ordered the Mothers of the believers to cover themselves with veils.' So the Divine Verses of Al-Hijab (i.e. veiling of the women) were revealed. I came to know that the Prophet (ﷺ) had blamed some of his wives so I entered upon them and said, 'You should either stop (troubling the Prophet (ﷺ) ) or else Allah will give His Apostle better wives than you.' When I came to one of his wives, she said to me, 'O `Umar! Does Allah's Messenger (ﷺ) haven't what he could advise his wives with, that you try to advise them?' " Thereupon Allah revealed:-- "It may be, if he divorced you (all) his Lord will give him instead of you, wives better than you Muslims (who submit to Allah)}}
\hadithdefcmd{bukhari}{4484}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، أَخْبَرَ عَبْدَ اللَّهِ بْنَ عُمَرَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلَمْ تَرَىْ أَنَّ قَوْمَكِ بَنَوُا الْكَعْبَةَ وَاقْتَصَرُوا عَنْ قَوَاعِدِ إِبْرَاهِيمَ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ أَلاَ تَرُدُّهَا عَلَى قَوَاعِدِ إِبْرَاهِيمَ قَالَ ‏"‏ لَوْلاَ حِدْثَانُ قَوْمِكِ بِالْكُفْرِ ‏"‏‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لَئِنْ كَانَتْ عَائِشَةُ سَمِعَتْ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أُرَى رَسُولَ اللَّهِ صلى الله عليه وسلم تَرَكَ اسْتِلاَمَ الرُّكْنَيْنِ اللَّذَيْنِ يَلِيَانِ الْحِجْرَ، إِلاَّ أَنَّ الْبَيْتَ لَمْ يُتَمَّمْ عَلَى قَوَاعِدِ إِبْرَاهِيمَ‏.‏\hadithno{4484}\hadithtrans{Narrated `Aisha:(The wife of the Prophet) Allah's Messenger (ﷺ) said, "Don't you see that when your people built the Ka`ba, they did not build it on all Abraham's foundations?" I said, "O Allah's Messenger (ﷺ)! Why don't you rebuild it on Abraham's foundations?" He said, "Were your people not so close to (the period of Heathenism, i.e. the Period between their being Muslims and being infidels), I would do so." The sub-narrator, `Abdullah bin `Umar said, "Aisha had surely heard Allah's Messenger (ﷺ) saying that, for I do not think that Allah's Messenger (ﷺ) left touching the two corners of the Ka`ba facing Al-Hijr except because the Ka`ba was not built on all Abraham's foundations}}
\hadithdefcmd{bukhari}{4485}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ أَهْلُ الْكِتَابِ يَقْرَءُونَ التَّوْرَاةَ بِالْعِبْرَانِيَّةِ، وَيُفَسِّرُونَهَا بِالْعَرَبِيَّةِ لأَهْلِ الإِسْلاَمِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُصَدِّقُوا أَهْلَ الْكِتَابِ وَلاَ تُكَذِّبُوهُمْ، وَقُولُوا ‏\{‏آمَنَّا بِاللَّهِ وَمَا أُنْزِلَ‏\}‏ الآيَةَ‏"‏‏.‏\hadithno{4485}\hadithtrans{Narrated Abu Huraira:The people of the Scripture (Jews) used to recite the Torah in Hebrew and they used to explain it in Arabic to the Muslims. On that Allah's Messenger (ﷺ) said, "Do not believe the people of the Scripture or disbelieve them, but say:-- "We believe in Allah and what is revealed to us}}
\hadithdefcmd{bukhari}{4486}{حَدَّثَنَا أَبُو نُعَيْمٍ، سَمِعَ زُهَيْرًا، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى إِلَى بَيْتِ الْمَقْدِسِ سِتَّةَ عَشَرَ شَهْرًا أَوْ سَبْعَةَ عَشَرَ شَهْرًا، وَكَانَ يُعْجِبُهُ أَنْ تَكُونَ قِبْلَتُهُ قِبَلَ الْبَيْتِ، وَإِنَّهُ صَلَّى ـ أَوْ صَلاَّهَا ـ صَلاَةَ الْعَصْرِ، وَصَلَّى مَعَهُ قَوْمٌ، فَخَرَجَ رَجُلٌ مِمَّنْ كَانَ صَلَّى مَعَهُ، فَمَرَّ عَلَى أَهْلِ الْمَسْجِدِ وَهُمْ رَاكِعُونَ قَالَ أَشْهَدُ بِاللَّهِ لَقَدْ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم قِبَلَ مَكَّةَ، فَدَارُوا كَمَا هُمْ قِبَلَ الْبَيْتِ، وَكَانَ الَّذِي مَاتَ عَلَى الْقِبْلَةِ قَبْلَ أَنْ تُحَوَّلَ قِبَلَ الْبَيْتِ رِجَالٌ قُتِلُوا لَمْ نَدْرِ مَا نَقُولُ فِيهِمْ، فَأَنْزَلَ اللَّهُ ‏\{‏وَمَا كَانَ اللَّهُ لِيُضِيعَ إِيمَانَكُمْ إِنَّ اللَّهَ بِالنَّاسِ لَرَءُوفٌ رَحِيمٌ ‏\}‏\hadithno{4486}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) prayed facing Bait-ulMaqdis (i.e. Jerusalem) for sixteen or seventeen months but he wished that his Qibla would be the Ka`ba (at Mecca). (So Allah Revealed (2.144) and he offered `Asr prayers(in his Mosque facing Ka`ba at Mecca) and some people prayed with him. A man from among those who had prayed with him, went out and passed by some people offering prayer in another mosque, and they were in the state of bowing. He said, "I, (swearing by Allah,) testify that I have prayed with the Prophet (ﷺ) facing Mecca." Hearing that, they turned their faces to the Ka`ba while they were still bowing. Some men had died before the Qibla was changed towards the Ka`ba. They had been killed and we did not know what to say about them (i.e. whether their prayers towards Jerusalem were accepted or not). So Allah revealed:-- "And Allah would never make your faith (i.e. prayer) to be lost (i.e. your prayers offered (towards Jerusalem). Truly Allah is Full of Pity, Most Merciful towards mankind}}
\hadithdefcmd{bukhari}{4487}{حَدَّثَنَا يُوسُفُ بْنُ رَاشِدٍ، حَدَّثَنَا جَرِيرٌ، وَأَبُو أُسَامَةَ ـ وَاللَّفْظُ لِجَرِيرٍ ـ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، وَقَالَ أَبُو أُسَامَةَ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُدْعَى نُوحٌ يَوْمَ الْقِيَامَةِ فَيَقُولُ لَبَّيْكَ وَسَعْدَيْكَ يَا رَبِّ‏.‏ فَيَقُولُ هَلْ بَلَّغْتَ فَيَقُولُ نَعَمْ‏.‏ فَيُقَالُ لأُمَّتِهِ هَلْ بَلَّغَكُمْ فَيَقُولُونَ مَا أَتَانَا مِنْ نَذِيرٍ‏.‏ فَيَقُولُ مَنْ يَشْهَدُ لَكَ فَيَقُولُ مُحَمَّدٌ وَأُمَّتُهُ‏.‏ فَتَشْهَدُونَ أَنَّهُ قَدْ بَلَّغَ ‏"‏‏.‏ ‏\{‏وَيَكُونَ الرَّسُولُ عَلَيْكُمْ شَهِيدًا‏\}‏ فَذَلِكَ قَوْلُهُ جَلَّ ذِكْرُهُ ‏\{‏وَكَذَلِكَ جَعَلْنَاكُمْ أُمَّةً وَسَطًا لِتَكُونُوا شُهَدَاءَ عَلَى النَّاسِ وَيَكُونَ الرَّسُولُ عَلَيْكُمْ شَهِيدًا‏\}‏ وَالْوَسَطُ الْعَدْلُ‏.‏\hadithno{4487}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "Noah will be called on the Day of Resurrection and he will say, 'Labbaik and Sa`daik, O my Lord!' Allah will say, 'Did you convey the Message?' Noah will say, 'Yes.' His nation will then be asked, 'Did he convey the Message to you?' They will say, 'No Warner came to us.' Then Allah will say (to Noah), 'Who will bear witness in your favor?' He will say, 'Muhammad and his followers. So they (i.e. Muslims) will testify that he conveyed the Message. And the Apostle (Muhammad) will be a witness over yourselves, and that is what is meant by the Statement of Allah "Thus We have made of you a just and the best nation that you may be witnesses over mankind and the Apostle (Muhammad) will be a witness over yourselves}}
\hadithdefcmd{bukhari}{4488}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ بَيْنَا النَّاسُ يُصَلُّونَ الصُّبْحَ فِي مَسْجِدِ قُبَاءٍ إِذْ جَاءَ جَاءٍ فَقَالَ أَنْزَلَ اللَّهُ عَلَى النَّبِيِّ صلى الله عليه وسلم قُرْآنًا أَنْ يَسْتَقْبِلَ الْكَعْبَةَ فَاسْتَقْبِلُوهَا‏.‏ فَتَوَجَّهُوا إِلَى الْكَعْبَةِ‏.‏\hadithno{4488}\hadithtrans{Narrated Ibn `Umar:While some people were offering Fajr prayer in the Quba' mosque, some-one came and said, "Allah has revealed to the Prophet (ﷺ) Qur'anic instructions that you should face the Ka`ba (while praying) so you too, should face it." Those people then turned towards the Ka`ba}}
\hadithdefcmd{bukhari}{4489}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لَمْ يَبْقَ مِمَّنْ صَلَّى الْقِبْلَتَيْنِ غَيْرِي‏.‏\hadithno{4489}\hadithtrans{Narrated Anas:None remains of those who prayed facing both Qiblas (that is, Jerusalem and Mecca) except myself}}
\hadithdefcmd{bukhari}{4490}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ بَيْنَمَا النَّاسُ فِي الصُّبْحِ بِقُبَاءٍ جَاءَهُمْ رَجُلٌ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أُنْزِلَ عَلَيْهِ اللَّيْلَةَ قُرْآنٌ، وَأُمِرَ أَنْ يَسْتَقْبِلَ الْكَعْبَةَ أَلاَ فَاسْتَقْبِلُوهَا‏.‏ وَكَانَ وَجْهُ النَّاسِ إِلَى الشَّأْمِ فَاسْتَدَارُوا بِوُجُوهِهِمْ إِلَى الْكَعْبَةِ‏.‏\hadithno{4490}\hadithtrans{Narrated Ibn `Umar:While some people were offering morning prayer at Quba' a man came to them and said, "A Qur'anic Order has been revealed to Allah's Messenger (ﷺ) tonight that he should face the Ka`ba at Mecca (in prayer), so you too should turn your faces towards it." At that moment their faces were towards Sham (i.e. Jerusalem) (and on hearing that) they turned towards the Ka`ba (at Mecca)}}
\hadithdefcmd{bukhari}{4491}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَيْنَا النَّاسُ بِقُبَاءٍ فِي صَلاَةِ الصُّبْحِ إِذْ جَاءَهُمْ آتٍ فَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ أُنْزِلَ عَلَيْهِ اللَّيْلَةَ قُرْآنٌ، وَقَدْ أُمِرَ أَنْ يَسْتَقْبِلَ الْكَعْبَةَ فَاسْتَقْبِلُوهَا‏.‏ وَكَانَتْ وُجُوهُهُمْ إِلَى الشَّأْمِ فَاسْتَدَارُوا إِلَى الْكَعْبَةِ‏.‏\hadithno{4491}\hadithtrans{Narrated Ibn `Umar:While some people were offering Fajr prayer at Quba' (mosque), some-one came to them and said, "Tonight some Qur'anic Verses have been revealed to the Prophet (ﷺ) and he has been ordered to face the Ka`ba (at Mecca) (during prayers), so you too should turn your faces towards it." At that time their faces were towards Sham (Jerusalem) so they turned towards the Ka`ba (at Mecca)}}
\hadithdefcmd{bukhari}{4492}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ صَلَّيْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم نَحْوَ بَيْتِ الْمَقْدِسِ سِتَّةَ عَشَرَ ـ أَوْ سَبْعَةَ عَشَرَ ـ شَهْرًا، ثُمَّ صَرَفَهُ نَحْوَ الْقِبْلَةِ‏.‏\hadithno{4492}\hadithtrans{Narrated Al-Bara:We prayed along with the Prophet (ﷺ) facing Jerusalem for sixteen or seventeen months. Then Allah ordered him to turn his face towards the Qibla (in Mecca):-- "And from whence-so-ever you start forth (for prayers) turn your face in the direction of (the Sacred Mosque of Mecca) Al-Masjid-ul Haram}}
\hadithdefcmd{bukhari}{4493}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ بَيْنَا النَّاسُ فِي الصُّبْحِ بِقُبَاءٍ إِذْ جَاءَهُمْ رَجُلٌ فَقَالَ أُنْزِلَ اللَّيْلَةَ قُرْآنٌ، فَأُمِرَ أَنْ يَسْتَقْبِلَ الْكَعْبَةَ، فَاسْتَقْبِلُوهَا‏.‏ وَاسْتَدَارُوا كَهَيْئَتِهِمْ، فَتَوَجَّهُوا إِلَى الْكَعْبَةِ وَكَانَ وَجْهُ النَّاسِ إِلَى الشَّأْمِ‏.‏\hadithno{4493}\hadithtrans{Narrated Ibn `Umar:While some people were at Quba (offering) morning prayer, a man came to them and said, "Last night Qur'anic Verses have been revealed whereby the Prophet (ﷺ) has been ordered to face the Ka`ba (at Mecca), so you too should face it." So they, keeping their postures, turned towards the Ka`ba. Formerly the people were facing Sham (Jerusalem) (Allah said):-- "And from whence-so-ever you start forth (for prayers), turn your face in the direction of the Sacred Mosque of Mecca (Al-Masjid-ul-Haram), and whence-so-ever you are, turn your face towards it (when you pray)}}
\hadithdefcmd{bukhari}{4494}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَيْنَمَا النَّاسُ فِي صَلاَةِ الصُّبْحِ بِقُبَاءٍ إِذْ جَاءَهُمْ آتٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أُنْزِلَ عَلَيْهِ اللَّيْلَةَ، وَقَدْ أُمِرَ أَنْ يَسْتَقْبِلَ الْكَعْبَةَ، فَاسْتَقْبِلُوهَا‏.‏ وَكَانَتْ وُجُوهُهُمْ إِلَى الشَّأْمِ فَاسْتَدَارُوا إِلَى الْقِبْلَةِ‏.‏\hadithno{4494}\hadithtrans{Narrated Ibn `Umar:While some people were offering Fajr prayer at Quba mosque, someone came to them and said, "Qur'anic literature" has been revealed to Allah's Messenger (ﷺ) tonight, and he has been ordered to face the Ka`ba (of Mecca) so you too, should turn your faces towards it. Their faces were then towards Sham (Jerusalem), so they turned towards the Qibla (i.e. Ka`ba of Mecca)}}
\hadithdefcmd{bukhari}{4495}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ قُلْتُ لِعَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَأَنَا يَوْمَئِذٍ حَدِيثُ السِّنِّ أَرَأَيْتِ قَوْلَ اللَّهِ تَبَارَكَ وَتَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏ فَمَا أُرَى عَلَى أَحَدٍ شَيْئًا أَنْ لاَ يَطَّوَّفَ بِهِمَا‏.‏ فَقَالَتْ عَائِشَةُ كَلاَّ لَوْ كَانَتْ كَمَا تَقُولُ كَانَتْ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا، إِنَّمَا أُنْزِلَتْ هَذِهِ الآيَةُ فِي الأَنْصَارِ، كَانُوا يُهِلُّونَ لِمَنَاةَ، وَكَانَتْ مَنَاةُ حَذْوَ قُدَيْدٍ، وَكَانُوا يَتَحَرَّجُونَ أَنْ يَطُوفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ، فَلَمَّا جَاءَ الإِسْلاَمُ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَنْزَلَ اللَّهُ ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏\hadithno{4495}\hadithtrans{Narrated `Urwa:I said to `Aisha, the wife of the Prophet, and I was at that time a young boy, "How do you interpret the Statement of Allah: "Verily, Safa and Marwa (i.e. two mountains at Mecca) are among the Symbols of Allah." So it is not harmful of those who perform the Hajj to the House of Allah) or perform the Umra, to ambulate (Tawaf) between them. In my opinion it is not sinful for one not to ambulate (Tawaf) between them." `Aisha said, "Your interpretation is wrong for as you say, the Verse should have been: "So it is not harmful of those who perform the Hajj or Umra to the House, not to ambulate (Tawaf) between them.' This Verse was revealed in connection with the Ansar who (during the Pre-Islamic Period) used to visit Manat (i.e. an idol) after assuming their Ihram, and it was situated near Qudaid (i.e. a place at Mecca), and they used to regard it sinful to ambulate between Safa and Marwa after embracing Islam. When Islam came, they asked Allah's Messenger (ﷺ) about it, whereupon Allah revealed:-- "Verily, Safa and Marwa (i.e. two mountains at Mecca) are among the Symbols of Allah. So it is not harmful of those who perform the Hajj of the House (of Allah) or perform the Umra, to ambulate (Tawaf) between them}}
\hadithdefcmd{bukhari}{4496}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ سُلَيْمَانَ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ عَنِ الصَّفَا، وَالْمَرْوَةِ،‏.‏ فَقَالَ كُنَّا نَرَى أَنَّهُمَا مِنْ أَمْرِ الْجَاهِلِيَّةِ، فَلَمَّا كَانَ الإِسْلاَمُ أَمْسَكْنَا عَنْهُمَا، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏أَنْ يَطَّوَّفَ بِهِمَا‏\}‏‏.‏\hadithno{4496}\hadithtrans{Narrated `Asim bin Sulaiman:I asked Anas bin Malik about Safa and Marwa. Anas replied, "We used to consider (i.e. going around) them a custom of the Pre-islamic period of Ignorance, so when Islam came, we gave up going around them. Then Allah revealed" "Verily, Safa and Marwa (i.e. two mountains at Mecca) are among the Symbols of Allah. So it is not harmful of those who perform the Hajj of the House (of Allah) or perform the Umra to ambulate (Tawaf) between them}}
\hadithdefcmd{bukhari}{4497}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم كَلِمَةً وَقُلْتُ أُخْرَى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ مَاتَ وَهْوَ يَدْعُو مِنْ دُونِ اللَّهِ نِدًّا دَخَلَ النَّارَ ‏"‏‏.‏ وَقُلْتُ أَنَا مَنْ مَاتَ وَهْوَ لاَ يَدْعُو لِلَّهِ نِدًّا دَخَلَ الْجَنَّةَ‏.‏\hadithno{4497}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said one statement and I said another. The Prophet (ﷺ) said "Whoever dies while still invoking anything other than Allah as a rival to Allah, will enter Hell (Fire)." And I said, "Whoever dies without invoking anything as a rival to Allah, will enter Paradise}}
\hadithdefcmd{bukhari}{4498}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، قَالَ سَمِعْتُ مُجَاهِدًا، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ كَانَ فِي بَنِي إِسْرَائِيلَ الْقِصَاصُ، وَلَمْ تَكُنْ فِيهِمُ الدِّيَةُ فَقَالَ اللَّهُ تَعَالَى لِهَذِهِ الأُمَّةِ ‏\{‏كُتِبَ عَلَيْكُمُ الْقِصَاصُ فِي الْقَتْلَى الْحُرُّ بِالْحُرِّ وَالْعَبْدُ بِالْعَبْدِ وَالأُنْثَى بِالأُنْثَى فَمَنْ عُفِيَ لَهُ مِنْ أَخِيهِ شَىْءٌ‏\}‏ فَالْعَفْوُ أَنْ يَقْبَلَ الدِّيَةَ فِي الْعَمْدِ ‏\{‏فَاتِّبَاعٌ بِالْمَعْرُوفِ وَأَدَاءٌ إِلَيْهِ بِإِحْسَانٍ‏\}‏ يَتَّبِعُ بِالْمَعْرُوفِ وَيُؤَدِّي بِإِحْسَانٍ، ‏\{‏ذَلِكَ تَخْفِيفٌ مِنْ رَبِّكُمْ‏\}‏ وَرَحْمَةٌ مِمَّا كُتِبَ عَلَى مَنْ كَانَ قَبْلَكُمْ‏.‏ ‏\{‏فَمَنِ اعْتَدَى بَعْدَ ذَلِكَ فَلَهُ عَذَابٌ أَلِيمٌ‏\}‏ قَتَلَ بَعْدَ قَبُولِ الدِّيَةِ‏.‏\hadithno{4498}\hadithtrans{Narrated Ibn `Abbas:The law of Qisas (i.e. equality in punishment) was prescribed for the children of Israel, but the Diya (i.e. blood money was not ordained for them). So Allah said to this Nation (i.e. Muslims): "O you who believe! The law of Al-Qisas (i.e. equality in punishment) is prescribed for you in cases of murder: The free for the free, the slave for the slave, and the female for the female. But if the relatives (or one of them) of the killed (person) forgive their brother (i.e. the killers something of Qisas (i.e. not to kill the killer by accepting blood money in the case of intentional murder)----then the relatives (of the killed person) should demand blood-money in a reasonable manner and the killer must pay with handsome gratitude. This is an alleviation and a Mercy from your Lord, (in comparison to what was prescribed for the nations before you). So after this, whoever transgresses the limits (i.e. to kill the killer after taking the blood-money) shall have a painful torment}}
\hadithdefcmd{bukhari}{4499}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا حُمَيْدٌ، أَنَّ أَنَسًا، حَدَّثَهُمْ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كِتَابُ اللَّهِ الْقِصَاصُ ‏"‏‏.‏\hadithno{4499}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "The prescribed Law of Allah is the equality in punishment (i.e. Al-Qisas)." (In cases of murders, etc)}}
\hadithdefcmd{bukhari}{4500}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ عَبْدَ اللَّهِ بْنَ بَكْرٍ السَّهْمِيَّ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، أَنَّ الرُّبَيِّعَ، عَمَّتَهُ كَسَرَتْ ثَنِيَّةَ جَارِيَةٍ، فَطَلَبُوا إِلَيْهَا الْعَفْوَ فَأَبَوْا، فَعَرَضُوا الأَرْشَ فَأَبَوْا، فَأَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَوْا إِلاَّ الْقِصَاصَ، فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْقِصَاصِ، فَقَالَ أَنَسُ بْنُ النَّضْرِ يَا رَسُولَ اللَّهِ، أَتُكْسَرُ ثَنِيَّةُ الرُّبَيِّعِ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ تُكْسَرُ ثَنِيَّتُهَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَنَسُ كِتَابُ اللَّهِ الْقِصَاصُ ‏"‏‏.‏ فَرَضِيَ الْقَوْمُ فَعَفَوْا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ مَنْ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏‏.‏\hadithno{4500}\hadithtrans{Narrated Anas:That his aunt, Ar-Rubai' broke an incisor tooth of a girl. My aunt's family requested the girl's relatives for forgiveness but they refused; then they proposed a compensation, but they refused. Then they went to Allah's Messenger (ﷺ) and refused everything except Al-Qisas (i.e. equality in punishment). So Allah's Apostle passed the judgment of Al-Qisas (i.e. equality of punishment). Anas bin Al-Nadr said, "O Allah's Messenger (ﷺ)! Will the incisor tooth of Ar-Rubai be broken? No, by Him Who sent you with the Truth, her incisor tooth will not be broken." Allah's Messenger (ﷺ) said, "O Anas! The prescribed law of Allah is equality in punishment (i.e. Al-Qisas.)" Thereupon those people became satisfied and forgave her. Then Allah's Messenger (ﷺ) said, "Among Allah's Worshippers there are some who, if they took Allah's Oath (for something), Allah fulfills their oaths}}
\hadithdefcmd{bukhari}{4501}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ عَاشُورَاءُ يَصُومُهُ أَهْلُ الْجَاهِلِيَّةِ، فَلَمَّا نَزَلَ رَمَضَانُ قَالَ ‏ "‏ مَنْ شَاءَ صَامَهُ، وَمَنْ شَاءَ لَمْ يَصُمْهُ ‏"‏‏.‏\hadithno{4501}\hadithtrans{Narrated Ibn `Umar:Fasting was observed on the day of 'Ashura' (i.e. 10th of Muharram) by the people of the Pre-Islamic Period. But when (the order of compulsory fasting) in the month of Ramadan was revealed, the Prophet said, "It is up to one to fast on it (i.e. day of 'Ashura') or not}}
\hadithdefcmd{bukhari}{4502}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ كَانَ عَاشُورَاءُ يُصَامُ قَبْلَ رَمَضَانَ، فَلَمَّا نَزَلَ رَمَضَانُ قَالَ ‏ "‏ مَنْ شَاءَ صَامَ، وَمَنْ شَاءَ أَفْطَرَ ‏"‏‏.‏\hadithno{4502}\hadithtrans{Narrated `Aisha:The people used to fast on the day of 'Ashura' before fasting in Ramadan was prescribed but when (the order of compulsory fasting in) Ramadan was revealed, it was up to one to fast on it (i.e. 'Ashura') or not}}
\hadithdefcmd{bukhari}{4503}{حَدَّثَنِي مَحْمُودٌ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ دَخَلَ عَلَيْهِ الأَشْعَثُ وَهْوَ يَطْعَمُ فَقَالَ الْيَوْمُ عَاشُورَاءُ‏.‏ فَقَالَ كَانَ يُصَامُ قَبْلَ أَنْ يَنْزِلَ رَمَضَانُ، فَلَمَّا نَزَلَ رَمَضَانُ تُرِكَ، فَادْنُ فَكُلْ‏.‏\hadithno{4503}\hadithtrans{Narrated `Abdullah:That Al-Ash'ath entered upon him while he was eating. Al-Ash'ath said, "Today is 'Ashura." I said (to him), "Fasting had been observed (on such a day) before (the order of compulsory fasting in) Ramadan was revealed. But when (the order of fasting in) Ramadan was revealed, fasting (on 'Ashura') was given up, so come and eat}}
\hadithdefcmd{bukhari}{4504}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ يَوْمُ عَاشُورَاءَ تَصُومُهُ قُرَيْشٌ فِي الْجَاهِلِيَّةِ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم يَصُومُهُ، فَلَمَّا قَدِمَ الْمَدِينَةَ صَامَهُ وَأَمَرَ بِصِيَامِهِ، فَلَمَّا نَزَلَ رَمَضَانُ كَانَ رَمَضَانُ الْفَرِيضَةَ، وَتُرِكَ عَاشُورَاءُ، فَكَانَ مَنْ شَاءَ صَامَهُ، وَمَنْ شَاءَ لَمْ يَصُمْهُ‏.‏\hadithno{4504}\hadithtrans{Narrated Aisha:During the Pre-Islamic Period of ignorance the Quraish used to observe fasting on the day of 'Ashura', and the Prophet (ﷺ) himself used to observe fasting on it too. But when he came to Medina, he fasted on that day and ordered the Muslims to fast on it. When (the order of compulsory fasting in ) Ramadan was revealed, fasting in Ramadan became an obligation, and fasting on 'Ashura' was given up, and who ever wished to fast (on it) did so, and whoever did not wish to fast on it, did not fast}}
\hadithdefcmd{bukhari}{4505}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا رَوْحٌ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ عَطَاءٍ، سَمِعَ ابْنَ عَبَّاسٍ، يَقْرَأُ ‏\{‏وَعَلَى الَّذِينَ يُطَوَّقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ ‏\}‏‏.‏ قَالَ ابْنُ عَبَّاسٍ لَيْسَتْ بِمَنْسُوخَةٍ، هُوَ الشَّيْخُ الْكَبِيرُ وَالْمَرْأَةُ الْكَبِيرَةُ لاَ يَسْتَطِيعَانِ أَنْ يَصُومَا، فَلْيُطْعِمَانِ مَكَانَ كُلِّ يَوْمٍ مِسْكِينًا‏.‏\hadithno{4505}\hadithtrans{Narrated 'Ata:That he heard Ibn `Abbas reciting the Divine Verse:-- "And for those who can fast they had a choice to either fast, or feed a poor for every day.." (2.184) Ibn `Abbas said, "This Verse is not abrogated, but it is meant for old men and old women who have no strength to fast, so they should feed one poor person for each day of fasting (instead of fasting)}}
\hadithdefcmd{bukhari}{4506}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ قَرَأَ ‏\{‏فِدْيَةٌ طَعَامُ مَسَاكِينَ‏\}‏ قَالَ هِيَ مَنْسُوخَةٌ‏.‏\hadithno{4506}\hadithtrans{Narrated Nafi`:Ibn `Umar recited: "They had a choice, either fast or feed a poor for every day.." and added, "This Verse is abrogated}}
\hadithdefcmd{bukhari}{4507}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنْ يَزِيدَ، مَوْلَى سَلَمَةَ بْنِ الأَكْوَعِ عَنْ سَلَمَةَ، قَالَ لَمَّا نَزَلَتْ ‏\{‏وَعَلَى الَّذِينَ يُطِيقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ‏\}‏ كَانَ مَنْ أَرَادَ أَنْ يُفْطِرَ وَيَفْتَدِيَ حَتَّى نَزَلَتِ الآيَةُ الَّتِي بَعْدَهَا فَنَسَخَتْهَا‏.‏ مَاتَ بُكَيْرٌ قَبْلَ يَزِيدَ‏.‏\hadithno{4507}\hadithtrans{Narrated Salama:When the Divine Revelation: "For those who can fast, they had a choice to either fast, or feed a poor for every day," (2.184) was revealed, it was permissible for one to give a ransom and give up fasting, till the Verse succeeding it was revealed and abrogated it}}
\hadithdefcmd{bukhari}{4508}{حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، وَحَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ، حَدَّثَنَا شُرَيْحُ بْنُ مَسْلَمَةَ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ يُوسُفَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ‏.‏ لَمَّا نَزَلَ صَوْمُ رَمَضَانَ كَانُوا لاَ يَقْرَبُونَ النِّسَاءَ رَمَضَانَ كُلَّهُ، وَكَانَ رِجَالٌ يَخُونُونَ أَنْفُسَهُمْ، فَأَنْزَلَ اللَّهُ ‏\{‏عَلِمَ اللَّهُ أَنَّكُمْ كُنْتُمْ تَخْتَانُونَ أَنْفُسَكُمْ فَتَابَ عَلَيْكُمْ وَعَفَا عَنْكُمْ‏\}‏‏.‏\hadithno{4508}\hadithtrans{Narrated Al-Bara':When the order of compulsory fasting of Ramadan was revealed, the people did not have sexual relations with their wives for the whole month of Ramadan, but some men cheated themselves (by violating that restriction). So Allah revealed: "Allah is aware that you were deceiving yourselves but He accepted your repentance and forgave you}}
\hadithdefcmd{bukhari}{4509}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيٍّ، قَالَ أَخَذَ عَدِيٌّ عِقَالاً أَبْيَضَ وَعِقَالاً أَسْوَدَ حَتَّى كَانَ بَعْضُ اللَّيْلِ نَظَرَ فَلَمْ يَسْتَبِينَا، فَلَمَّا أَصْبَحَ قَالَ يَا رَسُولَ اللَّهِ، جَعَلْتُ تَحْتَ وِسَادَتِي‏.‏ قَالَ ‏ "‏ إِنَّ وِسَادَكَ إِذًا لَعَرِيضٌ أَنْ كَانَ الْخَيْطُ الأَبْيَضُ وَالأَسْوَدُ تَحْتَ وِسَادَتِكَ ‏"‏‏.‏\hadithno{4509}\hadithtrans{Narrated Ash-Shu`bi:`Adi took a white rope (or thread) and a black one, and when some part of the night had passed, he looked at them but he could not distinguish one from the other. The next morning he said, "O Allah's Apostle! I put (a white thread and a black thread) underneath my pillow." The Prophet (ﷺ) said, "Then your pillow is too wide if the white thread (of dawn) and the black thread (of the night) are underneath your pillow}}
\hadithdefcmd{bukhari}{4510}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُطَرِّفٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ ـ رضى الله عنه ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ أَهُمَا الْخَيْطَانِ قَالَ ‏"‏ إِنَّكَ لَعَرِيضُ الْقَفَا إِنْ أَبْصَرْتَ الْخَيْطَيْنِ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ لاَ بَلْ هُوَ سَوَادُ اللَّيْلِ وَبَيَاضُ النَّهَارِ ‏"‏‏.‏\hadithno{4510}\hadithtrans{Narrated `Adi bin Hatim:I said, "O Allah's Messenger (ﷺ)! What is the meaning of the white thread distinct from the black thread? Are these two threads?" He said, "You are not intelligent if you watch the two threads." He then added, "No, it is the darkness of the night and the whiteness of the day}}
\hadithdefcmd{bukhari}{4511}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، مُحَمَّدُ بْنُ مُطَرِّفٍ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ وَأُنْزِلَتْ ‏\{‏وَكُلُوا وَاشْرَبُوا حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ‏\}‏ وَلَمْ يُنْزَلْ ‏\{‏مِنَ الْفَجْرِ‏\}‏ وَكَانَ رِجَالٌ إِذَا أَرَادُوا الصَّوْمَ رَبَطَ أَحَدُهُمْ فِي رِجْلَيْهِ الْخَيْطَ الأَبْيَضَ وَالْخَيْطَ الأَسْوَدَ، وَلاَ يَزَالُ يَأْكُلُ حَتَّى يَتَبَيَّنَ لَهُ رُؤْيَتُهُمَا، فَأَنْزَلَ اللَّهُ بَعْدَهُ ‏\{‏مِنَ الْفَجْرِ‏\}‏ فَعَلِمُوا أَنَّمَا يَعْنِي اللَّيْلَ مِنَ النَّهَارِ‏.‏\hadithno{4511}\hadithtrans{Narrated Sahl bin Sa`d The Verse "And eat and drink until the white thread appears to you distinct from the black thread." was revealed, but: '... of dawn' was not revealed (along with it). So some men, when intending to fast, used to tie their legs, one with white thread and the other with black thread and would keep on eating till they could distinguish one thread from the other. Then Allah revealed' ... of dawn,' whereupon they understood that meant the night and the day}}
\hadithdefcmd{bukhari}{4512}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كَانُوا إِذَا أَحْرَمُوا فِي الْجَاهِلِيَّةِ أَتَوُا الْبَيْتَ مِنْ ظَهْرِهِ، فَأَنْزَلَ اللَّهُ ‏\{‏وَلَيْسَ الْبِرُّ بِأَنْ تَأْتُوا الْبُيُوتَ مِنْ ظُهُورِهَا وَلَكِنَّ الْبِرَّ مَنِ اتَّقَى وَأْتُوا الْبُيُوتَ مِنْ أَبْوَابِهَا‏\}‏\hadithno{4512}\hadithtrans{Narrated Al-Bara:In the Pre-Islamic Period when the people assumed Ihram, they would enter their houses from the back. So Allah revealed:-- "And it is not righteousness that you enter houses from the back, but the righteous man is he who fears Allah, obeys His Orders and keeps away from what He has forbidden. So enter houses through their doors}}
\hadithdefcmd{bukhari}{4515}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَتَاهُ رَجُلاَنِ فِي فِتْنَةِ ابْنِ الزُّبَيْرِ فَقَالاَ إِنَّ النَّاسَ قَدْ ضُيِّعُوا، وَأَنْتَ ابْنُ عُمَرَ وَصَاحِبُ النَّبِيِّ صلى الله عليه وسلم فَمَا يَمْنَعُكَ أَنْ تَخْرُجَ فَقَالَ يَمْنَعُنِي أَنَّ اللَّهَ حَرَّمَ دَمَ أَخِي‏.‏ فَقَالاَ أَلَمْ يَقُلِ اللَّهُ ‏\{‏وَقَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ ‏\}‏ فَقَالَ قَاتَلْنَا حَتَّى لَمْ تَكُنْ فِتْنَةٌ، وَكَانَ الدِّينُ لِلَّهِ، وَأَنْتُمْ تُرِيدُونَ أَنْ تُقَاتِلُوا حَتَّى تَكُونَ فِتْنَةٌ، وَيَكُونَ الدِّينُ لِغَيْرِ اللَّهِ‏.‏ وَزَادَ عُثْمَانُ بْنُ صَالِحٍ عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي فُلاَنٌ، وَحَيْوَةُ بْنُ شُرَيْحٍ، عَنْ بَكْرِ بْنِ عَمْرٍو الْمَعَافِرِيِّ، أَنَّ بُكَيْرَ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُ عَنْ نَافِعٍ، أَنَّ رَجُلاً، أَتَى ابْنَ عُمَرَ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ مَا حَمَلَكَ عَلَى أَنْ تَحُجَّ عَامًا وَتَعْتَمِرَ عَامًا، وَتَتْرُكَ الْجِهَادَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ، وَقَدْ عَلِمْتَ مَا رَغَّبَ اللَّهُ فِيهِ قَالَ يَا ابْنَ أَخِي بُنِيَ الإِسْلاَمُ عَلَى خَمْسٍ إِيمَانٍ بِاللَّهِ وَرَسُولِهِ، وَالصَّلاَةِ الْخَمْسِ، وَصِيَامِ رَمَضَانَ، وَأَدَاءِ الزَّكَاةِ، وَحَجِّ الْبَيْتِ‏.‏ قَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ، أَلاَ تَسْمَعُ مَا ذَكَرَ اللَّهُ فِي كِتَابِهِ ‏\{‏وَإِنْ طَائِفَتَانِ مِنَ الْمُؤْمِنِينَ اقْتَتَلُوا فَأَصْلِحُوا بَيْنَهُمَا‏\}‏ ‏\{‏إِلَى أَمْرِ اللَّهِ‏\}‏ ‏\{‏قَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ‏\}‏ قَالَ فَعَلْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ الإِسْلاَمُ قَلِيلاً، فَكَانَ الرَّجُلُ يُفْتَنُ فِي دِينِهِ إِمَّا قَتَلُوهُ، وَإِمَّا يُعَذِّبُوهُ، حَتَّى كَثُرَ الإِسْلاَمُ فَلَمْ تَكُنْ فِتْنَةٌ‏.‏ قَالَ فَمَا قَوْلُكَ فِي عَلِيٍّ وَعُثْمَانَ قَالَ أَمَّا عُثْمَانُ فَكَأَنَّ اللَّهَ عَفَا عَنْهُ، وَأَمَّا أَنْتُمْ فَكَرِهْتُمْ أَنْ تَعْفُوا عَنْهُ، وَأَمَّا عَلِيٌّ فَابْنُ عَمِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَخَتَنُهُ‏.‏ وَأَشَارَ بِيَدِهِ فَقَالَ هَذَا بَيْتُهُ حَيْثُ تَرَوْنَ‏.‏\hadithno{4515}\hadithtrans{Narrated Nafi`:During the affliction of Ibn Az-Zubair, two men came to Ibn `Umar and said, "The people are lost, and you are the son of `Umar, and the companion of the Prophet, so what forbids you from coming out?" He said, "What forbids me is that Allah has prohibited the shedding of my brother's blood." They both said, "Didn't Allah say, 'And fight them until there is no more affliction?" He said "We fought until there was no more affliction and the worship is for Allah (Alone while you want to fight until there is affliction and until the worship becomes for other than Allah." Narrated Nafi` (through another group of sub-narrators): A man came to Ibn `Umar and said, "O Abu `Abdur Rahman! What made you perform Hajj in one year and Umra in another year and leave the Jihad for Allah' Cause though you know how much Allah recommends it?" Ibn `Umar replied, "O son of my brother! Islam is founded on five principles, i.e. believe in Allah and His Apostle, the five compulsory prayers, the fasting of the month of Ramadan, the payment of Zakat, and the Hajj to the House (of Allah)." The man said, "O Abu `Abdur Rahman! Won't you listen to what Allah has mentioned in His Book: 'If two groups of believers fight each other, then make peace between them, but if one of them transgresses beyond bounds against the other, then you all fight against the one that transgresses. (49.9) and:--"And fight them till there is no more affliction (i.e. no more worshiping of others along with Allah)." Ibn `Umar said, "We did it, during the lifetime of Allah's Messenger (ﷺ) when Islam had only a few followers. A man would be put to trial because of his religion; he would either be killed or tortured. But when the Muslims increased, there was no more afflictions or oppressions." The man said, "What is your opinion about `Uthman and `Ali?" Ibn `Umar said, "As for `Uthman, it seems that Allah has forgiven him, but you people dislike that he should be forgiven. And as for `Ali, he is the cousin of Allah's Messenger (ﷺ) and his son-in-law." Then he pointed with his hand and said, "That is his house which you see}}
\hadithdefcmd{bukhari}{4516}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا النَّضْرُ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، عَنْ حُذَيْفَةَ، ‏\{‏وَأَنْفِقُوا فِي سَبِيلِ اللَّهِ وَلاَ تُلْقُوا بِأَيْدِيكُمْ إِلَى التَّهْلُكَةِ‏\}‏ قَالَ نَزَلَتْ فِي النَّفَقَةِ‏.‏\hadithno{4516}\hadithtrans{Narrated Abu Wail:Hudhaifa said, "The Verse:-- "And spend (of your wealth) in the Cause of Allah and do not throw yourselves in destruction," (2.195) was revealed concerning spending in Allah's Cause (i.e. Jihad)}}
\hadithdefcmd{bukhari}{4517}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَعْقِلٍ، قَالَ قَعَدْتُ إِلَى كَعْبِ بْنِ عُجْرَةَ فِي هَذَا الْمَسْجِدِ ـ يَعْنِي مَسْجِدَ الْكُوفَةِ ـ فَسَأَلْتُهُ عَنْ فِدْيَةٌ مِنْ صِيَامٍ فَقَالَ حُمِلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَالْقَمْلُ يَتَنَاثَرُ عَلَى وَجْهِي فَقَالَ ‏"‏ مَا كُنْتُ أُرَى أَنَّ الْجَهْدَ قَدْ بَلَغَ بِكَ هَذَا، أَمَا تَجِدُ شَاةً ‏"‏‏.‏ قُلْتُ لاَ‏.‏ قَالَ ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ، أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ، لِكُلِّ مِسْكِينٍ نِصْفُ صَاعٍ مِنْ طَعَامٍ، وَاحْلِقْ رَأْسَكَ ‏"‏‏.‏ فَنَزَلَتْ فِيَّ خَاصَّةً وَهْىَ لَكُمْ عَامَّةً‏.‏\hadithno{4517}\hadithtrans{Narrated `Abdullah bin Ma`qil:I sat with Ka`b bin Ujra in this mosque, i.e. Kufa Mosque, and asked him about the meaning of: "Pay a ransom (i.e. Fidya) of either fasting or . . . . (2.196)" He said, "I was taken to the Prophet (ﷺ) while lice were falling on my face. The Prophet (ﷺ) said, 'I did not think that your trouble reached to such an extent. Can you afford to slaughter a sheep (as a ransom for shaving your head)?' I said, 'No.' He said, 'Then fast for three days, or feed six poor persons by giving half a Sa of food for each and shave your head.' So the above Verse was revealed especially for me and generally for all of you}}
\hadithdefcmd{bukhari}{4518}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عِمْرَانَ أَبِي بَكْرٍ، حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ـ رضى الله عنهما ـ قَالَ أُنْزِلَتْ آيَةُ الْمُتْعَةِ فِي كِتَابِ اللَّهِ فَفَعَلْنَاهَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَلَمْ يُنْزَلْ قُرْآنٌ يُحَرِّمُهُ، وَلَمْ يَنْهَ عَنْهَا حَتَّى مَاتَ قَالَ رَجُلٌ بِرَأْيِهِ مَا شَاءَ‏.‏\hadithno{4518}\hadithtrans{Narrated `Imran bin Husain:The Verse of Hajj-at-Tamattu was revealed in Allah's Book, so we performed it with Allah's Messenger (ﷺ), and nothing was revealed in Qur'an to make it illegal, nor did the Prophet (ﷺ) prohibit it till he died. But the man (who regarded it illegal) just expressed what his own mind suggested}}
\hadithdefcmd{bukhari}{4519}{حَدَّثَنِي مُحَمَّدٌ، قَالَ أَخْبَرَنِي ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَتْ عُكَاظٌ وَمَجَنَّةُ وَذُو الْمَجَازِ أَسْوَاقًا فِي الْجَاهِلِيَّةِ فَتَأَثَّمُوا أَنْ يَتَّجِرُوا فِي الْمَوَاسِمِ فَنَزَلَتْ ‏\{‏لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَبْتَغُوا فَضْلاً مِنْ رَبِّكُمْ‏\}‏ فِي مَوَاسِمِ الْحَجِّ‏.‏\hadithno{4519}\hadithtrans{Narrated Ibn `Abbas:`Ukaz, Mijanna and Dhul-Majaz were markets during the Pre-islamic Period. They (i.e. Muslims) considered it a sin to trade there during the Hajj time (i.e. season), so this Verse was revealed:-- "There is no harm for you if you seek of the Bounty of your Lord during the Hajj season}}
\hadithdefcmd{bukhari}{4520}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ خَازِمٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ كَانَتْ قُرَيْشٌ وَمَنْ دَانَ دِينَهَا يَقِفُونَ بِالْمُزْدَلِفَةِ، وَكَانُوا يُسَمَّوْنَ الْحُمْسَ، وَكَانَ سَائِرُ الْعَرَبِ يَقِفُونَ بِعَرَفَاتٍ، فَلَمَّا جَاءَ الإِسْلاَمُ أَمَرَ اللَّهُ نَبِيَّهُ صلى الله عليه وسلم أَنْ يَأْتِيَ عَرَفَاتٍ، ثُمَّ يَقِفَ بِهَا ثُمَّ يُفِيضَ مِنْهَا، فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ‏\}‏\hadithno{4520}\hadithtrans{Narrated `Aisha:The Quraish people and those who embraced their religion, used to stay at Muzdalifa and used to call themselves Al-Hums, while the rest of the Arabs used to stay at `Arafat. When Islam came, Allah ordered His Prophet to go to `Arafat and stay at it, and then pass on from there, and that is what is meant by the Statement of Allah:--"Then depart from the place whence all the people depart}}
\hadithdefcmd{bukhari}{4521}{حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، أَخْبَرَنِي كُرَيْبٌ، عَنِ ابْنِ عَبَّاسٍ، قَالَ يَطَوَّفُ الرَّجُلُ بِالْبَيْتِ مَا كَانَ حَلاَلاً حَتَّى يُهِلَّ بِالْحَجِّ، فَإِذَا رَكِبَ إِلَى عَرَفَةَ فَمَنْ تَيَسَّرَ لَهُ هَدِيَّةٌ مِنَ الإِبِلِ أَوِ الْبَقَرِ أَوِ الْغَنَمِ، مَا تَيَسَّرَ لَهُ مِنْ ذَلِكَ أَىَّ ذَلِكَ شَاءَ، غَيْرَ إِنْ لَمْ يَتَيَسَّرْ لَهُ فَعَلَيْهِ ثَلاَثَةُ أَيَّامٍ فِي الْحَجِّ، وَذَلِكَ قَبْلَ يَوْمِ عَرَفَةَ، فَإِنْ كَانَ آخِرُ يَوْمٍ مِنَ الأَيَّامِ الثَّلاَثَةِ يَوْمَ عَرَفَةَ فَلاَ جُنَاحَ عَلَيْهِ، ثُمَّ لِيَنْطَلِقْ حَتَّى يَقِفَ بِعَرَفَاتٍ مِنْ صَلاَةِ الْعَصْرِ إِلَى أَنْ يَكُونَ الظَّلاَمُ، ثُمَّ لِيَدْفَعُوا مِنْ عَرَفَاتٍ إِذَا أَفَاضُوا مِنْهَا حَتَّى يَبْلُغُوا جَمْعًا الَّذِي يُتَبَرَّرُ فِيهِ، ثُمَّ لِيَذْكُرُوا اللَّهَ كَثِيرًا، أَوْ أَكْثِرُوا التَّكْبِيرَ وَالتَّهْلِيلَ قَبْلَ أَنْ تُصْبِحُوا ثُمَّ أَفِيضُوا، فَإِنَّ النَّاسَ كَانُوا يُفِيضُونَ، وَقَالَ اللَّهُ تَعَالَى ‏\{‏ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ وَاسْتَغْفِرُوا اللَّهَ إِنَّ اللَّهَ غَفُورٌ رَحِيمٌ‏\}‏ حَتَّى تَرْمُوا الْجَمْرَةَ‏.‏\hadithno{4521}\hadithtrans{Narrated Ibn `Abbas:A man who wants to perform the Hajj (from Mecca) can perform the Tawaf around the Ka`ba as long as he is not in the state of Ihram till he assumes the Ihram for Hajj. Then, if he rides and proceeds to `Arafat, he should take a Hadi (i.e. animal for sacrifice), either a camel or a cow or a sheep, whatever he can afford; but if he cannot afford it, he should fast for three days during the Hajj before the day of `Arafat, but if the third day of his fasting happens to be the day of `Arafat (i.e. 9th of Dhul-Hijja) then it is no sin for him (to fast on it). Then he should proceed to `Arafat and stay there from the time of the `Asr prayer till darkness falls. Then the pilgrims should proceed from `Arafat, and when they have departed from it, they reach Jam' (i.e. Al-Muzdalifa) where they ask Allah to help them to be righteous and dutiful to Him, and there they remember Allah greatly or say Takbir (i.e. Allah is Greater) and Tahlil (i.e. None has the right to be worshipped but Allah) repeatedly before dawn breaks. Then, after offering the morning (Fajr) prayer you should pass on (to Mina) for the people used to do so and Allah said:-- "Then depart from the place whence all the people depart. And ask for Allah's Forgiveness. Truly! Allah is Oft-Forgiving, Most Merciful." (2.199) Then you should go on doing so till you throw pebbles over the Jamra}}
\hadithdefcmd{bukhari}{4522}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ رَبَّنَا آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنَا عَذَابَ النَّارِ ‏"‏‏.‏\hadithno{4522}\hadithtrans{Narrated Anas:The Prophet (ﷺ) used to say, "O Allah! Our Lord! Give us in this world that, which is good and in the Hereafter that, which is good and save us from the torment of the Fire}}
\hadithdefcmd{bukhari}{4523}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، تَرْفَعُهُ قَالَ ‏ "‏ أَبْغَضُ الرِّجَالِ إِلَى اللَّهِ الأَلَدُّ الْخَصِمُ ‏"‏‏.‏ وَقَالَ عَبْدُ اللَّهِ حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي ابْنُ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{4523}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "The most hated man in the Sight of Allah is the one who is the most quarrelsome}}
\hadithdefcmd{bukhari}{4525}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، يَقُولُ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏حَتَّى إِذَا اسْتَيْأَسَ الرُّسُلُ وَظَنُّوا أَنَّهُمْ قَدْ كُذِبُوا‏\}‏ خَفِيفَةً، ذَهَبَ بِهَا هُنَاكَ، وَتَلاَ ‏\{‏حَتَّى يَقُولَ الرَّسُولُ وَالَّذِينَ آمَنُوا مَعَهُ مَتَى نَصْرُ اللَّهِ أَلاَ إِنَّ نَصْرَ اللَّهِ قَرِيبٌ‏\}‏ فَلَقِيتُ عُرْوَةَ بْنَ الزُّبَيْرِ فَذَكَرْتُ لَهُ ذَلِكَ فَقَالَ قَالَتْ عَائِشَةُ مَعَاذَ اللَّهِ، وَاللَّهِ مَا وَعَدَ اللَّهُ رَسُولَهُ مِنْ شَىْءٍ قَطُّ إِلاَّ عَلِمَ أَنَّهُ كَائِنٌ قَبْلَ أَنْ يَمُوتَ، وَلَكِنْ لَمْ يَزَلِ الْبَلاَءُ بِالرُّسُلِ حَتَّى خَافُوا أَنْ يَكُونَ مَنْ مَعَهُمْ يُكَذِّبُونَهُمْ، فَكَانَتْ تَقْرَؤُهَا ‏\{‏وَظَنُّوا أَنَّهُمْ قَدْ كُذِّبُوا‏\}‏ مُثَقَّلَةً‏.‏\hadithno{4525}\hadithtrans{Narrated Ibn Abu Mulaika:Ibn `Abbas recited: "(Respite will be granted) until when the Apostles gave up hope (of their people) and thought that they were denied (by their people). There came to them Our Help ...." (12.110) reading Kudhibu without doubling the sound 'dh', and that was what he understood of the Verse. Then he went on reciting: "..even the Apostle and those who believed along with him said: When (will come) Allah's Help? Yes, verily, Allah's Help is near." (2.214) Then I met `Urwa bin Az-Zubair and I mentioned that to him. He said, "Aisha said, 'Allah forbid! By Allah, Allah never promised His Apostle anything but he knew that it would certainly happen before he died. But trials were continuously presented before the Apostles till they were afraid that their followers would accuse them of telling lies. So I used to recite:-- "Till they (come to) think that they were treated as liars." reading 'Kudh-dhibu with double 'dh}}
\hadithdefcmd{bukhari}{4527}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ إِذَا قَرَأَ الْقُرْآنَ لَمْ يَتَكَلَّمْ حَتَّى يَفْرُغَ مِنْهُ، فَأَخَذْتُ عَلَيْهِ يَوْمًا، فَقَرَأَ سُورَةَ الْبَقَرَةِ حَتَّى انْتَهَى إِلَى مَكَانٍ قَالَ تَدْرِي فِيمَا أُنْزِلَتْ‏.‏ قُلْتُ لاَ‏.‏ قَالَ أُنْزِلَتْ فِي كَذَا وَكَذَا‏.‏ ثُمَّ مَضَى‏.‏ وَعَنْ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، حَدَّثَنِي أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ‏\{‏فَأْتُوا حَرْثَكُمْ أَنَّى شِئْتُمْ‏\}‏ قَالَ يَأْتِيهَا فِي‏.‏ رَوَاهُ مُحَمَّدُ بْنُ يَحْيَى بْنِ سَعِيدٍ عَنْ أَبِيهِ عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ‏.‏\hadithno{4527}\hadithtrans{Narrated Nafi`:Whenever Ibn `Umar recited the Qur'an, he would not speak to anyone till he had finished his recitation. Once I held the Qur'an and he recited Surat-al-Baqara from his memory and then stopped at a certain Verse and said, "Do you know in what connection this Verse was revealed? " I replied, "No." He said, "It was revealed in such-and-such connection." Ibn `Umar then resumed his recitation. Nafi` added regarding the Verse:--"So go to your tilth when or how you will" Ibn `Umar said, "It means one should approach his wife in}}
\hadithdefcmd{bukhari}{4528}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ الْمُنْكَدِرِ، سَمِعْتُ جَابِرًا ـ رضى الله عنه ـ قَالَ كَانَتِ الْيَهُودُ تَقُولُ إِذَا جَامَعَهَا مِنْ وَرَائِهَا جَاءَ الْوَلَدُ أَحْوَلَ‏.‏ فَنَزَلَتْ ‏\{‏نِسَاؤُكُمْ حَرْثٌ لَكُمْ فَأْتُوا حَرْثَكُمْ أَنَّى شِئْتُمْ‏\}‏\hadithno{4528}\hadithtrans{Narrated Jabir:Jews used to say: "If one has sexual intercourse with his wife from the back, then she will deliver a squint-eyed child." So this Verse was revealed:-- "Your wives are a tilth unto you; so go to your tilth when or how you will}}
\hadithdefcmd{bukhari}{4529}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا عَبَّادُ بْنُ رَاشِدٍ، حَدَّثَنَا الْحَسَنُ، قَالَ حَدَّثَنِي مَعْقِلُ بْنُ يَسَارٍ، قَالَ كَانَتْ لِي أُخْتٌ تُخْطَبُ إِلَىَّ‏.‏ وَقَالَ إِبْرَاهِيمُ عَنْ يُونُسَ، عَنِ الْحَسَنِ، حَدَّثَنِي مَعْقِلُ بْنُ يَسَارٍ،‏.‏ حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، أَنَّ أُخْتَ، مَعْقِلِ بْنِ يَسَارٍ طَلَّقَهَا زَوْجُهَا، فَتَرَكَهَا حَتَّى انْقَضَتْ عِدَّتُهَا، فَخَطَبَهَا فَأَبَى مَعْقِلٌ، فَنَزَلَتْ ‏\{‏فَلاَ تَعْضُلُوهُنَّ أَنْ يَنْكِحْنَ أَزْوَاجَهُنَّ‏\}‏‏.‏\hadithno{4529}\hadithtrans{Narrated Al-Hasan:The sister of Ma'qil bin Yasar was divorced by her husband who left her till she had fulfilled her term of 'Iddat (i.e. the period which should elapse before she can Remarry) and then he wanted to remarry her but Ma'qil refused, so this Verse was revealed:-- "Do not prevent them from marrying their (former) husbands}}
\hadithdefcmd{bukhari}{4530}{حَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ حَبِيبٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ ابْنُ الزُّبَيْرِ قُلْتُ لِعُثْمَانَ بْنِ عَفَّانَ ‏\{‏وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا‏\}‏ قَالَ قَدْ نَسَخَتْهَا الآيَةُ الأُخْرَى فَلِمَ تَكْتُبُهَا أَوْ تَدَعُهَا قَالَ يَا ابْنَ أَخِي، لاَ أُغَيِّرُ شَيْئًا مِنْهُ مِنْ مَكَانِهِ‏.‏\hadithno{4530}\hadithtrans{Narrated Ibn Az-Zubair:I said to `Uthman bin `Affan (while he was collecting the Qur'an) regarding the Verse:-- "Those of you who die and leave wives ..." (2.240) "This Verse was abrogated by another Verse. So why should you write it? (Or leave it in the Qur'an)?" `Uthman said. "O son of my brother! I will not shift anything of it from its place}}
\hadithdefcmd{bukhari}{4531}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا شِبْلٌ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، ‏\{‏وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا‏\}‏ قَالَ كَانَتْ هَذِهِ الْعِدَّةُ تَعْتَدُّ عِنْدَ أَهْلِ زَوْجِهَا وَاجِبٌ، فَأَنْزَلَ اللَّهُ ‏\{‏وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا وَصِيَّةً لأَزْوَاجِهِمْ مَتَاعًا إِلَى الْحَوْلِ غَيْرَ إِخْرَاجٍ فَإِنْ خَرَجْنَ فَلاَ جُنَاحَ عَلَيْكُمْ فِيمَا فَعَلْنَ فِي أَنْفُسِهِنَّ مِنْ مَعْرُوفٍ‏\}‏ قَالَ جَعَلَ اللَّهُ لَهَا تَمَامَ السَّنَةِ سَبْعَةَ أَشْهُرٍ وَعِشْرِينَ لَيْلَةً وَصِيَّةً، إِنْ شَاءَتْ سَكَنَتْ فِي وَصِيَّتِهَا، وَإِنْ شَاءَتْ خَرَجَتْ، وَهْوَ قَوْلُ اللَّهِ تَعَالَى ‏\{‏غَيْرَ إِخْرَاجٍ فَإِنْ خَرَجْنَ فَلاَ جُنَاحَ عَلَيْكُمْ‏\}‏ فَالْعِدَّةُ كَمَا هِيَ وَاجِبٌ عَلَيْهَا‏.‏ زَعَمَ ذَلِكَ عَنْ مُجَاهِدٍ‏.‏ وَقَالَ عَطَاءٌ قَالَ ابْنُ عَبَّاسٍ نَسَخَتْ هَذِهِ الآيَةُ عِدَّتَهَا عِنْدَ أَهْلِهَا، فَتَعْتَدُّ حَيْثُ شَاءَتْ، وَهْوَ قَوْلُ اللَّهِ تَعَالَى ‏\{‏غَيْرَ إِخْرَاجٍ‏\}‏‏.‏ قَالَ عَطَاءٌ إِنْ شَاءَتِ اعْتَدَّتْ عِنْدَ أَهْلِهِ وَسَكَنَتْ فِي وَصِيَّتِهَا، وَإِنْ شَاءَتْ خَرَجَتْ لِقَوْلِ اللَّهِ تَعَالَى ‏\{‏فَلاَ جُنَاحَ عَلَيْكُمْ فِيمَا فَعَلْنَ‏\}‏‏.‏ قَالَ عَطَاءٌ ثُمَّ جَاءَ الْمِيرَاثُ فَنَسَخَ السُّكْنَى فَتَعْتَدُّ حَيْثُ شَاءَتْ، وَلاَ سُكْنَى لَهَا‏.‏ وَعَنْ مُحَمَّدِ بْنِ يُوسُفَ حَدَّثَنَا وَرْقَاءُ عَنِ ابْنِ أَبِي نَجِيحٍ عَنْ مُجَاهِدٍ بِهَذَا‏.‏ وَعَنِ ابْنِ أَبِي نَجِيحٍ عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ قَالَ نَسَخَتْ هَذِهِ الآيَةُ عِدَّتَهَا فِي أَهْلِهَا، فَتَعْتَدُّ حَيْثُ شَاءَتْ لِقَوْلِ اللَّهِ ‏\{‏غَيْرَ إِخْرَاجٍ‏\}‏ نَحْوَهُ‏.‏\hadithno{4531}\hadithtrans{Narrated Mujahi:(regarding the Verse):-- "Those of you who die and leave wives behind. They - (their wives) -- shall wait (as regards their marriage ) for four months and ten days)." (2.234) The widow, according to this Verse, was to spend this period of waiting with her husband's family, so Allah revealed: "Those of you who die and leave wives (i.e. widows) should bequeath for their wives, a year's maintenance and residence without turning them out, but if they leave (their residence), there is no blame on you for what they do with themselves provided it is honorable.' (i.e. lawful marriage) (2.240). So Allah entitled the widow to be bequeathed extra maintenance for seven months and twenty nights, and that is the completion of one year. If she wished she could stay (in her husband's home) according to the will, and she could leave it if she wished, as Allah says: "..without turning them out, but if they leave (the residence), there is no blame on you." So the 'Idda (i.e. four months and ten days as it) is obligatory for her. 'Ata said: Ibn `Abbas said, "This Verse, i.e. the Statement of Allah: "..without turning them out.." cancelled the obligation of staying for the waiting period in her dead husband's house, and she can complete this period wherever she likes." 'Ata' said: If she wished, she could complete her 'Idda by staying in her dead husband's residence according to the will or leave it according to Allah's Statement:-- "There is no blame on you for what they do with themselves." `Ata' added: Later the regulations of inheritance came and abrogated the order of the dwelling of the widow (in her dead husband's house), so she could complete the 'Idda wherever she likes. And it was no longer necessary to provide her with a residence. Ibn `Abbas said, "This Verse abrogated her (i.e. widow's) dwelling in her dead husband's house and she could complete the 'Idda (i.e. four months and ten days) wherever she liked, as Allah's Statement says:--"...without turning them out}}
\hadithdefcmd{bukhari}{4532}{حَدَّثَنَا حِبَّانُ، حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ جَلَسْتُ إِلَى مَجْلِسٍ فِيهِ عُظْمٌ مِنَ الأَنْصَارِ وَفِيهِمْ عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى، فَذَكَرْتُ حَدِيثَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ فِي شَأْنِ سُبَيْعَةَ بِنْتِ الْحَارِثِ، فَقَالَ عَبْدُ الرَّحْمَنِ وَلَكِنَّ عَمَّهُ كَانَ لاَ يَقُولُ ذَلِكَ‏.‏ فَقُلْتُ إِنِّي لَجَرِيءٌ إِنْ كَذَبْتُ عَلَى رَجُلٍ فِي جَانِبِ الْكُوفَةِ‏.‏ وَرَفَعَ صَوْتَهُ، قَالَ ثُمَّ خَرَجْتُ فَلَقِيتُ مَالِكَ بْنَ عَامِرٍ أَوْ مَالِكَ بْنَ عَوْفٍ قُلْتُ كَيْفَ كَانَ قَوْلُ ابْنِ مَسْعُودٍ فِي الْمُتَوَفَّى عَنْهَا زَوْجُهَا وَهْىَ حَامِلٌ فَقَالَ قَالَ ابْنُ مَسْعُودٍ أَتَجْعَلُونَ عَلَيْهَا التَّغْلِيظَ، وَلاَ تَجْعَلُونَ لَهَا الرُّخْصَةَ لَنَزَلَتْ سُورَةُ النِّسَاءِ الْقُصْرَى بَعْدَ الطُّولَى‏.‏ وَقَالَ أَيُّوبُ عَنْ مُحَمَّدٍ لَقِيتُ أَبَا عَطِيَّةَ مَالِكَ بْنَ عَامِرٍ‏.‏\hadithno{4532}\hadithtrans{Narrated Muhammad bin Seereen:I sat in a gathering in which the chiefs of the Ansar were present, and `Abdur-Rahman bin Abu Laila was amongst them. I mentioned the narration of `Abdullah bin `Utba regarding the question of Subai'a bint Al-Harith. `Abdur-Rahman said, "But `Abdullah's uncle used not to say so." I said, "I am too brave if I tell a lie concerning a person who is now in Al-Kufa," and I raised my voice. Then I went out and met Malik bin 'Amir or Malik bin `Auf, and said, "What was the verdict of Ibn Mas`ud about the pregnant widow whose husband had died?" He replied, "Ibn Mas`ud said, 'Why do you impose on her the hard order and don't let her make use of the leave? The shorter Sura of women (i.e. Surat-at- Talaq) was revealed after the longer Sura (i.e. Surat-al-Baqara)." (i.e. Her 'Idda is until she delivers)}}
\hadithdefcmd{bukhari}{4533}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَزِيدُ، أَخْبَرَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم‏.‏ حَدَّثَنِي عَبْدُ الرَّحْمَنِ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ قَالَ هِشَامٌ حَدَّثَنَا قَالَ حَدَّثَنَا مُحَمَّدٌ عَنْ عَبِيدَةَ عَنْ عَلِيٍّ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ يَوْمَ الْخَنْدَقِ ‏ "‏ حَبَسُونَا عَنْ صَلاَةِ الْوُسْطَى حَتَّى غَابَتِ الشَّمْسُ مَلأَ اللَّهُ قُبُورَهُمْ وَبُيُوتَهُمْ أَوْ أَجْوَافَهُمْ ـ شَكَّ يَحْيَى ـ نَارًا ‏"‏‏.‏\hadithno{4533}\hadithtrans{Narrated `Ali (through two chains):On the day of Al-Khandaq (the battle of the Trench). the Prophet (ﷺ) said, "They (i.e. pagans prevented us from offering the middle (the Best) Prayer till the sun had set. May Allah fill their graves, their houses (or their bodies) with fire}}
\hadithdefcmd{bukhari}{4534}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ الْحَارِثِ بْنِ شُبَيْلٍ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ كُنَّا نَتَكَلَّمُ فِي الصَّلاَةِ يُكَلِّمُ أَحَدُنَا أَخَاهُ فِي حَاجَتِهِ حَتَّى نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏حَافِظُوا عَلَى الصَّلَوَاتِ وَالصَّلاَةِ الْوُسْطَى وَقُومُوا لِلَّهِ قَانِتِينَ‏\}‏ فَأُمِرْنَا بِالسُّكُوتِ‏.‏\hadithno{4534}\hadithtrans{Narrated Zaid bin Arqam:We used to speak while in prayer. One of us used to speak to his brother (while in prayer) about his need, till the Verse was revealed:-- "Guard strictly the (five obligatory) prayers, especially the middle (the Best) (`Asr) Prayer and stand before Allah with obedience (and not to speak to others during the prayers)." Then we were ordered not to speak in the prayers}}
\hadithdefcmd{bukhari}{4535}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ إِذَا سُئِلَ عَنْ صَلاَةِ الْخَوْفِ قَالَ يَتَقَدَّمُ الإِمَامُ وَطَائِفَةٌ مِنَ النَّاسِ فَيُصَلِّي بِهِمِ الإِمَامُ رَكْعَةً، وَتَكُونُ طَائِفَةٌ مِنْهُمْ بَيْنَهُمْ وَبَيْنَ الْعَدُوِّ لَمْ يُصَلُّوا، فَإِذَا صَلَّوُا الَّذِينَ مَعَهُ رَكْعَةً اسْتَأْخَرُوا مَكَانَ الَّذِينَ لَمْ يُصَلُّوا وَلاَ يُسَلِّمُونَ، وَيَتَقَدَّمُ الَّذِينَ لَمْ يُصَلُّوا فَيُصَلُّونَ مَعَهُ رَكْعَةً، ثُمَّ يَنْصَرِفُ الإِمَامُ وَقَدْ صَلَّى رَكْعَتَيْنِ، فَيَقُومُ كُلُّ وَاحِدٍ مِنَ الطَّائِفَتَيْنِ فَيُصَلُّونَ لأَنْفُسِهِمْ رَكْعَةً بَعْدَ أَنْ يَنْصَرِفَ الإِمَامُ، فَيَكُونُ كُلُّ وَاحِدٍ مِنَ الطَّائِفَتَيْنِ قَدْ صَلَّى رَكْعَتَيْنِ، فَإِنْ كَانَ خَوْفٌ هُوَ أَشَدَّ مِنْ ذَلِكَ صَلَّوْا رِجَالاً، قِيَامًا عَلَى أَقْدَامِهِمْ، أَوْ رُكْبَانًا مُسْتَقْبِلِي الْقِبْلَةِ أَوْ غَيْرَ مُسْتَقْبِلِيهَا‏.‏ قَالَ مَالِكٌ قَالَ نَافِعٌ لاَ أُرَى عَبْدَ اللَّهِ بْنَ عُمَرَ ذَكَرَ ذَلِكَ إِلاَّ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{4535}\hadithtrans{Narrated Nafi`:Whenever `Abdullah bin `Umar was asked about Salat-al-Khauf (i.e. prayer of fear) he said, "The Imam comes forward with a group of people and leads them in a one rak`a prayer while another group from them who has not prayed yet, stay between the praying group and the enemy. When those who are with the Imam have finished their one rak`a, they retreat and take the positions of those who have not prayed but they will not finish their prayers with Taslim. Those who have not prayed, come forward to offer a rak`a with the Imam (while the first group covers them from the enemy). Then the Imam, having offered two rak`at, finishes his prayer. Then each member of the two groups offer the second rak`a alone after the Imam has finished his prayer. Thus each one of the two groups will have offered two rak`at. But if the fear is too great, they can pray standing on their feet or riding on their mounts, facing the Qibla or not." Nafi` added: I do not think that `Abdullah bin `Umar narrated this except from Allah's Messenger (ﷺ) (See Hadith No. 451, Vol 5 to know exactly "The Fear Prayer)}}
\hadithdefcmd{bukhari}{4536}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا حُمَيْدُ بْنُ الأَسْوَدِ، وَيَزِيدُ بْنُ زُرَيْعٍ، قَالاَ حَدَّثَنَا حَبِيبُ بْنُ الشَّهِيدِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ قَالَ ابْنُ الزُّبَيْرِ قُلْتُ لِعُثْمَانَ هَذِهِ الآيَةُ الَّتِي فِي الْبَقَرَةِ ‏\{‏وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا‏\}‏ إِلَى قَوْلِهِ ‏\{‏غَيْرَ إِخْرَاجٍ‏\}‏ قَدْ نَسَخَتْهَا الأُخْرَى، فَلِمَ تَكْتُبُهَا قَالَ تَدَعُهَا‏.‏ يَا ابْنَ أَخِي لاَ أُغَيِّرُ شَيْئًا مِنْهُ مِنْ مَكَانِهِ‏.‏ قَالَ حُمَيْدٌ أَوْ نَحْوَ هَذَا‏.‏\hadithno{4536}\hadithtrans{Narrated Ibn Az-Zubair:I said to `Uthman, "This Verse which is in Surat-al-Baqara: "Those of you who die and leave widows behind...without turning them out." has been abrogated by another Verse. Why then do you write it (in the Qur'an)?" `Uthman said. "Leave it (where it is), O the son of my brother, for I will not shift anything of it (i.e. the Qur'an) from its original position}}
\hadithdefcmd{bukhari}{4537}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَسَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَحْنُ أَحَقُّ بِالشَّكِّ مِنْ إِبْرَاهِيمَ إِذْ قَالَ ‏\{‏رَبِّ أَرِنِي كَيْفَ تُحْيِي الْمَوْتَى قَالَ أَوَلَمْ تُؤْمِنْ قَالَ بَلَى وَلَكِنْ لِيَطْمَئِنَّ قَلْبِي‏\}‏‏"‏\hadithno{4537}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "We have more right to be in doubt than Abraham when he said, 'My Lord! Show me how You give life to the dead.' He said, 'Do you not believe?' He said, 'Yes (I believe) but to be stronger in Faith}}
\hadithdefcmd{bukhari}{4538}{حَدَّثَنَا إِبْرَاهِيمُ، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي مُلَيْكَةَ، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ،‏.‏ قَالَ وَسَمِعْتُ أَخَاهُ أَبَا بَكْرِ بْنَ أَبِي مُلَيْكَةَ، يُحَدِّثُ عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، قَالَ قَالَ عُمَرُ ـ رضى الله عنه ـ يَوْمًا لأَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِيمَ تَرَوْنَ هَذِهِ الآيَةَ نَزَلَتْ ‏\{‏أَيَوَدُّ أَحَدُكُمْ أَنْ تَكُونَ لَهُ جَنَّةٌ‏\}‏ قَالُوا اللَّهُ أَعْلَمُ‏.‏ فَغَضِبَ عُمَرُ فَقَالَ قُولُوا نَعْلَمُ أَوْ لاَ نَعْلَمُ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ فِي نَفْسِي مِنْهَا شَىْءٌ يَا أَمِيرَ الْمُؤْمِنِينَ‏.‏ قَالَ عُمَرُ يَا ابْنَ أَخِي قُلْ وَلاَ تَحْقِرْ نَفْسَكَ‏.‏ قَالَ ابْنُ عَبَّاسٍ ضُرِبَتْ مَثَلاً لِعَمَلٍ‏.‏ قَالَ عُمَرُ أَىُّ عَمَلٍ قَالَ ابْنُ عَبَّاسٍ لِعَمَلٍ‏.‏ قَالَ عُمَرُ لِرَجُلٍ غَنِيٍّ يَعْمَلُ بِطَاعَةِ اللَّهِ عَزَّ وَجَلَّ، ثُمَّ بَعَثَ اللَّهُ لَهُ الشَّيْطَانَ فَعَمِلَ بِالْمَعَاصِي حَتَّى أَغْرَقَ أَعْمَالَهُ‏.‏ ‏\{‏فَصُرْهُنَّ‏\}‏ قَطِّعْهُنَّ‏.‏\hadithno{4538}\hadithtrans{Narrated Ubaid bin Umair:Once `Umar (bin Al-Khattab) said to the companions of the Prophet (ﷺ) "What do you think about this Verse:--"Does any of you wish that he should have a garden?" They replied, "Allah knows best." `Umar became angry and said, "Either say that you know or say that you do not know!" On that Ibn `Abbas said, "O chief of the believers! I have something in my mind to say about it." `Umar said, "O son of my brother! Say, and do not under estimate yourself." Ibn `Abbas said, "This Verse has been set up as an example for deeds." `Umar said, "What kind of deeds?" Ibn `Abbas said, "For deeds." `Umar said, "This is an example for a rich man who does good out of obedience of Allah and then Allah sends him Satan whereupon he commits sins till all his good deeds are lost}}
\hadithdefcmd{bukhari}{4539}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي شَرِيكُ بْنُ أَبِي نَمِرٍ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، وَعَبْدَ الرَّحْمَنِ بْنَ أَبِي عَمْرَةَ الأَنْصَارِيَّ، قَالاَ سَمِعْنَا أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَيْسَ الْمِسْكِينُ الَّذِي تَرُدُّهُ التَّمْرَةُ وَالتَّمْرَتَانِ وَلاَ اللُّقْمَةُ وَلاَ اللُّقْمَتَانِ‏.‏ إِنَّمَا الْمِسْكِينُ الَّذِي يَتَعَفَّفُ وَاقْرَءُوا إِنْ شِئْتُمْ يَعْنِي قَوْلَهُ ‏\{‏لاَ يَسْأَلُونَ النَّاسَ إِلْحَافًا‏\}‏‏"‏\hadithno{4539}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The poor person is not the one for whom a date or two or a morsel or two (of food is sufficient but the poor person is he who does not (beg or) ask the people (for something) or show his poverty at all. Recite if you wish, (Allah's Statement): "They do not beg of people at all}}
\hadithdefcmd{bukhari}{4540}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا مُسْلِمٌ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا نَزَلَتِ الآيَاتُ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي الرِّبَا قَرَأَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النَّاسِ، ثُمَّ حَرَّمَ التِّجَارَةَ فِي الْخَمْرِ‏.‏\hadithno{4540}\hadithtrans{Narrated `Aisha:When the Verses of Surat-al-Baqara regarding usury (i.e. Riba) were revealed, Allah's Messenger (ﷺ) recited them before the people and then he prohibited the trade of alcoholic liquors}}
\hadithdefcmd{bukhari}{4541}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، سَمِعْتُ أَبَا الضُّحَى، يُحَدِّثُ عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ لَمَّا أُنْزِلَتِ الآيَاتُ الأَوَاخِرُ مِنْ سُورَةِ الْبَقَرَةِ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَلاَهُنَّ فِي الْمَسْجِدِ، فَحَرَّمَ التِّجَارَةَ فِي الْخَمْرِ‏.‏\hadithno{4541}\hadithtrans{Narrated `Aisha:When the last Verses of Surat-al-Baqara were revealed. Allah's Messenger (ﷺ) went out and recited them in the Mosque and prohibited the trade of alcoholic liquors}}
\hadithdefcmd{bukhari}{4542}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا أُنْزِلَتِ الآيَاتُ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ قَرَأَهُنَّ النَّبِيُّ صلى الله عليه وسلم فِي الْمَسْجِدِ، وَحَرَّمَ التِّجَارَةَ فِي الْخَمْرِ‏.‏\hadithno{4542}\hadithtrans{Narrated `Aisha:When the last Verses of Surat-al-Baqara were revealed, the Prophet (ﷺ) read them in the Mosque and prohibited the trade of alcoholic liquors}}
\hadithdefcmd{bukhari}{4543}{وَقَالَ لَنَا مُحَمَّدُ بْنُ يُوسُفَ عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا أُنْزِلَتِ الآيَاتُ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَرَأَهُنَّ عَلَيْنَا، ثُمَّ حَرَّمَ التِّجَارَةَ فِي الْخَمْرِ‏.‏\hadithno{4543}\hadithtrans{Narrated `Aisha:When the last Verses of Surat-al-Baqara were revealed, Allah's Messenger (ﷺ) stood up and recited them before us and then prohibited the trade of alcoholic liquors}}
\hadithdefcmd{bukhari}{4544}{حَدَّثَنَا قَبِيصَةُ بْنُ عُقْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ آخِرُ آيَةٍ نَزَلَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم آيَةُ الرِّبَا‏.‏\hadithno{4544}\hadithtrans{Narrated Ibn `Abbas:The last Verse (in the Qur'an) revealed to the Prophet (ﷺ) was the Verse dealing with usury (i.e. Riba)}}
\hadithdefcmd{bukhari}{4545}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مِسْكِينٌ، عَنْ شُعْبَةَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ مَرْوَانَ الأَصْفَرِ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَهْوَ ابْنُ عُمَرَ أَنَّهَا قَدْ نُسِخَتْ ‏\{‏وَإِنْ تُبْدُوا مَا فِي أَنْفُسِكُمْ أَوْ تُخْفُوهُ‏\}‏ الآيَةَ‏.‏\hadithno{4545}\hadithtrans{Narrated Ibn `Umar:This Verse:--"Whether you show what is in your minds or conceal it.." (2.284) was abrogated}}
\hadithdefcmd{bukhari}{4546}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا رَوْحٌ، أَخْبَرَنَا شُعْبَةُ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ مَرْوَانَ الأَصْفَرِ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم ـ قَالَ أَحْسِبُهُ ابْنَ عُمَرَ ـ ‏\{‏إِنْ تُبْدُوا مَا فِي أَنْفُسِكُمْ أَوْ تُخْفُوهُ‏\}‏ قَالَ نَسَخَتْهَا الآيَةُ الَّتِي بَعْدَهَا‏.‏\hadithno{4546}\hadithtrans{Narrated Marwan Al-Asfar:A man from the companions of Allah's Messenger (ﷺ) who I think, was Ibn `Umar said, "The Verse:-- "Whether you show what is in your minds or conceal it...." was abrogated by the Verse following it}}
\hadithdefcmd{bukhari}{4547}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا يَزِيدُ بْنُ إِبْرَاهِيمَ التُّسْتَرِيُّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ تَلاَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَذِهِ الآيَةَ ‏\{‏هُوَ الَّذِي أَنْزَلَ عَلَيْكَ الْكِتَابَ مِنْهُ آيَاتٌ مُحْكَمَاتٌ هُنَّ أُمُّ الْكِتَابِ وَأُخَرُ مُتَشَابِهَاتٌ فَأَمَّا الَّذِينَ فِي قُلُوبِهِمْ زَيْغٌ فَيَتَّبِعُونَ مَا تَشَابَهَ مِنْهُ ابْتِغَاءَ الْفِتْنَةِ وَابْتِغَاءَ تَأْوِيلِهِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏أُولُو الأَلْبَابِ‏\}‏ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِذَا رَأَيْتَ الَّذِينَ يَتَّبِعُونَ مَا تَشَابَهَ مِنْهُ، فَأُولَئِكَ الَّذِينَ سَمَّى اللَّهُ، فَاحْذَرُوهُمْ ‏"‏‏.‏\hadithno{4547}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) recited the Verse:-- "It is He who has sent down to you the Book. In it are Verses that are entirely clear, they are the foundation of the Book, others not entirely clear. So as for those in whose hearts there is a deviation (from the Truth ). follow thereof that is not entirely clear seeking affliction and searching for its hidden meanings; but no one knows its hidden meanings but Allah. And those who are firmly grounded in knowledge say: "We believe in it (i.e. in the Qur'an) the whole of it (i.e. its clear and unclear Verses) are from our Lord. And none receive admonition except men of understanding." (3.7) Then Allah's Messenger (ﷺ) said, "If you see those who follow thereof that is not entirely clear, then they are those whom Allah has named [as having deviation (from the Truth)] 'So beware of them}}
\hadithdefcmd{bukhari}{4548}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ مَوْلُودٍ يُولَدُ إِلاَّ وَالشَّيْطَانُ يَمَسُّهُ حِينَ يُولَدُ، فَيَسْتَهِلُّ صَارِخًا مِنْ مَسِّ الشَّيْطَانِ إِيَّاهُ، إِلاَّ مَرْيَمَ وَابْنَهَا ‏"‏‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏وَإِنِّي أُعِيذُهَا بِكَ وَذُرِّيَّتَهَا مِنَ الشَّيْطَانِ الرَّجِيمِ ‏\}‏\hadithno{4548}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:Abu Huraira said, "The Prophet (ﷺ) said, 'No child is born but that, Satan touches it when it is born whereupon it starts crying loudly because of being touched by Satan, except Mary and her son." Abu Huraira then said, "Recite, if you wish: "And I seek Refuge with You (Allah) for her and her offspring from Satan, the outcast}}
\hadithdefcmd{bukhari}{4550}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ يَمِينَ صَبْرٍ لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً أُولَئِكَ لاَ خَلاَقَ لَهُمْ فِي الآخِرَةِ‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏ قَالَ فَدَخَلَ الأَشْعَثُ بْنُ قَيْسٍ وَقَالَ مَا يُحَدِّثُكُمْ أَبُو عَبْدِ الرَّحْمَنِ قُلْنَا كَذَا وَكَذَا‏.‏ قَالَ فِيَّ أُنْزِلَتْ كَانَتْ لِي بِئْرٌ فِي أَرْضِ ابْنِ عَمٍّ لِي قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بَيِّنَتُكَ أَوْ يَمِينُهُ ‏"‏ فَقُلْتُ إِذًا يَحْلِفَ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينِ صَبْرٍ يَقْتَطِعُ بِهَا مَالَ امْرِئٍ مُسْلِمٍ وَهْوَ فِيهَا فَاجِرٌ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانٌ ‏"‏‏.‏\hadithno{4550}\hadithtrans{Narrated Abu Wail:`Abdullah bin Masud said, "Allah's Messenger (ﷺ) said, 'Whoever takes an oath when asked to do so, in which he may deprive a Muslim of his property unlawfully, will meet Allah Who will be angry with him.' So Allah revealed in confirmation of this statement:--"Verily! Those who Purchase a small gain at the cost of Allah's Covenant and oaths, they shall have no portion in the Hereafter..." (3.77) Then entered Al-Ash'ath bin Qais and said, "What is Abu `Abdur-Rahman narrating to you?" We replied, 'So-and-so." Al-Ash'ath said, "This Verse was revealed in my connection. I had a well in the land of my cousin (and he denied my, possessing it). On that the Prophet (ﷺ) said to me, 'Either you bring forward a proof or he (i.e. your cousin) takes an oath (to confirm his claim)' I said, 'I am sure he would take a (false) oath, O Allah's Messenger (ﷺ).' He said, 'If somebody takes an oath when asked to do so through which he may deprive a Muslim of his property (unlawfully) and he is a liar in his oath, he will meet Allah Who will be angry with him}}
\hadithdefcmd{bukhari}{4551}{حَدَّثَنَا عَلِيٌّ ـ هُوَ ابْنُ أَبِي هَاشِمٍ ـ سَمِعَ هُشَيْمًا، أَخْبَرَنَا الْعَوَّامُ بْنُ حَوْشَبٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ـ رضى الله عنهما ـ أَنَّ رَجُلاً، أَقَامَ سِلْعَةً فِي السُّوقِ فَحَلَفَ فِيهَا لَقَدْ أَعْطَى بِهَا مَا لَمْ يُعْطَهُ‏.‏ لِيُوقِعَ فِيهَا رَجُلاً مِنَ الْمُسْلِمِينَ، فَنَزَلَتْ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏\hadithno{4551}\hadithtrans{Narrated `Abdullah bin Abu `Aufa:A man displayed some merchandise in the market and took an oath that he had been offered a certain price for it while in fact he had not, in order to cheat a man from the Muslims. So then was revealed:-- "Verily! Those who purchase a small gain at the cost of Allah's Covenant and their oaths}}
\hadithdefcmd{bukhari}{4552}{حَدَّثَنَا نَصْرُ بْنُ عَلِيِّ بْنِ نَصْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ امْرَأَتَيْنِ، كَانَتَا تَخْرِزَانِ فِي بَيْتٍ ـ أَوْ فِي الْحُجْرَةِ ـ فَخَرَجَتْ إِحْدَاهُمَا وَقَدْ أُنْفِذَ بِإِشْفًى فِي كَفِّهَا، فَادَّعَتْ عَلَى الأُخْرَى، فَرُفِعَ إِلَى ابْنِ عَبَّاسٍ، فَقَالَ ابْنُ عَبَّاسٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ يُعْطَى النَّاسُ بِدَعْوَاهُمْ لَذَهَبَ دِمَاءُ قَوْمٍ وَأَمْوَالُهُمْ ‏"‏‏.‏ ذَكِّرُوهَا بِاللَّهِ وَاقْرَءُوا عَلَيْهَا ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ‏\}‏‏.‏ فَذَكَّرُوهَا فَاعْتَرَفَتْ، فَقَالَ ابْنُ عَبَّاسٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْيَمِينُ عَلَى الْمُدَّعَى عَلَيْهِ ‏"‏‏.‏\hadithno{4552}\hadithtrans{Narrated Ibn Abu Mulaika:Two women were stitching shoes in a house or a room. Then one of them came out with an awl driven into her hand, and she sued the other for it. The case was brought before Ibn `Abbas, Ibn `Abbas said, "Allah's Messenger (ﷺ) said, 'If people were to be given what they claim (without proving their claim) the life and property of the nation would be lost.' Will you remind her (i.e. the defendant), of Allah and recite before her:--"Verily! Those who purchase a small gain at the cost of Allah's Covenant and their oaths..."(3.77) So they reminded her and she confessed. Ibn `Abbas then said, "The Prophet (ﷺ) said, 'The oath is to be taken by the defendant (in the absence of any proof against him)}}
\hadithdefcmd{bukhari}{4553}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، عَنْ هِشَامٍ، عَنْ مَعْمَرٍ،‏.‏ وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، قَالَ حَدَّثَنِي ابْنُ عَبَّاسٍ، قَالَ حَدَّثَنِي أَبُو سُفْيَانَ، مِنْ فِيهِ إِلَى فِيَّ قَالَ انْطَلَقْتُ فِي الْمُدَّةِ الَّتِي كَانَتْ بَيْنِي وَبَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم ـ قَالَ ـ فَبَيْنَا أَنَا بِالشَّأْمِ إِذْ جِيءَ بِكِتَابٍ مِنَ النَّبِيِّ صلى الله عليه وسلم إِلَى هِرَقْلَ قَالَ وَكَانَ دِحْيَةُ الْكَلْبِيُّ جَاءَ بِهِ فَدَفَعَهُ إِلَى عَظِيمِ بُصْرَى، فَدَفَعَهُ عَظِيمُ بُصْرَى إِلَى ـ هِرَقْلَ ـ قَالَ فَقَالَ هِرَقْلُ هَلْ هَا هُنَا أَحَدٌ مِنْ قَوْمِ هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ فَقَالُوا نَعَمْ‏.‏ قَالَ فَدُعِيتُ فِي نَفَرٍ مِنْ قُرَيْشٍ فَدَخَلْنَا عَلَى هِرَقْلَ، فَأُجْلِسْنَا بَيْنَ يَدَيْهِ فَقَالَ أَيُّكُمْ أَقْرَبُ نَسَبًا مِنْ هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ فَقَالَ أَبُو سُفْيَانَ فَقُلْتُ أَنَا‏.‏ فَأَجْلَسُونِي بَيْنَ يَدَيْهِ، وَأَجْلَسُوا أَصْحَابِي خَلْفِي، ثُمَّ دَعَا بِتُرْجُمَانِهِ فَقَالَ قُلْ لَهُمْ إِنِّي سَائِلٌ هَذَا عَنْ هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ، فَإِنْ كَذَبَنِي فَكَذِّبُوهُ‏.‏ قَالَ أَبُو سُفْيَانَ وَايْمُ اللَّهِ، لَوْلاَ أَنْ يُؤْثِرُوا عَلَىَّ الْكَذِبَ لَكَذَبْتُ‏.‏ ثُمَّ قَالَ لِتُرْجُمَانِهِ سَلْهُ كَيْفَ حَسَبُهُ فِيكُمْ قَالَ قُلْتُ هُوَ فِينَا ذُو حَسَبٍ‏.‏ قَالَ فَهَلْ كَانَ مِنْ آبَائِهِ مَلِكٌ قَالَ قُلْتُ لاَ‏.‏ قَالَ فَهَلْ كُنْتُمْ تَتَّهِمُونَهُ بِالْكَذِبِ قَبْلَ أَنْ يَقُولَ مَا قَالَ قُلْتُ لاَ‏.‏ قَالَ أَيَتَّبِعُهُ أَشْرَافُ النَّاسِ أَمْ ضُعَفَاؤُهُمْ قَالَ قُلْتُ بَلْ ضُعَفَاؤُهُمْ‏.‏ قَالَ يَزِيدُونَ أَوْ يَنْقُصُونَ قَالَ قُلْتُ لاَ بَلْ يَزِيدُونَ‏.‏ قَالَ هَلْ يَرْتَدُّ أَحَدٌ مِنْهُمْ عَنْ دِينِهِ، بَعْدَ أَنْ يَدْخُلَ فِيهِ، سَخْطَةً لَهُ قَالَ قُلْتُ لاَ‏.‏ قَالَ فَهَلْ قَاتَلْتُمُوهُ قَالَ قُلْتُ نَعَمْ‏.‏ قَالَ فَكَيْفَ كَانَ قِتَالُكُمْ إِيَّاهُ قَالَ قُلْتُ تَكُونُ الْحَرْبُ بَيْنَنَا وَبَيْنَهُ سِجَالاً، يُصِيبُ مِنَّا وَنُصِيبُ مِنْهُ‏.‏ قَالَ فَهَلْ يَغْدِرُ قَالَ قُلْتُ لاَ وَنَحْنُ مِنْهُ فِي هَذِهِ الْمُدَّةِ لاَ نَدْرِي مَا هُوَ صَانِعٌ فِيهَا‏.‏ قَالَ وَاللَّهِ مَا أَمْكَنَنِي مِنْ كَلِمَةٍ أُدْخِلُ فِيهَا شَيْئًا غَيْرَ هَذِهِ‏.‏ قَالَ فَهَلْ قَالَ هَذَا الْقَوْلَ أَحَدٌ قَبْلَهُ قُلْتُ لاَ‏.‏ ثُمَّ قَالَ لِتُرْجُمَانِهِ قُلْ لَهُ إِنِّي سَأَلْتُكَ عَنْ حَسَبِهِ فِيكُمْ، فَزَعَمْتَ أَنَّهُ فِيكُمْ ذُو حَسَبٍ، وَكَذَلِكَ الرُّسُلُ تُبْعَثُ فِي أَحْسَابِ قَوْمِهَا، وَسَأَلْتُكَ هَلْ كَانَ فِي آبَائِهِ مَلِكٌ فَزَعَمْتَ أَنْ لاَ فَقُلْتُ لَوْ كَانَ مِنْ آبَائِهِ مَلِكٌ قُلْتُ رَجُلٌ يَطْلُبُ مُلْكَ آبَائِهِ، وَسَأَلْتُكَ عَنْ أَتْبَاعِهِ أَضُعَفَاؤُهُمْ أَمْ أَشْرَافُهُمْ فَقُلْتَ بَلْ ضُعَفَاؤُهُمْ، وَهُمْ أَتْبَاعُ الرُّسُلِ، وَسَأَلْتُكَ هَلْ كُنْتُمْ تَتَّهِمُونَهُ بِالْكَذِبِ قَبْلَ أَنْ يَقُولَ مَا قَالَ فَزَعَمْتَ أَنْ لاَ، فَعَرَفْتُ أَنَّهُ لَمْ يَكُنْ لِيَدَعَ الْكَذِبَ عَلَى النَّاسِ ثُمَّ يَذْهَبَ فَيَكْذِبَ عَلَى اللَّهِ، وَسَأَلْتُكَ هَلْ يَرْتَدُّ أَحَدٌ مِنْهُمْ عَنْ دِينِهِ بَعْدَ أَنْ يَدْخُلَ فِيهِ سَخْطَةً لَهُ فَزَعَمْتَ أَنْ لاَ، وَكَذَلِكَ الإِيمَانُ إِذَا خَالَطَ بَشَاشَةَ الْقُلُوبِ، وَسَأَلْتُكَ هَلْ يَزِيدُونَ أَمْ يَنْقُصُونَ فَزَعَمْتَ أَنَّهُمْ يَزِيدُونَ، وَكَذَلِكَ الإِيمَانُ حَتَّى يَتِمَّ، وَسَأَلْتُكَ هَلْ قَاتَلْتُمُوهُ فَزَعَمْتَ أَنَّكُمْ قَاتَلْتُمُوهُ فَتَكُونُ الْحَرْبُ بَيْنَكُمْ وَبَيْنَهُ سِجَالاً، يَنَالُ مِنْكُمْ وَتَنَالُونَ مِنْهُ، وَكَذَلِكَ الرُّسُلُ تُبْتَلَى، ثُمَّ تَكُونُ لَهُمُ الْعَاقِبَةُ، وَسَأَلْتُكَ هَلْ يَغْدِرُ فَزَعَمْتَ أَنَّهُ لاَ يَغْدِرُ، وَكَذَلِكَ الرُّسُلُ لاَ تَغْدِرُ، وَسَأَلْتُكَ هَلْ قَالَ أَحَدٌ هَذَا الْقَوْلَ قَبْلَهُ فَزَعَمْتَ أَنْ لاَ، فَقُلْتُ لَوْ كَانَ قَالَ هَذَا الْقَوْلَ أَحَدٌ قَبْلَهُ قُلْتُ رَجُلٌ ائْتَمَّ بِقَوْلٍ قِيلَ قَبْلَهُ‏.‏ قَالَ ثُمَّ قَالَ بِمَ يَأْمُرُكُمْ قَالَ قُلْتُ يَأْمُرُنَا بِالصَّلاَةِ وَالزَّكَاةِ وَالصِّلَةِ وَالْعَفَافِ‏.‏ قَالَ إِنْ يَكُ مَا تَقُولُ فِيهِ حَقًّا فَإِنَّهُ نَبِيٌّ، وَقَدْ كُنْتُ أَعْلَمُ أَنَّهُ خَارِجٌ، وَلَمْ أَكُ أَظُنُّهُ مِنْكُمْ، وَلَوْ أَنِّي أَعْلَمُ أَنِّي أَخْلُصُ إِلَيْهِ لأَحْبَبْتُ لِقَاءَهُ، وَلَوْ كُنْتُ عِنْدَهُ لَغَسَلْتُ عَنْ قَدَمَيْهِ، وَلَيَبْلُغَنَّ مُلْكُهُ مَا تَحْتَ قَدَمَىَّ‏.‏ قَالَ ثُمَّ دَعَا بِكِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَرَأَهُ، فَإِذَا فِيهِ ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ، إِلَى هِرَقْلَ عَظِيمِ الرُّومِ، سَلاَمٌ عَلَى مَنِ اتَّبَعَ الْهُدَى، أَمَّا بَعْدُ، فَإِنِّي أَدْعُوكَ بِدِعَايَةِ الإِسْلاَمِ، أَسْلِمْ تَسْلَمْ، وَأَسْلِمْ يُؤْتِكَ اللَّهُ أَجْرَكَ مَرَّتَيْنِ، فَإِنْ تَوَلَّيْتَ فَإِنَّ عَلَيْكَ إِثْمَ الأَرِيسِيِّينَ، وَ‏\{‏يَا أَهْلَ الْكِتَابِ تَعَالَوْا إِلَى كَلِمَةٍ سَوَاءٍ بَيْنَنَا وَبَيْنَكُمْ أَنْ لاَ نَعْبُدَ إِلاَّ اللَّهَ‏\}‏ إِلَى قَوْلِهِ ‏\{‏اشْهَدُوا بِأَنَّا مُسْلِمُونَ‏\}‏‏"‏‏.‏ فَلَمَّا فَرَغَ مِنْ قِرَاءَةِ الْكِتَابِ ارْتَفَعَتِ الأَصْوَاتُ عِنْدَهُ، وَكَثُرَ اللَّغَطُ، وَأُمِرَ بِنَا فَأُخْرِجْنَا قَالَ فَقُلْتُ لأَصْحَابِي حِينَ خَرَجْنَا لَقَدْ أَمِرَ أَمْرُ ابْنِ أَبِي كَبْشَةَ، أَنَّهُ لَيَخَافُهُ مَلِكُ بَنِي الأَصْفَرِ فَمَا زِلْتُ مُوقِنًا بِأَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سَيَظْهَرُ حَتَّى أَدْخَلَ اللَّهُ عَلَىَّ الإِسْلاَمَ‏.‏ قَالَ الزُّهْرِيُّ فَدَعَا هِرَقْلُ عُظَمَاءَ الرُّومِ فَجَمَعَهُمْ فِي دَارٍ لَهُ فَقَالَ يَا مَعْشَرَ الرُّومِ، هَلْ لَكُمْ فِي الْفَلاَحِ وَالرَّشَدِ آخِرَ الأَبَدِ، وَأَنْ يَثْبُتَ لَكُمْ مُلْكُكُمْ قَالَ فَحَاصُوا حَيْصَةَ حُمُرِ الْوَحْشِ إِلَى الأَبْوَابِ، فَوَجَدُوهَا قَدْ غُلِقَتْ، فَقَالَ عَلَىَّ بِهِمْ‏.‏ فَدَعَا بِهِمْ فَقَالَ إِنِّي إِنَّمَا اخْتَبَرْتُ شِدَّتَكُمْ عَلَى دِينِكُمْ، فَقَدْ رَأَيْتُ مِنْكُمُ الَّذِي أَحْبَبْتُ‏.‏ فَسَجَدُوا لَهُ وَرَضُوا عَنْهُ‏.‏\hadithno{4553}\hadithtrans{Narrated Ibn `Abbas:Abu Sufyan narrated to me personally, saying, "I set out during the Truce that had been concluded between me and Allah's Messenger (ﷺ). While I was in Sham, a letter sent by the Prophet (ﷺ) was brought to Heraclius. Dihya Al-Kalbi had brought and given it to the governor of Busra, and the latter forwarded it to Heraclius. Heraclius said, 'Is there anyone from the people of this man who claims to be a prophet?' The people replied, 'Yes.' So I along with some of Quraishi men were called and we entered upon Heraclius, and we were seated in front of him. Then he said, 'Who amongst you is the nearest relative to the man who claims to be a prophet?' So they made me sit in front of him and made my companions sit behind me. Then he called upon his translator and said (to him), 'Tell them (i.e. Abu Sufyan's companions) that I am going to ask him (i.e. Abu Sufyan) regarding that man who claims to be a prophet. So, if he tells me a lie, they should contradict him (instantly).' By Allah, had I not been afraid that my companions would consider me a liar, I would have told lies. Heraclius then said to his translator, 'Ask him: What is his (i.e. the Prophet's) family status amongst you? I said, 'He belongs to a noble family amongst us." Heraclius said, 'Was any of his ancestors a king?' I said, 'No.' He said, 'Did you ever accuse him of telling lies before his saying what he has said?' I said, 'No.' He said, 'Do the nobles follow him or the poor people?' I said, 'It is the poor who followed him.' He said, 'Is the number of his followers increasing or decreasing?' I said, 'They are increasing.' He said, 'Does anyone renounce his religion (i.e. Islam) after embracing it, being displeased with it?' I said, 'No.' He said, 'Did you fight with him?' I replied, 'Yes.' He said, 'How was your fighting with him?' I said, 'The fighting between us was undecided and victory was shared by him and us by turns. He inflicts casualties upon us and we inflict casualties upon him.' He said, 'Did he ever betray?' I said, 'No, but now we are away from him in this truce and we do not know what he will do in it" Abu Sufyan added, "By Allah, I was not able to insert in my speech a word (against him) except that. Heraclius said, 'Did anybody else (amongst you) ever claim the same (i.e. Islam) before him?' I said, 'No.' Then Heraclius told his translator to tell me (i.e. Abu Sufyan), 'I asked you about his family status amongst you, and you told me that he comes from a noble family amongst you. Verily, all Apostles come from the noblest family among their people. Then I asked you whether any of his ancestors was a king, and you denied that. Thereupon I thought that had one of his fore-fathers been a king, I would have said that he (i.e. Muhammad) was seeking to rule the kingdom of his fore-fathers. Then I asked you regarding his followers, whether they were the noble or the poor among the people, and you said that they were only the poor (who follow him). In fact, such are the followers of the Apostles. Then I asked you whether you have ever accused him of telling lies before saying what he said, and your reply was in the negative. Therefore, I took for granted that a man who did not tell a lie about others, could ever tell a lie about Allah. Then I asked you whether anyone of his followers had renounced his religion (i.e. Islam) after embracing it, being displeased with it, and you denied that. And such is Faith when it mixes with the cheerfulness of the hearts. Then I asked you whether his followers were increasing or decreasing. You claimed that they were increasing. That is the way of true faith till it is complete. Then I asked you whether you had ever fought with him, and you claimed that you had fought with him and the battle between you and him was undecided and the victory was shared by you and him in turns; he inflicted casualties upon you and you inflicted casualties upon them. Such is the case with the Apostles; they are put to test and the final victory is for them. Then I asked you whether he had ever betrayed; you claimed that he had never betrayed. Indeed, Apostles never betray. Then I asked you whether anyone had said this statement before him; and you denied that. Thereupon I thought if somebody had said that statement before him, then I would have said that he was but a man copying some sayings said before him." Abu Sufyan said, "Heraclius then asked me, 'What does he order you to do?' I said, 'He orders us (to offer) prayers and (to pay) Zakat and to keep good relationship with the Kith and kin and to be chaste.' Then Heraclius said, 'If whatever you have said, is true, he is really a prophet, and I knew that he ( i.e. the Prophet (ﷺ) ) was going to appear, but I never thought that he would be from amongst you. If I were certain that I can reach him, I would like to meet him and if I were with him, I would wash his feet; and his kingdom will expand (surely to what is under my feet).' Then Heraclius asked for the letter of Allah's Messenger (ﷺ) and read it wherein was written: "In the Name of Allah, the Most Beneficent, the Most Merciful. This letter is from Muhammad, Apostle of Allah, to Heraclius, the sovereign of Byzantine........ Peace be upon him who follows the Right Path. Now then, I call you to embrace Islam. Embrace Islam and you will be saved (from Allah's Punishment); embrace Islam, and Allah will give you a double reward, but if you reject this, you will be responsible for the sins of the tillers (i.e. the people of your kingdom) and (Allah's Statement):--"O the people of the Scripture (Jews and Christians)! Come to a word common to you and us that we worship None but Allah....bear witness that we are Muslims.' (3.64) When he finished reading the letter, voices grew louder near him and there was a great hue and cry, and we were ordered to go out." Abu Sufyan added, "While coming out, I said to my companions, 'The situation of Ibn Abu Kabsha (i.e. Muhammad) has become strong; even the king of Banu Al-Asfar is afraid of him.' So I continued to believe that Allah's Messenger (ﷺ) would be victorious, till Allah made me embrace Islam." Az-Zuhri said, "Heraclius then invited all the chiefs of the Byzantines and had them assembled in his house and said, 'O group of Byzantines! Do you wish to have a permanent success and guidance and that your kingdom should remain with you?' (Immediately after hearing that), they rushed towards the gate like onagers, but they found them closed. Heraclius then said, 'Bring them back to me.' So he called them and said, 'I just wanted to test the strength of your adherence to your religion. Now I have observed of you that which I like.' Then the people fell in prostration before him and became pleased with him." (See Hadith No. 6,Vol)}}
\hadithdefcmd{bukhari}{4554}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ كَانَ أَبُو طَلْحَةَ أَكْثَرَ أَنْصَارِيٍّ بِالْمَدِينَةِ نَخْلاً، وَكَانَ أَحَبَّ أَمْوَالِهِ إِلَيْهِ بَيْرُحَاءٍ، وَكَانَتْ مُسْتَقْبِلَةَ الْمَسْجِدِ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُهَا وَيَشْرَبُ مِنْ مَاءٍ فِيهَا طَيِّبٍ، فَلَمَّا أُنْزِلَتْ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ قَامَ أَبُو طَلْحَةَ فَقَالَ يَا رَسُولَ اللَّهِ، إِنَّ اللَّهَ يَقُولُ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ وَإِنَّ أَحَبَّ أَمْوَالِي إِلَىَّ بَيْرُحَاءٍ وَإِنَّهَا صَدَقَةٌ لِلَّهِ، أَرْجُو بِرَّهَا وَذُخْرَهَا عِنْدَ اللَّهِ، فَضَعْهَا يَا رَسُولَ اللَّهِ حَيْثُ أَرَاكَ اللَّهُ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَخْ، ذَلِكَ مَالٌ رَايِحٌ، ذَلِكَ مَالٌ رَايِحٌ، وَقَدْ سَمِعْتُ مَا قُلْتَ، وَإِنِّي أَرَى أَنْ تَجْعَلَهَا فِي الأَقْرَبِينَ ‏"‏‏.‏ قَالَ أَبُو طَلْحَةَ أَفْعَلُ يَا رَسُولَ اللَّهِ‏.‏ فَقَسَمَهَا أَبُو طَلْحَةَ فِي أَقَارِبِهِ وَبَنِي عَمِّهِ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ يُوسُفَ وَرَوْحُ بْنُ عُبَادَةَ ‏"‏ ذَلِكَ مَالٌ رَابِحٌ ‏"‏‏.‏ حَدَّثَنِي يَحْيَى بْنُ يَحْيَى قَالَ قَرَأْتُ عَلَى مَالِكٍ ‏"‏ مَالٌ رَايِحٌ ‏"‏‏.‏\hadithno{4554}\hadithtrans{Narrated Anas bin Malik:Out of all the Ansar, living in Medina, Abu Talha had the largest number of (date palm trees) gardens, and the most beloved of his property to him was Bairuha garden which was standing opposite the Mosque (of the Prophet). Allah's Messenger (ﷺ) used to enter it and drink of its good water. When the Verse was revealed:--"By no means shall you attain righteousness unless you spend (in charity) of that which you love." (3.92) Abu Talha got up and said, "O Allah's Messenger (ﷺ), Allah says:--"By no means shall you attain righteousness unless you spend (in charity) of that which you love." (3.92) and the most beloved of my property to me is the Bairuha garden, so I give it (as a charitable gift) in Allah's Cause and hope to receive good out of it, and to have it stored for me with Allah. So, O Allah's Messenger (ﷺ)! Dispose it of (i.e. utilize it) in the way Allah orders you (to dispose it of)." Allah's Messenger (ﷺ) said, "Bravo! That is a fruitful property! That is a fruitful property! I have heard what you have said and I think that you should distribute that (garden) amongst your relatives." Then Abu Talha distributed that garden amongst his relatives and his cousins. Narrated Yahya bin Yahya: I learnt from Malik, "..a fruitful property}}
\hadithdefcmd{bukhari}{4555}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ فَجَعَلَهَا لِحَسَّانَ وَأُبِيٍّ، وَأَنَا أَقْرَبُ إِلَيْهِ، وَلَمْ يَجْعَلْ لِي مِنْهَا شَيْئًا‏.‏\hadithno{4555}\hadithtrans{Narrated Anas:Abu Talha distributed the garden between Hassan and Ubai, but he did not give me anything thereof although I was a nearer relative to him}}
\hadithdefcmd{bukhari}{4556}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ الْيَهُودَ، جَاءُوا إِلَى النَّبِيِّ صلى الله عليه وسلم بِرَجُلٍ مِنْهُمْ وَامْرَأَةٍ قَدْ زَنَيَا، فَقَالَ لَهُمْ ‏"‏ كَيْفَ تَفْعَلُونَ بِمَنْ زَنَى مِنْكُمْ ‏"‏‏.‏ قَالُوا نُحَمِّمُهُمَا وَنَضْرِبُهُمَا‏.‏ فَقَالَ ‏"‏ لاَ تَجِدُونَ فِي التَّوْرَاةِ الرَّجْمَ ‏"‏‏.‏ فَقَالُوا لاَ نَجِدُ فِيهَا شَيْئًا‏.‏ فَقَالَ لَهُمْ عَبْدُ اللَّهِ بْنُ سَلاَمٍ كَذَبْتُمْ ‏\{‏فَأْتُوا بِالتَّوْرَاةِ فَاتْلُوهَا إِنْ كُنْتُمْ صَادِقِينَ‏\}‏ فَوَضَعَ مِدْرَاسُهَا الَّذِي يُدَرِّسُهَا مِنْهُمْ كَفَّهُ عَلَى آيَةِ الرَّجْمِ، فَطَفِقَ يَقْرَأُ مَا دُونَ يَدِهِ وَمَا وَرَاءَهَا، وَلاَ يَقْرَأُ آيَةَ الرَّجْمِ، فَنَزَعَ يَدَهُ عَنْ آيَةِ الرَّجْمِ فَقَالَ مَا هَذِهِ فَلَمَّا رَأَوْا ذَلِكَ قَالُوا هِيَ آيَةُ الرَّجْمِ‏.‏ فَأَمَرَ بِهِمَا فَرُجِمَا قَرِيبًا مِنْ حَيْثُ مَوْضِعُ الْجَنَائِزِ عِنْدَ الْمَسْجِدِ، فَرَأَيْتُ صَاحِبَهَا يَجْنَأُ عَلَيْهَا يَقِيهَا الْحِجَارَةَ‏.‏\hadithno{4556}\hadithtrans{Narrated `Abdullah bin `Umar:The Jews brought to the Prophet (ﷺ) a man and a woman from among them who had committed illegal sexual intercourse. The Prophet (ﷺ) said to them, "How do you usually punish the one amongst you who has committed illegal sexual intercourse?" They replied, "We blacken their faces with coal and beat them," He said, "Don't you find the order of Ar-Rajm (i.e. stoning to death) in the Torah?" They replied, "We do not find anything in it." `Abdullah bin Salam (after hearing this conversation) said to them. "You have told a lie! Bring here the Torah and recite it if you are truthful." (So the Jews brought the Torah). And the religious teacher who was teaching it to them, put his hand over the Verse of Ar- Rajm and started reading what was written above and below the place hidden with his hand, but he did not read the Verse of Ar-Rajm. `Abdullah bin Salam removed his (i.e. the teacher's) hand from the Verse of Ar-Rajm and said, "What is this?" So when the Jews saw that Verse, they said, "This is the Verse of Ar-Rajm." So the Prophet (ﷺ) ordered the two adulterers to be stoned to death, and they were stoned to death near the place where biers used to be placed near the Mosque. I saw her companion (i.e. the adulterer) bowing over her so as to protect her from the stones}}
\hadithdefcmd{bukhari}{4557}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ سُفْيَانَ، عَنْ مَيْسَرَةَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَة َ ـ رضى الله عنه ـ ‏\{‏كُنْتُمْ خَيْرَ أُمَّةٍ أُخْرِجَتْ لِلنَّاسِ‏\}‏ قَالَ خَيْرَ النَّاسِ لِلنَّاسِ، تَأْتُونَ بِهِمْ فِي السَّلاَسِلِ فِي أَعْنَاقِهِمْ حَتَّى يَدْخُلُوا فِي الإِسْلاَمِ‏.‏\hadithno{4557}\hadithtrans{Narrated Abu Huraira:The Verse:--"You (true Muslims) are the best of peoples ever raised up for mankind." means, the best of peoples for the people, as you bring them with chains on their necks till they embrace Islam}}
\hadithdefcmd{bukhari}{4558}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ قَالَ عَمْرٌو سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّه ِ ـ رضى الله عنهما ـ يَقُولُ فِينَا نَزَلَتْ ‏\{‏إِذْ هَمَّتْ طَائِفَتَانِ مِنْكُمْ أَنْ تَفْشَلاَ وَاللَّهُ وَلِيُّهُمَا‏\}‏ قَالَ نَحْنُ الطَّائِفَتَانِ بَنُو حَارِثَةَ وَبَنُو سَلِمَةَ، وَمَا نُحِبُّ ـ وَقَالَ سُفْيَانُ مَرَّةً وَمَا يَسُرُّنِي ـ أَنَّهَا لَمْ تُنْزَلْ لِقَوْلِ اللَّهِ ‏\{‏وَاللَّهُ وَلِيُّهُمَا‏\}‏\hadithno{4558}\hadithtrans{Narrated Jabir bin `Abdullah:The Verse:--"When two parties from among you were about to lose heart, but Allah was their Protector," (3.122) was revealed concerning us, and we were the two parties, i.e. Banu Haritha and Banu Salama, and we do not wish (that it had not been revealed) or I would not have been pleased (if it had not been revealed), for Allah says:--"...Allah was their Protector}}
\hadithdefcmd{bukhari}{4559}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَالِمٌ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فِي الرَّكْعَةِ الآخِرَةِ مِنَ الْفَجْرِ يَقُولُ ‏"‏ اللَّهُمَّ الْعَنْ فُلاَنًا وَفُلاَنًا وَفُلاَنًا ‏"‏‏.‏ بَعْدَ مَا يَقُولُ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏لَيْسَ لَكَ مِنَ الأَمْرِ شَىْءٌ‏\}‏ إِلَى قَوْلِهِ ‏\{‏فَإِنَّهُمْ ظَالِمُونَ‏\}‏‏.‏ رَوَاهُ إِسْحَاقُ بْنُ رَاشِدٍ عَنِ الزُّهْرِيِّ‏.‏\hadithno{4559}\hadithtrans{Narrated Salim's father:That he heard Allah's Messenger (ﷺ) on raising his head from the bowing in the last rak`a in the Fajr prayer, saying, "O Allah, curse such-and-such person and such-and-such person, and such-and-such person," after saying, "Allah hears him who sends his praises to Him, O our Lord, all praise is for You." So Allah revealed:--"Not for you (O Muhammad) (but for Allah) is the decision, verily they are indeed wrongdoers}}
\hadithdefcmd{bukhari}{4560}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَدْعُوَ عَلَى أَحَدٍ أَوْ يَدْعُوَ لأَحَدٍ قَنَتَ بَعْدَ الرُّكُوعِ، فَرُبَّمَا قَالَ إِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ، اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ، اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ، وَسَلَمَةَ بْنَ هِشَامٍ، وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ، اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ وَاجْعَلْهَا سِنِينَ كَسِنِي يُوسُفَ ‏"‏‏.‏ يَجْهَرُ بِذَلِكَ وَكَانَ يَقُولُ فِي بَعْضِ صَلاَتِهِ فِي صَلاَةِ الْفَجْرِ ‏"‏ اللَّهُمَّ الْعَنْ فُلاَنًا وَفُلاَنًا ‏"‏‏.‏ لأَحْيَاءٍ مِنَ الْعَرَبِ، حَتَّى أَنْزَلَ اللَّهُ ‏\{‏لَيْسَ لَكَ مِنَ الأَمْرِ شَىْءٌ‏\}‏ الآيَةَ‏.‏\hadithno{4560}\hadithtrans{Narrated Abu Huraira:Whenever Allah's Messenger (ﷺ) intended to invoke evil upon somebody or invoke good upon somebody, he used to invoke (Allah) after bowing (in the prayer). Sometimes after saying, "Allah hears him who sends his praises to Him, all praise is for You, O our Lord," he would say, "O Allah. Save Al-Walid bin Al-Walid and Salama bin Hisham, and `Aiyash bin Abu Rabi`a. O Allah! Inflict Your Severe Torture on Mudar (tribe) and strike them with (famine) years like the years of Joseph." The Prophet (ﷺ) used to say in a loud voice, and he also used to say in some of his Fajr prayers, "O Allah! Curse so-and-so and so-and-so." naming some of the Arab tribes till Allah revealed:--"Not for you (O Muhammad) (but for Allah) is the decision}}
\hadithdefcmd{bukhari}{4561}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ قَالَ جَعَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى الرَّجَّالَةِ يَوْمَ أُحُدٍ عَبْدَ اللَّهِ بْنَ جُبَيْرٍ، وَأَقْبَلُوا مُنْهَزِمِينَ، فَذَاكَ إِذْ يَدْعُوهُمُ الرَّسُولُ فِي أُخْرَاهُمْ، وَلَمْ يَبْقَ مَعَ النَّبِيِّ صلى الله عليه وسلم غَيْرُ اثْنَىْ عَشَرَ رَجُلاً‏.‏\hadithno{4561}\hadithtrans{Narrated Al-Bara bin Azib:The Prophet (ﷺ) appointed `Abdullah bin Jubair as the commander of the infantry during the battle of Uhud. They returned defeated, and that is what is meant by:-- "And the Apostle was calling them back in the rear. None remained with the Prophet (ﷺ) then, but twelve men}}
\hadithdefcmd{bukhari}{4562}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ أَبُو يَعْقُوبَ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسٌ، أَنَّ أَبَا طَلْحَةَ، قَالَ غَشِيَنَا النُّعَاسُ وَنَحْنُ فِي مَصَافِّنَا يَوْمَ أُحُدٍ ـ قَالَ ـ فَجَعَلَ سَيْفِي يَسْقُطُ مِنْ يَدِي وَآخُذُهُ، وَيَسْقُطُ وَآخُذُهُ‏.‏\hadithno{4562}\hadithtrans{Narrated Abu Talha:Slumber overtook us during the battle of Uhud while we were in the front files. My sword would fall from my hand and I would pick it up, and again it would fall down and I would pick it up again}}
\hadithdefcmd{bukhari}{4563}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ ـ أُرَاهُ قَالَ ـ حَدَّثَنَا أَبُو بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي الضُّحَى، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏حَسْبُنَا اللَّهُ وَنِعْمَ الْوَكِيلُ‏\}‏ قَالَهَا إِبْرَاهِيمُ عَلَيْهِ السَّلاَمُ حِينَ أُلْقِيَ فِي النَّارِ، وَقَالَهَا مُحَمَّدٌ صلى الله عليه وسلم حِينَ قَالُوا ‏\{‏إِنَّ النَّاسَ قَدْ جَمَعُوا لَكُمْ فَاخْشَوْهُمْ فَزَادَهُمْ إِيمَانًا وَقَالُوا حَسْبُنَا اللَّهُ وَنِعْمَ الْوَكِيلُ‏\}‏\hadithno{4563}\hadithtrans{Narrated Ibn `Abbas:'Allah is Sufficient for us and He Is the Best Disposer of affairs," was said by Abraham when he was thrown into the fire; and it was said by Muhammad when they (i.e. hypocrites) said, "A great army is gathering against you, therefore, fear them," but it only increased their faith and they said: "Allah is Sufficient for us, and He is the Best Disposer (of affairs, for us)}}
\hadithdefcmd{bukhari}{4564}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي الضُّحَى، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ آخِرَ قَوْلِ إِبْرَاهِيمَ حِينَ أُلْقِيَ فِي النَّارِ حَسْبِيَ اللَّهُ وَنِعْمَ الْوَكِيلُ‏.‏\hadithno{4564}\hadithtrans{Narrated Ibn `Abbas:The last statement of Abraham when he was thrown into the fire was:--"Allah is Sufficient for us and He is the Best Disposer (of affairs for us)}}
\hadithdefcmd{bukhari}{4565}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ أَبَا النَّضْرِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ ـ هُوَ ابْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ ـ عَنْ أَبِيهِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ آتَاهُ اللَّهُ مَالاً فَلَمْ يُؤَدِّ زَكَاتَهُ، مُثِّلَ لَهُ مَالُهُ شُجَاعًا أَقْرَعَ، لَهُ زَبِيبَتَانِ يُطَوَّقُهُ يَوْمَ الْقِيَامَةِ، يَأْخُذُ بِلِهْزِمَتَيْهِ ـ يَعْنِي بِشِدْقَيْهِ ـ يَقُولُ أَنَا مَالُكَ أَنَا كَنْزُكَ ‏"‏‏.‏ ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏\{‏وَلاَ يَحْسِبَنَّ الَّذِينَ يَبْخَلُونَ بِمَا آتَاهُمُ اللَّهُ مِنْ فَضْلِهِ‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏\hadithno{4565}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Anyone whom Allah has given wealth but he does not pay its Zakat, then, on the Day of Resurrection, his wealth will be presented to him in the shape of a bald-headed poisonous male snake with two poisonous glands in its mouth and it will encircle itself round his neck and bite him over his cheeks and say, "I am your wealth; I am your treasure." Then the Prophet (ﷺ) recited this Divine Verse:-- "And let not those who covetously withhold of that which Allah has bestowed upon them of His Bounty}}
\hadithdefcmd{bukhari}{4566}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ أُسَامَةَ بْنَ زَيْدٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ عَلَى حِمَارٍ عَلَى قَطِيفَةٍ فَدَكِيَّةٍ، وَأَرْدَفَ أُسَامَةَ بْنَ زَيْدٍ وَرَاءَهُ، يَعُودُ سَعْدَ بْنَ عُبَادَةَ فِي بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ قَبْلَ وَقْعَةِ بَدْرٍ ـ قَالَ ـ حَتَّى مَرَّ بِمَجْلِسٍ فِيهِ عَبْدُ اللَّهِ بْنُ أُبَىٍّ، ابْنُ سَلُولَ، وَذَلِكَ قَبْلَ أَنْ يُسْلِمَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ فَإِذَا فِي الْمَجْلِسِ أَخْلاَطٌ مِنَ الْمُسْلِمِينَ وَالْمُشْرِكِينَ عَبَدَةِ الأَوْثَانِ وَالْيَهُودِ وَالْمُسْلِمِينَ، وَفِي الْمَجْلِسِ عَبْدُ اللَّهِ بْنُ رَوَاحَةَ، فَلَمَّا غَشِيَتِ الْمَجْلِسَ عَجَاجَةُ الدَّابَّةِ خَمَّرَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ أَنْفَهُ بِرِدَائِهِ، ثُمَّ قَالَ لاَ تُغَبِّرُوا عَلَيْنَا‏.‏ فَسَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَيْهِمْ ثُمَّ وَقَفَ فَنَزَلَ فَدَعَاهُمْ إِلَى اللَّهِ، وَقَرَأَ عَلَيْهِمُ الْقُرْآنَ، فَقَالَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ أَيُّهَا الْمَرْءُ، إِنَّهُ لاَ أَحْسَنَ مِمَّا تَقُولُ، إِنْ كَانَ حَقًّا، فَلاَ تُؤْذِينَا بِهِ فِي مَجْلِسِنَا، ارْجِعْ إِلَى رَحْلِكَ، فَمَنْ جَاءَكَ فَاقْصُصْ عَلَيْهِ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ رَوَاحَةَ بَلَى يَا رَسُولَ اللَّهِ، فَاغْشَنَا بِهِ فِي مَجَالِسِنَا، فَإِنَّا نُحِبُّ ذَلِكَ‏.‏ فَاسْتَبَّ الْمُسْلِمُونَ وَالْمُشْرِكُونَ وَالْيَهُودُ حَتَّى كَادُوا يَتَثَاوَرُونَ، فَلَمْ يَزَلِ النَّبِيُّ صلى الله عليه وسلم يُخَفِّضُهُمْ حَتَّى سَكَنُوا، ثُمَّ رَكِبَ النَّبِيُّ صلى الله عليه وسلم دَابَّتَهُ فَسَارَ حَتَّى دَخَلَ عَلَى سَعْدِ بْنِ عُبَادَةَ، فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا سَعْدُ أَلَمْ تَسْمَعْ مَا قَالَ أَبُو حُبَابٍ ‏"‏‏.‏ يُرِيدُ عَبْدَ اللَّهِ بْنَ أُبَىٍّ ‏"‏ قَالَ كَذَا وَكَذَا ‏"‏‏.‏ قَالَ سَعْدُ بْنُ عُبَادَةَ يَا رَسُولَ اللَّهِ، اعْفُ عَنْهُ وَاصْفَحْ عَنْهُ، فَوَالَّذِي أَنْزَلَ عَلَيْكَ الْكِتَابَ، لَقَدْ جَاءَ اللَّهُ بِالْحَقِّ الَّذِي أَنْزَلَ عَلَيْكَ، لَقَدِ اصْطَلَحَ أَهْلُ هَذِهِ الْبُحَيْرَةِ عَلَى أَنْ يُتَوِّجُوهُ فَيُعَصِّبُونَهُ بِالْعِصَابَةِ، فَلَمَّا أَبَى اللَّهُ ذَلِكَ بِالْحَقِّ الَّذِي أَعْطَاكَ اللَّهُ شَرِقَ بِذَلِكَ، فَذَلِكَ فَعَلَ بِهِ ما رَأَيْتَ‏.‏ فَعَفَا عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ يَعْفُونَ عَنِ الْمُشْرِكِينَ وَأَهْلِ الْكِتَابِ كَمَا أَمَرَهُمُ اللَّهُ، وَيَصْبِرُونَ عَلَى الأَذَى قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَلَتَسْمَعُنَّ مِنَ الَّذِينَ أُوتُوا الْكِتَابَ مِنْ قَبْلِكُمْ وَمِنَ الَّذِينَ أَشْرَكُوا أَذًى كَثِيرًا ‏\}‏ الآيَةَ، وَقَالَ اللَّهُ ‏\{‏وَدَّ كَثِيرٌ مِنْ أَهْلِ الْكِتَابِ لَوْ يَرُدُّونَكُمْ مِنْ بَعْدِ إِيمَانِكُمْ كُفَّارًا حَسَدًا مِنْ عِنْدِ أَنْفُسِهِمْ‏\}‏ إِلَى آخِرِ الآيَةِ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم يَتَأَوَّلُ الْعَفْوَ مَا أَمَرَهُ اللَّهُ بِهِ، حَتَّى أَذِنَ اللَّهُ فِيهِمْ، فَلَمَّا غَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَدْرًا، فَقَتَلَ اللَّهُ بِهِ صَنَادِيدَ كُفَّارِ قُرَيْشٍ قَالَ ابْنُ أُبَىٍّ ابْنُ سَلُولَ، وَمَنْ مَعَهُ مِنَ الْمُشْرِكِينَ، وَعَبَدَةِ الأَوْثَانِ هَذَا أَمْرٌ قَدْ تَوَجَّهَ‏.‏ فَبَايَعُوا الرَّسُولَ صلى الله عليه وسلم عَلَى الإِسْلاَمِ فَأَسْلَمُوا‏.‏\hadithno{4566}\hadithtrans{Narrated Usama bin Zaid:Allah's Messenger (ﷺ) rode a donkey, equipped with a thick cloth-covering made in Fadak and I was riding behind him. He was going to pay visit to Sa`d bin Ubada in Banu Al-Harith bin Al-Khazraj; and this incident happened before the battle of Badr. The Prophet (ﷺ) passed by a gathering in which `Abdullah bin Ubai bin Salul was present, and that was before `Abdullah bin Ubai embraced Islam. Behold in that gathering there were people of different religions: there were Muslims, pagans, idol-worshippers and Jews, and in that gathering `Abdullah bin Rawaha was also present. When a cloud of dust raised by the donkey reached that gathering, `Abdullah bin Ubai covered his nose with his garment and then said, "Do not cover us with dust." Then Allah's Messenger (ﷺ) greeted them and stopped and dismounted and invited them to Allah (i.e. to embrace Islam) and recited to them the Holy Qur'an. On that, `Abdullah bin Ubai bin Salul said, "O man ! There is nothing better than that what you say. If it is the truth, then do not trouble us with it in our gatherings. Return to your mount (or residence) and if somebody comes to you, relate (your tales) to him." On that `Abdullah bin Rawaha said, "Yes, O Allah's Apostle! Bring it (i.e. what you want to say) to us in our gathering, for we love that." So the Muslims, the pagans and the Jews started abusing one another till they were on the point of fighting with one another. The Prophet (ﷺ) kept on quietening them till they became quiet, whereupon the Prophet rode his animal (mount) and proceeded till he entered upon Sa`d bin Ubada. The Prophet (ﷺ) said to Sa`d, "Did you not hear what 'Abu Hubab said?" He meant `Abdullah bin Ubai. "He said so-and-so." On that Sa`d bin Ubada said, "O Allah's Messenger (ﷺ)! Excuse and forgive him, for by Him Who revealed the Book to you, Allah brought the Truth which was sent to you at the time when the people of this town (i.e. Medina) had decided unanimously to crown him and tie a turban on his head (electing him as chief). But when Allah opposed that (decision) through the Truth which Allah gave to you, he (i.e. `Abdullah bin Ubai) was grieved with jealousy, and that caused him to do what you have seen." So Allah's Messenger (ﷺ) excused him, for the Prophet (ﷺ) and his companions used to forgive the pagans and the people of Scripture as Allah had ordered them, and they used to put up with their mischief with patience. Allah said: "And you shall certainly hear much that will grieve you from those who received the Scripture before you and from the pagans........'(3.186) And Allah also said:--"Many of the people of the Scripture wish if they could turn you away as disbelievers after you have believed, from selfish envy.." (2.109) So the Prophet (ﷺ) used to stick to the principle of forgiveness for them as long as Allah ordered him to do so till Allah permitted fighting them. So when Allah's Messenger (ﷺ) fought the battle of Badr and Allah killed the nobles of Quraish infidels through him, Ibn Ubai bin Salul and the pagans and idolaters who were with him, said, "This matter (i.e. Islam) has appeared (i.e. became victorious)." So they gave the pledge of allegiance (for embracing Islam) to Allah's Messenger (ﷺ) and became Muslims}}
\hadithdefcmd{bukhari}{4567}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ رِجَالاً مِنَ الْمُنَافِقِينَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْغَزْوِ تَخَلَّفُوا عَنْهُ، وَفَرِحُوا بِمَقْعَدِهِمْ خِلاَفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم اعْتَذَرُوا إِلَيْهِ وَحَلَفُوا، وَأَحَبُّوا أَنْ يُحْمَدُوا بِمَا لَمْ يَفْعَلُوا، فَنَزَلَتْ ‏\{‏لاَ يَحْسِبَنَّ الَّذِينَ يَفْرَحُونَ‏\}‏ الآيَةَ‏.‏\hadithno{4567}\hadithtrans{Narrated Abu Sa`id Al-Khudri:During the lifetime of Allah's Messenger (ﷺ), some men among the hypocrites used to remain behind him (i.e. did not accompany him) when he went out for a Ghazwa and they would be pleased to stay at home behind Allah's Messenger (ﷺ) When Allah's Messenger (ﷺ) returned (from the battle) they would put forward (false) excuses and take oaths, wishing to be praised for what they had not done. So there was revealed:-- "Think not that those who rejoice in what they have done, and love to be praised for what they have not done}}
\hadithdefcmd{bukhari}{4568}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ عَلْقَمَةَ بْنَ وَقَّاصٍ، أَخْبَرَهُ أَنَّ مَرْوَانَ قَالَ لِبَوَّابِهِ اذْهَبْ يَا رَافِعُ إِلَى ابْنِ عَبَّاسٍ فَقُلْ لَئِنْ كَانَ كُلُّ امْرِئٍ فَرِحَ بِمَا أُوتِيَ، وَأَحَبَّ أَنْ يُحْمَدَ بِمَا لَمْ يَفْعَلْ، مُعَذَّبًا، لَنُعَذَّبَنَّ أَجْمَعُونَ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ وَمَا لَكُمْ وَلِهَذِهِ إِنَّمَا دَعَا النَّبِيُّ صلى الله عليه وسلم يَهُودَ فَسَأَلَهُمْ عَنْ شَىْءٍ، فَكَتَمُوهُ إِيَّاهُ، وَأَخْبَرُوهُ بِغَيْرِهِ، فَأَرَوْهُ أَنْ قَدِ اسْتَحْمَدُوا إِلَيْهِ بِمَا أَخْبَرُوهُ عَنْهُ فِيمَا سَأَلَهُمْ، وَفَرِحُوا بِمَا أُوتُوا مِنْ كِتْمَانِهِمْ، ثُمَّ قَرَأَ ابْنُ عَبَّاسٍ ‏\{‏وَإِذْ أَخَذَ اللَّهُ مِيثَاقَ الَّذِينَ أُوتُوا الْكِتَابَ‏\}‏ كَذَلِكَ حَتَّى قَوْلِهِ ‏\{‏يَفْرَحُونَ بِمَا أَتَوْا وَيُحِبُّونَ أَنْ يُحْمَدُوا بِمَا لَمْ يَفْعَلُوا‏\}‏‏.‏ تَابَعَهُ عَبْدُ الرَّزَّاقِ عَنِ ابْنِ جُرَيْجٍ‏.‏ حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا الْحَجَّاجُ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ أَخْبَرَهُ أَنَّ مَرْوَانَ بِهَذَا‏.‏\hadithno{4568}\hadithtrans{Narrated Alqama bin Waqqas:Marwan said to his gatekeeper, "Go to Ibn `Abbas, O Rafi`, and say, 'If everybody who rejoices in what he has done, and likes to be praised for what he has not done, will be punished, then all of us will be punished." Ibn `Abbas said, "What connection have you with this case? It was only that the Prophet (ﷺ) called the Jews and asked them about something, and they hid the truth and told him something else, and showed him that they deserved praise for the favor of telling him the answer to his question, and they became happy with what they had concealed. Then Ibn `Abbas recited:-- "(And remember) when Allah took a Covenant from those who were given the Scripture..and those who rejoice in what they have done and love to be praised for what they have not done.' " (3.187-188) Humaid bin `Abdur-Rahman bin `Auf narrated that Marwan had told him (the above narration)}}
\hadithdefcmd{bukhari}{4569}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي شَرِيكُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ، فَتَحَدَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ أَهْلِهِ سَاعَةً ثُمَّ رَقَدَ، فَلَمَّا كَانَ ثُلُثُ اللَّيْلِ الآخِرُ قَعَدَ فَنَظَرَ إِلَى السَّمَاءِ فَقَالَ ‏\{‏إِنَّ فِي خَلْقِ السَّمَوَاتِ وَالأَرْضِ وَاخْتِلاَفِ ��للَّيْلِ وَالنَّهَارِ لآيَاتٍ لأُولِي الأَلْبَابِ‏\}‏، ثُمَّ قَامَ فَتَوَضَّأَ وَاسْتَنَّ، فَصَلَّى إِحْدَى عَشْرَةَ رَكْعَةً، ثُمَّ أَذَّنَ بِلاَلٌ فَصَلَّى رَكْعَتَيْنِ، ثُمَّ خَرَجَ فَصَلَّى الصُّبْحَ‏.‏\hadithno{4569}\hadithtrans{Narrated Ibn `Abbas:I stayed overnight in the house of my aunt Maimuna. Allah's Messenger (ﷺ) talked with his wife for a while and then went to bed. When it was the last third of the night, he got up and looked towards the sky and said: "Verily! In the creation of the Heavens and the Earth and in the alteration of night and day, there are indeed signs for men of understanding." (3.190) Then he stood up, performed ablution, brushed his teeth with a Siwak, and then prayed eleven rak`at. Then Bilal pronounced the Adhan (i.e. call for the Fajr prayer). The Prophet (ﷺ) then offered two rak`at (Sunna) prayer and went out (to the Mosque) and offered the (compulsory congregational) Fajr prayer}}
\hadithdefcmd{bukhari}{4570}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ فَقُلْتُ لأَنْظُرَنَّ إِلَى صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَطُرِحَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وِسَادَةٌ، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي طُولِهَا، فَجَعَلَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ، ثُمَّ قَرَأَ الآيَاتِ الْعَشْرَ الأَوَاخِرَ مِنْ آلِ عِمْرَانَ حَتَّى خَتَمَ، ثُمَّ أَتَى شَنًّا مُعَلَّقًا، فَأَخَذَهُ فَتَوَضَّأَ، ثُمَّ قَامَ يُصَلِّي، فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ ثُمَّ جِئْتُ فَقُمْتُ إِلَى جَنْبِهِ، فَوَضَعَ يَدَهُ عَلَى رَأْسِي، ثُمَّ أَخَذَ بِأُذُنِي، فَجَعَلَ يَفْتِلُهَا، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ أَوْتَرَ‏.‏\hadithno{4570}\hadithtrans{Narrated Ibn `Abbas:(One night) I stayed overnight in the house of my aunt Maimuna, and said to myself, "I will watch the prayer of Allah's Messenger (ﷺ) " My aunt placed a cushion for Allah's Messenger (ﷺ) and he slept on it in its length-wise direction and (woke-up) rubbing the traces of sleep off his face and then he recited the last ten Verses of Surat-al-`Imran till he finished it. Then he went to a hanging water skin and took it, performed the ablution and then stood up to offer the prayer. I got up and did the same as he had done, and stood beside him. He put his hand on my head and held me by the ear and twisted it. He offered two rak`at, then two rak`at, then two rak`at, then two rak`at, then two rak`at, then two rak`at, and finally the witr (i.e. one rak`a) prayer}}
\hadithdefcmd{bukhari}{4571}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنَا مَالِكٌ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّهُ، بَاتَ عِنْدَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَهْىَ خَالَتُهُ قَالَ فَاضْطَجَعْتُ فِي عَرْضِ الْوِسَادَةِ، وَاضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ فِي طُولِهَا، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى انْتَصَفَ اللَّيْلُ، أَوْ قَبْلَهُ بِقَلِيلٍ، أَوْ بَعْدَهُ بِقَلِيلٍ، ثُمَّ اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ بِيَدَيْهِ، ثُمَّ قَرَأَ الْعَشْرَ الآيَاتِ الْخَوَاتِمَ مِنْ سُورَةِ آلِ عِمْرَانَ، ثُمَّ قَامَ إِلَى شَنٍّ مُعَلَّقَةٍ فَتَوَضَّأَ مِنْهَا، فَأَحْسَنَ وُضُوءَهُ، ثُمَّ قَامَ يُصَلِّي، فَصَنَعْتُ مِثْلَ مَا صَنَعَ، ثُمَّ ذَهَبْتُ فَقُمْتُ إِلَى جَنْبِهِ، فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ الْيُمْنَى عَلَى رَأْسِي، وَأَخَذَ بِأُذُنِي بِيَدِهِ الْيُمْنَى يَفْتِلُهَا، فَصَلَّى رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ أَوْتَرَ، ثُمَّ اضْطَجَعَ حَتَّى جَاءَهُ الْمُؤَذِّنُ، فَقَامَ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ خَرَجَ فَصَلَّى الصُّبْحَ‏.‏\hadithno{4571}\hadithtrans{Narrated `Abdullah bin `Abbas:That once he stayed overnight (in the house) of his aunt Maimuna. the wife of the Prophet. He added: I lay on the cushion transversely and Allah's Messenger (ﷺ) lay along with his wife in the lengthwise direction of the pillow. Allah's Messenger (ﷺ) slept till the middle of the night, either a bit before or a bit after it, and then woke up rubbing the traces of sleep off his face with his hands and then he recited the last ten Verses of Surat-al-`Imran, got up and went to a hanging water skin. He then performed the ablution from it, and it was perfect ablution, and then stood up to offer the prayer. I too did the same as he had done, and then went to stand beside him. Allah's Messenger (ﷺ) put his right hand on my head and held and twisted my right ear. He then offered two rak`at, then two rak`at, then two rak`at, then two rak`at, then two rak`at. then two rak`at, and finally one rak`a, the witr. Then he lay down again till the Muadhdhin (i.e. the call-maker) came to him, whereupon he got up and offered a light two-rak`at prayer, and went out (to the Mosque) and offered the (compulsory congregational) Fajr prayer}}
\hadithdefcmd{bukhari}{4572}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّهُ، بَاتَ عِنْدَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَهْىَ خَالَتُهُ قَالَ فَاضْطَجَعْتُ فِي عَرْضِ الْوِسَادَةِ، وَاضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ فِي طُولِهَا، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا انْتَصَفَ اللَّيْلُ، أَوْ قَبْلَهُ بِقَلِيلٍ، أَوْ بَعْدَهُ بِقَلِيلٍ، اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَلَسَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ بِيَدِهِ، ثُمَّ قَرَأَ الْعَشْرَ الآيَاتِ الْخَوَاتِمَ مِنْ سُورَةِ آلِ عِمْرَانَ، ثُمَّ قَامَ إِلَى شَنٍّ مُعَلَّقَةٍ فَتَوَضَّأَ مِنْهَا، فَأَحْسَنَ وُضُوءَهُ، ثُمَّ قَامَ يُصَلِّي‏.‏ قَالَ ابْنُ عَبَّاسٍ فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ، ثُمَّ ذَهَبْتُ فَقُمْتُ إِلَى جَنْبِهِ، فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ الْيُمْنَى عَلَى رَأْسِي، وَأَخَذَ بِأُذُنِي الْيُمْنَى يَفْتِلُهَا، فَصَلَّى رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ أَوْتَرَ ثُمَّ، اضْطَجَعَ حَتَّى جَاءَهُ الْمُؤَذِّنُ، فَقَامَ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ خَرَجَ فَصَلَّى الصُّبْحَ‏.‏\hadithno{4572}\hadithtrans{Narrated Ibn `Abbas:That once he stayed overnight in the house of his aunt, the wife of the Prophet. He added: I lay on the cushion transversely while Allah's Messenger (ﷺ) lay along with his wife in the lengthwise direction of the cushion. Allah's Messenger (ﷺ) slept till the middle of the night, either a bit before or a bit after it, and then woke up rubbing the traces of sleep off his face with his hands, and then recited the last ten Verses of Surat ali-`Imran. Then he got up and went to a hanging water skin, performed ablution from it ---- and performed it perfectly. Then he stood up to perform the prayer. I also did the same as he had done and then went to stand beside him. Allah's Messenger (ﷺ) put his right hand on my head and held and twisted my right ear. He then offered two rak`at, then two rak`at then two rak`at, then two rak`at, then two rak`at, then two rak`at, and finally, one rak`a witr. Then he lay down again till the Muadhdhin (i.e. the call-maker) came to him, whereupon he got up and offered a light two rak`at prayer and went out (to the Mosque) and offered the (compulsory congregational) Fajr prayer}}
\hadithdefcmd{bukhari}{4573}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَجُلاً، كَانَتْ لَهُ يَتِيمَةٌ فَنَكَحَهَا، وَكَانَ لَهَا عَذْقٌ، وَكَانَ يُمْسِكُهَا عَلَيْهِ، وَلَمْ يَكُنْ لَهَا مِنْ نَفْسِهِ شَىْءٌ فَنَزَلَتْ فِيهِ ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى‏\}‏ أَحْسِبُهُ قَالَ كَانَتْ شَرِيكَتَهُ فِي ذَلِكَ الْعَذْقِ وَفِي مَالِهِ‏.‏\hadithno{4573}\hadithtrans{Narrated Aisha:There was an orphan (girl) under the care of a man. He married her and she owned a date palm (garden). He married her just because of that and not because he loved her. So the Divine Verse came regarding his case: "If you fear that you shall not be able to deal justly with the orphan girls..." (4.3) The sub-narrator added: I think he (i.e. another sub-narrator) said, "That orphan girl was his partner in that datepalm (garden) and in his property}}
\hadithdefcmd{bukhari}{4574}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ قَوْلِ اللَّهِ، تَعَالَى ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى‏\}‏‏.‏ فَقَالَتْ يَا ابْنَ أُخْتِي، هَذِهِ الْيَتِيمَةُ تَكُونُ فِي حَجْرِ وَلِيِّهَا، تَشْرَكُهُ فِي مَالِهِ وَيُعْجِبُهُ مَالُهَا وَجَمَالُهَا، فَيُرِيدُ وَلِيُّهَا أَنْ يَتَزَوَّجَهَا، بِغَيْرِ أَنْ يُقْسِطَ فِي صَدَاقِهَا، فَيُعْطِيَهَا مِثْلَ مَا يُعْطِيهَا غَيْرُهُ، فَنُهُوا عَنْ أَنْ يَنْكِحُوهُنَّ، إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ، وَيَبْلُغُوا لَهُنَّ أَعْلَى سُنَّتِهِنَّ فِي الصَّدَاقِ، فَأُمِرُوا أَنْ يَنْكِحُوا مَا طَابَ لَهُمْ مِنَ النِّسَاءِ سِوَاهُنَّ‏.‏ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ وَإِنَّ النَّاسَ اسْتَفْتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ هَذِهِ الآيَةِ فَأَنْزَلَ اللَّهُ ‏\{‏وَيَسْتَفْتُونَكَ فِي النِّسَاءِ‏\}‏ قَالَتْ عَائِشَةُ وَقَوْلُ اللَّهِ تَعَالَى فِي آيَةٍ أُخْرَى ‏\{‏وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏ رَغْبَةُ أَحَدِكُمْ عَنْ يَتِيمَتِهِ حِينَ تَكُونُ قَلِيلَةَ الْمَالِ وَالْجَمَالِ قَالَتْ فَنُهُوا أَنْ يَنْكِحُوا عَنْ مَنْ رَغِبُوا فِي مَالِهِ وَجَمَالِهِ فِي يَتَامَى النِّسَاءِ، إِلاَّ بِالْقِسْطِ، مِنْ أَجْلِ رَغْبَتِهِمْ عَنْهُنَّ إِذَا كُنَّ قَلِيلاَتِ الْمَالِ وَالْجَمَالِ‏.‏\hadithno{4574}\hadithtrans{Narrated `Urwa bin Az-Zubair:That he asked `Aisha regarding the Statement of Allah: "If you fear that you shall not be able to deal justly with the orphan girls..." (4.3) She said, "O son of my sister! An Orphan girl used to be under the care of a guardian with whom she shared property. Her guardian, being attracted by her wealth and beauty, would intend to marry her without giving her a just Mahr, i.e. the same Mahr as any other person might give her (in case he married her). So such guardians were forbidden to do that unless they did justice to their female wards and gave them the highest Mahr their peers might get. They were ordered (by Allah, to marry women of their choice other than those orphan girls." `Aisha added," The people asked Allah's Messenger (ﷺ) his instructions after the revelation of this Divine Verse whereupon Allah revealed: "They ask your instruction regarding women " (4.127) `Aisha further said, "And the Statement of Allah: "And yet whom you desire to marry." (4.127) as anyone of you refrains from marrying an orphan girl (under his guardianship) when she is lacking in property and beauty." `Aisha added, "So they were forbidden to marry those orphan girls for whose wealth and beauty they had a desire unless with justice, and that was because they would refrain from marrying them if they were lacking in property and beauty}}
\hadithdefcmd{bukhari}{4575}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ فِي قَوْلِهِ تَعَالَى ‏\{‏وَمَنْ كَانَ غَنِيًّا فَلْيَسْتَعْفِفْ وَمَنْ كَانَ فَقِيرًا فَلْيَأْكُلْ بِالْمَعْرُوفِ‏\}‏ أَنَّهَا نَزَلَتْ فِي مَالِ الْيَتِيمِ إِذَا كَانَ فَقِيرًا، أَنَّهُ يَأْكُلُ مِنْهُ مَكَانَ قِيَامِهِ عَلَيْهِ، بِمَعْرُوفٍ‏.‏\hadithno{4575}\hadithtrans{Narrated Aisha:regarding the Statement of Allah: "And whoever amongst the guardian is rich, he should take no wages, but if he is poor, let him have for himself what is just and reasonable (according to his work). This Verse was revealed regarding the orphan's property. If the guardian is poor, he can take from the property of the orphan, what is just and reasonable according to his work and the time he spends on managing it}}
\hadithdefcmd{bukhari}{4576}{حَدَّثَنَا أَحْمَدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ الأَشْجَعِيُّ، عَنْ سُفْيَانَ، عَنِ الشَّيْبَانِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏وَإِذَا حَضَرَ الْقِسْمَةَ أُولُو الْقُرْبَى وَالْيَتَامَى وَالْمَسَاكِينُ‏\}‏ قَالَ هِيَ مُحْكَمَةٌ وَلَيْسَتْ بِمَنْسُوخَةٍ‏.‏ تَابَعَهُ سَعِيدٌ عَنِ ابْنِ عَبَّاسٍ‏.‏\hadithno{4576}\hadithtrans{Narrated Ikrima:Ibn `Abbas said ( regarding the verse), "And when the relatives and the orphans and the poor are present at the time of division, "this verse and its order is valid and not abrogated}}
\hadithdefcmd{bukhari}{4577}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي ابْنُ مُنْكَدِرٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ عَادَنِي النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ فِي بَنِي سَلِمَةَ مَاشِيَيْنِ فَوَجَدَنِي النَّبِيُّ صلى الله عليه وسلم لاَ أَعْقِلُ، فَدَعَا بِمَاءٍ فَتَوَضَّأَ مِنْهُ، ثُمَّ رَشَّ عَلَىَّ، فَأَفَقْتُ فَقُلْتُ مَا تَأْمُرُنِي أَنْ أَصْنَعَ فِي مَالِي يَا رَسُولَ اللَّهِ فَنَزَلَتْ ‏\{‏يُوصِيكُمُ اللَّهُ فِي أَوْلاَدِكُمْ‏\}‏\hadithno{4577}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) and Abu Bakr came on foot to pay me a visit (during my illness) at Banu Salama's (dwellings). The Prophet (ﷺ) found me unconscious, so he asked for water and performed the ablution from it and sprinkled some water over me. I came to my senses and said, "O Allah's Messenger (ﷺ)! What do you order me to do as regards my wealth?" So there was revealed:-- "Allah commands you as regards your children's (inheritance):}}
\hadithdefcmd{bukhari}{4578}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ وَرْقَاءَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ الْمَالُ لِلْوَلَدِ، وَكَانَتِ الْوَصِيَّةُ لِلْوَالِدَيْنِ، فَنَسَخَ اللَّهُ مِنْ ذَلِكَ مَا أَحَبَّ، فَجَعَلَ لِلذَّكَرِ مِثْلَ حَظِّ الأُنْثَيَيْنِ، وَجَعَلَ لِلأَبَوَيْنِ لِكُلِّ وَاحِدٍ مِنْهُمَا السُّدُسَ وَالثُّلُثَ، وَجَعَلَ لِلْمَرْأَةِ الثُّمُنَ وَالرُّبُعَ، وَلِلزَّوْجِ الشَّطْرَ وَالرُّبُعَ‏.‏\hadithno{4578}\hadithtrans{Narrated Ibn `Abbas:(In the Pre-Islamic Period ) the children used to inherit all the property but the parents used to inherit only through a will. So Allah cancelled that which He liked to cancel and put decreed that the share of a son was to be twice the share of a daughter, and for the parents one-sixth for each one of them, or one third, and for the wife one-eighth or one-fourth, and for the husband one-half, or one-fourth}}
\hadithdefcmd{bukhari}{4579}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الشَّيْبَانِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ،‏.‏ قَالَ الشَّيْبَانِيُّ وَذَكَرَهُ أَبُو الْحَسَنِ السُّوَائِيُّ وَلاَ أَظُنُّهُ ذَكَرَهُ إِلاَّ عَنِ ابْنِ عَبَّاسٍ، ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ يَحِلُّ لَكُمْ أَنْ تَرِثُوا النِّسَاءَ كَرْهًا وَلاَ تَعْضُلُوهُنَّ لِتَذْهَبُوا بِبَعْضِ مَا آتَيْتُمُوهُنَّ‏\}‏ قَالَ كَانُوا إِذَا مَاتَ الرَّجُلُ كَانَ أَوْلِيَاؤُهُ أَحَقَّ بِامْرَأَتِهِ، إِنْ شَاءَ بَعْضُهُمْ تَزَوَّجَهَا، وَإِنْ شَاءُوا زَوَّجُوهَا، وَإِنْ شَاءُوا لَمْ يُزَوِّجُوهَا، فَهُمْ أَحَقُّ بِهَا مِنْ أَهْلِهَا، فَنَزَلَتْ هَذِهِ الآيَةُ فِي ذَلِكَ‏.‏\hadithno{4579}\hadithtrans{Narrated Ibn `Abbas:regarding the Divine Verse: "O you who believe! You are forbidden to inherit women against their will, and you should not treat them with harshness that you may take back part of the (Mahr) dower you have given them." (4.19) (Before this revelation) if a man died, his relatives used to have the right to inherit his wife, and one of them could marry her if he wished, or they would give her in marriage if they wished, or, if they wished, they would not give her in marriage at all, and they would be more entitled to dispose her, than her own relatives. So the above Verse was revealed in this connection}}
\hadithdefcmd{bukhari}{4580}{حَدَّثَنِي الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ إِدْرِيسَ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاس ٍ ـ رضى الله عنهما ـ ‏\{‏وَلِكُلٍّ جَعَلْنَا مَوَالِيَ‏\}‏ قَالَ وَرَثَةً‏.‏ ‏\{‏وَالَّذِينَ عَاقَدَتْ أَيْمَانُكُمْ‏\}‏ كَانَ الْمُهَاجِرُونَ لَمَّا قَدِمُوا الْمَدِينَةَ يَرِثُ الْمُهَاجِرُ الأَنْصَارِيَّ دُونَ ذَوِي رَحِمِهِ لِلأُخُوَّةِ الَّتِي آخَى النَّبِيُّ صلى الله عليه وسلم بَيْنَهُمْ فَلَمَّا نَزَلَتْ ‏\{‏وَلِكُلٍّ جَعَلْنَا مَوَالِيَ‏\}‏ نُسِخَتْ، ثُمَّ قَالَ ‏\{‏وَالَّذِينَ عَاقَدَتْ أَيْمَانُكُمْ ‏\}‏ مِنَ النَّصْرِ، وَالرِّفَادَةِ وَالنَّصِيحَةِ، وَقَدْ ذَهَبَ الْمِيرَاثُ وَيُوصِي لَهُ‏.‏ سَمِعَ أَبُو أُسَامَةَ إِدْرِيسَ، وَسَمِعَ إِدْرِيسُ طَلْحَةَ‏.‏\hadithno{4580}\hadithtrans{Narrated Ibn `Abbas:Regarding the Verse: "To everyone, We have appointed heirs." (4.33) 'Mawali' means heirs. And regarding:-- "And those to whom your right hands have pledged." When the Emigrants came to Medina, an Emigrant used to be the heir of an Ansari with the exclusion of the latter's relatives, and that was because of the bond of brotherhood which the Prophet (ﷺ) had established between them (i.e. the Emigrants and the Ansar). So when the Verses:-- "To everyone We have appointed heirs." was revealed, (the inheritance through bond of brotherhood) was cancelled. Ibn `Abbas then said: "And those to whom your right hands have pledged." is concerned with the covenant of helping and advising each other. So allies are no longer to be the heir of each other, but they can bequeath each other some of their property by means of a will}}
\hadithdefcmd{bukhari}{4581}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا أَبُو عُمَرَ، حَفْصُ بْنُ مَيْسَرَةَ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ أُنَاسًا فِي زَمَنِ النَّبِيِّ صلى الله عليه وسلم قَالُوا يَا رَسُولَ اللَّهِ، هَلْ نَرَى رَبَّنَا يَوْمَ الْقِيَامَةِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ، هَلْ تُضَارُّونَ فِي رُؤْيَةِ الشَّمْسِ بِالظَّهِيرَةِ، ضَوْءٌ لَيْسَ فِيهَا سَحَابٌ ‏"‏‏.‏ قَالُوا لاَ‏.‏ قَالَ ‏"‏ وَهَلْ تُضَارُّونَ فِي رُؤْيَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ، ضَوْءٌ لَيْسَ فِيهَا سَحَابٌ ‏"‏‏.‏ قَالُوا لاَ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا تُضَارُّونَ فِي رُؤْيَةِ اللَّهِ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ، إِلاَّ كَمَا تُضَارُّونَ فِي رُؤْيَةِ أَحَدِهِمَا، إِذَا كَانَ يَوْمُ الْقِيَامَةِ أَذَّنَ مُؤَذِّنٌ تَتْبَعُ كُلُّ أُمَّةٍ مَا كَانَتْ تَعْبُدُ‏.‏ فَلاَ يَبْقَى مَنْ كَانَ يَعْبُدُ غَيْرَ اللَّهِ مِنَ الأَصْنَامِ وَالأَنْصَابِ إِلاَّ يَتَسَاقَطُونَ فِي النَّارِ، حَتَّى إِذَا لَمْ يَبْقَ إِلاَّ مَنْ كَانَ يَعْبُدُ اللَّهَ، بَرٌّ أَوْ فَاجِرٌ وَغُبَّرَاتُ أَهْلِ الْكِتَابِ، فَيُدْعَى الْيَهُودُ فَيُقَالُ لَهُمْ مَنْ كُنْتُمْ تَعْبُدُونَ قَالُوا كُنَّا نَعْبُدُ عُزَيْرَ ابْنَ اللَّهِ‏.‏ فَيُقَالُ لَهُمْ كَذَبْتُمْ، مَا اتَّخَذَ اللَّهُ مِنْ صَاحِبَةٍ وَلاَ وَلَدٍ، فَمَاذَا تَبْغُونَ فَقَالُوا عَطِشْنَا رَبَّنَا فَاسْقِنَا‏.‏ فَيُشَارُ أَلاَ تَرِدُونَ، فَيُحْشَرُونَ إِلَى النَّارِ كَأَنَّهَا سَرَابٌ، يَحْطِمُ بَعْضُهَا بَعْضًا فَيَتَسَاقَطُونَ فِي النَّارِ، ثُمَّ يُدْعَى النَّصَارَى، فَيُقَالُ لَهُمْ مَنْ كُنْتُمْ تَعْبُدُونَ قَالُوا كُنَّا نَعْبُدُ الْمَسِيحَ ابْنَ اللَّهِ‏.‏ فَيُقَالُ لَهُمْ كَذَبْتُمْ، مَا اتَّخَذَ اللَّهُ مِنْ صَاحِبَةٍ وَلاَ وَلَدٍ‏.‏ فَيُقَالُ لَهُمْ مَاذَا تَبْغُونَ فَكَذَلِكَ مِثْلَ الأَوَّلِ، حَتَّى إِذَا لَمْ يَبْقَ إِلاَّ مَنْ كَانَ يَعْبُدُ اللَّهَ مِنْ بَرٍّ أَوْ فَاجِرٍ، أَتَاهُمْ رَبُّ الْعَالَمِينَ فِي أَدْنَى صُورَةٍ مِنَ الَّتِي رَأَوْهُ فِيهَا، فَيُقَالُ مَاذَا تَنْتَظِرُونَ تَتْبَعُ كُلُّ أُمَّةٍ مَا كَانَتْ تَعْبُدُ‏.‏ قَالُوا فَارَقْنَا النَّاسَ فِي الدُّنْيَا عَلَى أَفْقَرِ مَا كُنَّا إِلَيْهِمْ، وَلَمْ نُصَاحِبْهُمْ، وَنَحْنُ نَنْتَظِرُ رَبَّنَا الَّذِي كُنَّا نَعْبُدُ‏.‏ فَيَقُولُ أَنَا رَبُّكُمْ، فَيَقُولُونَ لاَ نُشْرِكُ بِاللَّهِ شَيْئًا‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا ‏"‏‏.‏\hadithno{4581}\hadithtrans{Narrated Abu Sa`id Al-Khudri:During the lifetime of the Prophet (ﷺ) some people said, : O Allah's Messenger (ﷺ)! Shall we see our Lord on the Day of Resurrection?" The Prophet (ﷺ) said, "Yes; do you have any difficulty in seeing the sun at midday when it is bright and there is no cloud in the sky?" They replied, "No." He said, "Do you have any difficulty in seeing the moon on a full moon night when it is bright and there is no cloud in the sky?" They replied, "No." The Prophet (ﷺ) said, "(Similarly) you will have no difficulty in seeing Allah on the Day of Resurrection as you have no difficulty in seeing either of them. On the Day of Resurrection, a call-maker will announce, "Let every nation follow that which they used to worship." Then none of those who used to worship anything other than Allah like idols and other deities but will fall in Hell (Fire), till there will remain none but those who used to worship Allah, both those who were obedient (i.e. good) and those who were disobedient (i.e. bad) and the remaining party of the people of the Scripture. Then the Jews will be called upon and it will be said to them, 'Who did you use to worship?' They will say, 'We used to worship Ezra, the son of Allah.' It will be said to them, 'You are liars, for Allah has never taken anyone as a wife or a son. What do you want now?' They will say, 'O our Lord! We are thirsty, so give us something to drink.' They will be directed and addressed thus, 'Will you drink,' whereupon they will be gathered unto Hell (Fire) which will look like a mirage whose different sides will be destroying each other. Then they will fall into the Fire. Afterwards the Christians will be called upon and it will be said to them, 'Who did you use to worship?' They will say, 'We used to worship Jesus, the son of Allah.' It will be said to them, 'You are liars, for Allah has never taken anyone as a wife or a son,' Then it will be said to them, 'What do you want?' They will say what the former people have said. Then, when there remain (in the gathering) none but those who used to worship Allah (Alone, the real Lord of the Worlds) whether they were obedient or disobedient. Then (Allah) the Lord of the worlds will come to them in a shape nearest to the picture they had in their minds about Him. It will be said, 'What are you waiting for?' Every nation has followed what they used to worship.' They will reply, 'We left the people in the world when we were in great need of them and we did not take them as friends. Now we are waiting for our Lord Whom we used to worship.' Allah will say, 'I am your Lord.' They will say twice or thrice, 'We do not worship any besides Allah}}
\hadithdefcmd{bukhari}{4582}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ يَحْيَى بَعْضُ الْحَدِيثِ عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ اقْرَأْ عَلَىَّ ‏"‏‏.‏ قُلْتُ آقْرَأُ عَلَيْكَ وَعَلَيْكَ أُنْزِلَ قَالَ ‏"‏ فَإِنِّي أُحِبُّ أَنْ أَسْمَعَهُ مِنْ غَيْرِي ‏"‏‏.‏ فَقَرَأْتُ عَلَيْهِ سُورَةَ النِّسَاءِ حَتَّى بَلَغْتُ ‏\{‏فَكَيْفَ إِذَا جِئْنَا مِنْ كُلِّ أُمَّةٍ بِشَهِيدٍ وَجِئْنَا بِكَ عَلَى هَؤُلاَءِ شَهِيدًا‏\}‏ قَالَ ‏"‏ أَمْسِكْ ‏"‏‏.‏ فَإِذَا عَيْنَاهُ تَذْرِفَانِ‏.‏\hadithno{4582}\hadithtrans{Narrated `Abdullah bin Masud:Allah's Messenger (ﷺ) said to me, "Recite (of the Qur'an) for me," I said, "Shall I recite it to you although it had been revealed to you?" He said, "I like to hear (the Qur'an) from others." So I recited Surat-an- Nisa' till I reached: "How (will it be) then when We bring from each nation a witness, and We bring you (O Muhammad) as a witness against these people?" (4.41) Then he said, "Stop!" And behold, his eyes were overflowing with tears}}
\hadithdefcmd{bukhari}{4583}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ هَلَكَتْ قِلاَدَةٌ لأَسْمَاءَ فَبَعَثَ النَّبِيُّ صلى الله عليه وسلم فِي طَلَبِهَا، رِجَالاً فَحَضَرَتِ الصَّلاَةُ وَلَيْسُوا عَلَى وُضُوءٍ‏.‏ وَلَمْ يَجِدُوا مَاءً، فَصَلَّوْا وَهُمْ عَلَى غَيْرِ وُضُوءٍ، فَأَنْزَلَ اللَّهُ‏.‏ يَعْنِي آيَةَ التَّيَمُّمِ‏.‏\hadithno{4583}\hadithtrans{Narrated `Aisha:The necklace of Asma' was lost, so the Prophet (ﷺ) sent some men to look for it. The time for the prayer became due and they had not performed ablution and could not find water, so they offered the prayer without ablution. Then Allah revealed (the Verse of Tayammum)}}
\hadithdefcmd{bukhari}{4584}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ يَعْلَى بْنِ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏أَطِيعُوا اللَّهَ وَأَطِيعُوا الرَّسُولَ وَأُولِي الأَمْرِ مِنْكُمْ‏\}‏‏.‏ قَالَ نَزَلَتْ فِي عَبْدِ اللَّهِ بْنِ حُذَافَةَ بْنِ قَيْسِ بْنِ عَدِيٍّ، إِذْ بَعَثَهُ النَّبِيُّ صلى الله عليه وسلم فِي سَرِيَّةٍ‏.‏\hadithno{4584}\hadithtrans{Narrated Ibn `Abbas:The Verse: "Obey Allah and Obey the Apostle and those of you (Muslims) who are in authority." (4.59) was revealed in connection with `Abdullah bin Hudhafa bin Qais bin `Adi' when the Prophet (ﷺ) appointed him as the commander of a Sariyya (army detachment)}}
\hadithdefcmd{bukhari}{4585}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ خَاصَمَ الزُّبَيْرُ رَجُلاً مِنَ الأَنْصَارِ فِي شَرِيجٍ مِنَ الْحَرَّةِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلِ الْمَاءَ إِلَى جَارِكَ ‏"‏‏.‏ فَقَالَ الأَنْصَارِيُّ يَا رَسُولَ اللَّهِ أَنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُهُ ثُمَّ قَالَ ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ احْبِسِ الْمَاءَ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ، ثُمَّ أَرْسِلِ الْمَاءَ إِلَى جَارِكَ ‏"‏‏.‏ وَاسْتَوْعَى النَّبِيُّ صلى الله عليه وسلم لِلزُّبَيْرِ حَقَّهُ فِي صَرِيحِ الْحُكْمِ حِينَ أَحْفَظَهُ الأَنْصَارِيُّ، كَانَ أَشَارَ عَلَيْهِمَا بِأَمْرٍ لَهُمَا فِيهِ سَعَةٌ‏.‏ قَالَ الزُّبَيْرُ فَمَا أَحْسِبُ هَذِهِ الآيَاتِ إِلاَّ نَزَلَتْ فِي ذَلِكَ ‏\{‏فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ‏\}‏\hadithno{4585}\hadithtrans{Narrated `Urwa:Az-Zubair quarrelled with a man from the Ansar because of a natural mountainous stream at Al-Harra. The Prophet (ﷺ) said, "O Zubair! Irrigate (your lands) and then let the water flow to your neighbor." The Ansar said, "O Allah's Messenger (ﷺ) (This is because) he (Zubair) is your cousin?" At that, the Prophet's face became red (with anger) and he said "O Zubair! Irrigate (your land) and then withhold the water till it fills the land up to the walls and then let it flow to your neighbor." So the Prophet (ﷺ) enabled Az-Zubair to take his full right after the Ansari provoked his anger. The Prophet (ﷺ) had previously given an order that was in favor of both of them Az-Zubair said, "I don't think but the Verse was revealed in this connection: "But no, by your Lord, they can have no faith, until they make you judge in all disputes between them}}
\hadithdefcmd{bukhari}{4586}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ نَبِيٍّ يَمْرَضُ إِلاَّ خُيِّرَ بَيْنَ الدُّنْيَا وَالآخِرَةِ ‏"‏‏.‏ وَكَانَ فِي شَكْوَاهُ الَّذِي قُبِضَ فِيهِ أَخَذَتْهُ بُحَّةٌ شَدِيدَةٌ فَسَمِعْتُهُ يَقُولُ ‏\{‏مَعَ الَّذِينَ أَنْعَمَ اللَّهُ عَلَيْهِمْ مِنَ النَّبِيِّينَ وَالصِّدِّيقِينَ وَالشُّهَدَاءِ وَالصَّالِحِينَ‏\}‏ فَعَلِمْتُ أَنَّهُ خُيِّرَ‏.‏\hadithno{4586}\hadithtrans{Narrated `Aisha:I heard Allah's Messenger (ﷺ) saying, "No prophet gets sick but he is given the choice to select either this world or the Hereafter." `Aisha added: During his fatal illness, his voice became very husky and I heard him saying: "In the company of those whom is the Grace of Allah, of the prophets, the Siddiqin (those followers of the prophets who were first and foremost to believe in them), the martyrs and the pious.' (4.69) And from this I came to know that he has been given the option}}
\hadithdefcmd{bukhari}{4587}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، قَالَ كُنْتُ أَنَا وَأُمِّي، مِنَ الْمُسْتَضْعَفِينَ‏.‏\hadithno{4587}\hadithtrans{Narrated Ibn `Abbas:My mother and I were among the weak and oppressed (Muslims at Mecca)}}
\hadithdefcmd{bukhari}{4588}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ ابْنَ عَبَّاسٍ، تَلاَ ‏\{‏ِلاَّ الْمُسْتَضْعَفِينَ مِنَ الرِّجَالِ وَالنِّسَاءِ وَالْوِلْدَانِ‏\}‏ قَالَ كُنْتُ أَنَا وَأُمِّي مِمَّنْ عَذَرَ اللَّهُ‏.‏ وَيُذْكَرُ عَنِ ابْنِ عَبَّاسٍ ‏\{‏حَصِرَتْ‏\}‏ ضَاقَتْ ‏\{‏تَلْوُوا‏\}‏ أَلْسِنَتَكُمْ بِالشَّهَادَةِ‏.‏ وَقَالَ غَيْرُهُ الْمُرَاغَمُ الْمُهَاجَرُ‏.‏ رَاغَمْتُ هَاجَرْتُ قَوْمِي‏.‏ ‏\{‏مَوْقُوتًا‏\}‏ مُوَقَّتًا وَقْتَهُ عَلَيْهِمْ‏.‏\hadithno{4588}\hadithtrans{Narrated Ibn Abi Mulaika:Ibn `Abbas recited:-- "Except the weak ones among men women and children," (4.98) and said, "My mother and I were among those whom Allah had excused}}
\hadithdefcmd{bukhari}{4589}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، وَعَبْدُ الرَّحْمَنِ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ زَيْدِ بْنِ ثَابِت ٍ ـ رضى الله عنه ـ ‏\{‏فَمَا لَكُمْ فِي الْمُنَافِقِينَ فِئَتَيْنِ‏\}‏ رَجَعَ نَاسٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْ أُحُدٍ، وَكَانَ النَّاسُ فِيهِمْ فِرْقَتَيْنِ فَرِيقٌ يَقُولُ اقْتُلْهُمْ‏.‏ وَفَرِيقٌ يَقُولُ لاَ فَنَزَلَتْ ‏\{‏فَمَا لَكُمْ فِي الْمُنَافِقِينَ فِئَتَيْنِ‏\}‏ وَقَالَ ‏"‏ إِنَّهَا طَيْبَةُ تَنْفِي الْخَبَثَ كَمَا تَنْفِي النَّارُ خَبَثَ الْفِضَّةِ ‏"‏‏.‏\hadithno{4589}\hadithtrans{Narrated Zaid bin Thabit:Regarding the Verse:-- "Then what is the matter with you that you are divided into two parties about the hypocrites?" (4.88) Some of the companions of the Prophet (ﷺ) returned from the battle of Uhud (i.e. refused to fight) whereupon the Muslims got divided into two parties; one of them was in favor of their execution and the other was not in favour of it. So there was revealed: "Then what is the matter with you that you are divided into two parties about the hypocrites?" (4.88). Then the Prophet (ﷺ) said "It (i.e. Medina) is Taybah (good), it expels impurities as the fire expels the impurities of silver}}
\hadithdefcmd{bukhari}{4590}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُغِيرَةُ بْنُ النُّعْمَانِ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، قَالَ ‏\{‏آيَةٌ‏\}‏ اخْتَلَفَ فِيهَا أَهْلُ الْكُوفَةِ، فَرَحَلْتُ فِيهَا إِلَى ابْنِ عَبَّاسٍ فَسَأَلْتُهُ عَنْهَا فَقَالَ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ‏\}‏ هِيَ آخِرُ مَا نَزَلَ وَمَا نَسَخَهَا شَىْءٌ‏.‏\hadithno{4590}\hadithtrans{Narrated Sa`id bin Jubair:The people of Kufa disagreed (disputed) about the above Verse. So I went to Ibn `Abbas and asked him about it. He said, "This Verse:-- "And whoever kills a believer intentionally, his recompense is Hell." was revealed last of all (concerning premeditated murder) and nothing abrogated it}}
\hadithdefcmd{bukhari}{4591}{حَدَّثَنِي عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏وَلاَ تَقُولُوا لِمَنْ أَلْقَى إِلَيْكُمُ السَّلاَمَ لَسْتَ مُؤْمِنًا‏\}‏‏.‏ قَالَ قَالَ ابْنُ عَبَّاسٍ كَانَ رَجُلٌ فِي غُنَيْمَةٍ لَهُ فَلَحِقَهُ الْمُسْلِمُونَ فَقَالَ السَّلاَمُ عَلَيْكُمْ، فَقَتَلُوهُ وَأَخَذُوا غُنَيْمَتَهُ، فَأَنْزَلَ اللَّهُ فِي ذَلِكَ إِلَى قَوْلِهِ ‏\{‏عَرَضَ الْحَيَاةِ الدُّنْيَا‏\}‏ تِلْكَ الْغُنَيْمَةُ‏.‏ قَالَ قَرَأَ ابْنُ عَبَّاسٍ السَّلاَمَ‏.‏\hadithno{4591}\hadithtrans{Narrated Ibn `Abbas:Regarding the Verse: "And say not to anyone who offers you peace (by accepting Islam), You are not a believer." There was a man amidst his sheep. The Muslims pursued him, and he said (to them) "Peace be on you." But they killed him and took over his sheep. Thereupon Allah revealed in that concern, the above Verse up to:-- "...seeking the perishable good of this life." (4.94) i.e. those sheep}}
\hadithdefcmd{bukhari}{4592}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَهْلُ بْنُ سَعْدٍ السَّاعِدِيُّ، أَنَّهُ رَأَى مَرْوَانَ بْنَ الْحَكَمِ فِي الْمَسْجِدِ، فَأَقْبَلْتُ حَتَّى جَلَسْتُ إِلَى جَنْبِهِ، فَأَخْبَرَنَا أَنَّ زَيْدَ بْنَ ثَابِتٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمْلَى عَلَيْهِ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ فَجَاءَهُ ابْنُ أُمِّ مَكْتُومٍ وَهْوَ يُمِلُّهَا عَلَىَّ قَالَ يَا رَسُولَ اللَّهِ، وَاللَّهِ لَوْ أَسْتَطِيعُ الْجِهَادَ لَجَاهَدْتُ ـ وَكَانَ أَعْمَى ـ فَأَنْزَلَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم وَفَخِذُهُ عَلَى فَخِذِي، فَثَقُلَتْ عَلَىَّ حَتَّى خِفْتُ أَنْ تُرَضَّ فَخِذِي، ثُمَّ سُرِّيَ عَنْهُ، فَأَنْزَلَ اللَّهُ ‏\{‏غَيْرَ أُولِي الضَّرَرِ‏\}‏\hadithno{4592}\hadithtrans{Narrated Zaid bin Thabit:That the Prophet (ﷺ) dictated to him: "Not equal are those of the believers who sit (at home) and those who strive and fight in the Cause of Allah." Zaid added: Ibn Um Maktum came while the Prophet (ﷺ) was dictating to me and said, "O Allah's Apostle! By Allah, if I had the power to fight (in Allah's Cause), I would," and he was a blind man. So Allah revealed to His Apostle while his thigh was on my thigh, and his thigh became so heavy that I was afraid it might fracture my thigh. Then that state of the Prophet (ﷺ) passed and Allah revealed:-- "Except those who are disabled (by injury or are blind or lame etc)}}
\hadithdefcmd{bukhari}{4593}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ ‏\{‏لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ‏\}‏ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْدًا فَكَتَبَهَا، فَجَاءَ ابْنُ أُمِّ مَكْتُومٍ فَشَكَا ضَرَارَتَهُ، فَأَنْزَلَ اللَّهُ ‏\{‏غَيْرَ أُولِي الضَّرَرِ‏\}‏\hadithno{4593}\hadithtrans{Narrated Al-Bara:When the Verse:-- "Not equal are those of the believers who sit (at home)" (4.95) was revealed, Allah's Apostle called for Zaid who wrote it. In the meantime Ibn Um Maktum came and complained of his blindness, so Allah revealed: "Except those who are disabled (by injury or are blind or lame..." etc)}}
\hadithdefcmd{bukhari}{4594}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ لَمَّا نَزَلَتْ ‏\{‏لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ‏\}‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ادْعُوا فُلاَنًا ‏"‏‏.‏ فَجَاءَهُ وَمَعَهُ الدَّوَاةُ وَاللَّوْحُ أَوِ الْكَتِفُ فَقَالَ ‏"‏ اكْتُبْ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ وَخَلْفَ النَّبِيِّ صلى الله عليه وسلم ابْنُ أُمِّ مَكْتُومٍ فَقَالَ يَا رَسُولَ اللَّهِ أَنَا ضَرِيرٌ‏.‏ فَنَزَلَتْ مَكَانَهَا ‏\{‏لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ غَيْرُ أُولِي الضَّرَرِ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ ‏\}‏\hadithno{4594}\hadithtrans{Narrated Al-Bara:When the Verse:--"Not equal are those of the believers who sit (at home)," (4.95) was revealed, the Prophet said, "Call so-and-so." That person came to him with an ink-pot and a wooden board or a shoulder scapula bone. The Prophet (ﷺ) said (to him), "Write: 'Not equal are those believers who sit (at home) and those who strive and fight in the Cause of Allah." Ibn Um Maktum who was sitting behind the Prophet (ﷺ) then said, "O Allah's Messenger (ﷺ)! I am a blind man." So there was revealed in the place of that Verse, the Verse:--"Not equal are those of the believers who sit (at home) except those who are disabled (by injury, or are blind or lame etc.) and those who strive and fight in the Cause of Allah}}
\hadithdefcmd{bukhari}{4595}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ ح، وَحَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ الْكَرِيمِ، أَنَّ مِقْسَمًا، مَوْلَى عَبْدِ اللَّهِ بْنِ الْحَارِثِ أَخْبَرَهُ أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ ‏\{‏لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ‏\}‏ عَنْ بَدْرٍ وَالْخَارِجُونَ إِلَى بَدْرٍ‏.‏\hadithno{4595}\hadithtrans{Narrated Ibn `Abbas:Not equal are those believers who sat (at home) and did not join the Badr battle and those who joined the Badr battle}}
\hadithdefcmd{bukhari}{4596}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ، وَغَيْرُهُ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو الأَسْوَدِ، قَالَ قُطِعَ عَلَى أَهْلِ الْمَدِينَةِ بَعْثٌ فَاكْتُتِبْتُ فِيهِ، فَلَقِيتُ عِكْرِمَةَ مَوْلَى ابْنِ عَبَّاسٍ فَأَخْبَرْتُهُ، فَنَهَانِي عَنْ ذَلِكَ أَشَدَّ النَّهْىِ، ثُمَّ قَالَ أَخْبَرَنِي ابْنُ عَبَّاسٍ أَنَّ نَاسًا مِنَ الْمُسْلِمِينَ كَانُوا مَعَ الْمُشْرِكِينَ يُكَثِّرُونَ سَوَادَ الْمُشْرِكِينَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَأْتِي السَّهْمُ فَيُرْمَى بِهِ، فَيُصِيبُ أَحَدَهُمْ فَيَقْتُلُهُ أَوْ يُضْرَبُ فَيُقْتَلُ، فَأَنْزَلَ اللَّهُ ‏\{‏إِنَّ الَّذِينَ تَوَفَّاهُمُ الْمَلاَئِكَةُ ظَالِمِي أَنْفُسِهِمْ‏\}‏ الآيَةَ‏.‏ رَوَاهُ اللَّيْثُ عَنْ أَبِي الأَسْوَدِ‏.‏\hadithno{4596}\hadithtrans{Narrated Muhammad bin `Abdur-Rahman Abu Al-Aswad:The people of Medina were forced to prepare an army (to fight against the people of Sham during the caliphate of `Abdullah bin Az-Zubair at Mecca), and I was enlisted in it; Then I met `Ikrima, the freed slave of Ibn `Abbas, and informed him (about it), and he forbade me strongly to do so (i.e. to enlist in that army), and then said, "Ibn `Abbas informed me that some Muslim people were with the pagans, increasing the number of the pagans against Allah's Messenger (ﷺ). An arrow used to be shot which would hit one of them (the Muslims in the company of the pagans) and kill him, or he would be struck and killed (with a sword)." Then Allah revealed:-- "Verily! as for those whom the angels take (in death) while they are wronging themselves (by staying among the disbelievers)" (4.97) Abu AlAswad also narrated it}}
\hadithdefcmd{bukhari}{4597}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏إِلاَّ الْمُسْتَضْعَفِينَ‏\}‏ قَالَ كَانَتْ أُمِّي مِمَّنْ عَذَرَ اللَّهُ‏.‏\hadithno{4597}\hadithtrans{Narrated Ibn `Abbas:'"Except the weak ones" (4.98) and added: My mother was one of those whom Allah excused}}
\hadithdefcmd{bukhari}{4598}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الْعِشَاءَ إِذْ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏‏.‏ ثُمَّ قَالَ قَبْلَ أَنْ يَسْجُدَ ‏"‏ اللَّهُمَّ نَجِّ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ، اللَّهُمَّ نَجِّ سَلَمَةَ بْنَ هِشَامٍ، اللَّهُمَّ نَجِّ الْوَلِيدَ بْنَ الْوَلِيدِ، اللَّهُمَّ نَجِّ الْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ، اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ، اللَّهُمَّ اجْعَلْهَا سِنِينَ كَسِنِي يُوسُفَ ‏"‏‏.‏\hadithno{4598}\hadithtrans{Narrated Abu Huraira:While the Prophet (ﷺ) was offering the `Isha' prayer, he said, "Allah hears him who sends his praises to Him," and then said before falling in prostration, "O Allah, save `Aiyash bin Rabi`a. O Allah, save Salama bin Hisham. O Allah, save Al-Walid bin Al-Walid. O Allah, save the weak ones among the believers. O Allah, let Your punishment be severe on the tribe of Mudar. O Allah, inflict upon them years (of famine) like the years of Joseph}}
\hadithdefcmd{bukhari}{4599}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي يَعْلَى، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏إِنْ كَانَ بِكُمْ أَذًى مِنْ مَطَرٍ أَوْ كُنْتُمْ مَرْضَى‏\}‏ قَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفِ كَانَ جَرِيحًا‏.‏\hadithno{4599}\hadithtrans{Narrated Ibn `Abbas:Regarding the Verse: "Because of the inconvenience of rain or because you are ill." (4.102) (It was revealed in connection with) `Abdur-Rahman bin `Auf who was wounded}}
\hadithdefcmd{bukhari}{4600}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ ‏\{‏وَيَسْتَفْتُونَكَ فِي النِّسَاءِ قُلِ اللَّهُ يُفْتِيكُمْ فِيهِنَّ‏\}‏ إِلَى قَوْلِهِ ‏\{‏وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏‏.‏ قَالَتْ هُوَ الرَّجُلُ تَكُونُ عِنْدَهُ الْيَتِيمَةُ، هُوَ وَلِيُّهَا وَوَارِثُهَا، فَأَشْرَكَتْهُ فِي مَالِهِ حَتَّى فِي الْعِذْقِ، فَيَرْغَبُ أَنْ يَنْكِحَهَا، وَيَكْرَهُ أَنْ يُزَوِّجَهَا رَجُلاً، فَيَشْرَكُهُ فِي مَالِهِ بِمَا شَرِكَتْهُ فَيَعْضُلَهَا فَنَزَلَتْ هَذِهِ الآيَةُ‏.‏\hadithno{4600}\hadithtrans{Narrated `Aisha:Regarding the Verse:--"They ask your instruction concerning the women. Say: Allah instructs you about them and yet whom you desire to marry." (4.127) (has been revealed regarding the case of) a man who has an orphan girl, and he is her guardian and her heir. The girl shares with him all his property, even a date-palm (garden), but he dislikes to marry her and dislikes to give her in marriage to somebody else who would share with him the property she is sharing with him, and for this reason that guardian prevents that orphan girl from marrying. So, this Verse was revealed: (And Allah's statement:) "If a woman fears cruelty or desertion on her husband's part}}
\hadithdefcmd{bukhari}{4601}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ ‏\{‏وَإِنِ امْرَأَةٌ خَافَتْ مِنْ بَعْلِهَا نُشُوزًا أَوْ إِعْرَاضًا‏\}‏‏.‏ قَالَتِ الرَّجُلُ تَكُونُ عِنْدَهُ الْمَرْأَةُ لَيْسَ بِمُسْتَكْثِرٍ مِنْهَا يُرِيدُ أَنْ يُفَارِقَهَا فَتَقُولُ أَجْعَلُكَ مِنْ شَأْنِي فِي حِلٍّ‏.‏ فَنَزَلَتْ هَذِهِ الآيَةُ فِي ذَلِكَ‏.‏\hadithno{4601}\hadithtrans{Narrated `Aisha:Regarding the Verse:--"If a woman fears cruelty or desertion on her husband's part." (4.128) It is about a man who has a woman (wife) and he does not like her and wants to divorce her but she says to him, "I make you free as regards myself." So this Verse was revealed in this connection}}
\hadithdefcmd{bukhari}{4602}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، قَالَ كُنَّا فِي حَلْقَةِ عَبْدِ اللَّهِ فَجَاءَ حُذَيْفَةُ حَتَّى قَامَ عَلَيْنَا، فَسَلَّمَ ثُمَّ قَالَ لَقَدْ أُنْزِلَ النِّفَاقُ عَلَى قَوْمٍ خَيْرٍ مِنْكُمْ‏.‏ قَالَ الأَسْوَدُ سُبْحَانَ اللَّهِ، إِنَّ اللَّهَ يَقُولُ ‏\{‏إِنَّ الْمُنَافِقِينَ فِي الدَّرَكِ الأَسْفَلِ مِنَ النَّارِ‏\}‏ فَتَبَسَّمَ عَبْدُ اللَّهِ، وَجَلَسَ حُذَيْفَةُ فِي نَاحِيَةِ الْمَسْجِدِ، فَقَامَ عَبْدُ اللَّهِ فَتَفَرَّقَ أَصْحَابُهُ، فَرَمَانِي بِالْحَصَا، فَأَتَيْتُهُ فَقَالَ حُذَيْفَةُ عَجِبْتُ مِنْ ضَحِكِهِ، وَقَدْ عَرَفَ مَا قُلْتُ، لَقَدْ أُنْزِلَ النِّفَاقُ عَلَى قَوْمٍ كَانُوا خَيْرًا مِنْكُمْ، ثُمَّ تَابُوا فَتَابَ اللَّهُ عَلَيْهِمْ‏.‏\hadithno{4602}\hadithtrans{Narrated Al-Aswad:While we were sitting in a circle in `Abdullah's gathering, Hudhaifa came and stopped before us, and greeted us and then said, "People better than you became hypocrites." Al-Aswad said: I testify the uniqueness of Allah! Allah says: "Verily! The hypocrites will be in the lowest depths of the Fire." (4.145) On that `Abdullah smiled and Hudhaifa sat somewhere in the Mosque. `Abdullah then got up and his companions (sitting around him) dispersed. Hudhaifa then threw a pebble at me (to attract my attention). I went to him and he said, "I was surprised at `Abdullah's smile though he understood what I said. Verily, people better than you became hypocrites and then repented and Allah forgave them}}
\hadithdefcmd{bukhari}{4603}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي الأَعْمَشُ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يَنْبَغِي لأَحَدٍ أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏\hadithno{4603}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "None has the right to say that I am better than Jonah bin Matta}}
\hadithdefcmd{bukhari}{4604}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا هِلاَلٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى فَقَدْ كَذَبَ ‏"‏‏.‏\hadithno{4604}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever says that I am better than Jonah bin Matta, is a liar}}
\hadithdefcmd{bukhari}{4605}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ آخِرُ سُورَةٍ نَزَلَتْ بَرَاءَةَ، وَآخِرُ آيَةٍ نَزَلَتْ ‏\{‏يَسْتَفْتُونَكَ ‏\}‏\hadithno{4605}\hadithtrans{Narrated Al-Bara:The last Sura that was revealed was Bara'a, and the last Verse that was revealed was: "They ask you for a legal verdict, Say: Allah directs (thus) about those who leave no descendants or ascendants as heirs}}
\hadithdefcmd{bukhari}{4606}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ قَيْسٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، قَالَتِ الْيَهُودُ لِعُمَرَ إِنَّكُمْ تَقْرَءُونَ آيَةً لَوْ نَزَلَتْ فِينَا لاَتَّخَذْنَاهَا عِيدًا‏.‏ فَقَالَ عُمَرُ إِنِّي لأَعْلَمُ حَيْثُ أُنْزِلَتْ، وَأَيْنَ أُنْزِلَتْ، وَأَيْنَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أُنْزِلَتْ يَوْمَ عَرَفَةَ، وَإِنَّا وَاللَّهِ بِعَرَفَةَ ـ قَالَ سُفْيَانُ وَأَشُكُّ كَانَ يَوْمَ الْجُمُعَةِ أَمْ لاَ – ‏\{‏الْيَوْمَ أَكْمَلْتُ لَكُمْ دِينَكُمْ‏\}‏\hadithno{4606}\hadithtrans{Narrated Tariq bin Shihab:The Jews said to `Umar, "You (i.e. Muslims) recite a Verse, and had it been revealed to us, we would have taken the day of its revelation as a day of celebration." `Umar said, "I know very well when and where it was revealed, and where Allah's Messenger (ﷺ) was when it was revealed. (It was revealed on) the day of `Arafat (Hajj Day), and by Allah, I was at `Arafat" Sufyan, a sub-narrator said: I am in doubt whether the Verse:-- "This day I have perfected your religion for you." was revealed on a Friday or not}}
\hadithdefcmd{bukhari}{4607}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ، حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ أَوْ بِذَاتِ الْجَيْشِ انْقَطَعَ عِقْدٌ لِي، فَأَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْتِمَاسِهِ، وَأَقَامَ النَّاسُ مَعَهُ، وَلَيْسُوا عَلَى مَاءٍ، وَلَيْسَ مَعَهُمْ مَاءٌ فَأَتَى النَّاسُ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ فَقَالُوا أَلاَ تَرَى مَا صَنَعَتْ عَائِشَةُ أَقَامَتْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَبِالنَّاسِ، وَلَيْسُوا عَلَى مَاءٍ، وَلَيْسَ مَعَهُمْ مَاءٌ، فَجَاءَ أَبُو بَكْرٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاضِعٌ رَأْسَهُ عَلَى فَخِذِي قَدْ نَامَ، فَقَالَ حَبَسْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالنَّاسَ، وَلَيْسُوا عَلَى مَاءٍ، وَلَيْسَ مَعَهُمْ مَاءٌ قَالَتْ عَائِشَةُ فَعَاتَبَنِي أَبُو بَكْرٍ، وَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ، وَجَعَلَ يَطْعُنُنِي بِيَدِهِ فِي خَاصِرَتِي، وَلاَ يَمْنَعُنِي مِنَ التَّحَرُّكِ إِلاَّ مَكَانُ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى فَخِذِي، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَصْبَحَ عَلَى غَيْرِ مَاءٍ، فَأَنْزَلَ اللَّهُ آيَةَ التَّيَمُّمِ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ مَا هِيَ بِأَوَّلِ بَرَكَتِكُمْ يَا آلَ أَبِي بَكْرٍ‏.‏ قَالَتْ فَبَعَثْنَا الْبَعِيرَ الَّذِي كُنْتُ عَلَيْهِ فَإِذَا الْعِقْدُ تَحْتَهُ‏.‏\hadithno{4607}\hadithtrans{Narrated Aisha:The wife of the Prophet (ﷺ) : We set out with Allah's Messenger (ﷺ) on one of his journeys, and when we were at Baida' or at Dhat-al-Jaish, a necklace of mine was broken (and lost). Allah's Messenger (ﷺ) stayed there to look for it, and so did the people along with him. Neither were they at a place of water, nor did they have any water with them. So the people went to Abu Bakr As-Siddiq and said, "Don't you see what `Aisha has done? She has made Allah's Messenger (ﷺ) and the people, stay where there is no water and they have no water with them." Abu Bakr came while Allah's Messenger (ﷺ) was sleeping with his head on my thigh. He said (to me), "You have detained Allah's Messenger (ﷺ) and the people where there is no water, and they have no water with them." So he admonished me and said what Allah wished him to say, and he hit me on my flanks with his hand. Nothing prevented me from moving (because of pain) but the position of Allah's Messenger (ﷺ) on my thigh. So Allah's Messenger (ﷺ) got up when dawn broke and there was no water, so Allah revealed the Verse of Tayammum. Usaid bin Hudair said, "It is not the first blessing of yours, O the family of Abu Bakr." Then we made the camel on which I was riding get up, and found the necklace under it}}
\hadithdefcmd{bukhari}{4608}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ سَقَطَتْ قِلاَدَةٌ لِي بِالْبَيْدَاءِ وَنَحْنُ دَاخِلُونَ الْمَدِينَةَ، فَأَنَاخَ النَّبِيُّ صلى الله عليه وسلم وَنَزَلَ، فَثَنَى رَأْسَهُ فِي حَجْرِي رَاقِدًا، أَقْبَلَ أَبُو بَكْرٍ فَلَكَزَنِي لَكْزَةً شَدِيدَةً وَقَالَ حَبَسْتِ النَّاسَ فِي قِلاَدَةٍ‏.‏ فَبِي الْمَوْتُ لِمَكَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ أَوْجَعَنِي، ثُمَّ إِنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَيْقَظَ وَحَضَرَتِ الصُّبْحُ فَالْتُمِسَ الْمَاءُ فَلَمْ يُوجَدْ فَنَزَلَتْ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا إِذَا قُمْتُمْ إِلَى الصَّلاَةِ‏\}‏ الآيَةَ‏.‏ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ لَقَدْ بَارَكَ اللَّهُ لِلنَّاسِ فِيكُمْ يَا آلَ أَبِي بَكْرٍ، مَا أَنْتُمْ إِلاَّ بَرَكَةٌ لَهُمْ‏.‏\hadithno{4608}\hadithtrans{Narrated Aisha:A necklace of mine was lost at Al-Baida' and we were on our way to Medina. The Prophet (ﷺ) made his camel kneel down and dismounted and laid his head on my lap and slept. Abu Bakr came to me and hit me violently on the chest and said, "You have detained the people because of a necklace." I kept as motionless as a dead person because of the position of Allah's Messenger (ﷺ) ; (on my lap) although Abu Bakr had hurt me (with the slap). Then the Prophet (ﷺ) woke up and it was the time for the morning (prayer). Water was sought, but in vain; so the following Verse was revealed:-- "O you who believe! When you intend to offer prayer.." (5.6) Usaid bin Hudair said, "Allah has blessed the people for your sake, O the family of Abu Bakr. You are but a blessing for them}}
\hadithdefcmd{bukhari}{4609}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ مُخَارِقٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، سَمِعْتُ ابْنَ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ شَهِدْتُ مِنَ الْمِقْدَادِ ح وَحَدَّثَنِي حَمْدَانُ بْنُ عُمَرَ حَدَّثَنَا أَبُو النَّضْرِ حَدَّثَنَا الأَشْجَعِيُّ عَنْ سُفْيَانَ عَنْ مُخَارِقٍ عَنْ طَارِقٍ عَنْ عَبْدِ اللَّهِ قَالَ قَالَ الْمِقْدَادُ يَوْمَ بَدْرٍ يَا رَسُولَ اللَّهِ إِنَّا لاَ نَقُولُ لَكَ كَمَا قَالَتْ بَنُو إِسْرَائِيلَ لِمُوسَى ‏\{‏فَاذْهَبْ أَنْتَ وَرَبُّكَ فَقَاتِلاَ إِنَّا هَا هُنَا قَاعِدُونَ‏\}‏ وَلَكِنِ امْضِ وَنَحْنُ مَعَكَ‏.‏ فَكَأَنَّهُ سُرِّيَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ وَرَوَاهُ وَكِيعٌ عَنْ سُفْيَانَ عَنْ مُخَارِقٍ عَنْ طَارِقٍ أَنَّ الْمِقْدَادَ قَالَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{4609}\hadithtrans{Narrated `Abdullah (bin Masud):On the day of Badr, Al-Miqdad said, "O Allah's Messenger (ﷺ)! We do not say to you as the children of Israel said to Moses, 'Go you and your Lord and fight you two; we are sitting here, (5.24) but (we say). "Proceed, and we are with you." That seemed to delight Allah's Messenger (ﷺ) greatly}}
\hadithdefcmd{bukhari}{4610}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا ابْنُ عَوْنٍ، قَالَ حَدَّثَنِي سَلْمَانُ أَبُو رَجَاءٍ، مَوْلَى أَبِي قِلاَبَةَ عَنْ أَبِي قِلاَبَةَ، أَنَّهُ كَانَ جَالِسًا خَلْفَ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، فَذَكَرُوا وَذَكَرُوا فَقَالُوا وَقَالُوا قَدْ أَقَادَتْ بِهَا الْخُلَفَاءُ، فَالْتَفَتَ إِلَى أَبِي قِلاَبَةَ وَهْوَ خَلْفَ ظَهْرِهِ، فَقَالَ مَا تَقُولُ يَا عَبْدَ اللَّهِ بْنَ زَيْدٍ أَوْ قَالَ مَا تَقُولُ يَا أَبَا قِلاَبَةَ قُلْتُ مَا عَلِمْتُ نَفْسًا حَلَّ قَتْلُهَا فِي الإِسْلاَمِ إِلاَّ رَجُلٌ زَنَى بَعْدَ إِحْصَانٍ، أَوْ قَتَلَ نَفْسًا بِغَيْرِ نَفْسٍ، أَوْ حَارَبَ اللَّهَ وَرَسُولَهُ صلى الله عليه وسلم‏.‏ فَقَالَ عَنْبَسَةُ حَدَّثَنَا أَنَسٌ بِكَذَا وَكَذَا‏.‏ قُلْتُ إِيَّاىَ حَدَّثَ أَنَسٌ قَالَ قَدِمَ قَوْمٌ عَلَى النَّبِيِّ صلى الله عليه وسلم فَكَلَّمُوهُ فَقَالُوا قَدِ اسْتَوْخَمْنَا هَذِهِ الأَرْضَ‏.‏ فَقَالَ ‏ "‏ هَذِهِ نَعَمٌ لَنَا تَخْرُجُ، فَاخْرُجُوا فِيهَا، فَاشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏‏.‏ فَخَرَجُوا فِيهَا فَشَرِبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا وَاسْتَصَحُّوا، وَمَالُوا عَلَى الرَّاعِي فَقَتَلُوهُ، وَاطَّرَدُوا النَّعَمَ، فَمَا يُسْتَبْطَأُ مِنْ هَؤُلاَءِ قَتَلُوا النَّفْسَ وَحَارَبُوا اللَّهَ وَرَسُولَهُ، وَخَوَّفُوا رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ سُبْحَانَ اللَّهِ‏.‏ فَقُلْتُ تَتَّهِمُنِي قَالَ حَدَّثَنَا بِهَذَا أَنَسٌ‏.‏ قَالَ وَقَالَ يَا أَهْلَ كَذَا إِنَّكُمْ لَنْ تَزَالُوا بِخَيْرٍ مَا أُبْقِيَ هَذَا فِيكُمْ أَوْ مِثْلُ هَذَا‏.‏\hadithno{4610}\hadithtrans{Narrated Abu Qilaba:That he was sitting behind `Umar bin `Abdul `Aziz and the people mentioned and mentioned (about al-Qasama) and they said (various things), and said that the Caliphs had permitted it. `Umar bin `Abdul `Aziz turned towards Abu Qilaba who was behind him and said. "What do you say, O `Abdullah bin Zaid?" or said, "What do you say, O Abu Qilaba?" Abu Qilaba said, "I do not know that killing a person is lawful in Islam except in three cases: a married person committing illegal sexual intercourse, one who has murdered somebody unlawfully, or one who wages war against Allah and His Apostle." 'Anbasa said, "Anas narrated to us such-and-such." Abu Qilaba said, "Anas narrated to me in this concern, saying, some people came to the Prophet (ﷺ) and they spoke to him saying, 'The climate of this land does not suit us.' The Prophet (ﷺ) said, 'These are camels belonging to us, and they are to be taken out to the pasture. So take them out and drink of their milk and urine.' So they took them and set out and drank of their urine and milk, and having recovered, they attacked the shepherd, killed him and drove away the camels.' Why should there be any delay in punishing them as they murdered (a person) and waged war against Allah and His Apostle and frightened Allah's Messenger (ﷺ) ?" Anbasa said, "I testify the uniqueness of Allah!" Abu Qilaba said, "Do you suspect me?" 'Anbasa said, "No, Anas narrated that (Hadith) to us." Then 'Anbasa added, "O the people of such-and-such (country), you will remain in good state as long as Allah keeps this (man) and the like of this (man) amongst you}}
\hadithdefcmd{bukhari}{4611}{حَدَّثَنِي مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا الْفَزَارِيُّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَسَرَتِ الرُّبَيِّعُ ـ وَهْىَ عَمَّةُ أَنَسِ بْنِ مَالِكٍ ـ ثَنِيَّةَ جَارِيَةٍ مِنَ الأَنْصَارِ، فَطَلَبَ الْقَوْمُ الْقِصَاصَ، فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِالْقِصَاصِ‏.‏ فَقَالَ أَنَسُ بْنُ النَّضْرِ عَمُّ أَنَسِ بْنِ مَالِكٍ لاَ وَاللَّهِ لاَ تُكْسَرْ سِنُّهَا يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَنَسُ كِتَابُ اللَّهِ الْقِصَاصُ ‏"‏‏.‏ فَرَضِيَ الْقَوْمُ وَقَبِلُوا الأَرْشَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ مَنْ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏‏.‏\hadithno{4611}\hadithtrans{Narrated Anas (bin Malik):Ar-Rubai (the paternal aunt of Anas bin Malik) broke the incisor tooth of a young Ansari girl. Her family demanded the Qisas and they came to the Prophet (ﷺ) who passed the judgment of Qisas. Anas bin An-Nadr (the paternal uncle of Anas bin Malik) said, "O Allah's Messenger (ﷺ)! By Allah, her tooth will not be broken." The Prophet (ﷺ) said, "O Anas! (The law prescribed in) Allah's Book is Qisas." But the people (i.e. the relatives of the girl) gave up their claim and accepted a compensation. On that Allah's Apostle said, "Some of Allah's worshippers are such that if they take an oath, Allah will fulfill it for them}}
\hadithdefcmd{bukhari}{4612}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَنْ حَدَّثَكَ أَنَّ مُحَمَّدًا صلى الله عليه وسلم كَتَمَ شَيْئًا مِمَّا أُنْزِلَ عَلَيْهِ، فَقَدْ كَذَبَ، وَاللَّهُ يَقُولُ ‏\{‏يَا أَيُّهَا الرَّسُولُ بَلِّغْ مَا أُنْزِلَ إِلَيْكَ‏\}‏ الآيَةَ‏.‏\hadithno{4612}\hadithtrans{Narrated `Aisha:Whoever tells that Muhammad concealed part of what was revealed to him, is a liar, for Allah says:-- "O Apostle (Muhammad)! Proclaim (the Message) which has been sent down to you from your Lord}}
\hadithdefcmd{bukhari}{4613}{حَدَّثَنَا عَلِيُّ بْنُ سَلَمَةَ، حَدَّثَنَا مَالِكُ بْنُ سُعَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنِ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏لاَ يُؤَاخِذُكُمُ اللَّهُ بِاللَّغْوِ فِي أَيْمَانِكُمْ‏\}‏ فِي قَوْلِ الرَّجُلِ لاَ وَاللَّهِ، وَبَلَى وَاللَّهِ‏.‏\hadithno{4613}\hadithtrans{Narrated `Aisha:This Verse: "Allah will not punish you for what is unintentional in your oaths." (5.89) was revealed about a man's statement (during his talk), "No, by Allah," and "Yes, by Allah}}
\hadithdefcmd{bukhari}{4614}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا النَّضْرُ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ أَبَاهَا، كَانَ لاَ يَحْنَثُ فِي يَمِينٍ حَتَّى أَنْزَلَ اللَّهُ كَفَّارَةَ الْيَمِينِ‏.‏ قَالَ أَبُو بَكْرٍ لاَ أَرَى يَمِينًا أُرَى غَيْرَهَا خَيْرًا مِنْهَا، إِلاَّ قَبِلْتُ رُخْصَةَ اللَّهِ، وَفَعَلْتُ الَّذِي هُوَ خَيْرٌ‏.‏\hadithno{4614}\hadithtrans{Narrated Aisha:That her father (Abu Bakr) never broke his oath till Allah revealed the order of the legal expiation for oath. Abu Bakr said, "If I ever take an oath (to do something) and later find that to do something else is better, then I accept Allah's permission and do that which is better, (and do the legal expiation for my oath)}}
\hadithdefcmd{bukhari}{4615}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا خَالِدٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ عَبْدِ اللَّهِ، رضى الله عنه قَالَ كُنَّا نَغْزُو مَعَ النَّبِيِّ صلى الله عليه وسلم وَلَيْسَ مَعَنَا نِسَاءٌ فَقُلْنَا أَلاَ نَخْتَصِي فَنَهَانَا عَنْ ذَلِكَ، فَرَخَّصَ لَنَا بَعْدَ ذَلِكَ أَنْ نَتَزَوَّجَ الْمَرْأَةَ بِالثَّوْبِ، ثُمَّ قَرَأَ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تُحَرِّمُوا طَيِّبَاتِ مَا أَحَلَّ اللَّهُ لَكُمْ ‏\}‏\hadithno{4615}\hadithtrans{Narrated `Abdullah:We used to participate in the holy wars carried on by the Prophet (ﷺ) and we had no women (wives) with us. So we said (to the Prophet (ﷺ) ). "Shall we castrate ourselves?" But the Prophet (ﷺ) forbade us to do that and thenceforth he allowed us to marry a woman (temporarily) by giving her even a garment, and then he recited: "O you who believe! Do not make unlawful the good things which Allah has made lawful for you}}
\hadithdefcmd{bukhari}{4616}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَزَلَ تَحْرِيمُ الْخَمْرِ وَإِنَّ فِي الْمَدِينَةِ يَوْمَئِذٍ لَخَمْسَةَ أَشْرِبَةٍ، مَا فِيهَا شَرَابُ الْعِنَبِ‏.‏\hadithno{4616}\hadithtrans{Narrated Ibn `Umar:(The Verse of) prohibiting alcoholic drinks was revealed when there were in Medina five kinds of (alcoholic) drinks none of which was produced from grapes}}
\hadithdefcmd{bukhari}{4617}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، قَالَ قَالَ أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ مَا كَانَ لَنَا خَمْرٌ غَيْرُ فَضِيخِكُمْ هَذَا الَّذِي تُسَمُّونَهُ الْفَضِيخَ‏.‏ فَإِنِّي لَقَائِمٌ أَسْقِي أَبَا طَلْحَةَ وَفُلاَنًا وَفُلاَنًا إِذْ جَاءَ رَجُلٌ فَقَالَ وَهَلْ بَلَغَكُمُ الْخَبَرُ فَقَالُوا وَمَا ذَاكَ قَالَ حُرِّمَتِ الْخَمْرُ‏.‏ قَالُوا أَهْرِقْ هَذِهِ الْقِلاَلَ يَا أَنَسُ‏.‏ قَالَ فَمَا سَأَلُوا عَنْهَا وَلاَ رَاجَعُوهَا بَعْدَ خَبَرِ الرَّجُلِ‏.‏\hadithno{4617}\hadithtrans{Narrated Anas bin Malik:We had no alcoholic drink except that which was produced from dates and which you call Fadikh. While I was standing offering drinks to Abu Talha and so-and-so and so-and-so, a man came and said, "Has the news reached you? They said, "What is that?" He said, "Alcoholic drinks have been prohibited. They said, "Spill (the contents of these pots, O Anas!" Then they neither asked about it (alcoholic drinks) nor returned to it after the news from that man}}
\hadithdefcmd{bukhari}{4618}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، قَالَ صَبَّحَ أُنَاسٌ غَدَاةَ أُحُدٍ الْخَمْرَ فَقُتِلُوا مِنْ يَوْمِهِمْ جَمِيعًا شُهَدَاءَ، وَذَلِكَ قَبْلَ تَحْرِيمِهَا‏.‏\hadithno{4618}\hadithtrans{Narrated Jabir:Some people drank alcoholic beverages in the morning (of the day) of the Uhud battle and on the same day they were killed as martyrs, and that was before wine was prohibited}}
\hadithdefcmd{bukhari}{4619}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عِيسَى، وَابْنُ، إِدْرِيسَ عَنْ أَبِي حَيَّانَ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ عُمَرَ ـ رضى الله عنه ـ عَلَى مِنْبَرِ النَّبِيِّ صلى الله عليه وسلم يَقُولُ أَمَّا بَعْدُ أَيُّهَا النَّاسُ إِنَّهُ نَزَلَ تَحْرِيمُ الْخَمْرِ وَهْىَ مِنْ خَمْسَةٍ، مِنَ الْعِنَبِ وَالتَّمْرِ وَالْعَسَلِ وَالْحِنْطَةِ وَالشَّعِيرِ، وَالْخَمْرُ مَا خَامَرَ الْعَقْلَ‏.‏\hadithno{4619}\hadithtrans{Narrated Ibn `Umar:I heard `Umar while he was on the pulpit of the Prophet (ﷺ) saying, "Now then O people! The revelation about the prohibition of alcoholic drinks was revealed; and alcoholic drinks are extracted from five things: Grapes, dates, honey, wheat and barley. And the alcoholic drink is that which confuses and stupefies the mind}}
\hadithdefcmd{bukhari}{4620}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ الْخَمْرَ، الَّتِي أُهْرِيقَتِ الْفَضِيخُ‏.‏ وَزَادَنِي مُحَمَّدٌ عَنْ أَبِي النُّعْمَانِ قَالَ كُنْتُ سَاقِيَ الْقَوْمِ فِي مَنْزِلِ أَبِي طَلْحَةَ فَنَزَلَ تَحْرِيمُ الْخَمْرِ، فَأَمَرَ مُنَادِيًا فَنَادَى‏.‏ فَقَالَ أَبُو طَلْحَةَ اخْرُجْ فَانْظُرْ مَا هَذَا الصَّوْتُ قَالَ فَخَرَجْتُ فَقُلْتُ هَذَا مُنَادٍ يُنَادِي أَلاَ إِنَّ الْخَمْرَ قَدْ حُرِّمَتْ‏.‏ فَقَالَ لِي اذْهَبْ فَأَهْرِقْهَا‏.‏ قَالَ فَجَرَتْ فِي سِكَكِ الْمَدِينَةِ‏.‏ قَالَ وَكَانَتْ خَمْرُهُمْ يَوْمَئِذٍ الْفَضِيخَ فَقَالَ بَعْضُ الْقَوْمِ قُتِلَ قَوْمٌ وَهْىَ فِي بُطُونِهِمْ قَالَ فَأَنْزَلَ اللَّهُ ‏\{‏لَيْسَ عَلَى الَّذِينَ آمَنُوا وَعَمِلُوا الصَّالِحَاتِ جُنَاحٌ فِيمَا طَعِمُوا‏\}‏‏.‏\hadithno{4620}\hadithtrans{Narrated Anas:The alcoholic drink which was spilled was Al-Fadikh. I used to offer alcoholic drinks to the people at the residence of Abu Talha. Then the order of prohibiting Alcoholic drinks was revealed, and the Prophet ordered somebody to announce that: Abu Talha said to me, "Go out and see what this voice (this announcement ) is." I went out and (on coming back) said, "This is somebody announcing that alcoholic beverages have been prohibited." Abu Talha said to me, "Go and spill it (i.e. the wine)," Then it (alcoholic drinks) was seen flowing through the streets of Medina. At that time the wine was Al-Fadikh. The people said, "Some people (Muslims) were killed (during the battle of Uhud) while wine was in their stomachs." So Allah revealed: "On those who believe and do good deeds there is no blame for what they ate (in the past)}}
\hadithdefcmd{bukhari}{4621}{حَدَّثَنَا مُنْذِرُ بْنُ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ الْجَارُودِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم خُطْبَةً مَا سَمِعْتُ مِثْلَهَا قَطُّ، قَالَ ‏"‏ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏‏.‏ قَالَ فَغَطَّى أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم وُجُوهَهُمْ لَهُمْ خَنِينٌ، فَقَالَ رَجُلٌ مَنْ أَبِي قَالَ فُلاَنٌ فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏لاَ تَسْأَلُوا عَنْ أَشْيَاءَ إِنْ تُبْدَ لَكُمْ تَسُؤْكُمْ‏\}‏‏.‏ رَوَاهُ النَّضْرُ وَرَوْحُ بْنُ عُبَادَةَ عَنْ شُعْبَةَ‏.‏\hadithno{4621}\hadithtrans{Narrated Anas:The Prophet (ﷺ) delivered a sermon the like of which I had never heard before. He said, "If you but knew what I know then you would have laughed little and wept much." On hearing that, the companions of the Prophet (ﷺ) covered their faces and the sound of their weeping was heard. A man said, "Who is my father?" The Prophet (ﷺ) said, "So-and-so." So this Verse was revealed: "Ask not about things which, if made plain to you, may cause you trouble}}
\hadithdefcmd{bukhari}{4622}{حَدَّثَنَا الْفَضْلُ بْنُ سَهْلٍ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا أَبُو خَيْثَمَةَ، حَدَّثَنَا أَبُو الْجُوَيْرِيَةِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ قَوْمٌ يَسْأَلُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتِهْزَاءً، فَيَقُولُ الرَّجُلُ مَنْ أَبِي وَيَقُولُ الرَّجُلُ تَضِلُّ نَاقَتُهُ أَيْنَ نَاقَتِي فَأَنْزَلَ اللَّهُ فِيهِمْ هَذِهِ الآيَةَ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَسْأَلُوا عَنْ أَشْيَاءَ إِنْ تُبْدَ لَكُمْ تَسُؤْكُمْ‏\}‏ حَتَّى فَرَغَ مِنَ الآيَةِ كُلِّهَا‏.‏\hadithno{4622}\hadithtrans{Narrated Ibn `Abbas:Some people were asking Allah's Messenger (ﷺ) questions mockingly. A man would say, "Who is my father?" Another man whose she-camel had gone astray would say, "Where is my she-camel? "So Allah revealed this Verse in this connection: "O you who believe! Ask not about things which, if made plain to you, may cause you trouble}}
\hadithdefcmd{bukhari}{4623}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ الْبَحِيرَةُ الَّتِي يُمْنَعُ دَرُّهَا لِلطَّوَاغِيتِ فَلاَ يَحْلُبُهَا أَحَدٌ مِنَ النَّاسِ‏.‏ وَالسَّائِبَةُ كَانُوا يُسَيِّبُونَهَا لآلِهَتِهِمْ لاَ يُحْمَلُ عَلَيْهَا شَىْءٌ‏.‏ قَالَ وَقَالَ أَبُو هُرَيْرَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ عَمْرَو بْنَ عَامِرٍ الْخُزَاعِيَّ يَجُرُّ قُصْبَهُ فِي النَّارِ، كَانَ أَوَّلَ مَنْ سَيَّبَ السَّوَائِبَ ‏"‏‏.‏ وَالْوَصِيلَةُ النَّاقَةُ الْبِكْرُ تُبَكِّرُ فِي أَوَّلِ نِتَاجِ الإِبِلِ، ثُمَّ تُثَنِّي بَعْدُ بِأُنْثَى‏.‏ وَكَانُوا يُسَيِّبُونَهُمْ لِطَوَاغِيتِهِمْ إِنْ وَصَلَتْ إِحْدَاهُمَا بِالأُخْرَى لَيْسَ بَيْنَهُمَا ذَكَرٌ‏.‏ وَالْحَامِ فَحْلُ الإِبِلِ يَضْرِبُ الضِّرَابَ الْمَعْدُودَ، فَإِذَا قَضَى ضِرَابَهُ وَدَعُوهُ لِلطَّوَاغِيتِ وَأَعْفَوْهُ مِنَ الْحَمْلِ فَلَمْ يُحْمَلْ عَلَيْهِ شَىْءٌ وَسَمَّوْهُ الْحَامِيَ‏.‏ وَقَالَ لي أَبُو الْيَمَانِ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، سَمِعْتُ سَعِيدًا، قَالَ يُخْبِرُهُ بِهَذَا قَالَ وَقَالَ أَبُو هُرَيْرَةَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم نَحْوَهُ‏.‏ وَرَوَاهُ ابْنُ الْهَادِ عَنِ ابْنِ شِهَابٍ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{4623}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:Bahira is a she-camel whose milk is kept for the idols and nobody is allowed to milk it; Sa'iba was the she-camel which they used to set free for their gods and nothing was allowed to be carried on it. Abu Huraira said: Allah's Messenger (ﷺ) said, "I saw `Amr bin 'Amir Al-Khuza`i (in a dream) dragging his intestines in the Fire, and he was the first person to establish the tradition of setting free the animals (for the sake of their deities)," Wasila is the she-camel which gives birth to a she-camel as its first delivery, and then gives birth to another she-camel as its second delivery. People (in the Pre-Islamic periods of ignorance) used to let that she camel loose for their idols if it gave birth to two she-camels successively without giving birth to a male camel in between. 'Ham' was the male camel which was used for copulation. When it had finished the number of copulations assigned for it, they would let it loose for their idols and excuse it from burdens so that nothing would be carried on it, and they called it the 'Hami.' Abu Huraira said, "I heard the Prophet (ﷺ) saying so}}
\hadithdefcmd{bukhari}{4624}{حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي يَعْقُوبَ أَبُو عَبْدِ اللَّهِ الْكَرْمَانِيُّ، حَدَّثَنَا حَسَّانُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ جَهَنَّمَ يَحْطِمُ بَعْضُهَا بَعْضًا، وَرَأَيْتُ عَمْرًا يَجُرُّ قُصْبَهُ، وَهْوَ أَوَّلُ مَنْ سَيَّبَ السَّوَائِبَ ‏"‏‏.‏\hadithno{4624}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) said, "I saw Hell and its different portions were consuming each other and saw `Amr dragging his intestines (in it), and he was the first person to establish the tradition of letting animals loose (for the idols)}}
\hadithdefcmd{bukhari}{4625}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا الْمُغِيرَةُ بْنُ النُّعْمَانِ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّكُمْ مَحْشُورُونَ إِلَى اللَّهِ حُفَاةً عُرَاةً غُرْلاً ـ ثُمَّ قَالَ ـ ‏\{‏كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ وَعْدًا عَلَيْنَا إِنَّا كُنَّا فَاعِلِينَ‏\}‏ إِلَى آخِرِ الآيَةِ ـ ثُمَّ قَالَ ـ أَلاَ وَإِنَّ أَوَّلَ الْخَلاَئِقِ يُكْسَى يَوْمَ الْقِيَامَةِ إِبْرَاهِيمُ، أَلاَ وَإِنَّهُ يُجَاءُ بِرِجَالٍ مِنْ أُمَّتِي فَيُؤْخَذُ بِهِمْ ذَاتَ الشِّمَالِ، فَأَقُولُ يَا رَبِّ أُصَيْحَابِي‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ‏.‏ فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُ ‏\{‏وَكُنْتُ عَلَيْهِمْ شَهِيدًا مَا دُمْتُ فِيهِمْ فَلَمَّا تَوَفَّيْتَنِي كُنْتَ أَنْتَ الرَّقِيبَ عَلَيْهِمْ‏\}‏ فَيُقَالُ إِنَّ هَؤُلاَءِ لَمْ يَزَالُوا مُرْتَدِّينَ عَلَى أَعْقَابِهِمْ مُنْذُ فَارَقْتَهُمْ ‏"‏‏.‏\hadithno{4625}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) delivered a sermon and said, "O people! You will be gathered before Allah barefooted, naked and not circumcised." Then (quoting Qur'an) he said:-- "As We began the first creation, We shall repeat it. A promise We have undertaken: Truly We shall do it.." (21.104) The Prophet (ﷺ) then said, "The first of the human beings to be dressed on the Day of Resurrection, will be Abraham. Lo! Some men from my followers will be brought and then (the angels) will drive them to the left side (Hell-Fire). I will say. 'O my Lord! (They are) my companions!' Then a reply will come (from the Almighty), 'You do not know what they did after you.' I will say as the pious slave (the Prophet Jesus (ﷺ)) said: And I was a witness over them while I dwelt amongst them. When You took me up, You were the Watcher over them and You are a Witness to all things.' (5.117) Then it will be said, "These people have continued to be apostates since you left them}}
\hadithdefcmd{bukhari}{4626}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الْمُغِيرَةُ بْنُ النُّعْمَانِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّكُمْ مَحْشُورُونَ، وَإِنَّ نَاسًا يُؤْخَذُ بِهِمْ ذَاتَ الشِّمَالِ، فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُ ‏\{‏وَكُنْتُ عَلَيْهِمْ شَهِيدًا مَا دُمْتُ فِيهِمْ‏\}‏ إِلَى قَوْلِهِ ‏\{‏الْعَزِيزُ الْحَكِيمُ ‏\}‏‏"‏\hadithno{4626}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "You will be gathered (on the Day of Resurrection) and some people will be driven (by the angels) to the left side (and taken to Hell) whereupon I will say as the pious slave (Jesus) said:- - "And I was a witness over them while I dwelt amongst them...the ALMIGHTY, the All Wise}}
\hadithdefcmd{bukhari}{4627}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَفَاتِحُ الْغَيْبِ خَمْسٌ إِنَّ اللَّهَ عِنْدَهُ عِلْمُ السَّاعَةِ، وَيُنَزِّلُ الْغَيْثَ، وَيَعْلَمُ مَا فِي الأَرْحَامِ، وَمَا تَدْرِي نَفْسٌ مَاذَا تَكْسِبُ غَدًا، وَمَا تَدْرِي نَفْسٌ بِأَىِّ أَرْضٍ تَمُوتُ، إِنَّ اللَّهَ عَلِيمٌ خَبِيرٌ ‏"‏‏.‏\hadithno{4627}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "The keys of the Unseen are five: Verily with Allah (Alone) is the knowledge of the Hour He sends down the rain and knows what is in the wombs. No soul knows what it will earn tomorrow, and no soul knows in what land it will die. Verily, Allah is All-Knower, All-Aware}}
\hadithdefcmd{bukhari}{4628}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏قُلْ هُوَ الْقَادِرُ عَلَى أَنْ يَبْعَثَ عَلَيْكُمْ عَذَابًا مِنْ فَوْقِكُمْ‏\}‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعُوذُ بِوَجْهِكَ ‏"‏‏.‏ قَالَ ‏\{‏أَوْ مِنْ تَحْتِ أَرْجُلِكُمْ‏\}‏ قَالَ ‏"‏ أَعُوذُ بِوَجْهِكَ‏"‏ ‏\{‏أَوْ يَلْبِسَكُمْ شِيَعًا وَيُذِيقَ بَعْضَكُمْ بَأْسَ بَعْضٍ‏\}‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا أَهْوَنُ ‏"‏‏.‏ أَوْ ‏"‏ هَذَا أَيْسَرُ ‏"‏‏.‏\hadithno{4628}\hadithtrans{Narrated Jabir:When this Verse was revealed: "Say: He has power to send torment on you from above." (6.65) Allah's Messenger (ﷺ) said, "O Allah! I seek refuge with Your Face (from this punishment)." And when the verse: "or send torment from below your feet," (was revealed), Allah's Messenger (ﷺ) said, "(O Allah!) I seek refuge with Your Face (from this punishment)." (But when there was revealed): "Or confuse you in party strife and make you to taste the violence of one another." (6.65) Allah's Messenger (ﷺ) said, "This is lighter (or, this is easier)}}
\hadithdefcmd{bukhari}{4629}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ ‏\{‏وَلَمْ يَلْبِسُوا إِيمَانَهُمْ بِظُلْمٍ‏\}‏ قَالَ أَصْحَابُهُ وَأَيُّنَا لَمْ يَظْلِمْ فَنَزَلَتْ ‏\{‏إِنَّ الشِّرْكَ لَظُلْمٌ عَظِيمٌ‏\}‏\hadithno{4629}\hadithtrans{Narrated `Abdullah:When:"...and confuse not their belief with wrong." (6.82) was revealed, the Prophet's companions said, "Which of us has not done wrong?" Then there was revealed:-- "Verily joining others in worship with Allah is a tremendous wrong indeed}}
\hadithdefcmd{bukhari}{4630}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، قَالَ حَدَّثَنِي ابْنُ عَمِّ، نَبِيِّكُمْ يَعْنِي ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏\hadithno{4630}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Nobody has the rights to say that I am better than Jonah bin Matta}}
\hadithdefcmd{bukhari}{4631}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا سَعْدُ بْنُ إِبْرَاهِيمَ، قَالَ سَمِعْتُ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏\hadithno{4631}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Nobody has the right to say that I am better than Jonah bin Matta}}
\hadithdefcmd{bukhari}{4632}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي سُلَيْمَانُ الأَحْوَلُ، أَنَّ مُجَاهِدًا، أَخْبَرَهُ أَنَّهُ، سَأَلَ ابْنَ عَبَّاسٍ أَفِي ‏"‏ ص ‏"‏ سَجْدَةٌ فَقَالَ نَعَمْ‏.‏ ثُمَّ تَلاَ ‏\{‏وَوَهَبْنَا‏\}‏ إِلَى قَوْلِهِ ‏\{‏فَبِهُدَاهُمُ اقْتَدِهْ‏\}‏ ثُمَّ قَالَ هُوَ مِنْهُمْ‏.‏ زَادَ يَزِيدُ بْنُ هَارُونَ وَمُحَمَّدُ بْنُ عُبَيْدٍ وَسَهْلُ بْنُ يُوسُفَ عَنِ الْعَوَّامِ عَنْ مُجَاهِدٍ قُلْتُ لاِبْنِ عَبَّاسٍ فَقَالَ نَبِيُّكُمْ صلى الله عليه وسلم مِمَّنْ أُمِرَ أَنْ يَقْتَدِيَ بِهِمْ‏.‏\hadithno{4632}\hadithtrans{Narrated Mujahid:That he asked Ibn `Abbas, "Is there a prostration in Surat-al-Sa`d?" (38.24) Ibn `Abbas said, "Yes," and then recited: "We gave...So follow their guidance." (6.85,90) Then he said, "He (David ) is one of them (i.e. those prophets)." Mujahid narrated: I asked Ibn `Abbas (regarding the above Verse). He said, "Your Prophet (Muhammad) was one of those who were ordered to follow them}}
\hadithdefcmd{bukhari}{4633}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، قَالَ عَطَاءٌ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ، لَمَّا حَرَّمَ اللَّهُ عَلَيْهِمْ شُحُومَهَا جَمَلُوهُ ثُمَّ بَاعُوهُ فَأَكَلُوهَا ‏"‏‏.‏ وَقَالَ أَبُو عَاصِمٍ حَدَّثَنَا عَبْدُ الْحَمِيدِ، حَدَّثَنَا يَزِيدُ، كَتَبَ إِلَىَّ عَطَاءٌ سَمِعْتُ جَابِرًا، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{4633}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "May Allah curse the Jews! When Allah forbade them to eat the fat of animals, they melted it and sold it, and utilized its price}}
\hadithdefcmd{bukhari}{4634}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ ‏ "‏ لاَ أَحَدَ أَغْيَرُ مِنَ اللَّهِ، وَلِذَلِكَ حَرَّمَ الْفَوَاحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ، وَلاَ شَىْءَ أَحَبُّ إِلَيْهِ الْمَدْحُ مِنَ اللَّهِ، لِذَلِكَ مَدَحَ نَفْسَهُ ‏"‏‏.‏ قُلْتُ سَمِعْتَهُ مِنْ عَبْدِ اللَّهِ قَالَ نَعَمْ‏.‏ قُلْتُ وَرَفَعَهُ قَالَ نَعَمْ‏.‏\hadithno{4634}\hadithtrans{Narrated Abu Wail:`Abdullah (bin Mas`ud) said, "None has more sense of ghaira than Allah therefore - He prohibits shameful sins (illegal sexual intercourse, etc.) whether committed openly or secretly. And none loves to be praised more than Allah does, and for this reason He praises Himself." I asked Abu Wail, "Did you hear it from `Abdullah?" He said, "Yes," I said, "Did `Abdullah ascribe it to Allah's Messenger (ﷺ)?" He said, "Yes}}
\hadithdefcmd{bukhari}{4635}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عُمَارَةُ، حَدَّثَنَا أَبُو زُرْعَةَ، حَدَّثَنَا أَبُو هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا، فَإِذَا رَآهَا النَّاسُ آمَنَ مَنْ عَلَيْهَا، فَذَاكَ حِينَ لاَ يَنْفَعُ نَفْسًا إِيمَانُهَا، لَمْ تَكُنْ آمَنَتْ مِنْ قَبْلُ ‏"‏‏.‏\hadithno{4635}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established until the sun rises from the West: and when the people see it, then whoever will be living on the surface of the earth will have faith, and that is (the time) when no good will it do to a soul to believe then, if it believed not before}}
\hadithdefcmd{bukhari}{4636}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا فَإِذَا طَلَعَتْ وَرَآهَا النَّاسُ آمَنُوا أَجْمَعُونَ، وَذَلِكَ حِينَ لاَ يَنْفَعُ نَفْسًا إِيمَانُهَا ‏"‏‏.‏ ثُمَّ قَرَأَ الآيَةَ‏.‏\hadithno{4636}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The hour will not be established till the sun rises from the West; and when it rises (from the West) and the people see it, they all will believe. And that is (the time) when no good will it do to a soul to believe then." Then he recited the whole Verse}}
\hadithdefcmd{bukhari}{4637}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قُلْتُ أَنْتَ سَمِعْتَ هَذَا مِنْ عَبْدِ اللَّهِ قَالَ نَعَمْ، وَرَفَعَهُ‏.‏ قَالَ ‏ "‏ لاَ أَحَدَ أَغْيَرُ مِنَ اللَّهِ، فَلِذَلِكَ حَرَّمَ الْفَوَاحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ، وَلاَ أَحَدَ أَحَبُّ إِلَيْهِ الْمِدْحَةُ مِنَ اللَّهِ، فَلِذَلِكَ مَدَحَ نَفْسَهُ ‏"‏‏.‏\hadithno{4637}\hadithtrans{Narrated `Abdullah bin Mas`ud:Allah's Messenger (ﷺ) said, "None has more sense of ghaira than Allah, and for this He has forbidden shameful sins whether committed openly or secretly, and none loves to be praised more than Allah does, and this is why He Praises Himself}}
\hadithdefcmd{bukhari}{4638}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ جَاءَ رَجُلٌ مِنَ الْيَهُودِ إِلَى النَّبِيِّ صلى الله عليه وسلم قَدْ لُطِمَ وَجْهُهُ وَقَالَ يَا مُحَمَّدُ إِنَّ رَجُلاً مِنْ أَصْحَابِكَ مِنَ الأَنْصَارِ لَطَمَ وَجْهِي‏.‏ قَالَ ‏"‏ ادْعُوهُ ‏"‏‏.‏ فَدَعَوْهُ قَالَ ‏"‏ لِمَ لَطَمْتَ وَجْهَهُ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، إِنِّي مَرَرْتُ بِالْيَهُودِ فَسَمِعْتُهُ يَقُولُ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْبَشَرِ‏.‏ فَقُلْتُ وَعَلَى مُحَمَّدٍ وَأَخَذَتْنِي غَضْبَةٌ فَلَطَمْتُهُ‏.‏ قَالَ ‏"‏ لاَ تُخَيِّرُونِي مِنْ بَيْنِ الأَنْبِيَاءِ، فَإِنَّ النَّاسَ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ فَأَكُونُ أَوَّلَ مَنْ يُفِيقُ، فَإِذَا أَنَا بِمُوسَى آخِذٌ بِقَائِمَةٍ مِنْ قَوَائِمِ الْعَرْشِ، فَلاَ أَدْرِي أَفَاقَ قَبْلِي أَمْ جُزِيَ بِصَعْقَةِ الطُّورِ ‏"‏‏.‏\hadithno{4638}\hadithtrans{Narrated Abu Sa`id Al-Khudri:A man from the Jews, having been slapped on his face, came to the Prophet (ﷺ) and said, "O Muhammad! A man from your companions from the Ansar has slapped me on my face!" The Prophet (ﷺ) said, "Call him." When they called him, the Prophet (ﷺ) said, "Why did you slap him?" He said, "O Allah's Messenger (ﷺ)! While I was passing by the Jews, I heard him saying, 'By Him Who selected Moses above the human beings,' I said, 'Even above Muhammad?' I became furious and slapped him on the face." The Prophet (ﷺ) said, "Do not give me superiority over the other prophets, for on the Day of Resurrection the people will become unconscious and I will be the first to regain consciousness. Then I will see Moses holding one of the legs of the Throne. I will not know whether he has come to his senses before me or that the shock he had received at the Mountain, (during his worldly life) was sufficient for him}}
\hadithdefcmd{bukhari}{4639}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَمْرِو بْنِ حُرَيْثٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْكَمْأَةُ مِنَ الْمَنِّ وَمَاؤُهَا شِفَاءُ الْعَيْنِ ‏"‏‏.‏\hadithno{4639}\hadithtrans{Narrated Sa`id Ibn Zaid:The Prophet (ﷺ) said, "Al-Kam'a is like the Manna (sweet resin or gum) (in that it grows naturally without human care) and its water is a cure for the eye diseases}}
\hadithdefcmd{bukhari}{4640}{حَدَّثَنَا عَبْدُ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، وَمُوسَى بْنُ هَارُونَ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ بْنِ زَبْرٍ، قَالَ حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، قَالَ سَمِعْتُ أَبَا الدَّرْدَاءِ، يَقُولُ كَانَتْ بَيْنَ أَبِي بَكْرٍ وَعُمَرَ مُحَاوَرَةٌ، فَأَغْضَبَ أَبُو بَكْرٍ عُمَرَ، فَانْصَرَفَ عَنْهُ عُمَرُ مُغْضَبًا، فَاتَّبَعَهُ أَبُو بَكْرٍ يَسْأَلُهُ أَنْ يَسْتَغْفِرَ لَهُ، فَلَمْ يَفْعَلْ حَتَّى أَغْلَقَ بَابَهُ فِي وَجْهِهِ، فَأَقْبَلَ أَبُو بَكْرٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَبُو الدَّرْدَاءِ وَنَحْنُ عِنْدَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا صَاحِبُكُمْ هَذَا فَقَدْ غَامَرَ ‏"‏‏.‏ قَالَ وَنَدِمَ عُمَرُ عَلَى مَا كَانَ مِنْهُ فَأَقْبَلَ حَتَّى سَلَّمَ وَجَلَسَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَصَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْخَبَرَ‏.‏ قَالَ أَبُو الدَّرْدَاءِ وَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجَعَلَ أَبُو بَكْرٍ يَقُولُ وَاللَّهِ يَا رَسُولَ اللَّهِ لأَنَا كُنْتُ أَظْلَمَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ أَنْتُمْ تَارِكُو لِي صَاحِبِي هَلْ أَنْتُمْ تَارِكُو لِي صَاحِبِي إِنِّي قُلْتُ يَا أَيُّهَا النَّاسُ إِنِّي رَسُولُ اللَّهِ إِلَيْكُمْ جَمِيعًا فَقُلْتُمْ كَذَبْتَ‏.‏ وَقَالَ أَبُو بَكْرٍ صَدَقْتَ ‏ قَالَ أَبُو عَبْد اللَّهِ غَامَرَ سَبَقَ بِالْخَيْر"‏‏.‏\hadithno{4640}\hadithtrans{Narrated Abu Ad-Darda:There was a dispute between Abu Bakr and `Umar, and Abu Bakr made `Umar angry. So `Umar left angrily. Abu Bakr followed him, requesting him to ask forgiveness (of Allah) for him, but `Umar refused to do so and closed his door in Abu Bakr's face. So Abu Bakr went to Allah's Messenger (ﷺ) while we were with him. Allah's Messenger (ﷺ) said, "This friend of yours must have quarrelled (with somebody)." In the meantime `Umar repented and felt sorry for what he had done, so he came, greeted (those who were present) and sat with the Prophet (ﷺ) and related the story to him. Allah's Messenger (ﷺ) became angry and Abu Bakr started saying, "O Allah's Messenger (ﷺ)! By Allah, I was more at fault (than `Umar)." Allah's Apostle said, "Are you (people) leaving for me my companion? (Abu Bakr), Are you (people) leaving for me my companion? When I said, 'O people I am sent to you all as the Messenger of Allah,' you said, 'You tell a lie.' while Abu Bakr said, 'You have spoken the truth}}
\hadithdefcmd{bukhari}{4641}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قِيلَ لِبَنِي إِسْرَائِيلَ ‏\{‏ادْخُلُوا الْبَابَ سُجَّدًا وَقُولُوا حِطَّةٌ نَغْفِرْ لَكُمْ خَطَايَاكُمْ‏\}‏ فَبَدَّلُوا فَدَخَلُوا يَزْحَفُونَ عَلَى أَسْتَاهِهِمْ وَقَالُوا حَبَّةٌ فِي شَعَرَةٍ ‏"‏‏.‏\hadithno{4641}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "It was said to the children of Israel, 'Enter the gate in prostration and say Hittatun. We shall forgive you your faults.' (7.161) But they changed (Allah's Order) and entered, dragging themselves on their buttocks and said, 'Habbatun (a grain) in a Sha'ratin (hair)}}
\hadithdefcmd{bukhari}{4642}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ عُيَيْنَةُ بْنُ حِصْنِ بْنِ حُذَيْفَةَ فَنَزَلَ عَلَى ابْنِ أَخِيهِ الْحُرِّ بْنِ قَيْسٍ، وَكَانَ مِنَ النَّفَرِ الَّذِينَ يُدْنِيهِمْ عُمَرُ، وَكَانَ الْقُرَّاءُ أَصْحَابَ مَجَالِسِ عُمَرَ وَمُشَاوَرَتِهِ كُهُولاً كَانُوا أَوْ شُبَّانًا‏.‏ فَقَالَ عُيَيْنَةُ لاِبْنِ أَخِيهِ يَا ابْنَ أَخِي، لَكَ وَجْهٌ عِنْدَ هَذَا الأَمِيرِ فَاسْتَأْذِنْ لِي عَلَيْهِ‏.‏ قَالَ سَأَسْتَأْذِنُ لَكَ عَلَيْهِ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَاسْتَأْذَنَ الْحُرُّ لِعُيَيْنَةَ فَأَذِنَ لَهُ عُمَرُ، فَلَمَّا دَخَلَ عَلَيْهِ قَالَ هِيْ يَا ابْنَ الْخَطَّابِ، فَوَاللَّهِ مَا تُعْطِينَا الْجَزْلَ، وَلاَ تَحْكُمُ بَيْنَنَا بِالْعَدْلِ‏.‏ فَغَضِبَ عُمَرُ حَتَّى هَمَّ بِهِ، فَقَالَ لَهُ الْحُرُّ يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّ اللَّهَ تَعَالَى قَالَ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏خُذِ الْعَفْوَ وَأْمُرْ بِالْعُرْفِ وَأَعْرِضْ عَنِ الْجَاهِلِينَ‏\}‏ وَإِنَّ هَذَا مِنَ الْجَاهِلِينَ‏.‏ وَاللَّهِ مَا جَاوَزَهَا عُمَرُ حِينَ تَلاَهَا عَلَيْهِ، وَكَانَ وَقَّافًا عِنْدَ كِتَابِ اللَّهِ‏.‏\hadithno{4642}\hadithtrans{Narrated Ibn `Abbas:'Uyaina bin Hisn bin Hudhaifa came and stayed with his nephew Al-Hurr bin Qais who was one of those whom `Umar used to keep near him, as the Qurra' (learned men knowing Qur'an by heart) were the people of `Umar's meetings and his advisors whether they were old or young. 'Uyaina said to his nephew, "O son of my brother! You have an approach to this chief, so get for me the permission to see him." Al-Hurr said, "I will get the permission for you to see him." So Al-Hurr asked the permission for 'Uyaina and `Umar admitted him. When 'Uyaina entered upon him, he said, "Beware! O the son of Al-Khattab! By Allah, you neither give us sufficient provision nor judge among us with justice." Thereupon `Umar became so furious that he intended to harm him, but Al-Hurr said, "O chief of the Believers! Allah said to His Prophet: "Hold to forgiveness; command what is right; and leave (don't punish) the foolish." (7.199) and this (i.e. 'Uyaina) is one of the foolish." By Allah, `Umar did not overlook that Verse when Al-Hurr recited it before him; he observed (the orders of) Allah's Book strictly}}
\hadithdefcmd{bukhari}{4643}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، ‏\{‏خُذِ الْعَفْوَ وَأْمُرْ بِالْعُرْفِ‏\}‏ قَالَ مَا أَنْزَلَ اللَّهُ إِلاَّ فِي أَخْلاَقِ النَّاسِ‏.‏\hadithno{4643}\hadithtrans{Narrated `Abdullah bin Az-Zubair:(The Verse) "Hold to forgiveness; command what is right..." was not revealed by Allah except in connection with the character of the people}}
\hadithdefcmd{bukhari}{4644}{وَقَالَ عَبْدُ اللَّهِ بْنُ بَرَّادٍ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ أَمَرَ اللَّهُ نَبِيَّهُ صلى الله عليه وسلم أَنْ يَأْخُذَ الْعَفْوَ مِنْ أَخْلاَقِ النَّاسِ‏.‏ أَوْ كَمَا قَالَ‏.‏\hadithno{4644}\hadithtrans{Abdullah bin Az-Zubair said:Allah ordered His Prophet to forgive the people their misbehavior (towards him)}}
\hadithdefcmd{bukhari}{4645}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، أَخْبَرَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ ـ رضى الله عنهما ـ سُورَةُ الأَنْفَالِ قَالَ نَزَلَتْ فِي بَدْرٍ‏.‏ الشَّوْكَةُ الْحَدُّ ‏\{‏مُرْدَفِينَ‏\}‏ فَوْجًا بَعْدَ فَوْجٍ، رَدِفَنِي وَأَرْدَفَنِي جَاءَ بَعْدِي ‏\{‏ذُوقُوا‏\}‏ بَاشِرُوا وَجَرِّبُوا وَلَيْسَ هَذَا مِنْ ذَوْقِ الْفَمِ ‏\{‏فَيَرْكُمَهُ‏\}‏ يَجْمَعُهُ‏.‏ ‏\{‏شَرِّدْ‏\}‏ فَرِّقْ ‏\{‏وَإِنْ جَنَحُوا‏\}‏ طَلَبُوا ‏\{‏يُثْخِنَ‏\}‏ يَغْلِبَ‏.‏ وَقَالَ مُجَاهِدٌ ‏\{‏مُكَاءً‏\}‏ إِدْخَالُ أَصَابِعِهِمْ فِي أَفْوَاهِهِمْ وَ‏\{‏تَصْدِيَةً‏\}‏ الصَّفِيرُ ‏\{‏لِيُثْبِتُوكَ‏\}‏ لِيَحْبِسُوكَ‏.‏\hadithno{4645}\hadithtrans{Narrated Sa`id bin Jubair:I asked Ibn `Abbas regarding Surat-al-Anfal. He said, "It was revealed in connection with the Battle of Badr}}
\hadithdefcmd{bukhari}{4646}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا وَرْقَاءُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏إِنَّ شَرَّ الدَّوَابِّ عِنْدَ اللَّهِ الصُّمُّ الْبُكْمُ الَّذِينَ لاَ يَعْقِلُونَ‏\}‏ قَالَ هُمْ نَفَرٌ مِنْ بَنِي عَبْدِ الدَّارِ‏.‏\hadithno{4646}\hadithtrans{Narrated Ibn `Abbas:Regarding the Verse: "Verily! The worst of beasts in the Sight of Allah are the deaf and the dumb---- those who understand not." (8.22) (The people referred to here) were some persons from the tribe of Bani `Abd-Ad-Dar}}
\hadithdefcmd{bukhari}{4647}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا رَوْحٌ، حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، سَمِعْتُ حَفْصَ بْنَ عَاصِمٍ، يُحَدِّثُ عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى ـ رضى الله عنه ـ قَالَ كُنْتُ أُصَلِّي فَمَرَّ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَعَانِي فَلَمْ آتِهِ حَتَّى صَلَّيْتُ، ثُمَّ أَتَيْتُهُ فَقَالَ ‏"‏ مَا مَنَعَكَ أَنْ تَأْتِيَ أَلَمْ يَقُلِ اللَّهُ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا اسْتَجِيبُوا لِلَّهِ وَلِلرَّسُولِ إِذَا دَعَاكُمْ‏\}‏ ثُمَّ قَالَ لأُعَلِّمَنَّكَ أَعْظَمَ سُورَةٍ فِي الْقُرْآنِ قَبْلَ أَنْ أَخْرُجَ ‏"‏‏.‏ فَذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيَخْرُجَ فَذَكَرْتُ لَهُ‏.‏ وَقَالَ مُعَاذٌ حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبٍ، سَمِعَ حَفْصًا، سَمِعَ أَبَا سَعِيدٍ، رَجُلاً مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا، وَقَالَ هِيَ ‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ السَّبْعُ الْمَثَانِي‏.‏\hadithno{4647}\hadithtrans{Narrated Abu Sa`id bin Al-Mu'alla:While I was praying, Allah's Messenger (ﷺ) passed me and called me, but I did not go to him until I had finished the prayer. Then I went to him, and he said, "What prevented you from coming to me? Didn't Allah say:-- "O you who believe! Answer the call of Allah (by obeying Him) and His Apostle when He calls you?" He then said, "I will inform you of the greatest Sura in the Qur'an before I leave (the mosque)." When Allah's Messenger (ﷺ) got ready to leave (the mosque), I reminded him. He said, "It is: 'Praise be to Allah, the Lord of the worlds.' (i.e. Surat-al-Fatiha) As-sab'a Al-Mathani (the seven repeatedly recited Verses)}}
\hadithdefcmd{bukhari}{4648}{حَدَّثَنِي أَحْمَدُ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْحَمِيدِ ـ هُوَ ابْنُ كُرْدِيدٍ صَاحِبُ الزِّيَادِيِّ ـ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ أَبُو جَهْلٍ ‏\{‏اللَّهُمَّ إِنْ كَانَ هَذَا هُوَ الْحَقَّ مِنْ عِنْدِكَ فَأَمْطِرْ عَلَيْنَا حِجَارَةً مِنَ السَّمَاءِ أَوِ ائْتِنَا بِعَذَابٍ أَلِيمٍ‏\}‏ فَنَزَلَتْ ‏\{‏وَمَا كَانَ اللَّهُ لِيُعَذِّبَهُمْ وَأَنْتَ فِيهِمْ وَمَا كَانَ اللَّهُ مُعَذِّبَهُمْ وَهُمْ يَسْتَغْفِرُونَ * وَمَا لَهُمْ أَنْ لاَ يُعَذِّبَهُمُ اللَّهُ وَهُمْ يَصُدُّونَ عَنِ الْمَسْجِدِ الْحَرَامِ‏\}‏ الآيَةَ‏.‏\hadithno{4648}\hadithtrans{Narrated Anas bin Malik:Abu Jahl said, "O Allah! If this (Qur'an) is indeed the Truth from You, then rain down on us a shower of stones from the sky or bring on us a painful torment." So Allah revealed:-- "But Allah would not punish them while you were amongst them, nor He will punish them while they seek (Allah's) forgiveness..." (8.33) And why Allah should not punish them while they turn away (men) from Al- Masjid-al-Haram (the Sacred Mosque of Mecca)}}
\hadithdefcmd{bukhari}{4649}{حَدَّثَنَا مُحَمَّدُ بْنُ النَّضْرِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْحَمِيدِ، صَاحِبِ الزِّيَادِيِّ سَمِعَ أَنَسَ بْنَ مَالِكٍ، قَالَ قَالَ أَبُو جَهْلٍ ‏\{‏اللَّهُمَّ إِنْ كَانَ هَذَا هُوَ الْحَقَّ مِنْ عِنْدِكَ فَأَمْطِرْ عَلَيْنَا حِجَارَةً مِنَ السَّمَاءِ أَوِ ائْتِنَا بِعَذَابٍ أَلِيمٍ‏\}‏ فَنَزَلَتْ ‏\{‏وَمَا كَانَ اللَّهُ لِيُعَذِّبَهُمْ وَأَنْتَ فِيهِمْ وَمَا كَانَ اللَّهُ مُعَذِّبَهُمْ وَهُمْ يَسْتَغْفِرُونَ * وَمَا لَهُمْ أَنْ لاَ يُعَذِّبَهُمُ اللَّهُ وَهُمْ يَصُدُّونَ عَنِ الْمَسْجِدِ الْحَرَامِ‏\}‏ الآيَةَ‏.‏\hadithno{4649}\hadithtrans{Narrated Anas bin Malik:Abu Jahl said, "O Allah! If this (Qur'an) is indeed the Truth from You), then rain down on us a shower of stones from the sky or bring on us a painful punishment." So there was revealed:-- 'But Allah would not punish them while you (Muhammad) were amongst them, nor will He punish them while they seek (Allah's) Forgiveness. And why Allah should not punish them while they stop (men) from Al-Masjid-al-Haram}}
\hadithdefcmd{bukhari}{4650}{حَدَّثَنَا الْحَسَنُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَحْيَى، حَدَّثَنَا حَيْوَةُ، عَنْ بَكْرِ بْنِ عَمْرٍو، عَنْ بُكَيْرٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَجُلاً، جَاءَهُ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ، أَلاَ تَسْمَعُ مَا ذَكَرَ اللَّهُ فِي كِتَابِهِ ‏\{‏وَإِنْ طَائِفَتَانِ مِنَ الْمُؤْمِنِينَ اقْتَتَلُوا‏\}‏ إِلَى آخِرِ الآيَةِ، فَمَا يَمْنَعُكَ أَنْ لاَ تُقَاتِلَ كَمَا ذَكَرَ اللَّهُ فِي كِتَابِهِ‏.‏ فَقَالَ يَا ابْنَ أَخِي أَغْتَرُّ بِهَذِهِ الآيَةِ وَلاَ أُقَاتِلُ أَحَبُّ إِلَىَّ مِنْ أَنْ أَغْتَرَّ بِهَذِهِ الآيَةِ الَّتِي يَقُولُ اللَّهُ تَعَالَى ‏\{‏وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا‏\}‏ إِلَى آخِرِهَا‏.‏ قَالَ فَإِنَّ اللَّهَ يَقُولُ ‏\{‏وَقَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ‏\}‏‏.‏ قَالَ ابْنُ عُمَرَ قَدْ فَعَلْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ كَانَ الإِسْلاَمُ قَلِيلاً، فَكَانَ الرَّجُلُ يُفْتَنُ فِي دِينِهِ، إِمَّا يَقْتُلُوهُ وَإِمَّا يُوثِقُوهُ، حَتَّى كَثُرَ الإِسْلاَمُ، فَلَمْ تَكُنْ فِتْنَةٌ، فَلَمَّا رَأَى أَنَّهُ لاَ يُوَافِقُهُ فِيمَا يُرِيدُ قَالَ فَمَا قَوْلُكَ فِي عَلِيٍّ وَعُثْمَانَ‏.‏ قَالَ ابْنُ عُمَرَ مَا قَوْلِي فِي عَلِيٍّ وَعُثْمَانَ أَمَّا عُثْمَانُ فَكَانَ اللَّهُ قَدْ عَفَا عَنْهُ، فَكَرِهْتُمْ أَنْ يَعْفُوَ عَنْهُ، وَأَمَّا عَلِيٌّ فَابْنُ عَمِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَخَتَنُهُ‏.‏ وَأَشَارَ بِيَدِهِ وَهَذِهِ ابْنَتُهُ أَوْ بِنْتُهُ حَيْثُ تَرَوْنَ‏.‏\hadithno{4650}\hadithtrans{Narrated Ibn `Umar:That a man came to him (while two groups of Muslims were fighting) and said, "O Abu `Abdur Rahman! Don't you hear what Allah has mentioned in His Book: 'And if two groups of believers fight against each other...' (49.9) So what prevents you from fighting as Allah has mentioned in His Book?"' Ibn `Umar said, "O son of my brother! I would rather be blamed for not fighting because of this Verse than to be blamed because of another Verse where Allah says: 'And whoever kills a believer intentionally..." (4.93) Then that man said, "Allah says:-- 'And fight them until there is no more afflictions (worshipping other besides Allah) and the religion (i.e. worship) will be all for Allah (Alone)" (8.39) Ibn `Umar said, "We did this during the lifetime of Allah's Messenger (ﷺ) when the number of Muslims was small, and a man was put to trial because of his religion, the pagans would either kill or chain him; but when the Muslims increased (and Islam spread), there was no persecution." When that man saw that Ibn `Umar did not agree to his proposal, he said, "What is your opinion regarding `Ali and `Uthman?" Ibn `Umar said, "What is my opinion regarding `Ali and `Uthman? As for `Uthman, Allah forgave him and you disliked to forgive him, and `Ali is the cousin and son-in-law of Allah's Messenger (ﷺ) ." Then he pointed out with his hand and said, "And that is his daughter's (house) which you can see}}
\hadithdefcmd{bukhari}{4651}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا بَيَانٌ، أَنَّ وَبَرَةَ، حَدَّثَهُ قَالَ حَدَّثَنِي سَعِيدُ بْنُ جُبَيْرٍ، قَالَ خَرَجَ عَلَيْنَا أَوْ إِلَيْنَا ابْنُ عُمَرَ، فَقَالَ رَجُلٌ كَيْفَ تَرَى فِي قِتَالِ الْفِتْنَةِ‏.‏ فَقَالَ وَهَلْ تَدْرِي مَا الْفِتْنَةُ كَانَ مُحَمَّدٌ صلى الله عليه وسلم يُقَاتِلُ الْمُشْرِكِينَ، وَكَانَ الدُّخُولُ عَلَيْهِمْ فِتْنَةً، وَلَيْسَ كَقِتَالِكُمْ عَلَى الْمُلْكِ‏.‏\hadithno{4651}\hadithtrans{Narrated Sa`id bin Jubair:Ibn `Umar came to us and a man said (to him), "What do you think about 'Qit-alal-Fitnah' (fighting caused by afflictions)." Ibn `Umar said (to him), "And do you understand what an affliction is? Muhammad used to fight against the pagans, and his fighting with them was an affliction, (and his fighting was) not like your fighting which is carried on for the sake of ruling}}
\hadithdefcmd{bukhari}{4652}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ لَمَّا نَزَلَتْ ‏\{‏إِنْ يَكُنْ مِنْكُمْ عِشْرُونَ صَابِرُونَ يَغْلِبُوا مِائَتَيْنِ‏\}‏ فَكُتِبَ عَلَيْهِمْ أَنْ لاَ يَفِرَّ وَاحِدٌ مِنْ عَشَرَةٍ ـ فَقَالَ سُفْيَانُ غَيْرَ مَرَّةٍ أَنْ لاَ يَفِرَّ عِشْرُونَ مِنْ مِائَتَيْنِ ـ ثُمَّ نَزَلَتِ ‏\{‏الآنَ خَفَّفَ اللَّهُ عَنْكُمُ‏\}‏ الآيَةَ، فَكَتَبَ أَنْ لاَ يَفِرَّ مِائَةٌ مِنْ مِائَتَيْنِ ـ زَادَ سُفْيَانُ مَرَّةً ـ نَزَلَتْ ‏\{‏حَرِّضِ الْمُؤْمِنِينَ عَلَى الْقِتَالِ إِنْ يَكُنْ مِنْكُمْ عِشْرُونَ صَابِرُونَ‏\}‏‏.‏ قَالَ سُفْيَانُ وَقَالَ ابْنُ شُبْرُمَةَ وَأُرَى الأَمْرَ بِالْمَعْرُوفِ وَالنَّهْىَ عَنِ الْمُنْكَرِ مِثْلَ هَذَا‏.‏\hadithno{4652}\hadithtrans{Narrated Ibn `Abbas:When the Verse:-- "If there are twenty steadfast amongst you, they will overcome two hundred." (8.65) was revealed, then it became obligatory for the Muslims that one (Muslim) should not flee from ten (non-Muslims). Sufyan (the sub-narrator) once said, "Twenty (Muslims) should not flee before two hundred (non Muslims)." Then there was revealed: 'But now Allah has lightened your (task)..' (8.66) So it became obligatory that one-hundred (Muslims) should not flee before two hundred (nonmuslims). (Once Sufyan said extra, "The Verse: 'Urge the believers to the fight. If there are twenty steadfast amongst you (Muslims) ..' was revealed.) Sufyan said, "Ibn Shubruma said, "I see that this order is applicable to the obligation of enjoining good and forbidding evil}}
\hadithdefcmd{bukhari}{4653}{حَدَّثَنَا يَحْيَى بْنُ عَبْدِ اللَّهِ السُّلَمِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ أَخْبَرَنِي الزُّبَيْرُ بْنُ خِرِّيتٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا نَزَلَتْ ‏\{‏إِنْ يَكُنْ مِنْكُمْ عِشْرُونَ صَابِرُونَ يَغْلِبُوا مِائَتَيْنِ‏\}‏ شَقَّ ذَلِكَ عَلَى الْمُسْلِمِينَ حِينَ فُرِضَ عَلَيْهِمْ أَنْ لاَ يَفِرَّ وَاحِدٌ مِنْ عَشَرَةٍ، فَجَاءَ التَّخْفِيفُ فَقَالَ رالآنَ خَفَّفَ اللَّهُ عَنْكُمْ وَعَلِمَ أَنَّ فِيكُمْ ضُعْفًا فَإِنْ يَكُنْ مِنْكُمْ مِائَةٌ صَابِرَةٌ يَغْلِبُوا مِائَتَيْنِ‏\}‏‏.‏ قَالَ فَلَمَّا خَفَّفَ اللَّهُ عَنْهُمْ مِنَ الْعِدَّةِ نَقَصَ مِنَ الصَّبْرِ بِقَدْرِ مَا خُفِّفَ عَنْهُمْ‏.‏\hadithno{4653}\hadithtrans{Narrated Ibn `Abbas:When the Verse:--'If there are twenty steadfast amongst you (Muslims), they will overcome two-hundred (non-Muslims).' was revealed, it became hard on the Muslims when it became compulsory that one Muslim ought not to flee (in war) before ten (non-Muslims). So (Allah) lightened the order by revealing: '(But) now Allah has lightened your (task) for He knows that there is weakness in you. So if there are of you one-hundred steadfast, they will overcome (two-hundred (non-Muslims).' (8.66) So when Allah reduced the number of enemies which Muslims should withstand, their patience and perseverance against the enemy decreased as much as their task was lightened for them}}
\hadithdefcmd{bukhari}{4654}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ يَقُولُ آخِرُ آيَةٍ نَزَلَتْ ‏\{‏يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ‏\}‏ وَآخِرُ سُورَةٍ نَزَلَتْ بَرَاءَةٌ‏.‏\hadithno{4654}\hadithtrans{Narrated Al-Bara:The last Verse that was revealed was: 'They ask you for a legal verdict: Say: Allah directs (thus) about Al-Kalalah (those who leave no descendants or ascendants as heirs).' And the last Sura which was revealed was Baraatun}}
\hadithdefcmd{bukhari}{4655}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، وَأَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَعَثَنِي أَبُو بَكْرٍ فِي تِلْكَ الْحَجَّةِ فِي مُؤَذِّنِينَ، بَعَثَهُمْ يَوْمَ النَّحْرِ يُؤَذِّنُونَ بِمِنًى أَنْ لاَ يَحُجَّ بَعْدَ الْعَامِ مُشْرِكٌ، وَلاَ يَطُوفَ بِالْبَيْتِ عُرْيَانٌ‏.‏ قَالَ حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ ثُمَّ أَرْدَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعَلِيِّ بْنِ أَبِي طَالِبٍ، وَأَمَرَهُ أَنْ يُؤَذِّنَ بِبَرَاءَةَ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَأَذَّنَ مَعَنَا عَلِيٌّ يَوْمَ النَّحْرِ فِي أَهْلِ مِنًى بِبَرَاءَةَ، وَأَنْ لاَ يَحُجَّ بَعْدَ الْعَامِ مُشْرِكٌ، وَلاَ يَطُوفَ بِالْبَيْتِ عُرْيَانٌ‏.‏\hadithno{4655}\hadithtrans{Narrated Humaid bin `Abdur-Rahman:Abu Huraira said, "During that Hajj (in which Abu Bakr was the chief of the pilgrims) Abu Bakr sent me along with announcers on the Day of Nahr ( 10th of Dhul-Hijja) in Mina to announce: "No pagans shall perform, Hajj after this year, and none shall perform the Tawaf around the Ka`ba in a naked state." Humaid bin `Abdur Rahman added: Then Allah's Messenger (ﷺ) sent `Ali bin Abi Talib (after Abu Bakr) and ordered him to recite aloud in public Surat Bara'a. Abu Huraira added, "So `Ali, along with us, recited Bara'a (loudly) before the people at Mina on the Day of Nahr and announced; "No pagan shall perform Hajj after this year and none shall perform the Tawaf around the Ka`ba in a naked state}}
\hadithdefcmd{bukhari}{4656}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي عُقَيْلٌ، قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ بَعَثَنِي أَبُو بَكْرٍ ـ رضى الله عنه ـ فِي تِلْكَ الْحَجَّةِ فِي الْمُؤَذِّنِينَ، بَعَثَهُمْ يَوْمَ النَّحْرِ يُؤَذِّنُونَ بِمِنًى أَنْ لاَ يَحُجَّ بَعْدَ الْعَامِ مُشْرِكٌ، وَلاَ يَطُوفَ بِالْبَيْتِ عُرْيَانٌ‏.‏ قَالَ حُمَيْدٌ ثُمَّ أَرْدَفَ النَّبِيُّ صلى الله عليه وسلم بِعَلِيِّ بْنِ أَبِي طَالِبٍ، فَأَمَرَهُ أَنْ يُؤَذِّنَ بِبَرَاءَةَ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَأَذَّنَ مَعَنَا عَلِيٌّ فِي أَهْلِ مِنًى يَوْمَ النَّحْرِ بِبَرَاءَةَ، وَأَنْ لاَ يَحُجَّ بَعْدَ الْعَامِ مُشْرِكٌ، وَلاَ يَطُوفَ بِالْبَيْتِ عُرْيَانٌ‏.‏\hadithno{4656}\hadithtrans{Narrated Humaid bin `Abdur Rahman:Abu Huraira said, "Abu Bakr sent me in that Hajj in which he was the chief of the pilgrims along with the announcers whom he sent on the Day of Nahr to announce at Mina: "No pagan shall perform Hajj after this year, and none shall perform the Tawaf around the Ka`ba in a naked state." Humaid added: That the Prophet (ﷺ) sent `Ali bin Abi Talib (after Abu Bakr) and ordered him to recite aloud in public Surat-Baraa. Abu Huraira added, "So `Ali, along with us, recited Bara'a (loudly) before the people at Mina on the Day of Nahr and announced "No pagan shall perform Hajj after this year and none shall perform the Tawaf around the Ka`ba in a naked state}}
\hadithdefcmd{bukhari}{4657}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ أَخْبَرَهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ بَعَثَهُ فِي الْحَجَّةِ الَّتِي أَمَّرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَيْهَا قَبْلَ حَجَّةِ الْوَدَاعِ فِي رَهْطٍ يُؤَذِّنُ فِي النَّاسِ أَنْ لاَ يَحُجَّنَّ بَعْدَ الْعَامِ مُشْرِكٌ وَلاَ يَطُوفَ بِالْبَيْتِ عُرْيَانٌ‏.‏ فَكَانَ حُمَيْدٌ يَقُولُ يَوْمُ النَّحْرِ يَوْمُ الْحَجِّ الأَكْبَرِ‏.‏ مِنْ أَجْلِ حَدِيثِ أَبِي هُرَيْرَةَ‏.‏\hadithno{4657}\hadithtrans{Narrated Humaid bin `Abdur-Rahman:Abu Huraira said that Abu Bakr sent him during the Hajj in which Abu Bakr was made the chief of the pilgrims by Allah's Messenger (ﷺ) before (the year of) Hajjat al-Wada` in a group (of announcers) to announce before the people; 'No pagan shall perform the Hajj after this year, and none shall perform the Tawaf around the Ka`ba in a naked state. Humaid used to say The Day of Nahr is the day of Al- Hajj Al-Akbar (the Greatest Day) because of the narration of Abu Huraira}}
\hadithdefcmd{bukhari}{4658}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا زَيْدُ بْنُ وَهْبٍ، قَالَ كُنَّا عِنْدَ حُذَيْفَةَ فَقَالَ مَا بَقِيَ مِنْ أَصْحَابِ هَذِهِ الآيَةِ إِلاَّ ثَلاَثَةٌ، وَلاَ مِنَ الْمُنَافِقِينَ إِلاَّ أَرْبَعَةٌ‏.‏ فَقَالَ أَعْرَابِيٌّ إِنَّكُمْ أَصْحَابَ مُحَمَّدٍ صلى الله عليه وسلم تُخْبِرُونَا فَلاَ نَدْرِي فَمَا بَالُ هَؤُلاَءِ الَّذِينَ يَبْقُرُونَ بُيُوتَنَا وَيَسْرِقُونَ أَعْلاَقَنَا‏.‏ قَالَ أُولَئِكَ الْفُسَّاقُ، أَجَلْ لَمْ يَبْقَ مِنْهُمْ إِلاَّ أَرْبَعَةٌ‏.‏ أَحَدُهُمْ شَيْخٌ كَبِيرٌ لَوْ شَرِبَ الْمَاءَ الْبَارِدَ لَمَا وَجَدَ بَرْدَهُ‏.‏\hadithno{4658}\hadithtrans{Narrated Zaid bin Wahb:We were with Hudhaifa and he said, "None remains of the people described by this Verse (9.12), except three, and of the hypocrites except four." A bedouin said, "You the companions of Muhammad! Tell us (things) and we do not know that about those who break open our houses and steal our precious things? ' He (Hudhaifa) replied, "Those are Al Fussaq (rebellious wrongdoers) (not disbelievers or hypocrites). Really, none remains of them (hypocrite) but four, one of whom is a very old man who, if he drinks water, does not feel its coldness}}
\hadithdefcmd{bukhari}{4659}{حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ عَبْدَ الرَّحْمَنِ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَكُونُ كَنْزُ أَحَدِكُمْ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ ‏"‏‏.‏\hadithno{4659}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Kanz (money, the Zakat of which is not paid) of anyone of you will appear in the form of bald-headed poisonous male snake on the Day of Resurrection}}
\hadithdefcmd{bukhari}{4660}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ حُصَيْنٍ، عَنْ زَيْدِ بْنِ وَهْبٍ، قَالَ مَرَرْتُ عَلَى أَبِي ذَرٍّ بِالرَّبَذَةِ فَقُلْتُ مَا أَنْزَلَكَ بِهَذِهِ الأَرْضِ قَالَ كُنَّا بِالشَّأْمِ فَقَرَأْتُ ‏\{‏وَالَّذِينَ يَكْنِزُونَ الذَّهَبَ وَالْفِضَّةَ وَلاَ يُنْفِقُونَهَا فِي سَبِيلِ اللَّهِ فَبَشِّرْهُمْ بِعَذَابٍ أَلِيمٍ‏\}‏ قَالَ مُعَاوِيَةُ مَا هَذِهِ فِينَا، مَا هَذِهِ إِلاَّ فِي أَهْلِ الْكِتَابِ‏.‏ قَالَ قُلْتُ إِنَّهَا لَفِينَا وَفِيهِمْ‏.‏\hadithno{4660}\hadithtrans{Narrated Zaid bin Wahb:I passed by (visited ) Abu Dhar at Ar-Rabadha and said to him, "What has brought you to this land?" He said, "We were at Sham and I recited the Verse: "They who hoard up gold and silver and spend them not in the way of Allah; announce to them a painful torment, " (9.34) where upon Muawiya said, 'This Verse is not for us, but for the people of the Scripture.' Then I said, 'But it is both for us (Muslims) and for them}}
\hadithdefcmd{bukhari}{4661}{وَقَالَ أَحْمَدُ بْنُ شَبِيبِ بْنِ سَعِيدٍ حَدَّثَنَا أَبِي، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ خَالِدِ بْنِ أَسْلَمَ، قَالَ خَرَجْنَا مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ فَقَالَ هَذَا قَبْلَ أَنْ تُنْزَلَ، الزَّكَاةُ، فَلَمَّا أُنْزِلَتْ جَعَلَهَا اللَّهُ طُهْرًا لِلأَمْوَالِ‏.‏\hadithno{4661}\hadithtrans{Narrated Khãlid bin Aslam:We went out with 'Abdullãh bin 'Umar and he said, "This (Verse) was revealed before the prescription of Zakat, and when Zakãt was prescribed, Allah made it a means of purifying one's wealth}}
\hadithdefcmd{bukhari}{4662}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الزَّمَانَ قَدِ اسْتَدَارَ كَهَيْئَتِهِ يَوْمَ خَلَقَ اللَّهُ السَّمَوَاتِ وَالأَرْضَ، السَّنَةُ اثْنَا عَشَرَ شَهْرًا مِنْهَا، أَرْبَعَةٌ حُرُمٌ، ثَلاَثٌ مُتَوَالِيَاتٌ، ذُو الْقَعْدَةِ وَذُو الْحِجَّةِ وَالْمُحَرَّمُ وَرَجَبُ مُضَرَ الَّذِي بَيْنَ جُمَادَى وَشَعْبَانَ ‏"‏‏.‏\hadithno{4662}\hadithtrans{Narrated Abu Bakr:The Prophet (ﷺ) said, "Time has come back to its original state which it had when Allah created the Heavens and the Earth; the year is twelve months, four of which are sacred. Three of them are in succession; Dhul-Qa'da, Dhul-Hijja and Al-Muharram, and (the fourth being) Rajab Mudar (named after the tribe of Mudar as they used to respect this month) which stands between Jumad (ath-thani) and Sha'ban}}
\hadithdefcmd{bukhari}{4663}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا ثَابِتٌ، حَدَّثَنَا أَنَسٌ، قَالَ حَدَّثَنِي أَبُو بَكْرٍ ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الْغَارِ، فَرَأَيْتُ آثَارَ الْمُشْرِكِينَ قُلْتُ يَا رَسُولَ اللَّهِ، لَوْ أَنَّ أَحَدَهُمْ رَفَعَ قَدَمَهُ رَآنَا‏.‏ قَالَ ‏ "‏ مَا ظَنُّكَ بِاثْنَيْنِ اللَّهُ ثَالِثُهُمَا ‏"‏‏.‏\hadithno{4663}\hadithtrans{Narrated Abu Bakr:I was in the company of the Prophet (ﷺ) in the cave, and on seeing the traces of the pagans, I said, "O Allah's Messenger (ﷺ) If one of them (pagans) should lift up his foot, he will see us." He said, "What do you think of two, the third of whom is Allah?}}
\hadithdefcmd{bukhari}{4664}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ قَالَ حِينَ وَقَعَ بَيْنَهُ وَبَيْنَ ابْنِ الزُّبَيْرِ قُلْتُ أَبُوهُ الزُّبَيْرُ، وَأُمُّهُ أَسْمَاءُ، وَخَالَتُهُ عَائِشَةُ، وَجَدُّهُ أَبُو بَكْرٍ، وَجَدَّتُهُ صَفِيَّةُ‏.‏ فَقُلْتُ لِسُفْيَانَ إِسْنَادُهُ‏.‏ فَقَالَ حَدَّثَنَا، فَشَغَلَهُ إِنْسَانٌ وَلَمْ يَقُلِ ابْنُ جُرَيْجٍ‏.‏\hadithno{4664}\hadithtrans{Narrated Ibn Abi Mulaika:When there happened the disagreement between Ibn Az-Zubair and Ibn `Abbas, I said (to the latter), "(Why don't you take the oath of allegiance to him as) his father is Az-Zubair, and his mother is Asma,' and his aunt is `Aisha, and his maternal grandfather is Abu Bakr, and his grandmother is Safiya?}}
\hadithdefcmd{bukhari}{4665}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ قَالَ ابْنُ أَبِي مُلَيْكَةَ وَكَانَ بَيْنَهُمَا شَىْءٌ فَغَدَوْتُ عَلَى ابْنِ عَبَّاسٍ فَقُلْتُ أَتُرِيدُ أَنْ تُقَاتِلَ ابْنَ الزُّبَيْرِ، فَتُحِلُّ حَرَمَ اللَّهِ‏.‏ فَقَالَ مَعَاذَ اللَّهِ، إِنَّ اللَّهَ كَتَبَ ابْنَ الزُّبَيْرِ وَبَنِي أُمَيَّةَ مُحِلِّينَ، وَإِنِّي وَاللَّهِ لاَ أُحِلُّهُ أَبَدًا‏.‏ قَالَ قَالَ النَّاسُ بَايِعْ لاِبْنِ الزُّبَيْرِ‏.‏ فَقُلْتُ وَأَيْنَ بِهَذَا الأَمْرِ عَنْهُ أَمَّا أَبُوهُ فَحَوَارِيُّ النَّبِيِّ صلى الله عليه وسلم، يُرِيدُ الزُّبَيْرَ، وَأَمَّا جَدُّهُ فَصَاحِبُ الْغَارِ، يُرِيدُ أَبَا بَكْرٍ، وَأُمُّهُ فَذَاتُ النِّطَاقِ، يُرِيدُ أَسْمَاءَ، وَأَمَّا خَالَتُهُ فَأُمُّ الْمُؤْمِنِينَ، يُرِيدُ عَائِشَةَ، وَأَمَّا عَمَّتُهُ فَزَوْجُ النَّبِيِّ صلى الله عليه وسلم، يُرِيدُ خَدِيجَةَ، وَأَمَّا عَمَّةُ النَّبِيِّ صلى الله عليه وسلم فَجَدَّتُهُ، يُرِيدُ صَفِيَّةَ، ثُمَّ عَفِيفٌ فِي الإِسْلاَمِ، قَارِئٌ لِلْقُرْآنِ‏.‏ وَاللَّهِ إِنْ وَصَلُونِي وَصَلُونِي مِنْ قَرِيبٍ، وَإِنْ رَبُّونِي رَبَّنِي أَكْفَاءٌ كِرَامٌ، فَآثَرَ التُّوَيْتَاتِ وَالأُسَامَاتِ وَالْحُمَيْدَاتِ، يُرِيدُ أَبْطُنًا مِنْ بَنِي أَسَدٍ بَنِي تُوَيْتٍ وَبَنِي أُسَامَةَ وَبَنِي أَسَدٍ، إِنَّ ابْنَ أَبِي الْعَاصِ بَرَزَ يَمْشِي الْقُدَمِيَّةَ، يَعْنِي عَبْدَ الْمَلِكِ بْنَ مَرْوَانَ، وَإِنَّهُ لَوَّى ذَنَبَهُ، يَعْنِي ابْنَ الزُّبَيْرِ‏.‏\hadithno{4665}\hadithtrans{Narrated Ibn Abi Mulaika:There was a disagreement between them (i.e. Ibn `Abbas and Ibn Az-Zubair) so I went to Ibn `Abbas in the morning and said (to him), "Do you want to fight against Ibn Az-Zubair and thus make lawful what Allah has made unlawful (i.e. fighting in Mecca)?" Ibn `Abbas said, "Allah forbid! Allah ordained that Ibn Az-Zubair and Bani Umaiya would permit (fighting in Mecca), but by Allah, I will never regard it as permissible." Ibn `Abbas added. "The people asked me to take the oath of allegiance to Ibn Az-Zubair. I said, 'He is really entitled to assume authority for his father, Az-Zubair was the helper of the Prophet, his (maternal) grandfather, Abu Bakr was (the Prophet's) companion in the cave, his mother, Asma' was 'Dhatun-Nitaq', his aunt, `Aisha was the mother of the Believers, his paternal aunt, Khadija was the wife of the Prophet (ﷺ) , and the paternal aunt of the Prophet (ﷺ) was his grandmother. He himself is pious and chaste in Islam, well versed in the Knowledge of the Qur'an. By Allah! (Really, I left my relatives, Bani Umaiya for his sake though) they are my close relatives, and if they should be my rulers, they are equally apt to be so and are descended from a noble family}}
\hadithdefcmd{bukhari}{4666}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُمَرَ بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، دَخَلْنَا عَلَى ابْنِ عَبَّاسٍ فَقَالَ أَلاَ تَعْجَبُونَ لاِبْنِ الزُّبَيْرِ قَامَ فِي أَمْرِهِ هَذَا فَقُلْتُ لأُحَاسِبَنَّ نَفْسِي لَهُ مَا حَاسَبْتُهَا لأَبِي بَكْرٍ وَلاَ لِعُمَرَ، وَلَهُمَا كَانَا أَوْلَى بِكُلِّ خَيْرٍ مِنْهُ، وَقُلْتُ ابْنُ عَمَّةِ النَّبِيِّ صلى الله عليه وسلم، وَابْنُ الزُّبَيْرِ، وَابْنُ أَبِي بَكْرٍ، وَابْنُ أَخِي خَدِيجَةَ، وَابْنُ أُخْتِ عَائِشَةَ فَإِذَا هُوَ يَتَعَلَّى عَنِّي وَلاَ يُرِيدُ ذَلِكَ فَقُلْتُ مَا كُنْتُ أَظُنُّ أَنِّي أَعْرِضُ هَذَا مِنْ نَفْسِي، فَيَدَعُهُ، وَمَا أُرَاهُ يُرِيدُ خَيْرًا، وَإِنْ كَانَ لاَ بُدَّ لأَنْ يَرُبَّنِي بَنُو عَمِّي أَحَبُّ إِلَىَّ مِنْ أَنْ يَرُبَّنِي غَيْرُهُمْ‏.‏\hadithno{4666}\hadithtrans{Narrated Ibn Abi Mulaika:We entered upon Ibn `Abbas and he said "Are you not astonished at Ibn Az-Zubair's assuming the caliphate?" I said (to myself), "I will support him and speak of his good traits as I did not do even for Abu Bakr and `Umar though they were more entitled to receive all good than he was." I said "He (i.e Ibn Az-Zubair) is the son of the aunt of the Prophet (ﷺ) and the son of Az-Zubair, and the grandson of Abu Bakr and the son of Khadija's brother, and the son of `Aisha's sister." Nevertheless, he considers himself to be superior to me and does not want me to be one of his friends. So I said, "I never expected that he would refuse my offer to support him, and I don't think he intends to do me any good, therefore, if my cousins should inevitably be my rulers, it will be better for me to be ruled by them than by some others}}
\hadithdefcmd{bukhari}{4667}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيد ٍ ـ رضى الله عنه ـ قَالَ بُعِثَ إِلَى النَّبِيِّ صلى الله عليه وسلم بِشَىْءٍ، فَقَسَمَهُ بَيْنَ أَرْبَعَةٍ وَقَالَ ‏"‏ أَتَأَلَّفُهُمْ ‏"‏‏.‏ فَقَالَ رَجُلٌ مَا عَدَلْتَ‏.‏ فَقَالَ ‏"‏ يَخْرُجُ مِنْ ضِئْضِئِ هَذَا قَوْمٌ يَمْرُقُونَ مِنَ الدِّينِ ‏"‏‏.‏\hadithno{4667}\hadithtrans{Narrated Abu Sa`id:Something was sent to the Prophet (ﷺ) and he distributed it amongst four (men) and said, "I want to attract their hearts,(to Islam thereby)," A man said (to the Prophet (ﷺ) ), "You have not done justice." Thereupon the Prophet (ﷺ) said, "There will emerge from the offspring of this (man) some people who will renounce the religion}}
\hadithdefcmd{bukhari}{4668}{حَدَّثَنِي بِشْرُ بْنُ خَالِدٍ أَبُو مُحَمَّدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ لَمَّا أُمِرْنَا بِالصَّدَقَةِ كُنَّا نَتَحَامَلُ فَجَاءَ أَبُو عَقِيلٍ بِنِصْفِ صَاعٍ، وَجَاءَ إِنْسَانٌ بِأَكْثَرَ مِنْهُ، فَقَالَ الْمُنَافِقُونَ إِنَّ اللَّهَ لَغَنِيٌّ عَنْ صَدَقَةِ هَذَا، وَمَا فَعَلَ هَذَا الآخَرُ إِلاَّ رِئَاءً‏.‏ فَنَزَلَتْ ‏\{‏الَّذِينَ يَلْمِزُونَ الْمُطَّوِّعِينَ مِنَ الْمُؤْمِنِينَ فِي الصَّدَقَاتِ وَالَّذِينَ لاَ يَجِدُونَ إِلاَّ جُهْدَهُمْ‏\}‏ الآيَةَ‏.‏\hadithno{4668}\hadithtrans{Narrated Abu Mas`ud:When we were ordered to give alms, we began to work as porters (to earn something we could give in charity). Abu `Aqil came with one half of a Sa` (special measure for food grains) and another person brought more than he did. So the hypocrites said, "Allah is not in need of the alms of this (i.e. Abu `Aqil); and this other person did not give alms but for showing off." Then Allah revealed:-- 'Those who criticize such of the Believers who give charity voluntarily and those who could not find to give in charity except what is available to them}}
\hadithdefcmd{bukhari}{4669}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ قُلْتُ لأَبِي أُسَامَةَ أَحَدَّثَكُمْ زَائِدَةُ عَنْ سُلَيْمَانَ عَنْ شَقِيقٍ عَنْ أَب��ي مَسْعُودٍ الأَنْصَارِيِّ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِالصَّدَقَةِ، فَيَحْتَالُ أَحَدُنَا حَتَّى يَجِيءَ بِالْمُدِّ، وَإِنَّ لأَحَدِهِمِ الْيَوْمَ مِائَةَ أَلْفٍ‏.‏ كَأَنَّهُ يُعَرِّضُ بِنَفْسِهِ‏.‏\hadithno{4669}\hadithtrans{Narrated Shaqiq:Abu Mas`ud Al-Ansari said, "Allah's Messenger (ﷺ), used to order us to give alms. So one of us would exert himself to earn one Mud (special measure of wheat or dates, etc.,) to give in charity; while today one of us may have one hundred thousand." Shaqiq said: As if Abu Masud referred to himself}}
\hadithdefcmd{bukhari}{4670}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ لَمَّا تُوُفِّيَ عَبْدُ اللَّهِ جَاءَ ابْنُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ أَنْ يُعْطِيَهُ قَمِيصَهُ يُكَفِّنُ فِيهِ أَبَاهُ فَأَعْطَاهُ، ثُمَّ سَأَلَهُ أَنْ يُصَلِّيَ عَلَيْهِ، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ فَقَامَ عُمَرُ فَأَخَذَ بِثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ تُصَلِّي عَلَيْهِ وَقَدْ نَهَاكَ رَبُّكَ أَنْ تُصَلِّيَ عَلَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا خَيَّرَنِي اللَّهُ فَقَالَ ‏\{‏اسْتَغْفِرْ لَهُمْ أَوْ لاَ تَسْتَغْفِرْ لَهُمْ إِنْ تَسْتَغْفِرْ لَهُمْ سَبْعِينَ مَرَّةً‏\}‏ وَسَأَزِيدُهُ عَلَى السَّبْعِينَ ‏"‏‏.‏ قَالَ إِنَّهُ مُنَافِقٌ‏.‏ قَالَ فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ ‏\{‏وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا وَلاَ تَقُمْ عَلَى قَبْرِهِ‏\}‏‏.‏\hadithno{4670}\hadithtrans{Narrated Ibn `Abbas:When `Abdullah bin 'Ubai died, his son `Abdullah bin `Abdullah came to Allah's Messenger (ﷺ) and asked him to give him his shirt in order to shroud his father in it. He gave it to him and then `Abdullah asked the Prophet (ﷺ) to offer the funeral prayer for him (his father). Allah's Messenger (ﷺ) got up to offer the funeral prayer for him, but `Umar got up too and got hold of the garment of Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ) Will you offer the funeral prayer for him though your Lord has forbidden you to offer the prayer for him" Allah's Messenger (ﷺ) said, "But Allah has given me the choice by saying: '(Whether you) ask forgiveness for them, or do not ask forgiveness for them; even if you ask forgiveness for them seventy times..' (9.80) so I will ask more than seventy times." `Umar said, "But he (`Abdullah bin 'Ubai) is a hypocrite!" However, Allah's Messenger (ﷺ) did offer the funeral prayer for him whereupon Allah revealed: 'And never (O Muhammad) pray for anyone of them that dies, nor stand at his grave}}
\hadithdefcmd{bukhari}{4671}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ،‏.‏ وَقَالَ غَيْرُهُ حَدَّثَنِي اللَّيْثُ، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ أَنَّهُ قَالَ لَمَّا مَاتَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ دُعِيَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ عَلَيْهِ فَلَمَّا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَثَبْتُ إِلَيْهِ، فَقُلْتُ يَا رَسُولَ اللَّهِ، أَتُصَلِّي عَلَى ابْنِ أُبَىٍّ وَقَدْ قَالَ يَوْمَ كَذَا كَذَا وَكَذَا قَالَ أُعَدِّدُ عَلَيْهِ قَوْلَهُ، فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ أَخِّرْ عَنِّي يَا عُمَرُ ‏"‏‏.‏ فَلَمَّا أَكْثَرْتُ عَلَيْهِ قَالَ ‏"‏ إِنِّي خُيِّرْتُ فَاخْتَرْتُ، لَوْ أَعْلَمُ أَنِّي إِنْ زِدْتُ عَلَى السَّبْعِينَ يُغْفَرْ لَهُ لَزِدْتُ عَلَيْهَا ‏"‏‏.‏ قَالَ فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ انْصَرَفَ فَلَمْ يَمْكُثْ إِلاَّ يَسِيرًا حَتَّى نَزَلَتِ الآيَتَانِ مِنْ بَرَاءَةَ ‏\{‏وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا‏\}‏ إِلَى قَوْلِهِ ‏\{‏وَهُمْ فَاسِقُونَ‏\}‏ قَالَ فَعَجِبْتُ بَعْدُ مِنْ جُرْأَتِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَاللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏\hadithno{4671}\hadithtrans{Narrated `Umar bin Al-Khattab:When `Abdullah bin Ubai bin Salul died, Allah's Messenger (ﷺ) was called in order to offer the funeral prayer for him. When Allah's Messenger (ﷺ) got up (to offer the prayer) I jumped towards him and said, "O Allah's Messenger (ﷺ)! Do you offer the prayer for Ibn Ubai although he said so-and-so on such-and-such-a day?" I went on mentioning his sayings. Allah's Messenger (ﷺ) smiled and said, "Keep away from me, O `Umar!" But when I spoke too much to him, he said, "I have been given the choice, and I have chosen (this) ; and if I knew that if I asked forgiveness for him more than seventy times, he would be forgiven, I would ask it for more times than that." So Allah's Messenger (ﷺ) offered the funeral prayer for him and then left, but he did not stay long before the two Verses of Surat-Bara'a were revealed, i.e.:-- 'And never (O Muhammad) pray for anyone of them that dies.... and died in a state of rebellion.' (9.84) Later I was astonished at my daring to speak like that to Allah's Messenger (ﷺ) and Allah and His Apostle know best}}
\hadithdefcmd{bukhari}{4672}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ قَالَ لَمَّا تُوُفِّيَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ جَاءَ ابْنُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَعْطَاهُ قَمِيصَهُ وَأَمَرَهُ أَنْ يُكَفِّنَهُ فِيهِ ثُمَّ قَامَ يُصَلِّي عَلَيْهِ، فَأَخَذَ عُمَرُ بْنُ الْخَطَّابِ بِثَوْبِهِ فَقَالَ تُصَلِّي عَلَيْهِ وَهْوَ مُنَافِقٌ وَقَدْ نَهَاكَ اللَّهُ أَنْ تَسْتَغْفِرَ لَهُمْ‏.‏ قَالَ ‏"‏ إِنَّمَا خَيَّرَنِي اللَّهُ أَوْ أَخْبَرَنِي فَقَالَ ‏\{‏اسْتَغْفِرْ لَهُمْ أَوْ لاَ تَسْتَغْفِرْ لَهُمْ إِنْ تَسْتَغْفِرْ لَهُمْ سَبْعِينَ مَرَّةً فَلَنْ يَغْفِرَ اللَّهُ لَهُمْ‏\}‏ فَقَالَ سَأَزِيدُهُ عَلَى سَبْعِينَ ‏"‏‏.‏ قَالَ فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَلَّيْنَا مَعَهُ ثُمَّ أَنْزَلَ اللَّهُ عَلَيْهِ ‏\{‏وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا وَلاَ تَقُمْ عَلَى قَبْرِهِ إِنَّهُمْ كَفَرُوا بِاللَّهِ وَرَسُولِهِ وَمَاتُوا وَهُمْ فَاسِقُونَ‏\}‏\hadithno{4672}\hadithtrans{Narrated Ibn `Umar:When `Abdullah bin Ubai died, his son `Abdullah bin `Abdullah came to Allah's Messenger (ﷺ) who gave his shirt to him and ordered him to shroud his father in it. Then he stood up to offer the funeral prayer for the deceased, but `Umar bin Al-Khattab took hold of his garment and said, "Do you offer the funeral prayer for him though he was a hypocrite and Allah has forbidden you to ask forgiveness for hypocrites?" The Prophet (ﷺ) said, "Allah has given me the choice (or Allah has informed me) saying: "Whether you, O Muhammad, ask forgiveness for them, or do not ask forgiveness for them, even if you ask forgiveness for them seventy times, Allah will not forgive them," (9.80) Then he added, "I will (appeal to Allah for his sake) more than seventy times." So Allah's Messenger (ﷺ) offered the funeral prayer for him and we too, offered the prayer along with him. Then Allah revealed: "And never, O Muhammad, pray (funeral prayer) for anyone of them that dies, nor stand at his grave. Certainly they disbelieved in Allah and His Apostle and died in a state of rebellion}}
\hadithdefcmd{bukhari}{4673}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، حِينَ تَخَلَّفَ عَنْ تَبُوكَ، وَاللَّهِ، مَا أَنْعَمَ اللَّهُ عَلَىَّ مِنْ نِعْمَةٍ بَعْدَ إِذْ هَدَانِي أَعْظَمَ مِنْ صِدْقِي رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ لاَ أَكُونَ كَذَبْتُهُ فَأَهْلِكَ كَمَا هَلَكَ الَّذِينَ كَذَبُوا حِينَ أُنْزِلَ الْوَحْىُ ‏\{‏سَيَحْلِفُونَ بِاللَّهِ لَكُمْ إِذَا انْقَلَبْتُمْ إِلَيْهِمْ‏\}‏ إِلَى ‏\{‏الْفَاسِقِينَ‏\}‏‏.‏\hadithno{4673}\hadithtrans{Narrated `Abdullah bin Ka`b:I heard Ka`b bin Malik at the time he remained behind and did not join (the battle of) Tabuk, saying, "By Allah, no blessing has Allah bestowed upon me, besides my guidance to Islam, better than that of helping me speak the truth to Allah's Messenger (ﷺ) otherwise I would have told the Prophet (ﷺ) a lie and would have been ruined like those who had told a lie when the Divine Inspiration was revealed:-- "They will swear by Allah to you (Muslims) when you return to them.. the rebellious people}}
\hadithdefcmd{bukhari}{4674}{حَدَّثَنَا مُؤَمَّلٌ ـ هُوَ ابْنُ هِشَامٍ ـ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، وَحَدَّثَنَا عَوْفٌ، حَدَّثَنَا أَبُو رَجَاءٍ، حَدَّثَنَا سَمُرَةُ بْنُ جُنْدُبٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَنَا ‏ "‏ أَتَانِي اللَّيْلَةَ آتِيَانِ فَابْتَعَثَانِي، فَانْتَهَيْنَا إِلَى مَدِينَةٍ مَبْنِيَّةٍ بِلَبِنِ ذَهَبٍ وَلَبِنِ فِضَّةٍ، فَتَلَقَّانَا رِجَالٌ شَطْرٌ مِنْ خَلْقِهِمْ كَأَحْسَنِ مَا أَنْتَ رَاءٍ، وَشَطْرٌ كَأَقْبَحِ مَا أَنْتَ رَاءٍ قَالاَ لَهُمُ اذْهَبُوا فَقَعُوا فِي ذَلِكَ النَّهْرِ‏.‏ فَوَقَعُوا فِيهِ ثُمَّ رَجَعُوا إِلَيْنَا قَدْ ذَهَبَ ذَلِكَ السُّوءُ عَنْهُمْ، فَصَارُوا فِي أَحْسَنِ صُورَةٍ قَالاَ لِي هَذِهِ جَنَّةُ عَدْنٍ، وَهَذَاكَ مَنْزِلُكَ قَالاَ أَمَّا الْقَوْمُ الَّذِينَ كَانُوا شَطْرٌ مِنْهُمْ حَسَنٌ وَشَطْرٌ مِنْهُمْ قَبِيحٌ فَإِنَّهُمْ خَلَطُوا عَمَلاً صَالِحًا وَآخَرَ سَيِّئًا تَجَاوَزَ اللَّهُ عَنْهُمْ ‏"‏‏.‏\hadithno{4674}\hadithtrans{Narrated Samura bin Jundab:Allah's Messenger (ﷺ) said, "Tonight two (visitors) came to me (in my dream) and took me to a town built with gold bricks and silver bricks. There we met men who, half of their bodies, look like the most handsome human beings you have ever seen, and the other half, the ugliest human beings you have ever seen. Those two visitors said to those men, 'Go and dip yourselves in that river. So they dipped themselves therein and then came to us, their ugliness having disappeared and they were in the most handsome shape. The visitors said, 'The first is the Garden of Eden and that is your dwelling place.' Then they added, 'As for those people who were half ugly and half handsome, they were those who mixed good deeds and bad deeds, but Allah forgave them}}
\hadithdefcmd{bukhari}{4675}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِيهِ، قَالَ لَمَّا حَضَرَتْ أَبَا طَالِبٍ الْوَفَاةُ دَخَلَ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم وَعِنْدَهُ أَبُو جَهْلٍ وَعَبْدُ اللَّهِ بْنُ أَبِي أُمَيَّةَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَىْ عَمِّ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ أُحَاجُّ لَكَ بِهَا عِنْدَ اللَّهِ ‏"‏‏.‏ فَقَالَ أَبُو جَهْلٍ وَعَبْدُ اللَّهِ بْنُ أَبِي أُمَيَّةَ يَا أَبَا طَالِبٍ، أَتَرْغَبُ عَنْ مِلَّةِ عَبْدِ الْمُطَّلِبِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لأَسْتَغْفِرَنَّ لَكَ مَا لَمْ أُنْهَ عَنْكَ ‏"‏‏.‏ فَنَزَلَتْ ‏\{‏مَا كَانَ لِلنَّبِيِّ وَالَّذِينَ آمَنُوا أَنْ يَسْتَغْفِرُوا لِلْمُشْرِكِينَ وَلَوْ كَانُوا أُولِي قُرْبَى مِنْ بَعْدِ مَا تَبَيَّنَ لَهُمْ أَنَّهُمْ أَصْحَابُ الْجَحِيمِ‏\}‏\hadithno{4675}\hadithtrans{Narrated Al-Musaiyab:When Abu Talib's death approached, the Prophet (ﷺ) went to him while Abu Jahl and `Abdullah bin Abi Umaiya were present with him. The Prophet (ﷺ) said, "O uncle, say: None has the right to be worshipped except Allah, so that I may argue for your case with it before Allah." On that, Abu Jahl and `Abdullah bin Abu Umaiya said, "O Abu Talib! Do you want to renounce `Abdul Muttalib's religion?" Then the Prophet said, "I will keep on asking (Allah for) forgiveness for you unless I am forbidden to do so." Then there was revealed:-- 'It is not fitting for the Prophet (ﷺ) and those who believe that they should invoke (Allah) for forgiveness for pagans even though they be of kin, after it has become clear to them that they are companions of the Fire}}
\hadithdefcmd{bukhari}{4676}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، قَالَ أَحْمَدُ حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ كَعْبٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ كَعْبٍ ـ وَكَانَ قَائِدَ كَعْبٍ مِنْ بَنِيهِ حِينَ عَمِيَ ـ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، فِي حَدِيثِهِ ‏\{‏وَعَلَى الثَّلاَثَةِ الَّذِينَ خُلِّفُوا‏\}‏ قَالَ فِي آخِرِ حَدِيثِهِ إِنَّ مِنْ تَوْبَتِي أَنْ أَنْخَلِعَ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَرَسُولِهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمْسِكْ بَعْضَ مَالِكَ، فَهْوَ خَيْرٌ لَكَ ‏"‏‏.‏\hadithno{4676}\hadithtrans{Narrated `Abdullah bin Ka`b:I heard Ka`b bin Malik talking about the Verse:-- 'And to the three (He also forgave) who remained behind.' (9.118) saying in the last portion of his talk, "(I said), 'As a part (sign) of my repentance, I would like to give up all my property in the cause of Allah and His Apostle,' The Prophet (ﷺ) said to me, 'Keep some of your wealth as it is good for you." (To the three (He also forgave) who remained behind till for them the earth, vast as it is, was straitened}}
\hadithdefcmd{bukhari}{4677}{حَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، حَدَّثَنَا إِسْحَاقُ بْنُ رَاشِدٍ، أَنَّ الزُّهْرِيَّ، حَدَّثَهُ قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبِي كَعْبَ بْنَ مَالِكٍ،، وَهْوَ أَحَدُ الثَّلاَثَةِ الَّذِينَ تِيبَ عَلَيْهِمْ أَنَّهُ لَمْ يَتَخَلَّفْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ غَزَاهَا قَطُّ غَيْرَ غَزْوَتَيْنِ غَزْوَةِ الْعُسْرَةِ وَغَزْوَةِ بَدْرٍ‏.‏ قَالَ فَأَجْمَعْتُ صِدْقَ رَسُولِ اللَّهِ صلى الله عليه وسلم ضُحًى، وَكَانَ قَلَّمَا يَقْدَمُ مِنْ سَفَرٍ سَافَرَهُ إِلاَّ ضُحًى وَكَانَ يَبْدَأُ بِالْمَسْجِدِ، فَيَرْكَعُ رَكْعَتَيْنِ، وَنَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ كَلاَمِي وَكَلاَمِ صَاحِبَىَّ، وَلَمْ يَنْهَ عَنْ كَلاَمِ أَحَدٍ مِنَ الْمُتَخَلِّفِينَ غَيْرِنَا، فَاجْتَنَبَ النَّاسُ كَلاَمَنَا، فَلَبِثْتُ كَذَلِكَ حَتَّى طَالَ عَلَىَّ الأَمْرُ، وَمَا مِنْ شَىْءٍ أَهَمُّ إِلَىَّ مِنْ أَنْ أَمُوتَ فَلاَ يُصَلِّي عَلَىَّ النَّبِيُّ صلى الله عليه وسلم أَوْ يَمُوتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَكُونَ مِنَ النَّاسِ بِتِلْكَ الْمَنْزِلَةِ، فَلاَ يُكَلِّمُنِي أَحَدٌ مِنْهُمْ، وَلاَ يُصَلِّي عَلَىَّ، فَأَنْزَلَ اللَّهُ تَوْبَتَنَا عَلَى نَبِيِّهِ صلى الله عليه وسلم حِينَ بَقِيَ الثُّلُثُ الآخِرُ مِنَ اللَّيْلِ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ أُمِّ سَلَمَةَ، وَكَانَتْ أُمُّ سَلَمَةَ مُحْسِنَةً فِي شَأْنِي مَعْنِيَّةً فِي أَمْرِي، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أُمَّ سَلَمَةَ تِيبَ عَلَى كَعْبٍ ‏"‏‏.‏ قَالَتْ أَفَلاَ أُرْسِلُ إِلَيْهِ فَأُبَشِّرَهُ قَالَ ‏"‏ إِذًا يَحْطِمَكُمُ النَّاسُ فَيَمْنَعُونَكُمُ النَّوْمَ سَائِرَ اللَّيْلَةِ ‏"‏‏.‏ حَتَّى إِذَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْفَجْرِ آذَنَ بِتَوْبَةِ اللَّهِ عَلَيْنَا، وَكَانَ إِذَا اسْتَبْشَرَ اسْتَنَارَ وَجْهُهُ حَتَّى كَأَنَّهُ قِطْعَةٌ مِنَ الْقَمَرِ، وَكُنَّا أَيُّهَا الثَّلاَثَةُ الَّذِينَ خُلِّفُوا عَنِ الأَمْرِ الَّذِي قُبِلَ مِنْ هَؤُلاَءِ الَّذِينَ اعْتَذَرُوا حِينَ أَنْزَلَ اللَّهُ لَنَا التَّوْبَةَ، فَلَمَّا ذُكِرَ الَّذِينَ كَذَبُوا رَسُولَ اللَّهِ صلى الله عليه وسلم مِنَ الْمُتَخَلِّفِينَ، وَاعْتَذَرُوا بِالْبَاطِلِ، ذُكِرُوا بِشَرِّ مَا ذُكِرَ بِهِ أَحَدٌ قَالَ اللَّهُ سُبْحَانَهُ ‏\{‏يَعْتَذِرُونَ إِلَيْكُمْ إِذَا رَجَعْتُمْ إِلَيْهِمْ قُلْ لاَ تَعْتَذِرُوا لَنْ نُؤْمِنَ لَكُمْ قَدْ نَبَّأَنَا اللَّهُ مِنْ أَخْبَارِكُمْ وَسَيَرَى اللَّهُ عَمَلَكُمْ وَرَسُولُهُ‏\}‏ الآيَةَ‏.‏\hadithno{4677}\hadithtrans{Narrated `Abdullah bin Ka`b:I heard Ka`b bin Malik who was one of the three who were forgiven, saying that he had never remained behind Allah's Messenger (ﷺ) in any Ghazwa which he had fought except two Ghazwat Ghazwat- Al-`Usra (Tabuk) and Ghazwat-Badr. He added. "I decided to tell the truth to Allah's Messenger (ﷺ) in the forenoon, and scarcely did he return from a journey he made, except in the forenoon, he would go first to the mosque and offer a two-rak`at prayer. The Prophet (ﷺ) forbade others to speak to me or to my two companions, but he did not prohibit speaking to any of those who had remained behind excepting us. So the people avoided speaking to us, and I stayed in that state till I could no longer bear it, and the only thing that worried me was that I might die and the Prophet (ﷺ) would not offer the funeral prayer for me, or Allah's Messenger (ﷺ) might die and I would be left in that social status among the people that nobody would speak to me or offer the funeral prayer for me. But Allah revealed His Forgiveness for us to the Prophet (ﷺ) in the last third of the night while Allah's Messenger (ﷺ) was with Um Salama. Um Salama sympathized with me and helped me in my disaster. Allah's Messenger (ﷺ) said, 'O Um Salama! Ka`b has been forgiven!' She said, 'Shall I send someone to him to give him the good tidings?' He said, 'If you did so, the people would not let you sleep the rest of the night.' So when the Prophet (ﷺ) had offered the Fajr prayer, he announced Allah's Forgiveness for us. His face used to look as bright as a piece of the (full) moon whenever he was pleased. When Allah revealed His Forgiveness for us, we were the three whose case had been deferred while the excuse presented by those who had apologized had been accepted. But when there were mentioned those who had told the Prophet (ﷺ) lies and remained behind (the battle of Tabuk) and had given false excuses, they were described with the worse description one may be described with. Allah said: 'They will present their excuses to you (Muslims) when you return to them. Say: Present no excuses; we shall not believe you. Allah has already informed us of the true state of matters concerning you. Allah and His Apostle will observe your actions}}
\hadithdefcmd{bukhari}{4678}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبِ بْنِ مَالِكٍ ـ وَكَانَ قَائِدَ كَعْبِ بْنِ مَالِكٍ ـ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، يُحَدِّثُ حِينَ تَخَلَّفَ عَنْ قِصَّةِ، تَبُوكَ‏.‏ فَوَاللَّهِ مَا أَعْلَمُ أَحَدًا أَبْلاَهُ اللَّهُ فِي صِدْقِ الْحَدِيثِ أَحْسَنَ مِمَّا أَبْلاَنِي، مَا تَعَمَّدْتُ مُنْذُ ذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى يَوْمِي هَذَا كَذِبًا، وَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ عَلَى رَسُولِهِ صلى الله عليه وسلم ‏\{‏لَقَدْ تَابَ اللَّهُ عَلَى النَّبِيِّ وَالْمُهَاجِرِينَ‏\}‏ إِلَى قَوْلِهِ ‏\{‏وَكُونُوا مَعَ الصَّادِقِينَ‏\}‏\hadithno{4678}\hadithtrans{Narrated `Abdullah bin Ka`b:I heard Ka`b bin Malik talking about the story of the battle of Tabuk when he remained behind, "By Allah, I do not know anyone whom Allah has helped for telling the truth more than me since I mentioned that truth to Allah's Messenger (ﷺ) till today, I have never intended to tell a lie. And Allah revealed to His Apostle: "Verily! Allah has forgiven the Prophet, the Muhajirin............ and be with those who are true (in words and deeds)." (9.117-119) (See Hadith No. 702 Vol)}}
\hadithdefcmd{bukhari}{4679}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي ابْنُ السَّبَّاقِ، أَنَّ زَيْدَ بْنَ ثَابِتٍ الأَنْصَارِيَّ ـ رضى الله عنه ـ وَكَانَ مِمَّنْ يَكْتُبُ الْوَحْىَ قَالَ أَرْسَلَ إِلَىَّ أَبُو بَكْرٍ مَقْتَلَ أَهْلِ الْيَمَامَةِ وَعِنْدَهُ عُمَرُ، فَقَالَ أَبُو بَكْرٍ إِنَّ عُمَرَ أَتَانِي فَقَالَ إِنَّ الْقَتْلَ قَدِ اسْتَحَرَّ يَوْمَ الْيَمَامَةِ بِالنَّاسِ، وَإِنِّي أَخْشَى أَنْ يَسْتَحِرَّ الْقَتْلُ بِالْقُرَّاءِ فِي الْمَوَاطِنِ فَيَذْهَبَ كَثِيرٌ مِنَ الْقُرْآنِ، إِلاَّ أَنْ تَجْمَعُوهُ، وَإِنِّي لأَرَى أَنْ تَجْمَعَ الْقُرْآنَ‏.‏ قَالَ أَبُو بَكْرٍ قُلْتُ لِعُمَرَ كَيْفَ أَفْعَلُ شَيْئًا لَمْ يَفْعَلْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عُمَرُ هُوَ وَاللَّهِ خَيْرٌ‏.‏ فَلَمْ يَزَلْ عُمَرُ يُرَاجِعُنِي فِيهِ حَتَّى شَرَحَ اللَّهُ لِذَلِكَ صَدْرِي، وَرَأَيْتُ الَّذِي رَأَى عُمَرُ‏.‏ قَالَ زَيْدُ بْنُ ثَابِتٍ وَعُمَرُ عِنْدَهُ جَالِسٌ لاَ يَتَكَلَّمُ‏.‏ فَقَالَ أَبُو بَكْرٍ إِنَّكَ رَجُلٌ شَابٌّ عَاقِلٌ وَلاَ نَتَّهِمُكَ، كُنْتَ تَكْتُبُ الْوَحْىَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَتَتَبَّعِ الْقُرْآنَ فَاجْمَعْهُ‏.‏ فَوَاللَّهِ لَوْ كَلَّفَنِي نَقْلَ جَبَلٍ مِنَ الْجِبَالِ مَا كَانَ أَثْقَلَ عَلَىَّ مِمَّا أَمَرَنِي بِهِ مِنْ جَمْعِ الْقُرْآنِ قُلْتُ كَيْفَ تَفْعَلاَنِ شَيْئًا لَمْ يَفْعَلْهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ أَبُو بَكْرٍ هُوَ وَاللَّهِ خَيْرٌ، فَلَمْ أَزَلْ أُرَاجِعُهُ حَتَّى شَرَحَ اللَّهُ صَدْرِي لِلَّذِي شَرَحَ اللَّهُ لَهُ صَدْرَ أَبِي بَكْرٍ وَعُمَرَ، فَقُمْتُ فَتَتَبَّعْتُ الْقُرْآنَ أَجْمَعُهُ مِنَ الرِّقَاعِ وَالأَكْتَافِ وَالْعُسُبِ وَصُدُورِ الرِّجَالِ، حَتَّى وَجَدْتُ مِنْ سُورَةِ التَّوْبَةِ آيَتَيْنِ مَعَ خُزَيْمَةَ الأَنْصَارِيِّ، لَمْ أَجِدْهُمَا مَعَ أَحَدٍ غَيْرِهِ ‏\{‏لَقَدْ جَاءَكُمْ رَسُولٌ مِنْ أَنْفُسِكُمْ عَزِيزٌ عَلَيْهِ مَا عَنِتُّمْ حَرِيصٌ عَلَيْكُمْ‏\}‏ إِلَى آخِرِهِمَا، وَكَانَتِ الصُّحُفُ الَّتِي جُمِعَ فِيهَا الْقُرْآنُ عِنْدَ أَبِي بَكْرٍ حَتَّى تَوَفَّاهُ اللَّهُ، ثُمَّ عِنْدَ عُمَرَ حَتَّى تَوَفَّاهُ اللَّهُ، ثُمَّ عِنْدَ حَفْصَةَ بِنْتِ عُمَرَ‏.‏ تَابَعَهُ عُثْمَانُ بْنُ عُمَرَ وَاللَّيْثُ عَنْ يُونُسَ عَنِ ابْنِ شِهَابٍ‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ عَنِ ابْنِ شِهَابٍ وَقَالَ مَعَ أَبِي خُزَيْمَةَ الأَنْصَارِيِّ‏.‏ وَقَالَ مُوسَى عَنْ إِبْرَاهِيمَ حَدَّثَنَا ابْنُ شِهَابٍ مَعَ أَبِي خُزَيْمَةَ‏.‏ وَتَابَعَهُ يَعْقُوبُ بْنُ إِبْرَاهِيمَ عَنْ أَبِيهِ‏.‏ وَقَالَ أَبُو ثَابِتٍ حَدَّثَنَا إِبْرَاهِيمُ وَقَالَ مَعَ خُزَيْمَةَ، أَوْ أَبِي خُزَيْمَةَ‏.‏\hadithno{4679}\hadithtrans{Narrated Zaid bin Thabit Al-Ansari:who was one of those who used to write the Divine Revelation: Abu Bakr sent for me after the (heavy) casualties among the warriors (of the battle) of Yamama (where a great number of Qurra' were killed). `Umar was present with Abu Bakr who said, `Umar has come to me and said, The people have suffered heavy casualties on the day of (the battle of) Yamama, and I am afraid that there will be more casualties among the Qurra' (those who know the Qur'an by heart) at other battle-fields, whereby a large part of the Qur'an may be lost, unless you collect it. And I am of the opinion that you should collect the Qur'an." Abu Bakr added, "I said to `Umar, 'How can I do something which Allah's Apostle has not done?' `Umar said (to me), 'By Allah, it is (really) a good thing.' So `Umar kept on pressing, trying to persuade me to accept his proposal, till Allah opened my bosom for it and I had the same opinion as `Umar." (Zaid bin Thabit added:) `Umar was sitting with him (Abu Bakr) and was not speaking to me. "You are a wise young man and we do not suspect you (of telling lies or of forgetfulness): and you used to write the Divine Inspiration for Allah's Messenger (ﷺ). Therefore, look for the Qur'an and collect it (in one manuscript). " By Allah, if he (Abu Bakr) had ordered me to shift one of the mountains (from its place) it would not have been harder for me than what he had ordered me concerning the collection of the Qur'an. I said to both of them, "How dare you do a thing which the Prophet has not done?" Abu Bakr said, "By Allah, it is (really) a good thing. So I kept on arguing with him about it till Allah opened my bosom for that which He had opened the bosoms of Abu Bakr and `Umar. So I started locating Qur'anic material and collecting it from parchments, scapula, leaf-stalks of date palms and from the memories of men (who knew it by heart). I found with Khuza`ima two Verses of Surat-at-Tauba which I had not found with anybody else, (and they were):-- "Verily there has come to you an Apostle (Muhammad) from amongst yourselves. It grieves him that you should receive any injury or difficulty He (Muhammad) is ardently anxious over you (to be rightly guided)" (9.128) The manuscript on which the Qur'an was collected, remained with Abu Bakr till Allah took him unto Him, and then with `Umar till Allah took him unto Him, and finally it remained with Hafsa, `Umar's daughter}}
\hadithdefcmd{bukhari}{4680}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَالْيَهُودُ تَصُومُ عَاشُورَاءَ فَقَالُوا هَذَا يَوْمٌ ظَهَرَ فِيهِ مُوسَى عَلَى فِرْعَوْنَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأَصْحَابِهِ ‏ "‏ أَنْتُمْ أَحَقُّ بِمُوسَى مِنْهُمْ، فَصُومُوا ‏"‏‏.‏\hadithno{4680}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) arrived at Medina, the Jews were observing the fast on 'Ashura' (10th of Muharram) and they said, "This is the day when Moses became victorious over Pharaoh," On that, the Prophet (ﷺ) said to his companions, "You (Muslims) have more right to celebrate Moses' victory than they have, so observe the fast on this day}}
\hadithdefcmd{bukhari}{4681}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ صَبَّاحٍ، حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبَّادِ بْنِ جَعْفَرٍ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقْرَأُ ‏\{‏أَلاَ إِنَّهُمْ تَثْنَوْنِي صُدُورُهُمْ‏\}‏ قَالَ سَأَلْتُهُ عَنْهَا فَقَالَ أُنَاسٌ كَانُوا يَسْتَحْيُونَ أَنْ يَتَخَلَّوْا فَيُفْضُوا إِلَى السَّمَاءِ، وَأَنْ يُجَامِعُوا نِسَاءَهُمْ فَيُفْضُوا إِلَى السَّمَاءِ، فَنَزَلَ ذَلِكَ فِيهِمْ‏.‏\hadithno{4681}\hadithtrans{Narrated Muhammad bin `Abbas bin Ja`far:That he heard Ibn `Abbas reciting: "No doubt! They fold up their breasts." (11.5) and asked him about its explanation. He said, "Some people used to hide themselves while answering the call of nature in an open space lest they be exposed to the sky, and also when they had sexual relation with their wives in an open space lest they be exposed to the sky, so the above revelation was sent down regarding them}}
\hadithdefcmd{bukhari}{4682}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، وَأَخْبَرَنِي مُحَمَّدُ بْنُ عَبَّادِ بْنِ جَعْفَرٍ، أَنَّ ابْنَ عَبَّاسٍ، قَرَأَ ‏\{‏أَلاَ إِنَّهُمْ تَثْنَوْنِي صُدُورُهُمْ‏\}‏ قُلْتُ يَا أَبَا الْعَبَّاسِ مَا تَثْنَوْنِي صُدُورُهُمْ قَالَ كَانَ الرَّجُلُ يُجَامِعُ امْرَأَتَهُ فَيَسْتَحِي أَوْ يَتَخَلَّى فَيَسْتَحِي فَنَزَلَتْ ‏\{‏أَلاَ إِنَّهُمْ يَثْنُونَ صُدُورَهُمْ‏\}‏\hadithno{4682}\hadithtrans{Narrated Muhammad bin `Abbas bin Ja`far:Ibn `Abbas recited. "No doubt! They fold up their breasts." I said, "O Abu `Abbas! What is meant by "They fold up their breasts?" He said, "A man used to feel shy on having sexual relation with his wife or on answering the call of nature (in an open space) so this Verse was revealed:-- "No doubt! They fold up their breasts}}
\hadithdefcmd{bukhari}{4683}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، قَالَ قَرَأَ ابْنُ عَبَّاسٍ ‏\{‏أَلاَ إِنَّهُمْ يَثْنُونَ صُدُورَهُمْ لِيَسْتَخْفُوا مِنْهُ أَلاَ حِينَ يَسْتَغْشُونَ ثِيَابَهُمْ‏\}‏ وَقَالَ غَيْرُهُ عَنِ ابْنِ عَبَّاسٍ ‏\{‏يَسْتَغْشُونَ‏\}‏ يُغَطُّونَ رُءُوسَهُمْ ‏\{‏سِيءَ بِهِمْ‏\}‏ سَاءَ ظَنُّهُ بِقَوْمِهِ‏.‏ ‏\{‏وَضَاقَ بِهِمْ‏\}‏ بِأَضْيَافِهِ ‏\{‏بِقِطْعٍ مِنَ اللَّيْلِ‏\}‏ بِسَوَادٍ‏.‏ وَقَالَ مُجَاهِدٌ ‏\{‏أُنِيبُ‏\}‏ أَرْجِعُ‏.‏\hadithno{4683}\hadithtrans{Narrated `Amr:Ibn `Abbas recited:-- "No doubt! They fold up their breasts in order to hide from Him. Surely! Even when they cover themselves with their garments}}
\hadithdefcmd{bukhari}{4684}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ قَالَ اللَّهُ عَزَّ وَجَلَّ أَنْفِقْ أُنْفِقْ عَلَيْكَ ـ وَقَالَ ـ يَدُ اللَّهِ مَلأَى لاَ تَغِيضُهَا نَفَقَةٌ، سَحَّاءُ اللَّيْلَ وَالنَّهَارَ ـ وَقَالَ ـ أَرَأَيْتُمْ مَا أَنْفَقَ مُنْذُ خَلَقَ السَّمَاءَ وَالأَرْضَ فَإِنَّهُ لَمْ يَغِضْ مَا فِي يَدِهِ، وَكَانَ عَرْشُهُ عَلَى الْمَاءِ، وَبِيَدِهِ الْمِيزَانُ يَخْفِضُ وَيَرْفَعُ ‏"‏‏.‏ ‏\{‏اعْتَرَاكَ‏\}‏ افْتَعَلْتَ مِنْ عَرَوْتُهُ أَىْ أَصَبْتُهُ، وَمِنْهُ يَعْرُوهُ وَاعْتَرَانِي ‏\{‏آخِذٌ بِنَاصِيَتِهَا‏\}‏ أَىْ فِي مِلْكِهِ وَسُلْطَانِهِ‏.‏ عَنِيدٌ وَعَنُودٌ وَعَانِدٌ وَاحِدٌ، هُوَ تَأْكِيدُ التَّجَبُّرِ، ‏\{‏اسْتَعْمَرَكُمْ‏\}‏ جَعَلَكُمْ عُمَّارًا، أَعْمَرْتُهُ الدَّارَ فَهْىَ عُمْرَى جَعَلْتُهَا لَهُ‏.‏ ‏\{‏نَكِرَهُمْ‏\}‏ وَأَنْكَرَهُمْ وَاسْتَنْكَرَهُمْ وَاحِدٌ ‏\{‏حَمِيدٌ مَجِيدٌ‏\}‏ كَأَنَّهُ فَعِيلٌ مِنْ مَاجِدٍ‏.‏ مَحْمُودٌ مِنْ حَمِدَ‏.‏ سِجِّيلٌ الشَّدِيدُ الْكَبِيرُ‏.‏ سِجِّيلٌ وَسِجِّينٌ وَاللاَّمُ وَالنُّونُ أُخْتَانِ، وَقَالَ تَمِيمُ بْنُ مُقْبِلٍ وَرَجْلَةٍ يَضْرِبُونَ الْبَيْضَ ضَاحِيَةً ضَرْبًا تَوَاصَى بِهِ الأَبْطَالُ سِجِّينَا\hadithno{4684}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, 'Spend (O man), and I shall spend on you." He also said, "Allah's Hand is full, and (its fullness) is not affected by the continuous spending night and day." He also said, "Do you see what He has spent since He created the Heavens and the Earth? Nevertheless, what is in His Hand is not decreased, and His Throne was over the water; and in His Hand there is the balance (of justice) whereby He raises and lowers (people)}}
\hadithdefcmd{bukhari}{4685}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، وَهِشَامٌ، قَالاَ حَدَّثَنَا قَتَادَةُ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ، قَالَ بَيْنَا ابْنُ عُمَرَ يَطُوفُ إِذْ عَرَضَ رَجُلٌ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ ـ أَوْ قَالَ يَا ابْنَ عُمَرَ ـ سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم فِي النَّجْوَى فَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يُدْنَى الْمُؤْمِنُ مِنْ رَبِّهِ ـ وَقَالَ هِشَامٌ يَدْنُو الْمُؤْمِنُ ـ حَتَّى يَضَعَ عَلَيْهِ كَنَفَهُ، فَيُقَرِّرُهُ بِذُنُوبِهِ تَعْرِفُ ذَنْبَ كَذَا يَقُولُ أَعْرِفُ، يَقُولُ رَبِّ أَعْرِفُ مَرَّتَيْنِ، فَيَقُولُ سَتَرْتُهَا فِي الدُّنْيَا وَأَغْفِرُهَا لَكَ الْيَوْمَ ثُمَّ تُطْوَى صَحِيفَةُ حَسَنَاتِهِ، وَأَمَّا الآخَرُونَ أَوِ الْكُفَّارُ فَيُنَادَى عَلَى رُءُوسِ الأَشْهَادِ هَؤُلاَءِ الَّذِينَ كَذَبُوا عَلَى رَبِّهِمْ ‏"‏‏.‏ وَقَالَ شَيْبَانُ عَنْ قَتَادَةَ حَدَّثَنَا صَفْوَانُ‏.‏\hadithno{4685}\hadithtrans{Narrated Safwan bin Muhriz:While Ibn `Umar was performing the Tawaf (around the Ka`ba), a man came up to him and said, "O Abu `AbdurRahman!" or said, "O Ibn `Umar! Did you hear anything from the Prophet (ﷺ) about An-Najwa?" Ibn `Umar said, "I heard the Prophet (ﷺ) saying, 'The Believer will be brought near his Lord." (Hisham, a sub-narrator said, reporting the Prophet's words), "The believer will come near (his Lord) till his Lord covers him with His screen and makes him confess his sins. (Allah will ask him), 'Do you know (that you did) 'such-and-such sin?" He will say twice, 'Yes, I do.' Then Allah will say, 'I concealed it in the world and I forgive it for you today.' Then the record of his good deeds will be folded up. As for the others, or the disbelievers, it will be announced publicly before the witnesses: 'These are ones who lied against their Lord}}
\hadithdefcmd{bukhari}{4686}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا بُرَيْدُ بْنُ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ لَيُمْلِي لِلظَّالِمِ حَتَّى إِذَا أَخَذَهُ لَمْ يُفْلِتْهُ ‏"‏‏.‏ قَالَ ثُمَّ قَرَأَ ‏\{‏وَكَذَلِكَ أَخْذُ رَبِّكَ إِذَا أَخَذَ الْقُرَى وَهْىَ ظَالِمَةٌ إِنَّ أَخْذَهُ أَلِيمٌ شَدِيدٌ‏\}‏\hadithno{4686}\hadithtrans{Narrated Abu Musa:Allah's Messenger (ﷺ) said, "Allah gives respite to the oppressor, but when He takes him over, He never releases him." Then he recited:-- "Such is the seizure of your Lord when He seizes (population of) towns in the midst of their wrong: Painful indeed, and severe is His seizure}}
\hadithdefcmd{bukhari}{4687}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ ـ هُوَ ابْنُ زُرَيْعٍ ـ حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ أَنَّ رَجُلاً، أَصَابَ مِنَ امْرَأَةٍ قُبْلَةً، فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَأُنْزِلَتْ عَلَيْهِ ‏\{‏وَأَقِمِ الصَّلاَةَ طَرَفَىِ النَّهَارِ وَزُلَفًا مِنَ اللَّيْلِ إِنَّ الْحَسَنَاتِ يُذْهِبْنَ السَّيِّئَاتِ ذَلِكَ ذِكْرَى لِلذَّاكِرِينَ‏\}‏‏.‏ قَالَ الرَّجُلُ أَلِيَ هَذِهِ قَالَ ‏ "‏ لِمَنْ عَمِلَ بِهَا مِنْ أُمَّتِي ‏"‏‏.‏\hadithno{4687}\hadithtrans{Narrated Ibn Masud:A man kissed a woman and then came to Allah's Messenger (ﷺ) and told him of that, so this Divine Inspiration was revealed to the Prophet (ﷺ) 'And offer Prayers perfectly at the two ends of the day, and in some hours of the night; (i.e. (five) compulsory prayers). Verily, the good deeds remove the evil deeds (small sins) That is a reminder for the mindful.' (11.114) The man said, Is this instruction for me only?' The Prophet (ﷺ) said, "It is for all those of my followers who encounter a similar situation}}
\hadithdefcmd{bukhari}{4688}{وَقَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْكَرِيمُ بْنُ الْكَرِيمِ بْنِ الْكَرِيمِ بْنِ الْكَرِيمِ يُوسُفُ بْنُ يَعْقُوبَ بْنِ إِسْحَاقَ بْنِ إِبْرَاهِيمَ ‏"‏‏.‏\hadithno{4688}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "The honorable, the son of the honorable, the son of the honorable, the son of the honorable, i.e. Joseph, the son of Jacob, the son of Isaac, the son of Abraham}}
\hadithdefcmd{bukhari}{4689}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىُّ النَّاسِ أَكْرَمُ قَالَ ‏"‏ أَكْرَمُهُمْ عِنْدَ اللَّهِ أَتْقَاهُمْ ‏"‏‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَأَكْرَمُ النَّاسِ يُوسُفُ نَبِيُّ اللَّهِ ابْنُ نَبِيِّ اللَّهِ ابْنِ نَبِيِّ اللَّهِ ابْنِ خَلِيلِ اللَّهِ ‏"‏‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَعَنْ مَعَادِنِ الْعَرَبِ تَسْأَلُونِي ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ‏"‏ فَخِيَارُكُمْ فِي الْجَاهِلِيَّةِ خِيَارُكُمْ فِي الإِسْلاَمِ إِذَا فَقِهُوا ‏"‏‏.‏ تَابَعَهُ أَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ‏.‏\hadithno{4689}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) was asked, "Who are the most honorable of the people?" The Prophet (ﷺ) said, "The most honorable of them in Allah's Sight are those who keep their duty to Allah and fear Him. They said, "We do not ask you about that." He said, "Then the most honorable of the people is Joseph, Allah's prophet, the son of Allah's prophet, the son of Allah's prophet, the son of Allah's Khalil i.e. Abraham) They said, "We do not ask you about that." The Prophet (ﷺ) said, Do you ask about (the virtues of the ancestry of the Arabs?" They said, "Yes," He said, "Those who were the best amongst you in the pre-Islamic Period are the best amongst you in Islam if they comprehend (the Islamic religion)}}
\hadithdefcmd{bukhari}{4690}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ،‏.‏ قَالَ وَحَدَّثَنَا الْحَجَّاجُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ النُّمَيْرِيُّ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ الأَيْلِيُّ، قَالَ سَمِعْتُ الزُّهْرِيَّ، سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، وَسَعِيدَ بْنَ الْمُسَيَّبِ، وَعَلْقَمَةَ بْنَ وَقَّاصٍ، وَعُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، عَنْ حَدِيثِ، عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ مَا قَالُوا فَبَرَّأَهَا اللَّهُ، كُلٌّ حَدَّثَنِي طَائِفَةً مِنَ الْحَدِيثِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنْ كُنْتِ بَرِيئَةً فَسَيُبَرِّئُكِ اللَّهُ، وَإِنْ كُنْتِ أَلْمَمْتِ بِذَنْبٍ فَاسْتَغْفِرِي اللَّهَ وَتُوبِي إِلَيْهِ ‏"‏‏.‏ قُلْتُ إِنِّي وَاللَّهِ لاَ أَجِدُ مَثَلاً إِلاَّ أَبَا يُوسُفَ ‏\{‏فَصَبْرٌ جَمِيلٌ وَاللَّهُ الْمُسْتَعَانُ عَلَى مَا تَصِفُونَ‏\}‏ وَأَنْزَلَ اللَّهُ ‏\{‏إِنَّ الَّذِينَ جَاءُوا بِالإِفْكِ‏\}‏ الْعَشْرَ الآيَاتِ‏.‏\hadithno{4690}\hadithtrans{Narrated Az-Zuhri:`Urwa bin Az-Zubair, Sa`id bin Al-Musaiyab, 'Al-Qama bin Waqqas and 'Ubaidullah bin `Abdullah related the narration of `Aisha, the wife of the Prophet, when the slanderers had said about her what they had said and Allah later declared her innocence. Each of them related a part of the narration (wherein) the Prophet (ﷺ) said (to `Aisha). "If you are innocent, then Allah will declare your innocence: but if you have committed a sin, then ask for Allah's Forgiveness and repent to Him." `Aisha said, "By Allah, I find no example for my case except that of Joseph's father (when he said), 'So (for me) patience is most fitting.' " Then Allah revealed the ten Verses:-- "Verily those who spread the slander are a gang amongst you}}
\hadithdefcmd{bukhari}{4691}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ حُصَيْنٍ، عَنْ أَبِي وَائِلٍ، قَالَ حَدَّثَنِي مَسْرُوقُ بْنُ الأَجْدَعِ، قَالَ حَدَّثَتْنِي أُمُّ رُومَانَ، وَهْىَ أُمُّ عَائِشَةَ قَالَتْ بَيْنَا أَنَا وَعَائِشَةُ أَخَذَتْهَا الْحُمَّى، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَعَلَّ فِي حَدِيثٍ تُحُدِّثَ ‏"‏‏.‏ قَالَتْ نَعَمْ وَقَعَدَتْ عَائِشَةُ قَالَتْ مَثَلِي وَمَثَلُكُمْ كَيَعْقُوبَ وَبَنِيهِ وَاللَّهُ الْمُسْتَعَانُ عَلَى مَا تَصِفُونَ‏.‏\hadithno{4691}\hadithtrans{Narrated Um Ruman:Who was `Aisha's mother: While I was with `Aisha, `Aisha got fever, whereupon the Prophet (ﷺ) said, "Probably her fever is caused by the story related by the people (about her)." I said, "Yes." Then `Aisha sat up and said, "My example and your example is similar to that of Jacob and his sons:--'Nay, but your minds have made up a tale. So (for me) patience is most fitting. It is Allah (alone) Whose help can be sought against that which you assert}}
\hadithdefcmd{bukhari}{4692}{حَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ هَيْتَ لَكَ قَالَ وَإِنَّمَا نَقْرَؤُهَا كَمَا عُلِّمْنَاهَا ‏\{‏مَثْوَاهُ‏\}‏ مُقَامُهُ ‏\{‏أَلْفَيَا‏\}‏ وَجَدَا ‏\{‏أَلْفَوْا آبَاءَهُمْ‏\}‏ ‏\{‏أَلْفَيْنَا‏\}‏ وَعَنِ ابْنِ مَسْعُودٍ ‏\{‏بَلْ عَجِبْتَ وَيَسْخَرُونَ‏\}‏\hadithno{4692}\hadithtrans{Narrated Abu Wail:`Abdullah bin Mas`ud recited "Haita laka (Come you)," and added, "We recite it as we were taught it}}
\hadithdefcmd{bukhari}{4693}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ قُرَيْشًا لَمَّا أَبْطَئُوا عَنِ النَّبِيِّ صلى الله عليه وسلم بِالإِسْلاَمِ قَالَ ‏"‏ اللَّهُمَّ اكْفِنِيهِمْ بِسَبْعٍ كَسَبْعِ يُوسُفَ ‏"‏ فَأَصَابَتْهُمْ سَنَةٌ حَصَّتْ كُلَّ شَىْءٍ حَتَّى أَكَلُوا الْعِظَامَ حَتَّى جَعَلَ الرَّجُلُ يَنْظُرُ إِلَى السَّمَاءِ فَيَرَى بَيْنَهُ وَبَيْنَهَا مِثْلَ الدُّخَانِ قَالَ اللَّهُ ‏\{‏فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ‏\}‏ قَالَ اللَّهُ ‏\{‏إِنَّا كَاشِفُو الْعَذَابِ قَلِيلاً إِنَّكُمْ عَائِدُونَ‏\}‏ أَفَيُكْشَفُ عَنْهُمُ الْعَذَابُ يَوْمَ الْقِيَامَةِ، وَقَدْ مَضَى الدُّخَانُ وَمَضَتِ الْبَطْشَةُ‏.‏\hadithno{4693}\hadithtrans{Narrated `Abdullah (bin Mas`ud):When the Prophet (ﷺ) realized that the Quraish had delayed in embracing Islam, he said, "O Allah! Protect me against their evil by afflicting them with seven (years of famine) like the seven years of (Prophet) Joseph." So they were struck with a year of famine that destroyed everything till they had to eat bones, and till a man would look towards the sky and see something like smoke between him and it. Allah said:-- "Then watch you (O Muhammad) for the day when the sky will produce a kind of smoke plainly visible." (44.10) And Allah further said:-- "Verily! We shall withdraw the punishment a little, Verily you will return (to disbelief)." (44.15) (Will Allah relieve them from torture on the Day of Resurrection?) (The punishment of) the smoke had passed and Al-Batsha (the destruction of the pagans in the Badr battle) had passed too}}
\hadithdefcmd{bukhari}{4694}{حَدَّثَنَا سَعِيدُ بْنُ تَلِيدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنْ بَكْرِ بْنِ مُضَرَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَرْحَمُ اللَّهُ لُوطًا، لَقَدْ كَانَ يَأْوِي إِلَى رُكْنٍ شَدِيدٍ، وَلَوْ لَبِثْتُ فِي السِّجْنِ مَا لَبِثَ يُوسُفُ لأَجَبْتُ الدَّاعِيَ، وَنَحْنُ أَحَقُّ مِنْ إِبْرَاهِيمَ إِذْ قَالَ لَهُ ‏\{‏أَوَلَمْ تُؤْمِنْ قَالَ بَلَى وَلَكِنْ لِيَطْمَئِنَّ قَلْبِي‏\}‏‏"‏\hadithno{4694}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "May Allah bestow His Mercy on (Prophet) Lot. (When his nation troubled him) he wished if he could betake himself to some powerful support; and if I were to remain in prison for the period Joseph had remained, I would surely respond to the call; and we shall have more right (to be in doubt) than Abraham: When Allah said to him, "Don't you believe?' Abraham said, 'Yes, (I do believe) but to be stronger in faith;}}
\hadithdefcmd{bukhari}{4695}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَهُ وَهُوَ يَسْأَلُهَا عَنْ قَوْلِ اللَّهِ تَعَالَى ‏\{‏حَتَّى إِذَا اسْتَيْأَسَ الرُّسُلُ‏\}‏ قَالَ قُلْتُ أَكُذِبُوا أَمْ كُذِّبُوا قَالَتْ عَائِشَةُ كُذِّبُوا‏.‏ قُلْتُ فَقَدِ اسْتَيْقَنُوا أَنَّ قَوْمَهُمْ كَذَّبُوهُمْ فَمَا هُوَ بِالظَّنِّ قَالَتْ أَجَلْ لَعَمْرِي لَقَدِ اسْتَيْقَنُوا بِذَلِكَ‏.‏ فَقُلْتُ لَهَا وَظَنُّوا أَنَّهُمْ قَدْ كُذِبُوا قَالَتْ مَعَاذَ اللَّهِ لَمْ تَكُنِ الرُّسُلُ تَظُنُّ ذَلِكَ بِرَبِّهَا‏.‏ قُلْتُ فَمَا هَذِهِ الآيَةُ‏.‏ قَالَتْ هُمْ أَتْبَاعُ الرُّسُلِ الَّذِينَ آمَنُوا بِرَبِّهِمْ وَصَدَّقُوهُمْ، فَطَالَ عَلَيْهِمُ الْبَلاَءُ، وَاسْتَأْخَرَ عَنْهُمُ النَّصْرُ حَتَّى اسْتَيْأَسَ الرُّسُلُ مِمَّنْ كَذَّبَهُمْ مِنْ قَوْمِهِمْ وَظَنَّتِ الرُّسُلُ أَنَّ أَتْبَاعَهُمْ قَدْ كَذَّبُوهُمْ جَاءَهُمْ نَصْرُ اللَّهِ عِنْدَ ذَلِكَ‏.‏\hadithno{4695}\hadithtrans{Narrated `Urwa bin Az-Zubair:That when he asked `Aisha about the statement of Allah "Until when the Apostles gave up hope (of their people)." (12.110) she told him (its meaning), `Urwa added, "I said, 'Did they (Apostles) suspect that they were betrayed (by Allah) or that they were treated as liars by (their people)?' `Aisha said, '(They suspected) that they were treated as liars by (their people),' I said, 'But they were sure that their people treated them as liars and it was not a matter of suspicion.' She said, 'Yes, upon my life they were sure about it.' I said to her. 'So they (Apostles) suspected that they were betrayed (by Allah).' She said, "Allah forbid! The Apostles never suspected their Lord of such a thing.' I said, 'What about this Verse then?' She said, 'It is about the Apostles' followers who believed in their Lord and trusted their Apostles, but the period of trials was prolonged and victory was delayed till the Apostles gave up all hope of converting those of the people who disbelieved them and the Apostles thought that their followers treated them as liars; thereupon Allah's help came to them}}
\hadithdefcmd{bukhari}{4696}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، فَقُلْتُ لَعَلَّهَا ‏\{‏كُذِبُوا‏\}‏ مُخَفَّفَةً‏.‏ قَالَتْ مَعَاذَ اللَّهِ‏ نَحْوَهُ\hadithno{4696}\hadithtrans{Narrated `Urwa:"I told her (`Aisha): (Regarding the above narration), they (Apostles) were betrayed (by Allah)." She said: Allah forbid or said similarly}}
\hadithdefcmd{bukhari}{4697}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَفَاتِيحُ الْغَيْبِ خَمْسٌ لاَ يَعْلَمُهَا إِلاَّ اللَّهُ لاَ يَعْلَمُ مَا فِي غَدٍ إِلاَّ اللَّهُ، وَلاَ يَعْلَمُ مَا تَغِيضُ الأَرْحَامُ إِلاَّ اللَّهُ وَلاَ يَعْلَمُ مَتَى يَأْتِي الْمَطَرُ أَحَدٌ إِلاَّ اللَّهُ، وَلاَ تَدْرِي نَفْسٌ بِأَىِّ أَرْضٍ تَمُوتُ، وَلاَ يَعْلَمُ مَتَى تَقُومُ السَّاعَةُ إِلاَّ اللَّهُ ‏"‏‏.‏\hadithno{4697}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "The keys of Unseen are five which none knows but Allah: None knows what will happen tomorrow but Allah; none knows what is in the wombs (a male child or a female) but Allah; none knows when it will rain but Allah; none knows at what place one will die; none knows when the Hour will be established but Allah." (See The Qur'an 31:)}}
\hadithdefcmd{bukhari}{4698}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَخْبِرُونِي بِشَجَرَةٍ تُشْبِهُ أَوْ كَالرَّجُلِ الْمُسْلِمِ لاَ يَتَحَاتُّ وَرَقُهَا وَلاَ وَلاَ وَلاَ، تُؤْتِي أُكْلَهَا كُلَّ حِينٍ ‏"‏‏.‏ قَالَ ابْنُ عُمَرَ فَوَقَعَ فِي نَفْسِي أَنَّهَا النَّخْلَةُ، وَرَأَيْتُ أَبَا بَكْرٍ وَعُمَرَ لاَ يَتَكَلَّمَانِ، فَكَرِهْتُ أَنْ أَتَكَلَّمَ، فَلَمَّا لَمْ يَقُولُوا شَيْئًا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هِيَ النَّخْلَةُ ‏"‏‏.‏ فَلَمَّا قُمْنَا قُلْتُ لِعُمَرَ يَا أَبَتَاهُ وَاللَّهِ لَقَدْ كَانَ وَقَعَ فِي نَفْسِي أَنَّهَا النَّخْلَةُ فَقَالَ مَا مَنَعَكَ أَنْ تَكَلَّمَ قَالَ لَمْ أَرَكُمْ تَكَلَّمُونَ، فَكَرِهْتُ أَنْ أَتَكَلَّمَ أَوْ أَقُولَ شَيْئًا‏.‏ قَالَ عُمَرُ لأَنْ تَكُونَ قُلْتَهَا أَحَبُّ إِلَىَّ مِنْ كَذَا وَكَذَا‏.‏\hadithno{4698}\hadithtrans{Narrated Ibn `Umar:While we were with Allah's Messenger (ﷺ) he said, "Tell me of a tree which resembles a Muslim man. Its leaves do not fall and it does not, and does not, and does not, and it gives its fruits every now and then." It came to my mind that such a tree must be the date palm, but seeing Abu Bakr and `Umar saying nothing, I disliked to speak. So when they did not say anything, Allah's Messenger (ﷺ) said, "It is the date-palm tree." When we got up (from that place), I said to `Umar, "O my father! By Allah, it came to my mind that it must be the date palm tree." `Umar said, "What prevented you from speaking?" I replied, "I did not see you speaking, so I disliked to speak or say anything." `Umar then said, "If you had said it, it would have been dearer to me than so-and-so}}
\hadithdefcmd{bukhari}{4699}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَلْقَمَةُ بْنُ مَرْثَدٍ، قَالَ سَمِعْتُ سَعْدَ بْنَ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْمُسْلِمُ إِذَا سُئِلَ فِي الْقَبْرِ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ، فَذَلِكَ قَوْلُهُ ‏\{‏يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ‏\}‏‏"‏\hadithno{4699}\hadithtrans{Narrated Al-Bara bin Azib:Allah's Messenger (ﷺ) said, "When a Muslim is questioned in his grave, he will testify that none has the right to be worshipped but Allah and that Muhammad is Allah's Messenger (ﷺ), and that is what is meant by Allah's Statement:-- "Allah will keep firm those who believe with a Word that stands firm in this world and in the Hereafter}}
\hadithdefcmd{bukhari}{4700}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، سَمِعَ ابْنَ عَبَّاسٍ، ‏\{‏أَلَمْ تَرَ إِلَى الَّذِينَ بَدَّلُوا نِعْمَةَ اللَّهِ كُفْرًا‏\}‏ قَالَ هُمْ كُفَّارُ أَهْلِ مَكَّةَ‏.‏\hadithno{4700}\hadithtrans{Narrated Ata:When Ibn `Abbas heard:-- "Have you not seen those who have changed the favor of Allah into disbelief?" (14.28) he said, "Those were the disbelieving pagans of Mecca}}
\hadithdefcmd{bukhari}{4701}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَضَى اللَّهُ الأَمْرَ فِي السَّمَاءِ ضَرَبَتِ الْمَلاَئِكَةُ بِأَجْنِحَتِهَا خُضْعَانًا لِقَوْلِهِ كَالسِّلْسِلَةِ عَلَى صَفْوَانٍ ـ قَالَ عَلِيٌّ وَقَالَ غَيْرُهُ صَفْوَانٍ ـ يَنْفُذُهُمْ ذَلِكَ فَإِذَا فُزِّعَ عَنْ قُلُوبِهِمْ قَالُوا مَاذَا قَالَ رَبُّكُمْ، قَالُوا لِلَّذِي قَالَ الْحَقَّ وَهْوَ الْعَلِيُّ الْكَبِيرُ، فَيَسْمَعُهَا مُسْتَرِقُو السَّمْعِ، وَمُسْتَرِقُو السَّمْعِ هَكَذَا وَاحِدٌ فَوْقَ آخَرَ ـ وَوَصَفَ سُفْيَانُ بِيَدِهِ، وَفَرَّجَ بَيْنَ أَصَابِعِ يَدِهِ الْيُمْنَى، نَصَبَهَا بَعْضَهَا فَوْقَ بَعْضٍ ـ فَرُبَّمَا أَدْرَكَ الشِّهَابُ الْمُسْتَمِعَ، قَبْلَ أَنْ يَرْمِيَ بِهَا إِلَى صَاحِبِهِ، فَيُحْرِقَهُ وَرُبَّمَا لَمْ يُدْرِكْهُ حَتَّى يَرْمِيَ بِهَا إِلَى الَّذِي يَلِيهِ إِلَى الَّذِي هُوَ أَسْفَلُ مِنْهُ حَتَّى يُلْقُوهَا إِلَى الأَرْضِ ـ وَرُبَّمَا قَالَ سُفْيَانُ حَتَّى تَنْتَهِيَ إِلَى الأَرْضِ ـ فَتُلْقَى عَلَى فَمِ السَّاحِرِ، فَيَكْذِبُ مَعَهَا مِائَةَ كَذْبَةٍ فَيَصْدُقُ، فَيَقُولُونَ أَلَمْ يُخْبِرْنَا يَوْمَ كَذَا وَكَذَا يَكُونُ كَذَا وَكَذَا، فَوَجَدْنَاهُ حَقًّا لِلْكَلِمَةِ الَّتِي سُمِعَتْ مِنَ السَّمَاءِ ‏"‏‏.‏ حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، إِذَا قَضَى اللَّهُ الأَمْرَ‏.‏ وَزَادَ الْكَاهِنِ‏.‏ وَحَدَّثَنَا سُفْيَانُ فَقَالَ قَالَ عَمْرٌو سَمِعْتُ عِكْرِمَةَ حَدَّثَنَا أَبُو هُرَيْرَةَ قَالَ إِذَا قَضَى اللَّهُ الأَمْرَ وَقَالَ عَلَى فَمِ السَّاحِرِ‏.‏ قُلْتُ لِسُفْيَانَ قَالَ سَمِعْتُ عِكْرِمَةَ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ‏.‏ قَالَ نَعَمْ‏.‏ قُلْتُ لِسُفْيَانَ إِنَّ إِنْسَانًا رَوَى عَنْكَ عَنْ عَمْرٍو عَنْ عِكْرِمَةَ عَنْ أَبِي هُرَيْرَةَ وَيَرْفَعُهُ أَنَّهُ قَرَأَ فُزِّعَ‏.‏ قَالَ سُفْيَانُ هَكَذَا قَرَأَ عَمْرٌو‏.‏ فَلاَ أَدْرِي سَمِعَهُ هَكَذَا أَمْ لاَ‏.‏ قَالَ سُفْيَانُ وَهْىَ قِرَاءَتُنَا‏.‏\hadithno{4701}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When Allah has ordained some affair in the Heaven, the angels beat with their wings in obedience to His statement, which sounds like a chain dragged over a rock." (`Ali and other sub-narrators said, "The sound reaches them.") "Until when fear is banished from their (angels) hearts, they (angels) say, 'What was it that your Lord said? They say, 'The truth; And He is the Most High, the Most Great.' (34.23) Then those who gain a hearing by stealing (i.e. devils) will hear Allah's Statement:-- 'Those who gain a hearing by stealing, (stand one over the other like this). (Sufyan, to illustrate this, spread the fingers of his right hand and placed them one over the other horizontally.) A flame may overtake and burn the eavesdropper before conveying the news to the one below him; or it may not overtake him till he has conveyed it to the one below him, who in his turn, conveys it to the one below him, and so on till they convey the news to the earth. (Or probably Sufyan said, "Till the news reaches the earth.") Then the news is inspired to a sorcerer who would add a hundred lies to it. His prophecy will prove true (as far as the heavenly news is concerned). The people will say. 'Didn't he tell us that on such-and-such a day, such-and-such a thing will happen? We have found that is true because of the true news heard from heaven." The above hadith is also narrated by Abu Huraira, starting: 'When Allah has ordained some affair...') In this narration the word foreteller is added to the word wizard}}
\hadithdefcmd{bukhari}{4702}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأَصْحَابِ الْحِجْرِ ‏ "‏ لاَ تَدْخُلُوا عَلَى هَؤُلاَءِ الْقَوْمِ إِلاَّ أَنْ تَكُونُوا بَاكِينَ فَإِنْ لَمْ تَكُونُوا بَاكِينَ فَلاَ تَدْخُلُوا عَلَيْهِمْ أَنْ يُصِيبَكُمْ مِثْلُ مَا أَصَابَهُمْ ‏"‏‏.‏\hadithno{4702}\hadithtrans{Narrated `Abdullah bin `Umar:(While we were going for the Battle of Tabuk and when we reached the places of the dwellers of Al- Hijr), Allah's Messenger (ﷺ) said about the dwellers of Al-Hijr (to us). "Do not enter (the dwelling places) of these people unless you enter weeping, but if you weep not, then do not enter upon them, lest you be afflicted with what they were afflicted with}}
\hadithdefcmd{bukhari}{4703}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى، قَالَ مَرَّ بِيَ النَّبِيُّ صلى الله عليه وسلم وَأَنَا أُصَلِّي فَدَعَانِي فَلَمْ آتِهِ حَتَّى صَلَّيْتُ ثُمَّ أَتَيْتُ فَقَالَ ‏"‏ مَا مَنَعَكَ أَنْ تَأْتِيَ ‏"‏‏.‏ فَقُلْتُ كُنْتُ أُصَلِّي‏.‏ فَقَالَ ‏"‏ أَلَمْ يَقُلِ اللَّهُ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا اسْتَجِيبُوا لِلَّهِ وَلِلرَّسُولِ‏\}‏ ثُمَّ قَالَ أَلاَ أُعَلِّمُكَ أَعْظَمَ سُورَةٍ فِي الْقُرْآنِ قَبْلَ أَنْ أَخْرُجَ مِنَ الْمَسْجِدِ ‏"‏ فَذَهَبَ النَّبِيُّ صلى الله عليه وسلم لِيَخْرُجَ مِنَ الْمَسْجِدِ فَذَكَّرْتُهُ فَقَالَ ‏"‏‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ هِيَ السَّبْعُ الْمَثَانِي وَالْقُرْآنُ الْعَظِيمُ الَّذِي أُوتِيتُهُ ‏"‏‏.‏\hadithno{4703}\hadithtrans{Narrated Abu Sa`id Al-Mualla:While I was praying, the Prophet (ﷺ) passed by and called me, but I did not go to him till I had finished my prayer. When I went to him, he said, "What prevented you from coming?" I said, "I was praying." He said, "Didn't Allah say" "O you who believes Give your response to Allah (by obeying Him) and to His Apostle." (8.24) Then he added, "Shall I tell you the most superior Sura in the Qur'an before I go out of the mosque?" When the Prophet (ﷺ) intended to go out (of the Mosque), I reminded him and he said, "That is: "Al hamdu-li l-lahi Rabbil-`alamin (Surat-al-fatiha)' which is the seven oft repeated verses (Al-Mathani) and the Grand Qur'an which has been given to me}}
\hadithdefcmd{bukhari}{4704}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمُّ الْقُرْآنِ هِيَ السَّبْعُ الْمَثَانِي وَالْقُرْآنُ الْعَظِيمُ ‏"‏‏.‏\hadithno{4704}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Um (substance) of the Qur'an is the seven oft-repeated verses (Al-Mathani) and is the Great Qur'an (i.e. Surat-al-Fatiha)}}
\hadithdefcmd{bukhari}{4705}{حَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما ‏\{‏الَّذِينَ جَعَلُوا الْقُرْآنَ عِضِينَ‏\}‏ قَالَ هُمْ أَهْلُ الْكِتَابِ، جَزَّءُوهُ أَجْزَاءً، فَآمَنُوا بِبَعْضِهِ وَكَفَرُوا بِبَعْضِهِ‏.‏\hadithno{4705}\hadithtrans{Narrated Ibn `Abbas:Those who have made their Scripture into parts are the people of the Scripture who divided it into portions and believed in a part of it and disbelieved the other}}
\hadithdefcmd{bukhari}{4706}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنِ الأَعْمَشِ، عَنْ أَبِي ظَبْيَانَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏كَمَا أَنْزَلْنَا عَلَى الْمُقْتَسِمِينَ‏\}‏ قَالَ آمَنُوا بِبَعْضٍ وَكَفَرُوا بِبَعْضٍ، الْيَهُودُ وَالنَّصَارَى‏.‏\hadithno{4706}\hadithtrans{Narrated Ibn `Abbas concerning:"As We have sent down (the Scripture) on those who are divided (Jews and Christians)." (15.90) They believed in part of it and disbelieved in the other, (and they) are the Jews and the Christians}}
\hadithdefcmd{bukhari}{4707}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَارُونُ بْنُ مُوسَى أَبُو عَبْدِ اللَّهِ الأَعْوَرُ، عَنْ شُعَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو ‏ "‏ أَعُوذُ بِكَ مِنَ الْبُخْلِ وَالْكَسَلِ، وَأَرْذَلِ الْعُمُرِ، وَعَذَابِ الْقَبْرِ، وَفِتْنَةِ الدَّجَّالِ، وَفِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏‏.‏\hadithno{4707}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) used to invoke thus: "O Allah! I seek refuge with You from miserliness, laziness; from old geriatric age the punishment in the grave; from the affliction of Ad-Dajjal; and from the afflictions of life and death}}
\hadithdefcmd{bukhari}{4708}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، قَالَ سَمِعْتُ ابْنَ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ فِي بَنِي إِسْرَائِيلَ وَالْكَهْفِ وَمَرْيَمَ إِنَّهُنَّ مِنَ الْعِتَاقِ الأُوَلِ، وَهُنَّ مِنْ تِلاَدِي‏.‏ قَالَ ابْنُ عَبَّاسٍ ‏\{‏فَسَيُنْغِضُونَ‏\}‏ يَهُزُّونَ‏.‏ وَقَالَ غَيْرُهُ نَغَضَتْ سِنُّكَ أَىْ تَحَرَّكَتْ‏.‏\hadithno{4708}\hadithtrans{Narrated Ibn Mas`ud:Surat Bani Israel and Al-Kahf and Mary are among my first old property}}
\hadithdefcmd{bukhari}{4709}{حَدَّثَنَا عَبْدَانُ، حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ ابْنُ الْمُسَيَّبِ قَالَ أَبُو هُرَيْرَةَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ بِإِيلِيَاءَ بِقَدَحَيْنِ مِنْ خَمْرٍ وَلَبَنٍ، فَنَظَرَ إِلَيْهِمَا فَأَخَذَ اللَّبَنَ قَالَ جِبْرِيلُ الْحَمْدُ لِلَّهِ الَّذِي هَدَاكَ لِلْفِطْرَةِ، لَوْ أَخَذْتَ الْخَمْرَ غَوَتْ أُمَّتُكَ‏.‏\hadithno{4709}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) was presented with two cups one containing wine and the other milk on the night of his night journey at Jerusalem. He looked at it and took the milk. Gabriel said, "Thanks to Allah Who guided you to the Fitra (i.e. Islam); if you had taken the wine, your followers would have gone astray}}
\hadithdefcmd{bukhari}{4710}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَبُو سَلَمَةَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لَمَّا كَذَّبَنِي قُرَيْشٌ قُمْتُ فِي الْحِجْرِ، فَجَلَّى اللَّهُ لِي بَيْتَ الْمَقْدِسِ فَطَفِقْتُ أُخْبِرُهُمْ عَنْ آيَاتِهِ وَأَنَا أَنْظُرُ إِلَيْهِ ‏"‏‏.‏ زَادَ يَعْقُوبُ بْنُ إِبْرَاهِيمَ حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ عَنْ عَمِّهِ ‏"‏ لَمَّا كَذَّبَنِي قُرَيْشٌ حِينَ أُسْرِيَ بِي إِلَى بَيْتِ الْمَقْدِسِ ‏"‏‏.‏ نَحْوَهُ‏.‏ ‏\{‏قَاصِفًا‏\}‏ رِيحٌ تَقْصِفُ كُلَّ شَىْءٍ‏.‏\hadithno{4710}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "When the Quraish disbelieved me (concerning my night journey), I stood up in Al- Hijr (the unroofed portion of the Ka`ba) and Allah displayed Bait-ul-Maqdis before me, and I started to inform them (Quraish) about its signs while looking at it}}
\hadithdefcmd{bukhari}{4711}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، أَخْبَرَنَا مَنْصُورٌ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا نَقُولُ لِلْحَىِّ إِذَا كَثُرُوا فِي الْجَاهِلِيَّةِ أَمِرَ بَنُو فُلاَنٍ‏.‏ حَدَّثَنَا الْحُمَيْدِيُّ حَدَّثَنَا سُفْيَانُ وَقَالَ أَمِرَ‏.‏\hadithno{4711}\hadithtrans{Narrated `Abdullah:During the Pre-Islamic period of ignorance if any tribe became great in number, we used to say, "Amira the children of so-and-so." Narrated Al-Humaidi: Sufyan narrated to us something and used the word 'Amira}}
\hadithdefcmd{bukhari}{4712}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا أَبُو حَيَّانَ التَّيْمِيُّ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلَحْمٍ، فَرُفِعَ إِلَيْهِ الذِّرَاعُ، وَكَانَتْ تُعْجِبُهُ، فَنَهَسَ مِنْهَا نَهْسَةً ثُمَّ قَالَ ‏ "‏ أَنَا سَيِّدُ النَّاسِ يَوْمَ الْقِيَامَةِ، وَهَلْ تَدْرُونَ مِمَّ ذَلِكَ يُجْمَعُ النَّاسُ الأَوَّلِينَ وَالآخِرِينَ فِي صَعِيدٍ وَاحِدٍ، يُسْمِعُهُمُ الدَّاعِي، وَيَنْفُذُهُمُ الْبَصَرُ، وَتَدْنُو الشَّمْسُ، فَيَبْلُغُ النَّاسَ مِنَ الْغَمِّ وَالْكَرْبِ مَا لاَ يُطِيقُونَ وَلاَ يَحْتَمِلُونَ فَيَقُولُ النَّاسُ أَلاَ تَرَوْنَ مَا قَدْ بَلَغَكُمْ أَلاَ تَنْظُرُونَ مَنْ يَشْفَعُ لَكُمْ إِلَى رَبِّكُمْ فَيَقُولُ بَعْضُ النَّاسِ لِبَعْضٍ عَلَيْكُمْ بِآدَمَ فَيَأْتُونَ آدَمَ عليه السلام فَيَقُولُونَ لَهُ أَنْتَ أَبُو الْبَشَرِ خَلَقَكَ اللَّهُ بِيَدِهِ‏.‏ وَنَفَخَ فِيكَ مِنْ رُوحِهِ، وَأَمَرَ الْمَلاَئِكَةَ فَسَجَدُوا لَكَ، اشْفَعْ لَنَا إِلَى رَبِّكَ، أَلاَ تَرَى إِلَى مَا نَحْنُ فِيهِ أَلاَ تَرَى إِلَى مَا قَدْ بَلَغَنَا فَيَقُولُ آدَمُ إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ، وَإِنَّهُ نَهَانِي عَنِ الشَّجَرَةِ فَعَصَيْتُهُ، نَفْسِي نَفْسِي نَفْسِي، اذْهَبُوا إِلَى غَيْرِي، اذْهَبُوا إِلَى نُوحٍ، فَيَأْتُونَ نُوحًا فَيَقُولُونَ يَا نُوحُ إِنَّكَ أَنْتَ أَوَّلُ الرُّسُلِ إِلَى أَهْلِ الأَرْضِ، وَقَدْ سَمَّاكَ اللَّهُ عَبْدًا شَكُورًا اشْفَعْ لَنَا إِلَى رَبِّكَ، أَلاَ تَرَى إِلَى مَا نَحْنُ فِيهِ فَيَقُولُ إِنَّ رَبِّي عَزَّ وَجَلَّ قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ، وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ، وَإِنَّهُ قَدْ كَانَتْ لِي دَعْوَةٌ دَعَوْتُهَا عَلَى قَوْمِي نَفْسِي نَفْسِي نَفْسِي اذْهَبُوا إِلَى غَيْرِي، اذْهَبُوا إِلَى إِبْرَاهِيمَ، فَيَأْتُونَ إِبْرَاهِيمَ، فَيَقُولُونَ يَا إِبْرَاهِيمُ، أَنْتَ نَبِيُّ اللَّهِ وَخَلِيلُهُ مِنْ أَهْلِ الأَرْضِ اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى إِلَى مَا نَحْنُ فِيهِ فَيَقُولُ لَهُمْ إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ، وَإِنِّي قَدْ كُنْتُ كَذَبْتُ ثَلاَثَ كَذَبَاتٍ ـ فَذَكَرَهُنَّ أَبُو حَيَّانَ فِي الْحَدِيثِ ـ نَفْسِي نَفْسِي نَفْسِي، اذْهَبُوا إِلَى غَيْرِي اذْهَبُوا إِلَى مُوسَى، فَيَأْتُونَ مُوسَى، فَيَقُولُونَ يَا مُوسَى أَنْتَ رَسُولُ اللَّهِ، فَضَّلَكَ اللَّهُ بِرِسَالَتِهِ وَبِكَلاَمِهِ عَلَى النَّاسِ، اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى إِلَى مَا نَحْنُ فِيهِ فَيَقُولُ إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ، وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ، وَإِنِّي قَدْ قَتَلْتُ نَفْسًا لَمْ أُومَرْ بِقَتْلِهَا، نَفْسِي نَفْسِي نَفْسِي، اذْهَبُوا إِلَى غَيْرِي، اذْهَبُوا إِلَى عِيسَى، فَيَأْتُونَ عِيسَى فَيَقُولُونَ يَا عِيسَى أَنْتَ رَسُولُ اللَّهِ وَكَلِمَتُهُ أَلْقَاهَا إِلَى مَرْيَمَ وَرُوحٌ مِنْهُ، وَكَلَّمْتَ النَّاسَ فِي الْمَهْدِ صَبِيًّا اشْفَعْ لَنَا أَلاَ تَرَى إِلَى مَا نَحْنُ فِيهِ فَيَقُولُ عِيسَى إِنَّ رَبِّي قَدْ غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ، وَلَنْ يَغْضَبَ بَعْدَهُ مِثْلَهُ ـ وَلَمْ يَذْكُرْ ذَنْبًا ـ نَفْسِي نَفْسِي نَفْسِي، اذْهَبُوا إِلَى غَيْرِي اذْهَبُوا إِلَى مُحَمَّدٍ صلى الله عليه وسلم فَيَأْتُونَ مُحَمَّدًا صلى الله عليه وسلم فَيَقُولُونَ يَا مُحَمَّدُ أَنْتَ رَسُولُ اللَّهِ وَخَاتَمُ الأَنْبِيَاءِ، وَقَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ، اشْفَعْ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى إِلَى مَا نَحْنُ فِيهِ فَأَنْطَلِقُ فَآتِي تَحْتَ الْعَرْشِ، فَأَقَعُ سَاجِدًا لِرَبِّي عَزَّ وَجَلَّ ثُمَّ يَفْتَحُ اللَّهُ عَلَىَّ مِنْ مَحَامِدِهِ وَحُسْنِ الثَّنَاءِ عَلَيْهِ شَيْئًا لَمْ يَفْتَحْهُ عَلَى أَحَدٍ قَبْلِي ثُمَّ يُقَالُ يَا مُحَمَّدُ ارْفَعْ رَأْسَكَ، سَلْ تُعْطَهْ، وَاشْفَعْ تُشَفَّعْ، فَأَرْفَعُ رَأْسِي، فَأَقُولُ أُمَّتِي يَا رَبِّ، أُمَّتِي يَا رَبِّ فَيُقَالُ يَا مُحَمَّدُ أَدْخِلْ مِنْ أُمَّتِكَ مَنْ لاَ حِسَابَ عَلَيْهِمْ مِنَ الْبَابِ الأَيْمَنِ مِنْ أَبْوَابِ الْجَنَّةِ وَهُمْ شُرَكَاءُ النَّاسِ فِيمَا سِوَى ذَلِكَ مِنَ الأَبْوَابِ، ثُمَّ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّ مَا بَيْنَ الْمِصْرَاعَيْنِ مِنْ مَصَارِيعِ الْجَنَّةِ كَمَا بَيْنَ مَكَّةَ وَحِمْيَرَ، أَوْ كَمَا بَيْنَ مَكَّةَ وَبُصْرَى ‏"‏‏.‏\hadithno{4712}\hadithtrans{Narrated Abu Huraira:Some (cooked) meat was brought to Allah's Apostle and the meat of a forearm was presented to him as he used to like it. He ate a morsel of it and said, "I will be the chief of all the people on the Day of Resurrection. Do you know the reason for it? Allah will gather all the human beings of early generations as well as late generations on one plain so that the announcer will be able to make them all hear his voice and the watcher will be able to see all of them. The sun will come so close to the people that they will suffer such distress and trouble as they will not be able to bear or stand. Then the people will say, 'Don't you see to what state you have reached? Won't you look for someone who can intercede for you with your Lord?' Some people will say to some others, 'Go to Adam.' So they will go to Adam and say to him, 'You are the father of mankind; Allah created you with His Own Hand, and breathed into you of His Spirit (meaning the spirit which He created for you); and ordered the angels to prostrate before you; so (please) intercede for us with your Lord. Don't you see in what state we are? Don't you see what condition we have reached?' Adam will say, 'Today my Lord has become angry as He has never become before, nor will ever become thereafter. He forbade me (to eat of the fruit of) the tree, but I disobeyed Him . Myself! Myself! Myself! (I am preoccuied with my own problems). Go to someone else; go to Noah.' So they will go to Noah and say (to him), 'O Noah! You are the first (of Allah's Messengers) to the people of the earth, and Allah has named you a thankful slave; please intercede for us with your Lord. Don't you see in what state we are?' He will say, 'Today my Lord has become angry as He has never become nor will ever become thereafter. I had (in the world) the right to make one definitely accepted invocation, and I made it against my nation. Myself! Myself! Myself! Go to someone else; go to Abraham.' They will go to Abraham and say, 'O Abraham! You are Allah's Messenger (ﷺ) and His Khalil from among the people of the earth; so please intercede for us with your Lord. Don't you see in what state we are?' He will say to them, 'My Lord has today become angry as He has never become before, nor will ever become thereafter. I had told three lies (Abu Haiyan (the sub-narrator) mentioned them in the Hadith) Myself! Myself! Myself! Go to someone else; go to Moses.' The people will then go to Moses and say, 'O Moses! You are Allah's Messenger (ﷺ) and Allah gave you superiority above the others with His message and with His direct Talk to you; (please) intercede for us with your Lord Don't you see in what state we are?' Moses will say, 'My Lord has today become angry as He has never become before, nor will become thereafter, I killed a person whom I had not been ordered to kill. Myself! Myself! Myself! Go to someone else; go to Jesus.' So they will go to Jesus and say, 'O Jesus! You are Allah's Messenger (ﷺ) and His Word which He sent to Mary, and a superior soul created by Him, and you talked to the people while still young in the cradle. Please intercede for us with your Lord. Don't you see in what state we are?' Jesus will say, 'My Lord has today become angry as He has never become before nor will ever become thereafter. Jesus will not mention any sin, but will say, 'Myself! Myself! Myself! Go to someone else; go to Muhammad.' So they will come to me and say, 'O Muhammad! You are Allah's Messenger (ﷺ) and the last of the prophets, and Allah forgave your early and late sins. (Please) intercede for us with your Lord. Don't you see in what state we are?" The Prophet (ﷺ) added, "Then I will go beneath Allah's Throne and fall in prostration before my Lord. And then Allah will guide me to such praises and glorification to Him as He has never guided anybody else before me. Then it will be said, 'O Muhammad Raise your head. Ask, and it will be granted. Intercede and It (your intercession) will be accepted.' So I will raise my head and Say, 'My followers, O my Lord! My followers, O my Lord'. It will be said, 'O Muhammad! Let those of your followers who have no accounts, enter through such a gate of the gates of Paradise as lies on the right; and they will share the other gates with the people." The Prophet (ﷺ) further said, "By Him in Whose Hand my soul is, the distance between every two gate-posts of Paradise is like the distance between Mecca and Busra (in Sham)}}
\hadithdefcmd{bukhari}{4713}{حَدَّثَنِي إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خُفِّفَ عَلَى دَاوُدَ الْقِرَاءَةُ، فَكَانَ يَأْمُرُ بِدَابَّتِهِ لِتُسْرَجَ، فَكَانَ يَقْرَأُ قَبْلَ أَنْ يَفْرُغَ ‏"‏‏.‏ يَعْنِي الْقُرْآنَ‏.‏\hadithno{4713}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The recitation of Psalms (David's Qur'an) was made light and easy for David that he used to have his ridding animal be saddled while he would finish the recitation before the servant had saddled it}}
\hadithdefcmd{bukhari}{4714}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي سُلَيْمَانُ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، ‏\{‏إِلَى رَبِّهِمِ الْوَسِيلَةَ‏\}‏ قَالَ كَانَ نَاسٌ مِنَ الإِنْسِ يَعْبُدُونَ نَاسًا مِنَ الْجِنِّ، فَأَسْلَمَ الْجِنُّ، وَتَمَسَّكَ هَؤُلاَءِ بِدِينِهِمْ‏.‏ زَادَ الأَشْجَعِيُّ عَنْ سُفْيَانَ عَنِ الأَعْمَشِ‏.‏ ‏\{‏قُلِ ادْعُوا الَّذِينَ زَعَمْتُمْ‏\}‏\hadithno{4714}\hadithtrans{Narrated `Abdullah:Regarding the explanation of the Verse: 'Those whom they call upon (worship) (like Jesus the Son of Mary, angels etc.) desire (for themselves) means of access to their Lord (Allah) as to which of them should be the nearer and they hope for His Mercy and fear His torment.' (17.57) They themselves (e.g. Angels, saints, Apostles, Jesus, etc.,) worshipped Allah, Those Jinns who were worshipped by some Arabs became Muslims (embraced Islam), but those human beings stuck to their (old) religion. Al- A`mash said extra: 'Say, (O Muhammad): Call unto those besides Him whom you assume (to be gods)}}
\hadithdefcmd{bukhari}{4715}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ فِي هَذِهِ الآيَةِ ‏\{‏الَّذِينَ يَدْعُونَ يَبْتَغُونَ إِلَى رَبِّهِمِ الْوَسِيلَةَ‏\}‏ قَالَ نَاسٌ مِنَ الْجِنِّ ‏\{‏كَانُوا‏\}‏ يُعْبَدُونَ فَأَسْلَمُوا‏.‏\hadithno{4715}\hadithtrans{Narrated `Abdullah:Regarding the Verse: 'Those whom they call upon (worship) (like Jesus the Son of Mary or angels etc.) desire (for themselves) means of access, to their Lord....' (17.57) (It was revealed regarding) some Jinns who used to be worshipped (by human beings). They later embraced Islam (while those people kept on worshipping them)}}
\hadithdefcmd{bukhari}{4716}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنه ـ ‏\{‏وَمَا جَعَلْنَا الرُّؤْيَا الَّتِي أَرَيْنَاكَ إِلاَّ فِتْنَةً لِلنَّاسِ‏\}‏ قَالَ هِيَ رُؤْيَا عَيْنٍ أُرِيَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ ‏\{‏وَالشَّجَرَةَ الْمَلْعُونَةَ‏\}‏ شَجَرَةُ الزَّقُّومِ‏.‏\hadithno{4716}\hadithtrans{Narrated Ibn `Abbas:Regarding: 'And We granted the vision (Ascension to the Heaven "Miraj") which We showed you (O Muhammad as an actual eye witness) but as a trial for mankind.' (17.60) It was an actual eyewitness which was shown to Allah's Messenger (ﷺ) during the night he was taken on a journey (through the heavens). And the cursed tree is the tree of Az-Zaqqum (a bitter pungent tree which grows at the bottom of Hell)}}
\hadithdefcmd{bukhari}{4717}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، وَابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ فَضْلُ صَلاَةِ الْجَمِيعِ عَلَى صَلاَةِ الْوَاحِدِ خَمْسٌ وَعِشْرُونَ دَرَجَةً، وَتَجْتَمِعُ مَلاَئِكَةُ اللَّيْلِ وَمَلاَئِكَةُ النَّهَارِ فِي صَلاَةِ الصُّبْحِ ‏"‏‏.‏ يَقُولُ أَبُو هُرَيْرَةَ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏وَقُرْآنَ الْفَجْرِ إِنَّ قُرْآنَ الْفَجْرِ كَانَ مَشْهُودًا‏\}‏\hadithno{4717}\hadithtrans{Narrated Ibn Al-Musaiyab:Abu Huraira said, "The Prophet (ﷺ) said, 'A prayer performed in congregation is twenty-five times more superior in reward to a prayer performed by a single person. The angels of the night and the angels of the day are assembled at the time of the Fajr (Morning) prayer." Abu Huraira added, "If you wish, you can recite:-- 'Verily! The recitation of the Qur'an in the early dawn (Morning prayer) is ever witnessed (attended by the angels of the day and the night)}}
\hadithdefcmd{bukhari}{4718}{حَدَّثَنِي إِسْمَاعِيلُ بْنُ أَبَانَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ آدَمَ بْنِ عَلِيٍّ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، رضى الله عنهما يَقُولُ إِنَّ النَّاسَ يَصِيرُونَ يَوْمَ الْقِيَامَةِ جُثًا، كُلُّ أُمَّةٍ تَتْبَعُ نَبِيَّهَا، يَقُولُونَ يَا فُلاَنُ اشْفَعْ، حَتَّى تَنْتَهِيَ الشَّفَاعَةُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَذَلِكَ يَوْمَ يَبْعَثُهُ اللَّهُ الْمَقَامَ الْمَحْمُودَ‏.‏\hadithno{4718}\hadithtrans{Narrated Ibn `Umar:On the Day of Resurrection the people will fall on their knees and every nation will follow their prophet and they will say, "O so-and-so! Intercede (for us with Allah), "till (the right) intercession is given to the Prophet (Muhammad) and that will be the day when Allah will raise him into a station of praise and glory (i.e. Al-Maqam -al-Mahmud)}}
\hadithdefcmd{bukhari}{4719}{حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يَسْمَعُ النِّدَاءَ اللَّهُمَّ رَبَّ هَذِهِ الدَّعْوَةِ التَّامَّةِ وَالصَّلاَةِ الْقَائِمَةِ، آتِ مُحَمَّدًا الْوَسِيلَةَ وَالْفَضِيلَةَ، وَابْعَثْهُ مَقَامًا مَحْمُودًا الَّذِي وَعَدْتَهُ، حَلَّتْ لَهُ شَفَاعَتِي يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ رَوَاهُ حَمْزَةُ بْنُ عَبْدِ اللَّهِ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{4719}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "Whoever, after listening to the Adhan (for the prayer) says, 'O Allah, the Lord of this complete call and of this prayer, which is going to be established! Give Muhammad Al-Wasila and Al-Fadila and raise him to Al-Maqam-al-Mahmud which You have promised him,' will be granted my intercession for him on the Day of Resurrection}}
\hadithdefcmd{bukhari}{4720}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ وَحَوْلَ الْبَيْتِ سِتُّونَ وَثَلاَثُمِائَةِ نُصُبٍ فَجَعَلَ يَطْعُنُهَا بِعُودٍ فِي يَدِهِ وَيَقُولُ ‏\{‏جَاءَ الْحَقُّ وَزَهَقَ الْبَاطِلُ إِنَّ الْبَاطِلَ كَانَ زَهُوقًا‏\}‏ ‏\{‏جَاءَ الْحَقُّ وَمَا يُبْدِئُ الْبَاطِلُ وَمَا يُعِيدُ‏\}‏\hadithno{4720}\hadithtrans{Narrated `Abdullah bin Masud:Allah's Messenger (ﷺ) entered Mecca (in the year of the Conquest) and there were three-hundred and sixty idols around the Ka`ba. He then started hitting them with a stick in his hand and say: 'Truth (i.e. Islam) has come and falsehood (disbelief) vanished. Truly falsehood (disbelief) is ever bound to vanish.' (17.81) 'Truth has come and falsehood (Iblis) can not create anything}}
\hadithdefcmd{bukhari}{4721}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ بَيْنَا أَنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَرْثٍ وَهْوَ مُتَّكِئٌ عَلَى عَسِيبٍ إِذْ مَرَّ الْيَهُودُ، فَقَالَ بَعْضُهُمْ لِبَعْضٍ سَلُوهُ عَنِ الرُّوحِ، فَقَالَ مَا رَابَكُمْ إِلَيْهِ، وَقَالَ بَعْضُهُمْ لاَ يَسْتَقْبِلُكُمْ بِشَىْءٍ تَكْرَهُونَهُ فَقَالُوا سَلُوهُ فَسَأَلُوهُ عَنِ الرُّوحِ فَأَمْسَكَ النَّبِيُّ صلى الله عليه وسلم فَلَمْ يَرُدَّ عَلَيْهِمْ شَيْئًا، فَعَلِمْتُ أَنَّهُ يُوحَى إِلَيْهِ، فَقُمْتُ مَقَامِي، فَلَمَّا نَزَلَ الْوَحْىُ قَالَ ‏\{‏وَيَسْأَلُونَكَ عَنِ الرُّوحِ قُلِ الرُّوحُ مِنْ أَمْرِ رَبِّي وَمَا أُوتِيتُمْ مِنَ الْعِلْمِ إِلاَّ قَلِيلاً‏\}‏‏.‏\hadithno{4721}\hadithtrans{Narrated `Abdullah:While I was in the company of the Prophet (ﷺ) on a farm and he was reclining on a palm leaf stalk, some Jews passed by. Some of them said to the others. "Ask him (the Prophet (ﷺ) about the spirit." Some of them said, "What urges you to ask him about it" Others said, "(Don't) lest he should give you a reply which you dislike." But they said, "Ask him." So they asked him about the Spirit. The Prophet (ﷺ) kept quiet and did not give them any answer. I knew that he was being divinely inspired so I stayed at my place. When the divine inspiration had been revealed, the Prophet (ﷺ) said. "They ask you (O, Muhammad) concerning the Spirit, Say: "The spirit," its knowledge is with my Lord; and of knowledge you (mankind) have been given only a Little}}
\hadithdefcmd{bukhari}{4722}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ فِي قَوْلِهِ تَعَالَى ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏ قَالَ نَزَلَتْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُخْتَفٍ بِمَكَّةَ، كَانَ إِذَا صَلَّى بِأَصْحَابِهِ رَفَعَ صَوْتَهُ بِالْقُرْآنِ فَإِذَا سَمِعَهُ الْمُشْرِكُونَ سَبُّوا الْقُرْآنَ وَمَنْ أَنْزَلَهُ، وَمَنْ جَاءَ بِهِ، فَقَالَ اللَّهُ تَعَالَى لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ‏\}‏ أَىْ بِقِرَاءَتِكَ، فَيَسْمَعَ الْمُشْرِكُونَ، فَيَسُبُّوا الْقُرْآنَ، ‏\{‏وَلاَ تُخَافِتْ بِهَا‏\}‏ عَنْ أَصْحَابِكَ فَلاَ تُسْمِعُهُمْ ‏\{‏وَابْتَغِ بَيْنَ ذَلِكَ سَبِيلاً‏\}‏‏.‏\hadithno{4722}\hadithtrans{Narrated Ibn `Abbas:(regarding): 'Neither say your, prayer aloud, nor say it in a low tone.' (17.110) This Verse was revealed while Allah's Messenger (ﷺ) was hiding himself in Mecca. When he prayed with his companions, he used to raise his voice with the recitation of Qur'an, and if the pagans happened to hear him, they would abuse the Qur'an, the One who revealed it and the one who brought it. Therefore Allah said to His Prophet : 'Neither say your prayer aloud.' (17.110) i.e. do not recite aloud lest the pagans should hear you, but follow a way between}}
\hadithdefcmd{bukhari}{4723}{حَدَّثَنِي طَلْقُ بْنُ غَنَّامٍ، حَدَّثَنَا زَائِدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أُنْزِلَ ذَلِكَ فِي الدُّعَاءِ‏.‏\hadithno{4723}\hadithtrans{Narrated Aisha:The (above) verse was revealed in connection with the invocations}}
\hadithdefcmd{bukhari}{4724}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ حُسَيْنَ بْنَ عَلِيٍّ، أَخْبَرَهُ عَنْ عَلِيٍّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَرَقَهُ وَفَاطِمَةَ قَالَ ‏"‏ أَلاَ تُصَلِّيَانِ ‏"‏‏.‏ ‏\{‏رَجْمًا بِالْغَيْبِ‏\}‏ لَمْ يَسْتَبِنْ‏.‏ ‏\{‏فُرُطًا‏\}‏ نَدَمًا ‏\{‏سُرَادِقُهَا‏\}‏ مِثْلُ السُّرَادِقِ، وَالْحُجْرَةِ الَّتِي تُطِيفُ بِالْفَسَاطِيطِ، ‏\{‏يُحَاوِرُهُ‏\}‏ مِنَ الْمُحَاوَرَةِ ‏\{‏لَكِنَّا هُوَ اللَّهُ رَبِّي‏\}‏ أَىْ لَكِنْ أَنَا هُوَ اللَّهُ رَبِّي ثُمَّ حَذَفَ الأَلِفَ وَأَدْغَمَ إِحْدَى النُّونَيْنِ فِي الأُخْرَى‏.‏ ‏\{‏زَلَقًا‏\}‏ لاَ يَثْبُتُ فِيهِ قَدَمٌ‏.‏ ‏\{‏هُنَالِكَ الْوَلاَيَةُ‏\}‏ مَصْدَرُ الْوَلِيِّ‏.‏ ‏\{‏عُقُبًا‏\}‏ عَاقِبَةٌ وَعُقْبَى وَعُقْبَةٌ وَاحِدٌ وَهْىَ الآخِرَةُ قِبَلاً وَقُبُلاً وَقَبَلاً اسْتِئْنَافًا ‏\{‏لِيُدْحِضُوا‏\}‏ لِيُزِيلُوا، الدَّحْضُ الزَّلَقُ‏.‏\hadithno{4724}\hadithtrans{Narrated `Ali:That one night Allah's Messenger (ﷺ) came to him and Fatima and said, "Don't you (both offer the (Tahajjud) prayer?" `Ali said, 'When Allah wishes us to get up, we get up." The Prophet (ﷺ) then recited: 'But man is more quarrelsome than anything.' (18.54) (See Hadith No. 227,Vol)}}
\hadithdefcmd{bukhari}{4725}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ إِنَّ نَوْفًا الْبَكَالِيَّ يَزْعُمُ أَنَّ مُوسَى صَاحِبَ الْخَضِرِ لَيْسَ هُوَ مُوسَى صَاحِبَ بَنِي إِسْرَائِيلَ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ كَذَبَ عَدُوُّ اللَّهِ حَدَّثَنِي أُبَىُّ بْنُ كَعْبٍ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ مُوسَى قَامَ خَطِيبًا فِي بَنِي إِسْرَائِيلَ فَسُئِلَ أَىُّ النَّاسِ أَعْلَمُ فَقَالَ أَنَا فَعَتَبَ اللَّهُ عَلَيْهِ، إِذْ لَمْ يَرُدَّ الْعِلْمَ إِلَيْهِ فَأَوْحَى اللَّهُ إِلَيْهِ إِنَّ لِي عَبْدًا بِمَجْمَعِ الْبَحْرَيْنِ، هُوَ أَعْلَمُ مِنْكَ قَالَ مُوسَى يَا رَبِّ فَكَيْفَ لِي بِهِ قَالَ تَأْخُذُ مَعَكَ حُوتًا فَتَجْعَلُهُ فِي مِكْتَلٍ، فَحَيْثُمَا فَقَدْتَ الْحُوتَ فَهْوَ ثَمَّ، فَأَخَذَ حُوتًا فَجَعَلَهُ فِي مِكْتَلٍ ثُمَّ انْطَلَقَ، وَانْطَلَقَ مَعَهُ بِفَتَاهُ يُوشَعَ بْنِ نُونٍ، حَتَّى إِذَا أَتَيَا الصَّخْرَةَ وَضَعَا رُءُوسَهُمَا فَنَامَا، وَاضْطَرَبَ الْحُوتُ فِي الْمِكْتَلِ، فَخَرَجَ مِنْهُ، فَسَقَطَ فِي الْبَحْرِ فَاتَّخَذَ سَبِيلَهُ فِي الْبَحْرِ سَرَبًا، وَأَمْسَكَ اللَّهُ عَنِ الْحُوتِ جِرْيَةَ الْمَاءِ فَصَارَ عَلَيْهِ مِثْلَ الطَّاقِ فَلَمَّا اسْتَيْقَظَ، نَسِيَ صَاحِبُهُ أَنْ يُخْبِرَهُ بِالْحُوتِ، فَانْطَلَقَا بَقِيَّةَ يَوْمِهِمَا وَلَيْلَتَهُمَا، حَتَّى إِذَا كَانَ مِنَ الْغَدِ قَالَ مُوسَى لِفَتَاهُ آتِنَا غَدَاءَنَا لَقَدْ لَقِينَا مِنْ سَفَرِنَا هَذَا نَصَبًا قَالَ وَلَمْ يَجِدْ مُوسَى النَّصَبَ حَتَّى جَاوَزَ الْمَكَانَ الَّذِي أَمَرَ اللَّهُ بِهِ فَقَالَ لَهُ فَتَاهُ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ وَمَا أَنْسَانِيهِ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ، وَاتَّخَذَ سَبِيلَهُ فِي الْبَحْرِ عَجَبًا قَالَ فَكَانَ لِلْحُوتِ سَرَبًا وَلِمُوسَى وَلِفَتَاهُ عَجَبًا فَقَالَ مُوسَى ذَلِكَ مَا كُنَّا نَبْغِي فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا قَالَ رَجَعَا يَقُصَّانِ آثَارَهُمَا حَتَّى انْتَهَيَا إِلَى الصَّخْرَةِ، فَإِذَا رَجُلٌ مُسَجًّى ثَوْبًا، فَسَلَّمَ عَلَيْهِ مُوسَى‏.‏ فَقَالَ الْخَضِرُ وَأَنَّى بِأَرْضِكَ السَّلاَمُ قَالَ أَنَا مُوسَى‏.‏ قَالَ مُوسَى بَنِي إِسْرَائِيلَ قَالَ نَعَمْ أَتَيْتُكَ لِتُعَلِّمَنِي مِمَّا عُلِّمْتَ رَشَدًا‏.‏ قَالَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِي صَبْرًا، يَا مُوسَى إِنِّي عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ عَلَّمَنِيهِ لاَ تَعْلَمُهُ أَنْتَ وَأَنْتَ عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ عَلَّمَكَ اللَّهُ لاَ أَعْلَمُهُ‏.‏ فَقَالَ مُوسَى سَتَجِدُنِي إِنْ شَاءَ اللَّهُ صَابِرًا، وَلاَ أَعْصِي لَكَ أَمْرًا‏.‏ فَقَالَ لَهُ الْخَضِرُ، فَإِنِ اتَّبَعْتَنِي فَلاَ تَسْأَلْنِي عَنْ شَىْءٍ حَتَّى أُحْدِثَ لَكَ مِنْهُ ذِكْرًا، فَانْطَلَقَا يَمْشِيَانِ عَلَى سَاحِلِ الْبَحْرِ، فَمَرَّتْ سَفِينَةٌ فَكَلَّمُوهُمْ أَنْ يَحْمِلُوهُمْ، فَعَرَفُوا الْخَضِرَ، فَحَمَلُوهُ بِغَيْرِ نَوْلٍ فَلَمَّا رَكِبَا فِي السَّفِينَةِ، لَمْ يَفْجَأْ إِلاَّ وَالْخَضِرُ قَدْ قَلَعَ لَوْحًا مِنْ أَلْوَاحِ السَّفِينَةِ بِالْقَدُومِ‏.‏ فَقَالَ لَهُ مُوسَى قَوْمٌ حَمَلُونَا بِغَيْرِ نَوْلٍ، عَمَدْتَ إِلَى سَفِينَتِهِمْ فَخَرَقْتَهَا لِتُغْرِقَ أَهْلَهَا لَقَدْ جِئْتَ شَيْئًا إِمْرًا‏.‏ قَالَ أَلَمْ أَقُلْ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِي صَبْرًا‏.‏ قَالَ لاَ تُؤَاخِذْنِي بِمَا نَسِيتُ وَلاَ تُرْهِقْنِي مِنْ أَمْرِي عُسْرًا ‏"‏‏.‏ قَالَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَكَانَتِ الأُولَى مِنْ مُوسَى نِسْيَانًا قَالَ وَجَاءَ عُصْفُورٌ فَوَقَعَ عَلَى حَرْفِ السَّفِينَةِ فَنَقَرَ فِي الْبَحْرِ نَقْرَةً، فَقَالَ لَهُ الْخَضِرُ مَا عِلْمِي وَعِلْمُكَ مِنْ عِلْمِ اللَّهِ إِلاَّ مِثْلُ مَا نَقَصَ هَذَا الْعُصْفُورُ مِنْ هَذَا الْبَحْرِ ثُمَّ خَرَجَا مِنَ السَّفِينَةِ، فَبَيْنَا هُمَا يَمْشِيَانِ عَلَى السَّاحِلِ، إِذْ أَبْصَرَ الْخَضِرُ غُلاَمًا يَلْعَبُ مَعَ الْغِلْمَانِ، فَأَخَذَ الْخَضِرُ رَأْسَهُ بِيَدِهِ فَاقْتَلَعَهُ بِيَدِهِ فَقَتَلَهُ‏.‏ فَقَالَ لَهُ مُوسَى أَقَتَلْتَ نَفْسًا زَاكِيَةً بِغَيْرِ نَفْسٍ لَقَدْ جِئْتَ شَيْئًا نُكْرًا‏.‏ قَالَ أَلَمْ أَقُلْ لَكَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِي صَبْرًا قَالَ وَهَذَا أَشَدُّ مِنَ الأُولَى، قَالَ إِنْ سَأَلْتُكَ عَنْ شَىْءٍ بَعْدَهَا فَلاَ تُصَاحِبْنِي قَدْ بَلَغْتَ مِنْ لَدُنِّي عُذْرًا فَانْطَلَقَا حَتَّى إِذَا أَتَيَا أَهْلَ قَرْيَةٍ اسْتَطْعَمَا أَهْلَهَا فَأَبَوْا أَنْ يُضَيِّفُوهُمَا فَوَجَدَا فِيهَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ ـ قَالَ مَائِلٌ ـ فَقَامَ الْخَضِرُ فَأَقَامَهُ بِيَدِهِ فَقَالَ مُوسَى قَوْمٌ أَتَيْنَاهُمْ فَلَمْ يُطْعِمُونَا، وَلَمْ يُضَيِّفُونَا، لَوْ شِئْتَ لاَتَّخَذْتَ عَلَيْهِ أَجْرًا‏.‏ قَالَ ‏\{‏هَذَا فِرَاقُ بَيْنِي وَبَيْنِكَ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ذَلِكَ تَأْوِيلُ مَا لَمْ تَسْطِعْ عَلَيْهِ صَبْرًا‏\}‏‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَدِدْنَا أَنَّ مُوسَى كَانَ صَبَرَ حَتَّى يَقُصَّ اللَّهُ عَلَيْنَا مِنْ خَبَرِهِمَا ‏"‏‏.‏ قَالَ سَعِيدُ بْنُ جُبَيْرٍ فَكَانَ ابْنُ عَبَّاسٍ يَقْرَأُ وَكَانَ أَمَامَهُمْ مَلِكٌ يَأْخُذُ كُلَّ سَفِينَةٍ صَالِحَةٍ غَصْبًا، وَكَانَ يَقْرَأُ وَأَمَّا الْغُلاَمُ فَكَانَ كَافِرًا وَكَانَ أَبَوَاهُ مُؤْمِنَيْنِ‏.‏\hadithno{4725}\hadithtrans{Narrated Sa`id bin Jubair:I said to Ibn `Abbas, "Nauf Al-Bikali claims that Moses, the companion of Al-Khadir was not the Moses of the children of Israel" Ibn `Abbas said, "The enemy of Allah (Nauf) told a lie." Narrated Ubai bin Ka`b that he heard Allah's Messenger (ﷺ) saying, "Moses got up to deliver a speech before the children of Israel and he was asked, Who is the most learned person among the people?' Moses replied, 'I (am the most learned).' Allah admonished him for he did not ascribe knowledge to Allah alone. So Allah revealed to him: 'At the junction of the two seas there is a slave of Ours who is more learned than you.' Moses asked, 'O my Lord, how can I meet him?' Allah said, 'Take a fish and put it in a basket (and set out), and where you, will lose the fish, you will find him.' So Moses (took a fish and put it in a basket and) set out, along with his boy-servant Yusha` bin Noon, till they reached a rock (on which) they both lay their heads and slept. The fish moved vigorously in the basket and got out of it and fell into the sea and there it took its way through the sea (straight) as in a tunnel). (18.61) Allah stopped the current of water on both sides of the way created by the fish, and so that way was like a tunnel. When Moses got up, his companion forgot to tell him about the fish, and so they carried on their journey during the rest of the day and the whole night. The next morning Moses asked his boy-servant 'Bring us our early meal; no doubt, we have suffered much fatigue in this journey of ours.' (18.62) Moses did not get tired till he had passed the place which Allah had ordered him to seek after. His boy-servant then said to him,' 'Do you remember when we be-took ourselves to the rock I indeed forgot the fish, none but Satan made me forget to remember it. It took its course into the sea in a marvelous way.' (18.63) There was a tunnel for the fish and for Moses and his boy-servant there was astonishment. Moses said, 'That is what we have been seeking'. So they went back retracing their footsteps. (18.64) They both returned, retracing their steps till they reached the rock. Behold ! There they found a man covered with a garment. Moses greeted him. Al-Khadir said astonishingly, 'Is there such a greeting in your land?' Moses said, 'I am Moses.' He said, 'Are you the Moses of the children of Israel?' Moses said, 'I have come to you so that you may teach me of what you have been taught. Al-Khadir said, 'You will not be able to have patience with me. (18.66) O Moses! I have some of Allah's knowledge which He has bestowed upon me but you do not know it; and you too, have some of Allah's knowledge which He has bestowed upon you, but I do not know it." Moses said, "Allah willing, you will find me patient, and I will not disobey you in anything.' (18.6) Al-Khadir said to him, 'If you then follow me, do not ask me about anything until I myself speak to you concerning it.' (18.70), After that both of them proceeded along the sea coast, till a boat passed by and they requested the crew to let them go on board. The crew recognized Al-Khadir and allowed them to get on board free of charge. When they got on board suddenly Moses saw that Al-Khadir had pulled out one of the planks of the boat with an adze. Moses said to him.' These people gave us a free lift, yet you have scuttled their boat so as to drown its people! Truly, you have done a dreadful thing.' (18.71) Al-Khadir said, 'Didn't I say that you can have no patience with me ?' (18.72) Moses said, 'Call me not to account for what I forgot and be not hard upon me for my affair (with you.)" (18.73) Allah's Messenger (ﷺ) said, "The first excuse given by Moses, was that he had forgotten. Then a sparrow came and sat over the edge of the boat and dipped its beak once in the sea. Al-Khadir said to Moses, 'My knowledge and your knowledge, compared to Allah's knowledge is like what this sparrow has taken out of the sea.' Then they both got out of the boat, and while they were walking on the sea shore, Al-Khadir saw a boy playing with other boys. Al-Khadir got hold of the head of that boy and pulled it out with his hands and killed him. Moses said, 'Have you killed an innocent soul who has killed nobody! Truly, you have done an illegal thing.' (18.74) He said, "Didn't I tell you that you can have no patience with me?' (18.75) (The sub narrator said, the second blame was stronger than the first one.) Moses said, 'If I ask you about anything after this, keep me not in your company, you have received an excuse from me.' (18.76) Then they both proceeded until they came to the inhabitants of a town. They asked them for food but they refused to entertain them. (In that town) they found there a wall on the point of falling down. (18.77) Al-Khadir set it up straight with his own hands. Moses said, 'These are people to whom we came, but they neither fed us nor received us as guests. If you had wished, you could surely have exacted some recompense for it. Al-Khadir said, 'This is the parting between me and you ..that is the interpretation of (those things) over which you were unable to hold patience.' (18.78-82) Allah's Messenger (ﷺ) said, "We wished that Moses could have been more patient so that Allah might have described to us more about their story}}
\hadithdefcmd{bukhari}{4726}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي يَعْلَى بْنُ مُسْلِمٍ، وَعَمْرُو بْنُ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، يَزِيدُ أَحَدُهُمَا عَلَى صَاحِبِهِ وَغَيْرَهُمَا قَدْ سَمِعْتُهُ يُحَدِّثُهُ عَنْ سَعِيدٍ قَالَ إِنَّا لَعِنْدَ ابْنِ عَبَّاسٍ فِي بَيْتِهِ، إِذْ قَالَ سَلُونِي قُلْتُ أَىْ أَبَا عَبَّاسٍ ـ جَعَلَنِي اللَّهُ فِدَاكَ ـ بِالْكُوفَةِ رَجُلٌ قَاصٌّ يُقَالُ لَهُ نَوْفٌ، يَزْعُمُ أَنَّهُ لَيْسَ بِمُوسَى بَنِي إِسْرَائِيلَ، أَمَّا عَمْرٌو فَقَالَ لِي قَالَ قَدْ كَذَبَ عَدُوُّ اللَّهِ، وَأَمَّا يَعْلَى فَقَالَ لِي قَالَ ابْنُ عَبَّاسٍ حَدَّثَنِي أُبَىُّ بْنُ كَعْبٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مُوسَى رَسُولُ اللَّهِ ـ عَلَيْهِ السَّلاَمُ ـ قَالَ ذَكَّرَ النَّاسَ يَوْمًا حَتَّى إِذَا فَاضَتِ الْعُيُونُ، وَرَقَّتِ الْقُلُوبُ وَلَّى، فَأَدْرَكَهُ رَجُلٌ، فَقَالَ أَىْ رَسُولَ اللَّهِ هَلْ فِي الأَرْضِ أَحَدٌ أَعْلَمُ مِنْكَ قَالَ لاَ، فَعَتَبَ عَلَيْهِ إِذْ لَمْ يَرُدَّ الْعِلْمَ إِلَى اللَّهِ قِيلَ بَلَى قَالَ أَىْ رَبِّ فَأَيْنَ قَالَ بِمَجْمَعِ الْبَحْرَيْنِ قَالَ أَىْ رَبِّ اجْعَلْ لِي عَلَمًا أَعْلَمُ ذَلِكَ بِهِ ‏"‏‏.‏ فَقَالَ لِي عَمْرٌو قَالَ ‏"‏ حَيْثُ يُفَارِقُكَ الْحُوتُ ‏"‏‏.‏ وَقَالَ لِي يَعْلَى قَالَ ‏"‏ خُذْ نُونًا مَيِّتًا حَيْثُ يُنْفَخُ فِيهِ الرُّوحُ، فَأَخَذَ حُوتًا فَجَعَلَهُ فِي مِكْتَلٍ فَقَالَ لِفَتَاهُ لاَ أُكَلِّفُكَ إِلاَّ أَنْ تُخْبِرَنِي بِحَيْثُ يُفَارِقُكَ الْحُوتُ‏.‏ قَالَ مَا كَلَّفْتَ كَثِيرًا فَذَلِكَ قَوْلُهُ جَلَّ ذِكْرُهُ ‏\{‏وَإِذْ قَالَ مُوسَى لِفَتَاهُ‏\}‏ يُوشَعَ بْنِ نُونٍ ـ لَيْسَتْ عَنْ سَعِيدٍ ـ قَالَ فَبَيْنَمَا هُوَ فِي ظِلِّ صَخْرَةٍ فِي مَكَانٍ ثَرْيَانَ، إِذْ تَضَرَّبَ الْحُوتُ، وَمُوسَى نَائِمٌ، فَقَالَ فَتَاهُ لاَ أُوقِظُهُ حَتَّى إِذَا اسْتَيْقَظَ نَسِيَ أَنْ يُخْبِرَهُ، وَتَضَرَّبَ الْحُوتُ، حَتَّى دَخَلَ الْبَحْرَ فَأَمْسَكَ اللَّهُ عَنْهُ جِرْيَةَ الْبَحْرِ حَتَّى كَأَنَّ أَثَرَهُ فِي حَجَرٍ ـ قَالَ لِي عَمْرٌو هَكَذَا كَأَنَّ أَثَرَهُ فِي حَجَرٍ، وَحَلَّقَ بَيْنَ إِبْهَامَيْهِ وَاللَّتَيْنِ تَلِيانِهِمَا ـ لَقَدْ لَقِينَا مِنْ سَفَرِنَا هَذَا نَصَبًا قَالَ قَدْ قَطَعَ اللَّهُ عَنْكَ النَّصَبَ ـ لَيْسَتْ هَذِهِ عَنْ سَعِيدٍ ـ أَخْبَرَهُ، فَرَجَعَا فَوَجَدَا خَضِرًا ـ قَالَ لِي عُثْمَانُ بْنُ أَبِي سُلَيْمَانَ ـ عَلَى طِنْفِسَةٍ خَضْرَاءَ عَلَى كَبِدِ الْبَحْرِ ـ قَالَ سَعِيدُ بْنُ جُبَيْرٍ ـ مُسَجًّى بِثَوْبِهِ قَدْ جَعَلَ طَرَفَهُ تَحْتَ رِجْلَيْهِ، وَطَرَفَهُ تَحْتَ رَأْسِهِ، فَسَلَّمَ عَلَيْهِ مُوسَى، فَكَشَفَ عَنْ وَجْهِهِ، وَقَالَ هَلْ بِأَرْضِي مِنْ سَلاَمٍ مَنْ أَنْتَ قَالَ أَنَا مُوسَى‏.‏ قَالَ مُوسَى بَنِي إِسْرَائِيلَ قَالَ نَعَمْ‏.‏ قَالَ فَمَا شَأْنُكَ قَالَ جِئْتُ لِتُعَلِّمَنِي مِمَّا عُلِّمْتَ رَشَدًا‏.‏ قَالَ أَمَا يَكْفِيكَ أَنَّ التَّوْرَاةَ بِيَدَيْكَ، وَأَنَّ الْوَحْىَ يَأْتِيكَ، يَا مُوسَى إِنَّ لِي عِلْمًا لاَ يَنْبَغِي لَكَ أَنْ تَعْلَمَهُ وَإِنَّ لَكَ عِلْمًا لاَ يَنْبَغِي لِي أَنْ أَعْلَمَهُ، فَأَخَذَ طَائِرٌ بِمِنْقَارِهِ مِنَ الْبَحْرِ وَقَالَ وَاللَّهِ مَا عِلْمِي وَمَا عِلْمُكَ فِي جَنْبِ عِلْمِ اللَّهِ إِلاَّ كَمَا أَخَذَ هَذَا الطَّائِرُ بِمِنْقَارِهِ مِنَ الْبَحْرِ، حَتَّى إِذَا رَكِبَا فِي السَّفِينَةِ وَجَدَا مَعَابِرَ صِغَارًا تَحْمِلُ أَهْلَ هَذَا السَّاحِلِ إِلَى أَهْلِ هَذَا السَّاحِلِ الآخَرِ عَرَفُوهُ، فَقَالُوا عَبْدُ اللَّهِ الصَّالِحُ ـ قَالَ قُلْنَا لِسَعِيدٍ خَضِرٌ قَالَ نَعَمْ ـ لاَ نَحْمِلُهُ بِأَجْرٍ، فَخَرَقَهَا وَوَتَدَ فِيهَا وَتِدًا‏.‏ قَالَ مُوسَى أَخَرَقْتَهَا لِتُغْرِقَ أَهْلَهَا لَقَدْ جِئْتَ شَيْئًا إِمْرًا ـ قَالَ مُجَاهِدٌ مُنْكَرًا ـ قَالَ أَلَمْ أَقُلْ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِي صَبْرًا كَانَتِ الأُولَى نِسْيَانًا وَالْوُسْطَى شَرْطًا وَالثَّالِثَةُ عَمْدًا قَالَ لاَ تُؤَاخِذْنِي بِمَا نَسِيتُ وَلاَ تُرْهِقْنِي مِنْ أَمْرِي عُسْرًا، لَقِيَا غُلاَمًا فَقَتَلَهُ ـ قَالَ يَعْلَى قَالَ سَعِيدٌ ـ وَجَدَ غِلْمَانًا يَلْعَبُونَ، فَأَخَذَ غُلاَمًا كَافِرًا ظَرِيفًا فَأَضْجَعَهُ، ثُمَّ ذَبَحَهُ بِالسِّكِّينِ‏.‏ قَالَ أَقَتَلْتَ نَفْسًا زَكِيَّةً بِغَيْرِ نَفْسٍ لَمْ تَعْمَلْ بِالْحِنْثِ ـ وَكَانَ ابْنُ عَبَّاسٍ قَرَأَهَا زَكِيَّةً زَاكِيَةً مُسْلِمَةً كَقَوْلِكَ غُلاَمًا زَكِيًّا ـ فَانْطَلَقَا، فَوَجَدَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ فَأَقَامَهُ ـ قَالَ سَعِيدٌ بِيَدِهِ هَكَذَا ـ وَرَفَعَ يَدَهُ فَاسْتَقَامَ ـ قَالَ يَعْلَى ـ حَسِبْتُ أَنَّ سَعِيدًا قَالَ فَمَسَحَهُ بِيَدِهِ فَاسْتَقَامَ، لَوْ شِئْتَ لاَتَّخَذْتَ عَلَيْهِ أَجْرًا ـ قَالَ سَعِيدٌ أَجْرًا نَأْكُلُهُ ـ وَكَانَ وَرَاءَهُمْ، وَكَانَ أَمَامَهُمْ ـ قَرَأَهَا ابْنُ عَبَّاسٍ أَمَامَهُمْ مَلِكٌ ـ يَزْعُمُونَ عَنْ غَيْرِ سَعِيدٍ أَنَّهُ هُدَدُ بْنُ بُدَدٍ، وَالْغُلاَمُ الْمَقْتُولُ، اسْمُهُ يَزْعُمُونَ جَيْسُورٌ مَلِكٌ يَأْخُذُ كُلَّ سَفِينَةٍ غَصْبًا، فَأَرَدْتُ إِذَا هِيَ مَرَّتْ بِهِ أَنْ يَدَعَهَا لِعَيْبِهَا، فَإِذَا جَاوَزُوا أَصْلَحُوهَا فَانْتَفَعُوا بِهَا وَمِنْهُمْ مَنْ يَقُولُ سَدُّوهَا بِقَارُورَةٍ وَمِنْهُمْ مَنْ يَقُولُ بِالْقَارِ، كَانَ أَبَوَاهُ مُؤْمِنَيْنِ، وَكَانَ كَافِرًا فَخَشِينَا أَنْ يُرْهِقَهُمَا طُغْيَانًا وَكُفْرًا، أَنْ يَحْمِلَهُمَا حُبُّهُ عَلَى أَنْ يُتَابِعَاهُ عَلَى دِينِهِ فَأَرَدْنَا أَنْ يُبَدِّلَهُمَا رَبُّهُمَا خَيْرًا مِنْهُ زَكَاةً لِقَوْلِهِ أَقَتَلْتَ نَفْسًا زَكِيَّةً وَأَقْرَبَ رُحْمًا هُمَا بِهِ أَرْحَمُ مِنْهُمَا بِالأَوَّلِ، الَّذِي قَتَلَ خَضِرٌ وَزَعَمَ غَيْرُ سَعِيدٍ أَنَّهُمَا أُبْدِلاَ جَارِيَةً، وأَمَّا دَاوُدُ بْنُ أَبِي عَاصِمٍ فَقَالَ عَنْ غَيْرِ وَاحِدٍ إِنَّهَا جَارِيَةٌ‏"‏‏.‏\hadithno{4726}\hadithtrans{Narrated Ibn Juraij:Ya`la bin Muslim and `Amr bin Dinar and some others narrated the narration of Sa`id bin Jubair. Narrated Sa`id: While we were at the house of Ibn `Abbas, Ibn `Abbas said, "Ask me (any question)" I said, "O Abu `Abbas! May Allah let me be sacrificed for you ! There is a man at Kufa who is a storyteller called Nauf; who claims that he (Al-Khadir's companion) is not Moses of Bani Israel." As for `Amr, he said to me, "Ibn `Abbas said, "(Nauf) the enemy of Allah told a lie." But Ya`la said to me, "Ibn `Abbas said, Ubai bin Ka`b said, Allah's Messenger (ﷺ) said, 'Once Moses, Allah's Messenger (ﷺ), preached to the people till their eyes shed tears and their hearts became tender, whereupon he finished his sermon. Then a man came to Moses and asked, 'O Allah's Messenger (ﷺ)! Is there anyone on the earth who is more learned than you?' Moses replied, 'No.' So Allah admonished him (Moses), for he did not ascribe all knowledge to Allah. It was said, (on behalf of Allah), 'Yes, (there is a slave of ours who knows more than you ).' Moses said, 'O my Lord! Where is he?' Allah said, 'At the junction of the two seas.' Moses said, 'O my Lord! Tell me of a sign whereby I will recognize the place.' " `Amr said to me, Allah said, "That place will be where the fish will leave you." Ya`la said to me, "Allah said (to Moses), 'Take a dead fish (and your goal will be) the place where it will become alive.' " So Moses took a fish and put it in a basket and said to his boy-servant "I don't want to trouble you, except that you should inform me as soon as this fish leaves you." He said (to Moses)." You have not demanded too much." And that is as mentioned by Allah: 'And (remember) when Moses said to his attendant .... ' (18.60) Yusha` bin Noon. (Sa`id did not state that). The Prophet (ﷺ) said, "While the attendant was in the shade of the rock at a wet place, the fish slipped out (alive) while Moses was sleeping. His attendant said (to himself), "I will not wake him," but when he woke up, he forgot to tell him the fish slipped out and entered the sea. Allah stopped the flow of the sea where the fish was, so that its trace looked as if it was made on a rock. `Amr forming a hole with his two thumbs and index fingers, said to me, "Like this, as in its trace was made on a rock." Moses said "We have suffered much fatigue on this journey of ours." (This was not narrated by Sa`id). Then they returned back and found Al-Khadir. `Uthman bin Abi Sulaiman said to me, (they found him) on a green carpet in the middle of the sea. Al-Khadir was covered with his garment with one end under his feet and the other end under his head. When Moses greeted, he uncovered his face and said astonishingly, 'Is there such a greeting in my land? Who are you?' Moses said, 'I am Moses.' Al- Khadir said, 'Are you the Moses of Bani Israel?' Moses said, 'Yes.' Al-Khadir said, "What do you want?' Moses said, ' I came to you so that you may teach me of the truth which you were taught.' Al- Khadir said, 'Is it not sufficient for you that the Torah is in your hands and the Divine Inspiration comes to you, O Moses? Verily, I have a knowledge that you ought not learn, and you have a knowledge which I ought not learn.' At that time a bird took with its beak (some water) from the sea: Al-Khadir then said, 'By Allah, my knowledge and your knowledge besides Allah's Knowledge is like what this bird has taken with its beak from the sea.' Until, when they went on board the boat (18.71). They found a small boat which used to carry the people from this sea-side to the other sea-side. The crew recognized Al-Khadir and said, 'The pious slave of Allah.' (We said to Sa`id "Was that Khadir?" He said, "Yes.") The boat men said, 'We will not get him on board with fare.' Al-Khadir scuttled the boat and then plugged the hole with a piece of wood. Moses said, 'Have you scuttled it in order to drown these people? Surely, you have done a dreadful thing. (18.71) (Mujahid said. "Moses said so protestingly.") Al-Khadir said, didn't I say that you can have no patience with me?' (18.72) The first inquiry of Moses was done because of forgetfulness, the second caused him to be bound with a stipulation, and the third was done intentionally. Moses said, 'Call me not to account for what I forgot and be not hard upon me for my affair (with you).' (18.73) (Then) they found a boy and Al-Khadir killed him. Ya`la- said: Sa`id said 'They found boys playing and Al-Khadir got hold of a handsome infidel boy laid him down and then slew him with knife. Moses said, 'Have you killed a innocent soul who has killed nobody' (18.74) Then they proceeded and found a wall which was on the point of falling down, and Al-Khadir set it up straight. Sa`id moved his hand thus and said 'Al-Khadir raised his hand and the wall became straight. Ya`la said, 'I think Sa`id said, 'Al-Khadir touched the wall with his hand and it became straight (Moses said to Al-Khadir), 'If you had wished, you could have taken wages for it.' Sa`id said, 'Wages that we might had eaten.' And there was a king in furor (ahead) of them" (18.79) And there was in front of them. Ibn `Abbas recited: 'In front of them (was) a king.' It is said on the authority of somebody other than Sa`id that the king was Hudad bin Budad. They say that the boy was called Jaisur. 'A king who seized every ship by force. (18.79) So I wished that if that boat passed by him, he would leave it because of its defect and when they have passed they would repair it and get benefit from it. Some people said that they closed that hole with a bottle, and some said with tar. 'His parents were believers, and he (the boy) was a non-believer and we (Khadir) feared lest he would oppress them by obstinate rebellion and disbelief.' (18.80) (i.e. that their love for him would urge them to follow him in his religion, 'so we (Khadir) desired that their Lord should change him for them for one better in righteousness and near to mercy' (18:81). This was in reply to Moses' saying: Have you killed an innocent soul.'? (18.74). 'Near to mercy" means they will be more merciful to him than they were to the former whom Khadir had killed. Other than Sa`id, said that they were compensated with a girl. Dawud bin Abi `Asim said on the authority of more than one that this next child was a girl}}
\hadithdefcmd{bukhari}{4727}{حَدَّثَنِي قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنِي سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ إِنَّ نَوْفًا الْبَكَالِيَّ يَزْعُمُ أَنَّ مُوسَى بَنِي إِسْرَائِيلَ لَيْسَ بِمُوسَى الْخَضِرِ‏.‏ فَقَالَ كَذَبَ عَدُوُّ اللَّهِ حَدَّثَنَا أُبَىُّ بْنُ كَعْبٍ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ قَامَ مُوسَى خَطِيبًا فِي بَنِي إِسْرَائِيلَ فَقِيلَ لَهُ أَىُّ النَّاسِ أَعْلَمُ قَالَ أَنَا، فَعَتَبَ اللَّهُ عَلَيْهِ، إِذْ لَمْ يَرُدَّ الْعِلْمَ إِلَيْهِ، وَأَوْحَى إِلَيْهِ بَلَى عَبْدٌ مِنْ عِبَادِي بِمَجْمَعِ الْبَحْرَيْنِ، هُوَ أَعْلَمُ مِنْكَ قَالَ أَىْ رَبِّ كَيْفَ السَّبِيلُ إِلَيْهِ قَالَ تَأْخُذُ حُوتًا فِي مِكْتَلٍ فَحَيْثُمَا فَقَدْتَ الْحُوتَ فَاتَّبِعْهُ قَالَ فَخَرَجَ مُوسَى، وَمَعَهُ فَتَاهُ يُوشَعُ بْنُ نُونٍ، وَمَعَهُمَا الْحُوتُ حَتَّى انْتَهَيَا إِلَى الصَّخْرَةِ، فَنَزَلاَ عِنْدَهَا قَالَ فَوَضَعَ مُوسَى رَأْسَهُ فَنَامَ ـ قَالَ سُفْيَانُ وَفِي حَدِيثِ غَيْرِ عَمْرٍو قَالَ ـ وَفِي أَصْلِ الصَّخْرَةِ عَيْنٌ يُقَالُ لَهَا الْحَيَاةُ لاَ يُصِيبُ مِنْ مَائِهَا شَىْءٌ إِلاَّ حَيِيَ، فَأَصَابَ الْحُوتَ مِنْ مَاءِ تِلْكَ الْعَيْنِ، قَالَ فَتَحَرَّكَ، وَانْسَلَّ مِنَ الْمِكْتَلِ، فَدَخَلَ الْبَحْرَ فَلَمَّا اسْتَيْقَظَ مُوسَى ‏\{‏قَالَ لِفَتَاهُ آتِنَا غَدَاءَنَا‏\}‏ الآيَةَ قَالَ وَلَمْ يَجِدِ النَّصَبَ حَتَّى جَاوَزَ مَا أُمِرَ بِهِ، قَالَ لَهُ فَتَاهُ يُوشَعُ بْنُ نُونٍ ‏\{‏أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ‏\}‏ الآيَةَ قَالَ فَرَجَعَا يَقُصَّانِ فِي آثَارِهِمَا، فَوَجَدَا فِي الْبَحْرِ كَالطَّاقِ مَمَرَّ الْحُوتِ، فَكَانَ لِفَتَاهُ عَجَبًا، وَلِلْحُوتِ سَرَبًا قَالَ فَلَمَّا انْتَهَيَا إِلَى الصَّخْرَةِ، إِذْ هُمَا بِرَجُلٍ مُسَجًّى بِثَوْبٍ، فَسَلَّمَ عَلَيْهِ مُوسَى قَالَ وَأَنَّى بِأَرْضِكَ السَّلاَمُ فَقَالَ أَنَا مُوسَى‏.‏ قَالَ مُوسَى بَنِي إِسْرَائِيلَ قَالَ نَعَمْ هَلْ أَتَّبِعُكَ عَلَى أَنْ تُعَلِّمَنِي مِمَّا عُلِّمْتَ رَشَدًا‏.‏ قَالَ لَهُ الْخَضِرُ يَا مُوسَى إِنَّكَ عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ عَلَّمَكَهُ اللَّهُ لاَ أَعْلَمُهُ، وَأَنَا عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ عَلَّمَنِيهِ اللَّهُ لاَ تَعْلَمُهُ‏.‏ قَالَ بَلْ أَتَّبِعُكَ‏.‏ قَالَ فَإِنِ اتَّبَعْتَنِي فَلاَ تَسْأَلْنِي عَنْ شَىْءٍ حَتَّى أُحْدِثَ لَكَ مِنْهُ ذِكْرًا، فَانْطَلَقَا يَمْشِيَانِ عَلَى السَّاحِلِ فَمَرَّتْ بِهِمَا سَفِينَةٌ فَعُرِفَ الْخَضِرُ فَحَمَلُوهُمْ فِي سَفِينَتِهِمْ بِغَيْرِ نَوْلٍ ـ يَقُولُ بِغَيْرِ أَجْرٍ ـ فَرَكِبَا السَّفِينَةَ قَالَ وَوَقَعَ عُصْفُورٌ عَلَى حَرْفِ السَّفِينَةِ، فَغَمَسَ مِنْقَارَهُ الْبَحْرَ فَقَالَ الْخَضِرُ لِمُوسَى مَا عِلْمُكَ وَعِلْمِي وَعِلْمُ الْخَلاَئِقِ فِي عِلْمِ اللَّهِ إِلاَّ مِقْدَارُ مَا غَمَسَ هَذَا الْعُصْفُورُ مِنْقَارَهُ قَالَ فَلَمْ يَفْجَأْ مُوسَى، إِذْ عَمَدَ الْخَضِرُ إِلَى قَدُومٍ فَخَرَقَ السَّفِينَةَ، فَقَالَ لَهُ مُوسَى قَوْمٌ حَمَلُونَا بِغَيْرِ نَوْلٍ، عَمَدْتَ إِلَى سَفِينَتِهِمْ فَخَرَقْتَهَا ‏\{‏لِتُغْرِقَ أَهْلَهَا لَقَدْ جِئْتَ‏\}‏ الآيَةَ فَانْطَلَقَا إِذَا هُمَا بِغُلاَمٍ يَلْعَبُ مَعَ الْغِلْمَانِ، فَأَخَذَ الْخَضِرُ بِرَأْسِهِ فَقَطَعَهُ‏.‏ قَالَ لَهُ مُوسَى ‏\{‏أَقَتَلْتَ نَفْسًا زَكِيَّةً بِغَيْرِ نَفْسٍ لَقَدْ جِئْتَ شَيْئًا نُكْرًا * قَالَ أَلَمْ أَقُلْ لَكَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا‏\}‏ إِلَى قَوْلِهِ ‏\{‏فَأَبَوْا أَنْ يُضَيِّفُوهُمَا فَوَجَدَا فِيهَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ‏\}‏ فَقَالَ بِيَدِهِ هَكَذَا فَأَقَامَهُ، فَقَالَ لَهُ مُوسَى إِنَّا دَخَلْنَا هَذِهِ الْقَرْيَةَ، فَلَمْ يُضَيِّفُونَا وَلَمْ يُطْعِمُونَا، لَوْ شِئْتَ لاَتَّخَذْتَ عَلَيْهِ أَجْرًا‏.‏ قَالَ هَذَا فِرَاقُ بَيْنِي وَبَيْنِكَ سَأُنَبِّئُكَ بِتَأْوِيلِ مَا لَمْ تَسْتَطِعْ عَلَيْهِ صَبْرًا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَدِدْنَا أَنَّ مُوسَى صَبَرَ حَتَّى يُقَصَّ عَلَيْنَا مِنْ أَمْرِهِمَا ‏"‏‏.‏ قَالَ وَكَانَ ابْنُ عَبَّاسٍ يَقْرَأُ وَكَانَ أَمَامَهُمْ مَلِكٌ يَأْخُذُ كُلَّ سَفِينَةٍ صَالِحَةٍ غَصْبًا، وَأَمَّا الْغُلاَمُ فَكَانَ كَافِرًا‏.‏\hadithno{4727}\hadithtrans{Narrated Sa`id bin Jubair:I said to Ibn `Abbas, "Nauf-al-Bakali " claims that Moses of Bani Israel was not Moses, the companion of Al-Khadir." Ibn `Abbas said, "Allah's enemy tells a lie! Ubai bin Ka`b narrated to us that Allah's Messenger (ﷺ) said, 'Moses got up to deliver a sermon before Bani Israel and he was asked, 'Who is the most learned person among the people?' Moses replied, 'I (am the most learned).' Allah then admonished Moses for he did not ascribe all knowledge to Allah only (Then) came the Divine Inspiration:-- 'Yes, one of Our slaves at the junction of the two seas is more learned than you.' Moses said, 'O my Lord ! How can I meet him?' Allah said, 'Take a fish in a basket and wherever the fish is lost, follow it (you will find him at that place). So Moses set out along with his attendant Yusha` bin Noon, and they carried with them a fish till they reached a rock and rested there. Moses put his head down and slept. (Sufyan, a sub-narrator said that somebody other than `Amr said) 'At the rock there was a water spring called 'Al-Hayat' and none came in touch with its water but became alive. So some of the water of that spring fell over that fish, so it moved and slipped out of the basket and entered the sea. When Moses woke up, he asked his attendant, 'Bring our early meal' (18.62). The narrator added: Moses did not suffer from fatigue except after he had passed the place he had been ordered to observe. His attendant Yusha` bin Noon said to him, 'Do you remember (what happened) when we betook ourselves to the rock? I did indeed forget (about) the fish ...' (18.63) The narrator added: So they came back, retracing their steps and then they found in the sea, the way of the fish looking like a tunnel. So there was an astonishing event for his attendant, and there was tunnel for the fish. When they reached the rock, they found a man covered with a garment. Moses greeted him. The man said astonishingly, 'Is there any such greeting in your land?' Moses said, 'I am Moses.' The man said, 'Moses of Bani Israel?' Moses said, 'Yes,' and added, 'may I follow you so that you teach me something of the Knowledge which you have been taught?' (18.66). Al-Khadir said to him, 'O Moses! You have something of Allah's knowledge which Allah has taught you and which I do not know; and I have something of Allah's knowledge which Allah has taught me and which you do not know.' Moses said, 'But I will follow you.' Al-Khadir said, 'Then if you follow me, ask me no question about anything until I myself speak to you concerning it.' (18.70). After that both of them proceeded along the seashore. There passed by them a boat whose crew recognized Al-Khadir and received them on board free of charge. So they both got on board. A sparrow came and sat on the edge of the boat and dipped its beak unto the sea. Al-Khadir said to Moses, 'My knowledge and your knowledge and all the creation's knowledge compared to Allah's knowledge is not more than the water taken by this sparrow's beak.' Then Moses was startled by Al-Khadir's action of taking an adze and scuttling the boat with it. Moses said to him, 'These people gave us a free lift, but you intentionally scuttled their boat so as to drown them. Surely you have...' (18.71) Then they both proceeded and found a boy playing with other boys. Al-Khadir took hold of him by the head and cut it off. Moses said to him, 'Have you killed an innocent soul who has killed nobody? Surely you have done an illegal thing! ' (18.74) He said, "Didn't I tell you that you will not be able to have patient with me up to ..but they refused to entertain them as their guests. There they found a wall therein at the point of collapsing.' (18.75-77) Al-Khadir moved his hand thus and set it upright (repaired it). Moses said to him, 'When we entered this town, they neither gave us hospitality nor fed us; if you had wished, you could have taken wages for it,' Al- Khadir said, 'This is the parting between you and me I will tell you the interpretation of (those things) about which you were unable to hold patience.'...(18.78) Allah's Messenger (ﷺ) said, 'We wished that Moses could have been more patient so that He (Allah) could have described to us more about their story.' Ibn `Abbas used to recite:-- 'And in front (ahead) of them there was a king who used to seize every (serviceable) boat by force. (18.79) ...and as for the boy he was a disbeliever}}
\hadithdefcmd{bukhari}{4728}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ مُصْعَبٍ، قَالَ سَأَلْتُ أَبِي ‏\{‏قُلْ هَلْ نُنَبِّئُكُمْ بِالأَخْسَرِينَ أَعْمَالاً‏\}‏ هُمُ الْحَرُورِيَّةُ قَالَ لاَ، هُمُ الْيَهُودُ وَالنَّصَارَى، أَمَّا الْيَهُودُ فَكَذَّبُوا مُحَمَّدًا صلى الله عليه وسلم وَأَمَّا النَّصَارَى كَفَرُوا بِالْجَنَّةِ وَقَالُوا لاَ طَعَامَ فِيهَا وَلاَ شَرَابَ، وَالْحَرُورِيَّةُ الَّذِينَ يَنْقُضُونَ عَهْدَ اللَّهِ مِنْ بَعْدِ مِيثَاقِهِ، وَكَانَ سَعْدٌ يُسَمِّيهِمُ الْفَاسِقِينَ‏.‏\hadithno{4728}\hadithtrans{Narrated Mus`ab:I asked my father, "Was the Verse:-- 'Say: (O Muhammad) Shall We tell you the greatest losers in respect of their deeds?'(18.103) revealed regarding Al-Haruriyya?" He said, "No, but regarding the Jews and the Christians, for the Jews disbelieved Muhammad and the Christians disbelieved in Paradise and say that there are neither meals nor drinks therein. Al- Hururiyya are those people who break their pledge to Allah after they have confirmed that they will fulfill it, and Sa`d used to call them 'Al-Fasiqin (evildoers who forsake Allah's obedience)}}
\hadithdefcmd{bukhari}{4729}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا الْمُغِيرَةُ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّهُ لَيَأْتِي الرَّجُلُ الْعَظِيمُ السَّمِينُ يَوْمَ الْقِيَامَةِ لاَ يَزِنُ عِنْدَ اللَّهِ جَنَاحَ بَعُوضَةٍ وَقَالَ اقْرَءُوا ‏\{‏فَلاَ نُقِيمُ لَهُمْ يَوْمَ الْقِيَامَةِ وَزْنًا‏\}‏ ‏"‏‏.‏ وَعَنْ يَحْيَى بْنِ بُكَيْرٍ عَنِ الْمُغِيرَةِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي الزِّنَادِ مِثْلَهُ‏.‏\hadithno{4729}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "On the Day of Resurrection, a huge fat man will come who will not weigh, the weight of the wing of a mosquito in Allah's Sight." and then the Prophet (ﷺ) added, 'We shall not give them any weight on the Day of Resurrection}}
\hadithdefcmd{bukhari}{4730}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُؤْتَى بِالْمَوْتِ كَهَيْئَةِ كَبْشٍ أَمْلَحَ فَيُنَادِي مُنَادٍ يَا أَهْلَ الْجَنَّةِ، فَيَشْرَئِبُّونَ وَيَنْظُرُونَ فَيَقُولُ هَلْ تَعْرِفُونَ هَذَا فَيَقُولُونَ نَعَمْ هَذَا الْمَوْتُ، وَكُلُّهُمْ قَدْ رَآهُ، ثُمَّ يُنَادِي يَا أَهْلَ النَّارِ، فَيَشْرَئِبُّونَ وَيَنْظُرُونَ، فَيَقُولُ هَلْ تَعْرِفُونَ هَذَا فَيَقُولُونَ نَعَمْ هَذَا الْمَوْتُ، وَكُلُّهُمْ قَدْ رَآهُ، فَيُذْبَحُ ثُمَّ يَقُولُ يَا أَهْلَ الْجَنَّةِ، خُلُودٌ فَلاَ مَوْتَ، وَيَا أَهْلَ النَّارِ، خُلُودٌ فَلاَ مَوْتَ ثُمَّ قَرَأَ ‏\{‏وَأَنْذِرْهُمْ يَوْمَ الْحَسْرَةِ إِذْ قُضِيَ الأَمْرُ وَهُمْ فِي غَفْلَةٍ‏\}‏ وَهَؤُلاَءِ فِي غَفْلَةٍ أَهْلُ الدُّنْيَا ‏\{‏وَهُمْ لاَ يُؤْمِنُونَ‏\}‏‏"‏\hadithno{4730}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "On the Day of Resurrection Death will be brought forward in the shape of a black and white ram. Then a call maker will call, 'O people of Paradise!' Thereupon they will stretch their necks and look carefully. The caller will say, 'Do you know this?' They will say, 'Yes, this is Death.' By then all of them will have seen it. Then it will be announced again, 'O people of Hell !' They will stretch their necks and look carefully. The caller will say, 'Do you know this?' They will say, 'Yes, this is Death.' And by then all of them will have seen it. Then it (that ram) will be slaughtered and the caller will say, 'O people of Paradise! Eternity for you and no death O people of Hell! Eternity for you and no death."' Then the Prophet, recited:-- 'And warn them of the Day of distress when the case has been decided, while (now) they are in a state of carelessness (i.e. the people of the world) and they do not believe}}
\hadithdefcmd{bukhari}{4731}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عُمَرُ بْنُ ذَرٍّ، قَالَ سَمِعْتُ أَبِي، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِجِبْرِيلَ ‏"‏ مَا يَمْنَعُكَ أَنْ تَزُورَنَا أَكْثَرَ مِمَّا تَزُورُنَا فَنَزَلَتْ ‏\{‏وَمَا نَتَنَزَّلُ إِلاَّ بِأَمْرِ رَبِّكَ لَهُ مَا بَيْنَ أَيْدِينَا وَمَا خَلْفَنَا‏\}‏‏"‏\hadithno{4731}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said to Gabriel, "What prevents you from visiting us more often than you visit us now?" So there was revealed:-- 'And we (angels) descend not but by the command of your Lord. To Him belongs what is before us and what is behind us}}
\hadithdefcmd{bukhari}{4732}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ سَمِعْتُ خَبَّابًا، قَالَ جِئْتُ الْعَاصِيَ بْنَ وَائِلٍ السَّهْمِيَّ أَتَقَاضَاهُ حَقًّا لِي عِنْدَهُ، فَقَالَ لاَ أُعْطِيكَ حَتَّى تَكْفُرَ بِمُحَمَّدٍ فَقُلْتُ لاَ حَتَّى تَمُوتَ ثُمَّ تُبْعَثَ‏.‏ قَالَ وَإِنِّي لَمَيِّتٌ ثُمَّ مَبْعُوثٌ قُلْتُ نَعَمْ‏.‏ قَالَ إِنَّ لِي هُنَاكَ مَالاً وَوَلَدًا فَأَقْضِيكَهُ، فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏أَفَرَأَيْتَ الَّذِي كَفَرَ بِآيَاتِنَا وَقَالَ لأُوتَيَنَّ مَالاً وَوَلَدًا‏\}‏ رَوَاهُ الثَّوْرِيُّ وَشُعْبَةُ وَحَفْصٌ وَأَبُو مُعَاوِيَةَ وَوَكِيعٌ عَنِ الأَعْمَشِ‏.‏\hadithno{4732}\hadithtrans{Narrated Khabbab:I came to Al-`Asi bin Wail As-Sahmi and demanded something which he owed me. He said, "I will not give you (your money) till you disbelieve in Muhammad." I said, "No, I shall not disbelieve in Muhammad till you die and then be resurrected." He said, "Will I die and then be resurrected?" I said, 'Yes'. He said', "Then I will have wealth and children there, and I will pay you (there)." So this Verse was revealed:-- 'Have you then seen him who disbelieved in Our Signs and (yet) says: I shall certainly be given wealth and children?}}
\hadithdefcmd{bukhari}{4733}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ خَبَّابٍ، قَالَ كُنْتُ قَيْنًا بِمَكَّةَ، فَعَمِلْتُ لِلْعَاصِي بْنِ وَائِلِ السَّهْمِيِّ سَيْفًا، فَجِئْتُ أَتَقَاضَاهُ فَقَالَ لاَ أُعْطِيكَ حَتَّى تَكْفُرَ بِمُحَمَّدٍ‏.‏ قُلْتُ لاَ أَكْفُرُ بِمُحَمَّدٍ صلى الله عليه وسلم حَتَّى يُمِيتَكَ اللَّهُ، ثُمَّ يُحْيِيَكَ‏.‏ قَالَ إِذَا أَمَاتَنِي اللَّهُ ثُمَّ بَعَثَنِي، وَلِي مَالٌ وَوَلَدٌ فَأَنْزَلَ اللَّهُ ‏\{‏أَفَرَأَيْتَ الَّذِي كَفَرَ بِآيَاتِنَا وَقَالَ لأُوتَيَنَّ مَالاً وَوَلَدًا * أَطَّلَعَ الْغَيْبَ أَمِ اتَّخَذَ عِنْدَ الرَّحْمَنِ عَهْدًا‏\}‏‏.‏ قَالَ مَوْثِقًا‏.‏ لَمْ يَقُلِ الأَشْجَعِيُّ عَنْ سُفْيَانَ سَيْفًا وَلاَ مَوْثِقًا‏.‏\hadithno{4733}\hadithtrans{Narrated Khabbab:I was a blacksmith in Mecca Once I made a sword for Al-`Asi bin Wail As-Sahmi. When I went to demand its price, he said, "I will not give it to you till you disbelieve in Muhammad." I said, "I shall not disbelieve in Muhammad till Allah makes you die and then bring you to life again." He said, "If Allah should make me die and then resurrect me, I would have wealth and children." So Allah revealed:-- 'Have you seen him who disbelieved in Our Signs, and (yet) says I shall certainly be given wealth and children? Has he known the unseen or has he taken a covenant from (Allah) the Beneficent?}}
\hadithdefcmd{bukhari}{4734}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، سَمِعْتُ أَبَا الضُّحَى، يُحَدِّثُ عَنْ مَسْرُوقٍ، عَنْ خَبَّابٍ، قَالَ كُنْتُ قَيْنًا فِي الْجَاهِلِيَّةِ، وَكَانَ لِي دَيْنٌ عَلَى الْعَاصِي بْنِ وَائِلٍ قَالَ فَأَتَاهُ يَتَقَاضَاهُ، فَقَالَ لاَ أُعْطِيكَ حَتَّى تَكْفُرَ بِمُحَمَّدٍ فَقَالَ وَاللَّهِ لاَ أَكْفُرُ حَتَّى يُمِيتَكَ اللَّهُ ثُمَّ تُبْعَثَ‏.‏ قَالَ فَذَرْنِي حَتَّى أَمُوتَ ثُمَّ أُبْعَثَ، فَسَوْفَ أُوتَى مَالاً وَوَلَدًا، فَأَقْضِيكَ فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏أَفَرَأَيْتَ الَّذِي كَفَرَ بِآيَاتِنَا وَقَالَ لأُوتَيَنَّ مَالاً وَوَلَدًا‏\}‏\hadithno{4734}\hadithtrans{Narrated Masruq:Khabbab said, "During the pre-Islamic period, I was a blacksmith and Al-Asi bin Wail owed me a debt." So Khabbab went to him to demand the debt. He said, "I will not give you (your due) till you disbelieve in Muhammad." Khabbab said, "By Allah, I shall not disbelieve in Muhammad till Allah makes you die and then resurrects you." Al-Asi said, "So leave me till I die and then be resurrected, for I will be given wealth and children whereupon I will pay you your debt." So this Verse was revealed:-- 'Have you seen him who disbelieved in Our Signs and, (yet) says: I shall certainly be given wealth and children}}
\hadithdefcmd{bukhari}{4735}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ خَبَّابٍ، قَالَ كُنْتُ رَجُلاً قَيْنًا، وَكَانَ لِي عَلَى الْعَاصِي بْنِ وَائِلٍ دَيْنٌ فَأَتَيْتُهُ أَتَقَاضَاهُ، فَقَالَ لِي لاَ أَقْضِيكَ حَتَّى تَكْفُرَ بِمُحَمَّدٍ‏.‏ قَالَ قُلْتُ لَنْ أَكْفُرَ بِهِ حَتَّى تَمُوتَ ثُمَّ تُبْعَثَ‏.‏ قَالَ وَإِنِّي لَمَبْعُوثٌ مِنْ بَعْدِ الْمَوْتِ فَسَوْفَ أَقْضِيكَ إِذَا رَجَعْتُ إِلَى مَالٍ وَوَلَدٍ‏.‏ قَالَ فَنَزَلَتْ ‏\{‏أَفَرَأَيْتَ الَّذِي كَفَرَ بِآيَاتِنَا وَقَالَ لأُوتَيَنَّ مَالاً وَوَلَدًا * أَطَّلَعَ الْغَيْبَ أَمِ اتَّخَذَ عِنْدَ الرَّحْمَنِ عَهْدًا * كَلاَّ سَنَكْتُبُ مَا يَقُولُ وَنَمُدُّ لَهُ مِنَ الْعَذَابِ مَدًّا * وَنَرِثُهُ مَا يَقُولُ وَيَأْتِينَا فَرْدًا‏\}‏‏.‏\hadithno{4735}\hadithtrans{Narrated Khabbab:I was a blacksmith and Al-Asi Bin Wail owed me a debt, so I went to him to demand it. He said to me. "I will not pay you your debt till you disbelieve in Muhammad." I said, "I will not disbelieve in Muhammad till you die and then be resurrected." He said, "Will I be resurrected after my death? If so, I shall pay you (there) if I should find wealth and children." So there was revealed:-- 'Have you seen him who disbelieved in Our Signs, and yet says: I shall certainly be given wealth and children? Has he, known to the unseen or has he taken a covenant from (Allah) the Beneficent? Nay ! We shall record what he says, and we shall add and add to his punishment. And We shall inherit from him all that he talks of, and he shall appear before Us alone}}
\hadithdefcmd{bukhari}{4736}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْتَقَى آدَمُ وَمُوسَى، فَقَالَ مُوسَى لآدَمَ أَنْتَ الَّذِي أَشْقَيْتَ النَّاسَ وَأَخْرَجْتَهُمْ مِنَ الْجَنَّةِ قَالَ لَهُ آدَمُ أَنْتَ الَّذِي اصْطَفَاكَ اللَّهُ بِرِسَالَتِهِ، وَاصْطَفَاكَ لِنَفْسِهِ وَأَنْزَلَ عَلَيْكَ التَّوْرَاةَ قَالَ نَعَمْ‏.‏ قَالَ فَوَجَدْتَهَا كُتِبَ عَلَىَّ قَبْلَ أَنْ يَخْلُقَنِي قَالَ نَعَمْ‏.‏ فَحَجَّ آدَمُ مُوسَى ‏"‏‏.‏ الْيَمُّ الْبَحْرُ‏.‏\hadithno{4736}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Adam and Moses met, and Moses said to Adam "You are the one who made people miserable and turned them out of Paradise." Adam said to him, "You are the one whom Allah selected for His message and whom He selected for Himself and upon whom He revealed the Torah." Moses said, 'Yes.' Adam said, "Did you find that written in my fate before my creation?' Moses said, 'Yes.' So Adam overcame Moses with this argument}}
\hadithdefcmd{bukhari}{4737}{حَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ، وَالْيَهُودُ تَصُومُ عَاشُورَاءَ، فَسَأَلَهُمْ، فَقَالُوا هَذَا الْيَوْمُ الَّذِي ظَهَرَ فِيهِ مُوسَى عَلَى فِرْعَوْنَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نَحْنُ أَوْلَى بِمُوسَى مِنْهُمْ فَصُومُوهُ ‏"‏‏.‏\hadithno{4737}\hadithtrans{Narrated Ibn `Abbas:When Allah's Messenger (ﷺ) arrived at Medina, he found the Jews observing the fast on the day of 'Ashura' (10th of Muharram). The Prophet (ﷺ) asked them (about it) and they replied, "This is the day when Moses became victorious over Pharaoh." The Prophet (ﷺ) said (to the Muslims), "We are nearer to Moses than they, so fast on this day}}
\hadithdefcmd{bukhari}{4738}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَيُّوبُ بْنُ النَّجَّارِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ حَاجَّ مُوسَى آدَمَ، فَقَالَ لَهُ أَنْتَ الَّذِي أَخْرَجْتَ النَّاسَ مِنَ الْجَنَّةِ بِذَنْبِكَ وَأَشْقَيْتَهُمْ‏.‏ قَالَ قَالَ آدَمُ يَا مُوسَى أَنْتَ الَّذِي اصْطَفَاكَ اللَّهُ بِرِسَالَتِهِ وَبِكَلاَمِهِ أَتَلُومُنِي عَلَى أَمْرٍ كَتَبَهُ اللَّهُ عَلَىَّ قَبْلَ أَنْ يَخْلُقَنِي أَوْ قَدَّرَهُ عَلَىَّ قَبْلَ أَنْ يَخْلُقَنِي ‏"‏‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَحَجَّ آدَمُ مُوسَى ‏"‏‏.‏\hadithno{4738}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Moses argued with Adam and said to him (Adam), 'You are the one who got the people out of Paradise by your sin, and thus made them miserable." Adam replied, 'O Moses! You are the one whom Allah selected for His Message and for His direct talk. Yet you blame me for a thing which Allah had ordained for me before He created me?." Allah's Messenger (ﷺ) further said, "So Adam overcame Moses by this Argument}}
\hadithdefcmd{bukhari}{4739}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ بَنِي إِسْرَائِيلَ وَالْكَهْفُ وَمَرْيَمُ وَطَهَ وَالأَنْبِيَاءُ هُنَّ مِنَ الْعِتَاقِ الأُوَلِ، وَهُنَّ مِنْ تِلاَدِي‏.‏ وَقَالَ قَتَادَةُ ‏\{‏جُذَاذًا‏\}‏ قَطَّعَهُنَّ‏.‏ وَقَالَ الْحَسَنُ ‏\{‏فِي فَلَكٍ‏\}‏ مِثْلِ فَلْكَةِ الْمِغْزَلِ ‏\{‏يَسْبَحُونَ‏\}‏ يَدُورُونَ‏.‏ قَالَ ابْنُ عَبَّاسٍ ‏\{‏نَفَشَتْ‏\}‏ رَعَتْ ‏\{‏يُصْحَبُونَ‏\}‏ يُمْنَعُونَ‏.‏ ‏\{‏أُمَّتُكُمْ أُمَّةً وَاحِدَةً‏\}‏ قَالَ دِينُكُمْ دِينٌ وَاحِدٌ‏.‏ وَقَالَ عِكْرِمَةُ‏.‏ ‏\{‏حَصَبُ‏\}‏ حَطَبُ بِالْحَبَشِيَّةِ‏.‏ وَقَالَ غَيْرُهُ ‏\{‏أَحَسُّوا‏\}‏ تَوَقَّعُوهُ مِنْ أَحْسَسْتُ‏.‏ ‏\{‏خَامِدِينَ‏\}‏ هَامِدِينَ‏.‏ حَصِيدٌ مُسْتَأْصَلٌ يَقَعُ عَلَى الْوَاحِدِ وَالاِثْنَيْنِ وَالْجَمِيعِ‏.‏ ‏\{‏لاَ يَسْتَحْسِرُونَ‏\}‏ لاَ يُعْيُونَ، وَمِنْهُ حَسِيرٌ، وَحَسَرْتُ بَعِيرِي‏.‏ عَمِيقٌ بَعِيدٌ‏.‏ ‏\{‏نُكِسُوا‏\}‏ رُدُّوا‏.‏ ‏\{‏صَنْعَةَ لَبُوسٍ‏\}‏ الدُّرُوعُ‏.‏ ‏\{‏تَقَطَّعُوا أَمْرَهُمْ‏\}‏ اخْتَلَفُوا، الْحَسِيسُ وَالْحِسُّ وَالْجَرْسُ وَالْهَمْسُ وَاحِدٌ، وَهْوَ مِنَ الصَّوْتِ الْخَفِيِّ ‏\{‏آذَنَّاكَ‏\}‏ أَعْلَمْنَاكَ ‏\{‏آذَنْتُكُمْ‏\}‏ إِذَا أَعْلَمْتَهُ فَأَنْتَ وَهْوَ عَلَى سَوَاءٍ لَمْ تَغْدِرْ‏.‏ وَقَالَ مُجَاهِدٌ ‏\{‏لَعَلَّكُمْ تُسْأَلُونَ‏\}‏ تُفْهَمُونَ ‏\{‏ارْتَضَى‏\}‏ رَضِيَ‏.‏ ‏\{‏التَّمَاثِيلُ‏\}‏ الأَصْنَامُ، السِّجِلُّ الصَّحِيفَةُ‏.‏\hadithno{4739}\hadithtrans{Narrated `Abdullah:The Suras of Bani Israel, Al-Kahf, Mariyam, Taha and Al-Anbiya are from the very old Suras which I learnt by heart, and they are my first property}}
\hadithdefcmd{bukhari}{4740}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، شَيْخٍ مِنَ النَّخَعِ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَطَبَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّكُمْ مَحْشُورُونَ إِلَى اللَّهِ حُفَاةً عُرَاةً غُرْلاً ‏\{‏كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ وَعْدًا عَلَيْنَا إِنَّا كُنَّا فَاعِلِينَ‏\}‏ ثُمَّ إِنَّ أَوَّلَ مَنْ يُكْسَى يَوْمَ الْقِيَامَةِ إِبْرَاهِيمُ، أَلاَ إِنَّهُ يُجَاءُ بِرِجَالٍ مِنْ أُمَّتِي، فَيُؤْخَذُ بِهِمْ ذَاتَ الشِّمَالِ، فَأَقُولُ يَا رَبِّ أَصْحَابِي فَيُقَالُ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُ ‏\{‏وَكُنْتُ عَلَيْهِمْ شَهِيدًا مَا دُمْتُ‏\}‏ إِلَى قَوْلِهِ ‏\{‏شَهِيدٌ‏\}‏ فَيُقَالُ إِنَّ هَؤُلاَءِ لَمْ يَزَالُوا مُرْتَدِّينَ عَلَى أَعْقَابِهِمْ مُنْذُ فَارَقْتَهُمْ ‏"‏‏.‏\hadithno{4740}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) delivered a sermon and said, "You (people) will be gathered before Allah (on the Day of Resurrection) bare-footed, naked and uncircumcised." (The Prophet (ﷺ) then recited):-- 'As We began the first creation We shall repeat it. (It is) a promise We have undertaken and truly We shall do it.' and added, "The first man who will be dressed on the Day of Resurrection, will be Abraham. Lo! Some men from my followers will be brought and taken towards the left side, whereupon I will say, 'O Lord, (these are) my companions!' It will be said, 'You do not know what new things they introduced (into the religion) after you.' I will then say as the righteous pious slave, Jesus, said, 'I was a witness over them while I dwelt among them...(to His Statement)..and You are the Witness to all things.' (5.117) Then it will be said, '(O Muhammad) These people never stopped to apostate since you left them}}
\hadithdefcmd{bukhari}{4741}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ يَا آدَمُ‏.‏ يَقُولُ لَبَّيْكَ رَبَّنَا وَسَعْدَيْكَ، فَيُنَادَى بِصَوْتٍ إِنَّ اللَّهَ يَأْمُرُكَ أَنْ تُخْرِجَ مِنْ ذُرِّيَّتِكَ بَعْثًا إِلَى النَّارِ‏.‏ قَالَ يَا رَبِّ وَمَا بَعْثُ النَّارِ قَالَ مِنْ كُلِّ أَلْفٍ ـ أُرَاهُ قَالَ ـ تِسْعَمِائَةٍ وَتِسْعَةً وَتِسْعِينَ فَحِينَئِذٍ تَضَعُ الْحَامِلُ حَمْلَهَا وَيَشِيبُ الْوَلِيدُ ‏\{‏وَتَرَى النَّاسَ سُكَارَى وَمَا هُمْ بِسُكَارَى وَلَكِنَّ عَذَابَ اللَّهِ شَدِيدٌ‏\}‏ ‏"‏‏.‏ فَشَقَّ ذَلِكَ عَلَى النَّاسِ حَتَّى تَغَيَّرَتْ وُجُوهُهُمْ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مِنْ يَأْجُوجَ وَمَأْجُوجَ تِسْعَمِائَةٍ وَتِسْعَةً وَتِسْعِينَ، وَمِنْكُمْ وَاحِدٌ، ثُمَّ أَنْتُمْ فِي النَّاسِ كَالشَّعْرَةِ السَّوْدَاءِ فِي جَنْبِ الثَّوْرِ الأَبْيَضِ، أَوْ كَالشَّعْرَةِ الْبَيْضَاءِ فِي جَنْبِ الثَّوْرِ الأَسْوَدِ، وَإِنِّي لأَرْجُو أَنْ تَكُونُوا رُبُعَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ فَكَبَّرْنَا ثُمَّ قَالَ ‏"‏ ثُلُثَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ فَكَبَّرْنَا ثُمَّ قَالَ ‏"‏ شَطْرَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ فَكَبَّرْنَا‏.‏ قَالَ أَبُو أُسَامَةَ عَنِ الأَعْمَشِ ‏\{‏تَرَى النَّاسَ سُكَارَى وَمَا هُمْ بِسُكَارَى‏\}‏ وَقَالَ مِنْ كُلِّ أَلْفٍ تِسْعَمِائَةٍ وَتِسْعَةً وَتِسْعِينَ‏.‏ وَقَالَ جَرِيرٌ وَعِيسَى بْنُ يُونُسَ وَأَبُو مُعَاوِيَةَ ‏\{‏سَكْرَى وَمَا هُمْ بِسَكْرَى‏\}‏‏.‏\hadithno{4741}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "On the day of Resurrection Allah will say, 'O Adam!' Adam will reply, 'Labbaik our Lord, and Sa`daik ' Then there will be a loud call (saying), Allah orders you to take from among your offspring a mission for the (Hell) Fire.' Adam will say, 'O Lord! Who are the mission for the (Hell) Fire?' Allah will say, 'Out of each thousand, take out 999.' At that time every pregnant female shall drop her load (have a miscarriage) and a child will have grey hair. And you shall see mankind as in a drunken state, yet not drunk, but severe will be the torment of Allah." (22.2) (When the Prophet (ﷺ) mentioned this), the people were so distressed (and afraid) that their faces got changed (in color) whereupon the Prophet (ﷺ) said, "From Gog and Magog nine-hundred ninety-nine will be taken out and one from you. You Muslims (compared to the large number of other people) will be like a black hair on the side of a white ox, or a white hair on the side of a black ox, and I hope that you will be onefourth of the people of Paradise." On that, we said, "Allahu-Akbar!" Then he said, "I hope that you will be one-third of the people of Paradise." We again said, "Allahu-Akbar!" Then he said, "(I hope that you will be) one-half of the people of Paradise." So we said, "Allahu Akbar}}
\hadithdefcmd{bukhari}{4742}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْحَارِثِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي حَصِينٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ ‏\{‏وَمِنَ النَّاسِ مَنْ يَعْبُدُ اللَّهَ عَلَى حَرْفٍ‏\}‏ قَالَ كَانَ الرَّجُلُ يَقْدَمُ الْمَدِينَةَ، فَإِنْ وَلَدَتِ امْرَأَتُهُ غُلاَمًا، وَنُتِجَتْ خَيْلُهُ قَالَ هَذَا دِينٌ صَالِحٌ‏.‏ وَإِنْ لَمْ تَلِدِ امْرَأَتُهُ وَلَمْ تُنْتَجْ خَيْلُهُ قَالَ هَذَا دِينُ سُوءٍ‏.‏\hadithno{4742}\hadithtrans{Narrated Ibn `Abbas:Regarding the Verse: "And among men is he who worships Allah's as it were on the very edge." (22.11). A man used to come to Medina and if his wife brought a son and his mares produces offspring, he would say, "This religion (Islam) is good," but if his wife did not give birth to a child and his mares produced no offspring, he would say, "This religion is bad}}
\hadithdefcmd{bukhari}{4743}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو هَاشِمٍ، عَنْ أَبِي مِجْلَزٍ، عَنْ قَيْسِ بْنِ عُبَادٍ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ أَنَّهُ كَانَ يُقْسِمُ فِيهَا إِنَّ هَذِهِ الآيَةَ ‏\{‏هَذَانِ خَصْمَانِ اخْتَصَمُوا فِي رَبِّهِمْ‏\}‏ نَزَلَتْ فِي حَمْزَةَ وَصَاحِبَيْهِ، وَعُتْبَةَ وَصَاحِبَيْهِ يَوْمَ بَرَزُوا فِي يَوْمِ بَدْرٍ رَوَاهُ سُفْيَانُ عَنْ أَبِي هَاشِمٍ‏.‏ وَقَالَ عُثْمَانُ عَنْ جَرِيرٍ عَنْ مَنْصُورٍ عَنْ أَبِي هَاشِمٍ عَنْ أَبِي مِجْلَزٍ قَوْلَهُ‏.‏\hadithno{4743}\hadithtrans{Narrated Qais bin Ubad:Abu Dharr used to take an oath confirming that the Verse: 'These two opponents (believers, and disbelievers) dispute with each other about their Lord.' (22.19) was Revealed in connection with Hamza and his two companions and `Utbah and his two companions on the day when they went out to the battle of Badr}}
\hadithdefcmd{bukhari}{4744}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنَا أَبُو مِجْلَزٍ، عَنْ قَيْسِ بْنِ عُبَادٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ ـ رضى الله عنه ـ قَالَ أَنَا أَوَّلُ، مَنْ يَجْثُو بَيْنَ يَدَىِ الرَّحْمَنِ لِلْخُصُومَةِ يَوْمَ الْقِيَامَةِ‏.‏ قَالَ قَيْسٌ وَفِيهِمْ نَزَلَتْ ‏\{‏هَذَانِ خَصْمَانِ اخْتَصَمُوا فِي رَبِّهِمْ‏\}‏ قَالَ هُمُ الَّذِينَ بَارَزُوا يَوْمَ بَدْرٍ عَلِيٌّ وَحَمْزَةُ وَعُبَيْدَةُ وَشَيْبَةُ بْنُ رَبِيعَةَ وَعُتْبَةُ بْنُ رَبِيعَةَ وَالْوَلِيدُ بْنُ عُتْبَةَ‏.‏\hadithno{4744}\hadithtrans{Narrated Qais bin Ubad:`Ali said, "I will be the first to kneel before the Beneficent on the Day of Resurrection because of the dispute." Qais said; This Verse: 'These two opponents (believers and disbelievers dispute with each other about their Lord,' (22.19) was revealed in connection with those who came out for the Battle of Badr, i.e. `Ali, Hamza, 'Ubaida, Shaiba bin Rabi`a, `Utba bin Rabi`a and Al-Walid bin `Utba}}
\hadithdefcmd{bukhari}{4745}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ عُوَيْمِرًا، أَتَى عَاصِمَ بْنَ عَدِيٍّ وَكَانَ سَيِّدَ بَنِي عَجْلاَنَ فَقَالَ كَيْفَ تَقُولُونَ فِي رَجُلٍ وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَصْنَعُ سَلْ لِي رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَتَى عَاصِمٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ، فَسَأَلَهُ عُوَيْمِرٌ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَرِهَ الْمَسَائِلَ وَعَابَهَا، قَالَ عُوَيْمِرٌ وَاللَّهِ لاَ أَنْتَهِي حَتَّى أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَجَاءَ عُوَيْمِرٌ فَقَالَ يَا رَسُولَ اللَّهِ رَجُلٌ وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً، أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَصْنَعُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أَنْزَلَ اللَّهُ الْقُرْآنَ فِيكَ وَفِي صَاحِبَتِكَ ‏"‏‏.‏ فَأَمَرَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمُلاَعَنَةِ بِمَا سَمَّى اللَّهُ فِي كِتَابِهِ، فَلاَعَنَهَا ثُمَّ قَالَ يَا رَسُولَ اللَّهِ، إِنْ حَبَسْتُهَا فَقَدْ ظَلَمْتُهَا، فَطَلَّقَهَا، فَكَانَتْ سُنَّةً لِمَنْ كَانَ بَعْدَهُمَا فِي الْمُتَلاَعِنَيْنِ، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْظُرُوا فَإِنْ جَاءَتْ بِهِ أَسْحَمَ أَدْعَجَ الْعَيْنَيْنِ عَظِيمَ الأَلْيَتَيْنِ خَدَلَّجَ السَّاقَيْنِ فَلاَ أَحْسِبُ عُوَيْمِرًا إِلاَّ قَدْ صَدَقَ عَلَيْهَا، وَإِنْ جَاءَتْ بِهِ أُحَيْمِرَ كَأَنَّهُ وَحَرَةٌ فَلاَ أَحْسِبُ عُوَيْمِرًا، إِلاَّ قَدْ كَذَبَ عَلَيْهَا ‏"‏‏.‏ فَجَاءَتْ بِهِ عَلَى النَّعْتِ الَّذِي نَعَتَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ تَصْدِيقِ عُوَيْمِرٍ، فَكَانَ بَعْدُ يُنْسَبُ إِلَى أُمِّهِ‏.‏\hadithno{4745}\hadithtrans{Narrated Sahl bin Sa`d:'Uwaimir came to `Asim bin `Adi who was the chief of Bani Ajlan and said, "What do you say about a man who has found another man with his wife? Should he kill him whereupon you would kill him (i.e. the husband), or what should he do? Please ask Allah's Messenger (ﷺ) about this matter on my behalf." `Asim then went to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! (And asked him that question) but Allah's Messenger (ﷺ) disliked the question," When 'Uwaimir asked `Asim (about the Prophet's answer) `Asim replied that Allah's Messenger (ﷺ) disliked such questions and considered it shameful. "Uwaimir then said, "By Allah, I will not give up asking unless I ask Allah's Messenger (ﷺ) about it." Uwaimir came (to the Prophet ) and said, "O Allah's Messenger (ﷺ)! A man has found another man with his wife! Should he kill him whereupon you would kill him (the husband, in Qisas) or what should he do?" Allah's Messenger (ﷺ) said, "Allah has revealed regarding you and your wife's case in the Qur'an "So Allah's Messenger (ﷺ) ordered them to perform the measures of Mula'ana according to what Allah had mentioned in His Book. So 'Uwaimir did Mula'ana with her and said, "O Allah's Messenger (ﷺ)! If I kept her I would oppress her." So 'Uwaimir divorced her and so divorce became a tradition after them for those who happened to be involved in a case of Mula'ana. Allah's Messenger (ﷺ) then said, "Look! If she (Uwaimir's wife) delivers a black child with deep black large eyes, big hips and fat legs, then I will be of the opinion that 'Uwaimir has spoken the truth; but if she delivers a red child looking like a Wahra then we will consider that 'Uwaimir has told a lie against her." Later on she delivered a child carrying the qualities which Allah's Messenger (ﷺ) had mentioned as a proof for 'Uwaimir's claim; therefore the child was ascribed to its mother henceforth}}
\hadithdefcmd{bukhari}{4746}{حَدَّثَنِي سُلَيْمَانُ بْنُ دَاوُدَ أَبُو الرَّبِيعِ، حَدَّثَنَا فُلَيْحٌ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَجُلاً، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، أَرَأَيْتَ رَجُلاً رَأَى مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ فَأَنْزَلَ اللَّهُ فِيهِمَا مَا ذُكِرَ فِي الْقُرْآنِ مِنَ التَّلاَعُنِ، فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ قُضِيَ فِيكَ وَفِي امْرَأَتِكَ ‏"‏‏.‏ قَالَ فَتَلاَعَنَا، وَأَنَا شَاهِدٌ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَفَارَقَهَا فَكَانَتْ سُنَّةً أَنْ يُفَرَّقَ بَيْنَ الْمُتَلاَعِنَيْنِ وَكَانَتْ حَامِلاً، فَأَنْكَرَ حَمْلَهَا وَكَانَ ابْنُهَا يُدْعَى إِلَيْهَا، ثُمَّ جَرَتِ السُّنَّةُ فِي الْمِيرَاثِ أَنْ يَرِثَهَا، وَتَرِثَ مِنْهُ مَا فَرَضَ اللَّهُ لَهَا‏.‏\hadithno{4746}\hadithtrans{Narrated Sahl bin Sa`d:A man came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Suppose a man saw another man with his wife, should he kill him whereupon you might kill him (i.e. the killer) (in Qisas) or what should he do?" So Allah revealed concerning their case what is mentioned of the order of Mula'ana. Allah's Apostle said to the man, "The matter between you and your wife has been decided." So they did Mula'ana in the presence of Allah's Messenger (ﷺ) and I was present there, and then the man divorced his wife. So it became a tradition to dissolve the marriage of those spouses who were involved in a case of Mula'ana. The woman was pregnant and the husband denied that he was the cause of her pregnancy, so the son was (later) ascribed to her. Then it became a tradition that such a son would be the heir of his mother, and she would inherit of him what Allah prescribed for her}}
\hadithdefcmd{bukhari}{4747}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامِ بْنِ حَسَّانَ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ هِلاَلَ بْنَ أُمَيَّةَ، قَذَفَ امْرَأَتَهُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم بِشَرِيكِ بْنِ سَحْمَاءَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْبَيِّنَةَ أَوْ حَدٌّ فِي ظَهْرِكَ ‏"‏‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِذَا رَأَى أَحَدُنَا عَلَى امْرَأَتِهِ رَجُلاً يَنْطَلِقُ يَلْتَمِسُ الْبَيِّنَةَ‏.‏ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ الْبَيِّنَةَ وَإِلاَّ حَدٌّ فِي ظَهْرِكَ ‏"‏ فَقَالَ هِلاَلٌ وَالَّذِي بَعَثَكَ بِالْحَقِّ إِنِّي لَصَادِقٌ، فَلَيُنْزِلَنَّ اللَّهُ مَا يُبَرِّئُ ظَهْرِي مِنَ الْحَدِّ، فَنَزَلَ جِبْرِيلُ، وَأَنْزَلَ عَلَيْهِ ‏\{‏وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ‏\}‏ فَقَرَأَ حَتَّى بَلَغَ ‏\{‏إِنْ كَانَ مِنَ الصَّادِقِينَ‏\}‏ فَانْصَرَفَ النَّبِيُّ صلى الله عليه وسلم فَأَرْسَلَ إِلَيْهَا فَجَاءَ هِلاَلٌ، فَشَهِدَ، وَالنَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ اللَّهَ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏‏.‏ ثُمَّ قَامَتْ فَشَهِدَتْ فَلَمَّا كَانَتْ عِنْدَ الْخَامِسَةِ وَقَّفُوهَا، وَقَالُوا إِنَّهَا مُوجِبَةٌ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَتَلَكَّأَتْ وَنَكَصَتْ حَتَّى ظَنَنَّا أَنَّهَا تَرْجِعُ ثُمَّ قَالَتْ لاَ أَفْضَحُ قَوْمِي سَائِرَ الْيَوْمِ، فَمَضَتْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبْصِرُوهَا فَإِنْ جَاءَتْ بِهِ أَكْحَلَ الْعَيْنَيْنِ سَابِغَ الأَلْيَتَيْنِ خَدَلَّجَ السَّاقَيْنِ، فَهْوَ لِشَرِيكِ بْنِ سَحْمَاءَ ‏"‏‏.‏ فَجَاءَتْ بِهِ كَذَلِكَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْلاَ مَا مَضَى مِنْ كِتَابِ اللَّهِ لَكَانَ لِي وَلَهَا شَأْنٌ ‏"‏‏.‏\hadithno{4747}\hadithtrans{Narrated Ibn `Abbas:Hilal bin Umaiya accused his wife of committing illegal sexual intercourse with Sharik bin Sahma' and filed the case before the Prophet. The Prophet (ﷺ) said (to Hilal), "Either you bring forth a proof (four witnesses) or you will receive the legal punishment (lashes) on your back." Hilal said, "O Allah's Apostle! If anyone of us saw a man over his wife, would he go to seek after witnesses?" The Prophet (ﷺ) kept on saying, "Either you bring forth the witnesses or you will receive the legal punishment (lashes) on your back." Hilal then said, "By Him Who sent you with the Truth, I am telling the truth and Allah will reveal to you what will save my back from legal punishment." Then Gabriel came down and revealed to him:-- 'As for those who accuse their wives...' (24.6-9) The Prophet (ﷺ) recited it till he reached: '... (her accuser) is telling the truth.' Then the Prophet (ﷺ) left and sent for the woman, and Hilal went (and brought) her and then took the oaths (confirming the claim). The Prophet (ﷺ) was saying, "Allah knows that one of you is a liar, so will any of you repent?" Then the woman got up and took the oaths and when she was going to take the fifth one, the people stopped her and said, "It (the fifth oath) will definitely bring Allah's curse on you (if you are guilty)." So she hesitated and recoiled (from taking the oath) so much that we thought that she would withdraw her denial. But then she said, "I will not dishonor my family all through these days," and carried on (the process of taking oaths). The Prophet (ﷺ) then said, "Watch her; if she delivers a black-eyed child with big hips and fat shins then it is Sharik bin Sahma's child." Later she delivered a child of that description. So the Prophet (ﷺ) said, "If the case was not settled by Allah's Law, I would punish her severely}}
\hadithdefcmd{bukhari}{4748}{حَدَّثَنَا مُقَدَّمُ بْنُ مُحَمَّدِ بْنِ يَحْيَى، حَدَّثَنَا عَمِّي الْقَاسِمُ بْنُ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، وَقَدْ سَمِعَ مِنْهُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَجُلاً، رَمَى امْرَأَتَهُ فَانْتَفَى مِنْ وَلَدِهَا فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَلاَعَنَا كَمَا قَالَ اللَّهُ، ثُمَّ قَضَى بِالْوَلَدِ لِلْمَرْأَةِ وَفَرَّقَ بَيْنَ الْمُتَلاَعِنَيْنِ‏.‏\hadithno{4748}\hadithtrans{Narrated Ibn `Umar:A man accused his wife of illegal sexual intercourse and denied his paternity to her (conceived) child during the lifetime of Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) ordered them both to do Mula'ana as Allah decreed and then gave his decision that the child would be for the mother, and a divorce decree was issued for the couple involved in a case of Mula'ana}}
\hadithdefcmd{bukhari}{4749}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها – ‏\{‏وَالَّذِي تَوَلَّى كِبْرَهُ‏\}‏ قَالَتْ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ‏.‏\hadithno{4749}\hadithtrans{Narrated `Aisha:And as for him among them who had the greater share..' (24.11) was `Abdullah bin Ubai bin Salul}}
\hadithdefcmd{bukhari}{4750}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، وَعَلْقَمَةُ بْنُ وَقَّاصٍ، وَعُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ حَدِيثِ، عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ مَا قَالُوا، فَبَرَّأَهَا اللَّهُ مِمَّا قَالُوا وَكُلٌّ حَدَّثَنِي طَائِفَةً مِنَ الْحَدِيثِ، وَبَعْضُ حَدِيثِهِمْ يُصَدِّقُ بَعْضًا، وَإِنْ كَانَ بَعْضُهُمْ أَوْعَى لَهُ مِنْ بَعْضٍ الَّذِي حَدَّثَنِي عُرْوَةُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَخْرُجَ أَقْرَعَ بَيْنَ أَزْوَاجِهِ، فَأَيَّتُهُنَّ خَرَجَ سَهْمُهَا خَرَجَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَهُ، قَالَتْ عَائِشَةُ فَأَقْرَعَ بَيْنَنَا فِي غَزْوَةٍ غَزَاهَا، فَخَرَجَ سَهْمِي، فَخَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ مَا نَزَلَ الْحِجَابُ، فَأَنَا أُحْمَلُ فِي هَوْدَجِي وَأُنْزَلُ فِيهِ فَسِرْنَا حَتَّى إِذَا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ غَزْوَتِهِ تِلْكَ وَقَفَلَ، وَدَنَوْنَا مِنَ الْمَدِينَةِ قَافِلِينَ آذَنَ لَيْلَةً بِالرَّحِيلِ، فَقُمْتُ حِينَ آذَنُوا بِالرَّحِيلِ، فَمَشَيْتُ حَتَّى جَاوَزْتُ الْجَيْشَ، فَلَمَّا قَضَيْتُ شَأْنِي أَقْبَلْتُ إِلَى رَحْلِي، فَإِذَا عِقْدٌ لِي مِنْ جَزْعِ ظَفَارِ قَدِ انْقَطَعَ فَالْتَمَسْتُ عِقْدِي وَحَبَسَنِي ابْتِغَاؤُهُ وَأَقْبَلَ الرَّهْطُ الَّذِينَ كَانُوا يَرْحَلُونَ لِي، فَاحْتَمَلُوا هَوْدَجِي، فَرَحَلُوهُ عَلَى بَعِيرِي الَّذِي كُنْتُ رَكِبْتُ، وَهُمْ يَحْسِبُونَ أَنِّي فِيهِ، وَكَانَ النِّسَاءُ إِذْ ذَاكَ خِفَافًا لَمْ يُثْقِلْهُنَّ اللَّحْمُ، إِنَّمَا تَأْكُلُ الْعُلْقَةَ مِنَ الطَّعَامِ فَلَمْ يَسْتَنْكِرِ الْقَوْمُ خِفَّةَ الْهَوْدَجِ حِينَ رَفَعُوهُ، وَكُنْتُ جَارِيَةً حَدِيثَةَ السِّنِّ، فَبَعَثُوا الْجَمَلَ وَسَارُوا، فَوَجَدْتُ عِقْدِي بَعْدَ مَا اسْتَمَرَّ الْجَيْشُ، فَجِئْتُ مَنَازِلَهُمْ، وَلَيْسَ بِهَا دَاعٍ وَلاَ مُجِيبٌ، فَأَمَمْتُ مَنْزِلِي الَّذِي كُنْتُ بِهِ وَظَنَنْتُ أَنَّهُمْ سَيَفْقِدُونِي فَيَرْجِعُونَ إِلَىَّ فَبَيْنَا أَنَا جَالِسَةٌ فِي مَنْزِلِي غَلَبَتْنِي عَيْنِي فَنِمْتُ، وَكَانَ صَفْوَانُ بْنُ الْمُعَطَّلِ السُّلَمِيُّ ثُمَّ الذَّكْوَانِيُّ مِنْ وَرَاءِ الْجَيْشِ، فَأَدْلَجَ فَأَصْبَحَ عِنْدَ مَنْزِلِي، فَرَأَى سَوَادَ إِنْسَانٍ نَائِمٍ، فَأَتَانِي فَعَرَفَنِي حِينَ رَآنِي، وَكَانَ يَرَانِي قَبْلَ الْحِجَابِ، فَاسْتَيْقَظْتُ بِاسْتِرْجَاعِهِ حِينَ عَرَفَنِي فَخَمَّرْتُ وَجْهِي بِجِلْبَابِي، وَاللَّهِ مَا كَلَّمَنِي كَلِمَةً وَلاَ سَمِعْتُ مِنْهُ كَلِمَةً غَيْرَ اسْتِرْجَاعِهِ، حَتَّى أَنَاخَ رَاحِلَتَهُ فَوَطِئَ عَلَى يَدَيْهَا فَرَكِبْتُهَا فَانْطَلَقَ يَقُودُ بِي الرَّاحِلَةَ حَتَّى أَتَيْنَا الْجَيْشَ، بَعْدَ مَا نَزَلُوا مُوغِرِينَ فِي نَحْرِ الظَّهِيرَةِ، فَهَلَكَ مَنْ هَلَكَ، وَكَانَ الَّذِي تَوَلَّى الإِفْكَ عَبْدَ اللَّهِ بْنَ أُبَىٍّ ابْنَ سَلُولَ فَقَدِمْنَا الْمَدِينَةَ، فَاشْتَكَيْتُ حِينَ قَدِمْتُ شَهْرًا، وَالنَّاسُ يُفِيضُونَ فِي قَوْلِ أَصْحَابِ الإِفْكِ، لاَ أَشْعُرُ بِشَىْءٍ مِنْ ذَلِكَ، وَهْوَ يَرِيبُنِي فِي وَجَعِي أَنِّي لاَ أَعْرِفُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم اللَّطَفَ الَّذِي كُنْتُ أَرَى مِنْهُ حِينَ أَشْتَكِي، إِنَّمَا يَدْخُلُ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَيُسَلِّمُ ثُمَّ يَقُولُ ‏"‏ كَيْفَ تِيكُمْ ‏"‏‏.‏ ثُمَّ يَنْصَرِفُ، فَذَاكَ الَّذِي يَرِيبُنِي، وَلاَ أَشْعُرُ حَتَّى خَرَجْتُ بَعْدَ مَا نَقَهْتُ، فَخَرَجَتْ مَعِي أُمُّ مِسْطَحٍ قِبَلَ الْمَنَاصِعِ، وَهْوَ مُتَبَرَّزُنَا، وَكُنَّا لاَ نَخْرُجُ إِلاَّ لَيْلاً إِلَى لَيْلٍ، وَذَلِكَ قَبْلَ أَنْ نَتَّخِذَ الْكُنُفَ قَرِيبًا مِنْ بُيُوتِنَا، وَأَمْرُنَا أَمْرُ الْعَرَبِ الأُوَلِ فِي التَّبَرُّزِ قِبَلَ الْغَائِطِ، فَكُنَّا نَتَأَذَّى بِالْكُنُفِ أَنْ نَتَّخِذَهَا عِنْدَ بُيُوتِنَا فَانْطَلَقْتُ أَنَا وَأُمُّ مِسْطَحٍ، وَهْىَ ابْنَةُ أَبِي رُهْمِ بْنِ عَبْدِ مَنَافٍ، وَأُمُّهَا بِنْتُ صَخْرِ بْنِ عَامِرٍ خَالَةُ أَبِي بَكْرٍ الصِّدِّيقِ، وَابْنُهَا مِسْطَحُ بْنُ أُثَاثَةَ، فَأَقْبَلْتُ أَنَا وَأُمُّ مِسْطَحٍ قِبَلَ بَيْتِي، قَدْ فَرَغْنَا مِنْ شَأْنِنَا، فَعَثَرَتْ أُمُّ مِسْطَحٍ فِي مِرْطِهَا فَقَالَتْ تَعِسَ مِسْطَحٌ‏.‏ فَقُلْتُ لَهَا بِئْسَ مَا قُلْتِ أَتَسُبِّينَ رَجُلاً شَهِدَ بَدْرًا قَالَتْ أَىْ هَنْتَاهُ، أَوَلَمْ تَسْمَعِي مَا قَالَ قَالَتْ قُلْتُ وَمَا قَالَ فَأَخْبَرَتْنِي بِقَوْلِ أَهْلِ الإِفْكِ فَازْدَدْتُ مَرَضًا عَلَى مَرَضِي، فَلَمَّا رَجَعْتُ إِلَى بَيْتِي وَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم تَعْنِي سَلَّمَ ثُمَّ قَالَ ‏"‏ كَيْفَ تِيكُمْ ‏"‏‏.‏ فَقُلْتُ أَتَأْذَنُ لِي أَنْ آتِيَ أَبَوَىَّ قَالَتْ وَأَنَا حِينَئِذٍ أُرِيدُ أَنْ أَسْتَيْقِنَ الْخَبَرَ مِنْ قِبَلِهِمَا، قَالَتْ فَأَذِنَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَجِئْتُ أَبَوَىَّ فَقُلْتُ لأُمِّي يَا أُمَّتَاهْ، مَا يَتَحَدَّثُ النَّاسُ قَالَتْ يَا بُنَيَّةُ، هَوِّنِي عَلَيْكَ فَوَاللَّهِ، لَقَلَّمَا كَانَتِ امْرَأَةٌ قَطُّ وَضِيئَةً عِنْدَ رَجُلٍ يُحِبُّهَا وَلَهَا ضَرَائِرُ إِلاَّ كَثَّرْنَ عَلَيْهَا‏.‏ قَالَتْ فَقُلْتُ سُبْحَانَ اللَّهِ وَلَقَدْ تَحَدَّثَ النَّاسُ بِهَذَا قَالَتْ فَبَكَيْتُ تِلْكَ اللَّيْلَةَ حَتَّى أَصْبَحْتُ لاَ يَرْقَأُ لِي دَمْعٌ، وَلاَ أَكْتَحِلُ بِنَوْمٍ حَتَّى أَصْبَحْتُ أَبْكِي فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيَّ بْنَ أَبِي طَالِبٍ، وَأُسَامَةَ بْنَ زَيْدٍ ـ رضى الله عنهما ـ حِينَ اسْتَلْبَثَ الْوَحْىُ، يَسْتَأْمِرُهُمَا فِي فِرَاقِ أَهْلِهِ، قَالَتْ فَأَمَّا أُسَامَةُ بْنُ زَيْدٍ فَأَشَارَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِالَّذِي يَعْلَمُ مِنْ بَرَاءَةِ أَهْلِهِ، وَبِالَّذِي يَعْلَمُ لَهُمْ فِي نَفْسِهِ مِنَ الْوُدِّ، فَقَالَ يَا رَسُولَ اللَّهِ، أَهْلَكَ، وَمَا نَعْلَمُ إِلاَّ خَيْرًا، وَأَمَّا عَلِيُّ بْنُ أَبِي طَالِبٍ فَقَالَ يَا رَسُولَ اللَّهِ، لَمْ يُضَيِّقِ اللَّهُ عَلَيْكَ وَالنِّسَاءُ سِوَاهَا كَثِيرٌ، وَإِنْ تَسْأَلِ الْجَارِيَةَ تَصْدُقْكَ، قَالَتْ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَرِيرَةَ فَقَالَ ‏"‏ أَىْ بَرِيرَةُ، هَلْ رَأَيْتِ عَلَيْهَا مِنْ شَىْءٍ يَرِيبُكِ ‏"‏‏.‏ قَالَتْ بَرِيرَةُ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ، إِنْ رَأَيْتُ عَلَيْهَا أَمْرًا أَغْمِصُهُ عَلَيْهَا أَكْثَرَ مِنْ أَنَّهَا جَارِيَةٌ حَدِيثَةُ السِّنِّ، تَنَامُ عَنْ عَجِينِ أَهْلِهَا، فَتَأْتِي الدَّاجِنُ فَتَأْكُلُهُ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاسْتَعْذَرَ يَوْمَئِذٍ مِنْ عَبْدِ اللَّهِ بْنِ أُبَىٍّ ابْنِ سَلُولَ، قَالَتْ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ عَلَى الْمِنْبَرِ ‏"‏ يَا مَعْشَرَ الْمُسْلِمِينَ مَنْ يَعْذِرُنِي مِنْ رَجُلٍ، قَدْ بَلَغَنِي أَذَاهُ فِي أَهْلِ بَيْتِي، فَوَاللَّهِ مَا عَلِمْتُ عَلَى أَهْلِي إِلاَّ خَيْرًا، وَلَقَدْ ذَكَرُوا رَجُلاً، مَا عَلِمْتُ عَلَيْهِ إِلاَّ خَيْرًا، وَمَا كَانَ يَدْخُلُ عَلَى أَهْلِي إِلاَّ مَعِي ‏"‏‏.‏ فَقَامَ سَعْدُ بْنُ مُعَاذٍ الأَنْصَارِيُّ، فَقَالَ يَا رَسُولَ اللَّهِ أَنَا أَعْذِرُكَ مِنْهُ، إِنْ كَانَ مِنَ الأَوْسِ، ضَرَبْتُ عُنُقَهُ، وَإِنْ كَانَ مِنْ إِخْوَانِنَا مِنَ الْخَزْرَجِ، أَمَرْتَنَا، فَفَعَلْنَا أَمْرَكَ، قَالَتْ فَقَامَ سَعْدُ بْنُ عُبَادَةَ وَهْوَ سَيِّدُ الْخَزْرَجِ، وَكَانَ قَبْلَ ذَلِكَ رَجُلاً صَالِحًا، وَلَكِنِ احْتَمَلَتْهُ الْحَمِيَّةُ فَقَالَ لِسَعْدٍ كَذَبْتَ، لَعَمْرُ اللَّهِ لاَ تَقْتُلُهُ، وَلاَ تَقْدِرُ عَلَى قَتْلِهِ، فَقَامَ أُسَيْدُ بْنُ حُضَيْرٍ وَهْوَ ابْنُ عَمِّ سَعْدٍ، فَقَالَ لِسَعْدِ بْنِ عُبَادَةَ كَذَبْتَ، لَعَمْرُ اللَّهِ لَنَقْتُلَنَّهُ، فَإِنَّكَ مُنَافِقٌ تُجَادِلُ عَنِ الْمُنَافِقِينَ، فَتَثَاوَرَ الْحَيَّانِ الأَوْسُ وَالْخَزْرَجُ حَتَّى هَمُّوا أَنْ يَقْتَتِلُوا، وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ عَلَى الْمِنْبَرِ، فَلَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم يُخَفِّضُهُمْ حَتَّى سَكَتُوا وَسَكَتَ، قَالَتْ فَمَكُثْتُ يَوْمِي ذَلِكَ لاَ يَرْقَأُ لِي دَمْعٌ وَلاَ أَكْتَحِلُ بِنَوْمٍ، قَالَتْ فَأَصْبَحَ أَبَوَاىَ عِنْدِي ـ وَقَدْ بَكَيْتُ لَيْلَتَيْنِ وَيَوْمًا لاَ أَكْتَحِلُ بِنَوْمٍ وَلاَ يَرْقَأُ لِي دَمْعٌ ـ يَظُنَّانِ أَنَّ الْبُكَاءَ فَالِقٌ كَبِدِي، قَالَتْ فَبَيْنَمَا هُمَا جَالِسَانِ عِنْدِي وَأَنَا أَبْكِي، فَاسْتَأْذَنَتْ عَلَىَّ امْرَأَةٌ مِنَ الأَنْصَارِ، فَأَذِنْتُ لَهَا، فَجَلَسَتْ تَبْكِي مَعِي، قَالَتْ فَبَيْنَا نَحْنُ عَلَى ذَلِكَ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَلَّمَ ثُمَّ جَلَسَ قَالَتْ وَلَمْ يَجْلِسْ عِنْدِي مُنْذُ قِيلَ مَا قِيلَ قَبْلَهَا، وَقَدْ لَبِثَ شَهْرًا، لاَ يُوحَى إِلَيْهِ فِي شَأْنِي، قَالَتْ فَتَشَهَّدَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ جَلَسَ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ يَا عَائِشَةُ، فَإِنَّهُ قَدْ بَلَغَنِي عَنْكِ كَذَا وَكَذَا، فَإِنْ كُنْتِ بَرِيئَةً فَسَيُبَرِّئُكِ اللَّهُ، وَإِنْ كُنْتِ أَلْمَمْتِ بِذَنْبٍ فَاسْتَغْفِرِي اللَّهَ وَتُوبِي إِلَيْهِ، فَإِنَّ الْعَبْدَ إِذَا اعْتَرَفَ بِذَنْبِهِ ثُمَّ تَابَ إِلَى اللَّهِ تَابَ اللَّهُ عَلَيْهِ ‏"‏‏.‏ قَالَتْ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَقَالَتَهُ، قَلَصَ دَمْعِي حَتَّى مَا أُحِسُّ مِنْهُ قَطْرَةً، فَقُلْتُ لأَبِي أَجِبْ رَسُولَ اللَّهِ صلى الله عليه وسلم فِيمَا قَالَ‏.‏ قَالَ وَاللَّهِ مَا أَدْرِي مَا أَقُولُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لأُمِّي أَجِيبِي رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَتْ مَا أَدْرِي مَا أَقُولُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ فَقُلْتُ وَأَنَا جَارِيَةٌ حَدِيثَةُ السِّنِّ لاَ أَقْرَأُ كَثِيرًا مِنَ الْقُرْآنِ، إِنِّي وَاللَّهِ لَقَدْ عَلِمْتُ لَقَدْ سَمِعْتُمْ هَذَا الْحَدِيثَ حَتَّى اسْتَقَرَّ فِي أَنْفُسِكُمْ، وَصَدَّقْتُمْ بِهِ فَلَئِنْ قُلْتُ لَكُمْ إِنِّي بَرِيئَةٌ وَاللَّهُ يَعْلَمُ أَنِّي بَرِيئَةٌ لاَ تُصَدِّقُونِي بِذَلِكَ، وَلَئِنِ اعْتَرَفْتُ لَكُمْ بِأَمْرٍ، وَاللَّهُ يَعْلَمُ أَنِّي مِنْهُ بَرِيئَةٌ لَتُصَدِّقُنِّي، وَاللَّهِ مَا أَجِدُ لَكُمْ مَثَلاً إِلاَّ قَوْلَ أَبِي يُوسُفَ قَالَ ‏\{‏فَصَبْرٌ جَمِيلٌ وَاللَّهُ الْمُسْتَعَانُ عَلَى مَا تَصِفُونَ‏\}‏ قَالَتْ ثُمَّ تَحَوَّلْتُ فَاضْطَجَعْتُ عَلَى فِرَاشِي، قَالَتْ وَأَنَا حِينَئِذٍ أَعْلَمُ أَنِّي بَرِيئَةٌ، وَأَنَّ اللَّهَ مُبَرِّئِي بِبَرَاءَتِي، وَلَكِنْ وَاللَّهِ مَا كُنْتُ أَظُنُّ أَنَّ اللَّهَ مُنْزِلٌ فِي شَأْنِي وَحْيًا يُتْلَى، وَلَشَأْنِي فِي نَفْسِي كَانَ أَحْقَرَ مِنْ أَنْ يَتَكَلَّمَ اللَّهُ فِيَّ بِأَمْرٍ يُتْلَى، وَلَكِنْ كُنْتُ أَرْجُو أَنْ يَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّوْمِ رُؤْيَا يُبَرِّئُنِي اللَّهُ بِهَا، قَالَتْ فَوَاللَّهِ مَا رَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ خَرَجَ أَحَدٌ مِنْ أَهْلِ الْبَيْتِ حَتَّى أُنْزِلَ عَلَيْهِ، فَأَخَذَهُ مَا كَانَ يَأْخُذُهُ مِنَ الْبُرَحَاءِ حَتَّى إِنَّهُ لَيَتَحَدَّرُ مِنْهُ مِثْلُ الْجُمَانِ مِنَ الْعَرَقِ، وَهْوَ فِي يَوْمٍ شَاتٍ مِنْ ثِقَلِ الْقَوْلِ الَّذِي يُنْزَلُ عَلَيْهِ، قَالَتْ فَلَمَّا سُرِّيَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سُرِّيَ عَنْهُ وَهْوَ يَضْحَكُ، فَكَانَتْ أَوَّلُ كَلِمَةٍ تَكَلَّمَ بِهَا ‏"‏ يَا عَائِشَةُ، أَمَّا اللَّهُ عَزَّ وَجَلَّ فَقَدْ بَرَّأَكِ ‏"‏‏.‏ فَقَالَتْ أُمِّي قُومِي إِلَيْهِ‏.‏ قَالَتْ فَقُلْتُ وَاللَّهِ، لاَ أَقُومُ إِلَيْهِ، وَلاَ أَحْمَدُ إِلاَّ اللَّهَ عَزَّ وَجَلَّ‏.‏ وَأَنْزَلَ اللَّهُ ‏\{‏إِنَّ الَّذِينَ جَاءُوا بِالإِفْكِ عُصْبَةٌ مِنْكُمْ لاَ تَحْسِبُوهُ‏\}‏ الْعَشْرَ الآيَاتِ كُلَّهَا، فَلَمَّا أَنْزَلَ اللَّهُ هَذَا فِي بَرَاءَتِي قَالَ أَبُو بَكْرٍ الصِّدِّيقُ ـ رضى الله عنه ـ وَكَانَ يُنْفِقُ عَلَى مِسْطَحِ بْنِ أُثَاثَةَ لِقَرَابَتِهِ مِنْهُ، وَفَقْرِهِ وَاللَّهِ لاَ أُنْفِقُ عَلَى مِسْطَحٍ شَيْئًا أَبَدًا بَعْدَ الَّذِي قَالَ لِعَائِشَةَ مَا قَالَ، فَأَنْزَلَ اللَّهُ ‏\{‏وَلاَ يَأْتَلِ أُولُو الْفَضْلِ مِنْكُمْ وَالسَّعَةِ أَنْ يُؤْتُوا أُولِي الْقُرْبَى وَالْمَسَاكِينَ وَالْمُهَاجِرِينَ فِي سَبِيلِ اللَّهِ وَلْيَعْفُوا وَلْيَصْفَحُوا أَلاَ تُحِبُّونَ أَنْ يَغْفِرَ اللَّهُ لَكُمْ وَاللَّهُ غَفُورٌ رَحِيمٌ‏\}‏ قَالَ أَبُو بَكْرٍ بَلَى، وَاللَّهِ إِنِّي أُحِبُّ أَنْ يَغْفِرَ اللَّهُ لِي، فَرَجَعَ إِلَى مِسْطَحٍ النَّفَقَةَ الَّتِي كَانَ يُنْفِقُ عَلَيْهِ، وَقَالَ وَاللَّهِ لاَ أَنْزِعُهَا مِنْهُ أَبَدًا‏.‏ قَالَتْ عَائِشَةُ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْأَلُ زَيْنَبَ ابْنَةَ جَحْشٍ عَنْ أَمْرِي، فَقَالَ ‏"‏ يَا زَيْنَبُ مَاذَا عَلِمْتِ أَوْ رَأَيْتِ ‏"‏‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ، أَحْمِي سَمْعِي وَبَصَرِي، مَا عَلِمْتُ إِلاَّ خَيْرًا‏.‏ قَالَتْ وَهْىَ الَّتِي كَانَتْ تُسَامِينِي مِنْ أَزْوَاجِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَصَمَهَا اللَّهُ بِالْوَرَعِ، وَطَفِقَتْ أُخْتُهَا حَمْنَةُ تُحَارِبُ لَهَا فَهَلَكَتْ فِيمَنْ هَلَكَ مِنْ أَصْحَابِ الإِفْكِ‏.‏\hadithno{4750}\hadithtrans{Narrated Aisha:(The wife of the Prophet) Whenever Allah's Messenger (ﷺ) intended to go on a journey, he used to draw lots among his wives and would take with him the one on whom the lot had fallen. Once he drew lots when he wanted to carry out a Ghazwa, and the lot came upon me. So I proceeded with Allah's Apostle after Allah's order of veiling (the women) had been revealed and thus I was carried in my howdah (on a camel) and dismounted while still in it. We carried on our journey, and when Allah's Apostle had finished his Ghazwa and returned and we approached Medina, Allah's Messenger (ﷺ) ordered to proceed at night. When the army was ordered to resume the homeward journey, I got up and walked on till I left the army (camp) behind. When I had answered the call of nature, I went towards my howdah, but behold ! A necklace of mine made of Jaz Azfar (a kind of black bead) was broken and I looked for it and my search for it detained me. The group of people who used to carry me, came and carried my howdah on to the back of my camel on which I was riding, considering that I was therein. At that time women were light in weight and were not fleshy for they used to eat little (food), so those people did not feel the lightness of the howdah while raising it up, and I was still a young lady. They drove away the camel and proceeded. Then I found my necklace after the army had gone. I came to their camp but found nobody therein so I went to the place where I used to stay, thinking that they would miss me and come back in my search. While I was sitting at my place, I felt sleepy and slept. Safwan bin Al-Mu'attil As-Sulami Adh- Dhakw-ani was behind the army. He had started in the last part of the night and reached my stationing place in the morning and saw the figure of a sleeping person. He came to me and recognized me on seeing me for he used to see me before veiling. I got up because of his saying: "Inna Li l-lahi wa inna ilaihi rajiun," which he uttered on recognizing me. I covered my face with my garment, and by Allah, he did not say to me a single word except, "Inna Li l-lahi wa inna ilaihi rajiun," till he made his she-camel kneel down whereupon he trod on its forelegs and I mounted it. Then Safwan set out, leading the she-camel that was carrying me, till we met the army while they were resting during the hot midday. Then whoever was meant for destruction, fell in destruction, and the leader of the Ifk (forged statement) was `Abdullah bin Ubai bin Salul. After this we arrived at Medina and I became ill for one month while the people were spreading the forged statements of the people of the Ifk, and I was not aware of anything thereof. But what aroused my doubt while I was sick, was that I was no longer receiving from Allah's Messenger (ﷺ) the same kindness as I used to receive when I fell sick. Allah's Messenger (ﷺ) would enter upon me, say a greeting and add, "How is that (lady)?" and then depart. That aroused my suspicion but I was not aware of the propagated evil till I recovered from my ailment. I went out with Um Mistah to answer the call of nature towards Al-Manasi, the place where we used to relieve ourselves, and used not to go out for this purpose except from night to night, and that was before we had lavatories close to our houses. And this habit of ours was similar to the habit of the old 'Arabs (in the deserts or in the tents) concerning the evacuation of the bowels, for we considered it troublesome and harmful to take lavatories in the houses. So I went out with Um Mistah who was the daughter of Abi Ruhm bin `Abd Manaf, and her mother was daughter of Sakhr bin Amir who was the aunt of Abi Bakr As-Siddiq, and her son was Mistah bin Uthatha. When we had finished our affair, Um Mistah and I came back towards my house. Um Mistah stumbled over her robe whereupon she said, "Let Mistah be ruined ! " I said to her, "What a bad word you have said! Do you abuse a man who has taken part in the Battle of Badr?' She said, "O you there! Didn't you hear what he has said?" I said, "And what did he say?" She then told me the statement of the people of the Ifk (forged statement) which added to my ailment. When I returned home, Allah's Messenger (ﷺ) came to me, and after greeting, he said, "How is that (lady)?" I said, "Will you allow me to go to my parents?" At that time I intended to be sure of the news through them. Allah's Messenger (ﷺ) allowed me and I went to my parents and asked my mother, "O my mother! What are the people talking about?" My mother said, "O my daughter! Take it easy, for by Allah, there is no charming lady who is loved by her husband who has other wives as well, but that those wives would find fault with her." I said, "Subhan Allah! Did the people really talk about that?" That night I kept on weeping the whole night till the morning. My tears never stopped, nor did I sleep, and morning broke while I was still weeping, Allah's Messenger (ﷺ) called `Ali bin Abi Talib and Usama bin Zaid when the Divine Inspiration delayed, in order to consult them as to the idea of divorcing his wife. Usama bin Zaid told Allah's Messenger (ﷺ) of what he knew about the innocence of his wife and of his affection he kept for her. He said, "O Allah's Messenger (ﷺ)! She is your wife, and we do not know anything about her except good." But `Ali bin Abi Talib said, "O Allah's Messenger (ﷺ)! Allah does not impose restrictions on you; and there are plenty of women other than her. If you however, ask (her) slave girl, she will tell you the truth." `Aisha added: So Allah's Messenger (ﷺ) called for Barira and said, "O Barira! Did you ever see anything which might have aroused your suspicion? (as regards Aisha). Barira said, "By Allah Who has sent you with the truth, I have never seen anything regarding Aisha which I would blame her for except that she is a girl of immature age who sometimes sleeps and leaves the dough of her family unprotected so that the domestic goats come and eat it." So Allah's Messenger (ﷺ) got up (and addressed) the people and asked for somebody who would take revenge on `Abdullah bin Ubai bin Salul then. Allah's Messenger (ﷺ), while on the pulpit, said, "O Muslims! Who will help me against a man who has hurt me by slandering my family? By Allah, I know nothing except good about my family, and people have blamed a man of whom I know nothing except good, and he never used to visit my family except with me," Sa`d bin Mu`adh Al-Ansari got up and said, "O Allah's Messenger (ﷺ)! By Allah, I will relieve you from him. If he be from the tribe of (Bani) Al-Aus, then I will chop his head off; and if he be from our brethren, the Khazraj, then you give us your order and we will obey it." On that, Sa`d bin 'Ubada got up, and he was the chief of the Khazraj, and before this incident he had been a pious man but he was incited by his zeal for his tribe. He said to Sa`d (bin Mu`adh), "By Allah the Eternal, you have told a lie! You shall not kill him and you will never be able to kill him!" On that, Usaid bin Hudair, the cousin of Sa`d (bin Mu`adh) got up and said to Sa`d bin 'Ubada, "You are a liar! By Allah the Eternal, we will surely kill him; and you are a hypocrite defending the hypocrites!" So the two tribes of Al-Aus and Al-Khazraj got excited till they were on the point of fighting with each other while Allah's Messenger (ﷺ) was standing on the pulpit. Allah's Messenger (ﷺ) continued quietening them till they became silent whereupon he became silent too. On that day I kept on weeping so much that neither did my tears stop, nor could I sleep. In the morning my parents were with me, and I had wept for two nights and a day without sleeping and with incessant tears till they thought that my liver would burst with weeping. While they were with me and I was weeping, an Ansari woman asked permission to see me. I admitted her and she sat and started weeping with me. While I was in that state, Allah's Apostle came to us, greeted, and sat down. He had never sat with me since the day what was said, was said. He had stayed a month without receiving any Divine Inspiration concerning my case. Allah's Messenger (ﷺ) recited the Tashahhud after he had sat down, and then said, "Thereafter, O `Aisha! I have been informed such and-such a thing about you; and if you are innocent, Allah will reveal your innocence, and if you have committed a sin, then ask for Allah's forgiveness and repent to Him, for when a slave confesses his sin and then repents to Allah, Allah accepts his repentance." When Allah's Apostle had finished his speech, my tears ceased completely so that I no longer felt even a drop thereof. Then I said to my father, "Reply to Allah's Messenger (ﷺ) on my behalf as to what he said." He said, "By Allah, I do not know what to say to Allah's Messenger (ﷺ)." Then I said to my mother, "Reply to Allah's Apostle." She said, "I do not know what to say to Allah's Messenger (ﷺ)." Still a young girl as I was and though I had little knowledge of Qur'an, I said, "By Allah, I know that you heard this story (of the Ifk) so much so that it has been planted in your minds and you have believed it. So now, if I tell you that I am innocent, and Allah knows that I am innocent, you will not believe me; and if I confess something, and Allah knows that I am innocent of it, you will believe me. By Allah, I cannot find of you an example except that of Joseph's father: "So (for me) patience is most fitting against that which you assert and it is Allah (Alone) Whose help can be sought. Then I turned away and lay on my bed, and at that time I knew that I was innocent and that Allah would reveal my innocence. But by Allah, I never thought that Allah would sent down about my affair, Divine Inspiration that would be recited (forever), as I considered myself too unworthy to be talked of by Allah with something that was to be recited: but I hoped that Allah's Messenger (ﷺ) might have a vision in which Allah would prove my innocence. By Allah, Allah's Messenger (ﷺ) had not left his seat and nobody had left the house when the Divine Inspiration came to Allah's Messenger (ﷺ) . So there overtook him the same hard condition which used to overtake him (when he was Divinely Inspired) so that the drops of his sweat were running down, like pearls, though it was a (cold) winter day, and that was because of the heaviness of the Statement which was revealed to him. When that state of Allah's Messenger (ﷺ) was over, and he was smiling when he was relieved, the first word he said was, "Aisha, Allah has declared your innocence." My mother said to me, "Get up and go to him." I said, "By Allah, I will not go to him and I will not thank anybody but Allah." So Allah revealed: "Verily! They who spread the Slander are a gang among you. Think it not...." (24.11-20). When Allah revealed this to confirm my innocence, Abu Bakr As-Siddiq who used to provide for Mistah bin Uthatha because of the latter's kinship to him and his poverty, said, "By Allah, I will never provide for Mistah anything after what he has said about Aisha". So Allah revealed: "Let not those among you who are good and are wealthy swear not to give (help) to their kinsmen, those in need, and those who have left their homes for Allah's Cause. Let them Pardon and forgive (i.e. do not punish them). Do you not love that should forgive you? Verily Allah is Oft-forgiving. Most Merciful." (24.22) Abu Bakr said, "Yes, by Allah, I wish that Allah should forgive me." So he resumed giving Mistah the aid he used to give him before and said, "By Allah, I will never withhold it from him at all." Aisha further said: Allah's Messenger (ﷺ) also asked Zainab bint Jahsh about my case. He said, "O Zainab! What have you seen?" She replied, "O Allah's Messenger (ﷺ)! I protect my hearing and my sight (by refraining from telling lies). I know nothing but good (about Aisha)." Of all the wives of Allah's Messenger (ﷺ), it was Zainab who aspired to receive from him the same favor as I used to receive, yet, Allah saved her (from telling lies) because of her piety. But her sister, Hamna, kept on fighting on her behalf so she was destroyed as were those who invented and spread the slander}}
\hadithdefcmd{bukhari}{4751}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُلَيْمَانُ، عَنْ حُصَيْنٍ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ أُمِّ رُومَانَ أُمِّ عَائِشَةَ، أَنَّهَا قَالَتْ لَمَّا رُمِيَتْ عَائِشَةُ خَرَّتْ مَغْشِيًّا عَلَيْهَا‏.‏\hadithno{4751}\hadithtrans{Narrated Um Ruman:Aisha's mother, When `Aisha was accused, she fell down Unconscious}}
\hadithdefcmd{bukhari}{4752}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ ابْنُ أَبِي مُلَيْكَةَ سَمِعْتُ عَائِشَةَ، تَقْرَأُ ‏\{‏إِذْ تَلِقُونَهُ بِأَلْسِنَتِكُمْ‏\}‏\hadithno{4752}\hadithtrans{Narrated Ibn Abi Mulaika:I heard `Aisha reciting: "When you invented a lie (and carry it) on your tongues}}
\hadithdefcmd{bukhari}{4753}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، قَالَ حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، قَالَ اسْتَأْذَنَ ابْنُ عَبَّاسٍ قَبْلَ مَوْتِهَا عَلَى عَائِشَةَ، وَهْىَ مَغْلُوبَةٌ قَالَتْ أَخْشَى أَنْ يُثْنِيَ عَلَىَّ‏.‏ فَقِيلَ ابْنُ عَمِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمِنْ وُجُوهِ الْمُسْلِمِينَ‏.‏ قَالَتِ ائْذَنُوا لَهُ‏.‏ فَقَالَ كَيْفَ تَجِدِينَكِ قَالَتْ بِخَيْرٍ إِنِ اتَّقَيْتُ‏.‏ قَالَ فَأَنْتِ بِخَيْرٍ ـ إِنْ شَاءَ اللَّهُ ـ زَوْجَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ يَنْكِحْ بِكْرًا غَيْرَكِ، وَنَزَلَ عُذْرُكِ مِنَ السَّمَاءِ‏.‏ وَدَخَلَ ابْنُ الزُّبَيْرِ خِلاَفَهُ فَقَالَتْ دَخَلَ ابْنُ عَبَّاسٍ فَأَثْنَى عَلَىَّ وَوَدِدْتُ أَنِّي كُنْتُ نِسْيًا مَنْسِيًّا‏.‏\hadithno{4753}\hadithtrans{Narrated Ibn Abu Mulaika:Ibn `Abbas asked permission to visit Aisha before her death, and at that time she was in a state of agony. She then said. "I am afraid that he will praise me too much." And then it was said to her, "He is the cousin of Allah's Messenger (ﷺ) and one of the prominent Muslims." Then she said, "Allow him to enter." (When he entered) he said, "How are you?" She replied, "I am Alright if I fear (Allah)." Ibn `Abbas said, "Allah willing, you are Alright as you are the wife of Allah's Messenger (ﷺ) and he did not marry any virgin except you and proof of your innocence was revealed from the Heaven." Later on Ibn Az-Zubair entered after him and `Aisha said to him, "Ibn `Abbas came to me and praised me greatly, but I wish that I was a thing forgotten and out of sight}}
\hadithdefcmd{bukhari}{4754}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الْقَاسِمِ، أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنه ـ اسْتَأْذَنَ عَلَى عَائِشَةَ نَحْوَهُ‏.‏ وَلَمْ يَذْكُرْ نِسْيًا مَنْسِيًّا‏.‏\hadithno{4754}\hadithtrans{Narrated Al-Qasim:Ibn `Abbas asked `Aisha's permission to enter. Al-Qasim then narrated the whole Hadith (as in 277) but did not mention: "Would that I had been forgotten and out of sight}}
\hadithdefcmd{bukhari}{4755}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ جَاءَ حَسَّانُ بْنُ ثَابِتٍ يَسْتَأْذِنُ عَلَيْهَا قُلْتُ أَتَأْذَنِينَ لِهَذَا قَالَتْ أَوَلَيْسَ قَدْ أَصَابَهُ عَذَابٌ عَظِيمٌ‏.‏ قَالَ سُفْيَانُ تَعْنِي ذَهَابَ بَصَرِهِ‏.‏ فَقَالَ حَصَانٌ رَزَانٌ مَا تُزَنُّ بِرِيبَةٍ وَتُصْبِحُ غَرْثَى مِنْ لُحُومِ الْغَوَافِلِ قَالَتْ لَكِنْ أَنْتَ‏.‏ ‏.‏‏.‏ ‏.‏\hadithno{4755}\hadithtrans{Narrated Masruq:`Aisha said that Hassan bin Thabit came and asked permission to visit her. I said, "How do you permit such a person?" She said, "Hasn't he received a severely penalty?" (Sufyan, the subnarrator, said: She meant the loss of his sight.) Thereupon Hassan said the following poetic verse: "A chaste pious woman who arouses no suspicion. She never talks about chaste heedless women behind their backs.' On that she said, "But you are not so}}
\hadithdefcmd{bukhari}{4756}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، أَنْبَأَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ دَخَلَ حَسَّانُ بْنُ ثَابِتٍ عَلَى عَائِشَةَ فَشَبَّبَ وَقَالَ حَصَانٌ رَزَانٌ مَا تُزَنُّ بِرِيبَةٍ وَتُصْبِحُ غَرْثَى مِنْ لُحُومِ الْغَوَافِلِ قَالَتْ لَسْتَ كَذَاكَ‏.‏ قُلْتُ تَدَعِينَ مِثْلَ هَذَا يَدْخُلُ عَلَيْكِ وَقَدْ أَنْزَلَ اللَّهُ ‏\{‏وَالَّذِي تَوَلَّى كِبْرَهُ مِنْهُمْ‏\}‏ فَقَالَتْ وَأَىُّ عَذَابٍ أَشَدُّ مِنَ الْعَمَى وَقَالَتْ وَقَدْ كَانَ يَرُدُّ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{4756}\hadithtrans{Narrated Masruq:Hassan came to Aisha and said the following poetic Verse: 'A chaste pious woman who arouses no suspicion. She never talks against chaste heedless women behind their backs.' `Aisha said, "But you are not," I said (to `Aisha), "Why do you allow such a person to enter upon you after Allah has revealed: "...and as for him among them who had the greater share therein'?" (24.11) She said, "What punishment is worse than blindness?" She added, "And he used to defend Allah's Apostle against the pagans (in his poetry)}}
\hadithdefcmd{bukhari}{4757}{وَقَالَ أَبُو أُسَامَةَ عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، قَالَتْ لَمَّا ذُكِرَ مِنْ شَأْنِي الَّذِي ذُكِرَ وَمَا عَلِمْتُ بِهِ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيَّ خَطِيبًا، فَتَشَهَّدَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ أَشِيرُوا عَلَىَّ فِي أُنَاسٍ أَبَنُوا أَهْلِي، وَايْمُ اللَّهِ مَا عَلِمْتُ عَلَى أَهْلِي مِنْ سُوءٍ، وَأَبَنُوهُمْ بِمَنْ وَاللَّهِ مَا عَلِمْتُ عَلَيْهِ مِنْ سُوءٍ قَطُّ، وَلاَ يَدْخُلُ بَيْتِي قَطُّ إِلاَّ وَأَنَا حَاضِرٌ، وَلاَ غِبْتُ فِي سَفَرٍ إِلاَّ غَابَ مَعِي ‏"‏‏.‏ فَقَامَ سَعْدُ بْنُ مُعَاذٍ فَقَالَ ائْذَنْ لِي يَا رَسُولَ اللَّهِ أَنْ نَضْرِبَ أَعْنَاقَهُمْ، وَقَامَ رَجُلٌ مِنْ بَنِي الْخَزْرَجِ، وَكَانَتْ أُمُّ حَسَّانَ بْنِ ثَابِتٍ مِنْ رَهْطِ ذَلِكَ الرَّجُلِ، فَقَالَ كَذَبْتَ، أَمَا وَاللَّهِ، أَنْ لَوْ كَانُوا مِنَ الأَوْسِ مَا أَحْبَبْتَ أَنْ تُضْرَبَ أَعْنَاقُهُمْ‏.‏ حَتَّى كَادَ أَنْ يَكُونَ بَيْنَ الأَوْسِ وَالْخَزْرَجِ شَرٌّ فِي الْمَسْجِدِ، وَمَا عَلِمْتُ فَلَمَّا كَانَ مَسَاءُ ذَلِكَ الْيَوْمِ خَرَجْتُ لِبَعْضِ حَاجَتِي وَمَعِي أُمُّ مِسْطَحٍ‏.‏ فَعَثَرَتْ وَقَالَتْ تَعِسَ مِسْطَحٌ‏.‏ فَقُلْتُ أَىْ أُمِّ تَسُبِّينَ ابْنَكِ وَسَكَتَتْ ثُمَّ عَثَرَتِ الثَّانِيَةَ فَقَالَتْ تَعِسَ مِسْطَحٌ، فَقُلْتُ لَهَا تَسُبِّينَ ابْنَكِ ثُمَّ عَثَرَتِ الثَّالِثَةَ فَقَالَتْ تَعِسَ مِسْطَحٌ‏.‏ فَانْتَهَرْتُهَا، فَقَالَتْ وَاللَّهِ مَا أَسُبُّهُ إِلاَّ فِيكِ‏.‏ فَقُلْتُ فِي أَىِّ شَأْنِي قَالَتْ فَبَقَرَتْ لِي الْحَدِيثَ فَقُلْتُ وَقَدْ كَانَ هَذَا قَالَتْ نَعَمْ وَاللَّهِ، فَرَجَعْتُ إِلَى بَيْتِي كَأَنَّ الَّذِي خَرَجْتُ لَهُ لاَ أَجِدُ مِنْهُ قَلِيلاً وَلاَ كَثِيرًا، وَوُعِكْتُ فَقُلْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَرْسِلْنِي إِلَى بَيْتِ أَبِي‏.‏ فَأَرْسَلَ مَعِي الْغُلاَمَ، فَدَخَلْتُ الدَّارَ فَوَجَدْتُ أُمَّ رُومَانَ فِي السُّفْلِ وَأَبَا بَكْرٍ فَوْقَ الْبَيْتِ يَقْرَأُ‏.‏ فَقَالَتْ أُمِّي مَا جَاءَ بِكِ يَا بُنَيَّةُ فَأَخْبَرْتُهَا وَذَكَرْتُ لَهَا الْحَدِيثَ، وَإِذَا هُوَ لَمْ يَبْلُغْ مِنْهَا مِثْلَ مَا بَلَغَ مِنِّي، فَقَالَتْ يَا بُنَيَّةُ خَفِّضِي عَلَيْكِ الشَّأْنَ، فَإِنَّهُ وَاللَّهِ، لَقَلَّمَا كَانَتِ امْرَأَةٌ حَسْنَاءُ عِنْدَ رَجُلٍ يُحِبُّهَا، لَهَا ضَرَائِرُ، إِلاَّ حَسَدْنَهَا وَقِيلَ فِيهَا‏.‏ وَإِذَا هُوَ لَمْ يَبْلُغْ مِنْهَا مَا بَلَغَ مِنِّي، قُلْتُ وَقَدْ عَلِمَ بِهِ أَبِي قَالَتْ نَعَمْ‏.‏ قُلْتُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ نَعَمْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاسْتَعْبَرْتُ وَبَكَيْتُ، فَسَمِعَ أَبُو بَكْرٍ صَوْتِي وَهْوَ فَوْقَ الْبَيْتِ يَقْرَأُ، فَنَزَلَ فَقَالَ لأُمِّي مَا شَأْنُهَا قَالَتْ بَلَغَهَا الَّذِي ذُكِرَ مِنْ شَأْنِهَا‏.‏ فَفَاضَتْ عَيْنَاهُ، قَالَ أَقْسَمْتُ عَلَيْكِ أَىْ بُنَيَّةُ إِلاَّ رَجَعْتِ إِلَى بَيْتِكِ، فَرَجَعْتُ وَلَقَدْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْتِي، فَسَأَلَ عَنِّي خَادِمَتِي فَقَالَتْ لاَ وَاللَّهِ مَا عَلِمْتُ عَلَيْهَا عَيْبًا إِلاَّ أَنَّهَا كَانَتْ تَرْقُدُ حَتَّى تَدْخُلَ الشَّاةُ فَتَأْكُلَ خَمِيرَهَا أَوْ عَجِينَهَا‏.‏ وَانْتَهَرَهَا بَعْضُ أَصْحَابِهِ فَقَالَ اصْدُقِي رَسُولَ اللَّهِ صلى الله عليه وسلم حَتَّى أَسْقَطُوا لَهَا بِهِ فَقَالَتْ سُبْحَانَ اللَّهِ، وَاللَّهِ مَا عَلِمْتُ عَلَيْهَا إِلاَّ مَا يَعْلَمُ الصَّائِغُ عَلَى تِبْرِ الذَّهَبِ الأَحْمَرِ‏.‏ وَبَلَغَ الأَمْرُ إِلَى ذَلِكَ الرَّجُلِ الَّذِي قِيلَ لَهُ، فَقَالَ سُبْحَانَ اللَّهِ وَاللَّهِ مَا كَشَفْتُ كَنَفَ أُنْثَى قَطُّ‏.‏ قَالَتْ عَائِشَةُ فَقُتِلَ شَهِيدًا فِي سَبِيلِ اللَّهِ‏.‏ قَالَتْ وَأَصْبَحَ أَبَوَاىَ عِنْدِي، فَلَمْ يَزَالاَ حَتَّى دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ صَلَّى الْعَصْرَ، ثُمَّ دَخَلَ وَقَدِ اكْتَنَفَنِي أَبَوَاىَ عَنْ يَمِينِي وَعَنْ شِمَالِي، فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ يَا عَائِشَةُ، إِنْ كُنْتِ قَارَفْتِ سُوءًا أَوْ ظَلَمْتِ، فَتُوبِي إِلَى اللَّهِ، فَإِنَّ اللَّهَ يَقْبَلُ التَّوْبَةَ مِنْ عِبَادِهِ ‏"‏‏.‏ قَالَتْ وَقَدْ جَاءَتِ امْرَأَةٌ مِنَ الأَنْصَارِ فَهْىَ جَالِسَةٌ بِالْبَابِ فَقُلْتُ أَلاَ تَسْتَحِي مِنْ هَذِهِ الْمَرْأَةِ أَنْ تَذْكُرَ شَيْئًا‏.‏ فَوَعَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَالْتَفَتُّ إِلَى أَبِي فَقُلْتُ أَجِبْهُ‏.‏ قَالَ فَمَاذَا أَقُولُ فَالْتَفَتُّ إِلَى أُمِّي فَقُلْتُ أَجِيبِيهِ‏.‏ فَقَالَتْ أَقُولُ مَاذَا فَلَمَّا لَمْ يُجِيبَاهُ تَشَهَّدْتُ فَحَمِدْتُ اللَّهَ وَأَثْنَيْتُ عَلَيْهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قُلْتُ أَمَّا بَعْدُ فَوَاللَّهِ لَئِنْ قُلْتُ لَكُمْ إِنِّي لَمْ أَفْعَلْ‏.‏ وَاللَّهُ عَزَّ وَجَلَّ يَشْهَدُ إِنِّي لَصَادِقَةٌ، مَا ذَاكَ بِنَافِعِي عِنْدَكُمْ، لَقَدْ تَكَلَّمْتُمْ بِهِ وَأُشْرِبَتْهُ قُلُوبُكُمْ، وَإِنْ قُلْتُ إِنِّي فَعَلْتُ‏.‏ وَاللَّهُ يَعْلَمُ أَنِّي لَمْ أَفْعَلْ، لَتَقُولُنَّ قَدْ بَاءَتْ بِهِ عَلَى نَفْسِهَا، وَإِنِّي وَاللَّهِ مَا أَجِدُ لِي وَلَكُمْ مَثَلاً ـ وَالْتَمَسْتُ اسْمَ يَعْقُوبَ فَلَمْ أَقْدِرْ عَلَيْهِ ـ إِلاَّ أَبَا يُوسُفَ حِينَ قَالَ ‏\{‏فَصَبْرٌ جَمِيلٌ وَاللَّهُ الْمُسْتَعَانُ عَلَى مَا تَصِفُونَ‏\}‏ وَأُنْزِلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ سَاعَتِهِ فَسَكَتْنَا، فَرُفِعَ عَنْهُ وَإِنِّي لأَتَبَيَّنُ السُّرُورَ فِي وَجْهِهِ وَهْوَ يَمْسَحُ جَبِينَهُ وَيَقُولُ ‏"‏ أَبْشِرِي يَا عَائِشَةُ، فَقَدْ أَنْزَلَ اللَّهُ بَرَاءَتَكِ ‏"‏‏.‏ قَالَتْ وَكُنْتُ أَشَدَّ مَا كُنْتُ غَضَبًا فَقَالَ لِي أَبَوَاىَ قُومِي إِلَيْهِ‏.‏ فَقُلْتُ وَاللَّهِ لاَ أَقُومُ إِلَيْهِ، وَلاَ أَحْمَدُهُ وَلاَ أَحْمَدُكُمَا، وَلَكِنْ أَحْمَدُ اللَّهَ الَّذِي أَنْزَلَ بَرَاءَتِي، لَقَدْ سَمِعْتُمُوهُ، فَمَا أَنْكَرْتُمُوهُ وَلاَ غَيَّرْتُمُوهُ، وَكَانَتْ عَائِشَةُ تَقُولُ أَمَّا زَيْنَبُ ابْنَةُ جَحْشٍ فَعَصَمَهَا اللَّهُ بِدِينِهَا، فَلَمْ تَقُلْ إِلاَّ خَيْرًا، وَأَمَّا أُخْتُهَا حَمْنَةُ فَهَلَكَتْ فِيمَنْ هَلَكَ، وَكَانَ الَّذِي يَتَكَلَّمُ فِيهِ مِسْطَحٌ وَحَسَّانُ بْنُ ثَابِتٍ وَالْمُنَافِقُ عَبْدُ اللَّهِ بْنُ أُبَىٍّ، وَهْوَ الَّذِي كَانَ يَسْتَوْشِيهِ وَيَجْمَعُهُ، وَهْوَ الَّذِي تَوَلَّى كِبْرَهُ مِنْهُمْ هُوَ وَحَمْنَةُ قَالَتْ فَحَلَفَ أَبُو بَكْرٍ أَنْ لاَ يَنْفَعَ مِسْطَحًا بِنَافِعَةٍ أَبَدًا، فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَلاَ يَأْتَلِ أُولُو الْفَضْلِ مِنْكُمْ‏\}‏ إِلَى آخِرِ الآيَةِ يَعْنِي أَبَا بَكْرٍ vوَالسَّعَةِ أَنْ يُؤْتُوا أُولِي الْقُرْبَى وَالْمَسَاكِينَ‏\}‏ ـ يَعْنِي مِسْطَحًا ـ إِلَى قَوْلِهِ ‏\{‏أَلاَ تُحِبُّونَ أَنْ يَغْفِرَ اللَّهُ لَكُمْ وَاللَّهُ غَفُورٌ رَحِيمٌ‏\}‏ حَتَّى قَالَ أَبُو بَكْرٍ بَلَى وَاللَّهِ يَا رَبَّنَا إِنَّا لَنُحِبُّ أَنْ تَغْفِرَ لَنَا، وَعَادَ لَهُ بِمَا كَانَ يَصْنَعُ‏.‏\hadithno{4757}\hadithtrans{Narrated Aisha:When there was said about me what was said which I myself was unaware of, Allah's Messenger (ﷺ) got up and addressed the people. He recited Tashah-hud, and after glorifying and praising Allah as He deserved, he said, "To proceed: O people Give me your opinion regarding those people who made a forged story against my wife. By Allah, I do not know anything bad about her. By Allah, they accused her of being with a man about whom I have never known anything bad, and he never entered my house unless I was present there, and whenever I went on a journey, he went with me." Sa`d bin Mu`adh got up and said, "O Allah's Messenger (ﷺ) Allow me to chop their heads off". Then a man from the Al-Khazraj (Sa`d bin 'Ubada) to whom the mother of (the poet) Hassan bin Thabit was a relative, got up and said (to Sa`d bin Mu`adh), "You have told a lie! By Allah, if those persons were from the Aus Tribe, you would not like to chop their heads off." It was probable that some evil would take place between the Aus and the Khazraj in the mosque, and I was unaware of all that. In the evening of that day, I went out for some of my needs (i.e. to relieve myself), and Um Mistah was accompanying me. On our return, Um Mistah stumbled and said, "Let Mistah. be ruined" I said to her, "O mother Why do you abuse your Son" On that Um Mistah became silent for a while, and stumbling again, she said, "Let Mistah be ruined" I said to her, "Why do you abuse your son?" She stumbled for the third time and said, "Let Mistah be ruined" whereupon I rebuked her for that. She said, "By Allah, I do not abuse him except because of you." I asked her, "Concerning what of my affairs?" So she disclosed the whole story to me. I said, "Has this really happened?" She replied, "Yes, by Allah." I returned to my house, astonished (and distressed) that I did not know for what purpose I had gone out. Then I became sick (fever) and said to Allah's Messenger (ﷺ) "Send me to my father's house." So he sent a slave with me, and when I entered the house, I found Um Rum-an (my mother) downstairs while (my father) Abu Bakr was reciting something upstairs. My mother asked, "What has brought you, O (my) daughter?" I informed her and mentioned to her the whole story, but she did not feel it as I did. She said, "O my daughter! Take it easy, for there is never a charming lady loved by her husband who has other wives but that they feel jealous of her and speak badly of her." But she did not feel the news as I did. I asked (her), "Does my father know about it?" She said, "yes" I asked, Does Allah's Messenger (ﷺ) know about it too?" She said, "Yes, Allah's Messenger (ﷺ) does too." So the tears filled my eyes and I wept. Abu Bakr, who was reading upstairs heard my voice and came down and asked my mother, "What is the matter with her? " She said, "She has heard what has been said about her (as regards the story of Al-Ifk)." On that Abu- Bakr wept and said, "I beseech you by Allah, O my daughter, to go back to your home". I went back to my home and Allah's Messenger (ﷺ) had come to my house and asked my maid-servant about me (my character). The maid-servant said, "By Allah, I do not know of any defect in her character except that she sleeps and let the sheep enter (her house) and eat her dough." On that, some of the Prophet's companions spoke harshly to her and said, "Tell the truth to Allah's Messenger (ﷺ)." Finally they told her of the affair (of the slander). She said, "Subhan Allah! By Allah, I know nothing against her except what goldsmith knows about a piece of pure gold." Then this news reached the man who was accused, and he said, "Subhan Allah! By Allah, I have never uncovered the private parts of any woman." Later that man was martyred in Allah's Cause. Next morning my parents came to pay me a visit and they stayed with me till Allah's Messenger (ﷺ) came to me after he had offered the `Asr prayer. He came to me while my parents were sitting around me on my right and my left. He praised and glorified Allah and said, "Now then O `Aisha! If you have committed a bad deed or you have wronged (yourself), then repent to Allah as Allah accepts the repentance from his slaves." An Ansari woman had come and was sitting near the gate. I said (to the Prophet), "Isn't it improper that you speak in such a way in the presence of this lady? Allah's Apostle then gave a piece of advice and I turned to my father and requested him to answer him (on my behalf). My father said, "What should I say?" Then I turned to my mother and asked her to answer him. She said, "What should I say?" When my parents did not give a reply to the Prophet, I said, "I testify that none has the right to be worshipped except Allah, and that Muhammad is His Apostle!" And after praising and glorifying Allah as He deserves, I said, "Now then, by Allah, if I were to tell you that I have not done (this evil action) and Allah is a witness that I am telling the truth, that would not be of any use to me on your part because you (people) have spoken about it and your hearts have absorbed it; and if I were to tell you that I have done this sin and Allah knows that I have not done it, then you will say, 'She has confessed herself guilty." By Allah, 'I do not see a suitable example for me and you but the example of (I tried to remember Jacob's name but couldn't) Joseph's father when he said; So (for me) "Patience is most fitting against that which you assert. It is Allah (alone) whose help can be sought.' At that very hour the Divine Inspiration came to Allah's Messenger (ﷺ) and we remained silent. Then the Inspiration was over and I noticed the signs of happiness on his face while he was removing (the sweat) from his forehead and saying, "Have the good tidings O ' "Aisha! Allah has revealed your innocence." At that time I was extremely angry. My parents said to me, "Get up and go to him." I said, "By Allah, I will not do it and will not thank him nor thank either of you, but I will thank Allah Who has revealed my innocence. You have heard this story but neither did not deny it nor change it (to defend me)." (Aisha used to say:) "But as regards Zainab bint Jahsh, (the Prophet's wife), Allah protected her because of her piety, so she did not say anything except good (about me), but her sister, Hamna, was ruined among those who were ruined. Those who used to speak evil about me were Mistah, Hassan bin Thabit, and the hypocrite, `Abdullah bin Ubai, who used to spread that news and tempt others to speak of it, and it was he and Hamna who had the greater share therein. Abu Bakr took an oath that he would never do any favor to Mistah at all. Then Allah revealed the Divine Verse: "Let not those among you who are good and wealthy (i.e. Abu Bakr) swear not to give (any sort of help) to their kinsmen, and those in need, (i.e. Mistah) ...Do you not love that Allah should forgive you? And Allah is Oft-Forgiving, Most Merciful." (24.22) On that, Abu Bakr said, "Yes, by Allah, O our Lord! We wish that You should forgive us." So Abu Bakr again started giving to Mistah the expenditure which he used to give him before}}
\hadithdefcmd{bukhari}{4758}{وَقَالَ أَحْمَدُ بْنُ شَبِيبٍ حَدَّثَنَا أَبِي، عَنْ يُونُسَ، قَالَ ابْنُ شِهَابٍ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ يَرْحَمُ اللَّهُ نِسَاءَ الْمُهَاجِرَاتِ الأُوَلَ، لَمَّا أَنْزَلَ اللَّهُ ‏\{‏وَلْيَضْرِبْنَ بِخُمُرِهِنَّ عَلَى جُيُوبِهِنَّ‏\}‏ شَقَّقْنَ مُرُوطَهُنَّ فَاخْتَمَرْنَ بِها‏.‏\hadithno{4758}\hadithtrans{Narrated `Aishah:May Allah bestow His Mercy on the early emigrant women. When Allah revealed: "... and to draw their veils all over their Juyubihinna (i.e., their bodies, faces, necks and bosoms)..." (V.24:31) they tore their Murut (woolen dresses or waist-binding clothes or aprons etc.) and covered their heads and faces with those torn Muruts}}
\hadithdefcmd{bukhari}{4759}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ كَانَتْ تَقُولُ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَلْيَضْرِبْنَ بِخُمُرِهِنَّ عَلَى جُيُوبِهِنَّ‏\}‏ أَخَذْنَ أُزْرَهُنَّ فَشَقَّقْنَهَا مِنْ قِبَلِ الْحَوَاشِي فَاخْتَمَرْنَ بِهَا‏.‏\hadithno{4759}\hadithtrans{Narrated Safiya bint Shaiba:`Aisha used to say: "When (the Verse): "They should draw their veils over their necks and bosoms," was revealed, (the ladies) cut their waist sheets at the edges and covered their heads and faces with those cut pieces of cloth}}
\hadithdefcmd{bukhari}{4760}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ الْبَغْدَادِيُّ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ‏.‏ أَنَّ رَجُلاً، قَالَ يَا نَبِيَّ اللَّهِ يُحْشَرُ الْكَافِرُ عَلَى وَجْهِهِ يَوْمَ الْقِيَامَةِ قَالَ ‏ "‏ أَلَيْسَ الَّذِي أَمْشَاهُ عَلَى الرِّجْلَيْنِ فِي الدُّنْيَا قَادِرًا عَلَى أَنْ يُمْشِيَهُ عَلَى وَجْهِهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ قَالَ قَتَادَةُ بَلَى وَعِزَّةِ رَبِّنَا‏.‏\hadithno{4760}\hadithtrans{Narrated Anas bin Malik:A man said, "O Allah's Prophet! Will Allah gather the non-believers on their faces on the Day of Resurrection?" He said, "Will not the One Who made him walk on his feet in this world, be able to make him walk on his face on the Day of Resurrection?" (Qatada, a subnarrator, said: Yes, By the Power of Our Lord)}}
\hadithdefcmd{bukhari}{4761}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي مَنْصُورٌ، وَسُلَيْمَانُ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مَيْسَرَةَ، عَنْ عَبْدِ اللَّهِ،‏.‏ قَالَ وَحَدَّثَنِي وَاصِلٌ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ سَأَلْتُ ـ أَوْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ـ أَىُّ الذَّنْبِ عِنْدَ اللَّهِ أَكْبَرُ قَالَ ‏"‏ أَنْ تَجْعَلَ لِلَّهِ نِدًّا وَهْوَ خَلَقَكَ ‏"‏‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ ثُمَّ أَنْ تَقْتُلَ وَلَدَكَ خَشْيَةَ أَنْ يَطْعَمَ مَعَكَ‏"‏‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ أَنْ تُزَانِيَ بِحَلِيلَةِ جَارِكَ ‏"‏‏.‏ قَالَ وَنَزَلَتْ هَذِهِ الآيَةُ تَصْدِيقًا لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏\{‏وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَلَا يَزْنُونَ‏\}‏\hadithno{4761}\hadithtrans{Narrated `Abdullah:I or somebody, asked Allah's Messenger (ﷺ) "Which is the biggest sin in the Sight of Allah?" He said, "That you set up a rival (in worship) to Allah though He Alone created you." I asked, "What is next?" He said, "Then, that you kill your son, being afraid that he may share your meals with you." I asked, "What is next?" He said, "That you commit illegal sexual intercourse with the wife of your neighbor." Then the following Verse was revealed to confirm the statement of Allah's Messenger (ﷺ): "Those who invoke not with Allah, any other god, nor kill life as Allah has forbidden except for just cause, nor commit illegal sexual intercourse}}
\hadithdefcmd{bukhari}{4762}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي الْقَاسِمُ بْنُ أَبِي بَزَّةَ، أَنَّهُ سَأَلَ سَعِيدَ بْنَ جُبَيْرٍ هَلْ لِمَنْ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا مِنْ تَوْبَةٍ فَقَرَأْتُ عَلَيْهِ ‏\{‏وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ‏\}‏‏.‏ فَقَالَ سَعِيدٌ قَرَأْتُهَا عَلَى ابْنِ عَبَّاسٍ كَمَا قَرَأْتَهَا عَلَىَّ‏.‏ فَقَالَ هَذِهِ مَكِّيَّةٌ نَسَخَتْهَا آيَةٌ مَدَنِيَّةٌ، الَّتِي فِي سُورَةِ النِّسَاءِ‏.‏\hadithno{4762}\hadithtrans{Narrated Al-Qasim bin Abi Bazza:That he asked Sa`id bin Jubair, "Is there any repentance of the one who has murdered a believer intentionally?" Then I recited to him:-- "Nor kill such life as Allah has forbidden except for a just cause." Sa`id said, "I recited this very Verse before Ibn `Abbas as you have recited it before me. Ibn `Abbas said, 'This Verse was revealed in Mecca and it has been abrogated by a Verse in Surat-An-Nisa which was later revealed in Medina}}
\hadithdefcmd{bukhari}{4763}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ اخْتَلَفَ أَهْلُ الْكُوفَةِ فِي قَتْلِ الْمُؤْمِنِ، فَرَحَلْتُ فِيهِ إِلَى ابْنِ عَبَّاسٍ، فَقَالَ نَزَلَتْ فِي آخِرِ مَا نَزَلَ وَلَمْ يَنْسَخْهَا شَىْءٌ‏.‏\hadithno{4763}\hadithtrans{Narrated Sa`id bin Jubair:The people of Kufa differed as regards the killing of a believer so I entered upon Ibn `Abbas (and asked him) about that. Ibn `Abbas said, "The Verse (in Surat-An-Nisa', 4:93) was the last thing revealed in this respect and nothing cancelled its validity}}
\hadithdefcmd{bukhari}{4764}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مَنْصُورٌ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ عَنْ قَوْلِهِ تَعَالَى ‏\{‏فَجَزَاؤُهُ جَهَنَّمُ‏\}‏ قَالَ لاَ تَوْبَةَ لَهُ‏.‏ وَعَنْ قَوْلِهِ جَلَّ ذِكْرُهُ ‏\{‏لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ‏\}‏ قَالَ كَانَتْ هَذِهِ فِي الْجَاهِلِيَّةِ‏.‏\hadithno{4764}\hadithtrans{Narrated Sa`id bin Jubair:I asked Ibn `Abbas about Allah's saying:-- '.. this reward is Hell Fire.' (4.93) He said, "No repentance is accepted from him (i.e. the murderer of a believer)." I asked him regarding the saying of Allah: 'Those who invoke not with Allah any other god.' ...(25.68) He said, "This Verse was revealed concerning the pagans of the pre-Islamic period}}
\hadithdefcmd{bukhari}{4765}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قَالَ ابْنُ أَبْزَى سَلِ ابْنَ عَبَّاسٍ عَنْ قَوْلِهِ تَعَالَى ‏\{‏وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ‏\}‏ وَقَوْلِهِ ‏\{‏لاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ‏\}‏ حَتَّى بَلَغَ ‏\{‏إِلاَّ مَنْ تَابَ‏\}‏ فَسَأَلْتُهُ فَقَالَ لَمَّا نَزَلَتْ قَالَ أَهْلُ مَكَّةَ فَقَدْ عَدَلْنَا بِاللَّهِ وَقَتَلْنَا النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَأَتَيْنَا الْفَوَاحِشَ، فَأَنْزَلَ اللَّهُ ‏\{‏إِلاَّ مَنْ تَابَ وَآمَنَ وَعَمِلَ عَمَلاً صَالِحًا‏\}‏ إِلَى قَوْلِهِ ‏\{‏غَفُورًا رَحِيمًا‏\}‏\hadithno{4765}\hadithtrans{Narrated Sa`id bin Jubair:Ibn Abza said to me, "Ask Ibn `Abbas regarding the Statement of Allah: 'And whoever murders a believer intentionally, his recompense is Hell.' (4.69) And also His Statement: '...nor kill such life as Allah has forbidden, except for a just cause .....except those who repent, believe, and do good deeds.' " (25.68-70) So I asked Ibn `Abbas and he said, "When this (25.68-69) was revealed, the people of Mecca said, "We have invoked other gods with Allah, and we have murdered such lives which Allah has made sacred, and we have committed illegal sexual intercourse. So Allah revealed: 'Except those who repent, believe, and do good deeds and Allah is Oft-Forgiving, Most Merciful}}
\hadithdefcmd{bukhari}{4766}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا أَبِي، عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ أَمَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبْزَى أَنْ أَسْأَلَ ابْنَ عَبَّاسٍ، عَنْ هَاتَيْنِ الآيَتَيْنِ، ‏\{‏وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا‏\}‏، فَسَأَلْتُهُ فَقَالَ لَمْ يَنْسَخْهَا شَىْءٌ‏.‏ وَعَنْ ‏\{‏وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ‏\}‏ قَالَ نَزَلَتْ فِي أَهْلِ الشِّرْكِ‏.‏\hadithno{4766}\hadithtrans{Narrated Sa`id bin Jubair:`Abdur-Rahman bin Abza ordered me to ask Ibn `Abbas regarding the two Verses (the first of which was ): "And whosoever murders a believer intentionally." (4.93) So I asked him, and he said, "Nothing has abrogated this Verse." About (the other Verse): 'And those who invoke not with Allah any other god.' he said, "It was revealed concerning the pagans}}
\hadithdefcmd{bukhari}{4767}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا مُسْلِمٌ، عَنْ مَسْرُوقٍ، قَالَ قَالَ عَبْدُ اللَّهِ خَمْسٌ قَدْ مَضَيْنَ الدُّخَانُ وَالْقَمَرُ وَالرُّومُ وَالْبَطْشَةُ وَاللِّزَامُ ‏\{‏فَسَوْفَ يَكُونُ لِزَامًا‏\}‏\hadithno{4767}\hadithtrans{Narrated `Abdullah:Five (great events) have passed: the Smoke, the Moon, the Romans, the Mighty grasp and the constant Punishment which occurs in 'So the torment will be yours forever}}
\hadithdefcmd{bukhari}{4768}{وَقَالَ إِبْرَاهِيمُ بْنُ طَهْمَانَ عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ إِبْرَاهِيمَ ـ عَلَيْهِ الصَّلاَةُ وَالسَّلاَمُ ـ رَأَى أَبَاهُ يَوْمَ الْقِيَامَةِ عَلَيْهِ الْغَبَرَةُ وَالْقَتَرَةُ ‏"‏‏.‏ الْغَبَرَةُ هِيَ الْقَتَرَةُ‏.‏\hadithno{4768}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "On the Day of Resurrection Abraham will see his father covered with Qatara and Ghabara. (i.e. having a dark face)}}
\hadithdefcmd{bukhari}{4769}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا أَخِي، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَلْقَى إِبْرَاهِيمُ أَبَاهُ فَيَقُولُ يَا رَبِّ إِنَّكَ وَعَدْتَنِي أَنْ لاَ تُخْزِنِي يَوْمَ يُبْعَثُونَ فَيَقُولُ اللَّهُ إِنِّي حَرَّمْتُ الْجَنَّةَ عَلَى الْكَافِرِينَ ‏"‏‏.‏\hadithno{4769}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, Abraham will meet his father (on the Day of Resurrection) and will say, 'O my Lord! You promised me that You would not let me in disgrace on the Day when people will be resurrected.' Allah will say, 'I have forbidden Paradise to the non-believers}}
\hadithdefcmd{bukhari}{4770}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي عَمْرُو بْنُ مُرَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا نَزَلَتْ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ صَعِدَ النَّبِيُّ صلى الله عليه وسلم عَلَى الصَّفَا فَجَعَلَ يُنَادِي ‏"‏ يَا بَنِي فِهْرٍ، يَا بَنِي عَدِيٍّ ‏"‏‏.‏ لِبُطُونِ قُرَيْشٍ حَتَّى اجْتَمَعُوا، فَجَعَلَ الرَّجُلُ إِذَا لَمْ يَسْتَطِعْ أَنْ يَخْرُجَ أَرْسَلَ رَسُولاً لِيَنْظُرَ مَا هُوَ، فَجَاءَ أَبُو لَهَبٍ وَقُرَيْشٌ فَقَالَ ‏"‏ أَرَأَيْتَكُمْ لَوْ أَخْبَرْتُكُمْ أَنَّ خَيْلاً بِالْوَادِي تُرِيدُ أَنْ تُغِيرَ عَلَيْكُمْ، أَكُنْتُمْ مُصَدِّقِيَّ ‏"‏‏.‏ قَالُوا نَعَمْ، مَا جَرَّبْنَا عَلَيْكَ إِلاَّ صِدْقًا‏.‏ قَالَ ‏"‏ فَإِنِّي نَذِيرٌ لَكُمْ بَيْنَ يَدَىْ عَذَابٍ شَدِيدٍ ‏"‏‏.‏ فَقَالَ أَبُو لَهَبٍ تَبًّا لَكَ سَائِرَ الْيَوْمِ، أَلِهَذَا جَمَعْتَنَا فَنَزَلَتْ ‏\{‏تَبَّتْ يَدَا أَبِي لَهَبٍ وَتَبَّ * مَا أَغْنَى عَنْهُ مَالُهُ وَمَا كَسَبَ‏\}‏\hadithno{4770}\hadithtrans{Narrated Ibn `Abbas:When the Verse:--'And warn your tribe of near-kindred, was revealed, the Prophet (ﷺ) ascended the Safa (mountain) and started calling, "O Bani Fihr! O Bani `Adi!" addressing various tribes of Quraish till they were assembled. Those who could not come themselves, sent their messengers to see what was there. Abu Lahab and other people from Quraish came and the Prophet (ﷺ) then said, "Suppose I told you that there is an (enemy) cavalry in the valley intending to attack you, would you believe me?" They said, "Yes, for we have not found you telling anything other than the truth." He then said, "I am a warner to you in face of a terrific punishment." Abu Lahab said (to the Prophet) "May your hands perish all this day. Is it for this purpose you have gathered us?" Then it was revealed: "Perish the hands of Abu Lahab (one of the Prophet's uncles), and perish he! His wealth and his children will not profit him}}
\hadithdefcmd{bukhari}{4771}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أَنْزَلَ اللَّهُ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ قَالَ ‏"‏ يَا مَعْشَرَ قُرَيْشٍ ـ أَوْ كَلِمَةً نَحْوَهَا ـ اشْتَرُوا أَنْفُسَكُمْ، لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا، يَا بَنِي عَبْدِ مَنَافٍ، لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا، يَا عَبَّاسُ بْنَ عَبْدِ الْمُطَّلِبِ، لاَ أُغْنِي عَنْكَ مِنَ اللَّهِ شَيْئًا، وَيَا صَفِيَّةُ عَمَّةَ رَسُولِ اللَّهِ، لاَ أُغْنِي عَنْكِ مِنَ اللَّهِ شَيْئًا وَيَا فَاطِمَةُ بِنْتَ مُحَمَّدٍ سَلِينِي مَا شِئْتِ مِنْ مَالِي، لاَ أُغْنِي عَنْكِ مِنَ اللَّهِ شَيْئًا ‏"‏‏.‏ تَابَعَهُ أَصْبَغُ عَنِ ابْنِ وَهْبٍ عَنْ يُونُسَ عَنِ ابْنِ شِهَابٍ‏.‏\hadithno{4771}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) got up when the Verse:--'And warn your tribe of near kindred...." (26.214) was revealed and said, "O Quraish people! (or he said a similar word) Buy yourselves! I cannot save you from Allah (if you disobey Him) O Bani Abd Manaf! I cannot save you from Allah (if you disobey Him). O `Abbas, the son of `Abdul Muttalib! I cannot save you from Allah (if you disobey Him). O Safiya, (the aunt of Allah's Messenger (ﷺ)) I cannot save you from Allah (if you disobey Him). O Fatima, the daughter of Muhammad! Ask what you wish from my property, but I cannot save you from Allah (if you disobey Him)}}
\hadithdefcmd{bukhari}{4772}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِيهِ، قَالَ لَمَّا حَضَرَتْ أَبَا طَالِبٍ الْوَفَاةُ جَاءَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَوَجَدَ عِنْدَهِ أَبَا جَهْلٍ وَعَبْدَ اللَّهِ بْنَ أَبِي أُمَيَّةَ بْنِ الْمُغِيرَةِ، فَقَالَ ‏"‏ أَىْ عَمِّ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ، كَلِمَةً أُحَاجُّ لَكَ بِهَا عِنْدَ اللَّهِ ‏"‏‏.‏ فَقَالَ أَبُو جَهْلٍ وَعَبْدُ اللَّهِ بْنُ أَبِي أُمَيَّةَ أَتَرْغَبُ عَنْ مِلَّةِ عَبْدِ الْمُطَّلِبِ فَلَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْرِضُهَا عَلَيْهِ، وَيُعِيدَانِهِ بِتِلْكَ الْمَقَالَةِ حَتَّى قَالَ أَبُو طَالِبٍ آخِرَ مَا كَلَّمَهُمْ عَلَى مِلَّةِ عَبْدِ الْمُطَّلِبِ، وَأَبَى أَنْ يَقُولُ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَاللَّهِ لأَسْتَغْفِرَنَّ لَكَ مَا لَمْ أُنْهَ عَنْكَ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏مَا كَانَ لِلنَّبِيِّ وَالَّذِينَ آمَنُوا أَنْ يَسْتَغْفِرُوا لِلْمُشْرِكِينَ‏\}‏ وَأَنْزَلَ اللَّهُ فِي أَبِي طَالِبٍ، فَقَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏\{‏إِنَّكَ لاَ تَهْدِي مَنْ أَحْبَبْتَ وَلَكِنَّ اللَّهَ يَهْدِي مَنْ يَشَاءُ‏\}‏‏.‏ قَالَ ابْنُ عَبَّاسٍ ‏\{‏أُولِي الْقُوَّةِ‏\}‏ لاَ يَرْفَعُهَا الْعُصْبَةُ مِنَ الرِّجَالِ‏.‏ ‏\{‏لَتَنُوءُ‏\}‏ لَتُثْقِلُ‏.‏ ‏\{‏فَارِغًا‏\}‏ إِلاَّ مِنْ ذِكْرِ مُوسَى‏.‏ ‏\{‏الْفَرِحِينَ‏\}‏ الْمَرِحِينَ‏.‏ ‏\{‏قُصِّيهِ‏\}‏ اتَّبِعِي أَثَرَهُ، وَقَدْ يَكُونُ أَنْ يَقُصَّ الْكَلاَمَ ‏\{‏نَحْنُ نَقُصُّ عَلَيْكَ‏\}‏‏.‏ ‏\{‏عَنْ جُنُبٍ‏\}‏ عَنْ بُعْدٍ عَنْ جَنَابَةٍ وَاحِدٌ، وَعَنِ اجْتِنَابٍ أَيْضًا، يَبْطِشُ وَيَبْطُشُ‏.‏ ‏\{‏يَأْتَمِرُونَ‏\}‏ يَتَشَاوَرُونَ‏.‏ الْعُدْوَانُ وَالْعَدَاءُ وَالتَّعَدِّي وَاحِدٌ‏.‏ ‏\{‏آنَسَ‏\}‏ أَبْصَرَ‏.‏ الْجِذْوَةُ قِطْعَةٌ غَلِيظَةٌ مِنَ الْخَشَبِ، لَيْسَ فِيهَا لَهَبٌ، وَالشِّهَابُ فِيهِ لَهَبٌ‏.‏ وَالْحَيَّاتُ أَجْنَاسٌ الْجَانُّ وَالأَفَاعِي وَالأَسَاوِدُ‏.‏ ‏\{‏رِدْءًا‏\}‏ مُعِينًا‏.‏ قَالَ ابْنُ عَبَّاسٍ ‏\{‏يُصَدِّقُنِي‏\}‏ وَقَالَ غَيْرُهُ ‏\{‏سَنَشُدُّ‏\}‏ سَنُعِينُكَ كُلَّمَا عَزَّزْتَ شَيْئًا فَقَدْ جَعَلْتَ لَهُ عَضُدًا‏.‏ مَقْبُوحِينَ مُهْلَكِينَ‏.‏ ‏\{‏وَصَّلْنَا‏\}‏ بَيَّنَّاهُ وَأَتْمَمْنَاهُ‏.‏ ‏\{‏يُجْبَى‏\}‏ يُجْلَبُ ‏.‏‏\{‏بَطِرَتْ‏\}‏ أَشِرَتْ‏.‏ ‏\{‏فِي أُمِّهَا رَسُولاً‏\}‏ أُمُّ الْقُرَى مَكَّةُ وَمَا حَوْلَهَا‏.‏ ‏\{‏تُكِنُّ‏\}‏ تُخْفِي‏.‏ أَكْنَنْتُ الشَّىْءَ أَخْفَيْتُهُ، وَكَنَنْتُهُ أَخْفَيْتُهُ وَأَظْهَرْتُهُ‏.‏ ‏\{‏وَيْكَأَنَّ اللَّهَ‏\}‏ مِثْلُ أَلَمْ تَرَ أَنَّ اللَّهَ ‏\{‏يَبْسُطُ الرِّزْقَ لِمَنْ يَشَاءُ وَيَقْدِرُ‏\}‏ يُوَسِّعُ عَلَيْهِ وَيُضَيِّقُ عَلَيْهِ‏.‏\hadithno{4772}\hadithtrans{Narrated Al-Musaiyab:When Abu Talib was on his death bed, Allah's Messenger (ﷺ) came to him and found with him, Abu Jahl and `Abdullah bin Abi Umaiya bin Al-Mughira. Allah's Messenger (ﷺ) said, "O uncle! Say: None has the right to be worshipped except Allah, a sentence with which I will defend you before Allah." On that Abu Jahl and `Abdullah bin Abi Umaiya said to Abu Talib, "Will you now leave the religion of `Abdul Muttalib?" Allah's Messenger (ﷺ) kept on inviting him to say that sentence while the other two kept on repeating their sentence before him till Abu Talib said as the last thing he said to them, "I am on the religion of `Abdul Muttalib," and refused to say: None has the right to be worshipped except Allah. On that Allah's Messenger (ﷺ) said, "By Allah, I will keep on asking Allah's forgiveness for you unless I am forbidden (by Allah) to do so." So Allah revealed:-- 'It is not fitting for the Prophet (ﷺ) and those who believe that they should invoke (Allah) for forgiveness for pagans.' (9.113) And then Allah revealed especially about Abu Talib:--'Verily! You (O, Muhammad) guide not whom you like, but Allah guides whom He will}}
\hadithdefcmd{bukhari}{4773}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا يَعْلَى، حَدَّثَنَا سُفْيَانُ الْعُصْفُرِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏لَرَادُّكَ إِلَى مَعَادٍ‏\}‏ قَالَ إِلَى مَكَّةَ‏.‏\hadithno{4773}\hadithtrans{Narrated Ibn `Abbas:Qur'an 28.85'...will bring you home' means to Mecca}}
\hadithdefcmd{bukhari}{4774}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مَنْصُورٌ، وَالأَعْمَشُ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ بَيْنَمَا رَجُلٌ يُحَدِّثُ فِي كِنْدَةَ فَقَالَ يَجِيءُ دُخَانٌ يَوْمَ الْقِيَامَةِ فَيَأْخُذُ بِأَسْمَاعِ الْمُنَافِقِينَ وَأَبْصَارِهِمْ، يَأْخُذُ الْمُؤْمِنَ كَهَيْئَةِ الزُّكَامِ‏.‏ فَفَزِعْنَا، فَأَتَيْتُ ابْنَ مَسْعُودٍ، وَكَانَ مُتَّكِئًا، فَغَضِبَ فَجَلَسَ فَقَالَ مَنْ عَلِمَ فَلْيَقُلْ، وَمَنْ لَمْ يَعْلَمْ فَلْيَقُلِ اللَّهُ أَعْلَمُ‏.‏ فَإِنَّ مِنَ الْعِلْمِ أَنْ يَقُولَ لِمَا لاَ يَعْلَمُ لاَ أَعْلَمُ‏.‏ فَإِنَّ اللَّهَ قَالَ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏قُلْ مَا أَسْأَلُكُمْ عَلَيْهِ مِنْ أَجْرٍ وَمَا أَنَا مِنَ الْمُتَكَلِّفِينَ‏\}‏ وَإِنَّ قُرَيْشًا أَبْطَئُوا عَنِ الإِسْلاَمِ فَدَعَا عَلَيْهِمِ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ اللَّهُمَّ أَعِنِّي عَلَيْهِمْ بِسَبْعٍ كَسَبْعِ يُوسُفَ، فَأَخَذَتْهُمْ سَنَةٌ حَتَّى هَلَكُوا فِيهَا، وَأَكَلُوا الْمَيْتَةَ وَالْعِظَامَ وَيَرَى الرَّجُلُ مَا بَيْنَ السَّمَاءِ وَالأَرْضِ كَهَيْئَةِ الدُّخَانِ ‏"‏، فَجَاءَهُ أَبُو سُفْيَانَ فَقَالَ يَا مُحَمَّدُ جِئْتَ تَأْمُرُنَا بِصِلَةِ الرَّحِمِ، وَإِنَّ قَوْمَكَ قَدْ هَلَكُوا فَادْعُ اللَّهَ، فَقَرَأَ ‏\{‏فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ‏\}‏ إِلَى قَوْلِهِ ‏\{‏عَائِدُونَ‏\}‏ أَفَيُكْشَفُ عَنْهُمْ عَذَابُ الآخِرَةِ إِذَا جَاءَ ثُمَّ عَادُوا إِلَى كُفْرِهِمْ فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏يَوْمَ نَبْطِشُ الْبَطْشَةَ الْكُبْرَى‏\}‏ يَوْمَ بَدْرٍ وَلِزَامًا يَوْمَ بَدْرٍ ‏\{‏الم * غُلِبَتِ الرُّومُ‏\}‏ إِلَى ‏\{‏سَيَغْلِبُونَ‏\}‏ وَالرُّومُ قَدْ مَضَى‏.‏\hadithno{4774}\hadithtrans{Narrated Masruq:While a man was delivering a speech in the tribe of Kinda, he said, "Smoke will prevail on the Day of Resurrection and will deprive the hypocrites their faculties of hearing and seeing. The believers will be afflicted with something like cold only thereof." That news scared us, so I went to (Abdullah) Ibn Mas`ud while he was reclining (and told him the story) whereupon he became angry, sat up and said, "He who knows a thing can say, it, but if he does not know, he should say, 'Allah knows best,' for it is an aspect of knowledge to say, 'I do not know,' if you do not know a certain thing. Allah said to His prophet. 'Say (O Muhammad): No wage do I ask of you for this (Qur'an), nor I am one of the pretenders (a person who pretends things which do not exist.)' (38.86) The Quraish delayed in embracing Islam for a period, so the Prophet (ﷺ) invoked evil on them, saying, 'O Allah! Help me against them by sending seven years of (famine) like those of Joseph.' So they were afflicted with such a severe year of famine that they were destroyed therein and ate dead animals and bones. They started seeing something like smoke between the sky and the earth (because of severe hunger). Abu Sufyan then came (to the Prophet) and said, "O Muhammad! You came to order us for to keep good relations with Kith and kin, and your kinsmen have now perished, so please invoke Allah (to relieve them).' Then Ibn Mas`ud recited:-- 'Then watch you for the day that the sky will bring forth a kind of smoke plainly visible....but truly you will return! (to disbelief) (44.10-15) Ibn Mas`ud added, Then the punishment was stopped, but truly, they reverted to heathenism (their old way). So Allah (threatened them thus): 'On the day when we shall seize you with a mighty grasp.' (44.16) And that was the day of the Battle of Badr. Allah's saying- "Lizama" (the punishment) refers to the day of Badr Allah's Statement: Alif-Lam-Mim, the Romans have been defeated, and they, after their defeat, will be victorious,' (30.1- 3) (This verse): Indicates that the defeat of Byzantine has already passed}}
\hadithdefcmd{bukhari}{4775}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ مَوْلُودٍ إِلاَّ يُولَدُ عَلَى الْفِطْرَةِ، فَأَبَوَاهُ يُهَوِّدَانِهِ أَوْ يُنَصِّرَانِهِ أَوْ يُمَجِّسَانِهِ، كَمَا تُنْتَجُ الْبَهِيمَةُ بَهِيمَةً جَمْعَاءَ، هَلْ تُحِسُّونَ فِيهَا مِنْ جَدْعَاءَ ‏"‏ ثُمَّ يَقُولُ ‏\{‏فِطْرَةَ اللَّهِ الَّتِي فَطَرَ النَّاسَ عَلَيْهَا لاَ تَبْدِيلَ لِخَلْقِ اللَّهِ ذَلِكَ الدِّينُ الْقَيِّمُ‏\}‏\hadithno{4775}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "No child is born except on Al-Fitra (Islam) and then his parents make him Jewish, Christian or Magian, as an animal produces a perfect young animal: do you see any part of its body amputated?" Then he recited, 'The religion of pure Islamic Faith (Hanifa),(i.e. to worship none but Allah), The pure Allah's Islamic nature with which He (Allah) has created mankind. Let There be no change in Allah's religion (i.e. to join none in Allah's worship). That is the straight religion; but most of men know not}}
\hadithdefcmd{bukhari}{4776}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏الَّذِينَ آمَنُوا وَلَمْ يَلْبِسُوا إِيمَانَهُمْ بِظُلْمٍ‏\}‏ شَقَّ ذَلِكَ عَلَى أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَالُوا أَيُّنَا لَمْ يَلْبِسْ إِيمَانَهُ بِظُلْمٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَيْسَ بِذَاكَ، أَلاَ تَسْمَعُ إِلَى قَوْلِ لُقْمَانَ لاِبْنِهِ ‏\{‏إِنَّ الشِّرْكَ لَظُلْمٌ عَظِيمٌ‏\}‏‏"‏\hadithno{4776}\hadithtrans{Narrated `Abdullah:When there was revealed: 'It is those who believe and confuse not their beliefs with wrong.' (6.82) It was very hard for the companions of Allah's Messenger (ﷺ), so they said, "Which of us has not confused his belief with wrong?" Allah's Messenger (ﷺ) said, "The Verse does not mean this. Don't you hear Luqman's statement to his son: 'Verily! Joining others in worship, with Allah is a great wrong indeed}}
\hadithdefcmd{bukhari}{4777}{حَدَّثَنِي إِسْحَاقُ، عَنْ جَرِيرٍ، عَنْ أَبِي حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَوْمًا بَارِزًا لِلنَّاسِ إِذْ أَتَاهُ رَجُلٌ يَمْشِي فَقَالَ يَا رَسُولَ اللَّهِ مَا الإِيمَانُ قَالَ ‏"‏ الإِيمَانُ أَنْ تُؤْمِنَ بِاللَّهِ وَمَلاَئِكَتِهِ وَرُسُلِهِ وَلِقَائِهِ وَتُؤْمِنَ بِالْبَعْثِ الآخِرِ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَا الإِسْلاَمُ قَالَ ‏"‏ الإِسْلاَمُ أَنْ تَعْبُدَ اللَّهَ وَلاَ تُشْرِكَ بِهِ شَيْئًا، وَتُقِيمَ الصَّلاَةَ، وَتُؤْتِيَ الزَّكَاةَ الْمَفْرُوضَةَ، وَتَصُومَ رَمَضَانَ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، مَا الإِحْسَانُ قَالَ ‏"‏ الإِحْسَانُ أَنْ تَعْبُدَ اللَّهَ كَأَنَّكَ تَرَاهُ، فَإِنْ لَمْ تَكُنْ تَرَاهُ فَإِنَّهُ يَرَاكَ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَتَى السَّاعَةُ قَالَ ‏"‏ مَا الْمَسْئُولُ عَنْهَا بِأَعْلَمَ مِنَ السَّائِلِ، وَلَكِنْ سَأُحَدِّثُكَ عَنْ أَشْرَاطِهَا إِذَا وَلَدَتِ الْمَرْأَةُ رَبَّتَهَا، فَذَاكَ مِنْ أَشْرَاطِهَا، وَإِذَا كَانَ الْحُفَاةُ الْعُرَاةُ رُءُوسَ النَّاسِ فَذَاكَ مِنْ أَشْرَاطِهَا فِي خَمْسٍ لا يَعْلَمُهُنَّ إِلاَّ اللَّهُ ‏\{‏إِنَّ اللَّهَ عِنْدَهُ عِلْمُ السَّاعَةِ وَيُنَزِّلُ الْغَيْثَ وَيَعْلَمُ مَا فِي الأَرْحَامِ‏\}‏ ‏"‏‏.‏ ثُمَّ انْصَرَفَ الرَّجُلُ فَقَالَ ‏"‏ رُدُّوا عَلَىَّ ‏"‏‏.‏ فَأَخَذُوا لِيَرُدُّوا فَلَمْ يَرَوْا شَيْئًا‏.‏ فَقَالَ ‏"‏ هَذَا جِبْرِيلُ جَاءَ لِيُعَلِّمَ النَّاسَ دِينَهُمْ ‏"‏‏.‏\hadithno{4777}\hadithtrans{Narrated Abu Huraira:One day while Allah's Messenger (ﷺ) was sitting with the people, a man came to him walking and said, "O Allah's Messenger (ﷺ). What is Belief?" The Prophet (ﷺ) said, "Belief is to believe in Allah, His Angels, His Books, His Apostles, and the meeting with Him, and to believe in the Resurrection." The man asked, "O Allah's Messenger (ﷺ) What is Islam?" The Prophet (ﷺ) replied, "Islam is to worship Allah and not worship anything besides Him, to offer prayers perfectly, to pay the (compulsory) charity (i.e. Zakat) and to fast the month of Ramadan." The man again asked, "O Allah's Messenger (ﷺ) What is Ihsan (i.e. perfection or Benevolence)?" The Prophet (ﷺ) said, "Ihsan is to worship Allah as if you see Him, and if you do not achieve this state of devotion, then (take it for granted that) Allah sees you." The man further asked, "O Allah's Messenger (ﷺ) When will the Hour be established?" The Prophet (ﷺ) replied, "The one who is asked about it does not know more than the questioner does, but I will describe to you its portents. When the lady slave gives birth to her mistress, that will be of its portents; when the bare-footed naked people become the chiefs of the people, that will be of its portents. The Hour is one of five things which nobody knows except Allah. Verily, the knowledge of the Hour is with Allah (alone). He sends down the rain, and knows that which is in the wombs." (31.34) Then the man left. The Prophet (ﷺ) said, "Call him back to me." They went to call him back but could not see him. The Prophet (ﷺ) said, "That was Gabriel who came to teach the people their religion." (See Hadith No. 47 Vol)}}
\hadithdefcmd{bukhari}{4778}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدِ بْنِ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مَفَاتِيحُ الْغَيْبِ خَمْسٌ ‏"‏ ثُمَّ قَرَأَ ‏\{‏إِنَّ اللَّهَ عِنْدَهُ عِلْمُ السَّاعَةِ‏\}‏‏.‏\hadithno{4778}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "The keys of the Unseen are five." And then he recited: 'Verily, the knowledge of the Hour is with Allah (alone)}}
\hadithdefcmd{bukhari}{4779}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى أَعْدَدْتُ لِعِبَادِي الصَّالِحِينَ مَا لاَ عَيْنٌ رَأَتْ، وَلاَ أُذُنٌ سَمِعَتْ، وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏فَلاَ تَعْلَمُ نَفْسٌ مَا أُخْفِيَ لَهُمْ مِنْ قُرَّةِ أَعْيُنٍ‏\}‏‏.‏ وَحَدَّثَنَا سُفْيَانُ حَدَّثَنَا أَبُو الزِّنَادِ عَنِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ قَالَ قَالَ اللَّهُ مِثْلَهُ‏.‏ قِيلَ لِسُفْيَانَ رِوَايَةً‏.‏ قَالَ فَأَىُّ شَىْءٍ قَالَ أَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ قَرَأَ أَبُو هُرَيْرَةَ قُرَّاتِ أَعْيُنٍ‏.‏\hadithno{4779}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, 'I have prepared for my pious worshipers such things as no eye has ever seen, no ear has ever heard of, and nobody has ever thought of." Abu Huraira added: If you wish you can read:-- 'No soul knows what is kept hidden (in reserve) for them of joy as reward for what they used to do}}
\hadithdefcmd{bukhari}{4780}{حَدَّثَنِي إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الأَعْمَشِ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ يَقُولُ اللَّهُ تَعَالَى أَعْدَدْتُ لِعِبَادِي الصَّالِحِينَ مَا لاَ عَيْنٌ رَأَتْ، وَلاَ أُذُنٌ سَمِعَتْ، وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ، ذُخْرًا، بَلْهَ مَا أُطْلِعْتُمْ عَلَيْهِ ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏فَلاَ تَعْلَمُ نَفْسٌ مَا أُخْفِيَ لَهُمْ مِنْ قُرَّةِ أَعْيُنٍ جَزَاءً بِمَا كَانُوا يَعْمَلُونَ‏\}‏\hadithno{4780}\hadithtrans{Narrated Abu Huraira:The Prophet, said, "Allah said, 'I have prepared for My pious worshipers such things as no eye has ever seen, no ear has ever heard of, and nobody has ever thought of. All that is reserved, besides which, all that you have seen, is nothing." Then he recited:-- 'No soul knows what is kept hidden (in reserve) for them of joy as a reward for what they used to do}}
\hadithdefcmd{bukhari}{4781}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، حَدَّثَنَا أَبِي، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ مُؤْمِنٍ إِلاَّ وَأَنَا أَوْلَى النَّاسِ بِهِ فِي الدُّنْيَا وَالآخِرَةِ، اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏النَّبِيُّ أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ‏\}‏ فَأَيُّمَا مُؤْمِنٍ تَرَكَ مَالاً فَلْيَرِثْهُ عَصَبَتُهُ مَنْ كَانُوا، فَإِنْ تَرَكَ دَيْنًا أَوْ ضِيَاعًا فَلْيَأْتِنِي وَأَنَا مَوْلاَهُ ‏"‏‏.‏\hadithno{4781}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There is no believer but I, of all the people, I am the closest to him both in this world and in the Hereafter. Recite if you wish: 'The Prophet (ﷺ) is closer to the believers than their own selves.' (33.6) so if a believer (dies) leaves some property then his relatives will inherit that property; but if he is in debt or he leaves poor children, let those (creditors and children) come to me (that I may pay the debt and provide for the children), for them I am his sponsor (surely)}}
\hadithdefcmd{bukhari}{4782}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، قَالَ حَدَّثَنِي سَالِمٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ زَيْدَ بْنَ حَارِثَةَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا كُنَّا نَدْعُوهُ إِلاَّ زَيْدَ ابْنَ مُحَمَّدٍ حَتَّى نَزَلَ الْقُرْآنُ ‏\{‏ادْعُوهُمْ لآبَائِهِمْ هُوَ أَقْسَطُ عِنْدَ اللَّهِ‏\}‏‏.‏\hadithno{4782}\hadithtrans{Narrated `Abdullah bin `Umar:We used not to call Zaid bin Haritha the freed slave of Allah's Messenger (ﷺ) except Zaid bin Muhammad till the Qur'anic Verse was revealed: "Call them (adopted sons) by (the names of) their fathers. That is more than just in the Sight of Allah}}
\hadithdefcmd{bukhari}{4783}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ نُرَى هَذِهِ الآيَةَ نَزَلَتْ فِي أَنَسِ بْنِ النَّضْرِ ‏\{‏مِنَ الْمُؤْمِنِينَ رِجَالٌ صَدَقُوا مَا عَاهَدُوا اللَّهَ عَلَيْهِ‏\}‏‏.‏\hadithno{4783}\hadithtrans{Narrated Anas:We think that the Verse: 'Among the Believers are men who have been true to their covenant with Allah,' was revealed in favor of Anas bin An-Nadr}}
\hadithdefcmd{bukhari}{4784}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، أَنَّ زَيْدَ بْنَ ثَابِتٍ، قَالَ لَمَّا نَسَخْنَا الصُّحُفَ فِي الْمَصَاحِفِ فَقَدْتُ آيَةً مِنْ سُورَةِ الأَحْزَابِ، كُنْتُ أَسْمَعُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَؤُهَا، لَمْ أَجِدْهَا مَعَ أَحَدٍ إِلاَّ مَعَ خُزَيْمَةَ الأَنْصَارِيِّ، الَّذِي جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهَادَتَهُ شَهَادَةَ رَجُلَيْنِ ‏\{‏مِنَ الْمُؤْمِنِينَ رِجَالٌ صَدَقُوا مَا عَاهَدُوا اللَّهَ عَلَيْهِ‏\}‏\hadithno{4784}\hadithtrans{Narrated Zaid bin Thabit:When we collected the fragmentary manuscripts of the Qur'an into copies, I missed one of the Verses of Surat al-Ahzab which I used to hear Allah's Messenger (ﷺ) reading. Finally I did not find it with anybody except Khuza`ima Al-Ansari, whose witness was considered by Allah's Messenger (ﷺ) equal to the witness of two men. (And that Verse was:) 'Among the believers are men who have been true to their covenant with Allah}}
\hadithdefcmd{bukhari}{4785}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، رضى الله عنها زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَهَا حِينَ أَمَرَ اللَّهُ أَنْ يُخَيِّرَ أَزْوَاجَهُ، فَبَدَأَ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ تَسْتَعْجِلِي حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏، وَقَدْ عَلِمَ أَنَّ أَبَوَىَّ لَمْ يَكُونَا يَأْمُرَانِي بِفِرَاقِهِ، قَالَتْ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ قَالَ ‏\{‏يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ‏\}‏ ‏"‏‏.‏ إِلَى تَمَامِ الآيَتَيْنِ فَقُلْتُ لَهُ فَفِي أَىِّ هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ‏.‏\hadithno{4785}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Allah's Messenger (ﷺ) came to me when Allah ordered him to give option to his wives. So Allah's Messenger (ﷺ) started with me, saying, "I am going to mention to you something but you should not hasten (to give your reply) unless you consult your parents.' He knew that my parents would not order me to leave him. Then he said, "Allah says:-- "O Prophet! Say to your wives..." (33.28-29) On that I said to him, "Then why should I consult my parents? Verily, I seek Allah, His Apostle and the Home of the Hereafter}}
\hadithdefcmd{bukhari}{4786}{وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَمَّا أُمِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِتَخْيِيرِ أَزْوَاجِهِ بَدَأَ بِي فَقَالَ ‏"‏ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ لاَ تَعْجَلِي حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏‏.‏ قَالَتْ وَقَدْ عَلِمَ أَنَّ أَبَوَىَّ لَمْ يَكُونَا يَأْمُرَانِي بِفِرَاقِهِ، قَالَتْ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ جَلَّ ثَنَاؤُهُ قَالَ ‏\{‏يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ إِنْ كُنْتُنَّ تُرِدْنَ الْحَيَاةَ الدُّنْيَا وَزِينَتَهَا‏\}‏ إِلَى ‏\{‏أَجْرًا عَظِيمًا‏\}‏ ‏"‏‏.‏ قَالَتْ فَقُلْتُ فَفِي أَىِّ هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ، قَالَتْ ثُمَّ فَعَلَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم مِثْلَ مَا فَعَلْتُ‏.‏ تَابَعَهُ مُوسَى بْنُ أَعْيَنَ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ‏.‏ وَقَالَ عَبْدُ الرَّزَّاقِ وَأَبُو سُفْيَانَ الْمَعْمَرِيُّ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ‏.‏\hadithno{4786}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) when Allah's Messenger (ﷺ) was ordered to give option to his wives, he started with me, saying, "I am going to mention to you something, but you shall not hasten (to give your reply) unless you consult your parents." The Prophet (ﷺ) knew that my parents would not order me to leave him. Then he said, "Allah says: 'O Prophet (Muhammad)! Say to your wives: If you desire the life of this world and its glitter........a great reward." (33.28-29) I said, "Then why I consult my parents? Verily, I seek Allah, His Apostle and the Home of the Hereafter." Then all the other wives of the Prophet (ﷺ) did the same as I did}}
\hadithdefcmd{bukhari}{4787}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، عَنْ حَمَّادِ بْنِ زَيْدٍ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ هَذِهِ، الآيَةَ ‏\{‏وَتُخْفِي فِي نَفْسِكَ مَا اللَّهُ مُبْدِيهِ‏\}‏ نَزَلَتْ فِي شَأْنِ زَيْنَبَ ابْنَةِ جَحْشٍ وَزَيْدِ بْنِ حَارِثَةَ‏.‏\hadithno{4787}\hadithtrans{Narrated Anas bin Malik:The Verse: 'But you did hide in your mind that which Allah was about to make manifest.' (33.37) was revealed concerning Zainab bint Jahsh and Zaid bin Haritha}}
\hadithdefcmd{bukhari}{4788}{حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ هِشَامٌ حَدَّثَنَا عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كُنْتُ أَغَارُ عَلَى اللاَّتِي وَهَبْنَ أَنْفُسَهُنَّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَأَقُولُ أَتَهَبُ الْمَرْأَةُ نَفْسَهَا فَلَمَّا أَنْزَلَ اللَّهُ تَعَالَى ‏\{‏تُرْجِئُ مَنْ تَشَاءُ مِنْهُنَّ وَتُؤْوِي إِلَيْكَ مَنْ تَشَاءُ وَمَنِ ابْتَغَيْتَ مِمَّنْ عَزَلْتَ فَلاَ جُنَاحَ عَلَيْكَ‏\}‏ قُلْتُ مَا أُرَى رَبَّكَ إِلاَّ يُسَارِعُ فِي هَوَاكَ‏.‏\hadithno{4788}\hadithtrans{Narrated Aisha:I used to look down upon those ladies who had given themselves to Allah's Messenger (ﷺ) and I used to say, "Can a lady give herself (to a man)?" But when Allah revealed: "You (O Muhammad) can postpone (the turn of) whom you will of them (your wives), and you may receive any of them whom you will; and there is no blame on you if you invite one whose turn you have set aside (temporarily).' (33.51) I said (to the Prophet), "I feel that your Lord hastens in fulfilling your wishes and desires}}
\hadithdefcmd{bukhari}{4789}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عَاصِمٌ الأَحْوَلُ، عَنْ مُعَاذَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسْتَأْذِنُ فِي يَوْمِ الْمَرْأَةِ مِنَّا بَعْدَ أَنْ أُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏تُرْجِئُ مَنْ تَشَاءُ مِنْهُنَّ وَتُؤْوِي إِلَيْكَ مَنْ تَشَاءُ وَمَنِ ابْتَغَيْتَ مِمَّنْ عَزَلْتَ فَلاَ جُنَاحَ عَلَيْكَ‏\}‏‏.‏ فَقُلْتُ لَهَا مَا كُنْتِ تَقُولِينَ قَالَتْ كُنْتُ أَقُولُ لَهُ إِنْ كَانَ ذَاكَ إِلَىَّ فَإِنِّي لاَ أُرِيدُ يَا رَسُولَ اللَّهِ أَنْ أُوثِرَ عَلَيْكَ أَحَدًا‏.‏ تَابَعَهُ عَبَّادُ بْنُ عَبَّادٍ سَمِعَ عَاصِمًا‏.‏\hadithno{4789}\hadithtrans{Narrated Mu`adha:`Aisha said, "Allah's Messenger (ﷺ) used to take the permission of that wife with whom he was supposed to stay overnight if he wanted to go to one other than her, after this Verse was revealed:-- "You (O Muhammad) can postpone (the turn of) whom you will of them (your wives) and you may receive any (of them) whom you will; and there is no blame on you if you invite one whose turn you have set aside (temporarily). (33.51) I asked Aisha, "What did you use to say (in this case)?" She said, "I used to say to him, "If I could deny you the permission (to go to your other wives) I would not allow your favor to be bestowed on any other person}}
\hadithdefcmd{bukhari}{4790}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ عُمَرُ ـ رضى الله عنه ـ قُلْتُ يَا رَسُولَ اللَّهِ، يَدْخُلُ عَلَيْكَ الْبَرُّ وَالْفَاجِرُ، فَلَوْ أَمَرْتَ أُمَّهَاتِ الْمُؤْمِنِينَ بِالْحِجَابِ، فَأَنْزَلَ اللَّهُ آيَةَ الْحِجَابِ‏.‏\hadithno{4790}\hadithtrans{Narrated `Umar:I said, "O Allah's Messenger (ﷺ)! Good and bad persons enter upon you, so I suggest that you order the mothers of the Believers (i.e. your wives) to observe veils." Then Allah revealed the Verses of Al- Hijab}}
\hadithdefcmd{bukhari}{4791}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرَّقَاشِيُّ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي يَقُولُ، حَدَّثَنَا أَبُو مِجْلَزٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ لَمَّا تَزَوَّجَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْنَبَ ابْنَةَ جَحْشٍ دَعَا الْقَوْمَ، فَطَعِمُوا ثُمَّ جَلَسُوا يَتَحَدَّثُونَ وَإِذَا هُوَ كَأَنَّهُ يَتَهَيَّأُ لِلْقِيَامِ فَلَمْ يَقُومُوا، فَلَمَّا رَأَى ذَلِكَ قَامَ، فَلَمَّا قَامَ قَامَ مَنْ قَامَ، وَقَعَدَ ثَلاَثَةُ نَفَرٍ فَجَاءَ النَّبِيُّ صلى الله عليه وسلم لِيَدْخُلَ فَإِذَا الْقَوْمُ جُلُوسٌ ثُمَّ إِنَّهُمْ قَامُوا، فَانْطَلَقْتُ فَجِئْتُ فَأَخْبَرْتُ النَّبِيَّ صلى الله عليه وسلم أَنَّهُمْ قَدِ انْطَلَقُوا، فَجَاءَ حَتَّى دَخَلَ، فَذَهَبْتُ أَدْخُلُ فَأَلْقَى الْحِجَابَ بَيْنِي وَبَيْنَهُ فَأَنْزَلَ اللَّهُ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ‏\}‏ الآيَةَ\hadithno{4791}\hadithtrans{Narrated Anas bin Malik:When Allah's Messenger (ﷺ) married Zainab bint Jahsh, he invited the people to a meal. They took the meal and remained sitting and talking. Then the Prophet (showed them) as if he is ready to get up, yet they did not get up. When he noticed that (there was no response to his movement), he got up, and the others too, got up except three persons who kept on sitting. The Prophet (ﷺ) came back in order to enter his house, but he went away again. Then they left, whereupon I set out and went to the Prophet (ﷺ) to tell him that they had departed, so he came and entered his house. I wanted to enter along with him, but he put a screen between me and him. Then Allah revealed: 'O you who believe! Do not enter the houses of the Prophet}}
\hadithdefcmd{bukhari}{4792}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، قَالَ أَنَسُ بْنُ مَالِكٍ أَنَا أَعْلَمُ النَّاسِ، بِهَذِهِ الآيَةِ آيَةِ الْحِجَابِ، لَمَّا أُهْدِيَتْ زَيْنَبُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَتْ مَعَهُ فِي الْبَيْتِ، صَنَعَ طَعَامًا، وَدَعَا الْقَوْمَ، فَقَعَدُوا يَتَحَدَّثُونَ، فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَخْرُجُ، ثُمَّ يَرْجِعُ، وَهُمْ قُعُودٌ يَتَحَدَّثُونَ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ إِلاَّ أَنْ يُؤْذَنَ لَكُمْ إِلَى طَعَامٍ غَيْرَ نَاظِرِينَ إِنَاهُ‏\}‏ إِلَى قَوْلِهِ ‏\{‏مِنْ وَرَاءِ حِجَابٍ‏\}‏ فَضُرِبَ الْحِجَابُ، وَقَامَ الْقَوْمُ‏.‏\hadithno{4792}\hadithtrans{Narrated Anas bin Malik:I of all the people know best this verse of Al-Hijab. When Allah's Messenger (ﷺ) married Zainab bint Jahsh she was with him in the house and he prepared a meal and invited the people (to it). They sat down (after finishing their meal) and started chatting. So the Prophet (ﷺ) went out and then returned several times while they were still sitting and talking. So Allah revealed the Verse: 'O you who believe! Enter not the Prophet's houses until leave is given to you for a meal, (and then) not (so early as) to wait for its preparation .....ask them from behind a screen.' (33.53) So the screen was set up and the people went away}}
\hadithdefcmd{bukhari}{4793}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ بُنِيَ عَلَى النَّبِيِّ صلى الله عليه وسلم بِزَيْنَبَ ابْنَةِ جَحْشٍ بِخُبْزٍ وَلَحْمٍ فَأُرْسِلْتُ عَلَى الطَّعَامِ دَاعِيًا فَيَجِيءُ قَوْمٌ فَيَأْكُلُونَ وَيَخْرُجُونَ، ثُمَّ يَجِيءُ قَوْمٌ فَيَأْكُلُونَ وَيَخْرُجُونَ، فَدَعَوْتُ حَتَّى مَا أَجِدُ أَحَدًا أَدْعُو فَقُلْتُ يَا نَبِيَّ اللَّهِ مَا أَجِدُ أَحَدًا أَدْعُوهُ قَالَ ارْفَعُوا طَعَامَكُمْ، وَبَقِيَ ثَلاَثَةُ رَهْطٍ يَتَحَدَّثُونَ فِي الْبَيْتِ، فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَانْطَلَقَ إِلَى حُجْرَةِ عَائِشَةَ فَقَالَ ‏ "‏ السَّلاَمُ عَلَيْكُمْ أَهْلَ الْبَيْتِ وَرَحْمَةُ اللَّهِ ‏"‏‏.‏ فَقَالَتْ وَعَلَيْكَ السَّلاَمُ وَرَحْمَةُ اللَّهِ، كَيْفَ وَجَدْتَ أَهْلَكَ بَارَكَ اللَّهُ لَكَ فَتَقَرَّى حُجَرَ نِسَائِهِ كُلِّهِنَّ، يَقُولُ لَهُنَّ كَمَا يَقُولُ لِعَائِشَةَ، وَيَقُلْنَ لَهُ كَمَا قَالَتْ عَائِشَةُ، ثُمَّ رَجَعَ النَّبِيُّ صلى الله عليه وسلم فَإِذَا ثَلاَثَةُ رَهْطٍ فِي الْبَيْتِ يَتَحَدَّثُونَ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم شَدِيدَ الْحَيَاءِ، فَخَرَجَ مُنْطَلِقًا نَحْوَ حُجْرَةِ عَائِشَةَ فَمَا أَدْرِي آخْبَرْتُهُ أَوْ أُخْبِرَ أَنَّ الْقَوْمَ خَرَجُوا، فَرَجَعَ حَتَّى إِذَا وَضَعَ رِجْلَهُ فِي أُسْكُفَّةِ الْبَابِ دَاخِلَةً وَأُخْرَى خَارِجَةً أَرْخَى السِّتْرَ بَيْنِي وَبَيْنَهُ، وَأُنْزِلَتْ آيَةُ الْحِجَابِ‏.‏\hadithno{4793}\hadithtrans{Narrated Anas:A banquet of bread and meat was held on the occasion of the marriage of the Prophet (ﷺ) to Zainab bint Jahsh. I was sent to invite the people (to the banquet), and so the people started coming (in groups); They would eat and then leave. Another batch would come, eat and leave. So I kept on inviting the people till I found nobody to invite. Then I said, "O Allah's Prophet! I do not find anybody to invite." He said, "Carry away the remaining food." Then a batch of three persons stayed in the house chatting. The Prophet (ﷺ) left and went towards the dwelling place of Aisha and said, "Peace and Allah's Mercy be on you, O the people of the house!" She replied, "Peace and the mercy of Allah be on you too. How did you find your wife? May Allah bless you. Then he went to the dwelling places of all his other wives and said to them the same as he said to Aisha and they said to him the same as Aisha had said to him. Then the Prophet (ﷺ) returned and found a group of three persons still in the house chatting. The Prophet was a very shy person, so he went out (for the second time) and went towards the dwelling place of `Aisha. I do not remember whether I informed him that the people have gone away. So he returned and as soon as he entered the gate, he drew the curtain between me and him, and then the Verse of Al-Hijab was revealed}}
\hadithdefcmd{bukhari}{4794}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ السَّهْمِيُّ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ أَوْلَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ بَنَى بِزَيْنَبَ ابْنَةِ جَحْشٍ فَأَشْبَعَ النَّاسَ خُبْزًا وَلَحْمًا ثُمَّ خَرَجَ إِلَى حُجَرِ أُمَّهَاتِ الْمُؤْمِنِينَ كَمَا كَانَ يَصْنَعُ صَبِيحَةَ بِنَائِهِ فَيُسَلِّمُ عَلَيْهِنَّ وَيَدْعُو لَهُنَّ وَيُسَلِّمْنَ عَلَيْهِ وَيَدْعُونَ لَهُ فَلَمَّا رَجَعَ إِلَى بَيْتِهِ رَأَى رَجُلَيْنِ جَرَى بِهِمَا الْحَدِيثُ، فَلَمَّا رَآهُمَا رَجَعَ عَنْ بَيْتِهِ، فَلَمَّا رَأَى الرَّجُلاَنِ نَبِيَّ اللَّهِ صلى الله عليه وسلم رَجَعَ عَنْ بَيْتِهِ وَثَبَا مُسْرِعَيْنِ، فَمَا أَدْرِي أَنَا أَخْبَرْتُهُ بِخُرُوجِهِمَا أَمْ أُخْبِرَ فَرَجَعَ حَتَّى دَخَلَ الْبَيْتَ، وَأَرْخَى السِّتْرَ بَيْنِي وَبَيْنَهُ وَأُنْزِلَتْ آيَةُ الْحِجَابِ‏.‏ وَقَالَ ابْنُ أَبِي مَرْيَمَ أَخْبَرَنَا يَحْيَى حَدَّثَنِي حُمَيْدٌ سَمِعَ أَنَسًا عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{4794}\hadithtrans{Narrated Anas:When Allah's Messenger (ﷺ) married Zainab bint Jahsh, he made the people eat meat and bread to their fill (by giving a Walima banquet). Then he went out to the dwelling places of the mothers of the believers (his wives), as he used to do in the morning of his marriage. He would greet them and invoke good on them, and they (too) would return his greeting and invoke good on him. When he returned to his house, he found two men talking to each other; and when he saw them, he went out of his house again. When those two men saw Allah's Messenger (ﷺ): going out of his house, they quickly got up (and departed). I do not remember whether I informed him of their departure, or he was informed (by somebody else). So he returned, and when he entered the house, he lowered the curtain between me and him. Then the Verse of Al-Hijab was revealed}}
\hadithdefcmd{bukhari}{4795}{حَدَّثَنِي زَكَرِيَّاءُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ خَرَجَتْ سَوْدَةُ بَعْدَ مَا ضُرِبَ الْحِجَابُ لِحَاجَتِهَا، وَكَانَتِ امْرَأَةً جَسِيمَةً لاَ تَخْفَى عَلَى مَنْ يَعْرِفُهَا، فَرَآهَا عُمَرُ بْنُ الْخَطَّابِ فَقَالَ يَا سَوْدَةُ أَمَا وَاللَّهِ مَا تَخْفَيْنَ عَلَيْنَا، فَانْظُرِي كَيْفَ تَخْرُجِينَ، قَالَتْ فَانْكَفَأَتْ رَاجِعَةً، وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِي، وَإِنَّهُ لَيَتَعَشَّى‏.‏ وَفِي يَدِهِ عَرْقٌ فَدَخَلَتْ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي خَرَجْتُ لِبَعْضِ حَاجَتِي فَقَالَ لِي عُمَرُ كَذَا وَكَذَا‏.‏ قَالَتْ فَأَوْحَى اللَّهُ إِلَيْهِ ثُمَّ رُفِعَ عَنْهُ وَإِنَّ الْعَرْقَ فِي يَدِهِ مَا وَضَعَهُ فَقَالَ ‏ "‏ إِنَّهُ قَدْ أُذِنَ لَكُنَّ أَنْ تَخْرُجْنَ لِحَاجَتِكُنَّ ‏"‏‏.‏\hadithno{4795}\hadithtrans{Narrated Aisha:Sauda (the wife of the Prophet) went out to answer the call of nature after it was made obligatory (for all the Muslims ladies) to observe the veil. She had a large frame and everybody who knew her before could recognize her. So `Umar bin Al-Khattab saw her and said, "O Sauda! By Allah, you cannot hide yourself from us, so think of a way by which you should not be recognized on going out. Sauda returned while Allah's Messenger (ﷺ) was in my house taking his supper and a bone covered with meat was in his hand. She entered and said, "O Allah's Messenger (ﷺ)! I went out to answer the call of nature and `Umar said to me so-and-so." Then Allah inspired him (the Prophet) and when the state of inspiration was over and the bone was still in his hand as he had not put in down, he said (to Sauda), "You (women) have been allowed to go out for your needs}}
\hadithdefcmd{bukhari}{4796}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اسْتَأْذَنَ عَلَىَّ أَفْلَحُ أَخُو أَبِي الْقُعَيْسِ بَعْدَ مَا أُنْزِلَ الْحِجَابُ، فَقُلْتُ لاَ آذَنُ لَهُ حَتَّى أَسْتَأْذِنَ فِيهِ النَّبِيَّ صلى الله عليه وسلم فَإِنَّ أَخَاهُ أَبَا الْقُعَيْسِ لَيْسَ هُوَ أَرْضَعَنِي، وَلَكِنْ أَرْضَعَتْنِي امْرَأَةُ أَبِي الْقُعَيْسِ، فَدَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ لَهُ يَا رَسُولَ اللَّهِ، إِنَّ أَفْلَحَ أَخَا أَبِي الْقُعَيْسِ اسْتَأْذَنَ، فَأَبَيْتُ أَنْ آذَنَ حَتَّى أَسْتَأْذِنَكَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَمَا مَنَعَكِ أَنْ تَأْذَنِي عَمُّكِ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ الرَّجُلَ لَيْسَ هُوَ أَرْضَعَنِي، وَلَكِنْ أَرْضَعَتْنِي امْرَأَةُ أَبِي الْقُعَيْسِ‏.‏ فَقَالَ ‏"‏ ائْذَنِي لَهُ فَإِنَّهُ عَمُّكِ، تَرِبَتْ يَمِينُكِ ‏"‏‏.‏ قَالَ عُرْوَةُ فَلِذَلِكَ كَانَتْ عَائِشَةُ تَقُولُ حَرِّمُوا مِنَ الرَّضَاعَةِ مَا تُحَرِّمُونَ مِنَ النَّسَبِ‏.‏\hadithno{4796}\hadithtrans{Narrated `Aisha:Aflah, the brother of Abi Al-Qu`ais, asked permission to visit me after the order of Al-Hijab was revealed. I said, "I will not permit him unless I take permission of the Prophet (ﷺ) about him for it was not the brother of Abi Al-Qu`ais but the wife of Abi Al-Qu`ais that nursed me." The Prophet (ﷺ) entered upon me, and I said to him, "O Allah's Messenger (ﷺ)! Aflah, the brother of Abi Al-Qu`ais asked permission to visit me but I refused to permit him unless I took your permission." The Prophet (ﷺ) said, "What stopped you from permitting him? He is your uncle." I said, "O Allah's Messenger (ﷺ)! The man was not the person who had nursed me, but the woman, the wife of Abi Al-Qu`ais had nursed me." He said, "Admit him, for he is your uncle. Taribat Yaminuki (may your right hand be saved)" `Urwa, the sub-narrator added: For that `Aisha used to say, "Consider those things which are illegal because of blood relations as illegal because of the corresponding foster relations}}
\hadithdefcmd{bukhari}{4797}{حَدَّثَنِي سَعِيدُ بْنُ يَحْيَى، حَدَّثَنَا أَبِي، حَدَّثَنَا مِسْعَرٌ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ ـ رضى الله عنه ـ قِيلَ يَا رَسُولَ اللَّهِ، أَمَّا السَّلاَمُ عَلَيْكَ فَقَدْ عَرَفْنَاهُ فَكَيْفَ الصَّلاَةُ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ، كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ، اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ، كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏‏.‏\hadithno{4797}\hadithtrans{Narrated Ka`b bin Ujra:It was said, "O Allah's Messenger (ﷺ)! We know how to greet you, but how to invoke Allah for you?" The Prophet said, "Say: Allahumma salli ala Muhammadin wa'ala `Ali Muhammaddin, kama sallaita 'ala all Ibrahim, innaka Hamidun Majid}}
\hadithdefcmd{bukhari}{4798}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي ابْنُ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ هَذَا التَّسْلِيمُ فَكَيْفَ نُصَلِّي عَلَيْكَ قَالَ ‏"‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ عَبْدِكَ وَرَسُولِكَ، كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ، وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ ‏"‏‏.‏ قَالَ أَبُو صَالِحٍ عَنِ اللَّيْثِ ‏"‏ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ، كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ ‏"‏‏.‏ حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، وَالدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ، وَقَالَ، ‏"‏ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ، وَبَارِكْ عَلَى مُحَمَّدٍ وَآلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ وَآلِ إِبْرَاهِيمَ ‏"‏‏.‏\hadithno{4798}\hadithtrans{Narrated Abu Sa`id Al-Khudri:We said, "O Allah's Messenger (ﷺ)! (We know) this greeting (to you) but how shall we invoke Allah for you?" He said, "Say! Allahumma salli ala Muhammadin `Abdika wa rasulika kama- sallaita 'ala all Ibrahim wa barik ala Muhammadin wa'ala all Muhammadin kama barakta 'ala all Ibrahim.' Al-Laith said: 'Ala Muhammadin wa 'ala all Muhammadin kama barakta ala all Ibrahim. Narrated Ibn Abi Hazim and Ad-Darawardi: Yazid said, "Kama sallaita ala Ibrahima wa barik 'ala Muhammad in wa all Muhammadin kama barakta 'ala Abrahima wa all Ibrahim}}
\hadithdefcmd{bukhari}{4799}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا عَوْفٌ، عَنِ الْحَسَنِ، وَمُحَمَّدٍ، وَخِلاَسٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مُوسَى كَانَ رَجُلاً حَيِيًّا، وَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَكُونُوا كَالَّذِينَ آذَوْا مُوسَى فَبَرَّأَهُ اللَّهُ مِمَّا قَالُوا وَكَانَ عِنْدَ اللَّهِ وَجِيهًا‏\}‏‏"‏\hadithno{4799}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Moses was a shy man, and that is what the Statement of Allah means: 'O you who believe Be not like those who annoyed Moses, but Allah proved his innocence of that which they alleged and he was honorable in Allah's Sight}}
\hadithdefcmd{bukhari}{4800}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، قَالَ سَمِعْتُ عِكْرِمَةَ، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَضَى اللَّهُ الأَمْرَ فِي السَّمَاءِ ضَرَبَتِ الْمَلاَئِكَةُ بِأَجْنِحَتِهَا خُضْعَانًا لِقَوْلِهِ كَأَنَّهُ سِلْسِلَةٌ عَلَى صَفْوَانٍ فَإِذَا فُزِّعَ عَنْ قُلُوبِهِمْ قَالُوا مَاذَا قَالَ رَبُّكُمْ، قَالُوا لِلَّذِي قَالَ الْحَقَّ وَهُوَ الْعَلِيُّ الْكَبِيرُ فَيَسْمَعُهَا مُسْتَرِقُ السَّمْعِ، وَمُسْتَرِقُ السَّمْعِ هَكَذَا بَعْضُهُ فَوْقَ بَعْضٍ ـ وَوَصَفَ سُفْيَانُ بِكَفِّهِ فَحَرَفَهَا وَبَدَّدَ بَيْنَ أَصَابِعِهِ ـ فَيَسْمَعُ الْكَلِمَةَ، فَيُلْقِيهَا إِلَى مَنْ تَحْتَهُ ثُمَّ يُلْقِيهَا الآخَرُ إِلَى مَنْ تَحْتَهُ، حَتَّى يُلْقِيَهَا عَلَى لِسَانِ السَّاحِرِ أَوِ الْكَاهِنِ، فَرُبَّمَا أَدْرَكَ الشِّهَابُ قَبْلَ أَنْ يُلْقِيَهَا، وَرُبَّمَا أَلْقَاهَا قَبْلَ أَنْ يُدْرِكَهُ، فَيَكْذِبُ مَعَهَا مِائَةَ كَذْبَةٍ، فَيُقَالُ أَلَيْسَ قَدْ قَالَ لَنَا يَوْمَ كَذَا وَكَذَا كَذَا وَكَذَا فَيُصَدَّقُ بِتِلْكَ الْكَلِمَةِ الَّتِي سَمِعَ مِنَ السَّمَاءِ ‏"‏‏.‏\hadithno{4800}\hadithtrans{Narrated Abu Huraira:Allah's Prophet said, "When Allah decrees some order in the heaven, the angels flutter their wings indicating complete surrender to His saying which sounds like chains being dragged on rock. And when the state of fear disappears, they ask each other, "What has your Lord ordered? They say that He has said that which is true and just, and He is the Most High, the Most Great." (34.23). Then the stealthy listeners (devils) hear this order, and these stealthy listeners are like this, one over the other." (Sufyan, a sub-narrator demonstrated that by holding his hand upright and separating the fingers.) A stealthy listener hears a word which he will convey to that which is below him and the second will convey it to that which is below him till the last of them will convey it to the wizard or foreteller. Sometimes a flame (fire) may strike the devil before he can convey it, and sometimes he may convey it before the flame (fire) strikes him, whereupon the wizard adds to that word a hundred lies. The people will then say, 'Didn't he (i.e. magician) tell such-and-such a thing on such-and-such date?' So that magician is said to have told the truth because of the Statement which has been heard from the heavens}}
\hadithdefcmd{bukhari}{4801}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ خَازِمٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ صَعِدَ النَّبِيُّ صلى الله عليه وسلم الصَّفَا ذَاتَ يَوْمٍ فَقَالَ ‏"‏ يَا صَبَاحَاهْ ‏"‏ فَاجْتَمَعَتْ إِلَيْهِ قُرَيْشٌ قَالُوا مَا لَكَ قَالَ ‏"‏ أَرَأَيْتُمْ لَوْ أَخْبَرْتُكُمْ أَنَّ الْعَدُوَّ يُصَبِّحُكُمْ أَوْ يُمَسِّيكُمْ أَمَا كُنْتُمْ تُصَدِّقُونِي ‏"‏‏.‏ قَالُوا بَلَى‏.‏ قَالَ ‏"‏ فَإِنِّي نَذِيرٌ لَكُمْ بَيْنَ يَدَىْ عَذَابٍ شَدِيدٍ ‏"‏‏.‏ فَقَالَ أَبُو لَهَبٍ تَبًّا لَكَ أَلِهَذَا جَمَعْتَنَا فَأَنْزَلَ اللَّهُ ‏\{‏تَبَّتْ يَدَا أَبِي لَهَبٍ‏\}‏‏.‏\hadithno{4801}\hadithtrans{Narrated Ibn `Abbas:One day the Prophet (ﷺ) ascended Safa mountain and said, "Oh Sabahah! " All the Quraish gathered round him and said, "What is the matter?" He said, Look, if I told you that an enemy is going to attack you in the morning or in the evening, would you not believe me?" They said, "Yes, we will believe you." He said, "I am a warner to you in face of a terrible punishment." On that Abu Lahab said, "May you perish ! Is it for this thing that you have gathered us?" So Allah revealed: 'Perish the hands of Abu Lahab}}
\hadithdefcmd{bukhari}{4802}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الْمَسْجِدِ عِنْدَ غُرُوبِ الشَّمْسِ فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ أَتَدْرِي أَيْنَ تَغْرُبُ الشَّمْسُ ‏"‏‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ فَإِنَّهَا تَذْهَبُ حَتَّى تَسْجُدَ تَحْتَ الْعَرْشِ، فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏وَالشَّمْسُ تَجْرِي لِمُسْتَقَرٍّ لَهَا ذَلِكَ تَقْدِيرُ الْعَزِيزِ الْعَلِيمِ‏\}‏‏"‏\hadithno{4802}\hadithtrans{Narrated Abu Dharr:Once I was with the Prophet (ﷺ) in the mosque at the time of sunset. The Prophet (ﷺ) said, "O Abu Dharr! Do you know where the sun sets?" I replied, "Allah and His Apostle know best." He said, "It goes and prostrates underneath (Allah's) Throne; and that is Allah's Statement:-- 'And the sun runs on its fixed course for a term (decreed). And that is the decree of All-Mighty, the All-Knowing}}
\hadithdefcmd{bukhari}{4803}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنْ قَوْلِهِ تَعَالَى ‏\{‏وَالشَّمْسُ تَجْرِي لِمُسْتَقَرٍّ لَهَا‏\}‏ قَالَ ‏"‏ مُسْتَقَرُّهَا تَحْتَ الْعَرْشِ ‏"‏‏.‏\hadithno{4803}\hadithtrans{Narrated Abu Dharr:I asked the Prophet (ﷺ) about the Statement of Allah:-- 'And the sun runs on fixed course for a term (decreed), ' (36.38) He said, "Its course is underneath "Allah's Throne." (Prostration of Sun trees, stars. mentioned in Qur'an and Hadith does not mean like our prostration but it means that these objects are obedient to their Creator (Allah) and they obey for what they have been created for}}
\hadithdefcmd{bukhari}{4804}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يَنْبَغِي لأَحَدٍ أَنْ يَكُونَ خَيْرًا مِنِ ابْنِ مَتَّى ‏"‏‏.‏\hadithno{4804}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "Nobody has the right to be better than (Jonah) bin Matta}}
\hadithdefcmd{bukhari}{4805}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ هِلاَلِ بْنِ عَلِيٍّ، مِنْ بَنِي عَامِرِ بْنِ لُؤَىٍّ عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى فَقَدْ كَذَبَ ‏"‏‏.‏\hadithno{4805}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "He who says that I am better than Jonah bin Matta, tells a lie}}
\hadithdefcmd{bukhari}{4806}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الْعَوَّامِ، قَالَ سَأَلْتُ مُجَاهِدًا عَنِ السَّجْدَةِ، فِي ص قَالَ سُئِلَ ابْنُ عَبَّاسٍ فَقَالَ ‏\{‏أُولَئِكَ الَّذِينَ هَدَى اللَّهُ فَبِهُدَاهُمُ اقْتَدِهْ‏\}‏‏.‏ وَكَانَ ابْنُ عَبَّاسٍ يَسْجُدُ فِيهَا‏.‏\hadithno{4806}\hadithtrans{Narrated Al-Awwam:I asked Mujahid regarding the prostration in Surat Sa`d. He said, "Ibn `Abbas was asked the same question and he said, 'Those are they (the prophets) whom Allah had Guided. So follow their guidance." (6.90) Ibn `Abbas used to perform a prostration (on reading this Sura)}}
\hadithdefcmd{bukhari}{4807}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنِ الْعَوَّامِ، قَالَ سَأَلْتُ مُجَاهِدًا عَنْ سَجْدَةِ، ص فَقَالَ سَأَلْتُ ابْنَ عَبَّاسٍ مِنْ أَيْنَ سَجَدْتَ فَقَالَ أَوَمَا تَقْرَأُ ‏\{‏وَمِنْ ذُرِّيَّتِهِ دَاوُدَ وَسُلَيْمَانَ‏\}‏ ‏\{‏أُولَئِكَ الَّذِينَ هَدَى اللَّهُ فَبِهُدَاهُمُ اقْتَدِهْ‏\}‏ فَكَانَ دَاوُدُ مِمَّنْ أُمِرَ نَبِيُّكُمْ صلى الله عليه وسلم أَنْ يَقْتَدِيَ بِهِ، فَسَجَدَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ ‏\{‏عُجَابٌ‏\}‏ عَجِيبٌ‏.‏ الْقِطُّ الصَّحِيفَةُ هُوَ هَا هُنَا صَحِيفَةُ الْحَسَنَاتِ‏.‏ وَقَالَ مُجَاهِدٌ ‏\{‏فِي عِزَّةٍ‏\}‏ مُعَازِّينَ‏.‏ ‏\{‏الْمِلَّةِ الآخِرَةِ‏\}‏ مِلَّةُ قُرَيْشٍ‏.‏ الاِخْتِلاَقُ الْكَذِبُ‏.‏ الأَسْبَابُ طُرُقُ السَّمَاءِ فِي أَبْوَابِهَا ‏\{‏جُنْدٌ مَا هُنَالِكَ مَهْزُومٌ‏\}‏ يَعْنِي قُرَيْشًا ‏\{‏أُولَئِكَ الأَحْزَابُ‏\}‏ الْقُرُونُ الْمَاضِيَةُ‏.‏ ‏\{‏فَوَاقٍ‏\}‏ رُجُوعٍ‏.‏ ‏\{‏قِطَّنَا‏\}‏ عَذَابَنَا ‏\{‏اتَّخَذْنَاهُمْ سُخْرِيًّا‏\}‏ أَحَطْنَا بِهِمْ أَتْرَابٌ أَمْثَالٌ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ الأَيْدُ الْقُوَّةُ فِي الْعِبَادَةِ الأَبْصَارُ الْبَصَرُ فِي أَمْرِ اللَّهِ، ‏\{‏حُبَّ الْخَيْرِ عَنْ ذِكْرِ رَبِّي‏\}‏ مِنْ ذِكْرٍ‏.‏ ‏\{‏طَفِقَ مَسْحًا‏\}‏ يَمْسَحُ أَعْرَافَ الْخَيْلِ وَعَرَاقِيبَهَا‏.‏ ‏\{‏الأَصْفَادِ‏\}‏ الْوَثَاقِ‏.‏\hadithno{4807}\hadithtrans{Narrated Al-Awwam:I asked Mujahid regarding the prostration in Surat Sa`d. He said, "I asked Ibn `Abbas, 'What evidence makes you prostrate?' He said, "Don't you recite:--'And among his progeny, David and Solomon..(6.84). Those are they whom Allah had guided. So follow their guidance.' (6.90) So David was the one of those prophets whom Prophet (Muhammad) was ordered to follow. David prostrated, so Allah's Messenger (ﷺ) (Muhammad) performed this prostration too}}
\hadithdefcmd{bukhari}{4808}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا رَوْحٌ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ عِفْرِيتًا مِنَ الْجِنِّ تَفَلَّتَ عَلَىَّ الْبَارِحَةَ ـ أَوْ كَلِمَةً نَحْوَهَا ـ لِيَقْطَعَ عَلَىَّ الصَّلاَةَ، فَأَمْكَنَنِي اللَّهُ مِنْهُ وَأَرَدْتُ أَنْ أَرْبِطَهُ إِلَى سَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ حَتَّى تُصْبِحُوا وَتَنْظُرُوا إِلَيْهِ كُلُّكُمْ، فَذَكَرْتُ قَوْلَ أَخِي سُلَيْمَانَ رَبِّ هَبْ لِي مُلْكًا لاَ يَنْبَغِي لأَحَدٍ مِنْ بَعْدِي ‏"‏‏.‏ قَالَ رَوْحٌ فَرَدَّهُ خَاسِئًا‏.‏\hadithno{4808}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Last night a demon from the Jinns came to me (or the Prophet (ﷺ) said, a similar sentence) to disturb my prayer, but Allah gave me the power to overcome him. I intended to tie him to one of the pillars of the mosque till the morning so that all of you could see him, but then I remembered the Statement of my brother Solomon:--'My Lord! Forgive me and bestow on me a kingdom such as shall not belong to any other after me.' (38.35) The narrator added: Then he (the Prophet) dismissed him, rejected}}
\hadithdefcmd{bukhari}{4809}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ دَخَلْنَا عَلَى عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ يَا أَيُّهَا النَّاسُ مَنْ عَلِمَ شَيْئًا فَلْيَقُلْ بِهِ، وَمَنْ لَمْ يَعْلَمْ فَلْيَقُلِ اللَّهُ أَعْلَمُ، فَإِنَّ مِنَ الْعِلْمِ أَنْ يَقُولَ لِمَا لاَ يَعْلَمُ اللَّهُ أَعْلَمُ، قَالَ اللَّهُ عَزَّ وَجَلَّ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏قُلْ مَا أَسْأَلُكُمْ عَلَيْهِ مِنْ أَجْرٍ وَمَا أَنَا مِنَ الْمُتَكَلِّفِينَ‏\}‏ وَسَأُحَدِّثُكُمْ عَنِ الدُّخَانِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَعَا قُرَيْشًا إِلَى الإِسْلاَمِ فَأَبْطَئُوا عَلَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ أَعِنِّي عَلَيْهِمْ بِسَبْعٍ كَسَبْعِ يُوسُفَ ‏"‏، فَأَخَذَتْهُمْ سَنَةٌ فَحَصَّتْ كُلَّ شَىْءٍ حَتَّى أَكَلُوا الْمَيْتَةَ وَالْجُلُودَ حَتَّى جَعَلَ الرَّجُلُ يَرَى بَيْنَهُ وَبَيْنَ السَّمَاءِ دُخَانًا مِنَ الْجُوعِ، قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ * يَغْشَى النَّاسَ هَذَا عَذَابٌ أَلِيمٌ‏\}‏ قَالَ فَدَعَوْا ‏\{‏رَبَّنَا اكْشِفْ عَنَّا الْعَذَابَ إِنَّا مُؤْمِنُونَ * أَنَّى لَهُمُ الذِّكْرَى وَقَدْ جَاءَهُمْ رَسُولٌ مُبِينٌ * ثُمَّ تَوَلَّوْا عَنْهُ وَقَالُوا مُعَلَّمٌ مَجْنُونٌ * إِنَّا كَاشِفُو الْعَذَابِ قَلِيلاً إِنَّكُمْ عَائِدُونَ‏\}‏ أَفَيُكْشَفُ الْعَذَابُ يَوْمَ الْقِيَامَةِ قَالَ فَكُشِفَ ثُمَّ عَادُوا فِي كُفْرِهِمْ، فَأَخَذَهُمُ اللَّهُ يَوْمَ بَدْرٍ قَالَ اللَّهُ تَعَالَى ‏\{‏يَوْمَ نَبْطِشُ الْبَطْشَةَ الْكُبْرَى إِنَّا مُنْتَقِمُونَ‏\}‏‏.‏\hadithno{4809}\hadithtrans{Narrated Masruq:We came upon `Abdullah bin Mas`ud and he said "O people! If somebody knows something, he can say it, but if he does not know it, he should say, "Allah knows better,' for it is a sign of having knowledge to say about something which one does not know, 'Allah knows better.' Allah said to His Prophet: 'Say (O Muhammad ! ) No wage do I ask of You for this (Qur'an) nor am I one of the pretenders (a person who pretends things which do not exist).' (38.86) Now I will tell you about Ad- Dukhan (the smoke), Allah's Messenger (ﷺ) invited the Quraish to embrace Islam, but they delayed their response. So he said, "O Allah! Help me against them by sending on them seven years of famine similar to the seven years of famine of Joseph." So the famine year overtook them and everything was destroyed till they ate dead animals and skins. People started imagining to see smoke between them and the sky because of severe hunger. Allah said: 'Then watch you for the Day that the sky will bring forth a kind of smoke plainly visible, covering the people. . . This is painful torment.' (44.10-11) (So they invoked Allah) "Our Lord! Remove the punishment from us really we are believers." How can there be an (effectual) reminder for them when an Apostle, explaining things clearly, has already come to them? Then they had turned away from him and said: 'One taught (by a human being), a madman?' 'We shall indeed remove punishment for a while, but truly, you will revert (to disbelief).' (44.12-15) Will the punishment be removed on the Day of Resurrection?" `Abdullah added, "The punishment was removed from them for a while but they reverted to disbelief, so Allah destroyed them on the Day of Badr. Allah said: 'The day We shall seize you with a mighty grasp. We will indeed (then) exact retribution}}
\hadithdefcmd{bukhari}{4810}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ يَعْلَى إِنَّ سَعِيدَ بْنَ جُبَيْرٍ أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ نَاسًا، مِنْ أَهْلِ الشِّرْكِ كَانُوا قَدْ قَتَلُوا وَأَكْثَرُوا وَزَنَوْا وَأَكْثَرُوا، فَأَتَوْا مُحَمَّدًا صلى الله عليه وسلم فَقَالُوا إِنَّ الَّذِي تَقُولُ وَتَدْعُو إِلَيْهِ لَحَسَنٌ لَوْ تُخْبِرُنَا أَنَّ لِمَا عَمِلْنَا كَفَّارَةً‏.‏ فَنَزَلَ ‏\{‏وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَلاَ يَزْنُونَ‏\}‏ وَنَزَلَ ‏\{‏قُلْ يَا عِبَادِيَ الَّذِينَ أَسْرَفُوا عَلَى أَنْفُسِهِمْ لاَ تَقْنَطُوا مِنْ رَحْمَةِ اللَّهِ‏\}‏\hadithno{4810}\hadithtrans{Narrated Ibn `Abbas:Some pagans who committed murders in great number and committed illegal sexual intercourse excessively, came to Muhammad and said, "O Muhammad! Whatever you say and invite people to, is good: but we wish if you could inform us whether we can make an expiation for our (past evil) deeds." So the Divine Verses came: 'Those who invoke not with Allah any other god, not kill such life as Allah has forbidden except for just cause, nor commit illegal sexual intercourse.' (25.68) And there was also revealed:-- 'Say: O My slaves who have transgressed against their souls! Despair not of the Mercy of Allah}}
\hadithdefcmd{bukhari}{4811}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ جَاءَ حَبْرٌ مِنَ الأَحْبَارِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ، إِنَّا نَجِدُ أَنَّ اللَّهَ يَجْعَلُ السَّمَوَاتِ عَلَى إِصْبَعٍ وَالأَرَضِينَ عَلَى إِصْبَعٍ، وَالشَّجَرَ عَلَى إِصْبَعٍ، وَالْمَاءَ وَالثَّرَى عَلَى إِصْبَعٍ، وَسَائِرَ الْخَلاَئِقِ عَلَى إِصْبَعٍ، فَيَقُولُ أَنَا الْمَلِكُ‏.‏ فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم حَتَّى بَدَتْ نَوَاجِذُهُ تَصْدِيقًا لِقَوْلِ الْحَبْرِ ثُمَّ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏وَمَا قَدَرُوا اللَّهَ حَقَّ قَدْرِهِ وَالأَرْضُ جَمِيعًا قَبْضَتُهُ يَوْمَ الْقِيَامَةِ وَالسَّمَوَاتُ مَطْوِيَّاتٌ بِيَمِينِهِ سُبْحَانَهُ وَتَعَالَى عَمَّا يُشْرِكُونَ‏\}‏\hadithno{4811}\hadithtrans{Narrated `Abdullah:A (Jewish) Rabbi came to Allah's Messenger (ﷺ) and he said, "O Muhammad! We learn that Allah will put all the heavens on one finger, and the earths on one finger, and the trees on one finger, and the water and the dust on one finger, and all the other created beings on one finger. Then He will say, 'I am the King.' Thereupon the Prophet (ﷺ) smiled so that his pre-molar teeth became visible, and that was the confirmation of the Rabbi. Then Allah's Messenger (ﷺ) recited: 'They made not a just estimate of Allah such as is due to Him. And on the Day of Resurrection the whole of the earth will be grasped by His Hand and the heavens will be rolled up in His Right Hand. Glorified is He, and High is He above all that they associate as partners with Him}}
\hadithdefcmd{bukhari}{4812}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدِ بْنِ مُسَافِرٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَقْبِضُ اللَّهُ الأَرْضَ، وَيَطْوِي السَّمَوَاتِ بِيَمِينِهِ، ثُمَّ يَقُولُ أَنَا الْمَلِكُ، أَيْنَ مُلُوكُ الأَرْضِ ‏"‏‏.‏\hadithno{4812}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "Allah will hold the whole earth, and roll all the heavens up in His Right Hand, and then He will say, 'I am the King; where are the kings of the earth?}}
\hadithdefcmd{bukhari}{4813}{حَدَّثَنِي الْحَسَنُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ خَلِيلٍ، أَخْبَرَنَا عَبْدُ الرَّحِيمِ، عَنْ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، عَنْ عَامِرٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي أَوَّلُ مَنْ يَرْفَعُ رَأْسَهُ بَعْدَ النَّفْخَةِ الآخِرَةِ، فَإِذَا أَنَا بِمُوسَى مُتَعَلِّقٌ بِالْعَرْشِ فَلاَ أَدْرِي أَكَذَلِكَ كَانَ أَمْ بَعْدَ النَّفْخَةِ ‏"‏‏.‏\hadithno{4813}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "I will be the first to raise my head after the second blowing of the trumpet and will see Moses hanging on the Throne, and I will not know whether he had been in that state all the time or after the blowing of the trumpet}}
\hadithdefcmd{bukhari}{4814}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَ النَّفْخَتَيْنِ أَرْبَعُونَ ‏"‏‏.‏ قَالُوا يَا أَبَا هُرَيْرَةَ أَرْبَعُونَ يَوْمًا قَالَ أَبَيْتُ‏.‏ قَالَ أَرْبَعُونَ سَنَةً قَالَ أَبَيْتُ‏.‏ قَالَ أَرْبَعُونَ شَهْرًا‏.‏ قَالَ أَبَيْتُ، وَيَبْلَى كُلُّ شَىْءٍ مِنَ الإِنْسَانِ إِلاَّ عَجْبَ ذَنَبِهِ، فِيهِ يُرَكَّبُ الْخَلْقُ‏.‏\hadithno{4814}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Between the two blowing of the trumpet there will be forty." The people said, "O Abu Huraira! Forty days?" I refused to reply. They said, "Forty years?" I refused to reply and added: Everything of the human body will decay except the coccyx bone (of the tail) and from that bone Allah will reconstruct the whole body}}
\hadithdefcmd{bukhari}{4815}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ التَّيْمِيُّ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ أَخْبِرْنِي بِأَشَدِّ، مَا صَنَعَ الْمُشْرِكُونَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ بَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِفِنَاءِ الْكَعْبَةِ، إِذْ أَقْبَلَ عُقْبَةُ بْنُ أَبِي مُعَيْطٍ، فَأَخَذَ بِمَنْكِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَوَى ثَوْبَهُ فِي عُنُقِهِ فَخَنَقَهُ خَنْقًا شَدِيدًا، فَأَقْبَلَ أَبُو بَكْرٍ فَأَخَذَ بِمَنْكِبِهِ، وَدَفَعَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏\{‏أَتَقْتُلُونَ رَجُلاً أَنْ يَقُولَ رَبِّيَ اللَّهُ وَقَدْ جَاءَكُمْ بِالْبَيِّنَاتِ مِنْ رَبِّكُمْ‏\}‏\hadithno{4815}\hadithtrans{Narrated `Urwa bin Az-Zubair:I asked `Abdullah bin `Amr bin Al-`As to inform me of the worst thing the pagans had done to Allah's Apostle. He said: "While Allah's Messenger (ﷺ) was praying in the courtyard of the Ka`ba, `Uqba bin Abi Mu'ait came and seized Allah's Messenger (ﷺ) by the shoulder and twisted his garment round his neck and throttled him severely. Abu Bakr came and seized `Uqba's shoulder and threw him away from Allah's Apostle and said, "Would you kill a man because he says: 'My Lord is Allah,' and has come to you with clear Signs from your Lord?}}
\hadithdefcmd{bukhari}{4816}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ رَوْحِ بْنِ الْقَاسِمِ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنِ ابْنِ مَسْعُودٍ، ‏\{‏وَمَا كُنْتُمْ تَسْتَتِرُونَ أَنْ يَشْهَدَ، عَلَيْكُمْ سَمْعُكُمْ‏\}‏ الآيَةَ كَانَ رَجُلاَنِ مِنْ قُرَيْشٍ وَخَتَنٌ لَهُمَا مِنْ ثَقِيفَ، أَوْ رَجُلاَنِ مِنْ ثَقِيفَ وَخَتَنٌ لَهُمَا مِنْ قُرَيْشٍ فِي بَيْتٍ فَقَالَ بَعْضُهُمْ لِبَعْضٍ أَتُرَوْنَ أَنَّ اللَّهَ يَسْمَعُ حَدِيثَنَا قَالَ بَعْضُهُمْ يَسْمَعُ بَعْضَهُ‏.‏ وَقَالَ بَعْضُهُمْ لَئِنْ كَانَ يَسْمَعُ بَعْضَهُ لَقَدْ يَسْمَعُ كُلَّهُ‏.‏ فَأُنْزِلَتْ ‏\{‏وَمَا كُنْتُمْ تَسْتَتِرُونَ أَنْ يَشْهَدَ عَلَيْكُمْ سَمْعُكُمْ وَلاَ أَبْصَارُكُمْ‏\}‏ الآية\hadithno{4816}\hadithtrans{Narrated Ibn Mas`ud:(regarding) the Verse: 'And you have not been screening against yourself lest your ears, and your eyes and your skins should testify against you..' (41.22) While two persons from Quraish and their brother-in-law from Thaqif (or two persons from Thaqif and their brother-in-law from Quraish) were in a house, they said to each other, "Do you think that Allah hears our talks?" Some said, "He hears a portion thereof" Others said, "If He can hear a portion of it, He can hear all of it." Then the following Verse was revealed: 'And you have not been screening against yourself lest your ears, and your eyes and your skins should testify against you}}
\hadithdefcmd{bukhari}{4817}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ اجْتَمَعَ عِنْدَ الْبَيْتِ قُرَشِيَّانِ وَثَقَفِيٌّ ـ أَوْ ثَقَفِيَّانِ وَقُرَشِيٌّ ـ كَثِيرَةٌ شَحْمُ بُطُونِهِمْ قَلِيلَةٌ فِقْهُ قُلُوبِهِمْ فَقَالَ أَحَدُهُمْ أَتُرَوْنَ أَنَّ اللَّهَ يَسْمَعُ مَا نَقُولُ قَالَ الآخَرُ يَسْمَعُ إِنْ جَهَرْنَا وَلاَ يَسْمَعُ إِنْ أَخْفَيْنَا‏.‏ وَقَالَ الآخَرُ إِنْ كَانَ يَسْمَعُ إِذَا جَهَرْنَا فَإِنَّهُ يَسْمَعُ إِذَا أَخْفَيْنَا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَمَا كُنْتُمْ تَسْتَتِرُونَ أَنْ يَشْهَدَ عَلَيْكُمْ سَمْعُكُمْ وَلاَ أَبْصَارُكُمْ وَلاَ جُلُودُكُمْ‏\}‏ الآيَةَ‏.‏ وَكَانَ سُفْيَانُ يُحَدِّثُنَا بِهَذَا فَيَقُولُ حَدَّثَنَا مَنْصُورٌ أَوِ ابْنُ أَبِي نَجِيحٍ أَوْ حُمَيْدٌ أَحَدُهُمْ أَوِ اثْنَانِ مِنْهُمْ، ثُمَّ ثَبَتَ عَلَى مَنْصُورٍ، وَتَرَكَ ذَلِكَ مِرَارًا غَيْرَ وَاحِدَةٍ‏.‏ حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، بِنَحْوِهِ‏.‏\hadithno{4817}\hadithtrans{Narrated `Abdullah:There gathered near the House (i.e. the Ka`ba) two Quraishi persons and a person from Thaqif (or two persons from Thaqif and one from Quraish), and all of them with very fat bellies but very little intelligence. One of them said, "Do you think that Allah hears what we say?" Another said, "He hears us when we talk in a loud voice, but He doesn't hear us when we talk in a low tone." The third said, "If He can hear when we talk in a loud tone, then He can also hear when we speak in a low tone." Then Allah, the Honorable, the Majestic revealed: 'And you have not been screening against yourself lest your ears, and eyes and your skins should testify against you....' (41.22-23) This hadith has been narrated through another chain as well}}
\hadithdefcmd{bukhari}{4818}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، قَالَ سَمِعْتُ طَاوُسًا، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ‏.‏ أَنَّهُ سُئِلَ عَنْ قَوْلِهِ ‏\{‏إِلاَّ الْمَوَدَّةَ فِي الْقُرْبَى‏\}‏ فَقَالَ سَعِيدُ بْنُ جُبَيْرٍ قُرْبَى آلِ مُحَمَّدٍ صلى الله عليه وسلم فَقَالَ ابْنُ عَبَّاسٍ عَجِلْتَ إِنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَكُنْ بَطْنٌ مِنْ قُرَيْشٍ إِلاَّ كَانَ لَهُ فِيهِمْ قَرَابَةٌ فَقَالَ إِلاَّ أَنْ تَصِلُوا مَا بَيْنِي وَبَيْنَكُمْ مِنَ الْقَرَابَةِ‏.‏\hadithno{4818}\hadithtrans{Narrated Ibn `Abbas:That he was asked (regarding): "Except to be kind to me for my Kinship with you.' (42.23) Sa`id bin Zubair (who was present then) said, "It means here (to show what is due for) the relatives of Muhammad." On that Ibn `Abbas said: you have hurried in giving the answer! There was no branch of the tribe of Quraish but the Prophet (ﷺ) had relatives therein. The Prophet (ﷺ) said, "I do not want anything from (you ) except to be Kind to me for my Kinship with you}}
\hadithdefcmd{bukhari}{4819}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ عَلَى الْمِنْبَرِ ‏\{‏وَنَادَوْا يَا مَالِكُ لِيَقْضِ عَلَيْنَا رَبُّكَ‏\}‏ وَقَالَ قَتَادَةُ مَثَلاً لِلآخِرِينَ عِظَةً ‏لِمَنْ بَعْدَهُمْ.‏ وَقَالَ غَيْرُهُ ‏\{‏مُقْرِنِينَ‏\}‏ ضَابِطِينَ يُقَالُ فُلاَنٌ مُقْرِنٌ لِفُلاَنٍ ضَابِطٌ لَهُ وَالأَكْوَابُ الأَبَارِيقُ الَّتِي لاَ خَرَاطِيمَ لَهَا ‏\{‏أَوَّلُ الْعَابِدِينَ‏\}‏ أَىْ مَا كَانَ فَأَنَا أَوَّلُ الأَنِفِينَ وَهُمَا لُغَتَانِ رَجُلٌ عَابِدٌ وَعَبِدٌ وَقَرَأَ عَبْدُ اللَّهِ ‏\{‏وَقَالَ الرَّسُولُ يَا رَبِّ‏\}‏ وَيُقَالُ أَوَّلُ الْعَابِدِينَ الْجَاحِدِينَ مِنْ عَبِدَ يَعْبَدُ‏.‏\hadithno{4819}\hadithtrans{Narrated Ya`la:I heard the Prophet (ﷺ) reciting when on the pulpit: 'They will cry, "O Malik (Keeper of Hell) Let your Lord make an end of us}}
\hadithdefcmd{bukhari}{4820}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ مَضَى خَمْسٌ الدُّخَانُ وَالرُّومُ وَالْقَمَرُ وَالْبَطْشَةُ وَاللِّزَامُ‏.‏\hadithno{4820}\hadithtrans{Narrated `Abdullah:Five things have passed, i.e. the smoke, the defeat of the Romans, the splitting of the moon, Al-Batsha (the defeat of the infidels in the battle of Badr) and Al-Lizam (the punishment)}}
\hadithdefcmd{bukhari}{4821}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، قَالَ قَالَ عَبْدُ اللَّهِ إِنَّمَا كَانَ هَذَا لأَنَّ قُرَيْشًا لَمَّا اسْتَعْصَوْا عَلَى النَّبِيِّ صلى الله عليه وسلم دَعَا عَلَيْهِمْ بِسِنِينَ كَسِنِي يُوسُفَ، فَأَصَابَهُمْ قَحْطٌ وَجَهْدٌ حَتَّى أَكَلُوا الْعِظَامَ، فَجَعَلَ الرَّجُلُ يَنْظُرُ إِلَى السَّمَاءِ فَيَرَى مَا بَيْنَهُ وَبَيْنَهَا كَهَيْئَةِ الدُّخَانِ مِنَ الْجَهْدِ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ * يَغْشَى النَّاسَ هَذَا عَذَابٌ أَلِيمٌ‏\}‏ قَالَ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقِيلَ يَا رَسُولَ اللَّهِ اسْتَسْقِ اللَّهَ لِمُضَرَ، فَإِنَّهَا قَدْ هَلَكَتْ‏.‏ قَالَ ‏"‏ لِمُضَرَ إِنَّكَ لَجَرِيءٌ ‏"‏‏.‏ فَاسْتَسْقَى فَسُقُوا‏.‏ فَنَزَلَتْ ‏\{‏إِنَّكُمْ عَائِدُونَ‏\}‏ فَلَمَّا أَصَابَتْهُمُ الرَّفَاهِيَةُ عَادُوا إِلَى حَالِهِمْ حِينَ أَصَابَتْهُمُ الرَّفَاهِيَةُ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏يَوْمَ نَبْطِشُ الْبَطْشَةَ الْكُبْرَى إِنَّا مُنْتَقِمُونَ‏\}‏ قَالَ يَعْنِي يَوْمَ بَدْرٍ‏.‏\hadithno{4821}\hadithtrans{Narrated `Abdullah:It (i.e., the imagined smoke) was because, when the Quraish refused to obey the Prophet, he asked Allah to afflict them with years of famine similar to those of (Prophet) Joseph. So they were stricken with famine and fatigue, so much so that they ate even bones. A man would look towards the sky and imagine seeing something like smoke between him and the sky because of extreme fatigue. So Allah revealed:-- 'Then watch you for the Day that the sky will bring forth a kind of smoke plainly visible, covering the people; this is a painful torment.' (44.10-11) Then someone (Abu Sufyan) came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Invoke Allah to send rain for the tribes of Mudar for they are on the verge of destruction." On that the Prophet (ﷺ) said (astonishingly) "Shall I invoke Allah) for the tribes of Mudar? Verily, you are a brave man!" But the Prophet prayed for rain and it rained for them. Then the Verse was revealed. 'But truly you will return (to disbelief).' (44.15) (When the famine was over and) they restored prosperity and welfare, they reverted to their ways (of heathenism) whereupon Allah revealed: 'On the Day when We shall seize you with a Mighty Grasp. We will indeed (then) exact retribution.' (44.16) The narrator said, "That was the day of the Battle of Badr}}
\hadithdefcmd{bukhari}{4822}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ دَخَلْتُ عَلَى عَبْدِ اللَّهِ فَقَالَ إِنَّ مِنَ الْعِلْمِ أَنْ تَقُولَ لِمَا لاَ تَعْلَمُ اللَّهُ أَعْلَمُ، إِنَّ اللَّهَ قَالَ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏قُلْ مَا أَسْأَلُكُمْ عَلَيْهِ مِنْ أَجْرٍ وَمَا أَنَا مِنَ الْمُتَكَلِّفِينَ‏\}‏ إِنَّ قُرَيْشًا لَمَّا غَلَبُوا النَّبِيَّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ وَاسْتَعْصَوْا عَلَيْهِ قَالَ اللَّهُمَّ أَعِنِّي عَلَيْهِمْ بِسَبْعٍ كَسَبْعِ يُوسُفَ فَأَخَذَتْهُمْ سَنَةٌ أَكَلُوا فِيهَا الْعِظَامَ وَالْمَيْتَةَ مِنْ الْجَهْدِ حَتَّى جَعَلَ أَحَدُهُمْ يَرَى مَا بَيْنَهُ وَبَيْنَ السَّمَاءِ كَهَيْئَةِ الدُّخَانِ مِنْ الْجُوعِ قَالُوا ￼ رَبَّنَا اكْشِفْ عَنَّا الْعَذَابَ إِنَّا مُؤْمِنُونَ ￼ فَقِيلَ لَهُ إِنْ كَشَفْنَا عَنْهُمْ عَادُوا فَدَعَا رَبَّهُ فَكَشَفَ عَنْهُمْ فَعَادُوا فَانْتَقَمَ اللَّهُ مِنْهُمْ يَوْمَ بَدْرٍ فَذَلِكَ قَوْلُهُ تَعَالَى ￼ فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ إِلَى قَوْلِهِ جَلَّ ذِكْرُهُ إِنَّا مُنْتَقِمُونَ\hadithno{4822}\hadithtrans{Narrated `Abdullah:It is a sign of having knowledge that, when you do not know something, you say: 'Allah knows better.' Allah said to his Prophet: 'Say: No wage do I ask of you for this (Qur'an), nor am I one of the pretenders (a person who pretends things which do not exist)' (38.86) When the Quraish troubled and stood against the Prophet (ﷺ) he said, "O Allah! Help me against them by afflicting them with seven years of famine like the seven years of Joseph." So they were stricken with a year of famine during which they ate bones and dead animals because of too much suffering, and one of them would see something like smoke between him and the sky because of hunger. Then they said: Our Lord! Remove the torment from us, really we are believers. (44.12) And then it was said to the Prophet (by Allah), "If We remove it from them, they will revert to their ways (of heathenism)." So the Prophet (ﷺ) invoked his Lord, who removed the punishment from them, but later they reverted (to heathenism), whereupon Allah punished them on the day of the Battle of Badr, and that is what Allah's Statement indicates: 'Then watch for the day that the sky will bring forth a kind of smoke plainly visible...We will indeed (then) exact retribution}}
\hadithdefcmd{bukhari}{4823}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ دَخَلْتُ عَلَى عَبْدِ اللَّهِ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا دَعَا قُرَيْشًا كَذَّبُوهُ وَاسْتَعْصَوْا عَلَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ أَعِنِّي عَلَيْهِمْ بِسَبْعٍ كَسَبْعِ يُوسُفَ ‏"‏‏.‏ فَأَصَابَتْهُمْ سَنَةٌ حَصَّتْ ـ يَعْنِي ـ كُلَّ شَىْءٍ حَتَّى كَانُوا يَأْكُلُونَ الْمَيْتَةَ فَكَانَ يَقُومُ أَحَدُهُمْ فَكَانَ يَرَى بَيْنَهُ وَبَيْنَ السَّمَاءِ مِثْلَ الدُّخَانِ مِنَ الْجَهْدِ وَالْجُوعِ ثُمَّ قَرَأَ ‏\{‏فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ * يَغْشَى النَّاسَ هَذَا عَذَابٌ أَلِيمٌ‏\}‏ حَتَّى بَلَغَ ‏\{‏إِنَّا كَاشِفُو الْعَذَابِ قَلِيلاً إِنَّكُمْ عَائِدُونَ‏\}‏ قَالَ عَبْدُ اللَّهِ أَفَيُكْشَفُ عَنْهُمُ الْعَذَابُ يَوْمَ الْقِيَامَةِ قَالَ وَالْبَطْشَةُ الْكُبْرَى يَوْمَ بَدْرٍ‏.‏\hadithno{4823}\hadithtrans{Narrated Masruq:I came upon `Abdullah and he said, "When Allah's Messenger (ﷺ) invited Quraish (to Islam), they disbelieved him and stood against him. So he (the Prophet) said, "O Allah! Help me against them by afflicting them with seven years of famine similar to the seven years of Joseph.' So they were stricken with a year of drought that destroyed everything, and they started eating dead animals, and if one of them got up he would see something like smoke between him and the sky from the severe fatigue and hunger." `Abdullah then recited:-- 'Then watch you for the Day that the sky will bring forth a kind of smoke plainly visible, covering the people. This is a painful torment... (till he reached) ........ We shall indeed remove the punishment for a while, but truly you will revert (to heathenism): (44.10-15) `Abdullah added: "Will the punishment be removed from them on the Day of Resurrection?" He added," The severe grasp" was the Day of the Battle of Badr}}
\hadithdefcmd{bukhari}{4824}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، وَمَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ قَالَ عَبْدُ اللَّهِ إِنَّ اللَّهَ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم وَقَالَ ‏\{‏قُلْ مَا أَسْأَلُكُمْ عَلَيْهِ مِنْ أَجْرٍ وَمَا أَنَا مِنَ الْمُتَكَلِّفِينَ‏\}‏ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا رَأَى قُرَيْشًا اسْتَعْصَوْا عَلَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ أَعِنِّي عَلَيْهِمْ بِسَبْعٍ كَسَبْعِ يُوسُفَ ‏"‏‏.‏ فَأَخَذَتْهُمُ السَّنَةُ حَتَّى حَصَّتْ كُلَّ شَىْءٍ حَتَّى أَكَلُوا الْعِظَامَ وَالْجُلُودَ ـ فَقَالَ أَحَدُهُمْ حَتَّى أَكَلُوا الْجُلُودَ وَالْمَيْتَةَ ـ وَجَعَلَ يَخْرُجُ مِنَ الأَرْضِ كَهَيْئَةِ الدُّخَانِ فَأَتَاهُ أَبُو سُفْيَانَ فَقَالَ أَىْ مُحَمَّدُ إِنَّ قَوْمَكَ قَدْ هَلَكُوا فَادْعُ اللَّهَ أَنْ يَكْشِفَ عَنْهُمْ فَدَعَا ثُمَّ قَالَ ‏"‏ تَعُودُوا بَعْدَ هَذَا ‏"‏‏.‏ فِي حَدِيثِ مَنْصُورٍ ثُمَّ قَرَأَ ‏\{‏فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ‏\}‏ إِلَى ‏\{‏عَائِدُونَ‏\}‏ أَيُكْشَفُ عَذَابُ الآخِرَةِ فَقَدْ مَضَى الدُّخَانُ وَالْبَطْشَةُ وَاللِّزَامُ وَقَالَ أَحَدُهُمُ الْقَمَرُ وَقَالَ الآخَرُ الرُّومُ‏.‏\hadithno{4824}\hadithtrans{Narrated `Abdullah:Allah sent (the Prophet) Muhammad and said:-- 'Say, No wage do I ask of you for this (Qur'an) nor am I one of the pretenders (i.e. a person who pretends things which do not exist). (38.68) When Allah's Messenger (ﷺ) saw Quraish standing against him, he said, "O Allah! Help me against them by afflicting them with seven years of famine similar to the seven years (of famine) of Joseph. So they were afflicted with a year of drought that destroyed everything, and they ate bones and hides. (One of them said), "And they ate hides and dead animals, and (it seemed to them that) something like smoke was coming out of the earth. So Abu Sufyan came to the Prophet (ﷺ) and said, "O Muhammad! Your people are on the verge of destruction! Please invoke Allah to relieve them." So the Prophet (ﷺ) invoked Allah for them (and the famine disappeared). He said to them. "You will revert (to heathenism) after that." `Abdullah then recited: 'Then watch you for the Day that the sky will bring forth a kind of smoke plainly visible.......but truly you will revert (to disbelief).' He added, "Will the punishment be removed from them in the Hereafter? The smoke and the grasp and the Al-Lizam have all passed." One of the sub-narrators said, "The splitting of the moon." And another said, "The defeat of the Romans (has passed)}}
\hadithdefcmd{bukhari}{4825}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ خَمْسٌ قَدْ مَضَيْنَ اللِّزَامُ وَالرُّومُ وَالْبَطْشَةُ وَالْقَمَرُ وَالدُّخَانُ‏.‏\hadithno{4825}\hadithtrans{Narrated `Abdullah:Five things have passed: Al-Lizam, the defeat of the Romans, the mighty grasp, the splitting of the moon, and the smoke}}
\hadithdefcmd{bukhari}{4826}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ يُؤْذِينِي ابْنُ آدَمَ، يَسُبُّ الدَّهْرَ وَأَنَا الدَّهْرُ، بِيَدِي الأَمْرُ، أُقَلِّبُ اللَّيْلَ وَالنَّهَارَ ‏"‏‏.‏\hadithno{4826}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, 'The son of Adam hurts me for he abuses Time though I am Time: in My Hands are all things, and I cause the revolution of day and night}}
\hadithdefcmd{bukhari}{4827}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، قَالَ كَانَ مَرْوَانُ عَلَى الْحِجَازِ اسْتَعْمَلَهُ مُعَاوِيَةُ، فَخَطَبَ فَجَعَلَ يَذْكُرُ يَزِيدَ بْنَ مُعَاوِيَةَ، لِكَىْ يُبَايِعَ لَهُ بَعْدَ أَبِيهِ، فَقَالَ لَهُ عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ شَيْئًا، فَقَالَ خُذُوهُ‏.‏ فَدَخَلَ بَيْتَ عَائِشَةَ فَلَمْ يَقْدِرُوا ‏\{‏عَلَيْهِ‏\}‏ فَقَالَ مَرْوَانُ إِنَّ هَذَا الَّذِي أَنْزَلَ اللَّهُ فِيهِ ‏\{‏وَالَّذِي قَالَ لِوَالِدَيْهِ أُفٍّ لَكُمَا أَتَعِدَانِنِي‏\}‏‏.‏ فَقَالَتْ عَائِشَةُ مِنْ وَرَاءِ الْحِجَابِ مَا أَنْزَلَ اللَّهُ فِينَا شَيْئًا مِنَ الْقُرْآنِ إِلاَّ أَنَّ اللَّهَ أَنْزَلَ عُذْرِي‏.‏\hadithno{4827}\hadithtrans{Narrated Yusuf bin Mahak:Marwan had been appointed as the governor of Hijaz by Muawiya. He delivered a sermon and mentioned Yazid bin Muawiya so that the people might take the oath of allegiance to him as the successor of his father (Muawiya). Then `Abdur Rahman bin Abu Bakr told him something whereupon Marwan ordered that he be arrested. But `Abdur-Rahman entered `Aisha's house and they could not arrest him. Marwan said, "It is he (`AbdurRahman) about whom Allah revealed this Verse:-- 'And the one who says to his parents: 'Fie on you! Do you hold out the promise to me..?'" On that, `Aisha said from behind a screen, "Allah did not reveal anything from the Qur'an about us except what was connected with the declaration of my innocence (of the slander)}}
\hadithdefcmd{bukhari}{4829}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، أَنَّ أَبَا النَّضْرِ، حَدَّثَهُ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَاحِكًا حَتَّى أَرَى مِنْهُ لَهَوَاتِهِ، إِنَّمَا كَانَ يَتَبَسَّمُ‏.‏ قَالَتْ وَكَانَ إِذَا رَأَى غَيْمًا أَوْ رِيحًا عُرِفَ فِي وَجْهِهِ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ النَّاسَ إِذَا رَأَوُا الْغَيْمَ فَرِحُوا، رَجَاءَ أَنْ يَكُونَ فِيهِ الْمَطَرُ، وَأَرَاكَ إِذَا رَأَيْتَهُ عُرِفَ فِي وَجْهِكَ الْكَرَاهِيَةُ‏.‏ فَقَالَ ‏"‏ يَا عَائِشَةُ مَا يُؤْمِنِّي أَنْ يَكُونَ فِيهِ عَذَابٌ عُذِّبَ قَوْمٌ بِالرِّيحِ، وَقَدْ رَأَى قَوْمٌ الْعَذَابَ فَقَالُوا ‏\{‏هَذَا عَارِضٌ مُمْطِرُنَا‏\}‏‏"‏\hadithno{4829}\hadithtrans{Narrated `Aisha:(the wife of the Prophet), I never saw Allah's Messenger (ﷺ) laughing loudly enough to enable me to see his uvula, but he used to smile only. And whenever he saw clouds or winds, signs of deep concern would appear on his face. I said, "O Allah's Messenger (ﷺ)! When people see clouds they usually feel happy, hoping that it would rain, while I see that when you see clouds, one could notice signs of dissatisfaction on your face." He said, "O `Aisha! What is the guarantee for me that there will be no punishment in it, since some people were punished with a wind? Verily, some people saw (received) the punishment, but (while seeing the cloud) they said, 'This cloud will give us rain}}
\hadithdefcmd{bukhari}{4830}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي مُعَاوِيَةُ بْنُ أَبِي مُزَرَّدٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ خَلَقَ اللَّهُ الْخَلْقَ، فَلَمَّا فَرَغَ مِنْهُ قَامَتِ الرَّحِمُ فَأَخَذَتْ بِحَقْوِ الرَّحْمَنِ فَقَالَ لَهَا مَهْ‏.‏ قَالَتْ هَذَا مَقَامُ الْعَائِذِ بِكَ مِنَ الْقَطِيعَةِ‏.‏ قَالَ أَلاَ تَرْضَيْنَ أَنْ أَصِلَ مَنْ وَصَلَكِ وَأَقْطَعَ مَنْ قَطَعَكِ‏.‏ قَالَتْ بَلَى يَا رَبِّ‏.‏ قَالَ فَذَاكِ لَكِ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏فهَلْ عَسَيْتُمْ إِنْ تَوَلَّيْتُمْ أَنْ تُفْسِدُوا فِي الأَرْضِ وَتُقَطِّعُوا أَرْحَامَكُمْ‏\}‏\hadithno{4830}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah created His creation, and when He had finished it, the womb, got up and caught hold of Allah whereupon Allah said, "What is the matter?' On that, it said, 'I seek refuge with you from those who sever the ties of Kith and kin.' On that Allah said, 'Will you be satisfied if I bestow My favors on him who keeps your ties, and withhold My favors from him who severs your ties?' On that it said, 'Yes, O my Lord!' Then Allah said, 'That is for you.' " Abu Huraira added: If you wish, you can recite: "Would you then if you were given the authority. do mischief in the land and sever your ties of kinship}}
\hadithdefcmd{bukhari}{4831}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا حَاتِمٌ، عَنْ مُعَاوِيَةَ، قَالَ حَدَّثَنِي عَمِّي أَبُو الْحُبَابِ، سَعِيدُ بْنُ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ، بِهَذَا، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏فَهَلْ عَسَيْتُمْ‏\}‏\hadithno{4831}\hadithtrans{Narrated Abu Huraira:(As above, No. 354, but added) Then Allah's Messenger (ﷺ) said, "Recite if you wish: "Would you then}}
\hadithdefcmd{bukhari}{4832}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مُعَاوِيَةُ بْنُ أَبِي الْمُزَرَّدِ، بِهَذَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏فَهَلْ عَسَيْتُمْ‏\}‏\hadithno{4832}\hadithtrans{Narrated Muawiya bin Abi Al-Muzarrad:Allah's Messenger (ﷺ), said, "Recite if you wish: Would you then if you were given the authority}}
\hadithdefcmd{bukhari}{4833}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسِيرُ فِي بَعْضِ أَسْفَارِهِ وَعُمَرُ بْنُ الْخَطَّابِ يَسِيرُ مَعَهُ لَيْلاً، فَسَأَلَهُ عُمَرُ بْنُ الْخَطَّابِ عَنْ شَىْءٍ، فَلَمْ يُجِبْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ سَأَلَهُ فَلَمْ يُجِبْهُ، ثُمَّ سَأَلَهُ فُلَمْ يُجِبْهُ، فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ثَكِلَتْ أُمُّ عُمَرَ، نَزَرْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم ثَلاَثَ مَرَّاتٍ، كُلَّ ذَلِكَ لاَ يُجِيبُكَ‏.‏ قَالَ عُمَرُ فَحَرَّكْتُ بَعِيرِي، ثُمَّ تَقَدَّمْتُ أَمَامَ النَّاسِ، وَخَشِيتُ أَنْ يُنْزَلَ فِيَّ الْقُرْآنُ، فَمَا نَشِبْتُ أَنْ سَمِعْتُ صَارِخًا يَصْرُخُ بِي فَقُلْتُ لَقَدْ خَشِيتُ أَنْ يَكُونَ نَزَلَ فِيَّ قُرْآنٌ‏.‏ فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ فَقَالَ ‏"‏ لَقَدْ أُنْزِلَتْ عَلَىَّ اللَّيْلَةَ سُورَةٌ لَهِيَ أَحَبُّ إِلَىَّ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ ‏"‏‏.‏ ثُمَّ قَرَأَ ‏"‏‏\{‏إِنَّا فَتَحْنَا لَكَ فَتْحًا مُبِينًا‏\}‏‏"‏\hadithno{4833}\hadithtrans{Narrated Aslam:While Allah's Messenger (ﷺ) was proceeding at night during one of his journeys and `Umar bin Al-Khattab was traveling beside him, `Umar asked him about something but Allah's Messenger (ﷺ) did not reply. He asked again, but he did not reply, and then he asked (for the third time) but he did not reply. On that, `Umar bin Al-Khattab said to himself, "Thakilat Ummu `Umar (May `Umar's mother lose her son)! I asked Allah's Messenger (ﷺ) three times but he did not reply." `Umar then said, "I made my camel run faster and went ahead of the people, and I was afraid that some Qur'anic Verses might be revealed about me. But before getting involved in any other matter. I heard somebody calling me. I said to myself, 'I fear that some Qur'anic Verses have been revealed about me,' and so I went to Allah's Messenger (ﷺ) and greeted him. He (Allah's Messenger (ﷺ) ) said, 'Tonight a Sura has been revealed to me, and it is dearer to me than that on which the sun rises (i.e. the world)' Then he recited: "Verily, We have given you a manifest victory}}
\hadithdefcmd{bukhari}{4834}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ ‏\{‏إِنَّا فَتَحْنَا لَكَ فَتْحًا مُبِينًا‏\}‏ قَالَ الْحُدَيْبِيَةُ‏.‏\hadithno{4834}\hadithtrans{Narrated Anas:"Verily, We have given you (O Muhammad) a manifest victory.' refers to Al-Hudaibiya Peace treaty}}
\hadithdefcmd{bukhari}{4835}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُعَاوِيَةُ بْنُ قُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَرَأَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ سُورَةَ الْفَتْحِ فَرَجَّعَ فِيهَا‏.‏ قَالَ مُعَاوِيَةُ لَوْ شِئْتُ أَنْ أَحْكِيَ لَكُمْ قِرَاءَةَ النَّبِيِّ صلى الله عليه وسلم لَفَعَلْتُ‏.‏\hadithno{4835}\hadithtrans{Narrated `Abdullah bin Mughaffal:On the Day of the Conquest of Mecca, the Prophet (ﷺ) recited Surat Al-Fath in a vibrating and pleasant voice. (Muawiya, the sub-narrator said, "If I could imitate the recitation of the Prophet (ﷺ) I would do so}}
\hadithdefcmd{bukhari}{4836}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، حَدَّثَنَا زِيَادٌ، أَنَّهُ سَمِعَ الْمُغِيرَةَ، يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم حَتَّى تَوَرَّمَتْ قَدَمَاهُ فَقِيلَ لَهُ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ قَالَ ‏ "‏ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏‏.‏\hadithno{4836}\hadithtrans{Narrated Al-Mughira:The Prophet (ﷺ) used to offer night prayers till his feet became swollen. Somebody said, to him," "Allah has forgiven you, your faults of the past and those to follow." On that, he said, "Shouldn't I be a thankful slave of Allah)?}}
\hadithdefcmd{bukhari}{4837}{حَدَّثَنَا الْحَسَنُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَحْيَى، أَخْبَرَنَا حَيْوَةُ، عَنْ أَبِي الأَسْوَدِ، سَمِعَ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَقُومُ مِنَ اللَّيْلِ حَتَّى تَتَفَطَّرَ قَدَمَاهُ فَقَالَتْ عَائِشَةُ لِمَ تَصْنَعُ هَذَا يَا رَسُولَ اللَّهِ وَقَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ قَالَ ‏ "‏ أَفَلاَ أُحِبُّ أَنْ أَكُونَ عَبْدًا شَكُورًا ‏"‏‏.‏ فَلَمَّا كَثُرَ لَحْمُهُ صَلَّى جَالِسًا فَإِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ، فَقَرَأَ ثُمَّ رَكَعَ‏.‏\hadithno{4837}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) used to offer prayer at night (for such a long time) that his feet used to crack. I said, "O Allah's Messenger (ﷺ)! Why do you do it since Allah has forgiven you your faults of the past and those to follow?" He said, "Shouldn't I love to be a thankful slave (of Allah)?' When he became old, he prayed while sitting, but if he wanted to perform a bowing, he would get up, recite (some other verses) and then perform the bowing}}
\hadithdefcmd{bukhari}{4838}{حَدَّثَنَا عَبْدُ اللَّهِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنْ هِلاَلِ بْنِ أَبِي هِلاَلٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنهما ـ أَنَّ هَذِهِ، الآيَةَ الَّتِي فِي الْقُرْآنِ ‏\{‏يَا أَيُّهَا النَّبِيُّ إِنَّا أَرْسَلْنَاكَ شَاهِدًا وَمُبَشِّرًا وَنَذِيرًا‏\}‏ قَالَ فِي التَّوْرَاةِ يَا أَيُّهَا النَّبِيُّ إِنَّا أَرْسَلْنَاكَ شَاهِدًا وَمُبَشِّرًا وَحِرْزًا لِلأُمِّيِّينَ، أَنْتَ عَبْدِي وَرَسُولِي سَمَّيْتُكَ الْمُتَوَكِّلَ لَيْسَ بِفَظٍّ وَلاَ غَلِيظٍ وَلاَ سَخَّابٍ بِالأَسْوَاقِ وَلاَ يَدْفَعُ السَّيِّئَةَ بِالسَّيِّئَةِ وَلَكِنْ يَعْفُو وَيَصْفَحُ وَلَنْ يَقْبِضَهُ اللَّهُ حَتَّى يُقِيمَ بِهِ الْمِلَّةَ الْعَوْجَاءَ بِأَنْ يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَيَفْتَحَ بِهَا أَعْيُنًا عُمْيًا وَآذَانًا صُمًّا وَقُلُوبًا غُلْفًا‏.‏\hadithno{4838}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-As:This Verse: 'Verily We have sent you (O Muhammad) as a witness, as a bringer of glad tidings and as a warner.' (48.8) which is in the Qur'an, appears in the Torah thus: 'Verily We have sent you (O Muhammad) as a witness, as a bringer of glad tidings and as a warner, and as a protector for the illiterates (i.e., the Arabs.) You are my slave and My Apostle, and I have named you Al-Mutawakkil (one who depends upon Allah). You are neither hard-hearted nor of fierce character, nor one who shouts in the markets. You do not return evil for evil, but excuse and forgive. Allah will not take you unto Him till He guides through you a crooked (curved) nation on the right path by causing them to say: "None has the right to be worshipped but Allah." With such a statement He will cause to open blind eyes, deaf ears and hardened hearts}}
\hadithdefcmd{bukhari}{4839}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ بَيْنَمَا رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يَقْرَأُ، وَفَرَسٌ لَهُ مَرْبُوطٌ فِي الدَّارِ، فَجَعَلَ يَنْفِرُ، فَخَرَجَ الرَّجُلُ فَنَظَرَ فَلَمْ يَرَ شَيْئًا، وَجَعَلَ يَنْفِرُ، فَلَمَّا أَصْبَحَ ذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ تِلْكَ السَّكِينَةُ تَنَزَّلَتْ بِالْقُرْآنِ ‏"‏‏.‏\hadithno{4839}\hadithtrans{Narrated Al-Bara:While a man from the companions of the Prophet (ﷺ) was reciting (Qur'an) and his horse was tied in the house, the horse got startled and started jumping. The man came out, looked around but could not find anything, yet the horse went on jumping. The next morning he mentioned that to the Prophet. The Prophet (ﷺ) said, "That was the tranquility (calmness) which descended because of the recitation of the Qur'an}}
\hadithdefcmd{bukhari}{4840}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، قَالَ كُنَّا يَوْمَ الْحُدَيْبِيَةِ أَلْفًا وَأَرْبَعَمِائَةٍ‏.‏\hadithno{4840}\hadithtrans{Narrated Jabir:We were one thousand and four hundred on the Day of Al-Hudaibiya}}
\hadithdefcmd{bukhari}{4841}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ عُقْبَةَ بْنَ صُهْبَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ الْمُزَنِيِّ، إِنِّي مِمَّنْ شَهِدَ الشَّجَرَةَ، نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الْخَذْفِ‏.‏\hadithno{4841}\hadithtrans{Narrated `Uqba bin Suhban:`Abdullah bin Mughaffal Al-Muzani who was one of those who witnessed (the event of) the tree, said, "The Prophet (ﷺ) forbade the throwing of small stones (with two fingers)}}
\hadithdefcmd{bukhari}{4842}{وَعَنْ عُقْبَةَ بْنِ صُهْبَانَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الْمُغَفَّلِ الْمُزَنِيِّ، فِي الْبَوْلِ فِي الْمُغْتَسَلِ‏.‏\hadithno{4842}\hadithtrans{Abdullah bin Al-Mughaffal Al-Muzani also said:"The Prophet (ﷺ) also forbade urinating at the place where one takes a bath}}
\hadithdefcmd{bukhari}{4843}{حَدَّثَنِي مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ ـ رضى الله عنه ـ وَكَانَ مِنْ أَصْحَابِ الشَّجَرَةِ‏.‏\hadithno{4843}\hadithtrans{Narrated Thabit bin Ad-Dahhak:who was one of the companions of the tree (those who swore allegiance to the Prophet (ﷺ) beneath the tree at Al-Hudaibiya):}}
\hadithdefcmd{bukhari}{4844}{حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ السُّلَمِيُّ، حَدَّثَنَا يَعْلَى، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ سِيَاهٍ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، قَالَ أَتَيْتُ أَبَا وَائِلٍ أَسْأَلُهُ فَقَالَ كُنَّا بِصِفِّينَ فَقَالَ رَجُلٌ أَلَمْ تَرَ إِلَى الَّذِينَ يُدْعَوْنَ إِلَى كِتَابِ اللَّهِ‏.‏ فَقَالَ عَلِيٌّ نَعَمْ‏.‏ فَقَالَ سَهْلُ بْنُ حُنَيْفٍ اتَّهِمُوا أَنْفُسَكُمْ فَلَقَدْ رَأَيْتُنَا يَوْمَ الْحُدَيْبِيَةِ ـ يَعْنِي الصُّلْحَ الَّذِي كَانَ بَيْنَ النَّبِيِّ صلى الله عليه وسلم وَالْمُشْرِكِينَ ـ وَلَوْ نَرَى قِتَالاً لَقَاتَلْنَا، فَجَاءَ عُمَرُ فَقَالَ أَلَسْنَا عَلَى الْحَقِّ وَهُمْ عَلَى الْبَاطِلِ أَلَيْسَ قَتْلاَنَا فِي الْجَنَّةِ وَقَتْلاَهُمْ فِي النَّارِ قَالَ ‏"‏ بَلَى ‏"‏‏.‏ قَالَ فَفِيمَ أُعْطِي الدَّنِيَّةَ فِي دِينِنَا، وَنَرْجِعُ وَلَمَّا يَحْكُمِ اللَّهُ بَيْنَنَا‏.‏ فَقَالَ ‏"‏ يَا ابْنَ الْخَطَّابِ إِنِّي رَسُولُ اللَّهِ وَلَنْ يُضَيِّعَنِي اللَّهُ أَبَدًا ‏"‏‏.‏ فَرَجَعَ مُتَغَيِّظًا، فَلَمْ يَصْبِرْ حَتَّى جَاءَ أَبَا بَكْرٍ فَقَالَ يَا أَبَا بَكْرٍ أَلَسْنَا عَلَى الْحَقِّ وَهُمْ عَلَى الْبَاطِلِ قَالَ يَا ابْنَ الْخَطَّابِ إِنَّهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَنْ يُضَيِّعَهُ اللَّهُ أَبَدًا‏.‏ فَنَزَلَتْ سُورَةُ الْفَتْحِ‏.‏\hadithno{4844}\hadithtrans{Narrated Habib bin Abi Thabit:I went to Abu Wail to ask him (about those who had rebelled against `Ali). On that Abu Wail said, "We were at Siffin (a city on the bank of the Euphrates, the place where the battle took place between `Ali and Muawiya) A man said, "Will you be on the side of those who are called to consult Allah's Book (to settle the dispute)?" `Ali said, 'Yes (I agree that we should settle the matter in the light of the Qur'an)." ' Some people objected to `Ali's agreement and wanted to fight. On that Sahl bin Hunaif said, 'Blame yourselves! I remember how, on the day of Al-Hudaibiya (i.e. the peace treaty between the Prophet (ﷺ) and the Quraish pagans), if we had been allowed to choose fighting, we would have fought (the pagans). At that time `Umar came (to the Prophet) and said, "Aren't we on the right (path) and they (pagans) in the wrong? Won't our killed persons go to Paradise, and theirs in the Fire?" The Prophet replied, "Yes." `Umar further said, "Then why should we let our religion be degraded and return before Allah has settled the matter between us?" The Prophet (ﷺ) said, "O the son of Al-Khattab! No doubt, I am Allah's Messenger (ﷺ) and Allah will never neglect me." So `Umar left the place angrily and he was so impatient that he went to Abu Bakr and said, "O Abu Bakr! Aren't we on the right (path) and they (pagans) on the wrong?" Abu Bakr said, "O the son of Al-Khattab! He is Allah's Messenger (ﷺ), and Allah will never neglect him." Then Sura Al-Fath (The Victory) was revealed}}
\hadithdefcmd{bukhari}{4845}{حَدَّثَنَا يَسَرَةُ بْنُ صَفْوَانَ بْنِ جَمِيلٍ اللَّخْمِيُّ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ كَادَ الْخَيِّرَانِ أَنْ يَهْلِكَا ـ أَبَا بَكْرٍ وَعُمَرَ ـ رضى الله عنهما ـ رَفَعَا أَصْوَاتَهُمَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم حِينَ قَدِمَ عَلَيْهِ رَكْبُ بَنِي تَمِيمٍ، فَأَشَارَ أَحَدُهُمَا بِالأَقْرَعِ بْنِ حَابِسٍ أَخِي بَنِي مُجَاشِعٍ، وَأَشَارَ الآخَرُ بِرَجُلٍ آخَرَ ـ قَالَ نَافِعٌ لاَ أَحْفَظُ اسْمَهُ ـ فَقَالَ أَبُو بَكْرٍ لِعُمَرَ مَا أَرَدْتَ إِلاَّ خِلاَفِي‏.‏ قَالَ مَا أَرَدْتُ خِلاَفَكَ‏.‏ فَارْتَفَعَتْ أَصْوَاتُهُمَا فِي ذَلِكَ، فَأَنْزَلَ اللَّهُ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَرْفَعُوا أَصْوَاتَكُمْ‏\}‏ الآيَةَ‏.‏ قَالَ ابْنُ الزُّبَيْرِ فَمَا كَانَ عُمَرُ يُسْمِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ هَذِهِ الآيَةِ حَتَّى يَسْتَفْهِمَهُ‏.‏ وَلَمْ يَذْكُرْ ذَلِكَ عَنْ أَبِيهِ، يَعْنِي أَبَا بَكْرٍ‏.‏\hadithno{4845}\hadithtrans{Narrated Ibn Abi Mulaika:The two righteous persons were about to be ruined. They were Abu Bakr and `Umar who raised their voices in the presence of the Prophet (ﷺ) when a mission from Bani Tamim came to him. One of the two recommended Al-Aqra' bin Habis, the brother of Bani Mujashi (to be their governor) while the other recommended somebody else. (Nafi`, the sub-narrator said, I do not remember his name). Abu Bakr said to `Umar, "You wanted nothing but to oppose me!" `Umar said, "I did not intend to oppose you." Their voices grew loud in that argument, so Allah revealed: 'O you who believe! Raise not your voices above the voice of the Prophet.' (49.2) Ibn Az-Zubair said, "Since the revelation of this Verse, `Umar used to speak in such a low tone that the Prophet (ﷺ) had to ask him to repeat his statements." But Ibn Az-Zubair did not mention the same about his (maternal) grandfather (i.e. Abu Bakr)}}
\hadithdefcmd{bukhari}{4846}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَزْهَرُ بْنُ سَعْدٍ، أَخْبَرَنَا ابْنُ عَوْنٍ، قَالَ أَنْبَأَنِي مُوسَى بْنُ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم افْتَقَدَ ثَابِتَ بْنَ قَيْسٍ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَنَا أَعْلَمُ لَكَ عِلْمَهُ‏.‏ فَأَتَاهُ فَوَجَدَهُ جَالِسًا فِي بَيْتِهِ مُنَكِّسًا رَأْسَهُ فَقَالَ لَهُ مَا شَأْنُكَ‏.‏ فَقَالَ شَرٌّ‏.‏ كَانَ يَرْفَعُ صَوْتَهُ فَوْقَ صَوْتِ النَّبِيِّ صلى الله عليه وسلم فَقَدْ حَبِطَ عَمَلُهُ، وَهْوَ مِنْ أَهْلِ النَّارِ‏.‏ فَأَتَى الرَّجُلُ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ أَنَّهُ قَالَ كَذَا وَكَذَا ـ فَقَالَ مُوسَى ـ فَرَجَعَ إِلَيْهِ الْمَرَّةَ الآخِرَةَ بِبِشَارَةٍ عَظِيمَةٍ فَقَالَ ‏ "‏ اذْهَبْ إِلَيْهِ فَقُلْ لَهُ إِنَّكَ لَسْتَ مِنْ أَهْلِ النَّارِ، وَلَكِنَّكَ مِنْ أَهْلِ الْجَنَّةِ ‏"‏‏.‏\hadithno{4846}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) missed Thabit bin Qais for a period (So he inquired about him). A man said. "O Allah's Apostle! I will bring you his news." So he went to Thabit and found him sitting in his house and bowing his head. The man said to Thabit, " 'What is the matter with you?" Thabit replied that it was an evil affair, for he used to raise his voice above the voice of the Prophet (ﷺ) and so all his good deeds had been annulled, and he considered himself as one of the people of the Fire. Then the man returned to the Prophet (ﷺ) and told him that Thabit had said, so-and-so. (Musa bin Anas) said: The man returned to Thabit with great glad tidings. The Prophet (ﷺ) said to the man. "Go back to him and say to him: "You are not from the people of the Hell Fire, but from the people of Paradise}}
\hadithdefcmd{bukhari}{4847}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، أَخْبَرَهُمْ أَنَّهُ، قَدِمَ رَكْبٌ مِنْ بَنِي تَمِيمٍ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَبُو بَكْرٍ أَمِّرِ الْقَعْقَاعَ بْنَ مَعْبَدٍ‏.‏ وَقَالَ عُمَرُ بَلْ أَمِّرِ الأَقْرَعَ بْنَ حَابِسٍ‏.‏ فَقَالَ أَبُو بَكْرٍ مَا أَرَدْتَ إِلَى ـ أَوْ إِلاَّ ـ خِلاَفِي‏.‏ فَقَالَ عُمَرُ مَا أَرَدْتُ خِلاَفَكَ‏.‏ فَتَمَارَيَا حَتَّى ارْتَفَعَتْ أَصْوَاتُهُمَا، فَنَزَلَ فِي ذَلِكَ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تُقَدِّمُوا بَيْنَ يَدَىِ اللَّهِ وَرَسُولِهِ‏\}‏ حَتَّى انْقَضَتِ الآيَةُ‏.‏\hadithno{4847}\hadithtrans{Narrated `Abdullah bin Az-Zubair:A group of Bani Tamim came to the Prophet (and requested him to appoint a governor for them). Abu Bakr said, "Appoint Al-Qaqa bin Mabad." `Umar said, "Appoint Al-Aqra' bin Habis." On that Abu Bakr said (to `Umar). "You did not want but to oppose me!" `Umar replied "I did not intend to oppose you!" So both of them argued till their voices grew loud. So the following Verse was revealed: 'O you who believe! Be not forward}}
\hadithdefcmd{bukhari}{4848}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا حَرَمِيٌّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُلْقَى فِي النَّارِ وَتَقُولُ هَلْ مِنْ مَزِيدٍ‏.‏ حَتَّى يَضَعَ قَدَمَهُ فَتَقُولُ قَطِ قَطِ ‏"‏‏.‏\hadithno{4848}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "The people will be thrown into the (Hell) Fire and it will say: "Are there any more (to come)?' (50.30) till Allah puts His Foot over it and it will say, 'Qati! Qati! (Enough Enough)}}
\hadithdefcmd{bukhari}{4849}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْقَطَّانُ، حَدَّثَنَا أَبُو سُفْيَانَ الْحِمْيَرِيُّ، سَعِيدُ بْنُ يَحْيَى بْنِ مَهْدِيٍّ حَدَّثَنَا عَوْفٌ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، رَفَعَهُ وَأَكْثَرُ مَا كَانَ يُوقِفُهُ أَبُو سُفْيَانَ ‏ "‏ يُقَالُ لِجَهَنَّمَ هَلِ امْتَلأْتِ وَتَقُولُ هَلْ مِنْ مَزِيدٍ فَيَضَعُ الرَّبُّ تَبَارَكَ وَتَعَالَى قَدَمَهُ عَلَيْهَا فَتَقُولُ قَطِ قَطِ ‏"‏‏.‏\hadithno{4849}\hadithtrans{Narrated Abu Huraira:(that the Prophet (ﷺ) said) "It will be said to the Hell, 'Are you filled?' It will say, 'Are there any more (to come)?' On that Allah will put His Foot on it, and it will say 'Qati! Qati! (Enough! Enough)}}
\hadithdefcmd{bukhari}{4850}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تَحَاجَّتِ الْجَنَّةُ وَالنَّارُ فَقَالَتِ النَّارُ أُوثِرْتُ بِالْمُتَكَبِّرِينَ وَالْمُتَجَبِّرِينَ‏.‏ وَقَالَتِ الْجَنَّةُ مَا لِي لاَ يَدْخُلُنِي إِلاَّ ضُعَفَاءُ النَّاسِ وَسَقَطُهُمْ‏.‏ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى لِلْجَنَّةِ أَنْتِ رَحْمَتِي أَرْحَمُ بِكِ مَنْ أَشَاءُ مِنْ عِبَادِي‏.‏ وَقَالَ لِلنَّارِ إِنَّمَا أَنْتِ عَذَابٌ أُعَذِّبُ بِكِ مَنْ أَشَاءُ مِنْ عِبَادِي‏.‏ وَلِكُلِّ وَاحِدَةٍ مِنْهُمَا مِلْؤُهَا، فَأَمَّا النَّارُ فَلاَ تَمْتَلِئُ حَتَّى يَضَعَ رِجْلَهُ فَتَقُولُ قَطٍ قَطٍ قَطٍ‏.‏ فَهُنَالِكَ تَمْتَلِئُ وَيُزْوَى بَعْضُهَا إِلَى بَعْضٍ، وَلاَ يَظْلِمُ اللَّهُ ـ عَزَّ وَجَلَّ ـ مِنْ خَلْقِهِ أَحَدًا، وَأَمَّا الْجَنَّةُ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ يُنْشِئُ لَهَا خَلْقًا ‏"‏‏.‏\hadithno{4850}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Paradise and the Fire (Hell) argued, and the Fire (Hell) said, "I have been given the privilege of receiving the arrogant and the tyrants.' Paradise said, 'What is the matter with me? Why do only the weak and the humble among the people enter me?' On that, Allah said to Paradise. 'You are My Mercy which I bestow on whoever I wish of my servants.' Then Allah said to the (Hell) Fire, 'You are my (means of) punishment by which I punish whoever I wish of my slaves. And each of you will have its fill.' As for the Fire (Hell), it will not be filled till Allah puts His Foot over it whereupon it will say, 'Qati! Qati!' At that time it will be filled, and its different parts will come closer to each other; and Allah will not wrong any of His created beings. As regards Paradise, Allah will create a new creation to fill it with}}
\hadithdefcmd{bukhari}{4851}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ جَرِيرٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا جُلُوسًا لَيْلَةً مَعَ النَّبِيِّ صلى الله عليه وسلم فَنَظَرَ إِلَى الْقَمَرِ لَيْلَةَ أَرْبَعَ عَشْرَةَ فَقَالَ ‏"‏ إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ كَمَا تَرَوْنَ هَذَا، لاَ تُضَامُونَ فِي رُؤْيَتِهِ، فَإِنِ اسْتَطَعْتُمْ أَنْ لاَ تُغْلَبُوا عَلَى صَلاَةٍ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا فَافْعَلُوا ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏وَسَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ الْغُرُوبِ‏\}‏\hadithno{4851}\hadithtrans{Narrated Jarir bin `Abdullah:We were in the company of the Prophet (ﷺ) on a fourteenth night (of the lunar month), and he looked at the (full) moon and said, "You will see your Lord as you see this moon, and you will have no trouble in looking at Him. So, whoever can, should not miss the offering of prayers before sunrise (Fajr prayer) and before sunset (`Asr prayer)." Then the Prophet (ﷺ) recited: 'And celebrate the praises of your Lord before the rising of the sun and before (its) setting}}
\hadithdefcmd{bukhari}{4852}{حَدَّثَنَا آدَمُ، حَدَّثَنَا وَرْقَاءُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، قَالَ ابْنُ عَبَّاسٍ أَمَرَهُ أَنْ يُسَبِّحَ، فِي أَدْبَارِ الصَّلَوَاتِ كُلِّهَا‏.‏ يَعْنِي قَوْلَهُ ‏\{‏وَأَدْبَارَ السُّجُودِ‏\}‏\hadithno{4852}\hadithtrans{Narrated Mujahid:Ibn `Abbas said, "Allah ordered His Prophet to celebrate Allah's praises after all prayers." He refers to His Statement: 'After the prayers}}
\hadithdefcmd{bukhari}{4853}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ ابْنَةِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ شَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِّي أَشْتَكِي فَقَالَ ‏ "‏ طُوفِي مِنْ وَرَاءِ النَّاسِ، وَأَنْتِ رَاكِبَةٌ ‏"‏‏.‏ فَطُفْتُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي إِلَى جَنْبِ الْبَيْتِ يَقْرَأُ بِالطُّورِ وَكِتَابٍ مَسْطُورٍ‏.‏\hadithno{4853}\hadithtrans{Narrated Um Salama:I complained to Allah's Messenger (ﷺ) that I was sick, so he said, "Perform the Tawaf (of Ka`ba at Mecca) while riding behind the people (who are performing the Tawaf on foot)." So I performed the Tawaf while Allah's Messenger (ﷺ) was offering the prayer by the side of the Ka`ba and was reciting: 'By the Mount (Sinai) and by a Decree Inscribed}}
\hadithdefcmd{bukhari}{4854}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثُونِي عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْمَغْرِبِ بِالطُّورِ فَلَمَّا بَلَغَ هَذِهِ الآيَةَ ‏\{‏أَمْ خُلِقُوا مِنْ غَيْرِ شَىْءٍ أَمْ هُمُ الْخَالِقُونَ * أَمْ خَلَقُوا السَّمَوَاتِ وَالأَرْضَ بَلْ لاَ يُوقِنُونَ * أَمْ عِنْدَهُمْ خَزَائِنُ رَبِّكَ أَمْ هُمُ الْمُسَيْطِرُونَ‏\}‏ كَادَ قَلْبِي أَنْ يَطِيرَ‏.‏ قَالَ سُفْيَانُ فَأَمَّا أَنَا فَإِنَّمَا سَمِعْتُ الزُّهْرِيَّ يُحَدِّثُ عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ عَنْ أَبِيهِ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْمَغْرِبِ بِالطُّورِ‏.‏ لَمْ أَسْمَعْهُ زَادَ الَّذِي قَالُوا لِي‏.‏\hadithno{4854}\hadithtrans{Narrated Jubair bin Mut`im:I heard the Prophet (ﷺ) reciting Surat at-Tur in the Maghrib prayer, and when he reached the Verse: 'Were they created by nothing, Or were they themselves the creators, Or did they create the Heavens and the Earth? Nay, but they have no firm belief Or do they own the treasures of Your Lord? Or have they been given the authority to do as they like...' (52.35-37) my heart was about to fly (when I realized this firm argument)}}
\hadithdefcmd{bukhari}{4855}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، قَالَ قُلْتُ لِعَائِشَةَ ـ رضى الله عنها ـ يَا أُمَّتَاهْ هَلْ رَأَى مُحَمَّدٌ صلى الله عليه وسلم رَبَّهُ فَقَالَتْ لَقَدْ قَفَّ شَعَرِي مِمَّا قُلْتَ، أَيْنَ أَنْتَ مِنْ ثَلاَثٍ مَنْ حَدَّثَكَهُنَّ فَقَدْ كَذَبَ، مَنْ حَدَّثَكَ أَنَّ مُحَمَّدًا صلى الله عليه وسلم رَأَى رَبَّهُ فَقَدْ كَذَبَ‏.‏ ثُمَّ قَرَأَتْ ‏\{‏لاَ تُدْرِكُهُ الأَبْصَارُ وَهُوَ يُدْرِكُ الأَبْصَارَ وَهُوَ اللَّطِيفُ الْخَبِيرُ‏\}‏ ‏\{‏وَمَا كَانَ لِبَشَرٍ أَنْ يُكَلِّمَهُ اللَّهُ إِلاَّ وَحْيًا أَوْ مِنْ وَرَاءِ حِجَابٍ‏\}‏ وَمَنْ حَدَّثَكَ أَنَّهُ يَعْلَمُ مَا فِي غَدٍ فَقَدْ كَذَبَ ثُمَّ قَرَأَتْ ‏\{‏وَمَا تَدْرِي نَفْسٌ مَاذَا تَكْسِبُ غَدًا‏\}‏ وَمَنْ حَدَّثَكَ أَنَّهُ كَتَمَ فَقَدْ كَذَبَ ثُمَّ قَرَأَتْ ‏\{‏يَا أَيُّهَا الرَّسُولُ بَلِّغْ مَا أُنْزِلَ إِلَيْكَ مِنْ رَبِّكَ‏\}‏ الآيَةَ، وَلَكِنَّهُ رَأَى جِبْرِيلَ ـ عَلَيْهِ السَّلاَمُ ـ فِي صُورَتِهِ مَرَّتَيْنِ‏.‏\hadithno{4855}\hadithtrans{Narrated Masruq:I said to `Aisha, "O Mother! Did Prophet Muhammad see his Lord?" Aisha said, "What you have said makes my hair stand on end ! Know that if somebody tells you one of the following three things, he is a liar: Whoever tells you that Muhammad saw his Lord, is a liar." Then Aisha recited the Verse: 'No vision can grasp Him, but His grasp is over all vision. He is the Most Courteous Well-Acquainted with all things.' (6.103) 'It is not fitting for a human being that Allah should speak to him except by inspiration or from behind a veil.' (42.51) `Aisha further said, "And whoever tells you that the Prophet knows what is going to happen tomorrow, is a liar." She then recited: 'No soul can know what it will earn tomorrow.' (31.34) She added: "And whoever tells you that he concealed (some of Allah's orders), is a liar." Then she recited: 'O Apostle! Proclaim (the Message) which has been sent down to you from your Lord..' (5.67) `Aisha added, "But the Prophet (ﷺ) saw Gabriel in his true form twice}}
\hadithdefcmd{bukhari}{4856}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الشَّيْبَانِيُّ، قَالَ سَمِعْتُ زِرًّا، عَنْ عَبْدِ اللَّهِ، ‏\{‏فَكَانَ قَابَ قَوْسَيْنِ أَوْ أَدْنَى * فَأَوْحَى إِلَى عَبْدِهِ مَا أَوْحَى‏\}‏ قَالَ حَدَّثَنَا ابْنُ مَسْعُودٍ أَنَّهُ رَأَى جِبْرِيلَ لَهُ سِتُّمِائَةِ جَنَاحٍ‏.‏\hadithno{4856}\hadithtrans{Narrated `Abdullah:Regarding the Verses: 'And was at a distance of but two bow-lengths or (even) nearer; So did (Allah) convey the Inspiration to His slave (Gabriel) and then he Gabriel) conveyed (that to Muhammad...' (53.9-10) Ibn Mas`ud narrated to us that the Prophet (ﷺ) had seen Gabriel with six hundred wings}}
\hadithdefcmd{bukhari}{4857}{حَدَّثَنَا طَلْقُ بْنُ غَنَّامٍ، حَدَّثَنَا زَائِدَةُ، عَنِ الشَّيْبَانِيِّ، قَالَ سَأَلْتُ زِرًّا عَنْ قَوْلِهِ تَعَالَى ‏\{‏فَكَانَ قَابَ قَوْسَيْنِ أَوْ أَدْنَى * فَأَوْحَى إِلَى عَبْدِهِ مَا أَوْحَى‏\}‏ قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ أَنَّ مُحَمَّدًا صلى الله عليه وسلم رَأَى جِبْرِيلَ لَهُ سِتُّمِائَةِ جَنَاحٍ‏.‏\hadithno{4857}\hadithtrans{Narrated Ash-Shaibani:I asked Zirr about the Statement of Allah: 'And was at a distance of but two bow-lengths or (even) nearer. So did Allah convey the Inspiration to His slave (Gabriel) and then he (Gabriel) conveyed that to Muhammad.' (53.10) He said, "Abdullah (bin Mas`ud) informed us that Muhammad had seen Gabriel with six hundred wings}}
\hadithdefcmd{bukhari}{4858}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه – ‏\{‏لَقَدْ رَأَى مِنْ آيَاتِ رَبِّهِ الْكُبْرَى‏\}‏ قَالَ رَأَى رَفْرَفًا أَخْضَرَ قَدْ سَدَّ الأُفُقَ‏.‏\hadithno{4858}\hadithtrans{Narrated `Abdullah:(regarding the revelation) Truly he (Muhammad) did see of the signs of his Lord; the Greatest!' (53.18) The Prophet (ﷺ) saw a green screen covering the horizon}}
\hadithdefcmd{bukhari}{4859}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا أَبُو الأَشْهَبِ، حَدَّثَنَا أَبُو الْجَوْزَاءِ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما فِي قَوْلِهِ ‏\{‏اللاَّتَ وَالْعُزَّى‏\}‏ كَانَ الَّلاَتُ رَجُلاً يَلُتُّ سَوِيقَ الْحَاجِّ‏.‏\hadithno{4859}\hadithtrans{Narrated Ibn `Abbas:(regarding His Statement about the Lat and the `Uzza: Lat was originally a man who used to mix Sawiq for the pilgrim)}}
\hadithdefcmd{bukhari}{4860}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ فَقَالَ فِي حَلِفِهِ وَاللاَّتِ وَالْعُزَّى‏.‏ فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ وَمَنْ قَالَ لِصَاحِبِهِ تَعَالَ أُقَامِرْكَ‏.‏ فَلْيَتَصَدَّقْ ‏"‏‏.‏\hadithno{4860}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whomever takes an oath in which he mentions Lat and `Uzza (forgetfully), should say: None has the right to be worshipped but Allah, and whoever says to his companion. 'Come along, let us gamble' must give alms (as an expiation)}}
\hadithdefcmd{bukhari}{4861}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، سَمِعْتُ عُرْوَةَ، قُلْتُ لِعَائِشَةَ ـ رضى الله عنها ـ فَقَالَتْ إِنَّمَا كَانَ مَنْ أَهَلَّ بِمَنَاةَ الطَّاغِيَةِ الَّتِي بِالْمُشَلَّلِ لاَ يَطُوفُونَ بَيْنَ الصَّفَا وَالْمَرْوَةِ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ‏\}‏ فَطَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمُسْلِمُونَ‏.‏ قَالَ سُفْيَانُ مَنَاةُ بِالْمُشَلَّلِ مِنْ قُدَيْدٍ‏.‏ وَقَالَ عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ عَنِ ابْنِ شِهَابٍ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ نَزَلَتْ فِي الأَنْصَارِ كَانُوا هُمْ وَغَسَّانُ قَبْلَ أَنْ يُسْلِمُوا يُهِلُّونَ لِمَنَاةَ‏.‏ مِثْلَهُ‏.‏ وَقَالَ مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ كَانَ رِجَالٌ مِنَ الأَنْصَارِ مِمَّنْ كَانَ يُهِلُّ لِمَنَاةَ ـ وَمَنَاةُ صَنَمٌ بَيْنَ مَكَّةَ وَالْمَدِينَةِ ـ قَالُوا يَا نَبِيَّ اللَّهِ كُنَّا لاَ نَطُوفُ بَيْنَ الصَّفَا وَالْمَرْوَةِ تَعْظِيمًا لِمَنَاةَ‏.‏ نَحْوَهُ‏.‏\hadithno{4861}\hadithtrans{Narrated `Urwa:I asked `Aisha (regarding the Sai between As Safa and Al-Marwa). She said, "Out of reverence to the idol Manat which was placed in Al-Mushallal, those who used to assume Ihram in its name, used not to perform Sai between As-Safa and Al-Marwa, so Allah revealed: 'Verily! The As-Safa and Al-Marwa (two mountains at Mecca) are among the symbols of Allah.' (2.158). Thereupon, Allah's Messenger (ﷺ) and the Muslims used to perform Sai (between them)." Sufyan said: The (idol) Manat was at Al-Mushallal in Qudaid. `Aisha added, "The Verse was revealed in connection with the Ansar. They and (the tribe of) Ghassan used to assume Ihram in the name of Manat before they embraced Islam." `Aisha added, "There were men from the Ansar who used to assume Ihram in the name of Manat which was an idol between Mecca and Medina. They said, "O Allah's Messenger (ﷺ)! We used not to perform the Tawaf (Sai) between As-Safa and Al-Marwa out of reverence to Manat}}
\hadithdefcmd{bukhari}{4862}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ سَجَدَ النَّبِيُّ صلى الله عليه وسلم بِالنَّجْمِ وَسَجَدَ مَعَهُ الْمُسْلِمُونَ وَالْمُشْرِكُونَ وَالْجِنُّ وَالإِنْسُ‏.‏ تَابَعَهُ ابْنُ طَهْمَانَ عَنْ أَيُّوبَ‏.‏ وَلَمْ يَذْكُرِ ابْنُ عُلَيَّةَ ابْنَ عَبَّاسٍ‏.‏\hadithno{4862}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) performed a prostration when he finished reciting Surat-an-Najm, and all the Muslims and pagans and Jinns and human beings prostrated along with him}}
\hadithdefcmd{bukhari}{4863}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنِي أَبُو أَحْمَدَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ أَوَّلُ سُورَةٍ أُنْزِلَتْ فِيهَا سَجْدَةٌ ‏\{‏وَالنَّجْمِ‏\}‏‏.‏ قَالَ فَسَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَجَدَ مَنْ خَلْفَهُ، إِلاَّ رَجُلاً رَأَيْتُهُ أَخَذَ كَفًّا مِنْ تُرَابٍ فَسَجَدَ عَلَيْهِ، فَرَأَيْتُهُ بَعْدَ ذَلِكَ قُتِلَ كَافِرًا، وَهْوَ أُمَيَّةُ بْنُ خَلَفٍ‏.‏\hadithno{4863}\hadithtrans{Narrated `Abdullah:The first Sura in which a prostration was mentioned, was Sura An-Najm (The Star). Allah's Messenger (ﷺ) prostrated (while reciting it), and everybody behind him prostrated except a man whom I saw taking a hand-full of dust in his hand and prostrated on it. Later I saw that man killed as an infidel, and he was Umaiya bin Khalaf}}
\hadithdefcmd{bukhari}{4864}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، وَسُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي مَعْمَرٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ انْشَقَّ الْقَمَرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِرْقَتَيْنِ، فِرْقَةً فَوْقَ الْجَبَلِ وَفِرْقَةً دُونَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْهَدُوا ‏"‏‏.‏\hadithno{4864}\hadithtrans{Narrated Ibn Masud:During the lifetime of Allah's Messenger (ﷺ) the moon was split into two parts; one part remained over the mountain, and the other part went beyond the mountain. On that, Allah's Messenger (ﷺ) said, "Witness this miracle}}
\hadithdefcmd{bukhari}{4865}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، أَخْبَرَنَا ابْنُ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، قَالَ انْشَقَّ الْقَمَرُ وَنَحْنُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَصَارَ فِرْقَتَيْنِ، فَقَالَ لَنَا ‏ "‏ اشْهَدُوا، اشْهَدُوا ‏"‏‏.‏\hadithno{4865}\hadithtrans{Narrated `Abdullah:The moon was cleft asunder while we were in the company of the Prophet, and it became two parts. The Prophet (ﷺ) said, Witness, witness (this miracle)}}
\hadithdefcmd{bukhari}{4866}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنِي بَكْرٌ، عَنْ جَعْفَرٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ انْشَقَّ الْقَمَرُ فِي زَمَانِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{4866}\hadithtrans{Narrated Ibn `Abbas:The moon was cleft asunder during the lifetime of the Prophet}}
\hadithdefcmd{bukhari}{4867}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ سَأَلَ أَهْلُ مَكَّةَ أَنْ يُرِيَهُمْ آيَةً فَأَرَاهُمُ انْشِقَاقَ الْقَمَرِ‏.‏\hadithno{4867}\hadithtrans{Narrated Anas:The people of Mecca asked the Prophet (ﷺ) to show them a sign (miracle). So he showed them (the miracle) of the cleaving of the moon}}
\hadithdefcmd{bukhari}{4868}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ انْشَقَّ الْقَمَرُ فِرْقَتَيْنِ‏.‏\hadithno{4868}\hadithtrans{Narrated Anas:The moon was cleft asunder into two parts}}
\hadithdefcmd{bukhari}{4869}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ‏\}‏\hadithno{4869}\hadithtrans{Narrated `Abdullah bin Masud:The Prophet (ﷺ) used to recite: "Fahal-min-Maddakir (then is there any that will receive admonition?)}}
\hadithdefcmd{bukhari}{4870}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ أَنَّهُ كَانَ يَقْرَأُ ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ‏\}‏‏.‏\hadithno{4870}\hadithtrans{Narrated `Abdullah bin Masud:The Prophet (ﷺ) used to recite: "Fahal-min-Maddakir (then is there any that will receive admonition?)}}
\hadithdefcmd{bukhari}{4871}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، أَنَّهُ سَمِعَ رَجُلاً، سَأَلَ الأَسْوَدَ فَهَلْ مِنْ مُدَّكِرٍ أَوْ مُذَّكِرٍ فَقَالَ سَمِعْتُ عَبْدَ اللَّهِ يَقْرَؤُهَا ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ‏\}‏ قَالَ وَسَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَؤُهَا ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ‏\}‏ دَالاً‏.‏\hadithno{4871}\hadithtrans{Narrated Abu 'Is-haq:A man asked Al-Aswad, 'is it 'Fahal min-Muddakir' or'..Mudhdhakir?" Al Aswad replied, 'I have heard `Abdullah bin Masud reciting it, 'Fahal-min Muddakir'; I too, heard the Prophet (ﷺ) reciting it 'Fahal-min-Muddakir' with 'd}}
\hadithdefcmd{bukhari}{4872}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا أَبِي، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَرَأَ ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ‏\}‏ الآيَةَ‏.‏\hadithno{4872}\hadithtrans{Narrated `Abdullah bin Masud: The Prophet (ﷺ) used to recite: "Fahal-min-Maddakir (then is there any that will receive admonition?)}}
\hadithdefcmd{bukhari}{4873}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَرَأَ ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ‏، ولقد أهلكنا أشياعكم فهل من مُدَّكِرٍ‏\}‏\hadithno{4873}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) recited: 'Fahal-min Muddakir': 'And verily, We have destroyed nations like unto you; then is there any that will receive admonition?}}
\hadithdefcmd{bukhari}{4874}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَرَأْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَهَلْ مِنْ مُذَّكِرٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ‏\}‏\hadithno{4874}\hadithtrans{Narrated `Abdullah:I recited before the Prophet (ﷺ) 'Fahal-min-Mudhdhakir'. The Prophet (ﷺ) said, "It is Fahal-min Muddakir}}
\hadithdefcmd{bukhari}{4875}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ،‏.‏ وَحَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، عَنْ وُهَيْبٍ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهْوَ فِي قُبَّةٍ يَوْمَ بَدْرٍ ‏"‏ اللَّهُمَّ إِنِّي أَنْشُدُكَ عَهْدَكَ وَوَعْدَكَ، اللَّهُمَّ إِنْ تَشَأْ لاَ تُعْبَدْ بَعْدَ الْيَوْمِ ‏"‏‏.‏ فَأَخَذَ أَبُو بَكْرٍ بِيَدِهِ فَقَالَ حَسْبُكَ يَا رَسُولَ اللَّهِ، أَلْحَحْتَ عَلَى رَبِّكَ‏.‏ وَهْوَ يَثِبُ فِي الدِّرْعِ، فَخَرَجَ وَهْوَ يَقُولُ ‏"‏ ‏\{‏سَيُهْزَمُ الْجَمْعُ وَيُوَلُّونَ الدُّبُرَ‏\}‏‏.‏‏"‏\hadithno{4875}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) while in a tent on the day of the Battle of Badr, said, "O Allah! I request you (to fulfill) Your promise and contract! O Allah! If You wish that you will not be worshipped henceforth.." On that Abu Bakr held the Prophet (ﷺ) by the hand and said, "That is enough, O Allah's Messenger (ﷺ) You have appealed to your Lord too pressingly," while the Prophet (ﷺ) was putting on his armor. So Allah's Messenger (ﷺ) went out, reciting Their multitude will be put to flight, and they will show their backs}}
\hadithdefcmd{bukhari}{4876}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي يُوسُفُ بْنُ مَاهَكَ، قَالَ إِنِّي عِنْدَ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ قَالَتْ لَقَدْ أُنْزِلَ عَلَى مُحَمَّدٍ صلى الله عليه وسلم بِمَكَّةَ، وَإِنِّي لَجَارِيَةٌ أَلْعَبُ ‏\{‏بَلِ السَّاعَةُ مَوْعِدُهُمْ وَالسَّاعَةُ أَدْهَى وَأَمَرُّ‏\}‏\hadithno{4876}\hadithtrans{Narrated Yusuf bin Mahak:I was in the house of `Aisha, the mother of the Believers. She said, "This revelation: "Nay, but the Hour is their appointed time (for their full recompense); and the Hour will be more previous and most bitter." (54.46) was revealed to Muhammad at Mecca while I was a playful little girl}}
\hadithdefcmd{bukhari}{4877}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا خَالِدٌ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ وَهْوَ فِي قُبَّةٍ لَهُ يَوْمَ بَدْرٍ ‏"‏ أَنْشُدُكَ عَهْدَكَ وَوَعْدَكَ، اللَّهُمَّ إِنْ شِئْتَ لَمْ تُعْبَدْ بَعْدَ الْيَوْمِ أَبَدًا ‏"‏‏.‏ فَأَخَذَ أَبُو بَكْرٍ بِيَدِهِ وَقَالَ حَسْبُكَ يَا رَسُولَ اللَّهِ فَقَدْ أَلْحَحْتَ عَلَى رَبِّكَ‏.‏ وَهْوَ فِي الدِّرْعِ فَخَرَجَ وَهْوَ يَقُولُ ‏"‏ ‏\{‏سَيُهْزَمُ الْجَمْعُ وَيُوَلُّونَ الدُّبُرَ * بَلِ السَّاعَةُ مَوْعِدُهُمْ وَالسَّاعَةُ أَدْهَى وَأَمَرُّ‏\}‏‏"‏\hadithno{4877}\hadithtrans{Narrated Ibn `Abbas:While in his tent on the day the Battle of Badr, the Prophet (ﷺ) said, "O Allah! I request You (to fulfill) Your promise and contract. O Allah! It You wish that the Believers be destroyed). You will never be worshipped henceforth." On that, Abu Bakr held the Prophet (ﷺ) by the hand and said, "That is enough, O Allah's Messenger (ﷺ)! You have appealed to your Lord too pressingly" The Prophet (ﷺ) was wearing his armor and then went out reciting: 'Their multitude will be put to flight and they will show their backs. Nay, but the Hour is their appointed time (for their full recompense), and the Hour will be more previous and most bitter}}
\hadithdefcmd{bukhari}{4878}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ الْعَمِّيُّ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ جَنَّتَانِ مِنْ فِضَّةٍ، آنِيَتُهُمَا وَمَا فِيهِمَا وَجَنَّتَانِ مِنْ ذَهَبٍ آنِيَتُهُمَا وَمَا فِيهِمَا، وَمَا بَيْنَ الْقَوْمِ وَبَيْنَ أَنْ يَنْظُرُوا إِلَى رَبِّهِمْ إِلاَّ رِدَاءُ الْكِبْرِ عَلَى وَجْهِهِ فِي جَنَّةِ عَدْنٍ ‏"‏‏.‏\hadithno{4878}\hadithtrans{Narrated `Abdullah bin Qais:Allah's Messenger (ﷺ) said, "Two gardens, the utensils and the contents of which are of silver, and two other gardens, the utensils and contents of which are of gold. And nothing will prevent the people who will be in the Garden of Eden from seeing their Lord except the curtain of Majesty over His Face}}
\hadithdefcmd{bukhari}{4880}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ خَيْمَةً مِنْ لُؤْلُؤَةٍ مُجَوَّفَةٍ، عَرْضُهَا سِتُّونَ مِيلاً، فِي كُلِّ زَاوِيَةٍ مِنْهَا أَهْلٌ، مَا يَرَوْنَ الآخَرِينَ يَطُوفُ عَلَيْهِمُ الْمُؤْمِنُونَ ‏"‏‏.‏ ‏"‏ وَجَنَّتَانِ مِنْ فِضَّةٍ، آنِيَتُهُمَا وَمَا فِيهِمَا، وَجَنَّتَانِ مِنْ كَذَا آنِيَتُهُمَا، وَمَا فِيهِمَا، وَمَا بَيْنَ الْقَوْمِ وَبَيْنَ أَنْ يَنْظُرُوا إِلَى رَبِّهِمْ إِلاَّ رِدَاءُ الْكِبْرِ عَلَى وَجْهِهِ فِي جَنَّةِ عَدْنٍ ‏"‏‏.‏\hadithno{4880}\hadithtrans{Narrated `Abdullah bin Qais:Allah's Messenger (ﷺ) said, "In Paradise there is a pavilion made of a single hollow pearl sixty miles wide, in each corner of which there are wives who will not see those in the other corners; and the believers will visit and enjoy them. And there are two gardens, the utensils and contents of which are made of silver; and two other gardens, the utensils and contents of which are made of so-and-so (i.e. gold) and nothing will prevent the people staying in the Garden of Eden from seeing their Lord except the curtain of Majesty over His Face}}
\hadithdefcmd{bukhari}{4881}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ شَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ عَامٍ لاَ يَقْطَعُهَا، وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏وَظِلٍّ مَمْدُودٍ‏\}‏‏"‏‏.‏\hadithno{4881}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "In Paradise there is a tree which is so big that a rider can travel in its shade for one hundred years without passing it; and if you wish, you can recite: 'In shade long extended}}
\hadithdefcmd{bukhari}{4882}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ سُورَةُ التَّوْبَةِ قَالَ التَّوْبَةُ هِيَ الْفَاضِحَةُ، مَا زَالَتْ تَنْزِلُ وَمِنْهُمْ وَمِنْهُمْ، حَتَّى ظَنُّوا أَنَّهَا لَمْ تُبْقِ أَحَدًا مِنْهُمْ إِلاَّ ذُكِرَ فِيهَا‏.‏ قَالَ قُلْتُ سُورَةُ الأَنْفَالِ‏.‏ قَالَ نَزَلَتْ فِي بَدْرٍ‏.‏ قَالَ قُلْتُ سُورَةُ الْحَشْرِ‏.‏ قَالَ نَزَلَتْ فِي بَنِي النَّضِيرِ‏.‏\hadithno{4882}\hadithtrans{Narrated Sa`id bin Jubair:I asked Ibn `Abbas about Surat Al-Tauba, and he said, "Surat Al-Tauba? It is exposure (of all the evils of the infidels and the hypocrites). And it continued revealing (that the oft-repeated expression): '...and of them ...and of them.' till they started thinking that none would be left unmentioned therein." I said, "What about) Surat Al-Anfal?" He replied, "Surat Al-Anfal was revealed in connection with the Badr Battle." I said, "(What about) Surat Al-Hashr?" He replied, "It was revealed in connection with Bani an-Nadir}}
\hadithdefcmd{bukhari}{4883}{حَدَّثَنَا الْحَسَنُ بْنُ مُدْرِكٍ، حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ ـ رضى الله عنهما ـ سُورَةُ الْحَشْرِ قَالَ قُلْ سُورَةُ النَّضِيرِ‏.‏\hadithno{4883}\hadithtrans{Narrated Sa`id:I asked Ibn `Abbas about Surat Al-Hashr. He replied, "Say Surat An-Nadir}}
\hadithdefcmd{bukhari}{4884}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّقَ نَخْلَ بَنِي النَّضِيرِ وَقَطَعَ، وَهْىَ الْبُوَيْرَةُ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏مَا قَطَعْتُمْ مِنْ لِينَةٍ أَوْ تَرَكْتُمُوهَا قَائِمَةً عَلَى أُصُولِهَا فَبِإِذْنِ اللَّهِ وَلِيُخْزِيَ الْفَاسِقِينَ‏\}‏\hadithno{4884}\hadithtrans{Narrated Ibn `Umar:'Allah's Messenger (ﷺ) burnt and cut down the palm trees of Bani An-Nadir which were at Al-Buwaira (a place near Medina). There upon Allah revealed: 'What you (O Muslims) cut down of the palm trees (of the enemy) or you left them standing on their stems, it was by the leave of Allah, so that He might cover with shame the rebellious}}
\hadithdefcmd{bukhari}{4885}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَان ُ ـ غَيْرَ مَرَّةٍ ـ عَنْ عَمْرٍو، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، عَنْ عُمَرَ ـ رضى الله عنه ـ قَالَ كَانَتْ أَمْوَالُ بَنِي النَّضِيرِ مِمَّا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم مِمَّا لَمْ يُوجِفِ الْمُسْلِمُونَ عَلَيْهِ بِخَيْلٍ وَلاَ رِكَابٍ، فَكَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَاصَّةً، يُنْفِقُ عَلَى أَهْلِهِ مِنْهَا نَفَقَةَ سَنَتِهِ، ثُمَّ يَجْعَلُ مَا بَقِيَ فِي السِّلاَحِ وَالْكُرَاعِ، عُدَّةً فِي سَبِيلِ اللَّهِ‏.‏\hadithno{4885}\hadithtrans{Narrated `Umar:The properties of Bani An-Nadir were among the booty that Allah gave to His Apostle such Booty were not obtained by any expedition on the part of Muslims, neither with cavalry, nor with camelry. So those properties were for Allah's Messenger (ﷺ) only, and he used to provide thereof the yearly expenditure for his wives, and dedicate the rest of its revenues for purchasing arms and horses as war material to be used in Allah's Cause}}
\hadithdefcmd{bukhari}{4886}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ اللَّهُ الْوَاشِمَاتِ وَالْمُوتَشِمَاتِ وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ الْمُغَيِّرَاتِ خَلْقَ اللَّهِ‏.‏ فَبَلَغَ ذَلِكَ امْرَأَةً مِنْ بَنِي أَسَدٍ يُقَالُ لَهَا أُمُّ يَعْقُوبَ، فَجَاءَتْ فَقَالَتْ إِنَّهُ بَلَغَنِي أَنَّكَ لَعَنْتَ كَيْتَ وَكَيْتَ‏.‏ فَقَالَ وَمَا لِي لاَ أَلْعَنُ مَنْ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَنْ هُوَ فِي كِتَابِ اللَّهِ فَقَالَتْ لَقَدْ قَرَأْتُ مَا بَيْنَ اللَّوْحَيْنِ فَمَا وَجَدْتُ فِيهِ مَا تَقُولُ‏.‏ قَالَ لَئِنْ كُنْتِ قَرَأْتِيهِ لَقَدْ وَجَدْتِيهِ، أَمَا قَرَأْتِ ‏\{‏وَمَا آتَاكُمُ الرَّسُولُ فَخُذُوهُ وَمَا نَهَاكُمْ عَنْهُ فَانْتَهُوا‏\}‏‏.‏ قَالَتْ بَلَى‏.‏ قَالَ فَإِنَّهُ قَدْ نَهَى عَنْهُ‏.‏ قَالَتْ فَإِنِّي أَرَى أَهْلَكَ يَفْعَلُونَهُ‏.‏ قَالَ فَاذْهَبِي فَانْظُرِي‏.‏ فَذَهَبَتْ فَنَظَرَتْ فَلَمْ تَرَ مِنْ حَاجَتِهَا شَيْئًا، فَقَالَ لَوْ كَانَتْ كَذَلِكَ مَا جَامَعْتُها\hadithno{4886}\hadithtrans{Narrated Alqama:`Abdullah (bin Masud) said, "Allah curses those ladies who practice tattooing and those who get themselves tattooed, and those ladies who remove the hair from their faces and those who make artificial spaces between their teeth in order to look more beautiful whereby they change Allah's creation." His saying reached a lady from Bani Asad called Um Yaqub who came (to `Abdullah) and said, "I have come to know that you have cursed such-and-such (ladies)?" He replied, "Why should I not curse these whom Allah's Messenger (ﷺ) has cursed and who are (cursed) in Allah's Book!" Um Yaqub said, "I have read the whole Qur'an, but I did not find in it what you say." He said, "Verily, if you have read it (i.e. the Qur'an), you have found it. Didn't you read: 'And whatsoever the Apostle gives you take it and whatsoever he forbids you, you abstain (from it). (59.7) She replied, "Yes, I did," He said, "Verily, Allah's Messenger (ﷺ) forbade such things." "She said, "But I see your wife doing these things?" He said, "Go and watch her." She went and watched her but could not see anything in support of her statement. On that he said, "If my wife was as you thought, I would not keep her in my company}}
\hadithdefcmd{bukhari}{4887}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، قَالَ ذَكَرْتُ لِعَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ حَدِيثَ مَنْصُورٍ عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَاصِلَةَ فَقَالَ سَمِعْتُهُ مِنِ امْرَأَةٍ يُقَالُ لَهَا أُمُّ يَعْقُوبَ عَنْ عَبْدِ اللَّهِ مِثْلَ حَدِيثِ مَنْصُورٍ‏.‏\hadithno{4887}\hadithtrans{Narrated `Abdullah (bin Mas'ud):Allah's Messenger (ﷺ) has cursed the lady who uses false hair}}
\hadithdefcmd{bukhari}{4888}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ حُصَيْنٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ قَالَ عُمَرُ رضى الله عنه أُوصِي الْخَلِيفَةَ بِالْمُهَاجِرِينَ الأَوَّلِينَ أَنْ يَعْرِفَ لَهُمْ حَقَّهُمْ، وَأُوصِي الْخَلِيفَةَ بِالأَنْصَارِ الَّذِينَ تَبَوَّءُوا الدَّارَ وَالإِيمَانَ مِنْ قَبْلِ أَنْ يُهَاجِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَقْبَلَ مِنْ مُحْسِنِهِمْ وَيَعْفُوَ عَنْ مُسِيئِهِمْ‏.‏\hadithno{4888}\hadithtrans{Narrated `Umar:I recommend that my successor should take care of and secure the rights of the early emigrants; and I also advise my successor to be kind to the Ansar who had homes (in Medina) and had adopted the Faith, before the Prophet (ﷺ) migrated to them, and to accept the good from their good ones and excuse their wrong doers}}
\hadithdefcmd{bukhari}{4889}{حَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ كَثِيرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا فُضَيْلُ بْنُ غَزْوَانَ، حَدَّثَنَا أَبُو حَازِمٍ الأَشْجَعِيُّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَصَابَنِي الْجَهْدُ فَأَرْسَلَ إِلَى نِسَائِهِ فَلَمْ يَجِدْ عِنْدَهُنَّ شَيْئًا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ رَجُلٌ يُضَيِّفُ هَذِهِ اللَّيْلَةَ يَرْحَمُهُ اللَّهُ ‏"‏‏.‏ فَقَامَ رَجُلٌ مِنَ الأَنْصَارِ فَقَالَ أَنَا يَا رَسُولَ اللَّهِ‏.‏ فَذَهَبَ إِلَى أَهْلِهِ فَقَالَ لاِمْرَأَتِهِ ضَيْفُ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ تَدَّخِرِيهِ شَيْئًا‏.‏ قَالَتْ وَاللَّهِ مَا عِنْدِي إِلاَّ قُوتُ الصِّبْيَةِ‏.‏ قَالَ فَإِذَا أَرَادَ الصِّبْيَةُ الْعَشَاءَ فَنَوِّمِيهِمْ، وَتَعَالَىْ فَأَطْفِئِي السِّرَاجَ وَنَطْوِي بُطُونَنَا اللَّيْلَةَ‏.‏ فَفَعَلَتْ ثُمَّ غَدَا الرَّجُلُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ لَقَدْ عَجِبَ اللَّهُ عَزَّ وَجَلَّ ـ أَوْ ضَحِكَ ـ مِنْ فُلاَنٍ وَفُلاَنَةَ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَيُؤْثِرُونَ عَلَى أَنْفُسِهِمْ وَلَوْ كَانَ بِهِمْ خَصَاصَةٌ‏\}‏\hadithno{4889}\hadithtrans{Narrated Abu Huraira:A man came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! I am suffering from fatigue and hunger." The Prophet (ﷺ) sent (somebody) to his wives (to get something), but the messenger found nothing with them. Then Allah's Messenger (ﷺ) said (to his companions). "Isn't there anybody who can entertain this man tonight so that Allah may be merciful to him?" An Ansari man got up and said, "I (will, entertain him), O Allah's Messenger (ﷺ)!" So he went to his wife and said to her, "This is the guest of Allah's Messenger (ﷺ), so do not keep anything away from him." She said. "By Allah, I have nothing but the children's food." He said, "When the children ask for their dinner, put them to bed and put out the light; we shall not take our meals tonight," She did so. In the morning the Ansari man went to Allah's Messenger (ﷺ) who said, "Allah was pleased with (or He bestowed His Mercy) on so-and-so and his wife (because of their good deed)." Then Allah revealed: 'But give them preference over themselves even though they were in need of that}}
\hadithdefcmd{bukhari}{4890}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ حَدَّثَنِي الْحَسَنُ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ، أَنَّهُ سَمِعَ عُبَيْدَ اللَّهِ بْنَ أَبِي رَافِعٍ، كَاتِبَ عَلِيٍّ يَقُولُ سَمِعْتُ عَلِيًّا ـ رضى الله عنه ـ يَقُولُ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَا وَالزُّبَيْرَ وَالْمِقْدَادَ فَقَالَ ‏"‏ انْطَلِقُوا حَتَّى تَأْتُوا رَوْضَةَ خَاخٍ فَإِنَّ بِهَا ظَعِينَةً مَعَهَا كِتَابٌ فَخُذُوهُ مِنْهَا ‏"‏‏.‏ فَذَهَبْنَا تَعَادَى بِنَا خَيْلُنَا حَتَّى أَتَيْنَا الرَّوْضَةَ فَإِذَا نَحْنُ بِالظَّعِينَةِ فَقُلْنَا أَخْرِجِي الْكِتَابَ فَقَالَتْ مَا مَعِي مِنْ كِتَابٍ‏.‏ فَقُلْنَا لَتُخْرِجِنَّ الْكِتَابَ أَوْ لَنُلْقِيَنَّ الثِّيَابَ‏.‏ فَأَخْرَجَتْهُ مِنْ عِقَاصِهَا فَأَتَيْنَا بِهِ النَّبِيَّ صلى الله عليه وسلم فَإِذَا فِيهِ مِنْ حَاطِبِ بْنِ أَبِي بَلْتَعَةَ إِلَى أُنَاسٍ مِنَ الْمُشْرِكِينَ مِمَّنْ بِمَكَّةَ يُخْبِرُهُمْ بِبَعْضِ أَمْرِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا هَذَا يَا حَاطِبُ ‏"‏‏.‏ قَالَ لاَ تَعْجَلْ عَلَىَّ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ امْرَأً مِنْ قُرَيْشٍ وَلَمْ أَكُنْ مِنْ أَنْفُسِهِمْ وَكَانَ مَنْ مَعَكَ مِنَ الْمُهَاجِرِينَ لَهُمْ قَرَابَاتٌ يَحْمُونَ بِهَا أَهْلِيهِمْ وَأَمْوَالَهُمْ بِمَكَّةَ فَأَحْبَبْتُ إِذْ فَاتَنِي مِنَ النَّسَبِ فِيهِمْ أَنْ أَصْطَنِعَ إِلَيْهِمْ يَدًا يَحْمُونَ قَرَابَتِي وَمَا فَعَلْتُ ذَلِكَ كُفْرًا وَلاَ ارْتِدَادًا عَنْ دِينِي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّهُ قَدْ صَدَقَكُمْ ‏"‏‏.‏ فَقَالَ عُمَرُ دَعْنِي يَا رَسُولَ اللَّهِ فَأَضْرِبَ عُنُقَهُ‏.‏ فَقَالَ ‏"‏ إِنَّهُ شَهِدَ بَدْرًا وَمَا يُدْرِيكَ لَعَلَّ اللَّهَ ـ عَزَّ وَجَلَّ ـ اطَّلَعَ عَلَى أَهْلِ بَدْرٍ فَقَالَ اعْمَلُوا مَا شِئْتُمْ فَقَدْ غَفَرْتُ لَكُمْ ‏"‏‏.‏ قَالَ عَمْرٌو وَنَزَلَتْ فِيهِ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَتَّخِذُوا عَدُوِّي وَعَدُوَّكُمْ‏\}‏ قَالَ لاَ أَدْرِي الآيَةَ فِي الْحَدِيثِ أَوْ قَوْلُ عَمْرٍو‏.‏ حَدَّثَنَا عَلِيٌّ قِيلَ لِسُفْيَانَ فِي هَذَا فَنَزَلَتْ ‏\{‏لاَ تَتَّخِذُوا عَدُوِّي‏\}‏ قَالَ سُفْيَانُ هَذَا فِي حَدِيثِ النَّاسِ حَفِظْتُهُ مِنْ عَمْرٍو وَمَا تَرَكْتُ مِنْهُ حَرْفًا وَمَا أُرَى أَحَدًا حَفِظَهُ غَيْرِي‏.‏\hadithno{4890}\hadithtrans{Narrated `Ali:Allah's Messenger (ﷺ) sent me along with Az-Zubair and Al-Miqdad and said, "Proceed till you reach a place called Raudat-Khakh where there is a lady travelling in a howda on a camel. She has a letter. Take the letter from her." So we set out, and our horses ran at full pace till we reached Raudat Khakh, and behold, we saw the lady and said (to her), "Take out the letter!" She said, "I have no letter with me." We said, "Either you take out the letter or we will strip you of your clothes." So she took the letter out of her hair braid. We brought the letter to the Prophet (ﷺ) and behold, it was addressed by Hatib bin Abi Balta'a to some pagans at Mecca, informing them of some of the affairs of the Prophet. The Prophet (ﷺ) said, "What is this, O Hatib?" Hatib replied, "Do not be hasty with me, O Allah's Messenger (ﷺ)! I am an Ansari man and do not belong to them (Quraish infidels) while the emigrants who were with you had their relatives who used to protect their families and properties at Mecca. So, to compensate for not having blood relation with them.' I intended to do them some favor so that they might protect my relatives (at Mecca), and I did not do this out of disbelief or an inclination to desert my religion." The Prophet then said (to his companions), "He (Hatib) has told you the truth." `Umar said, "O Allah's Apostle! Allow me to chop his head off?" The Apostle said, "He is one of those who witnessed (fought in) the Battle of Badr, and what do you know, perhaps Allah looked upon the people of Badr (Badr warriors) and said, 'Do what you want as I have forgiven you.' " (`Amr, a sub-narrator, said,: This Verse was revealed about him (Hatib): 'O you who believe! Take not My enemies and your enemies as friends or protectors.' (60.1) Narrated `Ali: Sufyan was asked whether (the Verse): 'Take not My enemies and your enemies...' was revealed in connection with Hatib. Sufyan replied, "This occurs only in the narration of the people. I memorized the Hadith from `Amr, not overlooking even a single letter thereof, and I do not know of anybody who remembered it by heart other than myself}}
\hadithdefcmd{bukhari}{4891}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَمْتَحِنُ مَنْ هَاجَرَ إِلَيْهِ مِنَ الْمُؤْمِنَاتِ بِهَذِهِ الآيَةِ، بِقَوْلِ اللَّهِ ‏\{‏يَا أَيُّهَا النَّبِيُّ إِذَا جَاءَكَ الْمُؤْمِنَاتُ يُبَايِعْنَكَ‏\}‏ إِلَى قَوْلِهِ ‏\{‏غَفُورٌ رَحِيمٌ‏\}‏‏.‏ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ فَمَنْ أَقَرَّ بِهَذَا الشَّرْطِ مِنَ الْمُؤْمِنَاتِ قَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ بَايَعْتُكِ ‏"‏‏.‏ كَلاَمًا وَلاَ وَاللَّهِ مَا مَسَّتْ يَدُهُ يَدَ امْرَأَةٍ قَطُّ فِي الْمُبَايَعَةِ، مَا يُبَايِعُهُنَّ إِلاَّ بِقَوْلِهِ ‏"‏ قَدْ بَايَعْتُكِ عَلَى ذَلِكَ ‏"‏‏.‏ تَابَعَهُ يُونُسُ وَمَعْمَرٌ وَعَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ عَنِ الزُّهْرِيِّ‏.‏ وَقَالَ إِسْحَاقُ بْنُ رَاشِدٍ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ وَعَمْرَةَ‏.‏\hadithno{4891}\hadithtrans{Narrated `Urwa:Aisha the wife of the Prophet, said, "Allah's Messenger (ﷺ) used to examine the believing women who migrated to him in accordance with this Verse: 'O Prophet! When believing women come to you to take the oath of allegiance to you... Verily! Allah is Oft-Forgiving Most Merciful.' (60.12) `Aisha said, "And if any of the believing women accepted the condition (assigned in the above-mentioned Verse), Allah's Messenger (ﷺ) would say to her. "I have accepted your pledge of allegiance." "He would only say that, for, by Allah, his hand never touched, any lady during that pledge of allegiance. He did not receive their pledge except by saying, "I have accepted your pledge of allegiance for that}}
\hadithdefcmd{bukhari}{4892}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَرَأَ عَلَيْنَا ‏\{‏أَنْ لاَ يُشْرِكْنَ بِاللَّهِ شَيْئًا‏\}‏ وَنَهَانَا عَنِ النِّيَاحَةِ، فَقَبَضَتِ امْرَأَةٌ يَدَهَا فَقَالَتْ أَسْعَدَتْنِي فُلاَنَةُ أُرِيدُ أَنْ أَجْزِيَهَا‏.‏ فَمَا قَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم شَيْئًا فَانْطَلَقَتْ وَرَجَعَتْ فَبَايَعَهَا‏.‏\hadithno{4892}\hadithtrans{Narrated Um Atiya:We took the oath of allegiance to Allah's Messenger (ﷺ) and he recited to us: 'They will not associate anything in worship with Allah,' and forbade us to bewail the dead. Thereupon a lady withdrew her hand (refrained from taking the oath of allegiance), and said, "But such-and-such lady lamented over one of my relatives, so I must reward (do the same over the dead relatives of) hers." The Prophet (ﷺ) did not object to that, so she went (there) and returned to the Prophet (ﷺ) so he accepted her pledge of allegiance}}
\hadithdefcmd{bukhari}{4893}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ الزُّبَيْرَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ تَعَالَى ‏\{‏وَلاَ يَعْصِينَكَ فِي مَعْرُوفٍ‏\}‏ قَالَ إِنَّمَا هُوَ شَرْطٌ شَرَطَهُ اللَّهُ لِلنِّسَاءِ‏.‏\hadithno{4893}\hadithtrans{Narrated Ibn `Abbas:Regarding the saying of Allah: 'And they will not disobey you in any just matter.' (60.12) That was one of the conditions which Allah imposed on The believing) women (who came to take the oath of allegiance to the Prophet)}}
\hadithdefcmd{bukhari}{4894}{\{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ حَدَّثَنَاهُ قَالَ حَدَّثَنِي أَبُو إِدْرِيسَ، سَمِعَ عُبَادَةَ بْنَ الصَّامِتِ ـ رضى الله عنه ـ قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتُبَايِعُونِي عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَزْنُوا وَلاَ تَسْرِقُوا ‏"‏‏.‏ وَقَرَأَ آيَةَ النِّسَاءِ ـ وَأَكْثَرُ لَفْظِ سُفْيَانَ قَرَأَ الآيَةَ ـ ‏"‏ فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ، وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَعُوقِبَ فَهُوَ كَفَّارَةٌ لَهُ، وَمَنْ أَصَابَ مِنْهَا شَيْئًا مِنْ ذَلِكَ فَسَتَرَهُ اللَّهُ فَهْوَ إِلَى اللَّهِ، إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ غَفَرَ لَهُ‏\}‏ ‏"‏‏.‏ تَابَعَهُ عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ فِي الآيَةِ‏.‏\hadithno{4894}\hadithtrans{Narrated 'Ubada bin As-Samit:While we were with the Prophet, he said, "Will you swear to me the pledge of allegiance that you will not worship any thing besides Allah, will not commit illegal sexual intercourse, and will not steal?" Then he recited the Verse concerning the women. (Sufyan, the subnarrator, often said that the Prophet: added, "Whoever among you fulfills his pledge, will receive his reward from Allah, and whoever commits any of those sins and receives the legal punishment (in this life), his punishment will be an expiation for that sin; and whoever commits any of those sins and Allah screens him, then it is up to Allah to punish or forgive them}}
\hadithdefcmd{bukhari}{4895}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ وَأَخْبَرَنِي ابْنُ جُرَيْجٍ، أَنَّ الْحَسَنَ بْنَ مُسْلِمٍ، أَخْبَرَهُ عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ شَهِدْتُ الصَّلاَةَ يَوْمَ الْفِطْرِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ فَكُلُّهُمْ يُصَلِّيهَا قَبْلَ الْخُطْبَةِ ثُمَّ يَخْطُبُ بَعْدُ، فَنَزَلَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَكَأَنِّي أَنْظُرُ إِلَيْهِ حِينَ يُجَلِّسُ الرِّجَالَ بِيَدِهِ، ثُمَّ أَقْبَلَ يَشُقُّهُمْ حَتَّى أَتَى النِّسَاءَ مَعَ بِلاَلٍ فَقَالَ ‏\{‏يَا أَيُّهَا النَّبِيُّ إِذَا جَاءَكَ الْمُؤْمِنَاتُ يُبَايِعْنَكَ عَلَى أَنْ لاَ يُشْرِكْنَ بِاللَّهِ شَيْئًا وَلاَ يَسْرِقْنَ وَلاَ يَزْنِينَ وَلاَ يَقْتُلْنَ أَوْلاَدَهُنَّ وَلاَ يَأْتِينَ بِبُهْتَانٍ يَفْتَرِينَهُ بَيْنَ أَيْدِيهِنَّ وَأَرْجُلِهِنَّ‏\}‏ حَتَّى فَرَغَ مِنَ الآيَةِ كُلِّهَا ثُمَّ قَالَ حِينَ فَرَغَ ‏"‏ أَنْتُنَّ عَلَى ذَلِكَ ‏"‏‏.‏ وَقَالَتِ امْرَأَةٌ وَاحِدَةٌ لَمْ يُجِبْهُ غَيْرُهَا نَعَمْ يَا رَسُولَ اللَّهِ، لاَ يَدْرِي الْحَسَنُ مَنْ هِيَ‏.‏ قَالَ ‏"‏ فَتَصَدَّقْنَ ‏"‏ وَبَسَطَ بِلاَلٌ ثَوْبَهُ فَجَعَلْنَ يُلْقِينَ الْفَتَخَ وَالْخَوَاتِيمَ فِي ثَوْبِ بِلاَلٍ‏.‏\hadithno{4895}\hadithtrans{Narrated Ibn `Abbas:I witnessed the `Id-al-Fitr prayer with Allah's Messenger (ﷺ) , Abu Bakr, `Umar and `Uthman; and all of them offered it before delivering the sermon... and then delivered the sermon. Once the Prophet (after completing the prayer and the sermon) came down, as if I am now looking at him waving at the men with his hand to sit down, and walked through them till he, along with Bilal, reached (the rows of) the women. Then he recited: 'O Prophet! When believing women come to you to take the oath of allegiance that they will not worship anything other than Allah, will not steal, will not commit illegal sexual intercourse, will not kill their children, and will not utter slander, intentionally forging falsehood (by making illegal children belonging to their husbands)'....(60.12) Having finished, he said, 'Do you agree to that?" One lady, other than whom none replied the Prophet (ﷺ) said, "Yes, O Allah's Messenger (ﷺ)!" (The, sub-narrator, Al-Hasan did not know who the lady was.) Then the Prophet (ﷺ) said to them: "Will you give alms?" Thereupon Bilal spread out his garment and the women started throwing big rings and small rings into Bilal's garment. (See Hadith No. 95 vol)}}
\hadithdefcmd{bukhari}{4896}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ لِي أَسْمَاءً، أَنَا مُحَمَّدٌ، وَأَنَا أَحْمَدُ، وَأَنَا الْمَاحِي الَّذِي يَمْحُو اللَّهُ بِيَ الْكُفْرَ، وَأَنَا الْحَاشِرُ الَّذِي يُحْشَرُ النَّاسُ عَلَى قَدَمِي، وَأَنَا الْعَاقِبُ ‏"‏‏.‏\hadithno{4896}\hadithtrans{Narrated Jubair bin Mut`im:I heard Allah's Messenger (ﷺ) saying, 'I have several names: I am Muhammad and I am Ahmad, and I am Al- Mahi with whom Allah obliterates Kufr (disbelief), and I am Al-Hashir (gatherer) at whose feet (i.e. behind whom) the people will be gathered (on the Day of Resurrection), and I am Al-Aqib (i.e. who succeeds the other prophets in bringing about good)}}
\hadithdefcmd{bukhari}{4897}{حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ ثَوْرٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأُنْزِلَتْ عَلَيْهِ سُورَةُ الْجُمُعَةِ ‏\{‏وَآخَرِينَ مِنْهُمْ لَمَّا يَلْحَقُوا بِهِمْ‏\}‏ قَالَ قُلْتُ مَنْ هُمْ يَا رَسُولَ اللَّهِ فَلَمْ يُرَاجِعْهُ حَتَّى سَأَلَ ثَلاَثًا، وَفِينَا سَلْمَانُ الْفَارِسِيُّ، وَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ عَلَى سَلْمَانَ ثُمَّ قَالَ ‏"‏ لَوْ كَانَ الإِيمَانُ عِنْدَ الثُّرَيَّا لَنَالَهُ رِجَالٌ ـ أَوْ رَجُلٌ ـ مِنْ هَؤُلاَءِ ‏"‏‏.‏\hadithno{4897}\hadithtrans{Narrated Abu Huraira:While we were sitting with the Prophet (ﷺ) Surat Al-Jumu'a was revealed to him, and when the Verse, "And He (Allah) has sent him (Muhammad) also to other (Muslims).....' (62.3) was recited by the Prophet, I said, "Who are they, O Allah's Messenger (ﷺ)?" The Prophet (ﷺ) did not reply till I repeated my question thrice. At that time, Salman Al-Farisi was with us. So Allah's Messenger (ﷺ) put his hand on Salman, saying, "If Faith were at (the place of) Ath-Thuraiya (pleiades, the highest star), even then (some men or man from these people (i.e. Salman's folk) would attain it}}
\hadithdefcmd{bukhari}{4898}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، أَخْبَرَنِي ثَوْرٌ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لَنَالَهُ رِجَالٌ مِنْ هَؤُلاَءِ ‏"‏‏.‏\hadithno{4898}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said. Then some men from these people would attain it}}
\hadithdefcmd{bukhari}{4899}{حَدَّثَنِي حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حُصَيْنٌ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، وَعَنْ أَبِي سُفْيَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ أَقْبَلَتْ عِيرٌ يَوْمَ الْجُمُعَةِ وَنَحْنُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَثَارَ النَّاسُ إِلاَّ اثْنَا عَشَرَ رَجُلاً فَأَنْزَلَ اللَّهُ ‏\{‏وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا‏\}‏\hadithno{4899}\hadithtrans{Narrated Jabir bin `Abdullah:A caravan of merchandise arrived at Medina on a Friday while we were with the Prophet (ﷺ) All the people left (the Prophet (ﷺ) and headed for the caravan) except twelve persons. Then Allah revealed:-- 'But when they see some bargain or some amusement they disperse headlong to it}}
\hadithdefcmd{bukhari}{4900}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ كُنْتُ فِي غَزَاةٍ فَسَمِعْتُ عَبْدَ اللَّهِ بْنَ أُبَىٍّ، يَقُولُ لاَ تُنْفِقُوا عَلَى مَنْ عِنْدَ رَسُولِ اللَّهِ حَتَّى يَنْفَضُّوا مِنْ حَوْلِهِ وَلَوْ رَجَعْنَا مِنْ عِنْدِهِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا‏.‏ الأَذَلَّ فَذَكَرْتُ ذَلِكَ لِعَمِّي أَوْ لِعُمَرَ فَذَكَرَهُ لِلنَّبِيِّ صلى الله عليه وسلم فَدَعَانِي فَحَدَّثْتُهُ فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى عَبْدِ اللَّهِ بْنِ أُبَىٍّ وَأَصْحَابِهِ فَحَلَفُوا مَا قَالُوا فَكَذَّبَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَدَّقَهُ فَأَصَابَنِي هَمٌّ لَمْ يُصِبْنِي مِثْلُهُ قَطُّ، فَجَلَسْتُ فِي الْبَيْتِ فَقَالَ لِي عَمِّي مَا أَرَدْتَ إِلَى أَنْ كَذَّبَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَقَتَكَ‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِذَا جَاءَكَ الْمُنَافِقُونَ‏\}‏ فَبَعَثَ إِلَىَّ النَّبِيُّ صلى الله عليه وسلم فَقَرَأَ فَقَالَ ‏"‏ إِنَّ اللَّهَ قَدْ صَدَّقَكَ يَا زَيْدُ ‏"‏‏.‏\hadithno{4900}\hadithtrans{Narrated Zaid bin Arqam:While I was taking part in a Ghazwa. I heard `Abdullah bin Ubai (bin Abi Salul) saying. "Don't spend on those who are with Allah's Messenger (ﷺ), that they may disperse and go away from him. If we return (to Medina), surely, the more honorable will expel the meaner amongst them." I reported that (saying) to my uncle or to `Umar who, in his turn, informed the Prophet (ﷺ) of it. The Prophet (ﷺ) called me and I narrated to him the whole story. Then Allah's Messenger (ﷺ) sent for `Abdullah bin Ubai and his companions, and they took an oath that they did not say that. So Allah's Messenger (ﷺ) disbelieved my saying and believed his. I was distressed as I never was before. I stayed at home and my uncle said to me. "You just wanted Allah's Messenger (ﷺ) to disbelieve your statement and hate you." So Allah revealed (the Sura beginning with) 'When the hypocrites come to you.' (63.1) The Prophet (ﷺ) then sent for me and recited it and said, "O Zaid! Allah confirmed your statement}}
\hadithdefcmd{bukhari}{4901}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ زَيْدِ بْنِ أَرْقَمَ ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ عَمِّي فَسَمِعْتُ عَبْدَ اللَّهِ بْنَ أُبَىٍّ ابْنَ سَلُولَ يَقُولُ لاَ تُنْفِقُوا عَلَى مَنْ عِنْدَ رَسُولِ اللَّهِ حَتَّى يَنْفَضُّوا‏.‏ وَقَالَ أَيْضًا لَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ‏.‏ فَذَكَرْتُ ذَلِكَ لِعَمِّي فَذَكَرَ عَمِّي لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى عَبْدِ اللَّهِ بْنِ أُبَىٍّ وَأَصْحَابِهِ، فَحَلَفُوا مَا قَالُوا، فَصَدَّقَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَذَّبَنِي، فَأَصَابَنِي هَمٌّ لَمْ يُصِبْنِي مِثْلُهُ، فَجَلَسْتُ فِي بَيْتِي، فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏إِذَا جَاءَكَ الْمُنَافِقُونَ‏\}‏ إِلَى قَوْلِهِ ‏\{‏هُمُ الَّذِينَ يَقُولُونَ لاَ تُنْفِقُوا عَلَى مَنْ عِنْدَ رَسُولِ اللَّهِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ‏\}‏ فَأَرْسَلَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَرَأَهَا عَلَىَّ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ قَدْ صَدَّقَكَ ‏"‏‏.‏\hadithno{4901}\hadithtrans{Narrated Zaid bin Arqam:I was with my uncle and I heard `Abdullah bin Ubai bin Salul, saying, "Don't spend on those who are with Allah's Messenger (ﷺ) that they may disperse and go away from him." He also said, "If we return to Medina, surely, the more honorable will expel the meaner." So I informed my uncle of that and then my uncle informed Allah's Messenger (ﷺ) thereof. Allah's Messenger (ﷺ) sent for `Abdullah bin Ubai and his companions. They swore that they did not say anything of that sort Allah's Messenger (ﷺ) deemed their statement true and rejected mine. Thereof I became as distressed as I have never been before, and stayed at home. Then Allah revealed (Surat Al-Munafiqin): 'When the hypocrites come to you.....(63.1) They are the ones who say: Spend nothing on those who are with Allah's Messenger (ﷺ) ..(63.7) Verily the more honorable will expel therefrom the meaner..' (63.7-8) Allah's Messenger (ﷺ) sent for me and recited that Sura for me and said, "Allah has confirmed your statement}}
\hadithdefcmd{bukhari}{4902}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ كَعْبٍ الْقُرَظِيَّ، قَالَ سَمِعْتُ زَيْدَ بْنَ أَرْقَمَ ـ رضى الله عنه ـ قَالَ لَمَّا قَالَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ لاَ تُنْفِقُوا عَلَى مَنْ عِنْدَ رَسُولِ اللَّهِ‏.‏ وَقَالَ أَيْضًا لَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ‏.‏ أَخْبَرْتُ بِهِ النَّبِيَّ صلى الله عليه وسلم فَلاَمَنِي الأَنْصَارُ، وَحَلَفَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ مَا قَالَ ذَلِكَ، فَرَجَعْتُ إِلَى الْمَنْزِلِ فَنِمْتُ فَدَعَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُهُ فَقَالَ ‏"‏ إِنَّ اللَّهَ قَدْ صَدَّقَكَ ‏"‏‏.‏ وَنَزَلَ ‏\{‏هُمُ الَّذِينَ يَقُولُونَ لاَ تُنْفِقُوا‏\}‏ الآيَةَ‏.‏ وَقَالَ ابْنُ أَبِي زَائِدَةَ عَنِ الأَعْمَشِ عَنْ عَمْرٍو عَنِ ابْنِ أَبِي لَيْلَى عَنْ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{4902}\hadithtrans{Narrated Zaid bin Arqam:When `Abdullah bin Ubai said, "Do not spend on those who are with Allah's Messenger (ﷺ)," and also said, "If we return to Medina," I informed the Prophet (ﷺ) of his saying. The Ansar blamed me for that, and `Abdullah bin Ubai swore that he did not say. I returned to my house and slept. Allah's Messenger (ﷺ) then called me and I went to him. He said, "Allah has confirmed your statement." The Verse: "They are the one who say: Spend nothing......(63.7) was revealed}}
\hadithdefcmd{bukhari}{4903}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ زَيْدَ بْنَ أَرْقَمَ، قَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ أَصَابَ النَّاسَ فِيهِ شِدَّةٌ، فَقَالَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ لأَصْحَابِهِ لاَ تُنْفِقُوا عَلَى مَنْ عِنْدَ رَسُولِ اللَّهِ حَتَّى يَنْفَضُّوا مِنْ حَوْلِهِ‏.‏ وَقَالَ لَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَأَرْسَلَ إِلَى عَبْدِ اللَّهِ بْنِ أُبَىٍّ فَسَأَلَهُ، فَاجْتَهَدَ يَمِينَهُ مَا فَعَلَ، قَالُوا كَذَبَ زَيْدٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَوَقَعَ فِي نَفْسِي مِمَّا قَالُوا شِدَّةٌ، حَتَّى أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ تَصْدِيقِي فِي ‏\{‏إِذَا جَاءَكَ الْمُنَافِقُونَ‏\}‏ فَدَعَاهُمُ النَّبِيُّ صلى الله عليه وسلم لِيَسْتَغْفِرَ لَهُمْ فَلَوَّوْا رُءُوسَهُمْ‏.‏ وَقَوْلُهُ ‏\{‏خُشُبٌ مُسَنَّدَةٌ‏\}‏ قَالَ كَانُوا رِجَالاً أَجْمَلَ شَىْءٍ‏.‏\hadithno{4903}\hadithtrans{Narrated Zaid bin Arqam:We went out with the Prophet (ﷺ) : on a journey and the people suffered from lack of provisions. So `Abdullah bin Ubai said to his companions, "Don't spend on those who are with Allah's Messenger (ﷺ), that they may disperse and go away from him." He also said, "If we return to Medina, surely, the more honorable will expel therefrom the meaner. So I went to the Prophet (ﷺ) and informed him of that. He sent for `Abdullah bin Ubai and asked him, but `Abdullah bin Ubai swore that he did not say so. The people said, "Zaid told a lie to 'Allah's Messenger (ﷺ)." What they said distressed me very much. Later Allah revealed the confirmation of my statement in his saying:-- '(When the hypocrites come to you.' (63.1) So the Prophet (ﷺ) called them that they might ask Allah to forgive them, but they turned their heads aside. (Concerning Allah's saying: 'Pieces of wood propped up,' Zaid said; They were the most handsome men)}}
\hadithdefcmd{bukhari}{4904}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ كُنْتُ مَعَ عَمِّي فَسَمِعْتُ عَبْدَ اللَّهِ بْنَ أُبَىٍّ ابْنَ سَلُولَ، يَقُولُ لاَ تُنْفِقُوا عَلَى مَنْ عِنْدَ رَسُولِ اللَّهِ حَتَّى يَنْفَضُّوا، وَلَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ‏.‏ فَذَكَرْتُ ذَلِكَ لِعَمِّي، فَذَكَرَ عَمِّي لِلنَّبِيِّ صلى الله عليه وسلم ‏\{‏فَدَعَانِي فَحَدَّثْتُهُ، فَأَرْسَلَ إِلَى عَبْدِ اللَّهِ بْنِ أُبَىٍّ وَأَصْحَابِهِ فَحَلَفُوا مَا قَالُوا، وَكَذَّبَنِي النَّبِيُّ صلى الله عليه وسلم‏\}‏ وَصَدَّقَهُمْ، فَأَصَابَنِي غَمٌّ لَمْ يُصِبْنِي مِثْلُهُ قَطُّ، فَجَلَسْتُ فِي بَيْتِي وَقَالَ عَمِّي مَا أَرَدْتَ إِلَى أَنْ كَذَّبَكَ النَّبِيُّ صلى الله عليه وسلم وَمَقَتَكَ‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِذَا جَاءَكَ الْمُنَافِقُونَ قَالُوا نَشْهَدُ إِنَّكَ لَرَسُولُ اللَّهِ‏\}‏ وَأَرْسَلَ إِلَىَّ النَّبِيُّ صلى الله عليه وسلم فَقَرَأَهَا وَقَالَ ‏"‏ إِنَّ اللَّهَ قَدْ صَدَّقَكَ ‏"‏‏.‏\hadithno{4904}\hadithtrans{Narrated Zaid bin Arqam:While I was with my uncle, I heard `Abdullah bin Ubai bin Salul saying, "Do not spend on those who are with Allah's Messenger (ﷺ), that they may disperse and go away (from him). And if we return to Medina, surely, the more honorable will expel therefrom the meaner. "I mentioned that to my uncle who, in turn, mentioned it to the Prophet. The Prophet (ﷺ) called me and I told him about that. Then he sent for `Abdullah bin Ubai and his companions, and they swore that they did not say so. The Prophet (ﷺ) disbelieved my statement and believed theirs. I was distressed as I have never been before, and I remained in my house. My uncle said to me, "You just wanted the Prophet (ﷺ) to consider you a liar and hate you." Then Allah revealed:-- 'When the hypocrites come to you, they say: 'We bear witness that you are indeed the Apostle of Allah." (63.1) So the Prophet (ﷺ) sent for me and recited it and said, "Allah has confirmed your statement}}
\hadithdefcmd{bukhari}{4905}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كُنَّا فِي غَزَاةٍ ـ قَالَ سُفْيَانُ مَرَّةً فِي جَيْشٍ ـ فَكَسَعَ رَجُلٌ مِنَ الْمُهَاجِرِينَ رَجُلاً مِنَ الأَنْصَارِ فَقَالَ الأَنْصَارِيُّ يَا لَلأَنْصَارِ‏.‏ وَقَالَ الْمُهَاجِرِيُّ يَا لَلْمُهَاجِرِينَ‏.‏ فَسَمِعَ ذَاكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا بَالُ دَعْوَى جَاهِلِيَّةٍ ‏"‏ قَالُوا يَا رَسُولَ اللَّهِ كَسَعَ رَجُلٌ مِنَ الْمُهَاجِرِينَ رَجُلاً مِنَ الأَنْصَارِ‏.‏ فَقَالَ ‏"‏ دَعُوهَا فَإِنَّهَا مُنْتِنَةٌ ‏"‏‏.‏ فَسَمِعَ بِذَلِكَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ فَقَالَ فَعَلُوهَا، أَمَا وَاللَّهِ لَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ‏.‏ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَامَ عُمَرُ فَقَالَ يَا رَسُولَ اللَّهِ دَعْنِي أَضْرِبْ عُنُقَ هَذَا الْمُنَافِقِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ دَعْهُ لاَ يَتَحَدَّثُ النَّاسُ أَنَّ مُحَمَّدًا يَقْتُلُ أَصْحَابَهُ ‏"‏ وَكَانَتِ الأَنْصَارُ أَكْثَرَ مِنَ الْمُهَاجِرِينَ حِينَ قَدِمُوا الْمَدِينَةَ، ثُمَّ إِنَّ الْمُهَاجِرِينَ كَثُرُوا بَعْدُ‏.‏ قَالَ سُفْيَانُ فَحَفِظْتُهُ مِنْ عَمْرٍو قَالَ عَمْرٌو سَمِعْتُ جَابِرًا كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{4905}\hadithtrans{Narrated Jabir bin `Abdullah:We were in a Ghazwa (Sufyan once said, in an army) and a man from the emigrants kicked an Ansari man (on the buttocks with his foot). The Ansari man said, "O the Ansar! (Help!)" and the emigrant said. "O the emigrants! (Help!) Allah's Messenger (ﷺ) heard that and said, "What is this call for, which is characteristic of the period of ignorance?" They said, "O Allah's Messenger (ﷺ)! A man from the emigrants kicked one of the Ansar (on the buttocks with his foot)." Allah's Messenger (ﷺ) said, "Leave it (that call) as is a detestable thing." `Abdullah bin Ubai heard that and said, 'Have the (the emigrants) done so? By Allah, if we return Medina, surely, the more honorable will expel therefrom the meaner." When this statement reached the Prophet. `Umar got up an, said, "O Allah's Messenger (ﷺ)! Let me chop off the head of this hypocrite (`Abdullah bin Ubai)!" The Prophet (ﷺ) said "Leave him, lest the people say that Muhammad kills his companions." The Ansar were then more in number than the emigrants when the latter came to Medina, but later on the emigrant increased}}
\hadithdefcmd{bukhari}{4906}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ الْفَضْلِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ حَزِنْتُ عَلَى مَنْ أُصِيبَ بِالْحَرَّةِ فَكَتَبَ إِلَىَّ زَيْدُ بْنُ أَرْقَمَ وَبَلَغَهُ شِدَّةُ حُزْنِي يَذْكُرُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ اللَّهُمَّ اغْفِرْ لِلأَنْصَارِ وَلأَبْنَاءِ الأَنْصَارِ ‏"‏ ـ وَشَكَّ ابْنُ الْفَضْلِ فِي أَبْنَاءِ أَبْنَاءِ الأَنْصَارِ ـ فَسَأَلَ أَنَسًا بَعْضُ مَنْ كَانَ عِنْدَهُ فَقَالَ هُوَ الَّذِي يَقُولُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا الَّذِي أَوْفَى اللَّهُ لَهُ بِأُذُنِهِ ‏"‏‏.‏\hadithno{4906}\hadithtrans{Narrated Musa bin `Uqba:`Abdullah bin Al-Fadl told me that Anas bin Malik said, "I was much grieve over those who had been killed in the Battle of Al-Harra. When Zaid bin Arqarr heard of my intense grief (over the killed Ansar), he wrote a letter to me saying that he heard Allah's Messenger (ﷺ) saying, O Allah! Forgive the Ansar and the Ansar children. The subnarrator, Ibn Al-Fadl, is not sure whether the Prophet (ﷺ) also said, And their grand-children." Some of those who were present, asked Anas (about Zaid). He said, "He (Zaid) is the one about whom Allah's Messenger (ﷺ) said, 'He is the one whose sound hearing Allah testified}}
\hadithdefcmd{bukhari}{4907}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنْ عَمْرِو بْنِ دِينَارٍ قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ كُنَّا فِي غَزَاةٍ فَكَسَعَ رَجُلٌ مِنَ الْمُهَاجِرِينَ رَجُلاً مِنَ الأَنْصَارِ فَقَالَ الأَنْصَارِيُّ يَا لَلأَنْصَارِ‏.‏ وَقَالَ الْمُهَاجِرِيُّ يَا لَلْمُهَاجِرِينَ‏.‏ فَسَمَّعَهَا اللَّهُ رَسُولَهُ صلى الله عليه وسلم قَالَ ‏"‏ مَا هَذَا ‏"‏‏.‏ فَقَالُوا كَسَعَ رَجُلٌ مِنَ الْمُهَاجِرِينَ رَجُلاً مِنَ الأَنْصَارِ فَقَالَ الأَنْصَارِيُّ يَا لَلأَنْصَارِ‏.‏ وَقَالَ الْمُهَاجِرِيُّ يَالَلْمُهَاجِرِينَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ دَعُوهَا فَإِنَّهَا مُنْتِنَةٌ ‏"‏‏.‏ قَالَ جَابِرٌ وَكَانَتِ الأَنْصَارُ حِينَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم أَكْثَرَ، ثُمَّ كَثُرَ الْمُهَاجِرُونَ بَعْدُ، فَقَالَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ أَوَقَدْ فَعَلُوا، وَاللَّهِ لَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه دَعْنِي يَا رَسُولَ اللَّهِ أَضْرِبْ عُنُقَ هَذَا الْمُنَافِقِ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ دَعْهُ لاَ يَتَحَدَّثُ النَّاسُ أَنَّ مُحَمَّدًا يَقْتُلُ أَصْحَابَهُ ‏"‏‏.‏\hadithno{4907}\hadithtrans{Narrated Jabir bin `Abdullah:We were in a Ghazwa and a man from the emigrants kicked an Ansari (on the buttocks with his foot). The Ansari man said, "O the Ansari! (Help!)" The emigrant said, "O the emigrants! (Help)." When Allah's Messenger (ﷺ) heard that, he said, "What is that?" They said, "A man from the emigrants kicked a man from the Ansar (on the buttocks his foot). On that the Ansar said, 'O the Ansar!' and the emigrant said, 'O the emigrants!" The Prophet (ﷺ) said' "Leave it (that call) for it Is a detestable thing." The number of Ansar was larger (than that of the emigrants) at the time when the Prophet (ﷺ) came to Medina, but later the number of emigrants increased. `Abdullah bin Ubai said, "Have they, (the emigrants) done so? By Allah, if we return to Medina, surely, the more honorable will expel therefrom the meaner," `Umar bin Al-Khattab said, "O Allah's Messenger (ﷺ)! Let me chop off the head of this hypocrite!" The Prophet said, "Leave him, lest the people say Muhammad kills his companions:}}
\hadithdefcmd{bukhari}{4908}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمٌ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّهُ، طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ، فَذَكَرَ عُمَرُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَتَغَيَّظَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ لِيُرَاجِعْهَا ثُمَّ يُمْسِكْهَا حَتَّى تَطْهُرَ، ثُمَّ تَحِيضَ فَتَطْهُرَ، فَإِنْ بَدَا لَهُ أَنْ يُطَلِّقَهَا فَلْيُطَلِّقْهَا طَاهِرًا قَبْلَ أَنْ يَمَسَّهَا فَتِلْكَ الْعِدَّةُ كَمَا أَمَرَهُ اللَّهُ ‏"‏‏.‏\hadithno{4908}\hadithtrans{Narrated Salim:That `Abdullah bin `Umar told him that he had divorced his wife while she was in her menses so `Umar informed Allah's Messenger (ﷺ) of that. Allah's Messenger (ﷺ) became very angry at that and said, "(Ibn `Umar must return her to his house and keep her as his wife till she becomes clean and then menstruates and becomes clean again, whereupon, if he wishes to divorce her, he may do so while she is still clean and before having any sexual relations with her, for that is the legally prescribed period for divorce as Allah has ordered)}}
\hadithdefcmd{bukhari}{4909}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، قَالَ جَاءَ رَجُلٌ إِلَى ابْنِ عَبَّاسٍ وَأَبُو هُرَيْرَةَ جَالِسٌ عِنْدَهُ فَقَالَ أَفْتِنِي فِي امْرَأَةٍ وَلَدَتْ بَعْدَ زَوْجِهَا بِأَرْبَعِينَ لَيْلَةً‏.‏ فَقَالَ ابْنُ عَبَّاسٍ آخِرُ الأَجَلَيْنِ‏.‏ قُلْتُ أَنَا ‏\{‏وَأُولاَتُ الأَحْمَالِ أَجَلُهُنَّ أَنْ يَضَعْنَ حَمْلَهُنَّ‏\}‏ قَالَ أَبُو هُرَيْرَةَ أَنَا مَعَ ابْنِ أَخِي ـ يَعْنِي أَبَا سَلَمَةَ ـ فَأَرْسَلَ ابْنُ عَبَّاسٍ غُلاَمَهُ كُرَيْبًا إِلَى أُمِّ سَلَمَةَ يَسْأَلُهَا فَقَالَتْ قُتِلَ زَوْجُ سُبَيْعَةَ الأَسْلَمِيَّةِ وَهْىَ حُبْلَى، فَوَضَعَتْ بَعْدَ مَوْتِهِ بِأَرْبَعِينَ لَيْلَةً فَخُطِبَتْ فَأَنْكَحَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ أَبُو السَّنَابِلِ فِيمَنْ خَطَبَهَا‏.‏\hadithno{4909}\hadithtrans{Narrated Abu Salama:A man came to Ibn `Abbas while Abu Huraira was sitting with him and said, "Give me your verdict regarding a lady who delivered a baby forty days after the death of her husband." Ibn `Abbas said, "This indicates the end of one of the two prescribed periods." I said "For those who are pregnant, their prescribed period is until they deliver their burdens." Abu Huraira said, I agree with my cousin (Abu Salama)." Then Ibn `Abbas sent his slave, Kuraib to Um Salama to ask her (regarding this matter). She replied. "The husband of Subai'a al Aslamiya was killed while she was pregnant, and she delivered a baby forty days after his death. Then her hand was asked in marriage and Allah's Messenger (ﷺ) married her (to somebody). Abu As-Sanabil was one of those who asked for her hand in marriage}}
\hadithdefcmd{bukhari}{4910}{وَقَالَ سُلَيْمَانُ بْنُ حَرْبٍ وَأَبُو النُّعْمَانِ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، قَالَ كُنْتُ فِي حَلْقَةٍ فِيهَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى وَكَانَ أَصْحَابُهُ يُعَظِّمُونَهُ، فَذَكَرَ آخِرَ الأَجَلَيْنِ فَحَدَّثْتُ بِحَدِيثِ سُبَيْعَةَ بِنْتِ الْحَارِثِ عَنْ عَبْدِ اللَّهِ بْنِ عُتْبَةَ قَالَ فَضَمَّزَ لِي بَعْضُ أَصْحَابِهِ‏.‏ قَالَ مُحَمَّدٌ فَفَطِنْتُ لَهُ فَقُلْتُ إِنِّي إِذًا لَجَرِيءٌ إِنْ كَذَبْتُ عَلَى عَبْدِ اللَّهِ بْنِ عُتْبَةَ وَهْوَ فِي نَاحِيَةِ الْكُوفَةِ‏.‏ فَاسْتَحْيَا وَقَالَ لَكِنَّ عَمَّهُ لَمْ يَقُلْ ذَاكَ‏.‏ فَلَقِيتُ أَبَا عَطِيَّةَ مَالِكَ بْنَ عَامِرٍ فَسَأَلْتُهُ فَذَهَبَ يُحَدِّثُنِي حَدِيثَ سُبَيْعَةَ فَقُلْتُ هَلْ سَمِعْتَ عَنْ عَبْدِ اللَّهِ فِيهَا شَيْئًا فَقَالَ كُنَّا عِنْدَ عَبْدِ اللَّهِ فَقَالَ أَتَجْعَلُونَ عَلَيْهَا التَّغْلِيظَ وَلاَ تَجْعَلُونَ عَلَيْهَا الرُّخْصَةَ‏.‏ لَنَزَلَتْ سُورَةُ النِّسَاءِ الْقُصْرَى بَعْدَ الطُّولَى ‏\{‏وَأُولاَتُ الأَحْمَالِ أَجَلُهُنَّ أَنْ يَضَعْنَ حَمْلَهُنَّ‏\}‏‏.‏\hadithno{4910}\hadithtrans{See hadith}}
\hadithdefcmd{bukhari}{4911}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنِ ابْنِ حَكِيمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ فِي الْحَرَامِ يُكَفِّرُ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ إِسْوَةٌ حَسَنَةٌ‏\}‏‏.‏\hadithno{4911}\hadithtrans{Narrated Ibn `Abbas:If someone says to his wife, "You are unlawful to me." he must make an expiation (for his oath). Ibn `Abbas added: There is for you in Allah's Messenger (ﷺ), an excellent example to follow}}
\hadithdefcmd{bukhari}{4912}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَشْرَبُ عَسَلاً عِنْدَ زَيْنَبَ ابْنَةِ جَحْشٍ وَيَمْكُثُ عِنْدَهَا فَوَاطَيْتُ أَنَا وَحَفْصَةُ عَنْ أَيَّتُنَا دَخَلَ عَلَيْهَا فَلْتَقُلْ لَهُ أَكَلْتَ مَغَافِيرَ إِنِّي أَجِدُ مِنْكَ رِيحَ مَغَافِيرَ‏.‏ قَالَ ‏ "‏ لاَ وَلَكِنِّي كُنْتُ أَشْرَبُ عَسَلاً عِنْدَ زَيْنَبَ ابْنَةِ جَحْشٍ فَلَنْ أَعُودَ لَهُ وَقَدْ حَلَفْتُ لاَ تُخْبِرِي بِذَلِكِ أَحَدًا ‏"‏‏.‏\hadithno{4912}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to drink honey in the house of Zainab, the daughter of Jahsh, and would stay there with her. So Hafsa and I agreed secretly that, if he come to either of us, she would say to him. "It seems you have eaten Maghafir (a kind of bad-smelling resin), for I smell in you the smell of Maghafir," (We did so) and he replied. "No, but I was drinking honey in the house of Zainab, the daughter of Jahsh, and I shall never take it again. I have taken an oath as to that, and you should not tell anybody about it}}
\hadithdefcmd{bukhari}{4913}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يُحَدِّثُ أَنَّهُ قَالَ مَكَثْتُ سَنَةً أُرِيدُ أَنْ أَسْأَلَ عُمَرَ بْنَ الْخَطَّابِ عَنْ آيَةٍ، فَمَا أَسْتَطِيعُ أَنْ أَسْأَلَهُ هَيْبَةً لَهُ، حَتَّى خَرَجَ حَاجًّا فَخَرَجْتُ مَعَهُ فَلَمَّا رَجَعْتُ وَكُنَّا بِبَعْضِ الطَّرِيقِ عَدَلَ إِلَى الأَرَاكِ لِحَاجَةٍ لَهُ ـ قَالَ ـ فَوَقَفْتُ لَهُ حَتَّى فَرَغَ سِرْتُ مَعَهُ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ اللَّتَانِ تَظَاهَرَتَ�� عَلَى النَّبِيِّ صلى الله عليه وسلم مِنْ أَزْوَاجِهِ فَقَالَ تِلْكَ حَفْصَةُ وَعَائِشَةُ‏.‏ قَالَ فَقُلْتُ وَاللَّهِ إِنْ كُنْتُ لأُرِيدُ أَنْ أَسْأَلَكَ عَنْ هَذَا مُنْذُ سَنَةٍ، فَمَا أَسْتَطِيعُ هَيْبَةً لَكَ‏.‏ قَالَ فَلاَ تَفْعَلْ مَا ظَنَنْتَ أَنَّ عِنْدِي مِنْ عِلْمٍ فَاسْأَلْنِي، فَإِنْ كَانَ لِي عِلْمٌ خَبَّرْتُكَ بِهِ ـ قَالَ ـ ثُمَّ قَالَ عُمَرُ وَاللَّهِ إِنْ كُنَّا فِي الْجَاهِلِيَّةِ مَا نَعُدُّ لِلنِّسَاءِ أَمْرًا، حَتَّى أَنْزَلَ اللَّهُ فِيهِنَّ مَا أَنْزَلَ وَقَسَمَ لَهُنَّ مَا قَسَمَ ـ قَالَ ـ فَبَيْنَا أَنَا فِي أَمْرٍ أَتَأَمَّرُهُ إِذْ قَالَتِ امْرَأَتِي لَوْ صَنَعْتَ كَذَا وَكَذَا ـ قَالَ ـ فَقُلْتُ لَهَا مَالَكِ وَلِمَا هَا هُنَا فِيمَا تَكَلُّفُكِ فِي أَمْرٍ أُرِيدُهُ‏.‏ فَقَالَتْ لِي عَجَبًا لَكَ يَا ابْنَ الْخَطَّابِ مَا تُرِيدُ أَنْ تُرَاجَعَ أَنْتَ، وَإِنَّ ابْنَتَكَ لَتُرَاجِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم حَتَّى يَظَلَّ يَوْمَهُ غَضْبَانَ‏.‏ فَقَامَ عُمَرُ فَأَخَذَ رِدَاءَهُ مَكَانَهُ حَتَّى دَخَلَ عَلَى حَفْصَةَ فَقَالَ لَهَا يَا بُنَيَّةُ إِنَّكِ لَتُرَاجِعِينَ رَسُولَ اللَّهِ صلى الله عليه وسلم حَتَّى يَظَلَّ يَوْمَهُ غَضْبَانَ‏.‏ فَقَالَتْ حَفْصَةُ وَاللَّهِ إِنَّا لَنُرَاجِعُهُ‏.‏ فَقُلْتُ‏.‏ تَعْلَمِينَ أَنِّي أُحَذِّرُكِ عُقُوبَةَ اللَّهِ وَغَضَبَ رَسُولِهِ صلى الله عليه وسلم يَا بُنَيَّةُ لاَ يَغُرَّنَّكِ هَذِهِ الَّتِي أَعْجَبَهَا حُسْنُهَا حُبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم إِيَّاهَا ـ يُرِيدُ عَائِشَةَ ـ قَالَ ثُمَّ خَرَجْتُ حَتَّى دَخَلْتُ عَلَى أُمِّ سَلَمَةَ لِقَرَابَتِي مِنْهَا فَكَلَّمْتُهَا‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ عَجَبًا لَكَ يَا ابْنَ الْخَطَّابِ دَخَلْتَ فِي كُلِّ شَىْءٍ، حَتَّى تَبْتَغِي أَنْ تَدْخُلَ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَزْوَاجِهِ‏.‏ فَأَخَذَتْنِي وَاللَّهِ أَخْذًا كَسَرَتْنِي عَنْ بَعْضِ مَا كُنْتُ أَجِدُ، فَخَرَجْتُ مِنْ عِنْدِهَا، وَكَانَ لِي صَاحِبٌ مِنَ الأَنْصَارِ إِذَا غِبْتُ أَتَانِي بِالْخَبَرِ، وَإِذَا غَابَ كُنْتُ أَنَا آتِيهِ بِالْخَبَرِ، وَنَحْنُ نَتَخَوَّفُ مَلِكًا مِنْ مُلُوكِ غَسَّانَ، ذُكِرَ لَنَا أَنَّهُ يُرِيدُ أَنْ يَسِيرَ إِلَيْنَا، فَقَدِ امْتَلأَتْ صُدُورُنَا مِنْهُ، فَإِذَا صَاحِبِي الأَنْصَارِيُّ يَدُقُّ الْبَابَ فَقَالَ افْتَحِ افْتَحْ‏.‏ فَقُلْتُ جَاءَ الْغَسَّانِيُّ فَقَالَ بَلْ أَشَدُّ مِنْ ذَلِكَ‏.‏ اعْتَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَزْوَاجَهُ‏.‏ فَقُلْتُ رَغَمَ أَنْفُ حَفْصَةَ وَعَائِشَةَ‏.‏ فَأَخَذْتُ ثَوْبِيَ فَأَخْرُجُ حَتَّى جِئْتُ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَشْرُبَةٍ لَهُ يَرْقَى عَلَيْهَا بِعَجَلَةٍ، وَغُلاَمٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَسْوَدُ عَلَى رَأْسِ الدَّرَجَةِ فَقُلْتُ لَهُ قُلْ هَذَا عُمَرُ بْنُ الْخَطَّابِ‏.‏ فَأَذِنَ لِي ـ قَالَ عُمَرُ ـ فَقَصَصْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم هَذَا الْحَدِيثَ، فَلَمَّا بَلَغْتُ حَدِيثَ أُمِّ سَلَمَةَ تَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِنَّهُ لَعَلَى حَصِيرٍ مَا بَيْنَهُ وَبَيْنَهُ شَىْءٌ، وَتَحْتَ رَأْسِهِ وِسَادَةٌ مِنْ أَدَمٍ حَشْوُهَا لِيفٌ، وَإِنَّ عِنْدَ رِجْلَيْهِ قَرَظًا مَصْبُوبًا، وَعِنْدَ رَأْسِهِ أَهَبٌ مُعَلَّقَةٌ فَرَأَيْتُ أَثَرَ الْحَصِيرِ فِي جَنْبِهِ فَبَكَيْتُ فَقَالَ ‏"‏ مَا يُبْكِيكَ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ كِسْرَى وَقَيْصَرَ فِيمَا هُمَا فِيهِ وَأَنْتَ رَسُولُ اللَّهِ‏.‏ فَقَالَ ‏"‏ أَمَا تَرْضَى أَنْ تَكُونَ لَهُمُ الدُّنْيَا وَلَنَا الآخِرَةُ ‏"‏‏.‏\hadithno{4913}\hadithtrans{Narrated Ibn `Abbas:For the whole year I had the desire to ask `Umar bin Al-Khattab regarding the explanation of a Verse (in Surat Al-Tahrim) but I could not ask him because I respected him very much. When he went to perform the Hajj, I too went along with him. On our return, while we were still on the way home. `Umar went aside to answer the call of nature by the Arak trees. I waited till he finished and then I proceeded with him and asked him. "O chief of the Believers! Who were the two wives of the Prophet (ﷺ) who aided one another against him?" He said, "They were Hafsa and `Aisha." Then I said to him, "By Allah, I wanted to ask you about this a year ago, but I could not do so owing to my respect for you." `Umar said, "Do not refrain from asking me. If you think that I have knowledge (about a certain matter), ask me; and if I know (something about it), I will tell you." Then `Umar added, "By Allah, in the Pre-Islamic Period of Ignorance we did not pay attention to women until Allah revealed regarding them what He revealed regarding them and assigned for them what He has assigned. Once while I was thinking over a certain matter, my wife said, "I recommend that you do so-and-so." I said to her, "What have you got to do with the is matter? Why do you poke your nose in a matter which I want to see fulfilled.?" She said, How strange you are, O son of Al-Khattab! You don't want to be argued with whereas your daughter, Hafsa surely, argues with Allah's Messenger (ﷺ) so much that he remains angry for a full day!" `Umar then reported; how he at once put on his outer garment and went to Hafsa and said to her, "O my daughter! Do you argue with Allah's Messenger (ﷺ) so that he remains angry the whole day?" H. afsa said, "By Allah, we argue with him." `Umar said, "Know that I warn you of Allah's punishment and the anger of Allah's Messenger (ﷺ) . . . O my daughter! Don't be betrayed by the one who is proud of her beauty because of the love of Allah's Messenger (ﷺ) for her (i.e. `Aisha)." `Umar addled, "Then I went out to Um Salama's house who was one of my relatives, and I talked to her. She said, O son of Al-Khattab! It is rather astonishing that you interfere in everything; you even want to interfere between Allah's Apostle and his wives!' By Allah, by her talk she influenced me so much that I lost some of my anger. I left her (and went home). At that time I had a friend from the Ansar who used to bring news (from the Prophet) in case of my absence, and I used to bring him the news if he was absent. In those days we were afraid of one of the kings of Ghassan tribe. We heard that he intended to move and attack us, so fear filled our hearts because of that. (One day) my Ansari friend unexpectedly knocked at my door, and said, "Open Open!' I said, 'Has the king of Ghassan come?' He said, 'No, but something worse; Allah's Messenger (ﷺ) has isolated himself from his wives.' I said, 'Let the nose of `Aisha and Hafsa be stuck to dust (i.e. humiliated)!' Then I put on my clothes and went to Allah's Messenger's (ﷺ) residence, and behold, he was staying in an upper room of his to which he ascended by a ladder, and a black slave of Allah's Messenger (ﷺ) was (sitting) on the first step. I said to him, 'Say (to the Prophet (ﷺ) ) `Umar bin Al-Khattab is here.' Then the Prophet (ﷺ) admitted me and I narrated the story to Allah's Messenger (ﷺ). When I reached the story of Um Salama, Allah's Messenger (ﷺ) smiled while he was lying on a mat made of palm tree leaves with nothing between him and the mat. Underneath his head there was a leather pillow stuffed with palm fibres, and leaves of a saut tree were piled at his feet, and above his head hung a few water skins. On seeing the marks of the mat imprinted on his side, I wept. He said.' 'Why are you weeping?' I replied, "O Allah's Messenger (ﷺ)! Caesar and Khosrau are leading the life (i.e. Luxurious life) while you, Allah's Messenger (ﷺ) though you are, is living in destitute". The Prophet (ﷺ) then replied. 'Won't you be satisfied that they enjoy this world and we the Hereafter?}}
\hadithdefcmd{bukhari}{4914}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ سَمِعْتُ عُبَيْدَ بْنَ حُنَيْنٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ أَرَدْتُ أَنْ أَسْأَلَ عُمَرَ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ الْمَرْأَتَانِ اللَّتَانِ تَظَاهَرَتَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَا أَتْمَمْتُ كَلاَمِي حَتَّى قَالَ عَائِشَةُ وَحَفْصَةُ‏.‏\hadithno{4914}\hadithtrans{Narrated Ibn `Abbas:I intended to ask `Umar so I said, "Who were those two ladies who tried to back each other against the Prophet?" I hardly finished my speech when he said, They were `Aisha and Hafsa}}
\hadithdefcmd{bukhari}{4915}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ سَمِعْتُ عُبَيْدَ بْنَ حُنَيْنٍ، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَرَدْتُ أَنْ أَسْأَلَ، عُمَرَ عَنِ الْمَرْأَتَيْنِ اللَّتَيْنِ، تَظَاهَرَتَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَكُثْتُ سَنَةً فَلَمْ أَجِدْ لَهُ مَوْضِعًا، حَتَّى خَرَجْتُ مَعَهُ حَاجًّا، فَلَمَّا كُنَّا بِظَهْرَانَ ذَهَبَ عُمَرُ لِحَاجَتِهِ فَقَالَ أَدْرِكْنِي بِالْوَضُوءِ فَأَدْرَكْتُهُ بِالإِدَاوَةِ، فَجَعَلْتُ أَسْكُبُ عَلَيْهِ وَرَأَيْتُ مَوْضِعًا فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ الْمَرْأَتَانِ اللَّتَانِ تَظَاهَرَتَا قَالَ ابْنُ عَبَّاسٍ فَمَا أَتْمَمْتُ كَلاَمِي حَتَّى قَالَ عَائِشَةُ وَحَفْصَةُ‏.‏\hadithno{4915}\hadithtrans{Narrated Ibn `Abbas:I intended to ask `Umar about those two ladies who back each other against 'Allah's Messenger (ﷺ) . For one year I was seeking the opportunity to ask this question, but in vain, until once when I accompanied him for Hajj. While we were in Zahran, `Umar went to answer the call of nature and told me to follow him with some water for ablution. So I followed him with a container of water and started pouring water for him. I found it a good opportunity to ask him, so I said, "O chief of the Believers! Who were those two ladies who had backed each other (against the Prophet)?" Before I could complete my question, he replied, "They were `Aisha and Hafsa}}
\hadithdefcmd{bukhari}{4916}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ عُمَرُ ـ رضى الله عنه ـ اجْتَمَعَ نِسَاءُ النَّبِيِّ صلى الله عليه وسلم فِي الْغَيْرَةِ عَلَيْهِ فَقُلْتُ لَهُنَّ عَسَى رَبُّهُ إِنْ طَلَّقَكُنَّ أَنْ يُبَدِّلَهُ أَزْوَاجًا خَيْرًا مِنْكُنَّ‏.‏ فَنَزَلَتْ هَذِهِ الآيَةُ‏.‏\hadithno{4916}\hadithtrans{Narrated `Umar:The wives of the Prophet (ﷺ) out of their jealousy, backed each other against the Prophet, so I said to them, "It may be, if he divorced you all, that Allah will give him, instead of you wives better than you." So this Verse was revealed}}
\hadithdefcmd{bukhari}{4917}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي حَصِينٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏عُتُلٍّ بَعْدَ ذَلِكَ زَنِيمٍ‏\}‏ قَالَ رَجُلٌ مِنْ قُرَيْشٍ لَهُ زَنَمَةٌ مِثْلُ زَنَمَةِ الشَّاةِ‏.‏\hadithno{4917}\hadithtrans{Narrated Ibn `Abbas:(regarding the Verse):-- 'Cruel after all that, base-born (of illegitimate birth).' (68.13) It was revealed in connection with a man from Quaraish who had a notable sign (Zanamah) similar to the notable sign which usually-hung on the neck of a sheep (to recognize it)}}
\hadithdefcmd{bukhari}{4918}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، قَالَ سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ الْخُزَاعِيَّ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِأَهْلِ الْجَنَّةِ كُلُّ ضَعِيفٍ مُتَضَعِّفٍ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ، أَلاَ أُخْبِرُكُمْ بِأَهْلِ النَّارِ كُلُّ عُتُلٍّ جَوَّاظٍ مُسْتَكْبِرٍ ‏"‏‏.‏\hadithno{4918}\hadithtrans{Narrated Haritha bin Wahb Al-Khuza`i:I heard the Prophet (ﷺ) saying. "May I tell you of the people of Paradise? Every weak and poor obscure person whom the people look down upon but his oath is fulfilled by Allah when he takes an oath to do something. And may I inform you of the people of the Hell-Fire? They are all those violent, arrogant and stubborn people}}
\hadithdefcmd{bukhari}{4919}{حَدَّثَنَا آدَمُ، حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَكْشِفُ رَبُّنَا عَنْ سَاقِهِ فَيَسْجُدُ لَهُ كُلُّ مُؤْمِنٍ وَمُؤْمِنَةٍ، وَيَبْقَى مَنْ كَانَ يَسْجُدُ فِي الدُّنْيَا رِئَاءً وَسُمْعَةً، فَيَذْهَبُ لِيَسْجُدَ فَيَعُودُ ظَهْرُهُ طَبَقًا وَاحِدًا ‏"‏‏.‏\hadithno{4919}\hadithtrans{Narrated Abu Sa`id:I heard the Prophet (ﷺ) saying, "Our Lord Allah will lay bare His Shin, and then all the Believers, men and women, will prostrate themselves before Him, but there will remain those who used to prostrate in the world for showing off and for gaining good reputation. Such people will try to prostrate (on the Day of Judgment) but their back swill be as stiff as if it is one bone (a single vertebra)}}
\hadithdefcmd{bukhari}{4920}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، وَقَالَ، عَطَاءٌ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ صَارَتِ الأَوْثَانُ الَّتِي كَانَتْ فِي قَوْمِ نُوحٍ فِي الْعَرَبِ بَعْدُ، أَمَّا وُدٌّ كَانَتْ لِكَلْبٍ بِدَوْمَةِ الْجَنْدَلِ، وَأَمَّا سُوَاعٌ كَانَتْ لِهُذَيْلٍ، وَأَمَّا يَغُوثُ فَكَانَتْ لِمُرَادٍ ثُمَّ لِبَنِي غُطَيْفٍ بِالْجُرُفِ عِنْدَ سَبَا، وَأَمَّا يَعُوقُ فَكَانَتْ لِهَمْدَانَ، وَأَمَّا نَسْرٌ فَكَانَتْ لِحِمْيَرَ، لآلِ ذِي الْكَلاَعِ‏.‏ أَسْمَاءُ رِجَالٍ صَالِحِينَ مِنْ قَوْمِ نُوحٍ، فَلَمَّا هَلَكُوا أَوْحَى الشَّيْطَانُ إِلَى قَوْمِهِمْ أَنِ انْصِبُوا إِلَى مَجَالِسِهِمُ الَّتِي كَانُوا يَجْلِسُونَ أَنْصَابًا، وَسَمُّوهَا بِأَسْمَائِهِمْ فَفَعَلُوا فَلَمْ تُعْبَدْ حَتَّى إِذَا هَلَكَ أُولَئِكَ وَتَنَسَّخَ الْعِلْمُ عُبِدَتْ‏.‏\hadithno{4920}\hadithtrans{Narrated Ibn `Abbas:All the idols which were worshiped by the people of Noah were worshiped by the Arabs later on. As for the idol Wadd, it was worshiped by the tribe of Kalb at Daumat-al-Jandal; Suwa` was the idol of (the tribe of) Hudhail; Yaghouth was worshiped by (the tribe of) Murad and then by Bani Ghutaif at Al-Jurf near Saba; Ya`uq was the idol of Hamdan, and Nasr was the idol of Himyar, the branch of Dhi-al-Kala`. The names (of the idols) formerly belonged to some pious men of the people of Noah, and when they died Satan inspired their people to (prepare and place idols at the places where they used to sit, and to call those idols by their names. The people did so, but the idols were not worshiped till those people (who initiated them) had died and the origin of the idols had become obscure, whereupon people began worshiping them}}
\hadithdefcmd{bukhari}{4921}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ انْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي طَائِفَةٍ مِنْ أَصْحَابِهِ عَامِدِينَ إِلَى سُوقِ عُكَاظٍ، وَقَدْ حِيلَ بَيْنَ الشَّيَاطِينِ وَبَيْنَ خَبَرِ السَّمَاءِ، وَأُرْسِلَتْ عَلَيْهِمُ الشُّهُبُ فَرَجَعَتِ الشَّيَاطِينُ فَقَالُوا مَا لَكُمْ فَقَالُوا حِيلَ بَيْنَنَا وَبَيْنَ خَبَرِ السَّمَاءِ وَأُرْسِلَتْ عَلَيْنَا الشُّهُبُ‏.‏ قَالَ مَا حَالَ بَيْنَكُمْ وَبَيْنَ خَبَرِ السَّمَاءِ إِلاَّ مَا حَدَثَ، فَاضْرِبُوا مَشَارِقَ الأَرْضِ وَمَغَارِبَهَا فَانْظُرُوا مَا هَذَا الأَمْرُ الَّذِي حَدَثَ‏.‏ فَانْطَلَقُوا فَضَرَبُوا مَشَارِقَ الأَرْضِ وَمَغَارِبَهَا يَنْظُرُونَ مَا هَذَا الأَمْرُ الَّذِي حَالَ بَيْنَهُمْ وَبَيْنَ خَبَرِ السَّمَاءِ‏.‏ قَالَ فَانْطَلَقَ الَّذِينَ تَوَجَّهُوا نَحْوَ تِهَامَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِنَخْلَةَ، وَهْوَ عَامِدٌ إِلَى سُوقِ عُكَاظٍ، وَهْوَ يُصَلِّي بِأَصْحَابِهِ صَلاَةَ الْفَجْرِ، فَلَمَّا سَمِعُوا الْقُرْآنَ تَسَمَّعُوا لَهُ فَقَالُوا هَذَا الَّذِي حَالَ بَيْنَكُمْ وَبَيْنَ خَبَرِ السَّمَاءِ‏.‏ فَهُنَالِكَ رَجَعُوا إِلَى قَوْمِهِمْ فَقَالُوا يَا قَوْمَنَا إِنَّا سَمِعْنَا قُرْآنًا عَجَبًا يَهْدِي إِلَى الرُّشْدِ فَآمَنَّا بِهِ، وَلَنْ نُشْرِكَ بِرَبِّنَا أَحَدًا‏.‏ وَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ عَلَى نَبِيِّهِ صلى الله عليه وسلم ‏\{‏قُلْ أُوحِيَ إِلَىَّ أَنَّهُ اسْتَمَعَ نَفَرٌ مِنَ الْجِنِّ‏\}‏ وَإِنَّمَا أُوحِيَ إِلَيْهِ قَوْلُ الْجِنِّ‏.‏\hadithno{4921}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) went out along with a group of his companions towards `Ukaz Market. At that time something intervened between the devils and the news of the Heaven, and flames were sent down upon them, so the devils returned. Their fellow-devils said, "What is wrong with you? " They said, "Something has intervened between us and the news of the Heaven, and fires (flames) have been shot at us." Their fellow-devils said, "Nothing has intervened between you and the news of the Heaven, but an important event has happened. Therefore, travel all over the world, east and west, and try to find out what has happened." And so they set out and travelled all over the world, east and west, looking for that thing which intervened between them and the news of the Heaven. Those of the devils who had set out towards Tihama, went to Allah's Messenger (ﷺ) at Nakhla (a place between Mecca and Taif) while he was on his way to `Ukaz Market. (They met him) while he was offering the Fajr prayer with his companions. When they heard the Holy Qur'an being recited (by Allah's Messenger (ﷺ)), they listened to it and said (to each other). This is the thing which has intervened between you and the news of the Heavens." Then they returned to their people and said, "O our people! We have really heard a wonderful recital (Qur'an). It gives guidance to the right, and we have believed therein. We shall not join in worship, anybody with our Lord." (See 72.1-2) Then Allah revealed to His Prophet (Surat al- Jinn): 'Say: It has been revealed to me that a group (3 to 9) of Jinns listened (to the Qur'an).' (72.1) The statement of the Jinns was revealed to him}}
\hadithdefcmd{bukhari}{4922}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، سَأَلْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ عَنْ أَوَّلِ، مَا نَزَلَ مِنَ الْقُرْآنِ‏.‏ قَالَ ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ‏\}‏ قُلْتُ يَقُولُونَ ‏\{‏اقْرَأْ بِاسْمِ رَبِّكَ الَّذِي خَلَقَ‏\}‏ فَقَالَ أَبُو سَلَمَةَ سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ رضى الله عنهما عَنْ ذَلِكَ وَقُلْتُ لَهُ مِثْلَ الَّذِي قُلْتَ فَقَالَ جَابِرٌ لاَ أُحَدِّثُكَ إِلاَّ مَا حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ جَاوَرْتُ بِحِرَاءٍ، فَلَمَّا قَضَيْتُ جِوَارِي هَبَطْتُ فَنُودِيتُ فَنَظَرْتُ عَنْ يَمِينِي فَلَمْ أَرَ شَيْئًا، وَنَظَرْتُ عَنْ شِمَالِي فَلَمْ أَرَ شَيْئًا، وَنَظَرْتُ أَمَامِي فَلَمْ أَرَ شَيْئًا، وَنَظَرْتُ خَلْفِي فَلَمْ أَرَ شَيْئًا، فَرَفَعْتُ رَأْسِي فَرَأَيْتُ شَيْئًا، فَأَتَيْتُ خَدِيجَةَ فَقُلْتُ دَثِّرُونِي وَصُبُّوا عَلَىَّ مَاءً بَارِدًا ـ قَالَ ـ فَدَثَّرُونِي وَصَبُّوا عَلَىَّ مَاءً بَارِدًا قَالَ فَنَزَلَتْ ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ * قُمْ فَأَنْذِرْ * وَرَبَّكَ فَكَبِّرْ‏\}‏ ‏"‏‏.‏\hadithno{4922}\hadithtrans{Narrated Yahya bin Abi Kathir:I asked Aba Salama bin `Abdur-Rahman about the first Sura revealed of the Qur'an. He replied "O you, wrapped-up (i.e. Al Muddaththir)." I said, "They say it was, 'Read, in the Name of your Lord Who created,' (i.e. Surat Al-`Alaq (the Clot)." On that, Abu Salama said, "I asked Jabir bin `Abdullah about that, saying the same as you have said, whereupon he said, 'I will not tell you except what Allah's Messenger (ﷺ) had told us. Allah's Messenger (ﷺ) said, "I was in seclusion in the cave of Hiram', and after I completed the limited period of my seclusion. I came down (from the cave) and heard a voice calling me. I looked to my right, but saw nothing. Then I looked up and saw something. So I went to Khadija (the Prophet's wife) and told her to wrap me up and pour cold water on me. So they wrapped me up and poured cold water on me." Then, 'O you, (Muhammad) wrapped up! Arise and warn,' (Surat Al Muddaththir) was revealed}}
\hadithdefcmd{bukhari}{4923}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَغَيْرُهُ، قَالاَ حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، رضى الله عنهما عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ جَاوَرْتُ بِحِرَاءٍ ‏"‏‏.‏ مِثْلَ حَدِيثِ عُثْمَانَ بْنِ عُمَرَ عَنْ عَلِيِّ بْنِ الْمُبَارَكِ‏.‏\hadithno{4923}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "I was in a seclusion in the cave of Hira........."(similar to the narration related by `Ali bin Al-Mubarak, 444 above)}}
\hadithdefcmd{bukhari}{4924}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَرْبٌ، حَدَّثَنَا يَحْيَى، قَالَ سَأَلْتُ أَبَا سَلَمَةَ أَىُّ الْقُرْآنِ أُنْزِلَ أَوَّلُ فَقَالَ ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ‏\}‏ فَقُلْتُ أُنْبِئْتُ أَنَّهُ ‏\{‏اقْرَأْ بِاسْمِ رَبِّكَ الَّذِي خَلَقَ‏\}‏ فَقَالَ أَبُو سَلَمَةَ سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ أَىُّ الْقُرْآنِ أُنْزِلَ أَوَّلُ فَقَالَ ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ‏\}‏ فَقُلْتُ أُنْبِئْتُ أَنَّهُ ‏\{‏اقْرَأْ بِاسْمِ رَبِّكَ‏\}‏ فَقَالَ لاَ أُخْبِرُكَ إِلاَّ بِمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ جَاوَرْتُ فِي حِرَاءٍ فَلَمَّا قَضَيْتُ جِوَارِي، هَبَطْتُ فَاسْتَبْطَنْتُ الْوَادِيَ فَنُودِيتُ، فَنَظَرْتُ أَمَامِي وَخَلْفِي وَعَنْ يَمِينِي وَعَنْ شِمَالِي فَإِذَا هُوَ جَالِسٌ عَلَى عَرْشٍ بَيْنَ السَّمَاءِ وَالأَرْضِ، فَأَتَيْتُ خَدِيجَةَ فَقُلْتُ دَثِّرُونِي وَصُبُّوا عَلَىَّ مَاءً بَارِدًا، وَأُنْزِلَ عَلَىَّ ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ * قُمْ فَأَنْذِرْ * وَرَبَّكَ فَكَبِّرْ‏\}‏‏"‏\hadithno{4924}\hadithtrans{Narrated Yahya:I asked Aba Salama, "Which Sura of the Qur'an was revealed first?" He replied, "O you, wrapped-up' (Al-Muddaththir)." I said, "I have been informed that it was, 'Read, in the Name of your Lord who created (i.e. Surat Al-Alaq)...similar to the narration related by `Ali bin Al-Mubarak, 444 above}}
\hadithdefcmd{bukhari}{4925}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ،‏.‏ وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، فَأَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم وَهْوَ يُحَدِّثُ عَنْ فَتْرَةِ الْوَحْىِ فَقَالَ فِي حَدِيثِهِ ‏"‏ فَبَيْنَا أَنَا أَمْشِي إِذْ سَمِعْتُ صَوْتًا مِنَ السَّمَاءِ فَرَفَعْتُ رَأْسِي فَإِذَا الْمَلَكُ الَّذِي جَاءَنِي بِحِرَاءٍ جَالِسٌ عَلَى كُرْسِيٍّ بَيْنَ السَّمَاءِ وَالأَرْضِ، فَجَئِثْتُ مِنْهُ رُعْبًا فَرَجَعْتُ فَقُلْتُ زَمِّلُونِي زَمِّلُونِي‏.‏ فَدَثَّرُونِي فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ‏\}‏ إِلَى ‏\{‏وَالرِّجْزَ فَاهْجُرْ‏\}‏ ـ قَبْلَ أَنْ تُفْرَضَ الصَّلاَةُ ـ وَهْىَ الأَوْثَانُ ‏"‏‏.‏\hadithno{4925}\hadithtrans{Narrated Jabir bin `Abdullah:I heard the Prophet (ﷺ) describing the period of pause of the Divine Inspiration. He said in his talk, "While I was walking, I heard voices from the sky. I looked up, and behold ! I saw the same Angel who came to me in the cave of Hira' sitting on a chair between the sky and the earth. I was too much afraid of him (so I returned to my house) and said, 'Fold me up in garments!' They wrapped me up. Then Allah revealed: 'O you wrapped...and desert the idols before the prayer became compulsory.' Rujz means idols}}
\hadithdefcmd{bukhari}{4926}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، قَالَ ابْنُ شِهَابٍ سَمِعْتُ أَبَا سَلَمَةَ، قَالَ أَخْبَرَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُحَدِّثُ عَنْ فَتْرَةِ الْوَحْىِ ‏"‏ فَبَيْنَا أَنَا أَمْشِي سَمِعْتُ صَوْتًا مِنَ السَّمَاءِ فَرَفَعْتُ بَصَرِي قِبَلَ السَّمَاءِ، فَإِذَا الْمَلَكُ الَّذِي جَاءَنِي بِحِرَاءٍ قَاعِدٌ عَلَى كُرْسِيٍّ بَيْنَ السَّمَاءِ وَالأَرْضِ، فَجَئِثْتُ مِنْهُ حَتَّى هَوَيْتُ إِلَى الأَرْضِ، فَجِئْتُ أَهْلِي فَقُلْتُ زَمِّلُونِي زَمِّلُونِي‏.‏ فَزَمَّلُونِي فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ‏\}‏ إِلَى قَوْلِهِ ‏\{‏فَاهْجُرْ‏\}‏ ‏"‏ ـ قَالَ أَبُو سَلَمَةَ وَالرِّجْزَ الأَوْثَانَ ـ ‏"‏ ثُمَّ حَمِيَ الْوَحْىُ وَتَتَابَعَ ‏"‏‏.‏\hadithno{4926}\hadithtrans{Narrated Jabir bin `Abdullah:That he heard Allah's Messenger (ﷺ) describing the period of pause of the Divine Inspiration, and in his description he said, "While I was walking I heard a voice from the sky. I looked up towards the sky, and behold! I saw the same Angel who came to me in the Cave of Hira', sitting on a chair between the sky and the earth. I was so terrified by him that I fell down on the ground. Then I went to my wife and said, 'Wrap me in garments! Wrap me in garments!' They wrapped me, and then Allah revealed: "O you, (Muhammad) wrapped-up! Arise and warn...and desert the idols." (74.1-5) Abu Salama said....Rujz means idols." After that, the Divine Inspiration started coming more frequently and regularly}}
\hadithdefcmd{bukhari}{4927}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مُوسَى بْنُ أَبِي عَائِشَةَ ـ وَكَانَ ثِقَةً ـ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا نَزَلَ عَلَيْهِ الْوَحْىُ حَرَّكَ بِهِ لِسَانَهُ ـ وَوَصَفَ سُفْيَانُ ـ يُرِيدُ أَنْ يَحْفَظَهُ فَأَنْزَلَ اللَّهُ ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ‏\}‏\hadithno{4927}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) used to move his tongue when the divine Inspiration was being revealed to him. (Sufyan, a subnarrator, demonstrated (how the Prophet (ﷺ) used to move his lips) and added. "In order to memorize it." So Allah revealed: "Move not your tongue concerning (the Qur'an) to make haste therewith}}
\hadithdefcmd{bukhari}{4928}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، أَنَّهُ سَأَلَ سَعِيدَ بْنَ جُبَيْرٍ عَنْ قَوْلِهِ تَعَالَى ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ‏\}‏ قَالَ وَقَالَ ابْنُ عَبَّاسٍ كَانَ يُحَرِّكُ شَفَتَيْهِ إِذَا أُنْزِلَ عَلَيْهِ، فَقِيلَ لَهُ ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ‏\}‏ ـ يَخْشَى أَنْ يَنْفَلِتَ مِنْهُ ـ ‏\{‏إِنَّ عَلَيْنَا جَمْعَهُ وَقُرْآنَهُ‏\}‏ أَنْ نَجْمَعَهُ فِي صَدْرِكَ، وَقُرْآنَهُ أَنْ تَقْرَأَهُ ‏\{‏فَإِذَا قَرَأْنَاهُ‏\}‏ يَقُولُ أُنْزِلَ عَلَيْهِ ‏\{‏فَاتَّبِعْ قُرْآنَهُ * ثُمَّ إِنَّ عَلَيْنَا بَيَانَهُ‏\}‏ أَنْ نُبَيِّنَهُ عَلَى لِسَانِكَ‏.‏\hadithno{4928}\hadithtrans{Narrated Musa bin Abi Aisha:That he asked Sa`id bin Jubair regarding (the statement of Allah). 'Move not your tongue concerning (the Qur'an) to make haste therewith.' He said, "Ibn `Abbas said that the Prophet (ﷺ) used to move his lips when the Divine Inspiration was being revealed to him. So the Prophet (ﷺ) was ordered not to move his tongue, which he used to do, lest some words should escape his memory. 'It is for Us to collect it' means, We will collect it in your chest;' and its recitation' means, We will make you recite it. 'But when We recite it (i.e. when it is revealed to you), follow its recital; it is for Us to explain it and make it clear,' (i.e. We will explain it through your tongue)}}
\hadithdefcmd{bukhari}{4929}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ‏\}‏ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا نَزَلَ جِبْرِيلُ بِالْوَحْىِ، وَكَانَ مِمَّا يُحَرِّكُ بِهِ لِسَانَهُ وَشَفَتَيْهِ فَيَشْتَدُّ عَلَيْهِ وَكَانَ يُعْرَفُ مِنْهُ، فَأَنْزَلَ اللَّهُ الآيَةَ الَّتِي فِي ‏\{‏لاَ أُقْسِمُ بِيَوْمِ الْقِيَامَةِ‏\}‏ ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ * إِنَّ عَلَيْنَا جَمْعَهُ وَقُرْآنَهُ‏\}‏ قَالَ عَلَيْنَا أَنْ نَجْمَعَهُ فِي صَدْرِكَ، وَقُرْآنَهُ ‏\{‏فَإِذَا قَرَأْنَاهُ فَاتَّبِعْ قُرْآنَهُ‏\}‏ فَإِذَا أَنْزَلْنَاهُ فَاسْتَمِعْ ‏\{‏ثُمَّ إِنَّ عَلَيْنَا بَيَانَهُ‏\}‏ عَلَيْنَا أَنْ نُبَيِّنَهُ بِلِسَانِكَ ـ قَالَ ـ فَكَانَ إِذَا أَتَاهُ جِبْرِيلُ أَطْرَقَ، فَإِذَا ذَهَبَ قَرَأَهُ كَمَا وَعَدَهُ اللَّهُ‏.‏ ‏\{‏أَوْلَى لَكَ فَأَوْلَى‏\}‏ تَوَعُّدٌ‏.‏\hadithno{4929}\hadithtrans{Narrated Ibn `Abbas:(as regards) Allah's Statement: "Move not your tongue concerning (the Qur'an) to make haste therewith." (75.16) When Gabriel revealed the Divine Inspiration in Allah's Messenger (ﷺ) , he (Allah's Messenger (ﷺ)) moved his tongue and lips, and that state used to be very hard for him, and that movement indicated that revelation was taking place. So Allah revealed in Surat Al-Qiyama which begins: 'I do swear by the Day of Resurrection...' (75) the Verses:-- 'Move not your tongue concerning (the Qur'an) to make haste therewith. It is for Us to collect it (Qur'an) in your mind, and give you the ability to recite it by heart. (75.16-17) Ibn `Abbas added: It is for Us to collect it (Qur'an) (in your mind), and give you the ability to recite it by heart means, "When We reveal it, listen. Then it is for Us to explain it," means, 'It is for us to explain it through your tongue.' So whenever Gabriel came to Allah's Messenger (ﷺ) ' he would keep quiet (and listen), and when the Angel left, the Prophet (ﷺ) would recite that revelation as Allah promised him}}
\hadithdefcmd{bukhari}{4930}{حَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأُنْزِلَتْ عَلَيْهِ وَالْمُرْسَلاَتِ، وَإِنَّا لَنَتَلَقَّاهَا مِنْ فِيهِ فَخَرَجَتْ حَيَّةٌ، فَابْتَدَرْنَاهَا فَسَبَقَتْنَا فَدَخَلَتْ جُحْرَهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وُقِيَتْ شَرَّكُمْ، كَمَا وُقِيتُمْ شَرَّهَا ‏"‏‏.‏\hadithno{4930}\hadithtrans{Narrated `Abdullah:We were with the Prophet (ﷺ) when Surat Wal-Mursalat was revealed to him. While we were receiving it from his mouth, a snake suddenly came and we ran to kill it, but it outstripped us and entered its hole quickly. Allah's le said, "It has escaped your evil, and you too, have escaped its evil}}
\hadithdefcmd{bukhari}{4931}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، عَنْ مَنْصُورٍ، بِهَذَا‏.‏ وَعَنْ إِسْرَائِيلَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، مِثْلَهُ‏.‏ وَتَابَعَهُ أَسْوَدُ بْنُ عَامِرٍ عَنْ إِسْرَائِيلَ،‏.‏ وَقَالَ حَفْصٌ وَأَبُو مُعَاوِيَةَ وَسُلَيْمَانُ بْنُ قَرْمٍ عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ،‏.‏ قَالَ يَحْيَى بْنُ حَمَّادٍ أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ،‏.‏ وَقَالَ ابْنُ إِسْحَاقَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ\hadithno{4931}\hadithtrans{Narrated `Abdullah:(Similarly--as no. 452 above)}}
\hadithdefcmd{bukhari}{4931p2}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالَ قَالَ عَبْدُ اللَّهِ بَيْنَا نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَارٍ إِذْ نَزَلَتْ عَلَيْهِ وَالْمُرْسَلاَتِ فَتَلَقَّيْنَاهَا مِنْ فِيهِ وَإِنَّ فَاهُ لَرَطْبٌ بِهَا إِذْ خَرَجَتْ حَيَّةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَلَيْكُمُ اقْتُلُوهَا ‏"‏‏.‏ قَالَ فَابْتَدَرْنَاهَا فَسَبَقَتْنَا ـ قَالَ ـ فَقَالَ ‏"‏ وُقِيَتْ شَرَّكُمْ، كَمَا وُقِيتُمْ شَرَّهَا ‏"‏‏.‏\hadithno{4931.2}\hadithtrans{Narrated `Abdullah:While we were with Allah's Messenger (ﷺ) in a cave, Surat "Wal Mursalat" was revealed to him and we received it directly from his mouth as soon as he had received the revelation. Suddenly a snake came out and Allah's Messenger (ﷺ) said, "Get at it and kill it!" We ran to kill it but it outstripped us. Allah's Apostle said, "It has escaped your evil, as you too, have escaped its}}
\hadithdefcmd{bukhari}{4932}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَابِسٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، إِنَّهَا تَرْمِي بِشَرَرٍ كَالْقَصْرِ قَالَ كُنَّا نَرْفَعُ الْخَشَبَ بِقَصَرٍ ثَلاَثَةَ أَذْرُعٍ أَوْ أَقَلَّ، فَنَرْفَعُهُ لِلشِّتَاءِ فَنُسَمِّيهِ الْقَصَرَ‏.‏\hadithno{4932}\hadithtrans{Narrated Ibn `Abbas:(as regards the explanation of Hadith 454). 'Indeed, it (Hell) throws about sparks (huge) as Forts.' We used to collect wood in the form of logs, three cubits long or shorter. for heating purposes in winter., and we used to call such wood, the Qasr}}
\hadithdefcmd{bukhari}{4933}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَابِسٍ، سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏تَرْمِي بِشَرَرٍ‏\}‏ كُنَّا نَعْمِدُ إِلَى الْخَشَبَةِ ثَلاَثَةَ أَذْرُعٍ وَفَوْقَ ذَلِكَ، فَنَرْفَعُهُ لِلشِّتَاءِ فَنُسَمِّيهِ الْقَصَرَ‏.‏ ‏\{‏كَأَنَّهُ جِمَالاَتٌ صُفْرٌ‏\}‏ حِبَالُ السُّفْنِ تُجْمَعُ حَتَّى تَكُونَ كَأَوْسَاطِ الرِّجَالِ‏.‏\hadithno{4933}\hadithtrans{Narrated Ibn 'Abbas: (regarding) the explanation of "... It throws sparks as Al-Qasr ..." (V. 77:32): We used to collect logs of wood, three cubits long or longer, to store for heating purposes in winter, and we used to call it Al- Qasr, it also means a castle or a fort. "As if they were Jimalatun Sufr (yellow camels or bundles of ropes)" (V.77:33): means the ropes of a ship which are made in bundles till it become as wide as men's waists}}
\hadithdefcmd{bukhari}{4934}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ بَيْنَمَا نَحْنُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي غَارٍ إِذْ نَزَلَتْ عَلَيْهِ وَالْمُرْسَلاَتِ، فَإِنَّهُ لَيَتْلُوهَا وَإِنِّي لأَتَلَقَّاهَا مِنْ فِيهِ وَإِنَّ فَاهُ لَرَطْبٌ بِهَا، إِذْ وَثَبَتْ عَلَيْنَا حَيَّةٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اقْتُلُوهَا ‏"‏‏.‏ فَابْتَدَرْنَاهَا فَذَهَبَتْ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وُقِيَتْ شَرَّكُمْ، كَمَا وُقِيتُمْ شَرَّهَا ‏"‏‏.‏ قَالَ عُمَرُ حَفِظْتُهُ مِنْ أَبِي فِي غَارٍ بِمِنًى‏.‏\hadithno{4934}\hadithtrans{Narrated `Abdullah:While we were with the Prophet (ﷺ) in a cave, Surat wal-Mursalat was revealed to him and he recited it, and I heard it directly from his mouth as soon as he recited its revelation. Suddenly a snake sprang at us, and the Prophet (ﷺ) said, "Kill it!" We ran to kill it but it escaped quickly. The Prophet (ﷺ) said. "It has escaped your evil, and you too have escaped its evil}}
\hadithdefcmd{bukhari}{4935}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا بَيْنَ النَّفْخَتَيْنِ أَرْبَعُونَ ‏"‏‏.‏ قَالَ أَرْبَعُونَ يَوْمًا قَالَ أَبَيْتُ‏.‏ قَالَ أَرْبَعُونَ شَهْرًا قَالَ أَبَيْتُ‏.‏ قَالَ أَرْبَعُونَ سَنَةً قَالَ أَبَيْتُ‏.‏ قَالَ ‏"‏ ثُمَّ يُنْزِلُ اللَّهُ مِنَ السَّمَاءِ مَاءً‏.‏ فَيَنْبُتُونَ كَمَا يَنْبُتُ الْبَقْلُ لَيْسَ مِنَ الإِنْسَانِ شَىْءٌ إِلاَّ يَبْلَى إِلاَّ عَظْمًا وَاحِدًا وَهْوَ عَجْبُ الذَّنَبِ، وَمِنْهُ يُرَكَّبُ الْخَلْقُ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{4935}\hadithtrans{Narrated Al--A`mash:Abu Huraira said, "Allah's Messenger (ﷺ) said, 'Between the two sounds of the trumpet, there will be forty." Somebody asked Abu Huraira, "Forty days?" But he refused to reply. Then he asked, "Forty months?" He refused to reply. Then he asked, "Forty years?" Again, he refused to reply. Abu Huraira added. "Then (after this period) Allah will send water from the sky and then the dead bodies will grow like vegetation grows, There is nothing of the human body that does not decay except one bone; that is the little bone at the end of the coccyx of which the human body will be recreated on the Day of Resurrection." (See Hadith No)}}
\hadithdefcmd{bukhari}{4936}{حَدَّثَنَا أَحْمَدُ بْنُ الْمِقْدَامِ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا أَبُو حَازِمٍ، حَدَّثَنَا سَهْلُ بْنُ سَعْدٍ ـ رضى الله عنه ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ بِإِصْبَعَيْهِ هَكَذَا بِالْوُسْطَى وَالَّتِي تَلِي الإِبْهَامَ ‏ "‏ بُعِثْتُ وَالسَّاعَةَ كَهَاتَيْنِ ‏"‏‏.‏\hadithno{4936}\hadithtrans{Narrated Sahl bin Sa`d:I saw Allah's Messenger (ﷺ) pointing with his index and middle fingers, saying. "The time of my Advent and the Hour are like these two fingers}}
\hadithdefcmd{bukhari}{4937}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا قَتَادَةُ، قَالَ سَمِعْتُ زُرَارَةَ بْنَ أَوْفَى، يُحَدِّثُ عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الَّذِي يَقْرَأُ الْقُرْآنَ وَهْوَ حَافِظٌ لَهُ مَعَ السَّفَرَةِ الْكِرَامِ الْبَرَرَةِ، وَمَثَلُ الَّذِي يَقْرَأُ الْقُرْآنَ وَهْوَ يَتَعَاهَدُهُ وَهْوَ عَلَيْهِ شَدِيدٌ، فَلَهُ أَجْرَانِ ‏"‏‏.‏\hadithno{4937}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) said, "Such a person as recites the Qur'an and masters it by heart, will be with the noble righteous scribes (in Heaven). And such a person exerts himself to learn the Qur'an by heart, and recites it with great difficulty, will have a double reward}}
\hadithdefcmd{bukhari}{4938}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ ‏\{‏يَوْمَ يَقُومُ النَّاسُ لِرَبِّ الْعَالَمِينَ‏\}‏ حَتَّى يَغِيبَ أَحَدُهُمْ فِي رَشْحِهِ إِلَى أَنْصَافِ أُذُنَيْهِ ‏"‏‏.‏\hadithno{4938}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "On the Day when all mankind will stand before the Lord of the Worlds, some of them will be enveloped in their sweat up to the middle of their ears}}
\hadithdefcmd{bukhari}{4939}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، عَنْ عُثْمَانَ بْنِ الأَسْوَدِ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ أَبِي يُونُسَ، حَاتِمِ بْنِ أَبِي صَغِيرَةَ عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ أَحَدٌ يُحَاسَبُ إِلاَّ هَلَكَ ‏"‏‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ جَعَلَنِي اللَّهُ فِدَاءَكَ، أَلَيْسَ يَقُولُ اللَّهُ عَزَّ وَجَلَّ ‏\{‏فَأَمَّا مَنْ أُوتِيَ كِتَابَهُ بِيَمِينِهِ * فَسَوْفَ يُحَاسَبُ حِسَابًا يَسِيرًا‏\}‏‏.‏ قَالَ ‏"‏ ذَاكَ الْعَرْضُ يُعْرَضُونَ، وَمَنْ نُوقِشَ الْحِسَابَ هَلَكَ ‏"‏‏.‏\hadithno{4939}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) said," (On the Day of Resurrection) any one whose account will be taken will be ruined (i.e. go to Hell)." I said, "O Allah's Messenger (ﷺ)! May Allah make me be sacrificed for you. Doesn't Allah say: "Then as for him who will be given his record in his right hand, he surely will receive an easy reckoning.?" (84.7-8) He replied, "That is only the presentation of the accounts; but he whose record is questioned, will be ruined." (This hadith is also narrated through two other chains)}}
\hadithdefcmd{bukhari}{4940}{حَدَّثَنَا سَعِيدُ بْنُ النَّضْرِ، أَخْبَرَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، جَعْفَرُ بْنُ إِيَاسٍ عَنْ مُجَاهِدٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ ‏\{‏لَتَرْكَبُنَّ طَبَقًا عَنْ طَبَقٍ‏\}‏ حَالاً بَعْدَ حَالٍ، قَالَ هَذَا نَبِيُّكُمْ صلى الله عليه وسلم‏.‏\hadithno{4940}\hadithtrans{Narrated Ibn `Abbas:(as regards the Verse):--'You shall surely travel from stage to stage (in this life and in the Hereafter).' (It means) from one state to another. That concerns your Prophet}}
\hadithdefcmd{bukhari}{4941}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ أَوَّلُ مَنْ قَدِمَ عَلَيْنَا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مُصْعَبُ بْنُ عُمَيْرٍ وَابْنُ أُمِّ مَكْتُومٍ فَجَعَلاَ يُقْرِئَانِنَا الْقُرْآنَ، ثُمَّ جَاءَ عَمَّارٌ وَبِلاَلٌ وَسَعْدٌ ثُمَّ جَاءَ عُمَرُ بْنُ الْخَطَّابِ فِي عِشْرِينَ ثُمَّ جَاءَ النَّبِيُّ صلى الله عليه وسلم فَمَا رَأَيْتُ أَهْلَ الْمَدِينَةِ فَرِحُوا بِشَىْءٍ فَرَحَهُمْ بِهِ، حَتَّى رَأَيْتُ الْوَلاَئِدَ وَالصِّبْيَانَ يَقُولُونَ هَذَا رَسُولُ اللَّهِ قَدْ جَاءَ‏.‏ فَمَا جَاءَ حَتَّى قَرَأْتُ ‏\{‏سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى‏\}‏ فِي سُوَرٍ مِثْلِهَا‏.‏\hadithno{4941}\hadithtrans{Narrated Al-Bara:The first of the companions of the Prophet (ﷺ) who came to us (in Medina), were Mus`ab bin `Umair and Ibn Um Maktum, and they started teaching us the Qur'an. Then came `Ammar, Bilal and Sa`d. Afterwards `Umar bin Al-Kkattab came along with a batch of twenty (men): and after that the Prophet (ﷺ) came. I never saw the people of Medina so pleased with anything as they were with his arrival, so that even the little boys and girls were saying, "This is Allah's Messenger (ﷺ) who has come." He (the Prophet (ﷺ) ) did not come (to Medina) till I had learnt Surat Al-Ala and also other similar Suras}}
\hadithdefcmd{bukhari}{4942}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ عَبْدُ اللَّهِ بْنُ زَمْعَةَ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ وَذَكَرَ النَّاقَةَ وَالَّذِي عَقَرَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏\{‏إِذِ انْبَعَثَ أَشْقَاهَا‏\}‏ انْبَعَثَ لَهَا رَجُلٌ عَزِيزٌ عَارِمٌ، مَنِيعٌ فِي رَهْطِهِ، مِثْلُ أَبِي زَمْعَةَ ‏"‏‏.‏ وَذَكَرَ النِّسَاءَ فَقَالَ ‏"‏ يَعْمِدُ أَحَدُكُمْ يَجْلِدُ امْرَأَتَهُ جَلْدَ الْعَبْدِ، فَلَعَلَّهُ يُضَاجِعُهَا مِنْ آخِرِ يَوْمِهِ ‏"‏‏.‏ ثُمَّ وَعَظَهُمْ فِي ضَحِكِهِمْ مِنَ الضَّرْطَةِ وَقَالَ ‏"‏ لِمَ يَضْحَكُ أَحَدُكُمْ مِمَّا يَفْعَلُ ‏"‏‏.‏ وَقَالَ أَبُو مُعَاوِيَةَ حَدَّثَنَا هِشَامٌ عَنْ أَبِيهِ عَنْ عَبْدِ اللَّهِ بْنِ زَمْعَةَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مِثْلُ أَبِي زَمْعَةَ عَمِّ الزُّبَيْرِ بْنِ الْعَوَّامِ ‏"‏‏.‏\hadithno{4942}\hadithtrans{Narrated `Abdullah bin Zama:That he heard the Prophet (ﷺ) delivering a sermon, and he mentioned the she-camel and the one who hamstrung it. Allah's Messenger (ﷺ) recited:-- 'When, the most wicked man among them went forth (to hamstrung the she-camel).' (91.12.) Then he said, "A tough man whose equal was rare and who enjoyed the protection of his people, like Abi Zama went forth to (hamstrung) it." The Prophet (ﷺ) then mentioned about the women (in his sermon). "It is not wise for anyone of you to lash his wife like a slave, for he might sleep with her the same evening." Then he advised them not to laugh when somebody breaks wind and said, "Why should anybody laugh at what he himself does?}}
\hadithdefcmd{bukhari}{4943}{حَدَّثَنَا قَبِيصَةُ بْنُ عُقْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ دَخَلْتُ فِي نَفَرٍ مِنْ أَصْحَابِ عَبْدِ اللَّهِ الشَّأْمَ فَسَمِعَ بِنَا أَبُو الدَّرْدَاءِ فَأَتَانَا فَقَالَ أَفِيكُمْ مَنْ يَقْرَأُ فَقُلْنَا نَعَمْ‏.‏ قَالَ فَأَيُّكُمْ أَقْرَأُ فَأَشَارُوا إِلَىَّ فَقَالَ اقْرَأْ‏.‏ فَقَرَأْتُ ‏\{‏وَاللَّيْلِ إِذَا يَغْشَى * وَالنَّهَارِ إِذَا تَجَلَّى * وَالذَّكَرِ وَالأُنْثَى‏\}‏‏.‏ قَالَ أَنْتَ سَمِعْتَهَا مِنْ فِي صَاحِبِكَ قُلْتُ نَعَمْ‏.‏ قَالَ وَأَنَا سَمِعْتُهَا مِنْ فِي النَّبِيِّ صلى الله عليه وسلم وَهَؤُلاَءِ يَأْبَوْنَ عَلَيْنَا‏.‏\hadithno{4943}\hadithtrans{Narrated Alqama:I went to Sham with a group of the companions of `Abdullah (bin Mas`ud). Abu Ad-Darda' heard of our arrival so he came to us and said, "Is there anybody among you who can recite (Qur'an)" We replied in the affirmative. Then he asked, "Who is the best reciter?" They pointed at me. Then he told me to recite, so I recited the verse:-- 'By the night as it envelops 'By the day as it appears in brightness; By (Him Who created) male and the female.' (92.1-3) Abu Ad-Darda' then said to me, "Did you hear it (like this) from the mouth of your friend (`Abdullah bin Mas`ud)?" I said, "Yes." He said, "I too, heard it (like this) from the mouth of the Prophet, but these people do not consider this recitation as the correct one}}
\hadithdefcmd{bukhari}{4944}{حَدَّثَنَا عُمَرُ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، قَالَ قَدِمَ أَصْحَابُ عَبْدِ اللَّهِ عَلَى أَبِي الدَّرْدَاءِ فَطَلَبَهُمْ فَوَجَدَهُمْ فَقَالَ أَيُّكُمْ يَقْرَأُ عَلَى قِرَاءَةِ عَبْدِ اللَّهِ قَالَ كُلُّنَا‏.‏ قَالَ فَأَيُّكُمْ يَحْفَظُ وَأَشَارُوا إِلَى عَلْقَمَةَ‏.‏ قَالَ كَيْفَ سَمِعْتَهُ يَقْرَأُ ‏\{‏وَاللَّيْلِ إِذَا يَغْشَى‏\}‏‏.‏ قَالَ عَلْقَمَةُ ‏\{‏وَالذَّكَرِ وَالأُنْثَى‏\}‏‏.‏ قَالَ أَشْهَدُ أَنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ هَكَذَا، وَهَؤُلاَءِ يُرِيدُونِي عَلَى أَنْ أَقْرَأَ ‏\{‏وَمَا خَلَقَ الذَّكَرَ وَالأُنْثَى‏\}‏ وَاللَّهِ لاَ أُتَابِعُهُمْ‏.‏\hadithno{4944}\hadithtrans{Narrated Ibrahim:The companions of `Abdullah (bin Mas`ud) came to Abu Darda', (and before they arrived at his home), he looked for them and found them. Then he asked them,: 'Who among you can recite (Qur'an) as `Abdullah recites it?" They replied, "All of us." He asked, "Who among you knows it by heart?" They pointed at 'Alqama. Then he asked Alqama. "How did you hear `Abdullah bin Mas`ud reciting Surat Al-Lail (The Night)?" Alqama recited: 'By the male and the female.' Abu Ad-Darda said, "I testify that I heard me Prophet reciting it likewise, but these people want me to recite it:-- 'And by Him Who created male and female.' but by Allah, I will not follow them}}
\hadithdefcmd{bukhari}{4945}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي بَقِيعِ الْغَرْقَدِ فِي جَنَازَةٍ فَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ وَقَدْ كُتِبَ مَقْعَدُهُ مِنَ الْجَنَّةِ وَمَقْعَدُهُ مِنَ النَّارِ ‏"‏‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ أَفَلاَ نَتَّكِلُ فَقَالَ ‏"‏ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى‏\}‏ إِلَى قَوْلِهِ ‏\{‏لِلْعُسْرَى‏\}‏\hadithno{4945}\hadithtrans{Narrated `Ali:We were in the company of the Prophet (ﷺ) in a funeral procession at Baqi Al-Gharqad. He said, "There is none of you but has his place written for him in Paradise or in the Hell- Fire." They said, "O Allah's Apostle! Shall we depend (on this fact and give up work)?" He said, "Carry on doing (good deeds), for every body will find it easy to do (what will lead him to his destined place)." Then he recited: 'As for him who gives (in charity) and keeps his duty to Allah, and believes in the Best reward from Allah (i.e. Allah will compensate him for what he will spend in Allah's way). So, We will make smooth for him the path of ease. But he who is a greedy miser....for him, the path for evil}}
\hadithdefcmd{bukhari}{4945p2}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ كُنَّا قُعُودًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ الْحَدِيثَ‏.‏\hadithno{4945.2}\hadithtrans{Narrated Abu `Abdur-Rahman:`Ali said, "We were sitting with the Prophet," (He then mentioned the Hadith above)}}
\hadithdefcmd{bukhari}{4946}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ أَنَّهُ كَانَ فِي جَنَازَةٍ فَأَخَذَ عُودًا يَنْكُتُ فِي الأَرْضِ فَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ وَقَدْ كُتِبَ مَقْعَدُهُ مِنَ النَّارِ أَوْ مِنَ الْجَنَّةِ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَفَلاَ نَتَّكِلُ قَالَ ‏"‏ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ ‏\{‏فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى‏\}‏ الآيَةَ‏.‏ قَالَ شُعْبَةُ وَحَدَّثَنِي بِهِ مَنْصُورٌ فَلَمْ أُنْكِرْهُ مِنْ حَدِيثِ سُلَيْمَانَ‏"‏‏.‏\hadithno{4946}\hadithtrans{Narrated `Ali:While the Prophet (ﷺ) was in a funeral procession, he took a small stick and started scraping the earth with it and said, "There is none among you but has his place written for him, either in the Hell Fire or in Paradise." They (the people) said, "Allah's Messenger (ﷺ)! Shall we depend on this (and leave work)?" He replied. "Carry on doing (good deeds), for everybody will find easy (to do) such deeds as will lead him to his destined place." The Prophet (ﷺ) then recited:-- 'As for him who gives (in charity) and keeps his duty to Allah, and believes in the Best Reward}}
\hadithdefcmd{bukhari}{4947}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ ـ عَلَيْهِ السَّلاَمُ ـ قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ وَقَدْ كُتِبَ مَقْعَدُهُ مِنَ الْجَنَّةِ وَمَقْعَدُهُ مِنَ النَّارِ ‏"‏‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ أَفَلاَ نَتَّكِلُ قَالَ ‏"‏ لاَ، اعْمَلُوا فَكُلٌّ مُيَسَّرٌ ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى * فَسَنُيَسِّرُهُ لِلْيُسْرَى‏\}‏ إِلَى قَوْلِهِ ‏\{‏فَسَنُيَسِّرُهُ لِلْعُسْرَى‏\}‏\hadithno{4947}\hadithtrans{Narrated `Ali:We were in the company of the Prophet (ﷺ) and he said, "There is none among you but has his place written for him, either in Paradise or in the Hell-Fire." We said, "O Allah's Messenger (ﷺ)! Shall we depend (on this fact and give up work)?" He replied, "No! Carry on doing good deeds, for everybody will find easy (to do) such deeds as will lead him to his destined place." Then the Prophet (ﷺ) recited: 'As for him who gives (in charity) and keeps his duty to Allah, and believes in the Best reward. We will make smooth for him the path of ease....the path for evil}}
\hadithdefcmd{bukhari}{4948}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ كُنَّا فِي جَنَازَةٍ فِي بَقِيعِ الْغَرْقَدِ، فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَعَدَ وَقَعَدْنَا حَوْلَهُ، وَمَعَهُ مِخْصَرَةٌ فَنَكَّسَ، فَجَعَلَ يَنْكُتُ بِمِخْصَرَتِهِ ثُمَّ قَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ وَمَا مِنْ نَفْسٍ مَنْفُوسَةٍ إِلاَّ كُتِبَ مَكَانُهَا مِنَ الْجَنَّةِ وَالنَّارِ، وَإِلاَّ قَدْ كُتِبَتْ شَقِيَّةً أَوْ سَعِيدَةً ‏"‏‏.‏ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَفَلاَ نَتَّكِلُ عَلَى كِتَابِنَا وَنَدَعُ الْعَمَلَ فَمَنْ كَانَ مِنَّا مِنْ أَهْلِ السَّعَادَةِ فَسَيَصِيرُ إِلَى أَهْلِ السَّعَادَةِ، وَمَنْ كَانَ مِنَّا مِنْ أَهْلِ الشَّقَاءِ فَسَيَصِيرُ إِلَى عَمَلِ أَهْلِ الشَّقَاوَةِ‏.‏ قَالَ ‏"‏ أَمَّا أَهْلُ السَّعَادَةِ فَيُيَسَّرُونَ لِعَمَلِ أَهْلِ السَّعَادَةِ وَأَمَّا أَهْلُ الشَّقَاوَةِ فَيُيَسَّرُونَ لِعَمَلِ أَهْلِ الشَّقَاءِ ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى‏\}‏ الآيَةَ‏.‏\hadithno{4948}\hadithtrans{Narrated `Ali:While we were in a funeral procession in Baqi Al-Gharqad, Allah's Messenger (ﷺ) came and sat down, and we sat around him. He had a small stick in his hand and he bent his head and started scraping the ground with it. He then said, "There is none among you, and no created soul but has his place written for him either in Paradise or in the Hell-Fire, and also has his happy or miserable fate (in the Hereafter) written for him." A man said, "O Allah's Messenger (ﷺ)! Shall we depend upon what is written for us and give up doing (good) deeds? For whoever among us is destined to be fortunate (in the Hereafter), will join the fortunate peoples and whoever among us is destined to be miserable will do such deeds as are characteristic of the people who are destined to misery." The Prophet (ﷺ) said, "Those who are destined to be happy (in the Hereafter) will find it easy and pleasant to do the deeds characteristic of those destined to happiness, while those who are to be among the miserable (in the Hereafter), will find it easy to do the deeds characteristic of those destined to misery." Then he recited: 'As for him who gives (in charity) and keeps his duty to Allah and believes in the Best reward from Allah}}
\hadithdefcmd{bukhari}{4949}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ سَعْدَ بْنَ عُبَيْدَةَ، يُحَدِّثُ عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم فِي جَنَازَةٍ فَأَخَذَ شَيْئًا فَجَعَلَ يَنْكُتُ بِهِ الأَرْضَ فَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ وَقَدْ كُتِبَ مَقْعَدُهُ مِنَ النَّارِ وَمَقْعَدُهُ مِنَ الْجَنَّةِ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَفَلاَ نَتَّكِلُ عَلَى كِتَابِنَا وَنَدَعُ الْعَمَلَ قَالَ ‏"‏ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ، أَمَّا مَنْ كَانَ مِنْ أَهْلِ السَّعَادَةِ فَيُيَسَّرُ لِعَمَلِ أَهْلِ السَّعَادَةِ، وَأَمَّا مَنْ كَانَ مِنْ أَهْلِ الشَّقَاءِ فَيُيَسَّرُ لِعَمَلِ أَهْلِ الشَّقَاوَةِ ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى‏\}‏ الآيَةَ‏.‏\hadithno{4949}\hadithtrans{Narrated `Ali:While the Prophet (ﷺ) was in a funeral procession. he picked up something and started scraping the ground with it, and said, "There is none among you but has his place written for him either in the Hell Fire or in Paradise." They said, "O Allah's Messenger (ﷺ)! Shall we not depend upon what has been written for us and give up deeds? He said, "Carry on doing (good) deeds, for everybody will find easy to do such deeds as will lead him to his destined place for which he has been created. So he who is destined to be among the happy (in the Hereafter), will find it easy to do the deeds characteristic of such people, while he who is destined to be among the miserable ones, will find it easy to do the deeds characteristic of such people." Then he recited: 'As for him who gives (in charity) and fears Allah, and believes in the best}}
\hadithdefcmd{bukhari}{4950}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا الأَسْوَدُ بْنُ قَيْسٍ، قَالَ سَمِعْتُ جُنْدُبَ بْنَ سُفْيَانَ ـ رضى الله عنه ـ قَالَ اشْتَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَقُمْ لَيْلَتَيْنِ أَوْ ثَلاَثًا، فَجَاءَتِ امْرَأَةٌ فَقَالَتْ يَا مُحَمَّدُ إِنِّي لأَرْجُو أَنْ يَكُونَ شَيْطَانُكَ قَدْ تَرَكَكَ، لَمْ أَرَهُ قَرِبَكَ مُنْذُ لَيْلَتَيْنِ أَوْ ثَلاَثًا‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَالضُّحَى * وَاللَّيْلِ إِذَا سَجَى * مَا وَدَّعَكَ رَبُّكَ وَمَا قَلَى‏\}‏\hadithno{4950}\hadithtrans{Narrated Jundub bin Sufyan:Once Allah's Messenger (ﷺ) became sick and could not offer his night prayer (Tahajjud) for two or three nights. Then a lady (the wife of Abu Lahab) came and said, "O Muhammad! I think that your Satan has forsaken you, for I have not seen him with you for two or three nights!" On that Allah revealed: 'By the fore-noon, and by the night when it darkens, your Lord (O Muhammad) has neither forsaken you, nor hated you}}
\hadithdefcmd{bukhari}{4951}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، غُنْدَرٌ حَدَّثَنَا شُعْبَةُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، قَالَ سَمِعْتُ جُنْدَبًا الْبَجَلِيَّ، قَالَتِ امْرَأَةٌ يَا رَسُولَ اللَّهِ مَا أُرَى صَاحِبَكَ إِلاَّ أَبْطَأَكَ‏.‏ فَنَزَلَتْ ‏\{‏مَا وَدَّعَكَ رَبُّكَ وَمَا قَلَى‏\}‏\hadithno{4951}\hadithtrans{Narrated Jundub Al-Bajali:A lady said, "O Allah's Messenger (ﷺ)! I see that your friend has delayed. (in conveying Qur'an) to you." So there was revealed: 'Your Lord (O Muhammad) has neither forsaken you, not hated you}}
\hadithdefcmd{bukhari}{4952}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَدِيٌّ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي سَفَرٍ فَقَرَأَ فِي الْعِشَاءِ فِي إِحْدَى الرَّكْعَتَيْنِ بِالتِّينِ وَالزَّيْتُونِ‏.‏ ‏\{‏تَقْوِيمٍ‏\}‏ الْخَلْقِ‏.‏\hadithno{4952}\hadithtrans{Narrated Al-Bara:While the Prophet (ﷺ) was on a journey, he recited Surat at-Tini waz-Zaituni (95) in one of the first two rak`at of the `Isha prayer}}
\hadithdefcmd{bukhari}{4953}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ مَرْوَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، أَخْبَرَنَا أَبُو صَالِحٍ، سَلْمَوَيْهِ قَالَ حَدَّثَنِي عَبْدُ اللَّهِ، عَنْ يُونُسَ بْنِ يَزِيدَ، قَالَ أَخْبَرَنِي ابْنُ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، أَخْبَرَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ أَوَّلُ مَا بُدِئَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الرُّؤْيَا الصَّادِقَةُ فِي النَّوْمِ، فَكَانَ لاَ يَرَى رُؤْيَا إِلاَّ جَاءَتْ مِثْلَ فَلَقِ الصُّبْحِ، ثُمَّ حُبِّبَ إِلَيْهِ الْخَلاَءُ فَكَانَ يَلْحَقُ بِغَارِ حِرَاءٍ فَيَتَحَنَّثُ فِيهِ ـ قَالَ وَالتَّحَنُّثُ التَّعَبُّدُ ـ اللَّيَالِيَ ذَوَاتِ الْعَدَدِ قَبْلَ أَنْ يَرْجِعَ إِلَى أَهْلِهِ، وَيَتَزَوَّدُ لِذَلِكَ، ثُمَّ يَرْجِعُ إِلَى خَدِيجَةَ فَيَتَزَوَّدُ بِمِثْلِهَا، حَتَّى فَجِئَهُ الْحَقُّ وَهْوَ فِي غَارِ حِرَاءٍ فَجَاءَهُ الْمَلَكُ فَقَالَ اقْرَأْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَنَا بِقَارِئٍ ‏"‏‏.‏ قَالَ ‏"‏ فَأَخَذَنِي فَغَطَّنِي حَتَّى بَلَغَ مِنِّي الْجُهْدُ ثُمَّ أَرْسَلَنِي‏.‏ فَقَالَ اقْرَأْ‏.‏ قُلْتُ مَا أَنَا بِقَارِئٍ‏.‏ فَأَخَذَنِي فَغَطَّنِي الثَّانِيِةَ حَتَّى بَلَغَ مِنِّي الْجُهْدُ، ثُمَّ أَرْسَلَنِي‏.‏ فَقَالَ اقْرَأْ‏.‏ قُلْتُ مَا أَنَا بِقَارِئٍ‏.‏ فَأَخَذَنِي فَغَطَّنِي الثَّالِثَةَ حَتَّى بَلَغَ مِنِّي الْجُهْدُ ثُمَّ أَرْسَلَنِي‏.‏ فَقَالَ ‏\{‏اقْرَأْ بِاسْمِ رَبِّكَ الَّذِي خَلَقَ * خَلَقَ الإِنْسَانَ مِنْ عَلَقٍ * اقْرَأْ وَرَبُّكَ الأَكْرَمُ * الَّذِي عَلَّمَ بِالْقَلَمِ‏\}‏ ‏"‏‏.‏ الآيَاتِ إِلَى قَوْلِهِ ‏\{‏عَلَّمَ الإِنْسَانَ مَا لَمْ يَعْلَمْ‏\}‏ فَرَجَعَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم تَرْجُفُ بَوَادِرُهُ حَتَّى دَخَلَ عَلَى خَدِيجَةَ فَقَالَ ‏"‏ زَمِّلُونِي زَمِّلُونِي ‏"‏‏.‏ فَزَمَّلُوهُ حَتَّى ذَهَبَ عَنْهُ الرَّوْعُ قَالَ لِخَدِيجَةَ ‏"‏ أَىْ خَدِيجَةُ مَا لِي، لَقَدْ خَشِيتُ عَلَى نَفْسِي ‏"‏‏.‏ فَأَخْبَرَهَا الْخَبَرَ‏.‏ قَالَتْ خَدِيجَةُ كَلاَّ أَبْشِرْ، فَوَاللَّهِ لاَ يُخْزِيكَ اللَّهُ أَبَدًا، فَوَاللَّهِ إِنَّكَ لَتَصِلُ الرَّحِمَ، وَتَصْدُقُ الْحَدِيثَ، وَتَحْمِلُ الْكَلَّ، وَتَكْسِبُ الْمَعْدُومَ، وَتَقْرِي الضَّيْفَ، وَتُعِينُ عَلَى نَوَائِبِ الْحَقِّ‏.‏ فَانْطَلَقَتْ بِهِ خَدِيجَةُ حَتَّى أَتَتْ بِهِ وَرَقَةَ بْنَ نَوْفَلٍ وَهْوَ ابْنُ عَمِّ خَدِيجَةَ أَخِي أَبِيهَا، وَكَانَ امْرَأً تَنَصَّرَ فِي الْجَاهِلِيَّةِ، وَكَانَ يَكْتُبُ الْكِتَابَ الْعَرَبِيَّ وَيَكْتُبُ مِنَ الإِنْجِيلِ بِالْعَرَبِيَّةِ مَا شَاءَ اللَّهُ أَنْ يَكْتُبَ، وَكَانَ شَيْخًا كَبِيرًا قَدْ عَمِيَ فَقَالَتْ خَدِيجَةُ يَا ابْنَ عَمِّ اسْمَعْ مِنِ ابْنِ أَخِيكَ‏.‏ قَالَ وَرَقَةُ يَا ابْنَ أَخِي مَاذَا تَرَى فَأَخْبَرَهُ النَّبِيُّ صلى الله عليه وسلم خَبَرَ مَا رَأَى‏.‏ فَقَالَ وَرَقَةُ هَذَا النَّامُوسُ الَّذِي أُنْزِلَ عَلَى مُوسَى، لَيْتَنِي فِيهَا جَذَعًا، لَيْتَنِي أَكُونُ حَيًّا‏.‏ ذَكَرَ حَرْفًا‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوَمُخْرِجِيَّ هُمْ ‏"‏‏.‏ قَالَ وَرَقَةُ نَعَمْ لَمْ يَأْتِ رَجُلٌ بِمَا جِئْتَ بِهِ إِلاَّ أُوذِيَ، وَإِنْ يُدْرِكْنِي يَوْمُكَ حَيًّا أَنْصُرْكَ نَصْرًا مُؤَزَّرًا‏.‏ ثُمَّ لَمْ يَنْشَبْ وَرَقَةُ أَنْ تُوُفِّيَ، وَفَتَرَ الْوَحْىُ، فَتْرَةً حَتَّى حَزِنَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{4953}\hadithtrans{Narrated Aisha:(the wife of the Prophet) The commencement (of the Divine Inspiration) to Allah's Messenger (ﷺ) was in the form of true dreams in his sleep, for he never had a dream but it turned out to be true and clear as the bright daylight. Then he began to like seclusions, so he used to go in seclusion in the cave of Hira where he used to worship Allah continuously for many nights before going back to his family to take the necessary provision (of food) for the stay. He come back to (his wife) Khadija again to take his provision (of food) likewise, till one day he received the Guidance while he was in the cave of Hira. An Angel came to him and asked him to read. Allah's Messenger (ﷺ) replied, "I do not know how to read." The Prophet (ﷺ) added, "Then the Angel held me (forcibly) and pressed me so hard that I felt distressed. Then he released me and again asked me to read, and I replied, 'I do not know how to read.' Thereupon he held me again and pressed me for the second time till I felt distressed. He then released me and asked me to read, but again I replied. 'I do not know how to read.' Thereupon he held me for the third time and pressed me till I got distressed, and then he released me and said, 'Read, in the Name of your Lord Who has created (all that exists), has created man out of a clot, Read! And your Lord is the Most Generous. Who has taught (the writing) by the pen, has taught man that which he knew not." (96.1-5). Then Allah's Messenger (ﷺ) returned with that experience; and the muscles between his neck and shoulders were trembling till he came upon Khadija (his wife) and said, "Cover me!" They covered him, and when the state of fear was over, he said to Khadija, "O Khadija! What is wrong with me? I was afraid that something bad might happen to me." Then he told her the story. Khadija said, "Nay! But receive the good tidings! By Allah, Allah will never disgrace you, for by Allah, you keep good relations with your Kith and kin, speak the truth, help the poor and the destitute, entertain your guests generously and assist those who are stricken with calamities." Khadija then took him to Waraqa bin Naufil, the son of Khadija's paternal uncle. Waraqa had been converted to Christianity in the Pre-Islamic Period and used to write Arabic and write of the Gospel in Arabic as much as Allah wished him to write. He was an old man and had lost his eyesight. Khadija said (to Waraqa), "O my cousin! Listen to what your nephew is going to say." Waraqa said, "O my nephew! What have you seen?" The Prophet (ﷺ) then described whatever he had seen. Waraqa said, "This is the same Angel (Gabriel) who was sent to Moses. I wish I were young." He added some other statement. Allah's Messenger (ﷺ) asked, "Will these people drive me out?" Waraqa said, "Yes, for nobody brought the like of what you have brought, but was treated with hostility. If I were to remain alive till your day (when you start preaching). then I would support you strongly." But a short while later Waraqa died and the Divine Inspiration was paused (stopped) for a while so that Allah's Messenger (ﷺ) was very much grieved}}
\hadithdefcmd{bukhari}{4954}{قَالَ مُحَمَّدُ بْنُ شِهَابٍ فَأَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ الأَنْصَارِيِّ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ يُحَدِّثُ عَنْ فَتْرَةِ الْوَحْىِ قَالَ فِي حَدِيثِهِ ‏"‏ بَيْنَا أَنَا أَمْشِي سَمِعْتُ صَوْتًا مِنَ السَّمَاءِ فَرَفَعْتُ بَصَرِي، فَإِذَا الْمَلَكُ الَّذِي جَاءَنِي بِحِرَاءٍ جَالِسٌ عَلَى كُرْسِيٍّ بَيْنَ السَّمَاءِ وَالأَرْضِ فَفَرِقْتُ مِنْهُ فَرَجَعْتُ فَقُلْتُ زَمِّلُونِي زَمِّلُونِي ‏"‏‏.‏ فَدَثَّرُوهُ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ * قُمْ فَأَنْذِرْ * وَرَبَّكَ فَكَبِّرْ * وَثِيَابَكَ فَطَهِّرْ * وَالرِّجْزَ فَاهْجُرْ‏\}‏‏.‏ قَالَ أَبُو سَلَمَةَ وَهْىَ الأَوْثَانُ الَّتِي كَانَ أَهْلُ الْجَاهِلِيَّةِ يَعْبُدُونَ‏.‏ قَالَ ثُمَّ تَتَابَعَ الْوَحْىُ‏.‏\hadithno{4954}\hadithtrans{Narrated Jabir bin `Abdullah:While Allah's Messenger (ﷺ) was talking about the period of pause in revelation. he said in his narration. "Once while I was walking, all of a sudden I heard a voice from the sky. I looked up and saw to my surprise, the same Angel as had visited me in the cave of Hira.' He was sitting on a chair between the sky and the earth. I got afraid of him and came back home and said, Wrap me! Wrap me!" So they covered him and then Allah revealed: 'O you, wrapped up! Arise and warn and your Lord magnify, and your garments purify and dessert the idols.' (74.1-5) Abu Salama said, "(Rijz) are the idols which the people of the Pre-Islamic period used to worship." After this the revelation started coming frequently and regularly}}
\hadithdefcmd{bukhari}{4955}{حَدَّثَنَا ابْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَوَّلُ مَا بُدِئَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الرُّؤْيَا الصَّالِحَةُ فَجَاءَهُ الْمَلَكُ فَقَالَ ‏\{‏اقْرَأْ بِاسْمِ رَبِّكَ الَّذِي خَلَقَ * خَلَقَ الإِنْسَانَ مِنْ عَلَقٍ * اقْرَأْ وَرَبُّكَ الأَكْرَمُ‏\}‏\hadithno{4955}\hadithtrans{Narrated Aisha:The commencement of the Divine Inspiration to Allah's Messenger (ﷺ) was in the form of true dreams. The Angel came to him and said, "Read, in the Name of your Lord Who has created (all that exists), has created man a clot. Read! And your Lord is Most Generous}}
\hadithdefcmd{bukhari}{4956}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، ح وَقَالَ اللَّيْثُ حَدَّثَنِي عُقَيْلٌ، قَالَ مُحَمَّدُ أَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ ـ رضى الله عنها‏.‏ أَوَّلُ مَا بُدِئَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الرُّؤْيَا الصَّادِقَةُ جَاءَهُ الْمَلَكُ فَقَالَ ‏\{‏اقْرَأْ بِاسْمِ رَبِّكَ الَّذِي خَلَقَ * خَلَقَ الإِنْسَانَ مِنْ عَلَقٍ * اقْرَأْ وَرَبُّكَ الأَكْرَمُ * الَّذِي عَلَّمَ بِالْقَلَمِ‏\}‏\hadithno{4956}\hadithtrans{Narrated `Aisha:The commencement of (the Divine Inspirations to) Allah's Messenger (ﷺ) was in the form of true dreams. The Angel came to him and said, "Read! In the Name of your Lord Who has created all exists), has created man from a clot. Read! And your Lord is Most Generous, Who has taught (the writing) by the pen}}
\hadithdefcmd{bukhari}{4957}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ سَمِعْتُ عُرْوَةَ، قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ فَرَجَعَ النَّبِيُّ صلى الله عليه وسلم إِلَى خَدِيجَةَ فَقَالَ ‏ "‏ زَمِّلُونِي زَمِّلُونِي ‏"‏‏.‏ فَذَكَرَ الْحَدِيثَ\hadithno{4957}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) returned to Khadija and said, "Wrap me! Wrap me!" (Then the sub-narrator narrated the rest of the narration)}}
\hadithdefcmd{bukhari}{4958}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ عِكْرِمَةَ، قَالَ ابْنُ عَبَّاسٍ قَالَ أَبُو جَهْلٍ لَئِنْ رَأَيْتُ مُحَمَّدًا يُصَلِّي عِنْدَ الْكَعْبَةِ لأَطَأَنَّ عَلَى عُنُقِهِ‏.‏ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَوْ فَعَلَهُ لأَخَذَتْهُ الْمَلاَئِكَةُ ‏"‏‏.‏ تَابَعَهُ عَمْرُو بْنُ خَالِدٍ عَنْ عُبَيْدِ اللَّهِ عَنْ عَبْدِ الْكَرِيمِ‏.‏\hadithno{4958}\hadithtrans{Narrated Ibn `Abbas:Abu Jahl said, "If I see Muhammad praying at the Ka`ba, I will tread on his neck." When the Prophet (ﷺ) heard of that, he said, "If he does so, the Angels will snatch him away}}
\hadithdefcmd{bukhari}{4959}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم لأُبَىٍّ‏.‏ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ ‏\{‏لَمْ يَكُنِ الَّذِينَ كَفَرُوا‏\}‏ ‏"‏‏.‏ قَالَ وَسَمَّانِي قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ فَبَكَى‏.‏\hadithno{4959}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said to Ubai (bin Ka`b). "Allah has ordered me to recite to you:--'Those who disbelieve among the people of the Scripture and among the idolators are not going to stop (from their disbelief.') (Sura 98) Ubai said, "Did Allah mention me by name?" The Prophet (ﷺ) said, "Yes." On that, Ubai wept}}
\hadithdefcmd{bukhari}{4960}{حَدَّثَنَا حَسَّانُ بْنُ حَسَّانَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لأُبَىٍّ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ الْقُرْآنَ ‏"‏‏.‏ قَالَ أُبَىٌّ آللَّهُ سَمَّانِي لَكَ قَالَ ‏"‏ اللَّهُ سَمَّاكَ لِي ‏"‏‏.‏ فَجَعَلَ أُبَىٌّ يَبْكِي‏.‏ قَالَ قَتَادَةُ فَأُنْبِئْتُ أَنَّهُ قَرَأَ عَلَيْهِ ‏\{‏لَمْ يَكُنِ الَّذِينَ كَفَرُوا مِنْ أَهْلِ الْكِتَابِ‏\}‏\hadithno{4960}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said to Ubai, "Allah has ordered me recite Qur'an to you." Ubai asked, "Did Allah mention me by name to you?" The Prophet (ﷺ) said, "Allah has mentioned your name to me." On that Ubai started weeping. (The sub-narrator) Qatada added: I have been informed that the Prophet (ﷺ) recited: 'Those who disbelieve among the people of the Scripture," ...to Ubai}}
\hadithdefcmd{bukhari}{4961}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي دَاوُدَ أَبُو جَعْفَرٍ الْمُنَادِي، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ لأُبَىِّ بْنِ كَعْبٍ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أُقْرِئَكَ الْقُرْآنَ ‏"‏‏.‏ قَالَ آللَّهُ سَمَّانِي لَكَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قَالَ وَقَدْ ذُكِرْتُ عِنْدَ رَبِّ الْعَالَمِينَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ فَذَرَفَتْ عَيْنَاهُ‏.‏\hadithno{4961}\hadithtrans{Narrated Anas bin Malik:Allah's Prophet said to Ubai bin Ka`b, "Allah has ordered me to recite Qur'an to you." Ubai said, "Did Allah mention me by name to you?" The Prophet (ﷺ) said, "Yes." Ubai said, "Have I been mentioned by the Lord of the Worlds?" The Prophet (ﷺ) said, "Yes." Then Ubai burst into tears}}
\hadithdefcmd{bukhari}{4962}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْخَيْلُ لِثَلاَثَةٍ، لِرَجُلٍ أَجْرٌ، وَلِرَجُلٍ سِتْرٌ، وَعَلَى رَجُلٍ وِزْرٌ، فَأَمَّا الَّذِي لَهُ أَجْرٌ فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ فَأَطَالَ لَهَا فِي مَرْجٍ أَوْ رَوْضَةٍ، فَمَا أَصَابَتْ فِي طِيَلِهَا ذَلِكَ فِي الْمَرْجِ وَالرَّوْضَةِ، كَانَ لَهُ حَسَنَاتٍ، وَلَوْ أَنَّهَا قَطَعَتْ طِيَلَهَا فَاسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ كَانَتْ آثَارُهَا وَأَرْوَاثُهَا حَسَنَاتٍ لَهُ، وَلَوْ أَنَّهَا مَرَّتْ بِنَهَرٍ فَشَرِبَتْ مِنْهُ وَلَمْ يُرِدْ أَنْ يَسْقِيَ بِهِ كَانَ ذَلِكَ حَسَنَاتٍ لَهُ فَهْىَ لِذَلِكَ الرَّجُلِ أَجْرٌ، وَرَجُلٌ رَبَطَهَا تَغَنِّيًا وَتَعَفُّفًا وَلَمْ يَنْسَ حَقَّ اللَّهِ فِي رِقَابِهَا وَلاَ ظُهُورِهَا فَهْىَ لَهُ سِتْرٌ، وَرَجُلٌ رَبَطَهَا فَخْرًا وَرِئَاءً وَنِوَاءً فَهْىَ عَلَى ذَلِكَ وِزْرٌ‏.‏ فَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحُمُرِ‏.‏ قَالَ ‏"‏ مَا أَنْزَلَ اللَّهُ عَلَىَّ فِيهَا إِلاَّ هَذِهِ الآيَةَ الْفَاذَّةَ الْجَامِعَةَ ‏\{‏فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ‏\}‏\hadithno{4962}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, " Horses are kept for one of three purposes: A man may keep them (for Allah's Cause) to receive a reward in the Hereafter; another may keep them as a means of protection; and a third may keep them to be a burden for him. As for the man for whom the horse is a source of reward, he is the one who ties it for Allah's Cause, and he ties it with a long rope in a pasture or a garden, then, whatever it eats or drinks in that pasture or garden will be added to his good deeds. And if it breaks its rope and jumps over one or two hills, then, for all its footsteps and its manure, good deeds will be written for him. And if it passes by a river and drinks of its water though its owner had no intention to water it from that river, even then he will have good deeds written for him. So that horse will be (a source of) reward for such a man. If a man ties a horse for earning his livelihood and abstaining from asking others for help and he does not forget Allah's right, i.e. pays its Zakat and gives it to be used in Allah's Cause, then that horse will be a means of protection for him. But if a man ties it out of pride and to show off and to excite others, then that horse will be a burden (of sins) for him." Then Allah's Messenger (ﷺ) was asked regarding donkeys. He replied, "Nothing has been revealed to me except this comprehensive Verse which includes everything: 'So whoever does good equal to the weight of an atom (or a smallest ant) shall see it; and whoever does evil equal to the weight of an atom (or a smallest ant) shall see it}}
\hadithdefcmd{bukhari}{4963}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الْحُمُرِ فَقَالَ ‏"‏ لَمْ يُنْزَلْ عَلَىَّ فِيهَا شَىْءٌ إِلاَّ هَذِهِ الآيَةُ الْجَامِعَةُ الْفَاذَّةُ ‏\{‏فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ‏\}‏‏"‏‏.‏\hadithno{4963}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) was asked about donkeys and he replied, "Nothing has been revealed to me regarding donkeys except this comprehensive Verse which includes everything: "So whoever does good equal to the weight of an atom (or a smallest ant) shall see it; And whoever, does evil equal to the weight of an atom or a smallest ant) shall see it}}
\hadithdefcmd{bukhari}{4964}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شَيْبَانُ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لَمَّا عُرِجَ بِالنَّبِيِّ صلى الله عليه وسلم إِلَى السَّمَاءِ قَالَ ‏ "‏ أَتَيْتُ عَلَى نَهَرٍ حَافَتَاهُ قِبَابُ اللُّؤْلُؤِ مُجَوَّفًا فَقُلْتُ مَا هَذَا يَا جِبْرِيلُ قَالَ هَذَا الْكَوْثَرُ ‏"‏‏.‏\hadithno{4964}\hadithtrans{Narrated Anas:When the Prophet (ﷺ) was made to ascend to the Heavens, he said (after his return), "I came upon a river the banks of which were made of tents of hollow pearls. I asked Gabriel. What is this (river?) He replied, 'This is the Kauthar}}
\hadithdefcmd{bukhari}{4965}{حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ الْكَاهِلِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَ سَأَلْتُهَا عَنْ قَوْلِهِ تَعَالَى ‏\{‏إِنَّا أَعْطَيْنَاكَ الْكَوْثَرَ‏\}‏ قَالَتْ نَهَرٌ أُعْطِيَهُ نَبِيُّكُمْ صلى الله عليه وسلم شَاطِئَاهُ عَلَيْهِ دُرٌّ مُجَوَّفٌ آنِيَتُهُ كَعَدَدِ النُّجُومِ‏.‏ رَوَاهُ زَكَرِيَّاءُ وَأَبُو الأَحْوَصِ وَمُطَرِّفٌ عَنْ أَبِي إِسْحَاقَ‏.‏\hadithno{4965}\hadithtrans{Narrated Abu Ubaida:I asked `Aisha 'regarding the verse:--'Verily we have granted you the Kauthar.' She replied, "The Kauthar is a river which has been given to your Prophet on the banks of which there are (tents of) hollow pearls and its utensils are as numberless as the stars}}
\hadithdefcmd{bukhari}{4966}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ قَالَ فِي الْكَوْثَرِ هُوَ الْخَيْرُ الَّذِي أَعْطَاهُ اللَّهُ إِيَّاهُ‏.‏ قَالَ أَبُو بِشْرٍ قُلْتُ لِسَعِيدِ بْنِ جُبَيْرٍ فَإِنَّ النَّاسَ يَزْعُمُونَ أَنَّهُ نَهَرٌ فِي الْجَنَّةِ‏.‏ فَقَالَ سَعِيدٌ النَّهَرُ الَّذِي فِي الْجَنَّةِ مِنَ الْخَيْرِ الَّذِي أَعْطَاهُ اللَّهُ إِيَّاهُ‏.‏\hadithno{4966}\hadithtrans{Narrated Abu Bishr:Sa`id bin Jubair said that Ibn `Abbas said about Al-Kauthar. "That is the good which Allah has bestowed upon His Apostle." I said to Sa`id bin Jubair. "But the people claim that it is a river in Paradise." Sa`id said, "The river in Paradise is part of the good which Allah has bestowed on His Apostle}}
\hadithdefcmd{bukhari}{4967}{حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا صَلَّى النَّبِيُّ صلى الله عليه وسلم صَلاَةً بَعْدَ أَنْ نَزَلَتْ عَلَيْهِ ‏\{‏إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏ إِلاَّ يَقُولُ فِيهَا ‏"‏ سُبْحَانَكَ رَبَّنَا وَبِحَمْدِكَ، اللَّهُمَّ اغْفِرْ لِي ‏"‏‏.‏\hadithno{4967}\hadithtrans{Narrated Aisha:"When the "Surat-An-Nasr", 'When comes the Help of Allah and the conquest,' had been revealed to the Prophet (ﷺ) he did not offer any prayer except that he said therein, "Subhanka Rabbana wa bihamdika; Allahumma ighfirli (I testify the Uniqueness of our Lord, and all the praises are for Him: O Allah, forgive me)}}
\hadithdefcmd{bukhari}{4968}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ أَنْ يَقُولَ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ رَبَّنَا وَبِحَمْدِكَ، اللَّهُمَّ اغْفِرْ لِي ‏"‏‏.‏ يَتَأَوَّلُ الْقُرْآنَ‏.‏\hadithno{4968}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) used to say very often in bowing and prostration (during his prayers), Subhanka Allahumma Rabbana wa bihamdika; Allahumma ighfirli," according to the order of the Qur'an}}
\hadithdefcmd{bukhari}{4969}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ عُمَرَ ـ رضى الله عنه ـ سَأَلَهُمْ عَنْ قَوْلِهِ تَعَالَى ‏\{‏إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏ قَالُوا فَتْحُ الْمَدَائِنِ وَالْقُصُورِ قَالَ مَا تَقُولُ يَا ابْنَ عَبَّاسٍ قَالَ أَجَلٌ أَوْ مَثَلٌ ضُرِبَ لِمُحَمَّدٍ صلى الله عليه وسلم نُعِيَتْ لَهُ نَفْسُهُ‏.‏\hadithno{4969}\hadithtrans{Narrated Ibn `Abbas:`Umar asked the people regarding Allah's Statement: 'When comes the Help of Allah (to you O Muhammad against your enemies) and the conquest of Mecca.' (110.1) They replied, "It indicates the future conquest of towns and palaces (by Muslims)." `Umar said, "What do you say about it, O Ibn `Abbas?" I replied, "(This Surat) indicates the termination of the life of Muhammad. Through it he was informed of the nearness of his death}}
\hadithdefcmd{bukhari}{4970}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ عُمَرُ يُدْخِلُنِي مَعَ أَشْيَاخِ بَدْرٍ، فَكَأَنَّ بَعْضَهُمْ وَجَدَ فِي نَفْسِهِ فَقَالَ لِمَ تُدْخِلُ هَذَا مَعَنَا وَلَنَا أَبْنَاءٌ مِثْلُهُ فَقَالَ عُمَرُ إِنَّهُ مِنْ حَيْثُ عَلِمْتُمْ‏.‏ فَدَعَا ذَاتَ يَوْمٍ ـ فَأَدْخَلَهُ مَعَهُمْ ـ فَمَا رُئِيتُ أَنَّهُ دَعَانِي يَوْمَئِذٍ إِلاَّ لِيُرِيَهُمْ‏.‏ قَالَ مَا تَقُولُونَ فِي قَوْلِ اللَّهِ تَعَالَى ‏\{‏إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏ فَقَالَ بَعْضُهُمْ أُمِرْنَا نَحْمَدُ اللَّهَ وَنَسْتَغْفِرُهُ، إِذَا نُصِرْنَا وَفُتِحَ عَلَيْنَا‏.‏ وَسَكَتَ بَعْضُهُمْ فَلَمْ يَقُلْ شَيْئًا فَقَالَ لِي أَكَذَاكَ تَقُولُ يَا ابْنَ عَبَّاسٍ فَقُلْتُ لاَ‏.‏ قَالَ فَمَا تَقُولُ قُلْتُ هُوَ أَجَلُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَعْلَمَهُ لَهُ، قَالَ ‏\{‏إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏ وَذَلِكَ عَلاَمَةُ أَجَلِكَ ‏\{‏فَسَبِّحْ بِحَمْدِ رَبِّكَ وَاسْتَغْفِرْهُ إِنَّهُ كَانَ تَوَّابًا‏\}‏‏.‏ فَقَالَ عُمَرُ مَا أَعْلَمُ مِنْهَا إِلاَّ مَا تَقُولُ‏.‏\hadithno{4970}\hadithtrans{Narrated Ibn `Abbas:`Umar used to make me sit with the elderly men who had fought in the Battle of Badr. Some of them felt it (did not like that) and said to `Umar "Why do you bring in this boy to sit with us while we have sons like him?" `Umar replied, "Because of what you know of his position (i.e. his religious knowledge.)" One day `Umar called me and made me sit in the gathering of those people; and I think that he called me just to show them. (my religious knowledge). `Umar then asked them (in my presence). "What do you say about the interpretation of the Statement of Allah: 'When comes Help of Allah (to you O, Muhammad against your enemies) and the conquest (of Mecca).' (110.1) Some of them said, "We are ordered to praise Allah and ask for His forgiveness when Allah's Help and the conquest (of Mecca) comes to us." Some others kept quiet and did not say anything. On that, `Umar asked me, "Do you say the same, O Ibn `Abbas?" I replied, "No." He said, 'What do you say then?" I replied, "That is the sign of the death of Allah's Messenger (ﷺ) which Allah informed him of. Allah said:-- '(O Muhammad) When comes the Help of Allah (to you against your enemies) and the conquest (of Mecca) (which is the sign of your death). You should celebrate the praises of your Lord and ask for His Forgiveness, and He is the One Who accepts the repentance and forgives.' (110.3) On that `Umar said, "I do not know anything about it other than what you have said}}
\hadithdefcmd{bukhari}{4971}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا نَزَلَتْ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ وَرَهْطَكَ مِنْهُمُ الْمُخْلَصِينَ، خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى صَعِدَ الصَّفَا فَهَتَفَ ‏"‏ يَا صَبَاحَاهْ ‏"‏‏.‏ فَقَالُوا مَنْ هَذَا، فَاجْتَمَعُوا إِلَيْهِ‏.‏ فَقَالَ ‏"‏ أَرَأَيْتُمْ إِنْ أَخْبَرْتُكُمْ أَنَّ خَيْلاً تَخْرُجُ مِنْ سَفْحِ هَذَا الْجَبَلِ أَكُنْتُمْ مُصَدِّقِيَّ ‏"‏‏.‏ قَالُوا مَا جَرَّبْنَا عَلَيْكَ كَذِبًا‏.‏ قَالَ ‏"‏ فَإِنِّي نَذِيرٌ لَكُمْ بَيْنَ يَدَىْ عَذَابٍ شَدِيدٍ ‏"‏‏.‏ قَالَ أَبُو لَهَبٍ تَبًّا لَكَ مَا جَمَعْتَنَا إِلاَّ لِهَذَا ثُمَّ قَامَ فَنَزَلَتْ ‏\{‏تَبَّتْ يَدَا أَبِي لَهَبٍ وَتَبَّ‏\}‏ وَقَدْ تَبَّ هَكَذَا قَرَأَهَا الأَعْمَشُ يَوْمَئِذٍ‏.‏\hadithno{4971}\hadithtrans{Narrated Ibn `Abbas:When the Verse:-- 'And warn your tribe of near kindred.' (26.214) was revealed. Allah's Messenger (ﷺ) went out, and when he had ascended As-Safa mountain, he shouted, "O Sabahah!" The people said, "Who is that?" "Then they gathered around him, whereupon he said, "Do you see? If I inform you that cavalrymen are proceeding up the side of this mountain, will you believe me?" They said, "We have never heard you telling a lie." Then he said, "I am a plain warner to you of a coming severe punishment." Abu Lahab said, "May you perish! You gathered us only for this reason? " Then Abu Lahab went away. So the "Surat:--ul--LAHAB" 'Perish the hands of Abu Lahab!' (111.1) was revealed}}
\hadithdefcmd{bukhari}{4972}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ إِلَى الْبَطْحَاءِ فَصَعِدَ إِلَى الْجَبَلِ فَنَادَى ‏"‏ يَا صَبَاحَاهْ ‏"‏‏.‏ فَاجْتَمَعَتْ إِلَيْهِ قُرَيْشٌ فَقَالَ ‏"‏ أَرَأَيْتُمْ إِنْ حَدَّثْتُكُمْ أَنَّ الْعَدُوَّ مُصَبِّحُكُمْ أَوْ مُمَسِّيكُمْ، أَكُنْتُمْ تُصَدِّقُونِي ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ‏"‏ فَإِنِّي نَذِيرٌ لَكُمْ بَيْنَ يَدَىْ عَذَابٍ شَدِيدٍ ‏"‏‏.‏ فَقَالَ أَبُو لَهَبٍ أَلِهَذَا جَمَعْتَنَا تَبًّا لَكَ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏تَبَّتْ يَدَا أَبِي لَهَبٍ‏\}‏ إِلَى آخِرِهَا‏.‏\hadithno{4972}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) went out towards Al-Batha' and ascended the mountain and shouted, "O Sabahah!" So the Quraish people gathered around him. He said, "Do you see? If I tell you that an enemy is going to attack you in the morning or in the evening, will you believe me?" They replied, "Yes." He said, "Then I am a plain warner to you of a coming severe punishment." Abu Lahab said, "Is it for this reason that you have gathered us? May you perish ! " Then Allah revealed: 'Perish the hands of Abu Lahab}}
\hadithdefcmd{bukhari}{4973}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي عَمْرُو بْنُ مُرَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أَبُو لَهَبٍ تَبًّا لَكَ أَلِهَذَا جَمَعْتَنَا فَنَزَلَتْ ‏\{‏تَبَّتْ يَدَا أَبِي لَهَبٍ‏\}‏‏.‏\hadithno{4973}\hadithtrans{Narrated Ibn `Abbas:Abu Lahab said, "May you perish! Is it' for this that you have gathered us?" So there was revealed:'Perish the hands of Abu Lahab}}
\hadithdefcmd{bukhari}{4974}{حَدَّثَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ كَذَّبَنِي ابْنُ آدَمَ وَلَمْ يَكُنْ لَهُ ذَلِكَ، وَشَتَمَنِي وَلَمْ يَكُنْ لَهُ ذَلِكَ، فَأَمَّا تَكْذِيبُهُ إِيَّاىَ فَقَوْلُهُ لَنْ يُعِيدَنِي كَمَا بَدَأَنِي، وَلَيْسَ أَوَّلُ الْخَلْقِ بِأَهْوَنَ عَلَىَّ مِنْ إِعَادَتِهِ، وَأَمَّا شَتْمُهُ إِيَّاىَ فَقَوْلُهُ اتَّخَذَ اللَّهُ وَلَدًا، وَأَنَا الأَحَدُ الصَّمَدُ لَمْ أَلِدْ وَلَمْ أُولَدْ وَلَمْ يَكُنْ لِي كُفْأً أَحَدٌ ‏"‏‏.‏\hadithno{4974}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah said: 'The son of Adam tells a lie against Me,, though he hasn't the right to do so. He abuses me though he hasn't the right to do so. As for his telling a lie against Me, it is his saying that I will not recreate him as I created him for the first time. In fact, the first creation was not easier for Me than new creation. As for his abusing Me, it is his saying that Allah has begotten children, while I am the One, the Self-Sufficient Master Whom all creatures need, I beget not, nor was I begotten, and there is none like unto Me}}
\hadithdefcmd{bukhari}{4975}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ وَحَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَالَ اللَّهُ كَذَّبَنِي ابْنُ آدَمَ وَلَمْ يَكُنْ لَهُ ذَلِكَ، وَشَتَمَنِي وَلَمْ يَكُنْ لَهُ ذَلِكَ، أَمَّا تَكْذِيبُهُ إِيَّاىَ أَنْ يَقُولَ إِنِّي لَنْ أُعِيدَهُ كَمَا بَدَأْتُهُ، وَأَمَّا شَتْمُهُ إِيَّاىَ أَنْ يَقُولَ اتَّخَذَ اللَّهُ وَلَدًا، وَأَنَا الصَّمَدُ الَّذِي لَمْ أَلِدْ وَلَمْ أُولَدْ وَلَمْ يَكُنْ لِي كُفُؤًا أَحَدٌ ‏"‏‏.‏ ‏\{‏لَمْ يَلِدْ وَلَمْ يُولَدْ * وَلَمْ يَكُنْ لَهُ كُفُؤًا أَحَدٌ‏\}‏ كُفُؤًا وَكَفِيئًا وَكِفَاءً وَاحِدٌ‏.‏\hadithno{4975}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said:-- 'The son of Adam tells a lie against Me and he hasn't the right to do so; and he abuses me and he hasn't the right to do so. His telling a lie against Me is his saying that I will not recreate him as I created him for the first time; and his abusing Me is his saying that Allah has begotten children, while I am the self-sufficient Master, Whom all creatures need, Who begets not nor was He begotten, and there is none like unto Me}}
\hadithdefcmd{bukhari}{4976}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، وَعَبْدَةَ، عَنْ زِرِّ بْنِ حُبَيْشٍ، قَالَ سَأَلْتُ أُبَىَّ بْنَ كَعْبٍ عَنِ الْمُعَوِّذَتَيْنِ، فَقَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ قِيلَ لِي فَقُلْتُ فَنَحْنُ نَقُولُ كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{4976}\hadithtrans{Narrated Zirr bin Hubaish:I asked Ubai bin Ka`b regarding the two Muwwidhat (Surats of taking refuge with Allah). He said, "I asked the Prophet (ﷺ) about them, He said, 'These two Surats have been recited to me and I have recited them (and are present in the Qur'an).' So, we say as Allah's Messenger (ﷺ) said (i.e., they are part of the Qur'an)}}
\hadithdefcmd{bukhari}{4977}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَبْدَةُ بْنُ أَبِي لُبَابَةَ، عَنْ زِرِّ بْنِ حُبَيْشٍ، وَحَدَّثَنَا عَاصِمٌ، عَنْ زِرٍّ، قَالَ سَأَلْتُ أُبَىَّ بْنَ كَعْبٍ قُلْتُ يَا أَبَا الْمُنْذِرِ إِنَّ أَخَاكَ ابْنَ مَسْعُودٍ يَقُولُ كَذَا وَكَذَا‏.‏ فَقَالَ أُبَىٌّ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لِي قِيلَ لِي‏.‏ فَقُلْتُ، قَالَ فَنَحْنُ نَقُولُ كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{4977}\hadithtrans{Narrated Zirr bin Hubaish:I asked Ubai bin Ka`b, "O Abu AlMundhir! Your brother, Ibn Mas`ud said so-and-so (i.e., the two Mu'awwidh-at do not belong to the Qur'an)." Ubai said, "I asked Allah's Messenger (ﷺ) about them, and he said, 'They have been revealed to me, and I have recited them (as a part of the Qur'an)," So Ubai added, "So we say as Allah's Messenger (ﷺ) has said}}
