% Auto-generated chapter 21 for nasai
% Hadiths in this chapter: 272

\hadithdefcmd{nasai}{1818}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدٌ مِنْكُمُ الْمَوْتَ إِمَّا مُحْسِنًا فَلَعَلَّهُ أَنْ يَزْدَادَ خَيْرًا وَإِمَّا مُسِيئًا فَلَعَلَّهُ أَنْ يَسْتَعْتِبَ ‏"‏ ‏.‏\hadithno{1818}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"None of you should wish for death. Either he is a doer of good, so perhaps he may do more good, or he is an evildoer but perhaps he will give up his evil ways}}
\hadithdefcmd{nasai}{1819}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنَا الزُّبَيْدِيُّ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدُكُمُ الْمَوْتَ إِمَّا مُحْسِنًا فَلَعَلَّهُ أَنْ يَعِيشَ يَزْدَادُ خَيْرًا وَهُوَ خَيْرٌ لَهُ وَإِمَّا مُسِيئًا فَلَعَلَّهُ أَنْ يَسْتَعْتِبَ ‏"‏ ‏.‏\hadithno{1819}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Ubaid the freed slave of 'Abdur-Rahman bin Awf that he heard Abu Huraidah say:'None of you should wish for death. Either he is a doer of good, so if he lives he will do more good or he is a doer of evil but perhaps he will give up his evil ways}}
\hadithdefcmd{nasai}{1820}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدُكُمُ الْمَوْتَ لِضُرٍّ نَزَلَ بِهِ فِي الدُّنْيَا وَلَكِنْ لِيَقُلِ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏"‏ ‏.‏\hadithno{1820}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated form Anas that the Messenger of Allah said:"None of you should wish for death because of some harm that befalls him, rather he should say: 'Allahumma ahini ma kanatil-hayatu khairanli wa tawaffani idha kanatil-wafatu khairanli (O Allah, keep me alive so alive so long as life is good for me, and cause me to die when death is good for me)}}
\hadithdefcmd{nasai}{1821}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ، ح وَأَنْبَأَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ لاَ يَتَمَنَّى أَحَدُكُمُ الْمَوْتَ لِضُرٍّ نَزَلَ بِهِ فَإِنْ كَانَ لاَ بُدَّ مُتَمَنِّيًا الْمَوْتَ فَلْيَقُلِ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏"‏ ‏.‏\hadithno{1821}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah said: 'None of you should wish for death because of some harm that befalls him. If he must wish for death, let him say: Allahumma ahini ma kanatil-hayatu khairantli wa tawaffani idha kanatil-wafatu khairanli (O Allah, keep me alive so long as life is good for me, and cause me to die when death is good for me)}}
\hadithdefcmd{nasai}{1822}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنِ الْحَجَّاجِ، - وَهُوَ الْبَصْرِيُّ - عَنْ يُونُسَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَدْعُوا بِالْمَوْتِ وَلاَ تَتَمَنَّوْهُ فَمَنْ كَانَ دَاعِيًا لاَ بُدَّ فَلْيَقُلِ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏"‏ ‏.‏\hadithno{1822}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah said: 'Do not pray for death or wish for it. Whoever insists on praying for it let him say: Allahumma ahini ma kanatil-hayatu khairanli wa tawaffani idha kanatil-wafatu khairanli (O Allah, keep me alive so long as life is good for me, and cause me to die when death is good for me)}}
\hadithdefcmd{nasai}{1823}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي قَيْسٌ، قَالَ دَخَلْتُ عَلَى خَبَّابٍ وَقَدِ اكْتَوَى فِي بَطْنِهِ سَبْعًا وَقَالَ لَوْلاَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا أَنْ نَدْعُوَ بِالْمَوْتِ دَعَوْتُ بِهِ ‏.‏\hadithno{1823}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Qais said:"I entered upon Khabbab when he had been cauterized on his stomach seven times. He said: 'Were it not that the Messenger of Allah forbade us to pray for death, I would have prayed for it}}
\hadithdefcmd{nasai}{1824}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، ح وَأَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَكْثِرُوا ذِكْرَ هَاذِمِ اللَّذَّاتِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ مُحَمَّدُ بْنُ إِبْرَاهِيمَ وَالِدُ أَبِي بَكْرِ بْنِ أَبِي شَيْبَةَ ‏.‏\hadithno{1824}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Remember often the destroyer of pleasures."' (Hasan) Abu 'Abdur-Rahaman (An-Nasai) said: Muhammad bin Ibrahim (one of the narrators) is the father of Abu Bakr Ibn Abi Shaibah}}
\hadithdefcmd{nasai}{1825}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ يَحْيَى، عَنِ الأَعْمَشِ، قَالَ حَدَّثَنِي شَقِيقٌ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِذَا حَضَرْتُمُ الْمَرِيضَ فَقُولُوا خَيْرًا فَإِنَّ الْمَلاَئِكَةَ يُؤَمِّنُونَ عَلَى مَا تَقُولُونَ ‏"‏ ‏.‏ فَلَمَّا مَاتَ أَبُو سَلَمَةَ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَقُولُ قَالَ ‏"‏ قُولِي اللَّهُمَّ اغْفِرْ لَنَا وَلَهُ وَأَعْقِبْنِي مِنْهُ عُقْبَى حَسَنَةً ‏"‏ ‏.‏ فَأَعْقَبَنِي اللَّهُ عَزَّ وَجَلَّ مِنْهُ مُحَمَّدًا صلى الله عليه وسلم ‏.‏\hadithno{1825}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Umm Salamah said:"I heard the Messenger of Allah say: 'When you see the dead, say something good, for the angels say Amin to whatever you say; When Abu Salamah died, I said: 'O Messenger of Allah, what should I say?' He said: 'Say" Allahummaghfirlanaa wa lahu wa a 'qibni minhu 'uqbai hasanah (O Allah, forgive us and him, and compensate me well for this loss.)"' Then Allah, the Mighty and Sublime, compensated me with Muhammad}}
\hadithdefcmd{nasai}{1826}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، قَالَ حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ عُمَارَةَ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ، ح وَأَنْبَأَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقِّنُوا مَوْتَاكُمْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{1826}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Saeed said:"The Messenger of Allah said: 'Prompt your dying ones to say La ilaha illallah (there is none worthy of worship except Allah)}}
\hadithdefcmd{nasai}{1827}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنِي أَحْمَدُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا مَنْصُورُ ابْنُ صَفِيَّةَ، عَنْ أُمِّهِ، صَفِيَّةَ بِنْتِ شَيْبَةَ عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقِّنُوا هَلْكَاكُمْ قَوْلَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{1827}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'Prompt your dying ones to say La ilaha illahllah (there is none worthy of worship except Allah)}}
\hadithdefcmd{nasai}{1828}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَوْتُ الْمُؤْمِنِ بِعَرَقِ الْجَبِينِ ‏"‏ ‏.‏\hadithno{1828}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It is narrated from 'Abdullah bin Buraidah, from his father, that the Messenger of Allah said:"The believer dies with sweat on his forehead}}
\hadithdefcmd{nasai}{1829}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا يُوسُفُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا كَهْمَسٌ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْمُؤْمِنُ يَمُوتُ بِعَرَقِ الْجَبِينِ ‏"‏ ‏.‏\hadithno{1829}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from (Ibn Buraidah) that his father said:"I heard the Messenger of Allah say: 'The believer dies with sweat on his forehead}}
\hadithdefcmd{nasai}{1830}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي ابْنُ الْهَادِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِنَّهُ لَبَيْنَ حَاقِنَتِي وَذَاقِنَتِي فَلاَ أَكْرَهُ شِدَّةَ الْمَوْتِ لأَحَدٍ أَبَدًا بَعْدَ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1830}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah died while he was between my chest and my chin, and I never disliked the agony of death for anyone after I saw the Messenger of Allah}}
\hadithdefcmd{nasai}{1831}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ آخِرُ نَظْرَةٍ نَظَرْتُهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَشَفَ السِّتَارَةَ وَالنَّاسُ صُفُوفٌ خَلْفَ أَبِي بَكْرٍ رضى الله عنه فَأَرَادَ أَبُو بَكْرٍ أَنْ يَرْتَدَّ فَأَشَارَ إِلَيْهِمْ أَنِ امْكُثُوا وَأَلْقَى السِّجْفَ وَتُوُفِّيَ مِنْ آخِرِ ذَلِكَ الْيَوْمِ وَذَلِكَ يَوْمُ الاِثْنَيْنِ ‏.‏\hadithno{1831}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The last time I saw the Messenger of Allah, he drew back the curtain when the people were in rows behind Abu Bakr, may Allah be pleased with him. Abu Bakr wanted to step back, but he gestured to them to stay as they were, and let the curtain drop. He died at the end of that day, and that was a Monday}}
\hadithdefcmd{nasai}{1832}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي حُيَىُّ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ مَاتَ رَجُلٌ بِالْمَدِينَةِ مِمَّنْ وُلِدَ بِهَا فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ يَا لَيْتَهُ مَاتَ بِغَيْرِ مَوْلِدِهِ ‏"‏ ‏.‏ قَالُوا وَلِمَ ذَاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنَّ الرَّجُلَ إِذَا مَاتَ بِغَيْرِ مَوْلِدِهِ قِيسَ لَهُ مِنْ مَوْلِدِهِ إِلَى مُنْقَطَعِ أَثَرِهِ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1832}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"A man who had been born in Al-Madinah died there, and the Messenger of Allah prayed for him, then he said: 'Would that he had died somewhere other than the place where he was born.' They said: 'Why is that, O Messenger of Allah?' He said: If a man dies somewhere other than the place where he was born, a space in him equal to the distance between the place where he was born and the place where he died}}
\hadithdefcmd{nasai}{1833}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ قَسَامَةَ بْنِ زُهَيْرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا حُضِرَ الْمُؤْمِنُ أَتَتْهُ مَلاَئِكَةُ الرَّحْمَةِ بِحَرِيرَةٍ بَيْضَاءَ فَيَقُولُونَ اخْرُجِي رَاضِيَةً مَرْضِيًّا عَنْكِ إِلَى رَوْحِ اللَّهِ وَرَيْحَانٍ وَرَبٍّ غَيْرِ غَضْبَانَ ‏.‏ فَتَخْرُجُ كَأَطْيَبِ رِيحِ الْمِسْكِ حَتَّى أَنَّهُ لَيُنَاوِلُهُ بَعْضُهُمْ بَعْضًا حَتَّى يَأْتُونَ بِهِ بَابَ السَّمَاءِ فَيَقُولُونَ مَا أَطْيَبَ هَذِهِ الرِّيحَ الَّتِي جَاءَتْكُمْ مِنَ الأَرْضِ ‏.‏ فَيَأْتُونَ بِهِ أَرْوَاحَ الْمُؤْمِنِينَ فَلَهُمْ أَشَدُّ فَرَحًا بِهِ مِنْ أَحَدِكُمْ بِغَائِبِهِ يَقْدَمُ عَلَيْهِ فَيَسْأَلُونَهُ مَاذَا فَعَلَ فُلاَنٌ مَاذَا فَعَلَ فُلاَنٌ فَيَقُولُونَ دَعُوهُ فَإِنَّهُ كَانَ فِي غَمِّ الدُّنْيَا فَإِذَا قَالَ أَمَا أَتَاكُمْ قَالُوا ذُهِبَ بِهِ إِلَى أُمِّهِ الْهَاوِيَةِ وَإِنَّ الْكَافِرَ إِذَا احْتُضِرَ أَتَتْهُ مَلاَئِكَةُ الْعَذَابِ بِمِسْحٍ فَيَقُولُونَ اخْرُجِي سَاخِطَةً مَسْخُوطًا $$عَلَيْكِ إِلَى عَذَابِ اللَّهِ عَزَّ وَجَلَّ ‏.‏ فَتَخْرُجُ كَأَنْتَنِ رِيحِ جِيفَةٍ حَتَّى يَأْتُونَ بِهِ بَابَ الأَرْضِ فَيَقُولُونَ مَا أَنْتَنَ هَذِهِ الرِّيحَ حَتَّى يَأْتُونَ بِهِ أَرْوَاحَ الْكُفَّارِ ‏.‏\hadithno{1833}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"When the believer is dying, the angels of mercy come to him with white silk and sya: 'Come out content and with the pleasure of Allah upon you to the mercy of Allah, fragrance and a Lord Who is not angry; So it comes out like the best fragrance of musk. They pass him from one to another until they bring him to the gate of heaven, where they say: '; How good is this fragrance that has come to you from the Earth! Then the souls of the believers come to him and they rejoice more over him than any one of you rejoices when his absent loved one comes to him. They ask him: 'What happened to so-and-so, what happened to so-and-so?' They say: 'Let him be, for he was in the hardship of the world. When he says, 'Did he not come here?' They say: 'He was taken to the pit (of Hell).' Come out discontent, subject of Divine wrath, to the punishment of Allah, the Mighty and Sublime; So it comes out like the foulest stench of a corpse. They bring him to the gates of the Earth, where they say: 'How foul is this stench!' Then they bring him to the souls of the disbelievers}}
\hadithdefcmd{nasai}{1834}{أَخْبَرَنَا هَنَّادٌ، عَنْ أَبِي زُبَيْدٍ، - وَهُوَ عَبْثَرُ بْنُ الْقَاسِمِ - عَنْ مُطَرِّفٍ، عَنْ عَامِرٍ، عَنْ شُرَيْحِ بْنِ هَانِئٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ قَالَ شُرَيْحٌ فَأَتَيْتُ عَائِشَةَ فَقُلْتُ يَا أُمَّ الْمُؤْمِنِينَ سَمِعْتُ أَبَا هُرَيْرَةَ يَذْكُرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا إِنْ كَانَ كَذَلِكَ فَقَدْ هَلَكْنَا ‏.‏ قَالَتْ وَمَا ذَاكَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ وَلَكِنْ لَيْسَ مِنَّا أَحَدٌ إِلاَّ وَهُوَ يَكْرَهُ الْمَوْتَ قَالَتْ قَدْ قَالَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَيْسَ بِالَّذِي تَذْهَبُ إِلَيْهِ وَلَكِنْ إِذَا طَمَحَ الْبَصَرُ وَحَشْرَجَ الصَّدْرُ وَاقْشَعَرَّ الْجِلْدُ فَعِنْدَ ذَلِكَ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏.‏\hadithno{1834}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said; "The Messenger of Allah said:Allah loves to meet him, and whoever hates to meet Allah, Allah hates to meet him." (One of the narrators) Shuraih said: 'I went to Aishan and said: O mother of the believers! I heard Abu Hurairah narrate from the Messenger of Allah a Hadith which, if that is the case, we are all doomed. She said: 'What is that?' He said: 'The Messenger of Allah said: Whoever loves to meet him, and whoever hates to meet Allah, Allah hates to meet him. But there is no one among us who does not hate death.' She said: 'The Messenger of Allah did say that, but it is not what you think. When the eyes begin to stare, the death rattle sounds in the chest and the flesh shiver, at that point, whoever loves to meet Allah, Allah loves to meet him, and whoever hates to meet Allah, Allah hates to meet him}}
\hadithdefcmd{nasai}{1835}{أَخْبَرَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، حَدَّثَنِي مَالِكٌ، ح وَأَنْبَأَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْمُغِيرَةُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ تَعَالَى إِذَا أَحَبَّ عَبْدِي لِقَائِي أَحْبَبْتُ لِقَاءَهُ وَإِذَا كَرِهَ لِقَائِي كَرِهْتُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{1835}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: Allah, the Most High, said: If My slave loves to meet Me, I love to meet him, and if he hates to meet Me, I hate to meet him}}
\hadithdefcmd{nasai}{1836}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يُحَدِّثُ عَنْ عُبَادَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{1836}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Ubadah that the Prophet said:"Whoever loves to meet Allah, Allah loves to meet him, and whoever hates to meet Allah, Allah hates to meet him}}
\hadithdefcmd{nasai}{1837}{أَخْبَرَنَا أَبُو الأَشْعَثِ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{1837}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ubadah bin As-Samit said:"The Messenger of Allah said: 'whoever loves to meet Allah, Allah loves to meet him, and whoever hates to meet Allah, Allah, hates to meet him}}
\hadithdefcmd{nasai}{1838}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا سَعِيدٌ، ح وَأَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ خَالِدِ بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ زَادَ عَمْرٌو فِي حَدِيثِهِ فَقِيلَ يَا رَسُولَ اللَّهِ كَرَاهِيَةُ لِقَاءِ اللَّهِ كَرَاهِيَةُ الْمَوْتِ كُلُّنَا نَكْرَهُ الْمَوْتَ ‏.‏ قَالَ ‏"‏ ذَاكَ عِنْدَ مَوْتِهِ إِذَا بُشِّرَ بِرَحْمَةِ اللَّهِ وَمَغْفِرَتِهِ أَحَبَّ لِقَاءَ اللَّهِ وَأَحَبَّ اللَّهُ لِقَاءَهُ وَإِذَا بُشِّرَ بِعَذَابِ اللَّهِ كَرِهَ لِقَاءَ اللَّهِ وَكَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{1838}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"Whoever loves to meet Allah, Allah loves to meet him, and whoever hates to meet Allah, Allah, hates to meet him." Amr (one of the narrators) added in his narration: "t was said: 'O Messenger of Allah mean hating death? Fore all of us hate death.' He said; 'That is when he is dying; if he is given the glad tidings of the mercy and forgiveness of Allah, he loves to meet Allah and Allah loves to meet him. But if he is given the tidings of the punishment of Allah, he hates to meet Allah and Allah hates to meet him}}
\hadithdefcmd{nasai}{1839}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرٍو، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ، قَبَّلَ بَيْنَ عَيْنَىِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ مَيِّتٌ ‏.‏\hadithno{1839}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah:that Abu Bakr kissed the Prophet between the eyes when he had died}}
\hadithdefcmd{nasai}{1840}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي مُوسَى بْنُ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، وَعَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ، قَبَّلَ النَّبِيَّ صلى الله عليه وسلم وَهُوَ مَيِّتٌ ‏.‏\hadithno{1840}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas and Aishah:that Abu Bakr kissed the Prophet when he had died}}
\hadithdefcmd{nasai}{1841}{أَخْبَرَنَا سُوَيْدٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، قَالَ قَالَ مَعْمَرٌ وَيُونُسُ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي أَبُو سَلَمَةَ أَنَّ عَائِشَةَ أَخْبَرَتْهُ أَنَّ أَبَا بَكْرٍ أَقْبَلَ عَلَى فَرَسٍ مِنْ مَسْكَنِهِ بِالسُّنُحِ حَتَّى نَزَلَ فَدَخَلَ الْمَسْجِدَ فَلَمْ يُكَلِّمِ النَّاسَ حَتَّى دَخَلَ عَلَى عَائِشَةَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُسَجًّى بِبُرْدٍ حِبَرَةٍ فَكَشَفَ عَنْ وَجْهِهِ ثُمَّ أَكَبَّ عَلَيْهِ فَقَبَّلَهُ فَبَكَى ثُمَّ قَالَ بِأَبِي أَنْتَ وَاللَّهِ لاَ يَجْمَعُ اللَّهُ عَلَيْكَ مَوْتَتَيْنِ أَبَدًا أَمَّا الْمَوْتَةُ الَّتِي كَتَبَ اللَّهُ عَلَيْكَ فَقَدْ مُتَّهَا ‏.‏\hadithno{1841}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Aishah said that:Abu Bakr came riding a horse from his home in As-Sunuh, then he dismounted and entered the Masjid. He did not speak to the people until he met 'Aishah and the Messenger of Allah was covered with a Hibrah Burd. He uncovered his face, bent over him and kissed him, and wept. Then he said: "May my father be ransomed for you. By Allah! Allah will never cause you to die twice; the death that was decreed for you, you have died}}
\hadithdefcmd{nasai}{1842}{أَخْبَرَنِي مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ ابْنَ الْمُنْكَدِرِ، يَقُولُ سَمِعْتُ جَابِرًا، يَقُولُ جِيءَ بِأَبِي يَوْمَ أُحُدٍ وَقَدْ مُثِّلَ بِهِ فَوُضِعَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ سُجِّيَ بِثَوْبٍ فَجَعَلْتُ أُرِيدُ أَنْ أَكْشِفَ عَنْهُ فَنَهَانِي قَوْمِي فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَرُفِعَ فَلَمَّا رُفِعَ سَمِعَ صَوْتَ بَاكِيَةٍ فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ فَقَالُوا هَذِهِ بِنْتُ عَمْرٍو أَوْ أُخْتُ عَمْرٍو ‏.‏ قَالَ ‏"‏ فَلاَ تَبْكِي - أَوْ فَلِمَ تَبْكِي - مَا زَالَتِ الْمَلاَئِكَةُ تُظِلُّهُ بِأَجْنِحَتِهَا حَتَّى رُفِعَ ‏"‏ ‏.‏\hadithno{1842}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir said:"My father was brought on the day of Uhud and he had been mutilated. He was placed in front of the Messenger of Allah covered with a cloth. I wanted to uncover him but my people forbade m}}
\hadithdefcmd{nasai}{1843}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسِ، قَالَ لَمَّا حُضِرَتْ بِنْتٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم صَغِيرَةٌ فَأَخَذَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَضَمَّهَا إِلَى صَدْرِهِ ثُمَّ وَضَعَ يَدَهُ عَلَيْهَا فَقَضَتْ وَهِيَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَكَتْ أُمُّ أَيْمَنَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أُمَّ أَيْمَنَ أَتَبْكِينَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَكِ ‏"‏ ‏.‏ فَقَالَتْ مَا لِي لاَ أَبْكِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَبْكِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لَسْتُ أَبْكِي وَلَكِنَّهَا رَحْمَةٌ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمُؤْمِنُ بِخَيْرٍ عَلَى كُلِّ حَالٍ تُنْزَعُ نَفْسُهُ مِنْ بَيْنِ جَنْبَيْهِ وَهُوَ يَحْمَدُ اللَّهَ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{1843}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"When a young daughter of the Messenger of Allah was dying, the Messenger of Allah picked her up and held her to his chest, then he put his hand on her, and she died in front of the Messenger of Allah. Umm Ayman wept and the Messenger of Allah said 'Oh Umm Ayman, do you weep while the Messenger of Allah is with you?' She said: 'Why shouldn't I weep when the Messenger of Allah is weeping." So the Messenger of Allah said "Verily, I am not weeping. Rather it is compassion.' Then the Messenger of Allah said: 'The believer is fine whatever the situation; even when his soul is being pulled from his body and he praises Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{1844}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ فَاطِمَةَ، بَكَتْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ مَاتَ فَقَالَتْ يَا أَبَتَاهُ مِنْ رَبِّهِ مَا أَدْنَاهُ يَا أَبَتَاهُ إِلَى جِبْرِيلَ نَنْعَاهُ يَا أَبَتَاهُ جَنَّةُ الْفِرْدَوْسِ مَأْوَاهُ ‏.‏\hadithno{1844}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that Fatimah wept for the Messenger of Allah when he died. She said:"O my father, how close he is now to his Lord! O my father, we announce the news (of his death) to Jibril! O my father, Jannat Al-Firdawas is now his abode}}
\hadithdefcmd{nasai}{1845}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، أَنَّ أَبَاهُ، قُتِلَ يَوْمَ أُحُدٍ - قَالَ - فَجَعَلْتُ أَكْشِفُ عَنْ وَجْهِهِ، وَأَبْكِي، وَالنَّاسُ، يَنْهَوْنِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَنْهَانِي وَجَعَلَتْ عَمَّتِي تَبْكِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبْكِيهِ مَا زَالَتِ الْمَلاَئِكَةُ تُظِلُّهُ بِأَجْنِحَتِهَا حَتَّى رَفَعْتُمُوهُ ‏"‏ ‏.‏\hadithno{1845}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jabir that his father was killed on the day of Uhud. He saide:"I started to uncover his face, weeping. The people told me not to do that but the Messenger of Allah did not forbid me. My paternal aunt started to weep, and the Messenger of Allah said: 'Do not weep, for angels kept on shading him with their wings until you lifted him up}}
\hadithdefcmd{nasai}{1846}{أَخْبَرَنَا عُتْبَةُ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَبْرِ بْنِ عَتِيكٍ، أَنَّ عَتِيكَ بْنَ الْحَارِثِ، وَهُوَ جَدُّ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ أَبُو أُمِّهِ أَخْبَرَهُ أَنَّ جَبْرَ بْنَ عَتِيكٍ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم جَاءَ يَعُودُ عَبْدَ اللَّهِ بْنَ ثَابِتٍ فَوَجَدَهُ قَدْ غُلِبَ عَلَيْهِ فَصَاحَ بِهِ فَلَمْ يُجِبْهُ فَاسْتَرْجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ قَدْ غُلِبْنَا عَلَيْكَ أَبَا الرَّبِيعِ ‏"‏ ‏.‏ فَصِحْنَ النِّسَاءُ وَبَكَيْنَ فَجَعَلَ ابْنُ عَتِيكٍ يُسَكِّتُهُنَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعْهُنَّ فَإِذَا وَجَبَ فَلاَ تَبْكِيَنَّ بَاكِيَةٌ ‏"‏ ‏.‏ قَالُوا وَمَا الْوُجُوبُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْمَوْتُ ‏"‏ ‏.‏ قَالَتِ ابْنَتُهُ إِنْ كُنْتُ لأَرْجُو أَنْ تَكُونَ شَهِيدًا قَدْ كُنْتَ قَضَيْتَ جِهَازَكَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ أَوْقَعَ أَجْرَهُ عَلَيْهِ عَلَى قَدْرِ نِيَّتِهِ وَمَا تَعُدُّونَ الشَّهَادَةَ ‏"‏ ‏.‏ قَالُوا الْقَتْلُ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الشَّهَادَةُ سَبْعٌ سِوَى الْقَتْلِ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ الْمَطْعُونُ شَهِيدٌ وَالْمَبْطُونُ شَهِيدٌ وَالْغَرِيقُ شَهِيدٌ وَصَاحِبُ الْهَدْمِ شَهِيدٌ وَصَاحِبُ ذَاتِ الْجَنْبِ شَهِيدٌ وَصَاحِبُ الْحَرَقِ شَهِيدٌ وَالْمَرْأَةُ تَمُوتُ بِجُمْعٍ شَهِيدَةٌ ‏"‏ ‏.‏\hadithno{1846}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah bin 'Atik that 'Atik bin Al-Harith who was the grandfather of 'Abdullah bin 'Abdullah, his mother's fathr told him that the Jabir bin "Atik told him that:the Prophet came to visit 'Abdullah bin Thabit (when he was sick) and found him very close to death. He called out to him and he did not respond, so the Messenger of Allah said: "Truly, to Allah we belong and truly, to Him we shall return," and said: "We wanted you to live but we were overtaken by the decree of Allah, O Abu Ar-Rabi." The women screamed and wept, and Ibn "Atik started telling them to quiet. The Messenger of Allah said: "Leave them; when the inevitable comes, no one should weep." They said: "What is the inevitable, O Messenger of Allah?" He said: "Death." His daughter said: "I had hoped that you would become a martyr, for you had prepared yourself for it." The Messenger of Allah said: "Allah, the Mighty and Sublime, has rewarded him according to his intention. What do you think martyrdom is?" They said: "Being killed for the sake of Allah." The Messenger of Allah said: "Martyrdom is of seven types besides being killed for the sake of Allah. The one who dies of the plague is a martyr; the one who is crushed by a falling building is a martyr; the one who is crusheds by a falling building is a martyr; the one who dies of pleurisy is a martyr; the one who dies of pleurisy is a martyr; the one who is burned to death is a martyr, and the woman who dies in pregnancy is a martyr}}
\hadithdefcmd{nasai}{1847}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ قَالَ مُعَاوِيَةُ بْنُ صَالِحٍ وَحَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا أَتَى نَعْىُ زَيْدِ بْنِ حَارِثَةَ وَجَعْفَرِ بْنِ أَبِي طَالِبٍ وَعَبْدِ اللَّهِ بْنِ رَوَاحَةَ جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْرَفُ فِيهِ الْحُزْنُ وَأَنَا أَنْظُرُ مِنْ صِئْرِ الْبَابِ فَجَاءَهُ رَجُلٌ فَقَالَ إِنَّ نِسَاءَ جَعْفَرٍ يَبْكِينَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْطَلِقْ فَانْهَهُنَّ ‏"‏ ‏.‏ فَانْطَلَقَ ثُمَّ جَاءَ فَقَالَ قَدْ نَهَيْتُهُنَّ فَأَبَيْنَ أَنْ يَنْتَهِينَ ‏.‏ فَقَالَ ‏"‏ انْطَلِقْ فَانْهَهُنَّ ‏"‏ ‏.‏ فَانْطَلَقَ ثُمَّ جَاءَ فَقَالَ قَدْ نَهَيْتُهُنَّ فَأَبَيْنَ أَنْ يَنْتَهِينَ ‏.‏ قَالَ ‏"‏ فَانْطَلِقْ فَاحْثُ فِي أَفْوَاهِهِنَّ التُّرَابَ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ فَقُلْتُ أَرْغَمَ اللَّهُ أَنْفَ الأَبْعَدِ إِنَّكَ وَاللَّهِ مَا تَرَكْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَا أَنْتَ بِفَاعِلٍ ‏.‏\hadithno{1847}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:'When news of the death of Zaid bin Harithah, Ja'far bin Abi Talib and 'Abdullah bin Rawahah was announced, the Messenger of Allah sat down and it could be seen that he was grieving. I was looking through a crack in the door, and a man came and said: 'Ja'far's womenfolk are weeping.' The Messenger of Allah said: 'Go and prevent them.' He went away, then he came back, and said: I told them not to do that, but they refused to stop; He said: Go and prevent them; He went away then he came back, and said: I told them not to do that, but they refused to stop. He said: 'Throw dust in their mouths.'" Aishah said: "I said: 'May Allah rub his nose in the dust, the one who is over there! You did not leave the Messenger of Allah alone but you were not going to do (what he told you to do)}}
\hadithdefcmd{nasai}{1848}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَيِّتُ يُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1848}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar, from 'Umar, that the Prophet said:"The deceased is punished due to the weeping of his family for him}}
\hadithdefcmd{nasai}{1849}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ صُبَيْحٍ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ سِيرِينَ، يَقُولُ ذُكِرَ عِنْدَ عِمْرَانَ بْنِ حُصَيْنٍ الْمَيِّتُ يُعَذَّبُ بِبُكَاءِ الْحَىِّ فَقَالَ عِمْرَانُ قَالَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1849}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin Subaih said:"I heard Muhammad bin Sirin say: It was mentioned in the presence of 'Imran bin Husain that the deceased is punished due to the weeping of the living.' 'Imran said: "The Messenger of Allah said it}}
\hadithdefcmd{nasai}{1850}{أَخْبَرَنَا سُلَيْمَانُ بْنُ سَيْفٍ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ سَالِمٌ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ قَالَ عُمَرُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُعَذَّبُ الْمَيِّتُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1850}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Shihab said:"Salim said: 'I heard 'Abdullah bin 'Umar say: 'Umar said: The Messenger of Allah said: The deceased is punished due to his family's weeping for him}}
\hadithdefcmd{nasai}{1851}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ حَكِيمِ بْنِ قَيْسٍ، أَنَّ قَيْسَ بْنَ عَاصِمٍ، قَالَ لاَ تَنُوحُوا عَلَىَّ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يُنَحْ عَلَيْهِ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{1851}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Hakim bin Qais, that Qais bin 'Asim said:"Do not wail over me, for no one wailed over the Messenger of Allah." This is an abridgment}}
\hadithdefcmd{nasai}{1852}{أَخْبَرَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَ عَلَى النِّسَاءِ حِينَ بَايَعَهُنَّ أَنْ لاَ يَنُحْنَ فَقُلْنَ يَا رَسُولَ اللَّهِ إِنَّ نِسَاءً أَسْعَدْنَنَا فِي الْجَاهِلِيَّةِ أَفَنُسْعِدُهُنَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ إِسْعَادَ فِي الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{1852}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that:when the Messenger of Allah accepted the women's oath of allegiance, he accepted their pledge that they would not wail (over the death). They said: "O Messenger of Allah, there are women who helped us to mourn during the Jahiliyyah should we help them to mourn?" The Messenger of Allah said: "There is no helping to mourn in Islam}}
\hadithdefcmd{nasai}{1853}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْمَيِّتُ يُعَذَّبُ فِي قَبْرِهِ بِالنِّيَاحَةِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1853}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Umar said:"I heard the Messenger of Allah say: 'The deceased is punished in his grave due to the wailing over him}}
\hadithdefcmd{nasai}{1854}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، قَالَ أَنْبَأَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا مَنْصُورٌ، - هُوَ ابْنُ زَاذَانَ - عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ الْمَيِّتُ يُعَذَّبُ بِنِيَاحَةِ أَهْلِهِ عَلَيْهِ ‏.‏ فَقَالَ لَهُ رَجُلٌ أَرَأَيْتَ رَجُلاً مَاتَ بِخُرَاسَانَ وَنَاحَ أَهْلُهُ عَلَيْهِ هَا هُنَا أَكَانَ يُعَذَّبُ بِنِيَاحَةِ أَهْلِهِ قَالَ صَدَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَذَبْتَ أَنْتَ ‏.‏\hadithno{1854}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Imran bin Husain said:"The deceased is punished due to his family's wailing for him." A man said to him: "A man died in Khurasan and his family wailed for him here; will he be punished due to his family's wailing?" He said: "The Messenger of Allah spoke the truth and you are a liar}}
\hadithdefcmd{nasai}{1855}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ فَذُكِرَ ذَلِكَ لِعَائِشَةَ فَقَالَتْ وَهِلَ إِنَّمَا مَرَّ النَّبِيُّ صلى الله عليه وسلم عَلَى قَبْرٍ فَقَالَ ‏"‏ إِنَّ صَاحِبَ الْقَبْرِ لَيُعَذَّبُ وَإِنَّ أَهْلَهُ يَبْكُونَ عَلَيْهِ ‏"‏ ‏.‏ ثُمَّ قَرَأَتْ ‏\{‏ وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى ‏\}‏ ‏.‏\hadithno{1855}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said; "The Messenger of Allah said:'The deceased is punished due to his family's weeping over him; Mention of that was made to 'Aishah and she said: 'He is wrong; rather the Prophet passed by a grave and said: The occupant of this grave is being punished and his family are weeping for him." Then she recited: And no bearer of burdens shall bear another's burden}}
\hadithdefcmd{nasai}{1856}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، سَمِعَتْ عَائِشَةَ، وَذُكِرَ، لَهَا أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ الْحَىِّ عَلَيْهِ ‏.‏ قَالَتْ عَائِشَةُ يَغْفِرُ اللَّهُ لأَبِي عَبْدِ الرَّحْمَنِ أَمَا إِنَّهُ لَمْ يَكْذِبْ وَلَكِنْ نَسِيَ أَوْ أَخْطَأَ إِنَّمَا مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى يَهُودِيَّةٍ يُبْكَى عَلَيْهَا فَقَالَ ‏ "‏ إِنَّهُمْ لَيَبْكُونَ عَلَيْهَا وَإِنَّهَا لَتُعَذَّبُ ‏"‏ ‏.‏\hadithno{1856}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Amrah that she heard 'Aishah say:, when she was told that Ibn 'Umar said that the deceased is punished due to the weeping of the living for him, 'Aishah said: "May Allah forgive Abu 'Abdur-Rahman; he is not lying, but he has forgotten or made a mistake. The Messenger of Allah passed by a (deceased) Jewish woman for whom people were weeping and he said: 'They are weeping for her and she is being punished}}
\hadithdefcmd{nasai}{1857}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ بْنِ عَبْدِ الْجَبَّارِ، عَنْ سُفْيَانَ، قَالَ قَصَّهُ لَنَا عَمْرُو بْنُ دِينَارٍ قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، يَقُولُ قَالَ ابْنُ عَبَّاسٍ قَالَتْ عَائِشَةُ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَزِيدُ الْكَافِرَ عَذَابًا بِبَعْضِ بُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1857}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abbas said:"Aishah said: Rather the Messenger of Allah said: 'Allah, the Mighty and Sublime increases the punishment of the disbeliever due to some of his family's weeping for him}}
\hadithdefcmd{nasai}{1858}{أَخْبَرَنَا سُلَيْمَانُ بْنُ مَنْصُورٍ الْبَلْخِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْوَرْدِ، سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، يَقُولُ لَمَّا هَلَكَتْ أُمُّ أَبَانَ حَضَرْتُ مَعَ النَّاسِ فَجَلَسْتُ بَيْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ وَابْنِ عَبَّاسٍ فَبَكَيْنَ النِّسَاءُ فَقَالَ ابْنُ عُمَرَ أَلاَ تَنْهَى هَؤُلاَءِ عَنِ الْبُكَاءِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبَعْضِ بُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ قَدْ كَانَ عُمَرُ يَقُولُ بَعْضَ ذَلِكَ خَرَجْتُ مَعَ عُمَرَ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ رَأَى رَكْبًا تَحْتَ شَجَرَةٍ فَقَالَ انْظُرْ مَنِ الرَّكْبُ فَذَهَبْتُ فَإِذَا صُهَيْبٌ وَأَهْلُهُ فَرَجَعْتُ إِلَيْهِ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ هَذَا صُهَيْبٌ وَأَهْلُهُ ‏.‏ فَقَالَ عَلَىَّ بِصُهَيْبٍ ‏.‏ فَلَمَّا دَخَلْنَا الْمَدِينَةَ أُصِيبَ عُمَرُ فَجَلَسَ صُهَيْبٌ يَبْكِي عِنْدَهُ يَقُولُ وَاأُخَيَّاهُ وَاأُخَيَّاهُ ‏.‏ فَقَالَ عُمَرُ يَا صُهَيْبُ لاَ تَبْكِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبَعْضِ بُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَذَكَرْتُ ذَلِكَ لِعَائِشَةَ فَقَالَتْ أَمَا وَاللَّهِ مَا تُحَدِّثُونَ هَذَا الْحَدِيثَ عَنْ كَاذِبَيْنِ مُكَذَّبَيْنِ وَلَكِنَّ السَّمْعَ يُخْطِئُ وَإِنَّ لَكُمْ فِي الْقُرْآنِ لَمَا يَشْفِيكُمْ ‏\{‏ أَلاَّ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى ‏\}‏ وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ اللَّهَ لَيَزِيدُ الْكَافِرَ عَذَابًا بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1858}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abbul-Jabbar bin Al-Ward narrated:"I heard Ibn Abi Mulaikah say: 'When Umm Aban died, I attended with the people. I sat in front of 'Abdullah bin 'Umar and Ibn 'Abbas, and the women wept. Ibn 'Umar said: 'Why don't you tell them not to weep? For I heard the Messenger of Allah say: The deceased is punished due to some of his family's weeping for him."' Ibn 'Abbas said: "Umar used to narrate something like that. I went out with 'Umar and when we got to on uninhabited area, he saw a caravan beneath a tree. He said: 'See whose caravan this is.' I went and I found Suhaib and his family. I came back to him and said: 'O Commander of the Believers! This is Suhaib and his family.' He said: 'Bring Suhaib to me.' When we entered Al-Madinah, 'Umar was attacked and Suhaib sat by him, weeping and saying, 'O my brother, O my brother.' 'Umar said: 'O Suhaib, do not weep, for I heard the Messenger of Allah say: The deceased is punished due to some of the weeping of his family for him. He said: I mentioned that to 'Aishah and she said: 'By Allah you are not narrating this Hadith from two liars who have disbelieved, but sometimes you mishear. And no bearer of burdens shall bear another's burden. And the Messenger of Allah said: 'Allah increases the punishment of the disbeliever because of his family's weeping for him}}
\hadithdefcmd{nasai}{1859}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - هُوَ ابْنُ جَعْفَرٍ - عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، أَنَّ سَلَمَةَ بْنَ الأَزْرَقِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ مَاتَ مَيِّتٌ مِنْ آلِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاجْتَمَعَ النِّسَاءُ يَبْكِينَ عَلَيْهِ فَقَامَ عُمَرُ يَنْهَاهُنَّ وَيَطْرُدُهُنَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعْهُنَّ يَا عُمَرُ فَإِنَّ الْعَيْنَ دَامِعَةٌ وَالْقَلْبَ مُصَابٌ وَالْعَهْدَ قَرِيبٌ ‏"‏ ‏.‏\hadithno{1859}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muhammad bin 'Amr bin 'Ata that Salamah bin Al-Azraq said:"I heard Abu Hurairah say: 'Someone from the family of the Messenger of Allah died, and the women gathered, weeping for him. 'Umar stood up and told them not to do that, and threw them out, but the Messenger of Allah said: Let them be there, O 'Umar, for the eye weeps and the heart grieves, but soon we will join them}}
\hadithdefcmd{nasai}{1860}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ، قَالَ حَدَّثَنَا عِيسَى، عَنِ الأَعْمَشِ، ح أَنْبَأَنَا الْحَسَنُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ مِنَّا مَنْ ضَرَبَ الْخُدُودَ وَشَقَّ الْجُيُوبَ وَدَعَا بِدُعَاءِ الْجَاهِلِيَّةِ ‏"‏ ‏.‏ وَاللَّفْظُ لِعَلِيٍّ وَقَالَ الْحَسَنُ ‏"‏ بِدَعْوَى ‏"‏ ‏.‏\hadithno{1860}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah said: 'He is not one of us who strikes his cheeks, rends his garment, calls out the calls of the Jahiliyyah}}
\hadithdefcmd{nasai}{1861}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَوْفٍ، عَنْ خَالِدٍ الأَحْدَبِ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ، قَالَ أُغْمِيَ عَلَى أَبِي مُوسَى فَبَكَوْا عَلَيْهِ فَقَالَ أَبْرَأُ إِلَيْكُمْ كَمَا بَرِئَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْسَ مِنَّا مَنْ حَلَقَ وَلاَ خَرَقَ وَلاَ سَلَقَ ‏.‏\hadithno{1861}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Safwan bin Muhriz said:"Abu Musa fell unconscious and they wept for him. He said: 'I say to you the words of disavowal that the messenger of Allah said: He is not one of us who shaves his head (as a sign of mourning), rends his garments, or raises his voice in Lamentation}}
\hadithdefcmd{nasai}{1862}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي زُبَيْدٌ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنَّا مَنْ ضَرَبَ الْخُدُودَ وَشَقَّ الْجُيُوبَ وَدَعَا بِدَعْوَى الْجَاهِلِيَّةِ ‏"‏ ‏.‏\hadithno{1862}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah that the Prophet said:"He is not one of us who strikes his cheeks, rends his garment, and calls the calls of the Jahiliyyah}}
\hadithdefcmd{nasai}{1863}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ أَنْبَأَنَا جَعْفَرُ بْنُ عَوْفٍ، قَالَ حَدَّثَنَا أَبُو عُمَيْسٍ، عَنْ أَبِي صَخْرَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، وَأَبِي، بُرْدَةَ قَالاَ لَمَّا ثَقُلَ أَبُو مُوسَى أَقْبَلَتِ امْرَأَتُهُ تَصِيحُ - قَالاَ - فَأَفَاقَ فَقَالَ أَلَمْ أُخْبِرْكِ أَنِّي بَرِيءٌ مِمَّنْ بَرِئَ مِنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالاَ وَكَانَ يُحَدِّثُهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَنَا بَرِيءٌ مِمَّنْ حَلَقَ وَخَرَقَ وَسَلَقَ ‏"‏ ‏.‏\hadithno{1863}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sakhrah, that 'Abdur-Rahman bin Yazid and Abu Burdah said:"When Abu Musa was close to death, his wife started to scream." They said: "He woke up and said: 'Did I not tell you that I am free from what the Messenger of Allah is free?" They said: "He used to narrate that the Messenger of Allah said: 'I am free from the one who shaves his head, rends his garments or raises his voice in lamentation}}
\hadithdefcmd{nasai}{1864}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زُبَيْدٍ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنَّا مَنْ ضَرَبَ الْخُدُودَ وَشَقَّ الْجُيُوبَ وَدَعَا بِدَعْوَى الْجَاهِلِيَّةِ ‏"‏ ‏.‏\hadithno{1864}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah that the Prophet said:"He is not one of us who strikes his cheeks, rends his garment, and calls the calls of the Jahiliyyah}}
\hadithdefcmd{nasai}{1865}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ يَزِيدَ بْنِ أَوْسٍ، عَنْ أَبِي مُوسَى، أَنَّهُ أُغْمِيَ عَلَيْهِ فَبَكَتْ أُمُّ وَلَدٍ لَهُ فَلَمَّا أَفَاقَ قَالَ لَهَا أَمَا بَلَغَكِ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَأَلْنَاهَا فَقَالَتْ قَالَ ‏ "‏ لَيْسَ مِنَّا مَنْ سَلَقَ وَحَلَقَ وَخَرَقَ ‏"‏ ‏.‏\hadithno{1865}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Yazid bin Aws, that:Abu Musa said he fell unconscious and an Umm Walad of his wept. When he woke up, he asked her: "Have you not heard what the Messenger of Allah said?" She said: "He said: 'He is not one of us who raises his voice in lamentation, shaves his head, or rends his garments}}
\hadithdefcmd{nasai}{1866}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ يَزِيدَ بْنِ أَوْسٍ، عَنْ أُمِّ عَبْدِ اللَّهِ، امْرَأَةِ أَبِي مُوسَى عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَّا مَنْ حَلَقَ وَسَلَقَ وَخَرَقَ ‏"‏ ‏.‏\hadithno{1866}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Umm 'Abdullah, the wife of Abu Musa, that Abu Musa said:"The Messenger of Allah said: 'He is not one of us who shaves his head, raises his voice in lamentation or rends his garments}}
\hadithdefcmd{nasai}{1867}{أَخْبَرَنَا هَنَّادٌ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ سَهْمِ بْنِ مِنْجَابٍ، عَنِ الْقَرْثَعِ، قَالَ لَمَّا ثَقُلَ أَبُو مُوسَى صَاحَتِ امْرَأَتُهُ فَقَالَ أَمَا عَلِمْتِ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ بَلَى ‏.‏ ثُمَّ سَكَتَتْ فَقِيلَ لَهَا بَعْدَ ذَلِكَ أَىُّ شَىْءٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ مَنْ حَلَقَ أَوْ سَلَقَ أَوْ خَرَقَ ‏.‏\hadithno{1867}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Al-Qartha' said:"When Abu Musa was close to death, his wife screamed and he said: 'Do you not know what the Messenger of Allah said?" She said: 'Yes, Then she fell silent and it was said to her after that: 'What did the Messenger of Allah say?' She said: 'The Messenger of Allah cursed the one who shaves his head, raises his voice in lamentation or rends his garment}}
\hadithdefcmd{nasai}{1868}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَاصِمِ بْنِ سُلَيْمَانَ، عَنْ أَبِي عُثْمَانَ، قَالَ حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ، قَالَ أَرْسَلَتْ بِنْتُ النَّبِيِّ صلى الله عليه وسلم إِلَيْهِ أَنَّ ابْنًا لِي قُبِضَ فَأْتِنَا ‏.‏ فَأَرْسَلَ يَقْرَأُ السَّلاَمَ وَيَقُولُ ‏"‏ إِنَّ لِلَّهِ مَا أَخَذَ وَلَهُ مَا أَعْطَى وَكُلُّ شَىْءٍ عِنْدَ اللَّهِ بِأَجَلٍ مُسَمًّى فَلْتَصْبِرْ وَلْتَحْتَسِبْ ‏"‏ ‏.‏ فَأَرْسَلَتْ إِلَيْهِ تُقْسِمُ عَلَيْهِ لَيَأْتِيَنَّهَا فَقَامَ وَمَعَهُ سَعْدُ بْنُ عُبَادَةَ وَمُعَاذُ بْنُ جَبَلٍ وَأُبَىُّ بْنُ كَعْبٍ وَزَيْدُ بْنُ ثَابِتٍ وَرِجَالٌ فَرُفِعَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الصَّبِيُّ وَنَفْسُهُ تَقَعْقَعُ فَفَاضَتْ عَيْنَاهُ فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ مَا هَذَا قَالَ ‏"‏ هَذَا رَحْمَةٌ يَجْعَلُهَا اللَّهُ فِي قُلُوبِ عِبَادِهِ وَإِنَّمَا يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ الرُّحَمَاءَ ‏"‏ ‏.‏\hadithno{1868}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu 'Uthman said:"Usamah bin Zaid told me: 'The daughter of the Prophet sent word to him telling him: A son of mine is dying, come to us. He sent word to her, conveying his greeting of salam and saying: "To Allah belongs that which He takes and that which He gives, and everything has an appointed time with Allah. Let her be patient and seek reward." She sent word to him adjuring him to go to her. So he got up and went, accompanied by Sa'd bin 'Ubadah, Muadh bin Jabal, Ubayy bin Kab Zaid bin Thabit and some other men. The boy was lifted up to the Messenger of Allah, with the death rattle sounding in him, and his eyes filled with tears. Sa'd said: "O Messenger of Allah, what is this?" he said: "This is compassion which Allah has created in the hearts of His slaves. Allah has mercy on His compassionate slaves}}
\hadithdefcmd{nasai}{1869}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ ثَابِتٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصَّبْرُ عِنْدَ الصَّدْمَةِ الأُولَى ‏"‏ ‏.‏\hadithno{1869}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Thabit said:"I heard Anas say: 'The Messenger of Allah said: True patience is that which comes at the first blow}}
\hadithdefcmd{nasai}{1870}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا أَبُو إِيَاسٍ، - وَهُوَ مُعَاوِيَةُ بْنُ قُرَّةَ - عَنْ أَبِيهِ، رضى الله عنه أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم وَمَعَهُ ابْنٌ لَهُ فَقَالَ لَهُ ‏"‏ أَتُحِبُّهُ ‏"‏ ‏.‏ فَقَالَ أَحَبَّكَ اللَّهُ كَمَا أُحِبُّهُ ‏.‏ فَمَاتَ فَفَقَدَهُ فَسَأَلَ عَنْهُ فَقَالَ ‏"‏ مَا يَسُرُّكَ أَنْ لاَ تَأْتِيَ بَابًا مِنْ أَبْوَابِ الْجَنَّةِ إِلاَّ وَجَدْتَهُ عِنْدَهُ يَسْعَى يَفْتَحُ لَكَ ‏"‏ ‏.‏\hadithno{1870}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu lyas Mu'awiyah bin 'Qurrah narrated from his father that:a man came to the Prophet accompanied by a son of his. He said to him: "Do you love him?" He said: "May Allah love you as I love him." Then he (the son) died and he noticed his absence and asked about him. He said: "Will it not make you happy to know that you will not come to any of the gates of Paradise but you will find him there, trying to open it for you?}}
\hadithdefcmd{nasai}{1871}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، قَالَ أَنْبَأَنَا عُمَرُ بْنُ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، أَنَّ عَمْرَو بْنَ شُعَيْبٍ، كَتَبَ إِلَى عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي حُسَيْنٍ يُعَزِّيهِ بِابْنٍ لَهُ هَلَكَ وَذَكَرَ فِي كِتَابِهِ أَنَّهُ سَمِعَ أَبَاهُ يُحَدِّثُ عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ لاَ يَرْضَى لِعَبْدِهِ الْمُؤْمِنِ إِذَا ذَهَبَ بِصَفِيِّهِ مِنْ أَهْلِ الأَرْضِ فَصَبَرَ وَاحْتَسَبَ وَقَالَ مَا أُمِرَ بِهِ بِثَوَابٍ دُونَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1871}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Amr bin sa'eed bin Abi Husain told us that:'Amr bin Shu'aib wrote to 'Abdullah bin 'Abdur-Rahman bin Abi Husain to offer condolences for a son of his who had died. In his letter he mentioned that he had heard his father narrate, that his grandfather, 'Abdullah bin 'Amr bin Al-As said: "The Messenger of Allah said: 'Allah does not approve for His believing slave, if He takes away his loved one from among the people of the Earth, and he bears that with patience and seeks reward, and says that which he is commanded any reward less than Paradise}}
\hadithdefcmd{nasai}{1872}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عَمْرٌو، قَالَ حَدَّثَنِي بُكَيْرُ بْنُ عَبْدِ اللَّهِ، عَنْ عِمْرَانَ بْنِ نَافِعٍ، عَنْ حَفْصِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ احْتَسَبَ ثَلاَثَةً مِنْ صُلْبِهِ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ فَقَامَتِ امْرَأَةٌ فَقَالَتْ أَوِ اثْنَانِ قَالَ ‏"‏ أَوِ اثْنَانِ ‏"‏ ‏.‏ قَالَتِ الْمَرْأَةُ يَا لَيْتَنِي قُلْتُ وَاحِدًا ‏.‏\hadithno{1872}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that the Messenger of Allah said:"Whoever seeks reward for (the loss of) three of his own children, he will enter Paradise." A woman stood up and said: "Or two?" He said: "Or two." The woman said: "I wish that I had said, 'or one}}
\hadithdefcmd{nasai}{1873}{أَخْبَرَنَا يُوسُفُ بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمٍ يُتَوَفَّى لَهُ ثَلاَثَةٌ مِنَ الْوَلَدِ لَمْ يَبْلُغُوا الْحِنْثَ إِلاَّ أَدْخَلَهُ اللَّهُ الْجَنَّةَ بِفَضْلِ رَحْمَتِهِ إِيَّاهُمْ ‏"‏ ‏.‏\hadithno{1873}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah said: 'There is no Muslim, three of whose children die before reaching puberty, but Allah will admit him to Paradise by virtue of His mercy towards them}}
\hadithdefcmd{nasai}{1874}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ صَعْصَعَةَ بْنِ مُعَاوِيَةَ، قَالَ لَقِيتُ أَبَا ذَرٍّ قُلْتُ حَدِّثْنِي ‏.‏ قَالَ نَعَمْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمَيْنِ يَمُوتُ بَيْنَهُمَا ثَلاَثَةُ أَوْلاَدٍ لَمْ يَبْلُغُوا الْحِنْثَ إِلاَّ غَفَرَ اللَّهُ لَهُمَا بِفَضْلِ رَحْمَتِهِ إِيَّاهُمْ ‏"‏ ‏.‏\hadithno{1874}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'sa'ah bin Mu'awiyah said:"I met Abu Dharr and said: 'Tell me a Hadith.' He said: the Messenger of Allah said: There are no two Muslims, three of whose children die before reaching puberty, but Allah will forgive them by virtue of His mercy towards them}}
\hadithdefcmd{nasai}{1875}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمُوتُ لأَحَدٍ مِنَ الْمُسْلِمِينَ ثَلاَثَةٌ مِنَ الْوَلَدِ فَتَمَسَّهُ النَّارُ إِلاَّ تَحِلَّةَ الْقَسَمِ ‏"‏ ‏.‏\hadithno{1875}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"No Muslim, three of whose children die, will be touched by the Fire, except in fulfillment of the (Divine) oath}}
\hadithdefcmd{nasai}{1876}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ ابْنِ عُلَيَّةَ، وَعَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا إِسْحَاقُ، - وَهُوَ الأَزْرَقُ - عَنْ عَوْفٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ مُسْلِمَيْنِ يَمُوتُ بَيْنَهُمَا ثَلاَثَةُ أَوْلاَدٍ لَمْ يَبْلُغُوا الْحِنْثَ إِلاَّ أَدْخَلَهُمَا اللَّهُ بِفَضْلِ رَحْمَتِهِ إِيَّاهُمُ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ ‏"‏ يُقَالُ لَهُمُ ادْخُلُوا الْجَنَّةَ فَيَقُولُونَ حَتَّى يَدْخُلَ آبَاؤُنَا فَيُقَالُ ادْخُلُوا الْجَنَّةَ أَنْتُمْ وَآبَاؤُكُمْ ‏"‏ ‏.‏\hadithno{1876}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"There are no two Muslims, three of whose children die before reaching puberty, but Allah will admit them to Paradise by virtue of His mercy toward them. It will be said to them: 'Enter Paradise.' They will say: 'Not until our parents enter.' So it will be said: 'Enter Paradise, you and your parents}}
\hadithdefcmd{nasai}{1877}{أَخْبَرَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا جَرِيرٌ، قَالَ حَدَّثَنِي طَلْقُ بْنُ مُعَاوِيَةَ، وَحَفْصُ بْنُ غِيَاثٍ، قَالَ حَدَّثَنِي جَدِّي، طَلْقُ بْنُ مُعَاوِيَةَ عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِابْنٍ لَهَا يَشْتَكِي فَقَالَتْ يَا رَسُولَ اللَّهِ أَخَافُ عَلَيْهِ وَقَدْ قَدَّمْتُ ثَلاَثَةً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقَدِ احْتَظَرْتِ بِحِظَارٍ شَدِيدٍ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{1877}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"A woman came to the Messenger of Allah with a son of hers who was ill and said: 'O Messenger of Allah, I fear for him, and I have already lost three.' The Messenger of Allah said: "You have a great protection against the Hellfire}}
\hadithdefcmd{nasai}{1878}{أَخْبَرَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى زَيْدًا وَجَعْفَرًا قَبْلَ أَنْ يَجِيءَ خَبَرُهُمْ فَنَعَاهُمْ وَعَيْنَاهُ تَذْرِفَانِ ‏.‏\hadithno{1878}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas:that the Messenger of Allah announced the news of the death of Zaid and Ja'far before news of them came. He announced their death and his eyes were overflowing with tears}}
\hadithdefcmd{nasai}{1879}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، وَابْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُمَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى لَهُمُ النَّجَاشِيَّ صَاحِبَ الْحَبَشَةِ الْيَوْمَ الَّذِي مَاتَ فِيهِ وَقَالَ ‏ "‏ اسْتَغْفِرُوا لأَخِيكُمْ ‏"‏ ‏.‏\hadithno{1879}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Salamah and Ibn Al-Musayyab narrated that Abu Hurairah told them, that:the Messenger of Allah had told them of the death of An-Najashi, the ruler of Ethiopia, on the day that he died, and he said: "Pray for forgiveness for your brother}}
\hadithdefcmd{nasai}{1880}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، هُوَ ابْنُ يَزِيدَ الْمُقْرِئُ ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَعِيدٌ حَدَّثَنِي رَبِيعَةُ بْنُ سَيْفٍ الْمَعَافِرِيُّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ بَيْنَمَا نَحْنُ نَسِيرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ بَصُرَ بِامْرَأَةٍ لاَ تَظُنُّ أَنَّهُ عَرَفَهَا فَلَمَّا تَوَسَّطَ الطَّرِيقَ وَقَفَ حَتَّى انْتَهَتْ إِلَيْهِ فَإِذَا فَاطِمَةُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ لَهَا ‏"‏ مَا أَخْرَجَكِ مِنْ بَيْتِكِ يَا فَاطِمَةُ ‏"‏ ‏.‏ قَالَتْ أَتَيْتُ أَهْلَ هَذَا الْمَيِّتِ فَتَرَحَّمْتُ إِلَيْهِمْ وَعَزَّيْتُهُمْ بِمَيِّتِهِمْ ‏.‏ قَالَ ‏"‏ لَعَلَّكِ بَلَغْتِ مَعَهُمُ الْكُدَى ‏"‏ ‏.‏ قَالَتْ مَعَاذَ اللَّهِ أَنْ أَكُونَ بَلَغْتُهَا وَقَدْ سَمِعْتُكَ تَذْكُرُ فِي ذَلِكَ مَا تَذْكُرُ ‏.‏ فَقَالَ لَهَا ‏"‏ لَوْ بَلَغْتِهَا مَعَهُمْ مَا رَأَيْتِ الْجَنَّةَ حَتَّى يَرَاهَا جَدُّ أَبِيكِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ رَبِيعَةُ ضَعِيفٌ ‏.‏\hadithno{1880}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Rabiah bin Saif Al-Mu'afiri narrated from Abu 'Abdur-Rahman Al-Hubuli, from 'Abdullah bin 'Amr, who said:"while we were traveling with the Messenger of Allah, he saw a woman, and did not think that he knew her. When she was halfway to him, he stopped until she reached him, and it was Fatimah, the daughter of the Messenger of Allah. He said to her: 'What brought you out of your house, O Fatimah?' She said: 'I came to the people of this deceased one to pray for mercy for them, and to offer my condolences to them.' He said: 'Perhaps you went with them to Al-Kuda?" She said: 'Allah forbid that I should go there. I heard what you said about that.' He said: If you had gone there with them, you would never have seen Paradise until the grandfather of your father saw it}}
\hadithdefcmd{nasai}{1881}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، أَنَّ أُمَّ عَطِيَّةَ الأَنْصَارِيَّةَ، قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ تُوُفِّيَتِ ابْنَتُهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ ذَلِكِ بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَعْطَانَا حَقْوَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{1881}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Muhammad bin Sirin that Umm 'Atiyyah Al-Ansariyyah said:"The Messenger of Allah entered upon us when his daughter died, and said: 'Wash her three times or five, or more if you think (that is needed), with water and lote leaves, and put some camphor in it the last time, and when you have finished call me.' When we finished we called him and he gave us his waist-wrap, and said: 'Shroud her in it}}
\hadithdefcmd{nasai}{1882}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْحَسَنِ، مَوْلَى أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ عَنْ أُمِّ قَيْسٍ، قَالَتْ تُوُفِّيَ ابْنِي فَجَزِعْتُ عَلَيْهِ فَقُلْتُ لِلَّذِي يَغْسِلُهُ لاَ تَغْسِلِ ابْنِي بِالْمَاءِ الْبَارِدِ فَتَقْتُلَهُ ‏.‏ فَانْطَلَقَ عُكَّاشَةُ بْنُ مِحْصَنٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِقَوْلِهَا فَتَبَسَّمَ ثُمَّ قَالَ ‏ "‏ مَا قَالَتْ طَالَ عُمْرُهَا ‏"‏ ‏.‏ فَلاَ نَعْلَمُ امْرَأَةً عُمِرَتْ مَا عُمِرَتْ ‏.‏\hadithno{1882}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Al-Hasan, the freed slave of Umm Qais bint Mihsan, that Umm Qais said:"My son died, and I felt very sad. I said to the one who was washing him: 'Do not wash my son with cold water and kill him." 'Ukashah bin Mihsan went to the Messenger of Allah and told him what she had said, and he smiled then said: "What did she say, may Allah give her long life?" And we do not know of any woman who lived as long as she lived}}
\hadithdefcmd{nasai}{1883}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَيُّوبُ سَمِعْتُ حَفْصَةَ، تَقُولُ حَدَّثَتْنَا أُمُّ عَطِيَّةَ، أَنَّهُنَّ جَعَلْنَ رَأْسَ ابْنَةِ النَّبِيِّ صلى الله عليه وسلم ثَلاَثَةَ قُرُونٍ ‏.‏ قُلْتُ نَقَضْنَهُ وَجَعَلْنَهُ ثَلاَثَةَ قُرُونٍ قَالَتْ نَعَمْ ‏.‏\hadithno{1883}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ayyub:"I heard Hafsah saying: 'Umm 'Atiyyah said: They tied the hair of the daughter of the Prophet in three braids."' 'I said: Did they undo it, then make three braids? She said: 'Yes}}
\hadithdefcmd{nasai}{1884}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ خَالِدٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي غُسْلِ ابْنَتِهِ ‏ "‏ ابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ مِنْهَا ‏"‏ ‏.‏\hadithno{1884}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm 'Atiyyah that:the Messenger of Allah said concerning the washing of his daughter: "Start on the right and the parts that were washed in wudu}}
\hadithdefcmd{nasai}{1885}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَتْنَا حَفْصَةُ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ مَاتَتْ إِحْدَى بَنَاتِ النَّبِيِّ صلى الله عليه وسلم فَأَرْسَلَ إِلَيْنَا فَقَالَ ‏"‏ اغْسِلْنَهَا بِمَاءٍ وَسِدْرٍ وَاغْسِلْنَهَا وَتْرًا ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا إِنْ رَأَيْتُنَّ ذَلِكِ وَاجْعَلْنَ فِي الآخِرَةِ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَلْقَى إِلَيْنَا حَقْوَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏ وَمَشَطْنَاهَا ثَلاَثَةَ قُرُونٍ وَأَلْقَيْنَاهَا مِنْ خَلْفِهَا ‏.‏\hadithno{1885}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Umm 'Atiyyah said:"One of the daughters of the Prophet died, and he sent word to us saying: 'Wash her with water and lotus leaves, and wash her an odd number of times, three, or five, or seven if you think (that is needed), and put some camphor in it the last time. And when you have finished, inform me.' When we finished, we finished, we informed him, and he threw his informed him, and he threw his waist-wrap to us and said: 'Shroud her in it.' And we combed her hair and put it in three braids, and put it behind her}}
\hadithdefcmd{nasai}{1886}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ يَزِيدَ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَغْسِلُ ابْنَتَهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ ذَلِكِ بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَلْقَى إِلَيْنَا حَقْوَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{1886}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm 'Atiyyah said:"The Messenger of Allah entered upon us when we were washing his daughter and said: 'Wash her three times or five, or more if you think (that is necessary), with water and lotus leaves, and put camphor, or some camphor in it the last time. And when you have finished, inform me.' When we finished, we informed him, and he threw his waist-wrap to us and said: 'Shroud her in it}}
\hadithdefcmd{nasai}{1887}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ تُوُفِّيَتْ إِحْدَى بَنَاتِ النَّبِيِّ صلى الله عليه وسلم فَأَرْسَلَ إِلَيْنَا فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَلْقَى إِلَيْنَا حَقْوَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{1887}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm 'Atiyyah said:"The Messenger of Allah entered upon us while we were washing his daughter and said: 'Wash her three times, or five or more if you think (that is necessary), with water and lotus leaves, and put camphor, or some camphor in it the last time. And when you have finished, inform me.' When we finished, we informed him, and he threw his waist-wrap to us, and said: Shroud her in it}}
\hadithdefcmd{nasai}{1888}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، نَحْوَهُ غَيْرَ أَنَّهُ قَالَ ‏ "‏ ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ ذَلِكِ ‏"‏ ‏.‏\hadithno{1888}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Something similar was narrated from Umm 'Atiyyah except, that he (the narrator) said:"Three times or five, or seven, or more than that, if you think that (is necessary)}}
\hadithdefcmd{nasai}{1889}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، عَنْ سَلَمَةَ بْنِ عَلْقَمَةَ، عَنْ مُحَمَّدٍ، عَنْ بَعْضِ، إِخْوَتِهِ عَنْ أُمِّ عَطِيَّةَ، قَالَتْ تُوُفِّيَتِ ابْنَةٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَنَا بِغَسْلِهَا فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ ‏"‏ ‏.‏ قَالَتْ قُلْتُ وِتْرًا قَالَ ‏"‏ نَعَمْ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَعْطَانَا حَقْوَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{1889}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm 'Atiyyah said:"A daughter of the Messenger of Allah died and he told us to wash her. He said: 'Three times, or five or seven, or more than that, if you think that (is necessary).' I said: 'An odd number?' He said: 'Yes, and put camphor, or some camphor, in (the water) the last time. And when you have finished, inform me.' So when you have finished, we informed him, and then gave us his waist-wrap and said: 'Shroud her in it}}
\hadithdefcmd{nasai}{1890}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَغْسِلُ ابْنَتَهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ ذَلِكِ بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَلْقَى إِلَيْنَا حَقْوَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏ قَالَ أَوْ قَالَتْ حَفْصَةُ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا ‏.‏ قَالَ وَقَالَتْ أُمُّ عَطِيَّةَ مَشَطْنَاهَا ثَلاَثَةَ قُرُونٍ ‏.‏\hadithno{1890}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ayyub, from Muhammad, that Umm 'Atiyyah said:"The Messenger of Allah came to us when we were washing his daughter. He said: 'Wash her three times, or five, or more than that if you think that (is necessary), with water and lotus leaves, and put camphor, or some camphor in (the water) the last time. And when you have finished, inform me.' When we finished, we informed him and he threw his waist-wrap to us and said: 'Shroud her in it."' He said: "Hafsah said: 'We washed her three, or five, or seven times.' Umm 'Atiyyah said: 'We combed her hair into three braids}}
\hadithdefcmd{nasai}{1891}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، قَالَ أَخْبَرَتْنِي حَفْصَةُ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ وَجَعَلْنَا رَأْسَهَا ثَلاَثَةَ قُرُونٍ ‏.‏\hadithno{1891}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ayyub narrated from Muhammad, who said:"Hafsah informed me that Umm 'Atiyyah said: 'We put her hair in three braids}}
\hadithdefcmd{nasai}{1892}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، وَقَالَتْ، حَفْصَةُ عَنْ أُمِّ عَطِيَّةَ، وَجَعَلْنَا، رَأْسَهَا ثَلاَثَةَ قُرُونٍ ‏.‏\hadithno{1892}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hammad reported from Ayyub:"And Hafsah said, from Umm 'Atiyyah: 'We put her hair in three braids}}
\hadithdefcmd{nasai}{1893}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَيُّوبُ بْنُ أَبِي تَمِيمَةَ، أَنَّهُ سَمِعَ مُحَمَّدَ بْنَ سِيرِينَ، يَقُولُ كَانَتْ أُمُّ عَطِيَّةَ امْرَأَةٌ مِنَ الأَنْصَارِ قَدِمَتْ تُبَادِرُ ابْنًا لَهَا فَلَمْ تُدْرِكْهُ حَدَّثَتْنَا قَالَتْ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَيْنَا وَنَحْنُ نَغْسِلُ ابْنَتَهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا أَلْقَى إِلَيْنَا حَقْوَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏ وَلَمْ يَزِدْ عَلَى ذَلِكَ ‏.‏ قَالَ لاَ أَدْرِي أَىُّ بَنَاتِهِ ‏.‏ قَالَ قُلْتُ مَا قَوْلُهُ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏ أَتُؤَزَّرُ بِهِ قَالَ لاَ أُرَاهُ إِلاَّ أَنْ يَقُولَ الْفُفْنَهَا فِيهِ ‏.‏\hadithno{1893}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Muhammad bin Sirin said:"Umm 'Atiyyah was a woman from among the Ansar who told us: 'The Prophet entered upon us while we were washing his daughter and said: "Wash her three times, or five, or more than that if you think that (is necessary), with water and lotus leaves, and put camphor, or some camphor in it the last time. And when you have finished, inform me." So when we finished we informed him, and he threw his waist-wrap to us and said: "Shroud her in it." And he did not add to that. He (the narrator) said: "I do not know which of his daughters that was." I said: "What did he mean by: 'Shroud her in it?' Did he mean to put it on like an Izar?" He said: "No, I think he meant to wrap her completely}}
\hadithdefcmd{nasai}{1894}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ النَّسَائِيُّ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ تُوُفِّيَ إِحْدَى بَنَاتِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ ذَلِكِ وَاغْسِلْنَهَا بِالسِّدْرِ وَالْمَاءِ وَاجْعَلْنَ فِي آخِرِ ذَلِكِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ قَالَتْ فَآذَنَّاهُ فَأَلْقَى إِلَيْنَا حَقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{1894}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Umm 'Atiyyah said:"One of the daughters of the Prophet died and he said: 'Wash her three times, or five, or more than that if you think that (is necessary). Wash her with water and lotus leaves and put camphor, or some camphor in it the last time. And when you have finished inform me.' We informed him, and he threw his waist-wrapper to us and said: 'Shroud her in it}}
\hadithdefcmd{nasai}{1895}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ الرَّقِّيُّ الْقَطَّانُ، وَيُوسُفُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لَهُ - قَالَ أَنْبَأَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ رَجُلاً مِنْ أَصْحَابِهِ مَاتَ فَقُبِرَ لَيْلاً وَكُفِّنَ فِي كَفَنٍ غَيْرِ طَائِلٍ فَزَجَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُقْبَرَ إِنْسَانٌ لَيْلاً إِلاَّ أَنْ يُضْطَرَّ إِلَى ذَلِكَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَلِيَ أَحَدُكُمْ أَخَاهُ فَلْيُحَسِّنْ كَفَنَهُ ‏"‏ ‏.‏\hadithno{1895}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Juraij said:"Abu Az-Zubair told me that he heard Jabir say; 'The Messenger of Allah delivered a speech and mentioned a man among his Companions who had died. He had been buried at night and wrapped in a shroud that was not sufficient. The Messenger of Allah rebuked (them) and said that no one should be buried at night unless constrained to do that. And the Messenger of Allah said: When one of you wants to takes care of his brother, let him shroud him well}}
\hadithdefcmd{nasai}{1896}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ أَبِي عَرُوبَةَ، يُحَدِّثُ عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَسُوا مِنْ ثِيَابِكُمُ الْبَيَاضَ فَإِنَّهَا أَطْهَرُ وَأَطْيَبُ وَكَفِّنُوا فِيهَا مَوْتَاكُمْ ‏"‏ ‏.‏\hadithno{1896}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Juraij sad:"Abu Az-Zubair told me that he heard Jabir say: "The Messenger of Allah delivered a speech and mentioned a man among his Companions who had died. He had been buried at night and wrapped in a shroud that was not sufficient. The Messenger of Allah reduced (them) and said that no one should be buried at night unless constrained to do that. And the Messenger of Allah said: When one of you wants to takes care of his brother, let him shroud him well}}
\hadithdefcmd{nasai}{1897}{أَخْبَرَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُفِّنَ النَّبِيُّ صلى الله عليه وسلم فِي ثَلاَثَةِ أَثْوَابٍ سُحُولِيَّةٍ بِيضٍ ‏.‏\hadithno{1897}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Samurah that the Prophet said:"Wear white clothes for they are purer and better, and shroud your dead in them}}
\hadithdefcmd{nasai}{1898}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ سُحُولِيَّةٍ لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ ‏.‏\hadithno{1898}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Prophet was shrouded in three white Suhuli garments}}
\hadithdefcmd{nasai}{1899}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَفْصٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُفِّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ يَمَانِيَةٍ كُرْسُفٍ لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ فَذُكِرَ لِعَائِشَةَ قَوْلُهُمْ فِي ثَوْبَيْنِ وَبُرْدٍ مِنْ حِبَرَةٍ فَقَالَتْ قَدْ أُتِيَ بِالْبُرْدِ وَلَكِنَّهُمْ رَدُّوهُ وَلَمْ يُكَفِّنُوهُ فِيهِ ‏.‏\hadithno{1899}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Hisham narrated from his father, from 'Aishah that:the Messenger of Allah was shrouded in three white Yemeni garments of cotton, among which was no shirt and no turban. It was mentioned to 'Aishah that they said: "He was buried in two garments and a Burd made of Hibrah." She said: "A Burd was brought, but they sent it back and did not shroud him in it}}
\hadithdefcmd{nasai}{1900}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنَا نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ لَمَّا مَاتَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ جَاءَ ابْنُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَعْطِنِي قَمِيصَكَ حَتَّى أُكَفِّنَهُ فِيهِ وَصَلِّ عَلَيْهِ وَاسْتَغْفِرْ لَهُ ‏.‏ فَأَعْطَاهُ قَمِيصَهُ ثُمَّ قَالَ ‏"‏ إِذَا فَرَغْتُمْ فَآذِنُونِي أُصَلِّي عَلَيْهِ ‏"‏ ‏.‏ فَجَذَبَهُ عُمَرُ وَقَالَ قَدْ نَهَاكَ اللَّهُ أَنْ تُصَلِّيَ عَلَى الْمُنَافِقِينَ ‏.‏ فَقَالَ ‏"‏ أَنَا بَيْنَ خِيرَتَيْنِ ‏"‏ ‏.‏ قَالَ ‏\{‏ اسْتَغْفِرْ لَهُمْ أَوْ لاَ تَسْتَغْفِرْ لَهُمْ ‏\}‏ فَصَلَّى عَلَيْهِ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا وَلاَ تَقُمْ عَلَى قَبْرِهِ ‏\}‏ فَتَرَكَ الصَّلاَةَ عَلَيْهِمْ ‏.‏\hadithno{1900}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"When 'Abdullah bin Ubayy died, his son came to the Prophet and said: 'Give me your shirt so that I may shroud him in it, and (some and) offer the (funeral) prayer for him, and pray for forgiveness for him'. So he gave him his shirt then he said: 'When you have finished, inform me and I will offer the (funeral) prayer for him.' But 'Umar stopped him and said: 'Hasn't Allah forbidden you to offer the (funeral) prayer for the hypocrites?' He said: 'I have two options. Whether you ask forgiveness for them (hypocrites) or ask no forgiveness for them." So he offered the (funeral) prayer for him. Then Allah, Most High, revealed: 'And never pray (funeral prayer) for any of them (hypocrites) who dies, nor stand at his grave.' So he stopped offering the (funeral) prayer for them}}
\hadithdefcmd{nasai}{1901}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ بْنِ عَبْدِ الْجَبَّارِ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ أَتَى النَّبِيُّ صلى الله عليه وسلم قَبْرَ عَبْدِ اللَّهِ بْنِ أُبَىٍّ وَقَدْ وُضِعَ فِي حُفْرَتِهِ فَوَقَفَ عَلَيْهِ فَأَمَرَ بِهِ فَأُخْرِجَ لَهُ فَوَضَعَهُ عَلَى رُكْبَتَيْهِ وَأَلْبَسَهُ قَمِيصَهُ وَنَفَثَ عَلَيْهِ مِنْ رِيقِهِ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{1901}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sufyan, from 'Amr who said he heard Jabir say:"The Prophet came to the grave of 'Abdullah bin Ubayy when he had been placed in his grave and stood over it. He commanded that he be brought out to him and placed on his knees, and he dressed him in his shirt and blew on him (for blessing). And Allah knows best}}
\hadithdefcmd{nasai}{1902}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الزُّهْرِيُّ الْبَصْرِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ جَابِرًا، يَقُولُ وَكَانَ الْعَبَّاسُ بِالْمَدِينَةِ فَطَلَبَتِ الأَنْصَارُ ثَوْبًا يَكْسُونَهُ فَلَمْ يَجِدُوا قَمِيصًا يَصْلُحُ عَلَيْهِ إِلاَّ قَمِيصَ عَبْدِ اللَّهِ بْنِ أُبَىٍّ فَكَسَوْهُ إِيَّاهُ ‏.‏\hadithno{1902}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr heard Jabir say:"And Al-'Abass was in Al-Madinah, and he asked the Ansar for a garment to clothe him in, but they could not find a shirt that would fit him except the shirt of 'Abdullah bin Ubayy, so they clothed him in it}}
\hadithdefcmd{nasai}{1903}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ الأَعْمَشِ، ح وَأَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، قَالَ سَمِعْتُ الأَعْمَشَ، قَالَ سَمِعْتُ شَقِيقًا، قَالَ حَدَّثَنَا خَبَّابٌ، قَالَ هَاجَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَبْتَغِي وَجْهَ اللَّهِ تَعَالَى فَوَجَبَ أَجْرُنَا عَلَى اللَّهِ فَمِنَّا مَنْ مَاتَ لَمْ يَأْكُلْ مِنْ أَجْرِهِ شَيْئًا مِنْهُمْ مُصْعَبُ بْنُ عُمَيْرٍ قُتِلَ يَوْمَ أُحُدٍ فَلَمْ نَجِدْ شَيْئًا نُكَفِّنُهُ فِيهِ إِلاَّ نَمِرَةً كُنَّا إِذَا غَطَّيْنَا رَأْسَهُ خَرَجَتْ رِجْلاَهُ وَإِذَا غَطَّيْنَا بِهَا رِجْلَيْهِ خَرَجَتْ رَأْسُهُ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُغَطِّيَ بِهَا رَأْسَهُ وَنَجْعَلَ عَلَى رِجْلَيْهِ إِذْخِرًا وَمِنَّا مَنْ أَيْنَعَتْ لَهُ ثَمَرَتُهُ فَهُوَ يَهْدِبُهَا ‏.‏ وَاللَّفْظُ لإِسْمَاعِيلَ ‏.‏\hadithno{1903}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Khabbab said:"We emigrated with the Messenger of Allah, seeking the Face of Allah, the Most High, so our reward became due from Allah. Some of us died without enjoying anything of his reward (in this world) among them is Mus'ab bin Umair. He was matyred on the day of Uhud and we could not find anything to shroud him in except a Namirah; if we covered his head with it, his feet were uncovered, and if we covered his feet with it, his head became uncovered. The Messenger of Allah told us to cover his head with it and to put Idhkhir over his feet. And for some of us, the fruits of our labor have ripened and we are gathering them." This is the wording of Isma'il}}
\hadithdefcmd{nasai}{1904}{أَخْبَرَنَا عُتْبَةُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يُونُسُ بْنُ نَافِعٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوا الْمُحْرِمَ فِي ثَوْبَيْهِ اللَّذَيْنِ أَحْرَمَ فِيهِمَا وَاغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْهِ وَلاَ تُمِسُّوهُ بِطِيبٍ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُحْرِمًا ‏"‏ ‏.‏\hadithno{1904}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said: 'Wash the Muhrim in the two garments in which he entered Ihram, and wash him with water and lotus leaves, and shroud him in his two garments, and do not put perfume on him nor cover his head, for he will be raised on the Day of Resurrection in Ihram}}
\hadithdefcmd{nasai}{1905}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، وَشَبَابَةُ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ خُلَيْدِ بْنِ جَعْفَرٍ، سَمِعَ أَبَا نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَطْيَبُ الطِّيبِ الْمِسْكُ ‏"‏ ‏.‏\hadithno{1905}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah said: "The best of perfume is musk}}
\hadithdefcmd{nasai}{1906}{أَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ الدِّرْهَمِيُّ، قَالَ حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، عَنِ الْمُسْتَمِرِّ بْنِ الرَّيَّانِ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِنْ خَيْرِ طِيبِكُمُ الْمِسْكُ ‏"‏ ‏.‏\hadithno{1906}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah said: 'One of the best of your perfumes is musk}}
\hadithdefcmd{nasai}{1907}{أَخْبَرَنَا قُتَيْبَةُ، فِي حَدِيثِهِ عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّهُ أَخْبَرَهُ أَنَّ مِسْكِينَةً مَرِضَتْ فَأُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَرَضِهَا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُ الْمَسَاكِينَ وَيَسْأَلُ عَنْهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا مَاتَتْ فَآذِنُونِي ‏"‏ ‏.‏ فَأُخْرِجَ بِجَنَازَتِهَا لَيْلاً وَكَرِهُوا أَنْ يُوقِظُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَلَمَّا أَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم أُخْبِرَ بِالَّذِي كَانَ مِنْهَا فَقَالَ ‏"‏ أَلَمْ آمُرْكُمْ أَنْ تُؤْذِنُونِي بِهَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَرِهْنَا أَنْ نُوقِظَكَ لَيْلاً ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى صَفَّ بِالنَّاسِ عَلَى قَبْرِهَا وَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{1907}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Umamah bin Sahl bin Hunaif that:a poor woman fell sick and the Messenger of Allah was informed of her sickness. The Messenger of Allah used to visit the poor when they were sick and ask about them. The Messnger of Allah said: "If she dies, then inform me." Then her funeral took place at night and they did not like to wake the Messenger of Allah. When morning came, the Messenger of Allah was told what had happened to her. He said: "Did I not tell you to inform me?" They said: "O Messenger of Allah, we did not like to wake you up at night." The Messenger of Allah went out and the people lined up by her grave and he said four Takbirs}}
\hadithdefcmd{nasai}{1908}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مِهْرَانَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا وُضِعَ الرَّجُلُ الصَّالِحُ عَلَى سَرِيرِهِ قَالَ قَدِّمُونِي قَدِّمُونِي وَإِذَا وُضِعَ الرَّجُلُ - يَعْنِي السُّوءَ - عَلَى سَرِيرِهِ قَالَ يَا وَيْلِي أَيْنَ تَذْهَبُونَ بِي ‏"‏ ‏.‏\hadithno{1908}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin Mihran that Abu Huraiyrah said:"I heard the Messenger of Allah say: 'When the righteous man is placed on his bier, he says: Take me quickly, take me quickly. And when the bad man is placed on his bier he said: Woe to me! Where are you taking me?}}
\hadithdefcmd{nasai}{1909}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وُضِعَتِ الْجَنَازَةُ فَاحْتَمَلَهَا الرِّجَالُ عَلَى أَعْنَاقِهِمْ فَإِنْ كَانَتْ صَالِحَةً قَالَتْ قَدِّمُونِي قَدِّمُونِي وَإِنْ كَانَتْ غَيْرَ صَالِحَةٍ قَالَتْ يَا وَيْلَهَا إِلَى أَيْنَ تَذْهَبُونَ بِهَا يَسْمَعُ صَوْتَهَا كُلُّ شَىْءٍ إِلاَّ الإِنْسَانَ وَلَوْ سَمِعَهَا الإِنْسَانُ لَصَعِقَ ‏"‏ ‏.‏\hadithno{1909}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Sa'eed Al-Khudri said:"The Messenger of Allah said: 'When the Janazah (prepared body) is placed (on the bier) and the men lift it onto their shoulders, if it was a righteous person it says: Take me quickly, take me quickly. And if it was not a righteous person it says: Woe to me! Where are you taking me! And everything hears its voice except man, and if man heard it he would faint}}
\hadithdefcmd{nasai}{1910}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْرِعُوا بِالْجَنَازَةِ فَإِنْ تَكُ صَالِحَةً فَخَيْرٌ تُقَدِّمُونَهَا إِلَيْهِ وَإِنْ تَكُ غَيْرَ ذَلِكَ فَشَرٌّ تَضَعُونَهُ عَنْ رِقَابِكُمْ ‏"‏ ‏.‏\hadithno{1910}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah, who attributed it to the Prophet:"Hasten with the Janazah, for if it was righteous then your are taking it toward something good, and if it was otherwise, then it is an evil of which you are relieving yourselves}}
\hadithdefcmd{nasai}{1911}{أَخْبَرَنَا سُوَيْدٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو أُمَامَةَ بْنُ سَهْلٍ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَسْرِعُوا بِالْجَنَازَةِ فَإِنْ كَانَتْ صَالِحَةً قَدَّمْتُمُوهَا إِلَى الْخَيْرِ وَإِنْ كَانَتْ غَيْرَ ذَلِكَ كَانَتْ شَرًّا تَضَعُونَهُ عَنْ رِقَابِكُمْ ‏"‏ ‏.‏\hadithno{1911}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah say: ,Hsten with the Janazah, for if it was righteous then you are taking it toward something good, and if it was otherwise, then it is an evil of which you are relieving yourselves}}
\hadithdefcmd{nasai}{1912}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ أَنْبَأَنَا عُيَيْنَةُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ جَوْشَنٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، شَهِدْتُ جَنَازَةَ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ وَخَرَجَ زِيَادٌ يَمْشِي بَيْنَ يَدَىِ السَّرِيرِ فَجَعَلَ رِجَالٌ مِنْ أَهْلِ عَبْدِ الرَّحْمَنِ وَمَوَالِيهِمْ يَسْتَقْبِلُونَ السَّرِيرَ وَيَمْشُونَ عَلَى أَعْقَابِهِمْ وَيَقُولُونَ رُوَيْدًا رُوَيْدًا بَارَكَ اللَّهُ فِيكُمْ ‏.‏ فَكَانُوا يَدِبُّونَ دَبِيبًا حَتَّى إِذَا كُنَّا بِبَعْضِ طَرِيقِ الْمِرْبَدِ لَحِقَنَا أَبُو بَكْرَةَ عَلَى بَغْلَةٍ فَلَمَّا رَأَى الَّذِي يَصْنَعُونَ حَمَلَ عَلَيْهِمْ بِبَغْلَتِهِ وَأَهْوَى إِلَيْهِمْ بِالسَّوْطِ وَقَالَ خَلُّوا فَوَالَّذِي أَكْرَمَ وَجْهَ أَبِي الْقَاسِمِ صلى الله عليه وسلم لَقَدْ رَأَيْتُنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِنَّا لَنَكَادُ نَرْمُلُ بِهَا رَمْلاً ‏.‏ فَانْبَسَطَ الْقَوْمُ ‏.‏\hadithno{1912}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Uyaynah bin 'Abdur-Rahman bin Jawsh said:"My father told me: I witnessed the funeral of 'Abdur-Rahamn bin Samurah. Ziyad came out, walking in front of the bier, and some men from the family of 'Abdur-Rahman and their freed slaves came out, facing the bier and walking backward, saying: 'Slow down, slow down, may Allah bless you.' And they were walking slowly. Then when they were partway to Al-Mrbad, Abu Bakrah joined us on his mule. When he saw what they were doing, he rushed to them on his mule, brandishing his whip, and said: 'Move on, for by the One Who honored the face of Abu Al-Qasim, I remember when we were with the Messenger of Allah, we were walking fast, so the people speeded up}}
\hadithdefcmd{nasai}{1913}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ، وَهُشَيْمٍ، عَنْ عُيَيْنَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرَةَ، قَالَ لَقَدْ رَأَيْتُنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِنَّا لَنَكَادُ نَرْمُلُ بِهَا رَمَلاً ‏.‏ وَاللَّفْظُ حَدِيثُ هُشَيْمٍ ‏.‏\hadithno{1913}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Bakrah said:"I remember when we were with the Messnger of Allah, and we were walking fast with it (the Janazah)." This is the wording of Hushaim}}
\hadithdefcmd{nasai}{1914}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، عَنْ يَحْيَى، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَرَّتْ بِكُمْ جَنَازَةٌ فَقُومُوا فَمَنْ تَبِعَهَا فَلاَ يَقْعُدْ حَتَّى تُوضَعَ ‏"‏ ‏.‏\hadithno{1914}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed that the Messenger of Allah said:"When a funeral passes by you, stand up, and whoever follows it, let him not sit down until it is put down (in the grave)}}
\hadithdefcmd{nasai}{1915}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عَامِرِ بْنِ رَبِيعَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَى أَحَدُكُمُ الْجَنَازَةَ فَلَمْ يَكُنْ مَاشِيًا مَعَهَا فَلْيَقُمْ حَتَّى تُخَلِّفَهُ أَوْ تُوضَعَ مِنْ قَبْلِ أَنْ تُخَلِّفَهُ ‏"‏ ‏.‏\hadithno{1915}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Amir bin Rabi'ah that the Prophet said:"When any one of you sees a funeral and is not walking with it, let him stand up until it has passed him, or until (the body) is placed (in the grave) before if passes him}}
\hadithdefcmd{nasai}{1916}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ عَامِرِ بْنِ رَبِيعَةَ الْعَدَوِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا حَتَّى تُخَلِّفَكُمْ أَوْ تُوضَعَ ‏"‏ ‏.‏\hadithno{1916}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated form 'Amir bin Rabi'ah Al-'Adawi that the Messenger of Allah said:"When you see a funeral, stand up until it has passed you, or (the body) is placed (in the grave)}}
\hadithdefcmd{nasai}{1917}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ هِشَامٍ، ح وَأَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا فَمَنْ تَبِعَهَا فَلاَ يَقْعُدْ حَتَّى تُوضَعَ ‏"‏ ‏.‏\hadithno{1917}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah said: 'When you see a funeral, stand up, and whoever follows it, let him not sit down until (the body) is placed (in the grave)}}
\hadithdefcmd{nasai}{1918}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، وَأَبِي، سَعِيدٍ قَالاَ مَا رَأَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم شَهِدَ جَنَازَةً قَطُّ فَجَلَسَ حَتَّى تُوضَعَ ‏.‏\hadithno{1918}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah and Abu Sa'eed said:"We never saw the Messenger of Allah attend any funeral where he sat down until (the body) was placed (in the grave)}}
\hadithdefcmd{nasai}{1919}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا زَكَرِيَّا، عَنِ الشَّعْبِيِّ، قَالَ قَالَ أَبُو سَعِيدٍ ح وَأَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا أَبُو زَيْدٍ، سَعِيدُ بْنُ الرَّبِيعِ قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، قَالَ سَمِعْتُ الشَّعْبِيَّ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرُّوا عَلَيْهِ بِجَنَازَةٍ فَقَامَ ‏.‏ وَقَالَ عَمْرٌو إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّتْ بِهِ جَنَازَةٌ فَقَامَ ‏.‏\hadithno{1919}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa'eed that a funeral passed by the Messenger of Allah and he stood up. (One of the narrators) 'Amr said:"If a funeral passed by the Messenger of Allah he would stand up}}
\hadithdefcmd{nasai}{1920}{أَخْبَرَنِي أَيُّوبُ بْنُ مُحَمَّدٍ الْوَزَّانُ، قَالَ حَدَّثَنَا مَرْوَانُ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، قَالَ أَخْبَرَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، عَنْ عَمِّهِ، يَزِيدَ بْنِ ثَابِتٍ أَنَّهُمْ كَانُوا جُلُوسًا مَعَ النَّبِيِّ صلى الله عليه وسلم فَطَلَعَتْ جَنَازَةٌ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَامَ مَنْ مَعَهُ فَلَمْ يَزَالُوا قِيَامًا حَتَّى نَفَذَتْ ‏.‏\hadithno{1920}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated form Yazid bin Thabit:That they were sitting with the Messenger of Allah when a funeral appeared. The Messenger of Allah stood up, and those who were with him stood up, until it had passed by}}
\hadithdefcmd{nasai}{1921}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ كَانَ سَهْلُ بْنُ حُنَيْفٍ وَقَيْسُ بْنُ سَعْدِ بْنِ عُبَادَةَ بِالْقَادِسِيَّةِ فَمُرَّ عَلَيْهِمَا بِجَنَازَةٍ فَقَامَا فَقِيلَ لَهُمَا إِنَّهَا مِنْ أَهْلِ الأَرْضِ ‏.‏ فَقَالاَ مُرَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِجَنَازَةٍ فَقَامَ فَقِيلَ لَهُ إِنَّهُ يَهُودِيٌّ ‏.‏ فَقَالَ ‏ "‏ أَلَيْسَتْ نَفْسًا ‏"‏ ‏.‏\hadithno{1921}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdur-Rahman bin Abi Laila said:"Sahl bin Hunaif and Qais bin Sa'd bin 'Ubadah were in Al-Qadisiyyah when a funeral passed by them, so they stood up and it was said to them: 'It is one of the local people.' They said: 'A funeral passed the Messenger of Allah and he stood up, and it was said to him: It Is a Jew. He said: 'Is it not a soul?}}
\hadithdefcmd{nasai}{1922}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ هِشَامٍ، ح وَأَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ مَرَّتْ بِنَا جَنَازَةٌ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقُمْنَا مَعَهُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا هِيَ جَنَازَةُ يَهُودِيَّةٍ ‏.‏ فَقَالَ ‏ "‏ إِنَّ لِلْمَوْتِ فَزَعًا فَإِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا ‏"‏ ‏.‏ اللَّفْظُ لِخَالِدٍ ‏.‏\hadithno{1922}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"A funeral passed by us and the Messenger of Allah stood up and we stood with him. I said: 'O Messenger of Allah, it is a Jewish funeral.' He said: 'Death is something terrifying, so if you see a funeral, stand up,"' This is the wording of Khalid}}
\hadithdefcmd{nasai}{1923}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، قَالَ كُنَّا عِنْدَ عَلِيٍّ فَمَرَّتْ جَنَازَةٌ فَقَامُوا لَهَا فَقَالَ عَلِيٌّ مَا هَذَا قَالُوا أَمْرُ أَبِي مُوسَى ‏.‏ فَقَالَ إِنَّمَا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِجَنَازَةِ يَهُودِيَّةٍ وَلَمْ يَعُدْ بَعْدَ ذَلِكَ ‏.‏\hadithno{1923}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Ma'mar said:"We were with 'Ali and a funeral passed by him, and they stood up for it. 'Ali said: "What is this?' They said: 'The command of Abu Musa.' He said: 'Rather the Messenger of Allah stood up for a Jewish funeral but he did not do it again}}
\hadithdefcmd{nasai}{1924}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، أَنَّ جَنَازَةً، مَرَّتْ بِالْحَسَنِ بْنِ عَلِيٍّ وَابْنِ عَبَّاسٍ فَقَامَ الْحَسَنُ وَلَمْ يَقُمِ ابْنُ عَبَّاسٍ فَقَالَ الْحَسَنُ أَلَيْسَ قَدْ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِجَنَازَةِ يَهُودِيٍّ قَالَ ابْنُ عَبَّاسٍ نَعَمْ ثُمَّ جَلَسَ ‏.‏\hadithno{1924}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Muhammad that:a funeral passed by Al-Hasan bin 'Ali and Ibn 'Abbas. Al-Hasan stood up but Ibn 'Abbas did not/ Al-Hasan said: 'Didn't the Messenger of Allah stand up for the funeral of a Jew?' Ibn 'Abbas said: 'Yes, then he sat down}}
\hadithdefcmd{nasai}{1925}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا مَنْصُورٌ، عَنِ ابْنِ سِيرِينَ، قَالَ مُرَّ بِجَنَازَةٍ عَلَى الْحَسَنِ بْنِ عَلِيٍّ وَابْنِ عَبَّاسٍ فَقَامَ الْحَسَنُ وَلَمْ يَقُمِ ابْنُ عَبَّاسٍ فَقَالَ الْحَسَنُ لاِبْنِ عَبَّاسٍ أَمَا قَامَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ابْنُ عَبَّاسٍ قَامَ لَهَا ثُمَّ قَعَدَ ‏.‏\hadithno{1925}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Sirin said:"A funeral passed by Al-Hasan bin 'Ali and Ibn 'Abbas. Al-Hasan stood up but Ibn 'Abbas did not. Al-Hasan said to Ibn 'Abbas: 'Didn't the Messengr of Allah stand up for it?' Ibn 'Abbas said: 'He stood up for it then he sat}}
\hadithdefcmd{nasai}{1926}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ عُلَيَّةَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي مِجْلَزٍ، عَنِ ابْنِ عَبَّاسٍ، وَالْحَسَنِ بْنِ عَلِيٍّ، مَرَّتْ بِهِمَا جَنَازَةٌ فَقَامَ أَحَدُهُمَا وَقَعَدَ الآخَرُ فَقَالَ الَّذِي قَامَ أَمَا وَاللَّهِ لَقَدْ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ قَامَ قَالَ لَهُ الَّذِي جَلَسَ لَقَدْ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ جَلَسَ ‏.‏\hadithno{1926}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas and Al-Hasan bin 'Ali that:a funeral passed by them and one of them stood and the other sat. The one who stood up said: "By Allah, I know that the Messnger of Allah stood up." The one who was sitting said: "I know that the Messenger of Allah sat}}
\hadithdefcmd{nasai}{1927}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ هَارُونَ الْبَلْخِيُّ، قَالَ حَدَّثَنَا حَاتِمٌ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ الْحَسَنَ بْنَ عَلِيٍّ، كَانَ جَالِسًا فَمُرَّ عَلَيْهِ بِجَنَازَةٍ فَقَامَ النَّاسُ حَتَّى جَاوَزَتِ الْجَنَازَةُ فَقَالَ الْحَسَنُ إِنَّمَا مُرَّ بِجَنَازَةِ يَهُودِيٍّ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى طَرِيقِهَا جَالِسًا فَكَرِهَ أَنْ تَعْلُوَ رَأْسَهُ جَنَازَةُ يَهُودِيٍّ فَقَامَ ‏.‏\hadithno{1927}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ja'far bin Muhammad from his father that:Al-Hasan bin 'Ali was sitting when a funeral passed by. The People stood until the funeral had passed, and Al-Hasan said: "The funeral of Jew passed by when the Messenger of Allah was sitting in its path, and he did not want the funeral of a Jew to pass over his head, so he stood up}}
\hadithdefcmd{nasai}{1928}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم لِجَنَازَةِ يَهُودِيٍّ مَرَّتْ بِهِ حَتَّى تَوَارَتْ ‏.‏ وَأَخْبَرَنِي أَبُو الزُّبَيْرِ، أَيْضًا أَنَّهُ سَمِعَ جَابِرًا، رَضِيَ اللَّهُ عَنْهُ يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ لِجَنَازَةِ يَهُودِيٍّ حَتَّى تَوَارَتْ ‏.‏\hadithno{1928}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Az-Zubair narrated that he heard Jabir say:"The Prophet and his Companions stood up for the funeral of Jew that passed by him, until it disappeared." (In another narration) Jabir said: "The Prophet and his Companions stood up for the funeral of a Jew until it disappeared}}
\hadithdefcmd{nasai}{1929}{أَخْبَرَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا النَّضْرُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ جَنَازَةً، مَرَّتْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ فَقِيلَ إِنَّهَا جَنَازَةُ يَهُودِيٍّ ‏.‏ فَقَالَ ‏ "‏ إِنَّمَا قُمْنَا لِلْمَلاَئِكَةِ ‏"‏ ‏.‏\hadithno{1929}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that:a funeral passed by the Messenger of Allah and he stood up. It was said: "It is the funeral of a Jew." He said: "We stood up for the angels}}
\hadithdefcmd{nasai}{1930}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ مَعْبَدِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ بْنِ رِبْعِيٍّ، أَنَّهُ كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مُرَّ عَلَيْهِ بِجَنَازَةٍ فَقَالَ ‏"‏ مُسْتَرِيحٌ وَمُسْتَرَاحٌ مِنْهُ ‏"‏ ‏.‏ فَقَالُوا مَا الْمُسْتَرِيحُ وَمَا الْمُسْتَرَاحُ مِنْهُ قَالَ ‏"‏ الْعَبْدُ الْمُؤْمِنُ يَسْتَرِيحُ مِنْ نَصَبِ الدُّنْيَا وَأَذَاهَا وَالْعَبْدُ الْفَاجِرُ يَسْتَرِيحُ مِنْهُ الْعِبَادُ وَالْبِلاَدُ وَالشَّجَرُ وَالدَّوَابُّ ‏"‏ ‏.‏\hadithno{1930}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Qatadah bin Raib'i that he used to narrate:"A funeral passed by the Messenger of Allah and he said: 'He is relieved and others are relieved of him.' They said: 'What does relieved mean and what does relieved of him mean: He said: "The believing slave is relieved of the hardships and troubles of this world, and the people, the land, the trees and the animals are relieved of the immoral slave}}
\hadithdefcmd{nasai}{1931}{أَخْبَرَنَا مُحَمَّدُ بْنُ وَهْبِ بْنِ أَبِي كَرِيمَةَ الْحَرَّانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، - وَهُوَ الْحَرَّانِيُّ - عَنْ أَبِي عَبْدِ الرَّحِيمِ، حَدَّثَنِي زَيْدٌ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ مَعْبَدِ بْنِ كَعْبٍ، عَنْ أَبِي قَتَادَةَ، قَالَ كُنَّا جُلُوسًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ طَلَعَتْ جَنَازَةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُسْتَرِيحٌ وَمُسْتَرَاحٌ مِنْهُ الْمُؤْمِنُ يَمُوتُ فَيَسْتَرِيحُ مِنْ أَوْصَابِ الدُّنْيَا وَنَصَبِهَا وَأَذَاهَا وَالْفَاجِرُ يَمُوتُ فَيَسْتَرِيحُ مِنْهُ الْعِبَادُ وَالْبِلاَدُ وَالشَّجَرُ وَالدَّوَابُّ ‏"‏ ‏.‏\hadithno{1931}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Qatadah said:"We were sitting with the Messenger of Allah when a funeral appeared. The Messenger of Allah said: 'He is relieved and others are relieved of him. When the believer dies he is relieved of the calamities, hardships and troubles of this world, and when the evildoer dies, the people, the land, the trees and the animals are relieved of him}}
\hadithdefcmd{nasai}{1932}{أَخْبَرَنِي زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ مُرَّ بِجَنَازَةٍ فَأُثْنِيَ عَلَيْهَا خَيْرًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ وَمُرَّ بِجَنَازَةٍ أُخْرَى فَأُثْنِيَ عَلَيْهَا شَرًّا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ فَقَالَ عُمَرُ فِدَاكَ أَبِي وَأُمِّي مُرَّ بِجَنَازَةِ فَأُثْنِيَ عَلَيْهَا خَيْرًا فَقُلْتَ ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ وَمُرَّ بِجَنَازَةٍ فَأُثْنِيَ عَلَيْهَا شَرًّا فَقُلْتَ ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ فَقَالَ ‏"‏ مَنْ أَثْنَيْتُمْ عَلَيْهِ خَيْرًا وَجَبَتْ لَهُ الْجَنَّةُ وَمَنْ أَثْنَيْتُمْ عَلَيْهِ شَرًّا وَجَبَتْ لَهُ النَّارُ أَنْتُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ ‏"‏ ‏.‏\hadithno{1932}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"A funeral passed by and the deceased was praised." The Prophet said: "It is granted." Another funeral passed by and the deceased was criticized. The Prophet said: "It is granted." 'Umar said: "May my father and mother be ransomed for you. One funeral passed by and the deceased was praised, and you said, 'It is granted?"' He said: "Whoever is praised will be granted Paradise, and whoever is criticized will be granted Hell, You are the witnesses of Allah on Earth}}
\hadithdefcmd{nasai}{1933}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ إِبْرَاهِيمَ بْنَ عَامِرٍ، وَجَدُّهُ، أُمَيَّةُ بْنُ خَلَفٍ قَالَ سَمِعْتُ عَامِرَ بْنَ سَعْدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَرُّوا بِجَنَازَةٍ عَلَى النَّبِيِّ صلى الله عليه وسلم فَأَثْنَوْا عَلَيْهَا خَيْرًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ ثُمَّ مَرُّوا بِجَنَازَةٍ أُخْرَى فَأَثْنَوْا عَلَيْهَا شَرًّا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ قَوْلُكَ الأُولَى وَالأُخْرَى ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْمَلاَئِكَةُ شُهَدَاءُ اللَّهِ فِي السَّمَاءِ وَأَنْتُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ ‏"‏ ‏.‏\hadithno{1933}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"A funeral passed by the Prophet and they praised (the deceased). The Prophet said: 'It is granted.' Then another funeral passed by and they criticized (the deceased). The Prophet said: 'It is granted.' They said: 'O Messenger of Allah, you said in both cases, 'It is granted?' The Prophet said: 'The angels are the witnesses of Allah in heaven, and you are the witnesses of Allah on Earth}}
\hadithdefcmd{nasai}{1934}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، وَعَبْدُ اللَّهِ بْنُ يَزِيدَ، قَالاَ حَدَّثَنَا دَاوُدُ بْنُ أَبِي الْفُرَاتِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، قَالَ أَتَيْتُ الْمَدِينَةَ فَجَلَسْتُ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَمُرَّ بِجَنَازَةٍ فَأُثْنِيَ عَلَى صَاحِبِهَا خَيْرًا فَقَالَ عُمَرُ وَجَبَتْ ‏.‏ ثُمَّ مُرَّ بِأُخْرَى فَأُثْنِيَ عَلَى صَاحِبِهَا خَيْرًا فَقَالَ عُمَرُ وَجَبَتْ ‏.‏ ثُمَّ مُرَّ بِالثَّالِثِ فَأُثْنِيَ عَلَى صَاحِبِهَا شَرًّا فَقَالَ عُمَرُ وَجَبَتْ ‏.‏ فَقُلْتُ وَمَا وَجَبَتْ يَا أَمِيرَ الْمُؤْمِنِينَ قَالَ قُلْتُ كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّمَا مُسْلِمٍ شَهِدَ لَهُ أَرْبَعَةٌ قَالُوا خَيْرًا أَدْخَلَهُ اللَّهُ الْجَنَّةَ ‏"‏ ‏.‏ قُلْنَا أَوْ ثَلاَثَةٌ قَالَ ‏"‏ أَوْ ثَلاَثَةٌ ‏"‏ ‏.‏ قُلْنَا أَوِ اثْنَانِ قَالَ ‏"‏ أَوِ اثْنَانِ ‏"‏ ‏.‏\hadithno{1934}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Aswad Ad-Dili said:"I came to Al-Madinah and sat with 'Umar bin Al-Khattab. A funeral passed by and the deceased was praised, and 'Umar said: 'It is granted.' Then another passed by and the deceased was praised, and 'Umar Said: 'It is granted.' Then a third passed by, and the deceased was criticized, and 'Umar said: 'It is granted.' I said: What is granted, O commander of the believers?' He said: 'I said what the Messenger of Allah said: Any Muslim for whom four people bear witness and say good things, Allah will admit him to Paradise.' We said: 'Or three?' He said: 'Or three.' We said: 'Or two?' He said: 'Or two}}
\hadithdefcmd{nasai}{1935}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنِي أَحْمَدُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا مَنْصُورُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ ذُكِرَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم هَالِكٌ بِسُوءٍ فَقَالَ ‏ "‏ لاَ تَذْكُرُوا هَلْكَاكُمْ إِلاَّ بِخَيْرٍ ‏"‏ ‏.‏\hadithno{1935}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"Something bad was said in the presence of the Prophet about a person who had died. He said: 'Do not say anything but good about your dead}}
\hadithdefcmd{nasai}{1936}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ بِشْرٍ، - وَهُوَ ابْنُ الْمُفَضَّلِ - عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا الأَمْوَاتَ فَإِنَّهُمْ قَدْ أَفْضَوْا إِلَى مَا قَدَّمُوا ‏"‏ ‏.‏\hadithno{1936}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'Do not verbally abuse the dead, for they have reached the consequences of what they did}}
\hadithdefcmd{nasai}{1937}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَتْبَعُ الْمَيِّتَ ثَلاَثَةٌ أَهْلُهُ وَمَالُهُ وَعَمَلُهُ فَيَرْجِعُ اثْنَانِ أَهْلُهُ وَمَالُهُ وَيَبْقَى وَاحِدٌ عَمَلُهُ ‏"‏ ‏.‏\hadithno{1937}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin Abi Bakr said:"I heard Anas bin Malik say: The Messenger of Allah said: 'The dead person is followed by three: His family, his wealth and his deeds. Then two of them come back: His family and his wealth, and there remain only his deeds}}
\hadithdefcmd{nasai}{1938}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لِلْمُؤْمِنِ عَلَى الْمُؤْمِنِ سِتُّ خِصَالٍ يَعُودُهُ إِذَا مَرِضَ وَيَشْهَدُهُ إِذَا مَاتَ وَيُجِيبُهُ إِذَا دَعَاهُ وَيُسَلِّمُ عَلَيْهِ إِذَا لَقِيَهُ وَيُشَمِّتُهُ إِذَا عَطَسَ وَيَنْصَحُ لَهُ إِذَا غَابَ أَوْ شَهِدَ ‏"‏ ‏.‏\hadithno{1938}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"The believer owes six duties toward his fellow believer: To visit him when he is sick, to attend his funeral when he dies, to accept his invitation, to greet him with Salam when he meets him, to reply to him (say: Yarhamuk Allah, may Allah have mercy on you) when he sneezes and to be sincere to him, whether he is absent or present." (Hasan)}}
\hadithdefcmd{nasai}{1939}{أَخْبَرَنَا سُلَيْمَانُ بْنُ مَنْصُورٍ الْبَلْخِيُّ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، ح وَأَنْبَأَنَا هَنَّادُ بْنُ السَّرِيِّ، فِي حَدِيثِهِ عَنْ أَبِي الأَحْوَصِ، عَنْ أَشْعَثَ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدٍ، قَالَ هَنَّادٌ قَالَ الْبَرَاءُ بْنُ عَازِبٍ وَقَالَ سُلَيْمَانُ عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعٍ وَنَهَانَا عَنْ سَبْعٍ أَمَرَنَا بِعِيَادَةِ الْمَرِيضِ وَتَشْمِيتِ الْعَاطِسِ وَإِبْرَارِ الْقَسَمِ وَنُصْرَةِ الْمَظْلُومِ وَإِفْشَاءِ السَّلاَمِ وَإِجَابَةِ الدَّاعِي وَاتِّبَاعِ الْجَنَائِزِ وَنَهَانَا عَنْ خَوَاتِيمِ الذَّهَبِ وَعَنْ آنِيَةِ الْفِضَّةِ وَعَنِ الْمَيَاثِرِ وَالْقَسِّيَّةِ وَالإِسْتَبْرَقِ وَالْحَرِيرِ وَالدِّيبَاجِ ‏.‏\hadithno{1939}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Al-Bara bin 'Azib said:"The Messenger of Allah commanded us to do seven things, and forbade us form seven things. He commanded us to visit the risk, to reply (say: Yarhamuk Allah, may Allah have mercy on you) to one who sneezes, to fulfill our oaths, to support the oppressed, to spread the greeting of Salam, to accept invitation, and to attend funerals. And he forbade us from using gold rings, silver vessels, Mayathir, the Qasiyyah, Al-Istabraq, silk and Ad-Dibaj}}
\hadithdefcmd{nasai}{1940}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْثَرٌ، عَنْ بُرْدٍ، أَخِي يَزِيدَ بْنِ أَبِي زِيَادٍ عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَبِعَ جَنَازَةً حَتَّى يُصَلَّى عَلَيْهَا كَانَ لَهُ مِنَ الأَجْرِ قِيرَاطٌ وَمَنْ مَشَى مَعَ الْجَنَازَةِ حَتَّى تُدْفَنَ كَانَ لَهُ مِنَ الأَجْرِ قِيرَاطَانِ وَالْقِيرَاطُ مِثْلُ أُحُدٍ ‏"‏ ‏.‏\hadithno{1940}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Al-Musayyab bin Rafi' said:"I heard Al-Bara' bin 'Azib say: The Messenger of Allah said: 'whoever follows a Janazah until the prayer is offered, he will have one Qirat of reward and whoever walks with the funeral until (the body) is buried will have two Qirats of reward, and a Qirat is like Uhud}}
\hadithdefcmd{nasai}{1941}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُغَفَّلِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَبِعَ جَنَازَةً حَتَّى يُفْرَغَ مِنْهَا فَلَهُ قِيرَاطَانِ فَإِنْ رَجَعَ قَبْلَ أَنْ يُفْرَغَ مِنْهَا فَلَهُ قِيرَاطٌ ‏"‏ ‏.‏\hadithno{1941}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Al-Mughaffal said:"The Messenger of Allah said: 'Whoever follows a Janazah until it is finished, he will have two Qirats, and whoever goes back before it is finished, he will have one Qirat}}
\hadithdefcmd{nasai}{1942}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ وَاصِلٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدِ اللَّهِ، وَأَخُوهُ الْمُغِيرَةُ، جَمِيعًا عَنْ زِيَادِ بْنِ جُبَيْرٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرَّاكِبُ خَلْفَ الْجَنَازَةِ وَالْمَاشِي حَيْثُ شَاءَ مِنْهَا وَالطِّفْلُ يُصَلَّى عَلَيْهِ ‏"‏ ‏.‏\hadithno{1942}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Al-Mughirah bin Shu,bah said:"The Messenger of Allah said: The riders should move behind the Janazah and the pedestrian may walk wherever he wishes, and the (funeral) prayer should be offered for a child}}
\hadithdefcmd{nasai}{1943}{أَخْبَرَنِي أَحْمَدُ بْنُ بَكَّارٍ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، عَنْ سَعِيدٍ الثَّقَفِيِّ، عَنْ عَمِّهِ، زِيَادِ بْنِ جُبَيْرِ بْنِ حَيَّةَ عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرَّاكِبُ خَلْفَ الْجَنَازَةِ وَالْمَاشِي حَيْثُ شَاءَ مِنْهَا وَالطِّفْلُ يُصَلَّى عَلَيْهِ ‏"‏ ‏.‏\hadithno{1943}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Al-Mughirah bin Shu'bah said:"The Messenger of Allah said: "The rider should travel behind the Janazah and the pedestrian may travel wherever he wishes, and the (funeral) prayer should be offered for a child}}
\hadithdefcmd{nasai}{1944}{أَخْبَرَنَا إِسْحَاق�� بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ حُجْرٍ، وَقُتَيْبَةُ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ رَضِيَ اللَّهُ عَنْهُمَا يَمْشُونَ أَمَامَ الْجَنَازَةِ ‏.‏\hadithno{1944}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salim:That his father saw the Messenger of Allah, Abu Bakr and 'Umar, may Allah be pleased with them, walking in front of the Janazah}}
\hadithdefcmd{nasai}{1945}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا سُفْيَانُ، وَمَنْصُورٌ، وَزِيَادٌ، وَبَكْرٌ، - هُوَ ابْنُ وَائِلٍ - كُلُّهُمْ ذَكَرُوا أَنَّهُمْ سَمِعُوا مِنَ الزُّهْرِيِّ، يُحَدِّثُ أَنَّ سَالِمًا، أَخْبَرَهُ أَنَّ أَبَاهُ أَخْبَرَهُ أَنَّهُ، رَأَى النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ وَعُثْمَانَ يَمْشُونَ بَيْنَ يَدَىِ الْجَنَازَةِ ‏.‏ بَكْرٌ وَحْدَهُ لَمْ يَذْكُرْ عُثْمَانَ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ مُرْسَلٌ ‏.‏\hadithno{1945}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Salim narrated:That his father told him that he was the Prophet, Abu Bakr, 'Umar and 'Uthman walking in front of the Janazah}}
\hadithdefcmd{nasai}{1946}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، وَعَمْرُو بْنُ زُرَارَةَ النَّيْسَابُورِيُّ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَخَاكُمْ قَدْ مَاتَ فَقُومُوا فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏\hadithno{1946}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Imran bin Husain said:"The Messenger of Allah said: 'Your brother has died, so get up and pray for him}}
\hadithdefcmd{nasai}{1947}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ عَمَّتِهِ، عَائِشَةَ بِنْتِ طَلْحَةَ عَنْ خَالَتِهَا أُمِّ الْمُؤْمِنِينَ، عَائِشَةَ قَالَتْ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَبِيٍّ مِنْ صِبْيَانِ الأَنْصَارِ فَصَلَّى عَلَيْهِ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ طُوبَى لِهَذَا عُصْفُورٌ مِنْ عَصَافِيرِ الْجَنَّةِ لَمْ يَعْمَلْ سُوءًا وَلَمْ يُدْرِكْهُ ‏.‏ قَالَ ‏ "‏ أَوَغَيْرَ ذَلِكَ يَا عَائِشَةُ خَلَقَ اللَّهُ عَزَّ وَجَلَّ الْجَنَّةَ وَخَلَقَ لَهَا أَهْلاً وَخَلَقَهُمْ فِي أَصْلاَبِ آبَائِهِمْ وَخَلَقَ النَّارَ وَخَلَقَ لَهَا أَهْلاً وَخَلَقَهُمْ فِي أَصْلاَبِ آبَائِهِمْ ‏"‏ ‏.‏\hadithno{1947}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{The mother of the believers, 'Aishah, said:"One of the children of the Ansar (who had died) was brought to the Messenger of Allah so he prayed for him." 'Aishah said: "How fortunate he is, one of the little birds of Paradise. He never did any evil or reached the age of puberty." He said: "It is better not to say anything, O 'Aishah Allah, the Mighty and Sublime, created Paradise and created people for it, He created them in the loins of their fathers. And He created Hell and created people for it, and He created them in the loins of their fathers}}
\hadithdefcmd{nasai}{1948}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ زِيَادَ بْنَ جُبَيْرٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّهُ ذَكَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الرَّاكِبُ خَلْفَ الْجَنَازَةِ وَالْمَاشِي حَيْثُ شَاءَ مِنْهَا وَالطِّفْلُ يُصَلَّى عَلَيْهِ ‏"‏ ‏.‏\hadithno{1948}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Mughirah bin Shu'bah that:the Messenger of Allah said: "The rider should move behind the Janazah and the pedestrian may walk wherever he wishes, and the (funeral) prayer should be offered for a child}}
\hadithdefcmd{nasai}{1949}{أَخْبَرَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَوْلاَدِ الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{1949}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah was asked about the children of the idolators and he said: 'Allah knows best what they would have done}}
\hadithdefcmd{nasai}{1950}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ قَيْسٍ، - هُوَ ابْنُ سَعْدٍ - عَنْ طَاوُسٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنْ أَوْلاَدِ الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{1950}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah was asked about the children of the idolators and he said: 'Allah knows best what they would have done}}
\hadithdefcmd{nasai}{1951}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَوْلاَدِ الْمُشْرِكِينَ فَقَالَ ‏ "‏ خَلَقَهُمُ اللَّهُ حِينَ خَلَقَهُمْ وَهُوَ يَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{1951}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah was asked about the children of the idolators and he said: 'Allah created them when He created them, and He knows best what they would have done}}
\hadithdefcmd{nasai}{1952}{أَخْبَرَنِي مُجَاهِدُ بْنُ مُوسَى، عَنْ هُشَيْمٍ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ ذَرَارِيِّ الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{1952}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah was asked about he children of the idolators and he said: 'Allah knows best what they would have done}}
\hadithdefcmd{nasai}{1953}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عِكْرِمَةُ بْنُ خَالِدٍ، أَنَّ ابْنَ أَبِي عَمَّارٍ، أَخْبَرَهُ عَنْ شَدَّادِ بْنِ الْهَادِ، أَنَّ رَجُلاً، مِنَ الأَعْرَابِ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَآمَنَ بِهِ وَاتَّبَعَهُ ثُمَّ قَالَ أُهَاجِرُ مَعَكَ ‏.‏ فَأَوْصَى بِهِ النَّبِيُّ صلى الله عليه وسلم بَعْضَ أَصْحَابِهِ فَلَمَّا كَانَتْ غَزْوَةٌ غَنِمَ النَّبِيُّ صلى الله عليه وسلم سَبْيًا فَقَسَمَ وَقَسَمَ لَهُ فَأَعْطَى أَصْحَابَهُ مَا قَسَمَ لَهُ وَكَانَ يَرْعَى ظَهْرَهُمْ فَلَمَّا جَاءَ دَفَعُوهُ إِلَيْهِ فَقَالَ مَا هَذَا قَالُوا قِسْمٌ قَسَمَهُ لَكَ النَّبِيُّ صلى الله عليه وسلم ‏.‏ فَأَخَذَهُ فَجَاءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ مَا هَذَا قَالَ ‏"‏ قَسَمْتُهُ لَكَ ‏"‏ ‏.‏ قَالَ مَا عَلَى هَذَا اتَّبَعْتُكَ وَلَكِنِّي اتَّبَعْتُكَ عَلَى أَنْ أُرْمَى إِلَى هَا هُنَا - وَأَشَارَ إِلَى حَلْقِهِ بِسَهْمٍ - فَأَمُوتَ فَأَدْخُلَ الْجَنَّةَ ‏.‏ فَقَالَ ‏"‏ إِنْ تَصْدُقِ اللَّهَ يَصْدُقْكَ ‏"‏ ‏.‏ فَلَبِثُوا قَلِيلاً ثُمَّ نَهَضُوا فِي قِتَالِ الْعَدُوِّ فَأُتِيَ بِهِ النَّبِيُّ صلى الله عليه وسلم يُحْمَلُ قَدْ أَصَابَهُ سَهْمٌ حَيْثُ أَشَارَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَهُوَ هُوَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ صَدَقَ اللَّهَ فَصَدَقَهُ ‏"‏ ‏.‏ ثُمَّ كَفَّنَهُ النَّبِيُّ صلى الله عليه وسلم فِي جُبَّةِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَدَّمَهُ فَصَلَّى عَلَيْهِ فَكَانَ فِيمَا ظَهَرَ مِنْ صَلاَتِهِ ‏"‏ اللَّهُمَّ هَذَا عَبْدُكَ خَرَجَ مُهَاجِرًا فِي سَبِيلِكَ فَقُتِلَ شَهِيدًا أَنَا شَهِيدٌ عَلَى ذَلِكَ ‏"‏ ‏.‏\hadithno{1953}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Shaddad bin Al-Had that:a man from among the Bedouins came to the Prophet and believed in him and followed him, then he said: "I will emigrate with you." The Prophet told one of his Companions to look after him. During one battle the Prophet got some prisoners as spoils of war, and he distributed them, giving him (that Bedouin) a share. His Companions gave him what had been allocated to him. He had been looking after some livestock for them, and when he came they gave him his share. He said: "What is this?" They said: "A share that the Prophet has allocated to you." He took it and brought it to the Prophet and said: "What is this?" He said: "I allocated it to your." He said: "It is not for this that I follwed you. Rather I followed you so that I might be shot her - and he pointed to his throat - with an arrow and die and enter Paradise." He said: "If you are sincere toward Allah, Allah will fulfill your wish." Shortly after that they got up to fight the enemy, then he was brought to the Prophet; he had pointed to. The Prophet said: "Is it him?" They said: "yes." He said: "He was sincere toward Allah and Allah fulfilled his wish." Then the Prophet shrouded him in his own cloak and out him in front of him and offered the (funeral) prayer for him. During his supplication he said: "O allah, this is Your sloave who went out as a emigrant (Muhajir) for your sake and was killed as a martyr; I am a witness to that.: (Sahih)}}
\hadithdefcmd{nasai}{1954}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يَوْمًا فَصَلَّى عَلَى أَهْلِ أُحُدٍ صَلاَتَهُ عَلَى الْمَيِّتِ ثُمَّ انْصَرَفَ إِلَى الْمِنْبَرِ فَقَالَ ‏ "‏ إِنِّي فَرَطٌ لَكُمْ وَأَنَا شَهِيدٌ عَلَيْكُمْ ‏"‏ ‏.‏\hadithno{1954}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Upbah that:the Messenger of Allah went out one day and offered the funeral prayer for the people f Uhd, then he went to the Minbar and said: "I am your predecessor and I am a witness over your}}
\hadithdefcmd{nasai}{1955}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ فِي ثَوْبٍ وَاحِدٍ ثُمَّ يَقُولُ ‏"‏ أَيُّهُمَا أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏ ‏.‏ فَإِذَا أُشِيرَ إِلَى أَحَدِهِمَا قَدَّمَهُ فِي اللَّحْدِ ‏.‏ قَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ ‏"‏ ‏.‏ وَأَمَرَ بِدَفْنِهِمْ فِي دِمَائِهِمْ وَلَمْ يُصَلِّ عَلَيْهِمْ وَلَمْ يُغَسَّلُوا ‏.‏\hadithno{1955}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdur-Rahman bin Ka 'b bin Malik that Jabir bin 'Abdullah told him that:the Messenger of Allah put two men from those who had been slain in Uhud in one shrud, then he would ask which of them had learned more Qur'an and when one of them was pointed out, he would put him in the Lahd (grave) first. He said: "I am a witness to these." And he ordered that they be buried with their blood, and that the funeral prayer should not be offered, and they should not be washed}}
\hadithdefcmd{nasai}{1956}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى، وَنُوحُ بْنُ حَبِيبٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مِنْ أَسْلَمَ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَاعْتَرَفَ بِالزِّنَا فَأَعْرَضَ عَنْهُ ثُمَّ اعْتَرَفَ فَأَعْرَضَ عَنْهُ ثُمَّ اعْتَرَفَ فَأَعْرَضَ عَنْهُ حَتَّى شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ مَرَّاتٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبِكَ جُنُونٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَحْصَنْتَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَرُجِمَ فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ فَرَّ فَأُدْرِكَ فَرُجِمَ فَمَاتَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم خَيْرًا وَلَمْ يُصَلِّ عَلَيْهِ ‏.‏\hadithno{1956}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin Abdullah that:a man from Aslam came to the Prophet and confessed to committing Zina, and he turned away from him. He admitted it again, and he turned away from him. He admitted it again, and he turned away from him. Then when he had testified against himself four times, the Prophet said: "Are your crazy?" He said: "No." He said: "Have you been marred?" he said: "Yes." So the Prophet ordered that he be stoned. When the stones struck him, he ran away, but they caught up with him and stoned him and he died. Then the Prophet spoke well of him but he did not pray for him. (Shih)}}
\hadithdefcmd{nasai}{1957}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ امْرَأَةً، مِنْ جُهَيْنَةَ أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي زَنَيْتُ وَهِيَ حُبْلَى فَدَفَعَهَا إِلَى وَلِيِّهَا فَقَالَ ‏"‏ أَحْسِنْ إِلَيْهَا فَإِذَا وَضَعَتْ فَائْتِنِي بِهَا ‏"‏ ‏.‏ فَلَمَّا وَضَعَتْ جَاءَ بِهَا فَأَمَرَ بِهَا فَشُكَّتْ عَلَيْهَا ثِيَابُهَا ثُمَّ رَجَمَهَا ثُمَّ صَلَّى عَلَيْهَا فَقَالَ لَهُ عُمَرُ أَتُصَلِّي عَلَيْهَا وَقَدْ زَنَتْ فَقَالَ ‏"‏ لَقَدْ تَابَتْ تَوْبَةً لَوْ قُسِمَتْ بَيْنَ سَبْعِينَ مِنْ أَهْلِ الْمَدِينَةِ لَوَسِعَتْهُمْ وَهَلْ وَجَدْتَ تَوْبَةً أَفْضَلَ مِنْ أَنْ جَادَتْ بِنَفْسِهَا لِلَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{1957}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from "Imran bin Husain that:a woman from Juhainah came to the Messenger of Allah sand said: "I have committed Zina." And she was committed Zina." And She was pregnant. He handed her over to her guardian and said: "Look after her, and when she gave birth, he brought her to him. He ordered that her garment be wrapped around her, then he offered the funeral prayer for her. 'Umar said to him: "Are you praying for her even though she committed Zina?" he said: "She has repented in a manner that, if it were to be shared among seventy of the people of Al-Madinah it would suffice them. Have you ever seen repentance better than the one who sacrificed herself for the sake of Allah, the Mighty and Sublime?}}
\hadithdefcmd{nasai}{1958}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا هُشَيْمٌ، عَنْ مَنْصُورٍ، - وَهُوَ ابْنُ زَاذَانَ - عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، أَعْتَقَ سِتَّةً مَمْلُوكِينَ لَهُ عِنْدَ مَوْتِهِ وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرَهُمْ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَغَضِبَ مِنْ ذَلِكَ وَقَالَ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ لاَ أُصَلِّيَ عَلَيْهِ ‏"‏ ‏.‏ ثُمَّ دَعَا مَمْلُوكِيهِ فَجَزَّأَهُمْ ثَلاَثَةَ أَجْزَاءٍ ثُمَّ أَقْرَعَ بَيْنَهُمْ فَأَعْتَقَ اثْنَيْنِ وَأَرَقَّ أَرْبَعَةً ‏.‏\hadithno{1958}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Imran bin Husain that:a man freed six slaves of his when he was dying, and he did not have any wealth apart from them. News of that reached the Prophet and he was angry about that. He said: "I was thinking of not offering the funeral prapyer for him." Then he called the slaves and divided them into three groups. He cast lost among them, then freed two and left four as slaves}}
\hadithdefcmd{nasai}{1959}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَبِي عَمْرَةَ، عَنْ زَيْدِ بْنِ خَالِدٍ، قَالَ مَاتَ رَجُلٌ بِخَيْبَرَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلُّوا عَلَى صَاحِبِكُمْ إِنَّهُ غَلَّ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ فَفَتَّشْنَا مَتَاعَهُ فَوَجَدْنَا فِيهِ خَرَزًا مِنْ خَرَزِ يَهُودَ مَا يُسَاوِي دِرْهَمَيْنِ ‏.‏\hadithno{1959}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Zaid bin Khalid said:"A man died at Khaibar and the Messenger of Allah said: 'Pray for your companion; he stole from the spoils war.' We inspected his luggage and fund some of the beads of the Jews that were not even worth two Dirhams}}
\hadithdefcmd{nasai}{1960}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي قَتَادَةَ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِرَجُلٍ مِنَ الأَنْصَارِ لِيُصَلِّيَ عَلَيْهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ فَإِنَّ عَلَيْهِ دَيْنًا ‏"‏ ‏.‏ قَالَ أَبُو قَتَادَةَ هُوَ عَلَىَّ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِالْوَفَاءِ ‏"‏ ‏.‏ قَالَ بِالْوَفَاءِ ‏.‏ فَصَلَّى عَلَيْهِ ‏.‏\hadithno{1960}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Abi Qatadah narrated from his father that:a man was brought to the Prophet for him to offer the funeral prayer, and he said: "Pray for your companion, for he owes a debt." Abu Qatadah said: " I will pay it." The Prophet said: "In full?" He said: "In full." So he prayed for him}}
\hadithdefcmd{nasai}{1961}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا يَزِيدُ بْنُ أَبِي عُبَيْدٍ، قَالَ حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ الأَكْوَعِ - قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِجَنَازَةٍ فَقَالُوا يَا نَبِيَّ اللَّهِ صَلِّ عَلَيْهَا ‏.‏ قَالَ ‏"‏ هَلْ تَرَكَ عَلَيْهِ دَيْنًا ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ هَلْ تَرَكَ مِنْ شَىْءٍ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ قَالَ رَجُلٌ مِنَ الأَنْصَارِ يُقَالُ لَهُ أَبُو قَتَادَةَ صَلِّ عَلَيْهِ وَعَلَىَّ دَيْنُهُ ‏.‏ فَصَلَّى عَلَيْهِ ‏.‏\hadithno{1961}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Salamah - meaning, bin Al-Akwa' - said:"A Janazah was brought to the Prophet and they said: " O Prophet of Allah, pray for him.' He said: "Did he leave any debt behind?' They said: "Yes.' He said 'Did he leave anything?' They said: No. He said; 'Pray fro your companion.' A man among the Ansar who was called Abu Qatadah said: 'Pray for him and I will pay off his debt.' So he prayed for him}}
\hadithdefcmd{nasai}{1962}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ الْقُومِسِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يُصَلِّي عَلَى رَجُلٍ عَلَيْهِ دَيْنٌ فَأُتِيَ بِمَيِّتٍ فَسَأَلَ ‏"‏ أَعَلَيْهِ دَيْنٌ ‏"‏ ‏.‏ قَالُوا نَعَمْ عَلَيْهِ دِينَارَانِ ‏.‏ قَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ قَالَ أَبُو قَتَادَةَ هُمَا عَلَىَّ يَا رَسُولَ اللَّهِ ‏.‏ فَصَلَّى عَلَيْهِ فَلَمَّا فَتَحَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم قَالَ ‏"‏ أَنَا أَوْلَى بِكُلِّ مُؤْمِنٍ مِنْ نَفْسِهِ مَنْ تَرَكَ دَيْنًا فَعَلَىَّ وَمَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ ‏"‏ ‏.‏\hadithno{1962}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Prophet would not pray for a man who owed a debt. A deceased person was brought to him and he said: 'Does he owe any debt?' They said: 'Yes, he owes two Dinars.' He said: 'Pray for your companion.' Abu Qatadah said: 'I will pay them, O Messenger of Alllah, So he prayed for him. Then, when Allah made His Messenger rich though conquest, he said: ' I am closer to each believer than his own self. Whoever leaves behind a debt, I will pay it, and whoever leaves behind wealth, it is for his heirs}}
\hadithdefcmd{nasai}{1963}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، وَابْنُ أَبِي ذِئْبٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا تُوُفِّيَ الْمُؤْمِنُ وَعَلَيْهِ دَيْنٌ سَأَلَ ‏"‏ هَلْ تَرَكَ لِدَيْنِهِ مِنْ قَضَاءٍ ‏"‏ ‏.‏ فَإِنْ قَالُوا نَعَمْ صَلَّى عَلَيْهِ وَإِنْ قَالُوا لاَ قَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ فَلَمَّا فَتَحَ اللَّهُ عَزَّ وَجَلَّ عَلَى رَسُولِهِ صلى الله عليه وسلم قَالَ ‏"‏ أَنَا أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ فَمَنْ تُوُفِّيَ وَعَلَيْهِ دَيْنٌ فَعَلَىَّ قَضَاؤُهُ وَمَنْ تَرَكَ مَالاً فَهُوَ لِوَرَثَتِهِ ‏"‏ ‏.‏\hadithno{1963}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:if a believer died with debts outstanding, the Messenger of Allah would ask whether he had left behind anything to pay off his debts. If they said yes, he would pray for him, but if they said no, he would say: "Pray for your companion." Then, when Allah made His Messenger rich through conquest, he said: "I am closer to the believers than their own selves. Whoever dies and leaves behind a debt, I will pay it, and whoever leavers behind wealth, it is for his heirs}}
\hadithdefcmd{nasai}{1964}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا أَبُو خَيْثَمَةَ، زُهَيْرٌ قَالَ حَدَّثَنَا سِمَاكٌ، عَنِ جَابِرِ بْنِ سَمُرَةَ، أَنَّ رَجُلاً، قَتَلَ نَفْسَهُ بِمَشَاقِصَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمَّا أَنَا فَلاَ أُصَلِّي عَلَيْهِ ‏"‏ ‏.‏\hadithno{1964}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin Samurah that:a man killed himself with an arrowhead and the Messenger of Allah said: "As for me, I will not pray for him}}
\hadithdefcmd{nasai}{1965}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، سَمِعْتُ ذَكْوَانَ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَرَدَّى مِنْ جَبَلٍ فَقَتَلَ نَفْسَهُ فَهُوَ فِي نَارِ جَهَنَّمَ يَتَرَدَّى خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا وَمَنْ تَحَسَّى سُمًّا فَقَتَلَ نَفْسَهُ فَسُمُّهُ فِي يَدِهِ يَتَحَسَّاهُ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا وَمَنْ قَتَلَ نَفْسَهُ بِحَدِيدَةٍ - ثُمَّ انْقَطَعَ عَلَىَّ شَىْءٌ خَالِدٌ يَقُولُ - كَانَتْ حَدِيدَتُهُ فِي يَدِهِ يَجَأُ بِهَا فِي بَطْنِهِ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا ‏"‏ ‏.‏\hadithno{1965}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Whoever throws himself, he will be in the Fire of Hell, throwing himself down forever and ever. And whoever kills himself with a piece of iron"- then I missed something ( one of the narrators) Khalid said-"will have his piece of iron in his hand, stabbing himself in the stomach in the Fire of Hell, forever and ever}}
\hadithdefcmd{nasai}{1966}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ لَمَّا مَاتَ عَبْدُ اللَّهِ بْنُ أُبَىِّ ابْنِ سَلُولَ دُعِي لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ عَلَيْهِ فَلَمَّا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَثَبْتُ إِلَيْهِ فَقُلْتُ يَا رَسُولَ اللَّهِ تُصَلِّي عَلَى ابْنِ أُبَىٍّ وَقَدْ قَالَ يَوْمَ كَذَا وَكَذَا كَذَا وَكَذَا أُعَدِّدُ عَلَيْهِ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ أَخِّرْ عَنِّي يَا عُمَرُ ‏"‏ ‏.‏ فَلَمَّا أَكْثَرْتُ عَلَيْهِ قَالَ ‏"‏ إِنِّي قَدْ خُيِّرْتُ فَاخْتَرْتُ فَلَوْ عَلِمْتُ أَنِّي لَوْ زِدْتُ عَلَى السَّبْعِينَ غُفِرَ لَهُ لَزِدْتُ عَلَيْهَا ‏"‏ ‏.‏ فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ انْصَرَفَ فَلَمْ يَمْكُثْ إِلاَّ يَسِيرًا حَتَّى نَزَلَتِ الآيَتَانِ مِنْ بَرَاءَةَ ‏\{‏ وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا وَلاَ تَقُمْ عَلَى قَبْرِهِ إِنَّهُمْ كَفَرُوا بِاللَّهِ وَرَسُولِهِ وَمَاتُوا وَهُمْ فَاسِقُونَ ‏\}‏ فَعَجِبْتُ بَعْدُ مِنْ جُرْأَتِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ وَاللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏\hadithno{1966}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Umar bin Al-Khattab said:"When 'Abdullah bin Ubayy bin Soul died, the Messenger of Allah was called upon to offer the funeral prayer for him. When the Messenger of Allah stood up (to offer the prayer), I got up quickly and said: 'O Messenger of Allah Are you going to pray for Ibn Ubayy when he said such-and-such an occasion?' And I stated to list all the things that he had said. The Messenger of Allah smiled and said: 'Leave me alone, O 'Umar.' When I spoke too much he said: 'I have been given the choice and I have chosen (to offer the prayer for him). If I knew that he could be forgiven by asking Allah's forgiveness more than seventy times, I would have done so.' The Messenger of Allah offered the funeral prayer for him, and then left. A short while later, the two Verses form surah Bara were revealed: 'And never pray (funeral prayer) for any of them (hypocrites) who dies, nor stand at his grave. Certainly they disbelieved in Allah and His Messenger, and died while they were rebellious.' Later I was astonished by my audacity toward the Messenger of Allah on that day. And Allah and His Messenger know best}}
\hadithdefcmd{nasai}{1967}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ الْوَاحِدِ بْنِ حَمْزَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ مَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى سُهَيْلِ ابْنِ بَيْضَاءَ إِلاَّ فِي الْمَسْجِدِ ‏.‏\hadithno{1967}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah did not ofer gthe funeral prayer for shail bin Baida anywhere but in the Masjid}}
\hadithdefcmd{nasai}{1968}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَبْدِ الْوَاحِدِ بْنِ حَمْزَةَ، أَنَّ عَبَّادَ بْنَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَخْبَرَهُ أَنَّ عَائِشَةَ قَالَتْ مَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى سُهَيْلِ ابْنِ بَيْضَاءَ إِلاَّ فِي جَوْفِ الْمَسْجِدِ ‏.‏\hadithno{1968}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdul-Wahid bin Hamzah that 'Abbad bin 'Abdullah bin Az-Zubair told him that 'Aishah said:"the Messenger of Allah did not offer the funeral prayer for Suhail bin Baida anywhere but inside the Masjid}}
\hadithdefcmd{nasai}{1969}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو أُمَامَةَ بْنُ سَهْلِ بْنِ حُنَيْفٍ، أَنَّهُ قَالَ اشْتَكَتِ امْرَأَةٌ بِالْعَوَالِي مِسْكِينَةٌ فَكَانَ النَّبِيُّ صلى الله عليه وسلم يَسْأَلُهُمْ عَنْهَا وَقَالَ ‏"‏ إِنْ مَاتَتْ فَلاَ تَدْفِنُوهَا حَتَّى أُصَلِّيَ عَلَيْهَا ‏"‏ ‏.‏ فَتُوُفِّيَتْ فَجَاءُوا بِهَا إِلَى الْمَدِينَةِ بَعْدَ الْعَتَمَةِ فَوَجَدُوا رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ نَامَ فَكَرِهُوا أَنْ يُوقِظُوهُ فَصَلُّوا عَلَيْهَا وَدَفَنُوهَا بِبَقِيعِ الْغَرْقَدِ فَلَمَّا أَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَاءُوا فَسَأَلَهُمْ عَنْهَا فَقَالُوا قَدْ دُفِنَتْ يَا رَسُولَ اللَّهِ وَقَدْ جِئْنَاكَ فَوَجَدْنَاكَ نَائِمًا فَكَرِهْنَا أَنْ نُوقِظَكَ ‏.‏ قَالَ ‏"‏ فَانْطَلِقُوا ‏"‏ ‏.‏ فَانْطَلَقَ يَمْشِي وَمَشَوْا مَعَهُ حَتَّى أَرَوْهُ قَبْرَهَا فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَفُّوا وَرَاءَهُ فَصَلَّى عَلَيْهَا وَكَبَّرَ أَرْبَعًا ‏.‏\hadithno{1969}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Umamah bin Sahl bin Hunaif said:"A poor woman in Al-Awali fell sick and the Prophet used to ask them about her. He said: 'If she dies, do not bury her until I have offered the funeral prayer for her. She died and they brought her to Al-Madinah after dark, and they found that the Messenger of Allah had gone to sleep. They did not like to wake him up, so they offered the funeral prayer for her and buried her in Baqi' Al-Gharqab. The next morning they came and the Messenger of Allah asked them about her. They said: 'She has been buried, O Messenger of Allah. We came to you and found you sleeping, and we did not like to wake you up.' He said: 'let's go.' He set out walking and they went with him and showed him her grave. The Messenger of Allah stood and they formed rows behind him, and he offered the funeral prayer for her, saying the Takbir four times}}
\hadithdefcmd{nasai}{1970}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ حَفْصِ بْنِ غِيَاثٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَخَاكُمُ النَّجَاشِيَّ قَدْ مَاتَ فَقُومُوا فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏ فَقَامَ فَصَفَّ بِنَا كَمَا يُصَفُّ عَلَى الْجَنَازَةِ وَصَلَّى عَلَيْهِ ‏.‏\hadithno{1970}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jair that:the Messenger of Allah said: "Your brother An-Najashi has died, so get up and offer the funeral prayer for him." He stood up and put us in rows as is done for the funeral prayer, and we prayed for him}}
\hadithdefcmd{nasai}{1971}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَعَى لِلنَّاسِ النَّجَاشِيَّ الْيَوْمَ الَّذِي مَاتَ فِيهِ ثُمَّ خَرَجَ بِهِمْ إِلَى الْمُصَلَّى فَصَفَّ بِهِمْ فَصَلَّى عَلَيْهِ وَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{1971}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah:That the Prophet announced the death of An-Najashi to the people on the day that he died, then he took them out to the prayer place and put them in rows and offered the funeral prayer for him, saying the Takbir four times}}
\hadithdefcmd{nasai}{1972}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ نَعَى رَسُولُ اللَّهِ صلى الله عليه وسلم النَّجَاشِيَّ لأَصْحَابِهِ بِالْمَدِينَةِ فَصَفُّوا خَلْفَهُ فَصَلَّى عَلَيْهِ وَكَبَّرَ أَرْبَعًا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ ابْنُ الْمُسَيَّبِ إِنِّي لَمْ أَفْهَمْهُ كَمَا أَرَدْتَ ‏.‏\hadithno{1972}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah announced the death of An-Najashi to his Companions in Al-Madinah, so they formed rows behind him and he offered the funeral prayer for him, saying the Takbir four times}}
\hadithdefcmd{nasai}{1973}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَخَاكُمْ قَدْ مَاتَ فَقُومُوا فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏ فَصَفَفْنَا عَلَيْهِ صَفَّيْنِ ‏.‏\hadithno{1973}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:the Messenger of Allah said: "Your brother has died, so get up and offer the funeral prayer for him." So we formed two rows for him}}
\hadithdefcmd{nasai}{1974}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، سَمِعْتُ شُعْبَةَ، يَقُولُ السَّاعَةَ يَخْرُجُ السَّاعَةَ يَخْرُجُ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُنْتُ فِي الصَّفِّ الثَّانِي يَوْمَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النَّجَاشِيِّ ‏.‏\hadithno{1974}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"I was in the second row on the day the Messenger of Allah offered the funeral prayer for An-Najashi}}
\hadithdefcmd{nasai}{1975}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، قَالَ حَدَّثَنَا يُونُسُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَخَاكُمُ النَّجَاشِيَّ قَدْ مَاتَ فَقُومُوا فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَقُمْنَا فَصَفَفْنَا عَلَيْهِ كَمَا يُصَفُّ عَلَى الْمَيِّتِ وَصَلَّيْنَا عَلَيْهِ كَمَا يُصَلَّى عَلَى الْمَيِّتِ ‏.‏\hadithno{1975}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Imran bin Husain said:"The Messenger of Allah said to us: 'Your brother An-Najashi has died, so get up and offer the funeral prayer for him.' So we got up and formed row to pray for him, as rows are formed to pray for the dead, and he led us in praying for him as people pray for the dead}}
\hadithdefcmd{nasai}{1976}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ سَمُرَةَ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى أُمِّ كَعْبٍ مَاتَتْ فِي نِفَاسِهَا فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الصَّلاَةِ فِي وَسَطِهَا ‏.‏\hadithno{1976}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Samurah said:"I offered the funeral prayer with the Messenger of Allah for Umm kab who had died in childbirth, and the Messenger of Allah stood in line at her mid-section to pray}}
\hadithdefcmd{nasai}{1977}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ عَمَّارٍ، قَالَ حَضَرَتْ جَنَازَةُ صَبِيٍّ وَامْرَأَةٍ فَقُدِّمَ الصَّبِيُّ مِمَّا يَلِي الْقَوْمَ وَوُضِعَتِ الْمَرْأَةُ وَرَاءَهُ فَصَلَّى عَلَيْهِمَا وَفِي الْقَوْمِ أَبُو سَعِيدٍ الْخُدْرِيُّ وَابْنُ عَبَّاسٍ وَأَبُو قَتَادَةَ وَأَبُو هُرَيْرَةَ فَسَأَلْتُهُمْ عَنْ ذَلِكَ فَقَالُوا السُّنَّةُ ‏.‏\hadithno{1977}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Ammar said:"The Janazah of a boy and a woman were brought. The boy was placed closer to the people and the woman was placed beyond him, and the funeral prayer was offered for them. Among the people were Abu Saeed Al-Khudri, Ibn Abbas, Abu Qatadah and Abu Hurairah. I asked them about that and they said: '(It is) Sunnah}}
\hadithdefcmd{nasai}{1978}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ نَافِعًا، يَزْعُمُ أَنَّ ابْنَ عُمَرَ، صَلَّى عَلَى تِسْعِ جَنَائِزَ جَمِيعًا فَجَعَلَ الرِّجَالَ يَلُونَ الإِمَامَ وَالنِّسَاءَ يَلِينَ الْقِبْلَةَ فَصَفَّهُنَّ صَفًّا وَاحِدًا وَوُضِعَتْ جَنَازَةُ أُمِّ كُلْثُومٍ بِنْتِ عَلِيٍّ امْرَأَةِ عُمَرَ بْنِ الْخَطَّابِ وَابْنٍ لَهَا يُقَالُ لَهُ زَيْدٌ وُضِعَا جَمِيعًا وَالإِمَامُ يَوْمَئِذٍ سَعِيدُ بْنُ الْعَاصِ وَفِي النَّاسِ ابْنُ عُمَرَ وَأَبُو هُرَيْرَةَ وَأَبُو سَعِيدٍ وَأَبُو قَتَادَةَ فَوُضِعَ الْغُلاَمُ مِمَّا يَلِي الإِمَامَ فَقَالَ رَجُلٌ فَأَنْكَرْتُ ذَلِكَ فَنَظَرْتُ إِلَى ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ وَأَبِي قَتَادَةَ فَقُلْتُ مَا هَذَا قَالُوا هِيَ السُّنَّةُ ‏.‏\hadithno{1978}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Juraij said:"I heard Naji, claim that Ibn 'Umar offered the funeral prayer for nine together. He put the men closer to the Imam and the women closer to the Qiblah, and he placed them (the women) in one row. And the body of Umm Kulthum bint 'Ali the wife of 'Umar bin Al-Khattab, and a son of hers called Zaid were placed together. The Imam that day was Saeed bin Al-As and among the people were Ibn 'Umar, Abu Hurairah, Abu Saeed and Abu Qatadah. The boy was placed closer to the Imam. A man said something objecting to that, so I looked at Ibn 'Abbas, Abu Hurairah, Abu Saeed and Abu Qatadah and said: 'What is this?' They said: 'It is the Sunnah}}
\hadithdefcmd{nasai}{1979}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ، وَالْفَضْلُ بْنُ مُوسَى، ح وَأَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ حُسَيْنٍ الْمُكْتِبِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى عَلَى أُمِّ فُلاَنٍ مَاتَتْ فِي نِفَاسِهَا فَقَامَ فِي وَسَطِهَا ‏.‏\hadithno{1979}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Samurah bin Jundab:That the Messenger of Allah offered the funeral prayer for a mother who had died in childbirth, and he stood in line with her middle}}
\hadithdefcmd{nasai}{1980}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى لِلنَّاسِ النَّجَاشِيَّ وَخَرَجَ بِهِمْ فَصَفَّ بِهِمْ وَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{1980}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah:That the Messenger of Allah announced the death of An-Najashi to the people, and he led thme out and arranged them in rows, and said the Takbir four times}}
\hadithdefcmd{nasai}{1981}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، قَالَ مَرِضَتِ امْرَأَةٌ مِنْ أَهْلِ الْعَوَالِي وَكَانَ النَّبِيُّ صلى الله عليه وسلم أَحْسَنَ شَىْءٍ عِيَادَةً لِلْمَرِيضِ فَقَالَ ‏ "‏ إِذَا مَاتَتْ فَآذِنُونِي ‏"‏ ‏.‏ فَمَاتَتْ لَيْلاً فَدَفَنُوهَا وَلَمْ يُعْلِمُوا النَّبِيَّ صلى الله عليه وسلم فَلَمَّا أَصْبَحَ سَأَلَ عَنْهَا فَقَالُوا كَرِهْنَا أَنْ نُوقِظَكَ يَا رَسُولَ اللَّهِ ‏.‏ فَأَتَى قَبْرَهَا فَصَلَّى عَلَيْهَا وَكَبَّرَ أَرْبَعًا ‏.‏\hadithno{1981}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Umamah bin Sahi said:"A woman from among the people of Al-'Awali fell sick and the Prophet was the best in visiting the sick. He said: 'When she dies, inform me.' She died at night and they buried her without telling the Prophet. The following morning he asked about her and they said: we did not like to wake you, O Messenger of Allah.' So he went to her grave and offered the funeral prayer for her and said Takbir four times}}
\hadithdefcmd{nasai}{1982}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي عَمْرُو بْنُ مُرَّةَ، عَنِ ابْنِ أَبِي لَيْلَى، أَنَّ زَيْدَ بْنَ أَرْقَمَ، صَلَّى عَلَى جَنَازَةٍ فَكَبَّرَ عَلَيْهَا خَمْسًا وَقَالَ كَبَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1982}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Laila:That Zaid bin Arqam offered the funeral prayer and said the Takbir five times, and said that the Messenger of Allah had said the Takbir like this}}
\hadithdefcmd{nasai}{1983}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ أَبِي حَمْزَةَ بْنِ سُلَيْمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى عَلَى جَنَازَةٍ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لَهُ وَارْحَمْهُ وَاعْفُ عَنْهُ وَعَافِهِ وَأَكْرِمْ نُزُلَهُ وَوَسِّعْ مُدْخَلَهُ وَاغْسِلْهُ بِمَاءٍ وَثَلْجٍ وَبَرَدٍ وَنَقِّهِ مِنَ الْخَطَايَا كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ وَأَبْدِلْهُ دَارًا خَيْرًا مِنْ دَارِهِ وَأَهْلاً خَيْرًا مِنْ أَهْلِهِ وَزَوْجًا خَيْرًا مِنْ زَوْجِهِ وَقِهِ عَذَابَ الْقَبْرِ وَعَذَابَ النَّارِ ‏"‏ ‏.‏ قَالَ عَوْفٌ فَتَمَنَّيْتُ أَنْ لَوْ كُنْتُ الْمَيِّتَ لِدُعَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم لِذَلِكَ الْمَيِّتِ ‏.‏\hadithno{1983}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Awf bin Malik said:"I heard the Messenger of Allah offer the funeral prayer and say: Allahumma ighfir lahu warhamhu wa`fu `anhu wa `afihi, wa akrim nuzulahu wa wassi` mudkhalahu waghsilhu bi-ma'in wa thaljin wa-barad, wa naqqihi min al-khataya kama yunaqqa ath-thawb al-abyad min ad-danas. Wa abdilhu daran khairan min darihi wa ahlan khayran min ahlihi, wa zawjan khayran min zawjihi, wa qihi 'adhab al-qabri wa 'adhab an-nar (O Allah, forgive him and have mercy on him, forgive him and keep him safe and sound, honor the place where he settles and make his entrance wide; wash him with water and snow and hail, and cleanse him of his sin as a white garment is cleansed of dirt. Give him a house better than his house and a family better than his family and a spouse better than his spouse. Protect him from the torment of the grave and the torment of Hell-fire)." 'Awf said: "I wished that I was that deceased person because of the supplication that the Messenger of Allah said for that deceased person}}
\hadithdefcmd{nasai}{1984}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ حَبِيبِ بْنِ عُبَيْدٍ الْكَلاَعِيِّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ الْحَضْرَمِيِّ، قَالَ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى مَيِّتٍ فَسَمِعْتُ فِي دُعَائِهِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لَهُ وَارْحَمْهُ وَعَافِهِ وَاعْفُ عَنْهُ وَأَكْرِمْ نُزُلَهُ وَوَسِّعْ مُدْخَلَهُ وَاغْسِلْهُ بِالْمَاءِ وَالثَّلْجِ وَالْبَرَدِ وَنَقِّهِ مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ وَأَبْدِلْهُ دَارًا خَيْرًا مِنْ دَارِهِ وَأَهْلاً خَيْرًا مِنْ أَهْلِهِ وَزَوْجًا خَيْرًا مِنْ زَوْجِهِ وَأَدْخِلْهُ الْجَنَّةَ وَنَجِّهِ مِنَ النَّارِ - أَوْ قَالَ - وَأَعِذْهُ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{1984}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jubair bin Nufair Al-Hadrami said:"I heard 'Awf bin Malik say: "I heard the Messenger of Allah offering the funeral prayer for one who had died, and I heard him say in his supplication: Allahummaghfir lahu warhamhu wa 'afihi, wa a'fu 'anhu, wa akrim nuzulahu wa wassi' mudkhalahu waghsilhu bil-ma wath-thalji wal-barad, wa naqqihi min al-khataya kama naqqaita-thawb al-abyad min ad-danas. Wa abdilhu daran khairan min darihi, wa ahlan khayran min ahlihi, wa zawjan khayran min zawjihi. Wa adkhilahul-jannah wa najjihi min an-nar" (O Allah, forgive him and have mercy on him, keep him safe and sound and forgive him, honor the place where he settles and make his entrance wide; wash him with water and snow and hail, and cleanse him of his sin as you cleanse a white garment of dirt. O Allah, give him a house better than his house and a family better than his family and a wife better than his wife, and admit him to Paradise and save him from Hellfire)." Or he said: "Wa a'idhhu min 'adhab al-qabr (And protect him from the torment of the grave)}}
\hadithdefcmd{nasai}{1985}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ عَمْرَو بْنَ مَيْمُونٍ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ رُبَيِّعَةَ السُّلَمِيِّ، وَكَانَ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ عُبَيْدِ بْنِ خَالِدٍ السُّلَمِيِّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم آخَى بَيْنَ رَجُلَيْنِ فَقُتِلَ أَحَدُهُمَا وَمَاتَ الآخَرُ بَعْدَهُ فَصَلَّيْنَا عَلَيْهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا قُلْتُمْ ‏"‏ ‏.‏ قَالُوا دَعَوْنَا لَهُ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ اللَّهُمَّ أَلْحِقْهُ بِصَاحِبِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَأَيْنَ صَلاَتُهُ بَعْدَ صَلاَتِهِ وَأَيْنَ عَمَلُهُ بَعْدَ عَمَلِهِ فَلَمَا بَيْنَهُمَا كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏"‏ ‏.‏ قَالَ عَمْرُو بْنُ مَيْمُونٍ أَعْجَبَنِي لأَنَّهُ أَسْنَدَ لِي ‏.‏\hadithno{1985}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Maimun from "Abdullah bin Rubayy'ah As-Sulami, who was also one of the Companions of Allah's Messenger from 'Ubaid bin Khalid As-Sulami, that:the Messenger of Allah established the bond of brotherhood between two men. One of them was killed and the other died after him. We offered the funeral prayer for him, and the Prophet said: "What did you say?" They said: "O Allah, forgive him; O Allah, have mercy on him; O Allah, join him with his companion." The Prophet said: "Where is his Salah in comparison to his companion's Salah? Where are his deeds in comparison to his companion's deeds? Indeed the difference between heaven and Earth." (One of narrators) 'Amr bin Maimun Said: "I was happy with that because he raised it for me}}
\hadithdefcmd{nasai}{1986}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا هِشَامُ بْنُ أَبِي عَبْدِ اللَّهِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي إِبْرَاهِيمَ الأَنْصَارِيِّ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ فِي الصَّلاَةِ عَلَى الْمَيِّتِ ‏ "‏ اللَّهُمَّ اغْفِرْ لِحَيِّنَا وَمَيِّتِنَا وَشَاهِدِنَا وَغَائِبِنَا وَذَكَرِنَا وَأُنْثَانَا وَصَغِيرِنَا وَكَبِيرِنَا ‏"‏ ‏.‏\hadithno{1986}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Ibrahim Al-Ansari, from his father, that:he heard the Prophet say, when offering the funeral prayer for one who had died: Allahummighfir lihayyina wa mayyitina wa shahidina wa gha'ibina wadhakarina wa unthana wa saghirina wa kabirina (O Allah, forgive our living and our dead, those who are present among us and those who are absent, our males and our females, our young and our old)}}
\hadithdefcmd{nasai}{1987}{أَخْبَرَنَا الْهَيْثَمُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ، - وَهُوَ ابْنُ سَعْدٍ - قَالَ حَدَّثَنَا أَبِي، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، قَالَ صَلَّيْتُ خَلْفَ ابْنِ عَبَّاسٍ عَلَى جَنَازَةٍ فَقَرَأَ بِفَاتِحَةِ الْكِتَابِ وَسُورَةٍ وَجَهَرَ حَتَّى أَسْمَعَنَا فَلَمَّا فَرَغَ أَخَذْتُ بِيَدِهِ فَسَأَلْتُهُ فَقَالَ سُنَّةٌ وَحَقٌّ ‏.‏\hadithno{1987}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Talhah bin 'Abdullah bin 'Awf said:"I offered the funeral prayer behind Ibn 'Abbas. He recited Fatihat Al-Kitab and a Surah, which he recited loudly, such that we could hear him. When he finished I took him by the hand and asked him. He said: '(It is) Sunnah and the truth}}
\hadithdefcmd{nasai}{1988}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ، قَالَ صَلَّيْتُ خَلْفَ ابْنِ عَبَّاسٍ عَلَى جَنَازَةٍ فَسَمِعْتُهُ يَقْرَأُ، بِفَاتِحَةِ الْكِتَابِ فَلَمَّا انْصَرَفَ أَخَذْتُ بِيَدِهِ فَسَأَلْتُهُ فَقُلْتُ تَقْرَأُ قَالَ نَعَمْ إِنَّهُ حَقٌّ وَسُنَّةٌ ‏.‏\hadithno{1988}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Talhah bin 'Abdullah said:"I offered the funeral prayer behind Ibn 'Abbas and I heard him reciting Fatihat Al-Kitab. When he finished I took him by the hand and asked him. 'Did you recite?' He said: 'Yes, it is the truth and the Sunnah}}
\hadithdefcmd{nasai}{1989}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ، أَنَّهُ قَالَ السُّنَّةُ فِي الصَّلاَةِ عَلَى الْجَنَازَةِ أَنْ يَقْرَأَ فِي التَّكْبِيرَةِ الأُولَى بِأُمِّ الْقُرْآنِ مُخَافَتَةً ثُمَّ يُكَبِّرَ ثَلاَثًا وَالتَّسْلِيمُ عِنْدَ الآخِرَةِ ‏.‏\hadithno{1989}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(It was narrated that Abu Umamah said:"The Sunnah, when offering the funeral prayer, is to recite Umm Al-Qur'an) the Exxence of the Qur'an) quietly in the first Takbir, Then to say three (more) Takbir and to say the Taslim after the last one}}
\hadithdefcmd{nasai}{1990}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ سُوَيْدٍ الدِّمَشْقِيِّ الْفِهْرِيِّ، عَنِ الضَّحَّاكِ بْنِ قَيْسٍ الدِّمَشْقِيِّ، بِنَحْوِ ذَلِكَ ‏.‏\hadithno{1990}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated by Ad-Dahhak bin Qais Ad-Dimashqi:A similar report was narrated from Ad-Dahhak bin Qais Ad-Dimashqi}}
\hadithdefcmd{nasai}{1991}{أَخْبَرَنَا سُوَيْدٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ سَلاَّمِ بْنِ أَبِي مُطِيعٍ الدِّمَشْقِيِّ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، رَضِيعِ عَائِشَةَ عَنْ عَائِشَةَ، رَضِيَ اللَّهُ عَنْهَا عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مَيِّتٍ يُصَلِّي عَلَيْهِ أُمَّةٌ مِنَ الْمُسْلِمِينَ يَبْلُغُونَ أَنْ يَكُونُوا مِائَةً يَشْفَعُونَ إِلاَّ شُفِّعُوا فِيهِ ‏"‏ ‏.‏ قَالَ سَلاَّمٌ فَحَدَّثْتُ بِهِ شُعَيْبَ بْنَ الْحَبْحَابِ فَقَالَ حَدَّثَنِي بِهِ أَنَسُ بْنُ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1991}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"There is no deceased person for whom a group of Muslims whose number reaches one hundred, offers the funeral prayer, interceding for him; but their intercession for him will be accepted." (One of the narrators) Sallam said: "I narrated it to Shu'aib bin Al-Habhab and he said: 'Anas bin Malik narrated it to me from the Prophet}}
\hadithdefcmd{nasai}{1992}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، - رَضِيعٌ لِعَائِشَةَ رضى الله عنها - عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمُوتُ أَحَدٌ مِنَ الْمُسْلِمِينَ فَيُصَلِّي عَلَيْهِ أُمَّةٌ مِنَ النَّاسِ فَيَبْلُغُوا أَنْ يَكُونُوا مِائَةً فَيَشْفَعُوا إِلاَّ شُفِّعُوا فِيهِ ‏"‏ ‏.‏\hadithno{1992}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"No Muslim dies and a group of people whose number reaches one hundred offers the funeral prayer for him, interceding fro him, but their intercession for him will be accepted}}
\hadithdefcmd{nasai}{1993}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ سَوَاءٍ أَبُو الْخَطَّابِ، قَالَ حَدَّثَنَا أَبُو بَكَّارٍ الْحَكَمُ بْنُ فَرُّوخٍ، قَالَ صَلَّى بِنَا أَبُو الْمَلِيحِ عَلَى جَنَازَةٍ فَظَنَنَّا أَنَّهُ قَدْ كَبَّرَ فَأَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ أَقِيمُوا صُفُوفَكُمْ وَلْتَحْسُنْ شَفَاعَتُكُمْ قَالَ أَبُو الْمَلِيحِ حَدَّثَنِي عَبْدُ اللَّهِ - وَهُوَ ابْنُ سَلِيطٍ - عَنْ إِحْدَى أُمَّهَاتِ الْمُؤْمِنِينَ وَهِيَ مَيْمُونَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم قَالَتْ أَخْبَرَنِي النَّبِيُّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مَيِّتٍ يُصَلِّي عَلَيْهِ أُمَّةٌ مِنَ النَّاسِ إِلاَّ شُفِّعُوا فِيهِ ‏"‏ ‏.‏ فَسَأَلْتُ أَبَا الْمَلِيحِ عَنِ الأُمَّةِ فَقَالَ أَرْبَعُونَ ‏.‏\hadithno{1993}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Bakkar Al-Hakam bin Farrukh said:"Abu Al-Malih led us in offering the funeral prayer and we thought that he had said the Takbir, but he turned to us and said: 'Make you rows straight and intercede properly.' Abu Al-Malih said: Abdullah - meaning Ibn Salit-narrated to me that one of the Mothers of the believes, Maimunah the wife of the Prophet, said: The Prophet told me: There is no deceased person for whom a group of people offers the funeral prayer, but their intercession for him will be accepted.' I asked Abu Al-Malih about the (number of that) group and he said: 'Forty}}
\hadithdefcmd{nasai}{1994}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى عَلَى جَنَازَةٍ فَلَهُ قِيرَاطٌ وَمَنِ انْتَظَرَهَا حَتَّى تُوضَعَ فِي اللَّحْدِ فَلَهُ قِيرَاطَانِ وَالْقِيرَاطَانِ مِثْلُ الْجَبَلَيْنِ الْعَظِيمَيْنِ ‏"‏ ‏.‏\hadithno{1994}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{(It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever offers the funeral prayer will have one Qirat and whoever stays until )the body) is placed in the Lahd will have two Qirats, and the two Qirats are like two great mountains}}
\hadithdefcmd{nasai}{1995}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ الأَعْرَجُ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ شَهِدَ جَنَازَةً حَتَّى يُصَلَّى عَلَيْهَا فَلَهُ قِيرَاطٌ وَمَنْ شَهِدَ حَتَّى تُدْفَنَ فَلَهُ قِيرَاطَانِ ‏"‏ ‏.‏ قِيلَ وَمَا الْقِيرَاطَانِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ مِثْلُ الْجَبَلَيْنِ الْعَظِيمَيْنِ ‏"‏ ‏.‏\hadithno{1995}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah Said:"The Messenger of Allah said: 'Whoever attends a funeral until the prayer is offered will have one Qirat and whoever attends until (the body) is buried will have two Qirats."' It was said: "What are the two Qirats, O Messenger of Allah?" He said: "Like two great mountains}}
\hadithdefcmd{nasai}{1996}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ عَوْفٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَبِعَ جَنَازَةَ رَجُلٍ مُسْلِمٍ احْتِسَابًا فَصَلَّى عَلَيْهَا وَدَفَنَهَا فَلَهُ قِيرَاطَانِ وَمَنْ صَلَّى عَلَيْهَا ثُمَّ رَجَعَ قَبْلَ أَنْ تُدْفَنَ فَإِنَّهُ يَرْجِعُ بِقِيرَاطٍ مِنَ الأَجْرِ ‏"‏ ‏.‏\hadithno{1996}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever follows the funeral of a Muslim man, seeking reward, and offers the prayer and buries him, will have two Qirats. And whoever offers the funeral prayer then goes back before the burial, then he returns with one Qirat of reward}}
\hadithdefcmd{nasai}{1997}{أَخْبَرَنَا الْحَسَنُ بْنُ قَزَعَةَ، قَالَ حَدَّثَنَا مَسْلَمَةُ بْنُ عَلْقَمَةَ، قَالَ أَنْبَأَنَا دَاوُدُ، عَنْ عَامِرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَبِعَ جَنَازَةً فَصَلَّى عَلَيْهَا ثُمَّ انْصَرَفَ فَلَهُ قِيرَاطٌ مِنَ الأَجْرِ وَمَنْ تَبِعَهَا فَصَلَّى عَلَيْهَا ثُمَّ قَعَدَ حَتَّى يُفْرَغَ مِنْ دَفْنِهَا فَلَهُ قِيرَاطَانِ مِنَ الأَجْرِ كُلُّ وَاحِدٍ مِنْهُمَا أَعْظَمُ مِنْ أُحُدٍ ‏"‏ ‏.‏\hadithno{1997}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever follows a funeral and offers the funeral prayer then leaves, will have one Qirat reward. And whoever follows it and offers the funeral prayer then stays until the burial is completed will have two Qirat of reward, both of which are greater than Uhud}}
\hadithdefcmd{nasai}{1998}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هِشَامٍ، وَالأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا وَمَنْ تَبِعَهَا فَلاَ يَقْعُدَنَّ حَتَّى تُوضَعَ ‏"‏ ‏.‏\hadithno{1998}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah said: 'If you see a funeral, then stand up, and whoever follows it, then let him not sit down until (the body) is placed in the grave}}
\hadithdefcmd{nasai}{1999}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى، عَنْ وَاقِدٍ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ مَسْعُودِ بْنِ الْحَكَمِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، ‏:‏ أَنَّهُ ذُكِرَ الْقِيَامُ عَلَى الْجَنَازَةِ حَتَّى تُوضَعَ، فَقَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ ‏:‏ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَعَدَ ‏.‏\hadithno{1999}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Ali bin Abi Talib that:mention was made of standing at the funeral until the body is placed in the grave. 'Ali bin Abi Talib said: "The Messenger of Allah stood, then he sat down}}
\hadithdefcmd{nasai}{2000}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ مَسْعُودِ بْنِ الْحَكَمِ، عَنْ عَلِيٍّ، قَالَ ‏:‏ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فَقُمْنَا، وَرَأَيْنَاهُ قَعَدَ فَقَعَدْنَا ‏.‏\hadithno{2000}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ali bin Abi Talib that:mention was made of standing at the funeral until the body is placed in the grave. 'Ali bin Abi Talib said: "The Messenger of Allah stood, then he sat down}}
\hadithdefcmd{nasai}{2001}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ زَاذَانَ، عَنِ الْبَرَاءِ، قَالَ ‏:‏ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي جَنَازَةٍ، فَلَمَّا انْتَهَيْنَا إِلَى الْقَبْرِ وَلَمْ يُلْحَدْ، فَجَلَسَ وَجَلَسْنَا حَوْلَهُ كَأَنَّ عَلَى رُءُوسِنَا الطَّيْرَ ‏.‏\hadithno{2001}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Bark' said:"We went out with the Messenger of Allah for a funeral, and when we reached the grave the Lahd had not yet been prepared. He sat, and we sat around him, as if there were birds on our heads}}
\hadithdefcmd{nasai}{2002}{أَخْبَرَنَا هَنَّادٌ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ ثَعْلَبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِقَتْلَى أُحُدٍ ‏:‏ ‏ "‏ زَمِّلُوهُمْ بِدِمَائِهِمْ، فَإِنَّهُ لَيْسَ كَلْمٌ يُكْلَمُ فِي اللَّهِ إِلاَّ يَأْتِي يَوْمَ الْقِيَامَةِ يَدْمَى، لَوْنُهُ لَوْنُ الدَّمِ وَرِيحُهُ رِيحُ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2002}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Tha'labah said:"The Messenger of Allah said, concerning those who had been slain at Uhud: 'Wrap them up on their clothes that are stained with blood, for there is no wound that is sustained for the sake of Allah, but it will come bleeding on the Day of Resurrection: its color will be the color of blood, but its fragrance will be the fragrance of musk}}
\hadithdefcmd{nasai}{2003}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ السَّائِبِ، عَنْ رَجُلٍ، يُقَالُ لَهُ عُبَيْدُ اللَّهِ بْنُ مُعَيَّةَ قَالَ ‏:‏ أُصِيبَ رَجُلاَنِ مِنَ الْمُسْلِمِينَ يَوْمَ الطَّائِفِ، فَحُمِلاَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَ أَنْ يُدْفَنَا حَيْثُ أُصِيبَا ‏.‏ وَكَانَ ابْنُ مُعَيَّةَ وُلِدَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2003}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that a man called 'Ubaidullah bin Mu'ayyah said:"Two Muslim men were killed on the day of At-Ta'if, and they were taken to the Messenger of Allah. He commanded that they be buried where they were killed." Ibn Mu'ayyah was born during the time of the Messenger of Allah}}
\hadithdefcmd{nasai}{2004}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ قَيْسٍ، عَنْ نُبَيْحٍ الْعَنَزِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، ‏:‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِقَتْلَى أُحُدٍ أَنْ يُرَدُّوا إِلَى مَصَارِعِهِمْ، وَكَانُوا قَدْ نُقِلُوا إِلَى الْمَدِينَةِ ‏.‏\hadithno{2004}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah:That the Prophet commanded that those who had been killed at Uhud should be taken back to the place where they fell; they had been brought to Al-Madinah}}
\hadithdefcmd{nasai}{2005}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ نُبَيْحٍ الْعَنَزِيِّ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ ادْفِنُوا الْقَتْلَى فِي مَصَارِعِهِمْ ‏"‏ ‏.‏\hadithno{2005}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that the Prophet said:"Bury the slain where they fell}}
\hadithdefcmd{nasai}{2006}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، عَنْ نَاجِيَةَ بْنِ كَعْبٍ، عَنْ عَلِيٍّ، قَالَ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم، إِنَّ عَمَّكَ الشَّيْخَ الضَّالَّ مَاتَ، فَمَنْ يُوَارِيهِ قَالَ ‏:‏ ‏ "‏ اذْهَبْ فَوَارِ أَبَاكَ وَلاَ تُحْدِثَنَّ حَدَثًا حَتَّى تَأْتِيَنِي ‏"‏ ‏.‏ فَوَارَيْتُهُ ثُمَّ جِئْتُ فَأَمَرَنِي فَاغْتَسَلْتُ وَدَعَا لِي، وَذَكَرَ دُعَاءً لَمْ أَحْفَظْهُ ‏.‏\hadithno{2006}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"I said to the Prophet: 'Your paternal uncle, the old misguided man has died. Who will bury him?' He said: 'Go and bury your father, then do not do anything until you come to me.' So I buried him then I came, and he told me to perform Ghusl and he prayed for me, and he mentioned a supplication that I do not remember}}
\hadithdefcmd{nasai}{2007}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، قَالَ ‏:‏ الْحَدُوا لِي لَحْدًا، وَانْصِبُوا عَلَىَّ نَصْبًا كَمَا فُعِلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2007}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sa'd said:"Make a niche for me in the side of the grave and set up (bricks) over me as was done for the Messenger of Allah}}
\hadithdefcmd{nasai}{2008}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، ‏:‏ أَنَّ سَعْدًا، لَمَّا حَضَرَتْهُ الْوَفَاةُ قَالَ ‏:‏ الْحَدُوا لِي لَحْدًا، وَانْصِبُوا عَلَىَّ نَصْبًا كَمَا فُعِلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2008}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Amir bin Sa'd that when Sa'd was dying he said:"Make a niche for me in the side of the grave and set up (bricks) over me as was done for the Messenger of Allah}}
\hadithdefcmd{nasai}{2009}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ أَبُو عَبْدِ الرَّحْمَنِ الأَذْرَمِيُّ، عَنْ حَكَّامِ بْنِ سَلْمٍ الرَّازِيِّ، عَنْ عَلِيِّ بْنِ عَبْدِ الأَعْلَى، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ اللَّحْدُ لَنَا وَالشَّقُّ لِغَيْرِنَا ‏"‏ ‏.‏\hadithno{2009}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa'eed bin Jubair that Ibn 'Abbas said:The Messenger of Allah said: "The niche is for us and the ditch is for others." (Daif)}}
\hadithdefcmd{nasai}{2010}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ هِشَامِ بْنِ عَامِرٍ، قَالَ ‏:‏ شَكَوْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ أُحُدٍ فَقُلْنَا ‏:‏ يَا رَسُولَ اللَّهِ الْحَفْرُ عَلَيْنَا لِكُلِّ إِنْسَانٍ شَدِيدٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ احْفِرُوا وَأَعْمِقُوا وَأَحْسِنُوا، وَادْفِنُوا الاِثْنَيْنِ وَالثَّلاَثَةَ فِي قَبْرٍ وَاحِدٍ ‏"‏ ‏.‏ قَالُوا ‏:‏ فَمَنْ نُقَدِّمُ يَا رَسُولَ اللَّهِ قَالَ ‏:‏ ‏"‏ قَدِّمُوا أَكْثَرَهُمْ قُرْآنًا ‏"‏ ‏.‏ قَالَ ‏:‏ فَكَانَ أَبِي ثَالِثَ ثَلاَثَةٍ فِي قَبْرٍ وَاحِدٍ ‏.‏\hadithno{2010}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hisham bin 'Amir said:"We complained to the Messenger of Allah on the day of Uhud, saying: 'O Messneger of Allah, it is too difficult for us to dig a grave for each person.' The Messenger of Allah said: 'Dig graves and make them good and deep, and bury two or three in one grave.' They said: 'Who should we put in first, O Messenger of Allah?' He said: 'Put in first the one who knew more Qur'an."' He said: "My father was the third of three in one grave}}
\hadithdefcmd{nasai}{2011}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ حُمَيْدَ بْنَ هِلاَلٍ، عَنْ سَعْدِ بْنِ هِشَامِ بْنِ عَامِرٍ، عَنْ أَبِيهِ، قَالَ ‏:‏ لَمَّا كَانَ يَوْمُ أُحُدٍ أُصِيبَ مِنَ الْمُسْلِمِينَ، وَأَصَابَ النَّاسَ جِرَاحَاتٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ احْفِرُوا وَأَوْسِعُوا، وَادْفِنُوا الاِثْنَيْنِ وَالثَّلاَثَةَ فِي الْقَبْرِ، وَقَدِّمُوا أَكْثَرَهُمْ قُرْآنًا ‏"‏ ‏.‏\hadithno{2011}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sa'eed bin Hisham bin 'Amir that his father said:"On the day of Uhud some of the people among the Muslims were killed, and people were wounded. The Messenger of Allah said: 'Dig graves and make them wide, and bury two or three in a grave, and put the one who knew more Qur'an in first}}
\hadithdefcmd{nasai}{2012}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ جُعِلَ تَحْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ دُفِنَ قَطِيفَةٌ حَمْرَاءُ ‏.‏\hadithno{2012}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"When the Messenger of Allah was buried, a red velvet cloak was placed beneath him}}
\hadithdefcmd{nasai}{2013}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا مُوسَى بْنُ عُلَىِّ بْنِ رَبَاحٍ، قَالَ سَمِعْتُ أَبِي قَالَ، سَمِعْتُ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، قَالَ ‏:‏ ثَلاَثُ سَاعَاتٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَانَا أَنْ نُصَلِّيَ فِيهِنَّ، أَوْ نَقْبُرَ فِيهِنَّ مَوْتَانَا ‏:‏ حِينَ تَطْلُعُ الشَّمْسُ بَازِغَةً حَتَّى تَرْتَفِعَ، وَحِينَ يَقُومُ قَائِمُ الظَّهِيرَةِ حَتَّى تَزُولَ الشَّمْسُ، وَحِينَ تَضَيَّفُ الشَّمْسُ لِلْغُرُوبِ ‏.‏\hadithno{2013}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Uqbah bin 'Amir Al-Juhani said:"There are three times at which the Messenger of Allah forbade us to pray or to bury our dead: When the sun has risen fully until it is higher, when it reaches its zenith until it has passed the zenith, and when the sun starts to set" (Sahib)}}
\hadithdefcmd{nasai}{2014}{أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ الْقَطَّانُ الرَّقِّيُّ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ ‏:‏ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ رَجُلاً مِنْ أَصْحَابِهِ مَاتَ فَقُبِرَ لَيْلاً، وَكُفِّنَ فِي كَفَنٍ غَيْرِ طَائِلٍ، فَزَجَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُقْبَرَ إِنْسَانٌ لَيْلاً إِلاَّ أَنْ يُضْطَرَّ إِلَى ذَلِكَ ‏.‏\hadithno{2014}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jabir said:"The Messenger of Allah delivered a Khutbah and mentioned a man among his Companions who had died and had been buried at night in a shroud that was not sufficient. The Messenger of Allah reprimanded them, telling them not to bury a person at night except in cases of emergency}}
\hadithdefcmd{nasai}{2015}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ هِشَامِ بْنِ عَامِرٍ، قَالَ ‏:‏ لَمَّا كَانَ يَوْمُ أُحُدٍ أَصَابَ النَّاسَ جَهْدٌ شَدِيدٌ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ احْفِرُوا وَأَوْسِعُوا، وَادْفِنُوا الاِثْنَيْنِ وَالثَّلاَثَةَ فِي قَبْرٍ ‏"‏ ‏.‏ فَقَالُوا ‏:‏ يَا رَسُولَ اللَّهِ فَمَنْ نُقَدِّمُ قَالَ ‏:‏ ‏"‏ قَدِّمُوا أَكْثَرَهُمْ قُرْآنًا ‏"‏ ‏.‏\hadithno{2015}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hisham bin 'Amir said:"On the day of Uhud the people were exhausted. The Prophet said: 'Dig graves and make them wide, and bury two or three in a grave.' They said: 'O Messenger of Allah, who should we 'put in first? He said: 'Put in first the one who knew the Qur'an most}}
\hadithdefcmd{nasai}{2016}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ أَنْبَأَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ سَعْدِ بْنِ هِشَامِ بْنِ عَامِرٍ، عَنْ أَبِيهِ، قَالَ ‏:‏ اشْتَدَّ الْجِرَاحُ يَوْمَ أُحُدٍ فَشُكِيَ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏:‏ ‏ "‏ احْفِرُوا وَأَوْسِعُوا وَأَحْسِنُوا، وَادْفِنُوا فِي الْقَبْرِ الاِثْنَيْنِ وَالثَّلاَثَةَ، وَقَدِّمُوا أَكْثَرَهُمْ قُرْآنًا ‏"‏ ‏.‏\hadithno{2016}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sa'd bin Hisham bin 'Amir that his father said:"Many people were wounded on the day of Uhud and complaints were made to the Messenger of Allah about that. He said: 'Dig graves and make them good and wide, and bury two or three in a grave, and put in first the one who knew the Qur'an most}}
\hadithdefcmd{nasai}{2017}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي الدَّهْمَاءِ، عَنْ هِشَامِ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ احْفِرُوا وَأَحْسِنُوا، وَادْفِنُوا الاِثْنَيْنِ وَالثَّلاَثَةَ، وَقَدِّمُوا أَكْثَرَهُمْ قُرْآنًا ‏"‏ ‏.‏\hadithno{2017}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Hisham bin 'Amir that the Messenger of Allah said:"Dig graves and dig them well, and bury two or three (together), and put in first the one who knew the Qur'an most}}
\hadithdefcmd{nasai}{2018}{حَدَّثَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ هِشَامِ بْنِ عَامِرٍ، قَالَ ‏:‏ قُتِلَ أَبِي يَوْمَ أُحُدٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏ "‏ احْفِرُوا وَأَوْسِعُوا وَأَحْسِنُوا، وَادْفِنُوا الاِثْنَيْنِ وَالثَّلاَثَةَ فِي الْقَبْرِ، وَقَدِّمُوا أَكْثَرَهُمْ قُرْآنًا ‏"‏ ‏.‏ فَكَانَ أَبِي ثَالِثَ ثَلاَثَةٍ وَكَانَ أَكْثَرَهُمْ قُرْآنًا فَقُدِّمَ ‏.‏\hadithno{2018}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hisham bin 'Amir said:"My father was killed on the day of Uhud, and the Prophet said: 'Dig graves and make them good and wide, and bury two or three in a grave, and put in first the one who knew the Qur'an most.' My father was the third of three, and the one who knew the Qur'an most was placed (in the grave) first}}
\hadithdefcmd{nasai}{2019}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنْ سُفْيَانَ، قَالَ سَمِعَ عَمْرٌو، جَابِرًا يَقُولُ ‏:‏ أَتَى النَّبِيُّ صلى الله عليه وسلم عَبْدَ اللَّهِ بْنَ أُبَىٍّ بَعْدَ مَا أُدْخِلَ فِي قَبْرِهِ، فَأَمَرَ بِهِ فَأُخْرِجَ فَوَضَعَهُ عَلَى رُكْبَتَيْهِ، وَنَفَثَ عَلَيْهِ مِنْ رِيقِهِ وَأَلْبَسَهُ قَمِيصَهُ، وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{2019}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jabir said:"The Prophet came to 'Abdullah bin Ubayy after he had been placed in his grave, and commanded that he be brought out. He placed him on his knees and blew on him and clothed him in his shirt. And Allah knows best}}
\hadithdefcmd{nasai}{2020}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ ‏:‏ إِنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِعَبْدِ اللَّهِ بْنِ أُبَىٍّ فَأَخْرَجَهُ مِنْ قَبْرِهِ، فَوَضَعَ رَأْسَهُ عَلَى رُكْبَتَيْهِ فَتَفَلَ فِيهِ مِنْ رِيقِهِ، وَأَلْبَسَهُ قَمِيصَهُ ‏.‏ قَالَ جَابِرٌ ‏:‏ وَصَلَّى عَلَيْهِ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{2020}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir said:"The Prophet commanded that 'Abdullah bin Ubayy by brought out of his grave, then he placed his head on his knees and blew on him and put his shirt on him." "And he prayed for him. And Allah knows best}}
\hadithdefcmd{nasai}{2021}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، عَنْ سَعِيدِ بْنِ عَامِرٍ، عَنْ شُعْبَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ ‏:‏ دُفِنَ مَعَ أَبِي رَجُلٌ فِي الْقَبْرِ فَلَمْ يَطِبْ قَلْبِي حَتَّى أَخْرَجْتُهُ وَدَفَنْتُهُ عَلَى حِدَةٍ ‏.‏\hadithno{2021}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir said:"A man was buried with my father in the same grave and I felt restless until I brought him out and buried him on his own}}
\hadithdefcmd{nasai}{2022}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ أَبُو قُدَامَةَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، عَنْ خَارِجَةَ بْنِ زَيْدِ بْنِ ثَابِتٍ، عَنْ عَمِّهِ، يَزِيدَ بْنِ ثَابِتٍ ‏:‏ أَنَّهُمْ خَرَجُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ، فَرَأَى قَبْرًا جَدِيدًا فَقَالَ ‏:‏ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالُوا ‏:‏ هَذِهِ فُلاَنَةُ مَوْلاَةُ بَنِي فُلاَنٍ، فَعَرَفَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَاتَتْ ظُهْرًا وَأَنْتَ نَائِمٌ قَائِلٌ، فَلَمْ نُحِبَّ أَنْ نُوقِظَكَ بِهَا ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَفَّ النَّاسَ خَلْفَهُ وَكَبَّرَ عَلَيْهَا أَرْبَعًا ثُمَّ قَالَ ‏:‏ ‏"‏ لاَ يَمُوتُ فِيكُمْ مَيِّتٌ مَا دُمْتُ بَيْنَ أَظْهُرِكُمْ إِلاَّ آذَنْتُمُونِي بِهِ، فَإِنَّ صَلاَتِي لَهُ رَحْمَةٌ ‏"‏ ‏.‏\hadithno{2022}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Yazid bin Thabit that:they went out with the Messenger of Allah one day and he saw a new grave. He said: "What is this?" They said: "This is so-and-so, the freed slave woman of Banu so-and-so" - whom Messenger of Allah knew - "She died at midday and we did not like to wake you up when you were fasting and taking a nap." The Messenger of Allah stood (for prayer) and the people formed rows behind him. He said four Takbirs over her then he said: "If anyone among you dies while I am still among you, inform me, for my prayer for his is a mercy}}
\hadithdefcmd{nasai}{2023}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، ‏:‏ أَخْبَرَنِي مَنْ، مَرَّ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى قَبْرٍ مُنْتَبِذٍ، فَأَمَّهُمْ وَصَفَّ خَلْفَهُ، قُلْتُ ‏:‏ مَنْ هُوَ يَا أَبَا عَمْرٍو قَالَ ‏:‏ ابْنُ عَبَّاسٍ ‏.‏\hadithno{2023}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sulaiman Ash-Shaibani from Ash-Sha'bi:"Some people passed by an isolated grave with the Messenger of Allah and he led them in prayer and they formed rows behind him." I said: "Who was that O Abu 'Amr?" He said: "Ibn 'Abbas}}
\hadithdefcmd{nasai}{2024}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ الشَّيْبَانِيُّ أَنْبَأَنَا عَنِ الشَّعْبِيِّ، قَالَ أَخْبَرَنِي مَنْ، رَأَى النَّبِيَّ صلى الله عليه وسلم مَرَّ بِقَبْرٍ مُنْتَبِذٍ، فَصَلَّى عَلَيْهِ وَصَفَّ أَصْحَابَهُ خَلْفَهُ ‏.‏ قِيلَ ‏:‏ مَنْ حَدَّثَكَ قَالَ ‏:‏ ابْنُ عَبَّاسٍ ‏.‏\hadithno{2024}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ash-Shaibani narrated that Ash-Sha'bi said:"Someone who saw the Prophet pass by an isolated grave told me that he offered the funeral prayer there and his Companions formed rows behind him." It was said: "Who told you this?" He said: "Ibn 'Abbas}}
\hadithdefcmd{nasai}{2025}{أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا زَيْدُ بْنُ عَلِيٍّ، - وَهُوَ أَبُو أُسَامَةَ - قَالَ حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنْ حَبِيبِ بْنِ أَبِي مَرْزُوقٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، ‏:‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى قَبْرِ امْرَأَةٍ بَعْدَ مَا دُفِنَتْ ‏.‏\hadithno{2025}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir:That the Prophet prayed at the grave of a woman after she had been buried}}
\hadithdefcmd{nasai}{2026}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، وَيَحْيَى بْنُ آدَمَ، قَالاَ حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ ‏:‏ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى جَنَازَةِ أَبِي الدَّحْدَاحِ، فَلَمَّا رَجَعَ أُتِيَ بِفَرَسٍ مُعْرَوْرًى فَرَكِبَ وَمَشَيْنَا مَعَهُ ‏.‏\hadithno{2026}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"The Messenger of Allah went our to the funeral of Ibn Ad-Dahdah, and when he came back an unsaddled horse was brought to him, so he rode and we walked with him}}
\hadithdefcmd{nasai}{2027}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا حَفْصٌ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، وَأَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ ‏:‏ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُبْنَى عَلَى الْقَبْرِ، أَوْ يُزَادَ عَلَيْهِ، أَوْ يُجَصَّصَ ‏.‏ زَادَ سُلَيْمَانُ بْنُ مُوسَى ‏:‏ أَوْ يُكْتَبَ عَلَيْهِ ‏.‏\hadithno{2027}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah forbade building over graves, making them larger or plastering over them." (One of two narrators) Sulaiman bin Musa added: "Or writing on them}}
\hadithdefcmd{nasai}{2028}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ ‏:‏ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ تَقْصِيصِ الْقُبُورِ، أَوْ يُبْنَى عَلَيْهَا، أَوْ يَجْلِسَ عَلَيْهَا أَحَدٌ ‏.‏\hadithno{2028}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir said:"The Messenger of Allah forbade plastering over graves, building over them or sitting on them}}
\hadithdefcmd{nasai}{2029}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ ‏:‏ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ تَجْصِيصِ الْقُبُورِ ‏.‏\hadithno{2029}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah forbade plastering over graves}}
\hadithdefcmd{nasai}{2030}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ ثُمَامَةَ بْنَ شُفَىٍّ، حَدَّثَهُ قَالَ ‏:‏ كُنَّا مَعَ فَضَالَةَ بْنِ عُبَيْدٍ بِأَرْضِ الرُّومِ فَتُوُفِّيَ صَاحِبٌ لَنَا، فَأَمَرَ فَضَالَةُ بِقَبْرِهِ فَسُوِّيَ، ثُمَّ قَالَ ‏:‏ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِتَسْوِيَتِهَا ‏.‏\hadithno{2030}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thumamah bin Shufa narrated:"We were with Fadalah bin 'Ubaid in the land of the Romans, and a companion of ours died. Fadalah ordered that his grave be made level, then he said: 'I heard the Messenger of Allah commanding that it be made level}}
\hadithdefcmd{nasai}{2031}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي الْهَيَّاجِ، قَالَ قَالَ عَلِيٌّ رضى الله عنه ‏:‏ أَلاَ أَبْعَثُكَ عَلَى مَا بَعَثَنِي عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ تَدَعَنَّ قَبْرًا مُشْرِفًا إِلاَّ سَوَّيْتَهُ، وَلاَ صُورَةً فِي بَيْتٍ إِلاَّ طَمَسْتَهَا ‏.‏\hadithno{2031}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ali said:"Shall I not send you on the same mission as the Messenger of Allah sent me? Do not leave any raised grave without leveling it, or any image in a house without erasing it}}
\hadithdefcmd{nasai}{2032}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، عَنِ ابْنِ فُضَيْلٍ، عَنْ أَبِي سِنَانٍ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ نَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوهَا، وَنَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي فَوْقَ ثَلاَثَةِ أَيَّامٍ فَأَمْسِكُوا مَا بَدَا لَكُمْ، وَنَهَيْتُكُمْ عَنِ النَّبِيذِ إِلاَّ فِي سِقَاءٍ فَاشْرَبُوا فِي الأَسْقِيَةِ كُلِّهَا، وَلاَ تَشْرَبُوا مُسْكِرًا ‏"‏ ‏.‏\hadithno{2032}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It is was narrated from 'Abdullah bin Buraidah that his father said:"The Messenger of Allah said: 'I forbade you to visit graves but now visit them; and I forbade you to eat the sacrificial meat after three days, but now keep it as long as you want; and I forbade you to make Nabidh I anything but a water-skin but now drink it from any kind of container, but do not drink intoxicants}}
\hadithdefcmd{nasai}{2033}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ أَبِي فَرْوَةَ، عَنِ الْمُغِيرَةِ بْنِ سُبَيْعٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، ‏:‏ أَنَّهُ كَانَ فِي مَجْلِسٍ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏:‏ ‏ "‏ إِنِّي كُنْتُ نَهَيْتُكُمْ أَنْ تَأْكُلُوا لُحُومَ الأَضَاحِي إِلاَّ ثَلاَثًا، فَكُلُوا وَأَطْعِمُوا وَادَّخِرُوا مَا بَدَا لَكُمْ، وَذَكَرْتُ لَكُمْ أَنْ لاَ تَنْتَبِذُوا فِي الظُّرُوفِ الدُّبَّاءِ وَالْمُزَفَّتِ وَالنَّقِيرِ وَالْحَنْتَمِ، انْتَبِذُوا فِيمَا رَأَيْتُمْ وَاجْتَنِبُوا كُلَّ مُسْكِرٍ، وَنَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَمَنْ أَرَادَ أَنْ يَزُورَ فَلْيَزُرْ، وَلاَ تَقُولُوا هُجْرًا ‏"‏ ‏.‏\hadithno{2033}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Buraidah narrated from his father:That he was in a gathering where the Messenger of Allah was present and he said: "I used to forbid you to eat the sacrificial mea for more than three days, but now eat it, give it to others and store it for as long as you want. And I told you not to make Nabidh in these containers: Ad-Dubba', Al-Muzaqqat, An-Naqir, and Al-Hantam. But now make Nabidh in whatever you want, but avoid everything that intoxicates. And I forbade you to visit graves, but now whoever want to visit them, let him do so, but do not utter anything which is not suitable}}
\hadithdefcmd{nasai}{2034}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏:‏ زَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْرَ أُمِّهِ فَبَكَى وَأَبْكَى مَنْ حَوْلَهُ وَقَالَ ‏:‏ ‏ "‏ اسْتَأْذَنْتُ رَبِّي عَزَّ وَجَلَّ فِي أَنْ أَسْتَغْفِرَ لَهَا فَلَمْ يُؤْذَنْ لِي، وَاسْتَأْذَنْتُ فِي أَنْ أَزُورَ قَبْرَهَا فَأَذِنَ لِي، فَزُورُوا الْقُبُورَ فَإِنَّهَا تُذَكِّرُكُمُ الْمَوْتَ ‏"‏ ‏.‏\hadithno{2034}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah visited the grave of his mother and wept, and caused those around him to weep. He said: 'I asked my Lord for permission to pray for forgiveness for her and He did not give me permission, and I asked Him for permission to visit her grave and He gave me permission, so visit the graves, for they will remind you of death}}
\hadithdefcmd{nasai}{2035}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ ثَوْرٍ - عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِيهِ، قَالَ ‏:‏ لَمَّا حَضَرَتْ أَبَا طَالِبٍ الْوَفَاةُ دَخَلَ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم وَعِنْدَهُ أَبُو جَهْلٍ وَعَبْدُ اللَّهِ بْنُ أَبِي أُمَيَّةَ فَقَالَ ‏:‏ ‏"‏ أَىْ عَمِّ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ كَلِمَةً أُحَاجُّ لَكَ بِهَا عِنْدَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ فَقَالَ لَهُ أَبُو جَهْلٍ وَعَبْدُ اللَّهِ بْنُ أَبِي أُمَيَّةَ ‏:‏ يَا أَبَا طَالِبٍ أَتَرْغَبُ عَنْ مِلَّةِ عَبْدِ الْمُطَّلِبِ ‏.‏ فَلَمْ يَزَالاَ يُكَلِّمَانِهِ حَتَّى كَانَ آخِرُ شَىْءٍ كَلَّمَهُمْ بِهِ عَلَى مِلَّةِ عَبْدِ الْمُطَّلِبِ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ لأَسْتَغْفِرَنَّ لَكَ مَا لَمْ أُنْهَ عَنْكَ ‏"‏ ‏.‏ فَنَزَلَتْ ‏\{‏ مَا كَانَ لِلنَّبِيِّ وَالَّذِينَ آمَنُوا أَنْ يَسْتَغْفِرُوا لِلْمُشْرِكِينَ ‏\}‏ وَنَزَلَتْ ‏\{‏ إِنَّكَ لاَ تَهْدِي مَنْ أَحْبَبْتَ ‏\}‏ ‏.‏\hadithno{2035}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sa'eed bin Al-Musayyab that his father said:"When Abu Talib was dying, the Prophet came to him and found Abu Jahl and 'Abdullah bin Abi Umayyah with him. He said: 'O uncle, say La ilaha illallah(there is none worthy of worship except Allah), a word with which I will defend you before Allah.' Abu Jahl and 'Abdullah bin Abi Umayyah said: 'O Abu Talib, are you turning away from the religion of 'Abdul-Muttalib.' Then the Prophet said: 'I will keep on asking for Allah's forgiveness for you unless I am forbidden to do so.' Then the following was revealed: It is not (proper) for the Prophet and those who believe to ask Allah's forgiveness for the idolaters. And the following was revealed: Verily, you (O Muhammad) guide not whom you like}}
\hadithdefcmd{nasai}{2036}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَلِيٍّ، قَالَ ‏:‏ سَمِعْتُ رَجُلاً، يَسْتَغْفِرُ لأَبَوَيْهِ وَهُمَا مُشْرِكَانِ فَقُلْتُ ‏:‏ أَتَسْتَغْفِرُ لَهُمَا وَهُمَا مُشْرِكَانِ فَقَالَ أَوَلَمْ يَسْتَغْفِرْ إِبْرَاهِيمُ لأَبِيهِ ‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَنَزَلَتْ ‏\{‏ وَمَا كَانَ اسْتِغْفَارُ إِبْرَاهِيمَ لأَبِيهِ إِلاَّ عَنْ مَوْعِدَةٍ وَعَدَهَا إِيَّاهُ ‏\}‏ ‏.‏\hadithno{2036}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"I heard a man praying for forgiveness for his parents who were idolaters, and I said: 'Are you praying for forgiveness for them even though they are idolators?" He said: 'Didn't Ibrahim pray for forgiveness for his father?' I went to the Prophet and told him about that, then the following revealed: And Ibrahim's (Abraham) invoking (of Allah) for his father's forgiveness was only because of a promise he (Ibrahim) had made to him (his father)." (Daif)}}
\hadithdefcmd{nasai}{2037}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، أَنَّهُ سَمِعَ مُحَمَّدَ بْنَ قَيْسِ بْنِ مَخْرَمَةَ، يَقُولُ سَمِعْتُ عَائِشَةَ، تُحَدِّثُ قَالَتْ ‏:‏ أَلاَ أُحَدِّثُكُمْ عَنِّي وَعَنِ النَّبِيِّ صلى الله عليه وسلم قُلْنَا ‏:‏ بَلَى ‏.‏ قَالَتْ ‏:‏ لَمَّا كَانَتْ لَيْلَتِي الَّتِي هُوَ عِنْدِي تَعْنِي النَّبِيَّ صلى الله عليه وسلم انْقَلَبَ فَوَضَعَ نَعْلَيْهِ عِنْدَ رِجْلَيْهِ، وَبَسَطَ طَرَفَ إِزَارِهِ عَلَى فِرَاشِهِ، فَلَمْ يَلْبَثْ إِلاَّ رَيْثَمَا ظَنَّ أَنِّي قَدْ رَقَدْتُ، ثُمَّ انْتَعَلَ رُوَيْدًا وَأَخَذَ رِدَاءَهُ رُوَيْدًا، ثُمَّ فَتَحَ الْبَابَ رُوَيْدًا وَخَرَجَ رُوَيْدًا وَجَعَلْتُ دِرْعِي فِي رَأْسِي وَاخْتَمَرْتُ وَتَقَنَّعْتُ إِزَارِي، وَانْطَلَقْتُ فِي إِثْرِهِ حَتَّى جَاءَ الْبَقِيعَ، فَرَفَعَ يَدَيْهِ ثَلاَثَ مَرَّاتٍ فَأَطَالَ، ثُمَّ انْحَرَفَ فَانْحَرَفْتُ، فَأَسْرَعَ فَأَسْرَعْتُ، فَهَرْوَلَ فَهَرْوَلْتُ، فَأَحْضَرَ فَأَحْضَرْتُ وَسَبَقْتُهُ فَدَخَلْتُ، فَلَيْسَ إِلاَّ أَنِ اضْطَجَعْتُ فَدَخَلَ فَقَالَ ‏:‏ ‏"‏ مَا لَكِ يَا عَائِشَةُ حَشْيَا رَابِيَةً ‏"‏ ‏.‏ قَالَتْ ‏:‏ لاَ ‏.‏ قَالَ ‏:‏ ‏"‏ لَتُخْبِرِنِّي أَوْ لَيُخْبِرَنِّي اللَّطِيفُ الْخَبِيرُ ‏"‏ ‏.‏ قُلْتُ ‏:‏ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي، فَأَخْبَرْتُهُ الْخَبَرَ ‏.‏ قَالَ ‏:‏ ‏"‏ فَأَنْتِ السَّوَادُ الَّذِي رَأَيْتُ أَمَامِي ‏"‏ ‏.‏ قَالَتْ ‏:‏ نَعَمْ، فَلَهَزَنِي فِي صَدْرِي لَهْزَةً أَوْجَعَتْنِي، ثُمَّ قَالَ ‏:‏ ‏"‏ أَظَنَنْتِ أَنْ يَحِيفَ اللَّهُ عَلَيْكِ وَرَسُولُهُ ‏"‏ ‏.‏ قُلْتُ ‏:‏ مَهْمَا يَكْتُمُ النَّاسُ فَقَدْ عَلِمَهُ اللَّهُ ‏.‏ قَالَ ‏:‏ ‏"‏ فَإِنَّ جِبْرِيلَ أَتَانِي حِينَ رَأَيْتِ وَلَمْ يَدْخُلْ عَلَىَّ وَقَدْ وَضَعْتِ ثِيَابَكِ فَنَادَانِي، فَأَخْفَى مِنْكِ فَأَجَبْتُهُ فَأَخْفَيْتُهُ مِنْكِ، فَظَنَنْتُ أَنْ قَدْ رَقَدْتِ وَكَرِهْتُ أَنْ أُوقِظَكِ، وَخَشِيتُ أَنْ تَسْتَوْحِشِي، فَأَمَرَنِي أَنْ آتِيَ الْبَقِيعَ فَأَسْتَغْفِرَ لَهُمْ ‏"‏ ‏.‏ قُلْتُ ‏:‏ كَيْفَ أَقُولُ يَا رَسُولَ اللَّهِ قَالَ ‏:‏ ‏"‏ قُولِي السَّلاَمُ عَلَى أَهْلِ الدِّيَارِ مِنَ الْمُؤْمِنِينَ وَالْمُسْلِمِينَ، يَرْحَمُ اللَّهُ الْمُسْتَقْدِمِينَ مِنَّا وَالْمُسْتَأْخِرِينَ، وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ ‏"‏ ‏.‏\hadithno{2037}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin Qais bin Makhramah said:"Aishah said: 'Shall I not tell you about me and about the Prophet?' We said: 'Yes.' She said: 'When it was my night when he was with me' - meaning the Prophet -'He came back (from 'Isha' prayer), put his sandals by his feet and spread the edge of his Izar on his bed. He stayed until he thought that I had gone to sleep. Then he put his sandals on slowly, picked up his cloak slowly, then opened the door slowly and went out slowly. I covered my head, put on my vie and tightened my waist wrapper, then I followed his steps until he came to Al-Baqi'. He raised his hands three times, and stood there for a long time, then he left and I left. He hastened and I also hastened; he ran and I also ran. He came (to the house) and I also came, but I got there first and entered, and as I lay down he came in. He said: "Tell me, or the Subtle, the All-Aware will tell me.' I said: 'O Messenger of Allah, may my father and mother be ransomed for you,' and I told him (the whole story). He said: 'So you were the black shape that I saw in front of me?' I said, 'Yes.' He gave me a nudge on the chest which I felt, then he said: 'Did you think that Allah and His Messenger would deal unjustly with you?' I said: 'Whatever the people conceal, Allah knows it.' He said: Jibril came to me when I saw you, but he did not enter upon me because you where not fully dressed. He called me but he concealed that from you, and I answered him, but I concealed that from you too. I thought that you had gone to sleep and I did not want to wake you up, and I was afraid that you would be frightened. He told me to go to Al-Baqi' and pray for forgiveness for them.' I said: 'What should I say, O Messenger of Allah?' He said: 'Say" Peace be upon the inhabitants of this place among the believers and Muslims. May Allah have mercy upon those who have gone on ahead of us and those who come later on, and we will join you, if Allah wills}}
\hadithdefcmd{nasai}{2038}{أَخْبَرَنِي مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، أَنَّهَا سَمِعَتْ عَائِشَةَ، تَقُولُ ‏:‏ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَلَبِسَ ثِيَابَهُ ثُمَّ خَرَجَ - قَالَتْ - فَأَمَرْتُ جَارِيَتِي بَرِيرَةَ تَتْبَعُهُ فَتَبِعَتْهُ حَتَّى جَاءَ الْبَقِيعَ، فَوَقَفَ فِي أَدْنَاهُ مَا شَاءَ اللَّهُ أَنْ يَقِفَ، ثُمَّ انْصَرَفَ فَسَبَقَتْهُ بَرِيرَةُ فَأَخْبَرَتْنِي، فَلَمْ أَذْكُرْ لَهُ شَيْئًا حَتَّى أَصْبَحْتُ، ثُمَّ ذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏:‏ ‏ "‏ إِنِّي بُعِثْتُ إِلَى أَهْلِ الْبَقِيعِ لأُصَلِّيَ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{2038}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Alqamah bin Abi 'Alqamah, from his mother, that she heard 'Aishah say:"The Messenger of Allah got up one night and got dressed, then he went out. I told my slave girl Barirah to follow him, so she followed him until he came to Al-Baqi. Then he stood near if for as long as Allah willed that he should stand, then he left. Barirah came back before he did and told me, but I did not mention anything until morning came, then I mentioned that to him. He said: 'I was sent to the people of Al-Baqi' to pray for them}}
\hadithdefcmd{nasai}{2039}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا شَرِيكٌ، - وَهُوَ ابْنُ أَبِي نَمِرٍ - عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، قَالَتْ ‏:‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم كُلَّمَا كَانَتْ لَيْلَتُهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَخْرُجُ فِي آخِرِ اللَّيْلِ إِلَى الْبَقِيعِ فَيَقُولُ ‏:‏ ‏ "‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ، وَإِنَّا وَإِيَّاكُمْ مُتَوَاعِدُونَ غَدًا أَوْ مُوَاكِلُونَ، وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ، اللَّهُمَّ اغْفِرْ لأَهْلِ بَقِيعِ الْغَرْقَدِ ‏"‏ ‏.‏\hadithno{2039}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said that:every time it was her night for the Messenger of Allah to stay with her, he would go out at the end of the night to Al-Baqi' and say: "As-salamu 'alaykum dara qawmin mu'minin, wa inna wa iyyakum mutawa'idun ghadan wa mutawakilun, wa inna in sha' Allahu bikum lahiqun. Allahummaghfir li ahli baqi'il gharaqad. (Peace be upon you, O abode of believing people. You and we used to remind one another about the Day of Resurrection and we are relying on one another (with regard to intercession and bearing witness). Soon we will join you, if Allah willing. O Allah, forgive the people of Baqi' Al-Charqad}}
\hadithdefcmd{nasai}{2040}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَتَى عَلَى الْمَقَابِرِ فَقَالَ ‏:‏ ‏ "‏ السَّلاَمُ عَلَيْكُمْ أَهْلَ الدِّيَارِ مِنَ الْمُؤْمِنِينَ وَالْمُسْلِمِينَ، وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ، أَنْتُمْ لَنَا فَرَطٌ وَنَحْنُ لَكُمْ تَبَعٌ، أَسْأَلُ اللَّهَ الْعَافِيَةَ لَنَا وَلَكُمْ ‏"‏ ‏.‏\hadithno{2040}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sulaiman bin Buraidah, from his father, that:when the Messenger of Allah came to the graveyard he would say: "As-salamu 'alaykum ahli ad-diyari min al-mu'minin wal-muslimin wa inna I sha' Allahu bikum lana faratun wa nahnu lakum taba'un, as'alullahal-'afiyata lana wa lakum. (Peace by upon the inhabitants of this place among the believers and Muslims. Soon we will join you, if Allah willing. You have gone on ahead of us and we will follow you. I ask Allah to keep us and you safe and sound)}}
\hadithdefcmd{nasai}{2041}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏:‏ لَمَّا مَاتَ النَّجَاشِيُّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏ "‏ اسْتَغْفِرُوا لَهُ ‏"‏ ‏.‏\hadithno{2041}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"When An-Najashi died, the Prophet said: 'Pray for forgiveness for him}}
\hadithdefcmd{nasai}{2042}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، وَابْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُمَا ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى لَهُمُ النَّجَاشِيَّ صَاحِبَ الْحَبَشَةِ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ فَقَالَ ‏:‏ ‏ "‏ اسْتَغْفِرُوا لأَخِيكُمْ ‏"‏ ‏.‏\hadithno{2042}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah:Said that the Messenger of Allah announced the death of An-Najashi, the ruler of Ethiopia, to them on the day that he died, and said "Pray for forgiveness for your brother}}
\hadithdefcmd{nasai}{2043}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ أَبِي صَالِحٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَائِرَاتِ الْقُبُورِ وَالْمُتَّخِذِينَ عَلَيْهَا الْمَسَاجِدَ وَالسُّرُجَ ‏.‏\hadithno{2043}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allah cursed women who visit graves, and those who take them as Masjid and put lamps on them}}
\hadithdefcmd{nasai}{2044}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، عَنْ وَكِيعٍ، عَنْ سُفْيَانَ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَجْلِسَ أَحَدُكُمْ عَلَى جَمْرَةٍ حَتَّى تَحْرِقَ ثِيَابَهُ خَيْرٌ لَهُ مِنْ أَنْ يَجْلِسَ عَلَى قَبْرٍ ‏"‏ ‏.‏\hadithno{2044}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'If any one of you were to sit on a live coal until it burns his garment, that would be better for him than sitting on a grave}}
\hadithdefcmd{nasai}{2045}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنِ النَّضْرِ بْنِ عَبْدِ اللَّهِ السَّلَمِيِّ، عَنْ عَمْرِو بْنِ حَزْمٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقْعُدُوا عَلَى الْقُبُورِ ‏"‏ ‏.‏\hadithno{2045}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Hazm that the Messenger of Allah said:"do not sit on graves}}
\hadithdefcmd{nasai}{2046}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ قَوْمًا اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏\hadithno{2046}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Aishah that the Prophet said:"May Allah curse people who take the graves of their prophets as Masjids}}
\hadithdefcmd{nasai}{2047}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ أَبُو يَحْيَى، صَاعِقَةُ قَالَ حَدَّثَنَا أَبُو سَلَمَةَ الْخُزَاعِيُّ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْيَهُودَ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏\hadithno{2047}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"May Allah curse the Jews and Christians who took the graves of their prophets as Masjids." (Sahih) Chpater 107. It Is Disliked to Walk Between Grave Wearing Sibtiyah Sandals}}
\hadithdefcmd{nasai}{2048}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَسْوَدِ بْنِ شَيْبَانَ، - وَكَانَ ثِقَةً - عَنْ خَالِدِ بْنِ سُمَيْرٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، أَنَّ بَشِيرَ ابْنَ الْخَصَاصِيَّةِ، قَالَ كُنْتُ أَمْشِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَرَّ عَلَى قُبُورِ الْمُسْلِمِينَ فَقَالَ ‏"‏ لَقَدْ سَبَقَ هَؤُلاَءِ شَرًّا كَثِيرًا ‏"‏ ‏.‏ ثُمَّ مَرَّ عَلَى قُبُورِ الْمُشْرِكِينَ فَقَالَ ‏"‏ لَقَدْ سَبَقَ هَؤُلاَءِ خَيْرًا كَثِيرًا ‏"‏ ‏.‏ فَحَانَتْ مِنْهُ الْتِفَاتَةٌ فَرَأَى رَجُلاً يَمْشِي بَيْنَ الْقُبُورِ فِي نَعْلَيْهِ فَقَالَ ‏"‏ يَا صَاحِبَ السِّبْتِيَّتَيْنِ أَلْقِهِمَا ‏"‏ ‏.‏\hadithno{2048}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Bashir bin Al-Khasasiyyah said:"I was waliking with the Messenger of Allah and he passed by the graves of the Muslims and aid: 'They died before a great deal of evil came to them.' Then he passed by the grave of the idolators and said: 'They died before a great deal of good came to them.' Then he rurned, and he saw a man walking between the graves in his sandals and he said; 'O you with the Sibtiyah sandals, take them off"'. (Shahih)}}
\hadithdefcmd{nasai}{2049}{أَخْبَرَنَا أَحْمَدُ بْنُ أَبِي عُبَيْدِ اللَّهِ الْوَرَّاقُ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْعَبْدَ إِذَا وُضِعَ فِي قَبْرِهِ وَتَوَلَّى عَنْهُ أَصْحَابُهُ إِنَّهُ لَيَسْمَعُ قَرْعَ نِعَالِهِمْ ‏"‏ ‏.‏\hadithno{2049}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that the Prophet said:"when a person is placed in his grave and his companions depart from him, he hears the sound of their sandals}}
\hadithdefcmd{nasai}{2050}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، وَإِبْرَاهِيمُ بْنُ يَعْقُوبَ بْنِ إِسْحَاقَ، قَالاَ حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، عَنْ شَيْبَانَ، عَنْ قَتَادَةَ، أَنْبَأَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْعَبْدَ إِذَا وُضِعَ فِي قَبْرِهِ وَتَوَلَّى عَنْهُ أَصْحَابُهُ إِنَّهُ لَيَسْمَعُ قَرْعَ نِعَالِهِمْ ‏"‏ ‏.‏ قَالَ ‏"‏ فَيَأْتِيهِ مَلَكَانِ فَيُقْعِدَانِهِ فَيَقُولاَنِ لَهُ مَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ فَأَمَّا الْمُؤْمِنُ فَيَقُولُ أَشْهَدُ أَنَّهُ عَبْدُ اللَّهِ وَرَسُولُهُ فَيُقَالُ لَهُ انْظُرْ إِلَى مَقْعَدِكَ مِنَ النَّارِ قَدْ أَبْدَلَكَ اللَّهُ بِهِ مَقْعَدًا مِنَ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَيَرَاهُمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{2050}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Anas bin Malik said:"The Prophet of Allah said: 'When a person is placed in his grave and his companions depart from him, he hears the sound of their sandals. Then two angles came to him and make him sit up, and they say to him: What did you say about this man? As for the believer, he says: "I bear witness that he is the slave of Allah and His Messenger. Then it is said to him: Look at your place in Hell, Which Allah has replaced for you with a place in Paradise. The prophet said: 'And he sees them both}}
\hadithdefcmd{nasai}{2051}{أَخْبَرَنَا أَحْمَدُ بْنُ أَبِي عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْعَبْدَ إِذَا وُضِعَ فِي قَبْرِهِ وَتَوَلَّى عَنْهُ أَصْحَابُهُ إِنَّهُ لَيَسْمَعُ قَرْعَ نِعَالِهِمْ أَتَاهُ مَلَكَانِ فَيُقْعِدَانِهِ فَيَقُولاَنِ لَهُ مَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ مُحَمَّدٍ فَأَمَّا الْمُؤْمِنُ فَيَقُولُ أَشْهَدُ أَنَّهُ عَبْدُ اللَّهِ وَرَسُولُهُ فَيُقَالُ لَهُ انْظُرْ إِلَى مَقْعَدِكَ مِنَ النَّارِ قَدْ أَبْدَلَكَ اللَّهُ بِهِ مَقْعَدًا خَيْرًا مِنْهُ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَيَرَاهُمَا جَمِيعًا وَأَمَّا الْكَافِرُ أَوِ الْمُنَافِقُ فَيُقَالُ لَهُ مَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ فَيَقُولُ لاَ أَدْرِي كُنْتُ أَقُولُ كَمَا يَقُولُ النَّاسُ ‏.‏ فَيُقَالُ لَهُ لاَ دَرَيْتَ وَلاَ تَلَيْتَ ‏.‏ ثُمَّ يُضْرَبُ ضَرْبَةً بَيْنَ أُذُنَيْهِ فَيَصِيحُ صَيْحَةً يَسْمَعُهَا مَنْ يَلِيهِ غَيْرُ الثَّقَلَيْنِ ‏"‏ ‏.‏\hadithno{2051}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that the Prophet said:"When a person is put in his grave and his companions leave him, he hears the sound of their sandals. Two angels come to him, making him sit up, and say to him: 'What did you say about this man (Muhammad)?' As for the believer, he says: 'I bear witness that he says: 'I bear witness that he is the slave of Allah and His Messenger.' It is said to him: 'Look at your place in hell; Allah has replaced it for you with a place better than it.''' The Messenger of Allah said: "Then he sees them both." As for the disbeliever or the hypocrite, it is said to him: 'What did you say about this man?' He says: 'I do not know; I used to say what the people said.' It is said to him: 'You did not understand and you did not follow those who had understanding.' Then he is dealt a blow between his ears and the man utters a scream which everything near him hears, except for the two races}}
\hadithdefcmd{nasai}{2052}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، قَالَ أَخْبَرَنِي جَامِعُ بْنُ شَدَّادٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَسَارٍ، قَالَ كُنْتُ جَالِسًا وَسُلَيْمَانُ بْنُ صُرَدٍ وَخَالِدُ بْنُ عُرْفُطَةَ فَذَكَرُوا أَنَّ رَجُلاً، تُوُفِّيَ مَاتَ بِبَطْنِهِ فَإِذَا هُمَا يَشْتَهِيَانِ أَنْ يَكُونَا شُهَدَاءَ جَنَازَتِهِ فَقَالَ أَحَدُهُمَا لِلآخَرِ أَلَمْ يَقُلْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَقْتُلْهُ بَطْنُهُ فَلَنْ يُعَذَّبَ فِي قَبْرِهِ ‏"‏ ‏.‏ فَقَالَ الآخَرُ بَلَى ‏.‏\hadithno{2052}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Yasar said:"I was sitting with sulaiman bin Sard and Khalid bin 'Urfutah, and they said that a man had died as a result of abdominal illness. They wanted to attend his funeral, and one of them said to the other: 'Didn't the Messenger of Allah say: Whoever is killed by an abdominal illness, he will not be punished in his grave? The other said: 'Yes}}
\hadithdefcmd{nasai}{2053}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنْ لَيْثِ بْنِ سَعْدٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، أَنَّ صَفْوَانَ بْنَ عَمْرٍو، حَدَّثَهُ عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَجُلاً قَالَ يَا رَسُولَ اللَّهِ مَا بَالُ الْمُؤْمِنِينَ يُفْتَنُونَ فِي قُبُورِهِمْ إِلاَّ الشَّهِيدَ قَالَ ‏ "‏ كَفَى بِبَارِقَةِ السُّيُوفِ عَلَى رَأْسِهِ فِتْنَةً ‏"‏ ‏.‏\hadithno{2053}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Rashid bin Sa'd, that a man among the Companions of the Prophet said:"O Messenger of Allah, why will the believers be tested in their graves except the martyr?" He said: "The flashing of the swords above his head is trial enough}}
\hadithdefcmd{nasai}{2054}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، عَنْ عَامِرِ بْنِ مَالِكٍ، عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، قَالَ الطَّاعُونُ وَالْمَبْطُونُ وَالْغَرِيقُ وَالنُّفَسَاءُ شَهَادَةٌ ‏.‏ قَالَ وَحَدَّثَنَا أَبُو عُثْمَانَ مِرَارًا وَرَفَعَهُ مَرَّةً إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2054}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Safwan bin Umayyah said:"The plague, abdominal illness, drowning and dying in childbirth are martyrdom." (One of the narrators) said: Abu 'Uthman narrated this to us several times, and on one occasion he attributed it to the Prophet}}
\hadithdefcmd{nasai}{2055}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ الْعَنْقَزِيُّ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ هَذَا الَّذِي تَحَرَّكَ لَهُ الْعَرْشُ وَفُتِحَتْ لَهُ أَبْوَابُ السَّمَاءِ وَشَهِدَهُ سَبْعُونَ أَلْفًا مِنَ الْمَلاَئِكَةِ لَقَدْ ضُمَّ ضَمَّةً ثُمَّ فُرِّجَ عَنْهُ ‏"‏ ‏.‏\hadithno{2055}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah said:Thos is the one at whose death the Throne shook, the gates of heaven were opened of him and seventy thousand angles attended his funeral. It squeezed him once then released him}}
\hadithdefcmd{nasai}{2056}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِيهِ، عَنْ خَيْثَمَةَ، عَنِ الْبَرَاءِ، قَالَ ‏\{‏ يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ ‏\}‏ قَالَ نَزَلَتْ فِي عَذَابِ الْقَبْرِ ‏.‏\hadithno{2056}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that:Al-Bara said about Allah will keep firm those who believe, with the word that stands firm in this world and in the Hereafter "It was revealed concerning the torment of the grave}}
\hadithdefcmd{nasai}{2057}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏\{‏ يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ ‏\}‏ قَالَ نَزَلَتْ فِي عَذَابِ الْقَبْرِ يُقَالُ لَهُ مَنْ رَبُّكَ فَيَقُولُ رَبِّيَ اللَّهُ وَدِينِي دِينُ مُحَمَّدٍ صلى الله عليه وسلم فَذَلِكَ قَوْلُهُ ‏\{‏ يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ ‏\}‏ ‏.‏\hadithno{2057}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated form Al Bara bin Azib that the Prophet said:"Allah will keep firm those who believe, with the world that stands firm in this world, and in the Hereafter. This was revelated concerning the torment in the grave. It will be said to him (the deceased: 'Who is your Lord?' and he will say: 'My Lord is Allah and my Prophet is Muhammad. That is what is (the meaning of) His saying: Allah will keep firm those who believe, with the word that stands firm in this world, and in the Hereafter}}
\hadithdefcmd{nasai}{2058}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَمِعَ صَوْتًا مِنْ قَبْرٍ فَقَالَ ‏"‏ مَتَى مَاتَ هَذَا ‏"‏ ‏.‏ قَالُوا مَاتَ فِي الْجَاهِلِيَّةِ ‏.‏ فَسُرَّ بِذَلِكَ وَقَالَ ‏"‏ لَوْلاَ أَنْ لاَ تَدَافَنُوا لَدَعَوْتُ اللَّهَ أَنْ يُسْمِعَكُمْ عَذَابَ الْقَبْرِ ‏"‏ ‏.‏\hadithno{2058}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that the Prophet heard a sound from a grave and said:"When died this man die?" They said: "he died during the Jahiliyyah." So he was delighted and said: "Were it not that you would not bury one another, I would have prayed to Allah to make you hear the torment of the grave}}
\hadithdefcmd{nasai}{2059}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ أَخْبَرَنِي عَوْنُ بْنُ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنْ أَبِي أَيُّوبَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ مَا غَرَبَتِ الشَّمْسُ فَسَمِعَ صَوْتًا فَقَالَ ‏ "‏ يَهُودُ تُعَذَّبُ فِي قُبُورِهَا ‏"‏ ‏.‏\hadithno{2059}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Ayyub said:"The Messenger of Allah went out after the sun had set, and heard a sound. He said '(It is ) Jews being tormented in their graves}}
\hadithdefcmd{nasai}{2060}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ عَذَابِ النَّارِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{2060}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah used to say:"Allahumma inni a udhu bika min adhabil-qabri wa a 'udhu bika min 'adhabin-nar, wa a 'udhu bika min fitnatil-mahya wal-mamat, wa audhu bika min fitnatil-masihid-dajjal (O Allah, I seek refuge with you from the torment of the grave, and I seek refuge with You from the torment of the Fire, and I seek refuge with You from the trial of the Dajjal)}}
\hadithdefcmd{nasai}{2061}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ يَسْتَعِيذُ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{2061}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"I heard the Messenger of Allah after that seeking refuge with Allah from the torment of the grave}}
\hadithdefcmd{nasai}{2062}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَمِعَ أَسْمَاءَ بِنْتَ أَبِي بَكْرٍ، تَقُولُ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ الْفِتْنَةَ الَّتِي يُفْتَنُ بِهَا الْمَرْءُ فِي قَبْرِهِ فَلَمَّا ذَكَرَ ذَلِكَ ضَجَّ الْمُسْلِمُونَ ضَجَّةً حَالَتْ بَيْنِي وَبَيْنَ أَنْ أَفْهَمَ كَلاَمَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا سَكَنَتْ ضَجَّتُهُمْ قُلْتُ لِرَجُلٍ قَرِيبٍ مِنِّي أَىْ بَارَكَ اللَّهُ لَكَ مَاذَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي آخِرِ قَوْلِهِ قَالَ ‏ "‏ قَدْ أُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ قَرِيبًا مِنْ فِتْنَةِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{2062}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Urwah bin Az-Zubair (narrated) that he heard Asma' bint Abi Bakr say:"The Messenger of Allah stood up and mentioned the trail with which a person will be tested in his grave. When he mentioned that the people became restless, which prevented me from understanding what the Messenger of Allah had said. When they settled down, I said to a man who was near me: 'May Allah bless you, what did the end?' he said: 'It has been revealed to me that you will be tested in your graves with a trial close to that of the Dajjal}}
\hadithdefcmd{nasai}{2063}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعَلِّمُهُمْ هَذَا الدُّعَاءَ كَمَا يُعَلِّمُهُمُ السُّورَةَ مِنَ الْقُرْآنِ ‏ "‏ قُولُوا اللَّهُمَّ إِنَّا نَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{2063}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that:The Messenger of Allah used to teach them this supplication as he taught them surahs of the Quran: Allahumma inna na'udhu bika min 'adhabil-qabri wa a'udhu bika min fitnatil-masihid-dajjal, wa a'udhu bika min fitnatil-mahya wal-mamat (O Allah, We seek refuge with You from the torment of Hell, and I seek refuge with You from the torment of the grave, and I seek refuge with You from the trail of Al-Masihid-Dajjal, and I seek refuge with You from the trails of life and death)}}
\hadithdefcmd{nasai}{2064}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عُرْوَةُ، أَنَّ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي امْرَأَةٌ مِنَ الْيَهُودِ وَهِيَ تَقُولُ إِنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ ‏.‏ فَارْتَاعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ إِنَّمَا تُفْتَنُ يَهُودُ ‏"‏ ‏.‏ وَقَالَتْ عَائِشَةُ فَلَبِثْنَا لَيَالِيَ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ أُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدُ يَسْتَعِيذُ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{2064}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah came to me and there was a Jewish woman with me who was saying: 'You will be tested in your graves.' The Messenger of Allah got upset and said: 'Rather the Jews will be tested."' 'Aishah said: "A few nights later, the Messenger of Allah said: 'It has been revealed to me that you will be tested in your graves."' 'Aishah said; "Afterward I heard the Messenger of Allah seeking refuge with Allah from the torment of the grave}}
\hadithdefcmd{nasai}{2065}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَسْتَعِيذُ مِنْ عَذَابِ الْقَبْرِ وَمِنْ فِتْنَةِ الدَّجَّالِ وَقَالَ ‏ "‏ إِنَّكُمْ تُفْتَنُونَ فِي قُبُورِكُمْ ‏"‏ ‏.‏\hadithno{2065}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Aishah that:the Prophet used to seek refuge with Allah from the torment of the grave and the trial of the Dajjal, and he said: "You will be tested in your graves}}
\hadithdefcmd{nasai}{2066}{أَخْبَرَنَا هَنَّادٌ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، دَخَلَتْ يَهُودِيَّةٌ عَلَيْهَا فَاسْتَوْهَبَتْهَا شَيْئًا فَوَهَبَتْ لَهَا عَائِشَةُ فَقَالَتْ أَجَارَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ ‏.‏ قَالَتْ عَائِشَةُ فَوَقَعَ فِي نَفْسِي مِنْ ذَلِكَ حَتَّى جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ إِنَّهُمْ لَيُعَذَّبُونَ فِي قُبُورِهِمْ عَذَابًا تَسْمَعُهُ الْبَهَائِمُ ‏"‏ ‏.‏\hadithno{2066}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that:a Jewish woman came to her and asked her to give her something, so 'Aishah gave her something, and she said: "May Allah protect you from the torment of the grave." 'Aishah said:" She made me worried, until the Messenger of Allah came and I mentioned that to him. He said: 'They are tormented in their graves with a torment that the animals hear}}
\hadithdefcmd{nasai}{2067}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَتْ عَلَىَّ عَجُوزَتَانِ مِنْ عُجُزِ يَهُودِ الْمَدِينَةِ فَقَالَتَا إِنَّ أَهْلَ الْقُبُورِ يُعَذَّبُونَ فِي قُبُورِهِمْ ‏.‏ فَكَذَّبْتُهُمَا وَلَمْ أَنْعَمْ أَنْ أُصَدِّقَهُمَا فَخَرَجَتَا وَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ عَجُوزَتَيْنِ مِنْ عُجُزِ يَهُودِ الْمَدِينَةِ قَالَتَا إِنَّ أَهْلَ الْقُبُورِ يُعَذَّبُونَ فِي قُبُورِهِمْ ‏.‏ قَالَ ‏ "‏ صَدَقَتَا إِنَّهُمْ يُعَذَّبُونَ عَذَابًا تَسْمَعُهُ الْبَهَائِمُ كُلُّهَا ‏"‏ ‏.‏ فَمَا رَأَيْتُهُ صَلَّى صَلاَةً إِلاَّ تَعَوَّذَ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{2067}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Two of the old Jewish women of Al-Madinah came to me and said: 'The people of the graves are tormented in their graves.' But I did not believe them, and I did not believe them, and I did not want to believe them. They left and the Messenger of Allah entered upon me, and I said: 'O Messenger of Allah, two of the old Jewish women of Al-Madinah said that the people of the graves are tormented in their graves.' He said: 'They spoke the truth. They are tormented in a manner that all the animals can hear.' And I never saw him offer any Salah but he sought refuge with Allah from the torment of the grave}}
\hadithdefcmd{nasai}{2068}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِحَائِطٍ مِنْ حِيطَانِ مَكَّةَ أَوِ الْمَدِينَةِ سَمِعَ صَوْتَ إِنْسَانَيْنِ يُعَذَّبَانِ فِي قُبُورِهِمَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ بَلَى كَانَ أَحَدُهُمَا لاَ يَسْتَبْرِئُ مِنْ بَوْلِهِ وَكَانَ الآخَرُ يَمْشِي بِالنَّمِيمَةِ ‏"‏ ‏.‏ ثُمَّ دَعَا بِجَرِيدَةٍ فَكَسَرَهَا كِسْرَتَيْنِ فَوَضَعَ عَلَى كُلِّ قَبْرٍ مِنْهُمَا كِسْرَةً فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ لِمَ فَعَلْتَ هَذَا قَالَ ‏"‏ لَعَلَّهُ أَنْ يُخَفَّفَ عَنْهُمَا مَا لَمْ يَيْبَسَا أَوْ أَنْ يَيْبَسَا ‏"‏ ‏.‏\hadithno{2068}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that:The Messenger of Allah passed by one of the gardens of Makkah or Al-Madinah and heard the sound of two men being tormented in their graves. The Messenger of Allah said: "They are being punished but they are not being punished for anything that was difficult to avoid." Then he said: "Indeed, one of them used not to take care to avoid getting urine on his body or clothes, and the other used to walk around spreading gossip." They he called for a palm stalk which he broke in two and placed a piece of it on each grave. It was said to him: "O Messenger of Allah, why did you do that?" He said: "May it be reduced for them so long as this does not dry out" or: "until this dries out}}
\hadithdefcmd{nasai}{2069}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، فِي حَدِيثِهِ عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَبْرَيْنِ فَقَالَ ‏"‏ إِنَّهُمَا لَيُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا أَحَدُهُمَا فَكَانَ لاَ يَسْتَبْرِئُ مِنْ بَوْلِهِ وَأَمَّا الآخَرُ فَكَانَ يَمْشِي بِالنَّمِيمَةِ ‏"‏ ‏.‏ ثُمَّ أَخَذَ جَرِيدَةً رَطْبَةً فَشَقَّهَا نِصْفَيْنِ ثُمَّ غَرَزَ فِي كُلِّ قَبْرٍ وَاحِدَةً فَقَالُوا يَا رَسُولَ اللَّهِ لِمَ صَنَعْتَ هَذَا فَقَالَ ‏"‏ لَعَلَّهُمَا أَنْ يُخَفَّفَ عَنْهُمَا مَا لَمْ يَيْبَسَا ���"‏ ‏.‏\hadithno{2069}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ' Abbas said:"The Messenger of Allah passed by two graves and said: "They are being punished but they are not being punished for anything that was difficult to avoid. One of them used not to take care to avoid getting urine on his body or clothes, and the other used to walk about spreading gossip.' Then he took a fresh palm stalk and broke it in half, and planted one half on each grave. They said: 'O Messenger of Allah, why did not do that?' He said: 'May it be reduced for them so long as this does not dry out}}
\hadithdefcmd{nasai}{2070}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ إِنَّ أَحَدَكُمْ إِذَا مَاتَ عُرِضَ عَلَيْهِ مَقْعَدُهُ بِالْغَدَاةِ وَالْعَشِيِّ إِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَمِنْ أَهْلِ الْجَنَّةِ وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ حَتَّى يَبْعَثَهُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2070}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet said:"When one of you dies he is shown his place morning and evening. If he is one of the people of paradise them he is one of the people of Paradise, and if he is one of the people of Hell, then he is one of the people of Hell, until Allah, the Mighty and Sublime, raises him up on the Day of Resurrection}}
\hadithdefcmd{nasai}{2071}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ، يُحَدِّثُ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُعْرَضُ عَلَى أَحَدِكُمْ إِذَا مَاتَ مَقْعَدُهُ مِنَ الْغَدَاةِ وَالْعَشِيِّ فَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ قِيلَ هَذَا مَقْعَدُكَ حَتَّى يَبْعَثَكَ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2071}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah said:"When one of you dies, he is shown his place morning and evening. If he is one of the people of hell it is said: 'This is your place, until Allah, the Mighty and Sublime, raises you up on the Day of Resurrection}}
\hadithdefcmd{nasai}{2072}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَاتَ أَحَدُكُمْ عُرِضَ عَلَى مَقْعَدِهِ بِالْغَدَاةِ وَالْعَشِيِّ إِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَمِنْ أَهْلِ الْجَنَّةِ وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ فَيُقَالُ هَذَا مَقْعَدُكَ حَتَّى يَبْعَثَكَ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2072}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah said:"When one of you dies, he is shown his place morning and evening. If he is one of the people of Paradise then he is one of the people of Paradise, and if he is one of the people of Hell. It is said: 'This is your place, until Allah, the Mighty and Sublime, raises you up on the Day of Resurrection}}
\hadithdefcmd{nasai}{2073}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبٍ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَاهُ كَعْبَ بْنَ مَالِكٍ كَانَ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا نَسَمَةُ الْمُؤْمِنِ طَائِرٌ فِي شَجَرِ الْجَنَّةِ حَتَّى يَبْعَثَهُ اللَّهُ عَزَّ وَجَلَّ إِلَى جَسَدِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2073}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ka 'b bin Malik used to narrate that the Messenger of Allah said:"The soul of the belevier is (like a bird) flying among the trees of Paradise, until Allah, the Mighty and sublime, sends it back to his body on the Day of Resurrection." (Da 'if)}}
\hadithdefcmd{nasai}{2074}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُلَيْمَانُ، - وَهُوَ ابْنُ الْمُغِيرَةِ - قَالَ حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ كُنَّا مَعَ عُمَرَ بَيْنَ مَكَّةَ وَالْمَدِينَةِ أَخَذَ يُحَدِّثُنَا عَنْ أَهْلِ بَدْرٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَيُرِينَا مَصَارِعَهُمْ بِالأَمْسِ قَالَ ‏"‏ هَذَا مَصْرَعُ فُلاَنٍ إِنْ شَاءَ اللَّهُ غَدًا ‏"‏ ‏.‏ قَالَ عُمَرُ وَالَّذِي بَعَثَهُ بِالْحَقِّ مَا أَخْطَئُوا تِيكَ فَجُعِلُوا فِي بِئْرٍ فَأَتَاهُمُ النَّبِيُّ صلى الله عليه وسلم فَنَادَى ‏"‏ يَا فُلاَنُ بْنَ فُلاَنٍ يَا فُلاَنُ بْنَ فُلاَنٍ هَلْ وَجَدْتُمْ مَا وَعَدَ رَبُّكُمْ حَقًّا فَإِنِّي وَجَدْتُ مَا وَعَدَنِي اللَّهُ حَقًّا ‏"‏ ‏.‏ فَقَالَ عُمَرُ تُكَلِّمُ أَجْسَادًا لاَ أَرْوَاحَ فِيهَا فَقَالَ ‏"‏ مَا أَنْتُمْ بِأَسْمَعَ لِمَا أَقُولُ مِنْهُمْ ‏"‏ ‏.‏\hadithno{2074}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"We were with 'Umar between Makkah and Al-Madinah, when he strted to tell us about the people of Badr. He said: The Messenger of Allah showed us the day before where they (the disbelivers) would fall. He said: This is the place where so-and-so will fall tomorrow, if Allah wills.' 'Umar said: 'By the One Who sent him with the truth! They did not miss those places, They were placed in a well and the Prophet came to them and called out: O so-and-so, son of so-and-so! O so-and-so, son of so-andso! Have you found what your Lord promised to be true? Of I have found what allah promised me to be true. 'Umar said: 'Are you speaking to bodies in which there are no souls?' He said: 'You do not hear what I say any better than they do}}
\hadithdefcmd{nasai}{2075}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ سَمِعَ الْمُسْلِمُونَ، مِنَ اللَّيْلِ بِبِئْرِ بَدْرٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يُنَادِي ‏"‏ يَا أَبَا جَهْلِ بْنَ هِشَامٍ وَيَا شَيْبَةُ بْنَ رَبِيعَةَ وَيَا عُتْبَةُ بْنَ رَبِيعَةَ وَيَا أُمَيَّةُ بْنَ خَلَفٍ هَلْ وَجَدْتُمْ مَا وَعَدَ رَبُّكُمْ حَقًّا فَإِنِّي وَجَدْتُ مَا وَعَدَنِي رَبِّي حَقًّا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَوَتُنَادِي قَوْمًا قَدْ جَيَّفُوا فَقَالَ ‏"‏ مَا أَنْتُمْ بِأَسْمَعَ لِمَا أَقُولُ مِنْهُمْ وَلَكِنَّهُمْ لاَ يَسْتَطِيعُونَ أَنْ يُجِيبُوا ‏"‏ ‏.‏\hadithno{2075}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"During the night, the Muslims heard the Messenger of Allah standing and calling out at the well of badr; 'O Abu Jahl bin Hisham! O Shaaibh bin Rabiah! O 'Utbah bin Rabiah! O Umayyah bin Khalaf! Have you found what your Lord promised to be true? For I have found what my Lord promised me to be true.' They said: 'O Messenger of Allah, are you calling out to people who have turned into rotten corpses?' He said: 'You do not hear what I say any better than they do, but they cannot answer}}
\hadithdefcmd{nasai}{2076}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، قَالَ حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَقَفَ عَلَى قَلِيبِ بَدْرٍ فَقَالَ ‏"‏ هَلْ وَجَدْتُمْ مَا وَعَدَ رَبُّكُمْ حَقًّا - قَالَ - إِنَّهُمْ لَيَسْمَعُونَ الآنَ مَا أَقُولُ لَهُمْ ‏"‏ ‏.‏ فَذُكِرَ ذَلِكَ لِعَائِشَةَ فَقَالَتْ وَهَلَ ابْنُ عُمَرَ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُمُ الآنَ يَعْلَمُونَ أَنَّ الَّذِي كُنْتُ أَقُولُ لَهُمْ هُوَ الْحَقُّ ‏"‏ ‏.‏ ثُمَّ قَرَأَتْ قَوْلَهُ ‏\{‏ إِنَّكَ لاَ تُسْمِعُ الْمَوْتَى ‏\}‏ حَتَّى قَرَأَتِ الآيَةَ ‏.‏\hadithno{2076}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{it was narrated from Ibn 'Umar that the Prophet stood at the well of Badr and said:"Have you found what your Lord promised to be true?" he said: "They can hear what I am saying to them now". Mention of that was made to 'Aishah and she said: "Ibn 'Umar is mistaken. Rather the Messenger of Allah said: "Ibn 'Umar is mistaken. Rather the Messenger of Allah said: 'Now they know that what I used to say to them is the truth.' Then she recited: So verily, you (O Muhammad) cannot make the dead to hear., until she recited the verse}}
\hadithdefcmd{nasai}{2077}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، وَمُغِيرَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ بَنِي آدَمَ - وَفِي حَدِيثِ مُغِيرَةَ كُلُّ ابْنِ آدَمَ - يَأْكُلُهُ التُّرَابُ إِلاَّ عَجْبَ الذَّنَبِ مِنْهُ خُلِقَ وَفِيهِ يُرَكَّبُ ‏"‏ ‏.‏\hadithno{2077}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The Messenger of Allah said: 'The whole of the son of Adam will be consumed by the earth, except for the tailbone, from which he was created and from which he will be created anwe}}
\hadithdefcmd{nasai}{2078}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ كَذَّبَنِي ابْنُ آدَمَ وَلَمْ يَكُنْ يَنْبَغِي لَهُ أَنْ يُكَذِّبَنِي وَشَتَمَنِي ابْنُ آدَمَ وَلَمْ يَكُنْ يَنْبَغِي لَهُ أَنْ يَشْتِمَنِي أَمَّا تَكْذِيبُهُ إِيَّاىَ فَقَوْلُهُ إِنِّي لاَ أُعِيدُهُ كَمَا بَدَأْتُهُ وَلَيْسَ آخِرُ الْخَلْقِ بِأَعَزَّ عَلَىَّ مِنْ أَوَّلِهِ وَأَمَّا شَتْمُهُ إِيَّاىَ فَقَوْلُهُ اتَّخَذَ اللَّهُ وَلَدًا وَأَنَا اللَّهُ الأَحَدُ الصَّمَدُ لَمْ أَلِدْ وَلَمْ أُولَدْ وَلَمْ يَكُنْ لِي كُفُوًا أَحَدٌ ‏"‏ ‏.‏\hadithno{2078}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Allah, the Mighty and Sublinm, says: 'The son of Adam denied Me and he had no right to do so. and the son of Adam reviled Me and he had no right to do so. As for his denying Me, It is his saying that I will not resurrect him as I created him in the beginning, but resurrecting him is not more difficult for Me than creating him in the first place. And as for his reviling Me, it is his saying that Allah has taken a son, but I am Allah, the One, the Self-Sufficient Master, I beget not nor was I begotten, and there is none co-equal or comparable unto Me}}
\hadithdefcmd{nasai}{2079}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَسْرَفَ عَبْدٌ عَلَى نَفْسِهِ حَتَّى حَضَرَتْهُ الْوَفَاةُ قَالَ لأَهْلِهِ إِذَا أَنَا مُتُّ فَأَحْرِقُونِي ثُمَّ اسْحَقُونِي ثُمَّ اذْرُونِي فِي الرِّيحِ فِي الْبَحْرِ فَوَاللَّهِ لَئِنْ قَدَرَ اللَّهُ عَلَىَّ لَيُعَذِّبَنِّي عَذَابًا لاَ يُعَذِّبُهُ أَحَدًا مِنْ خَلْقِهِ قَالَ فَفَعَلَ أَهْلُهُ ذَلِكَ قَالَ اللَّهُ عَزَّ وَجَلَّ لِكُلِّ شَىْءٍ أَخَذَ مِنْهُ شَيْئًا أَدِّ مَا أَخَذْتَ فَإِذَا هُوَ قَائِمٌ قَالَ اللَّهُ عَزَّ وَجَلَّ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ قَالَ خَشْيَتُكَ ‏.‏ فَغَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏\hadithno{2079}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"I heard the Messenger of Allah say: 'There was a man who wronged himself greatly, and when he was dying he said to his family: When I am dead, burn my body then grind my bones and scatter me in the wind and at sea, for by Allah , if Allah gets hold of me, he will punish me in a way that He will not punish anyone else. So his family did that, but Allah, the Mighty and Sublime, said to everything that had taken any part of him to give up what it had taken. Then there he was, standing Allah, the Mighty and Sublime, said: What made you do what you did? He said: Fear of You. So Allah forgave him}}
\hadithdefcmd{nasai}{2080}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ رَجُلٌ مِمَّنْ كَانَ قَبْلَكُمْ يُسِيءُ الظَّنَّ بِعَمَلِهِ فَلَمَّا حَضَرَتْهُ الْوَفَاةُ قَالَ لأَهْلِهِ إِذَا أَنَا مُتُّ فَأَحْرِقُونِي ثُمَّ اطْحَنُونِي ثُمَّ اذْرُونِي فِي الْبَحْرِ فَإِنَّ اللَّهَ إِنْ يَقْدِرْ عَلَىَّ لَمْ يَغْفِرْ لِي ‏.‏ قَالَ فَأَمَرَ اللَّهُ عَزَّ وَجَلَّ الْمَلاَئِكَةَ فَتَلَقَّتْ رُوحَهُ قَالَ لَهُ مَا حَمَلَكَ عَلَى مَا فَعَلْتَ قَالَ يَا رَبِّ مَا فَعَلْتُ إِلاَّ مِنْ مَخَافَتِكَ ‏.‏ فَغَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏\hadithno{2080}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Hudhaifah that the Messenger of Allah said:"There was a man among those who came before you who thought badly of his deeds, so when death was approaching he said to his family: 'When I am dead, burn my body and grind up my bones, then scatter me in the sea, for if Allah gets hold of me, He will never forgive me.' But Allah commanded the angles to seize his soul. He said to him: 'What made you do what you did?' He said:: 'O Lord, I only did it because I feared You.' So Allah forgave him}}
\hadithdefcmd{nasai}{2081}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ إِنَّكُمْ مُلاَقُو اللَّهِ عَزَّ وَجَلَّ حُفَاةً عُرَاةً غُرْلاً ‏"‏ ‏.‏\hadithno{2081}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"I heard the Messenger of Allah delivering a Khutbah from the Minbar and he said: 'You will meet Allah barefoot, naked and uncircumcised}}
\hadithdefcmd{nasai}{2082}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي الْمُغِيرَةُ بْنُ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُحْشَرُ النَّاسُ يَوْمَ الْقِيَامَةِ عُرَاةً غُرْلاً وَأَوَّلُ الْخَلاَئِقِ يُكْسَى إِبْرَاهِيمُ عَلَيْهِ السَّلاَمُ ثُمَّ قَرَأَ ‏\{‏ كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ ‏\}‏ ‏"‏ ‏.‏\hadithno{2082}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet said:"The people will be gathered on the Day of Resurrection naked and uncircumcised. The first one to be clothed will be Ibrahim." Then he recited: As We began the first creation, We shall repeat it}}
\hadithdefcmd{nasai}{2083}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ أَخْبَرَنِي الزُّبَيْدِيُّ، قَالَ أَخْبَرَنِي الزُّهْرِيُّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يُبْعَثُ النَّاسُ يَوْمَ الْقِيَامَةِ حُفَاةً عُرَاةً غُرْلاً ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ فَكَيْفَ بِالْعَوْرَاتِ قَالَ ‏"‏ لِكُلِّ امْرِئٍ مِنْهُمْ يَوْمَئِذٍ شَأْنٌ يُغْنِيهِ ‏"‏ ‏.‏\hadithno{2083}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"The people will be raised up on the Day of Resurrection barefoot, naked and uncircumcised." 'Aishah said: "What about their 'Awrahs?" he said: "Every man that day will have enough to make him careless of others}}
\hadithdefcmd{nasai}{2084}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا أَبُو يُونُسَ الْقُشَيْرِيُّ، قَالَ حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّكُمْ تُحْشَرُونَ حُفَاةً عُرَاةً ‏"‏ ‏.‏ قُلْتُ الرِّجَالُ وَالنِّسَاءُ يَنْظُرُ بَعْضُهُمْ إِلَى بَعْضٍ قَالَ ‏"‏ إِنَّ الأَمْرَ أَشَدُّ مِنْ أَنْ يُهِمَّهُمْ ذَلِكَ ‏"‏ ‏.‏\hadithno{2084}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"You will be gathered (one the Day of Resurrection) barefoot and naked." I said: "Men and women looking at one another?" he said: "The matter will be too difficult for people to pay attention to that}}
\hadithdefcmd{nasai}{2085}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ، قَالَ حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ أَبُو بَكْرٍ، قَالَ حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُحْشَرُ النَّاسُ يَوْمَ الْقِيَامَةِ عَلَى ثَلاَثِ طَرَائِقَ رَاغِبِينَ رَاهِبِينَ اثْنَانِ عَلَى بَعِيرٍ وَثَلاَثَةٌ عَلَى بَعِيرٍ وَأَرْبَعَةٌ عَلَى بَعِيرٍ وَعَشْرَةٌ عَلَى بَعِيرٍ وَتَحْشُرُ بَقِيَّتَهُمُ النَّارُ تَقِيلُ مَعَهُمْ حَيْثُ قَالُوا وَتَبِيتُ مَعَهُمْ حَيْثُ بَاتُوا وَتُصْبِحُ مَعَهُمْ حَيْثُ أَصْبَحُوا وَتُمْسِي مَعَهُمْ حَيْثُ أَمْسَوْا ‏"‏ ‏.‏\hadithno{2085}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The people will be gathered on the Day of Resurrection in three ways. (the first will be) those who have the hope (of Paradise) and the fear (of punishment). (the second will be) those who come riding two on a camel, or three on a camel, or four on a camel, or the on a camel, or four on a camel, or ten on a camel or ten o a camel. And the rest of them will be gathered by the Fire which will accompany them, stopping with them where they rest in the afternoon, and staying with them where they stop overnight, and staying with them wherever they are in the morning, and in the evening}}
\hadithdefcmd{nasai}{2086}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ الْوَلِيدِ بْنِ جُمَيْعٍ، قَالَ حَدَّثَنَا أَبُو الطُّفَيْلِ، عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ، عَنْ أَبِي ذَرٍّ، قَالَ إِنَّ الصَّادِقَ الْمَصْدُوقَ صلى الله عليه وسلم حَدَّثَنِي ‏ "‏ أَنَّ النَّاسَ يُحْشَرُونَ ثَلاَثَةَ أَفْوَاجٍ فَوْجٌ رَاكِبِينَ طَاعِمِينَ كَاسِينَ وَفَوْجٌ تَسْحَبُهُمُ الْمَلاَئِكَةُ عَلَى وُجُوهِهِمْ وَتَحْشُرُهُمُ النَّارُ وَفَوْجٌ يَمْشُونَ وَيَسْعَوْنَ يُلْقِي اللَّهُ الآفَةَ عَلَى الظَّهْرِ فَلاَ يَبْقَى حَتَّى إِنَّ الرَّجُلَ لَتَكُونُ لَهُ الْحَدِيقَةُ يُعْطِيهَا بِذَاتِ الْقَتَبِ لاَ يَقْدِرُ عَلَيْهَا ‏"‏ ‏.‏\hadithno{2086}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Dharr said; "The truthful one whom people believe told me:'The people will be gathered in three groups: A group who will be riding, well fed and well clothed; a group whom the angels will drag on their faces and whom the fire will drive; and a group who will be walking with difficulty. Allah will send a disease to kill all the riding beasts and none will remain, until a man would give a garden for a she-camel but he will not be able to have it}}
\hadithdefcmd{nasai}{2087}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ أَخْبَرَنَا وَكِيعٌ، وَوَهْبُ بْنُ جَرِيرٍ، وَأَبُو دَاوُدَ عَنْ شُعْبَةَ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمَوْعِظَةِ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّكُمْ مَحْشُورُونَ إِلَى اللَّهِ عَزَّ وَجَلَّ عُرَاةً ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏"‏ حُفَاةً غُرْلاً ‏"‏ ‏.‏ وَقَالَ وَكِيعٌ وَوَهْبٌ ‏"‏ عُرَاةً غُرْلاً ‏\{‏ كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ ‏\}‏ قَالَ أَوَّلُ مَنْ يُكْسَى يَوْمَ الْقِيَامَةِ إِبْرَاهِيمُ عَلَيْهِ السَّلاَمُ وَإِنَّهُ سَيُؤْتَى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏"‏ يُجَاءُ ‏"‏ ‏.‏ وَقَالَ وَهْبٌ وَوَكِيعٌ ‏"‏ سَيُؤْتَى بِرِجَالٍ مِنْ أُمَّتِي فَيُؤْخَذُ بِهِمْ ذَاتَ الشِّمَالِ فَأَقُولُ رَبِّ أَصْحَابِي ‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُ ‏\{‏ وَكُنْتُ عَلَيْهِمْ شَهِيدًا مَا دُمْتُ فِيهِمْ فَلَمَّا تَوَفَّيْتَنِي ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ وَإِنْ تَغْفِرْ لَهُمْ ‏\}‏ الآيَةَ فَيُقَالُ إِنَّ هَؤُلاَءِ لَمْ يَزَالُوا مُدْبِرِينَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏"‏ مُرْتَدِّينَ عَلَى أَعْقَابِهِمْ مُنْذُ فَارَقْتَهُمْ ‏"‏ ‏.‏\hadithno{2087}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allah stood up to give an admonition and he said: 'O people, you will be gathered to Allah naked."' (One of the narrators) Abu Dawud said: "Barefoot and uncircumcised." (The narrators) Waki and Wahb said: "Naked and uncircumcised: As We began the first creation, We shall repeat it. The first one to be clothed on the Day of Resurrection will be Ibrahim, peace be upon him. Then some men from among my Ummah will be brought and will be taken toward the left. I will say: 'O Lord, my companions.' It will be said: 'You do not know what they innovated after you were gone,' and I shall say what the righteous slave said: 'And I was witness over them while I dwelt amongst them, but when You took me up, You were the Watcher over them, but when You took me up, You were the Watcher over them; and You are a Witness to all things. If You punish them, they are Your slaves, and if You forgive them, verily, You, only You, are the All-Mighty, the All-Wise.' And it will be said: 'These people kept turning away since you left them}}
\hadithdefcmd{nasai}{2088}{أَخْبَرَنَا هَارُونُ بْنُ زَيْدٍ، - وَهُوَ ابْنُ أَبِي الزَّرْقَاءِ - قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا خَالِدُ بْنُ مَيْسَرَةَ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ قُرَّةَ، عَنْ أَبِيهِ، قَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِذَا جَلَسَ يَجْلِسُ إِلَيْهِ نَفَرٌ مِنْ أَصْحَابِهِ وَفِيهِمْ رَجُلٌ لَهُ ابْنٌ صَغِيرٌ يَأْتِيهِ مِنْ خَلْفِ ظَهْرِهِ فَيُقْعِدُهُ بَيْنَ يَدَيْهِ فَهَلَكَ فَامْتَنَعَ الرَّجُلُ أَنْ يَحْضُرَ الْحَلْقَةَ لِذِكْرِ ابْنِهِ فَحَزِنَ عَلَيْهِ فَفَقَدَهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا لِي لاَ أَرَى فُلاَنًا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ بُنَيَّهُ الَّذِي رَأَيْتَهُ هَلَكَ ‏.‏ فَلَقِيَهُ النَّبِيُّ صلى الله عليه وسلم فَسَأَلَهُ عَنْ بُنَيِّهِ فَأَخْبَرَهُ أَنَّهُ هَلَكَ فَعَزَّاهُ عَلَيْهِ ثُمَّ قَالَ ‏"‏ يَا فُلاَنُ أَيُّمَا كَانَ أَحَبُّ إِلَيْكَ أَنْ تَمَتَّعَ بِهِ عُمْرَكَ أَوْ لاَ تَأْتِي غَدًا إِلَى بَابٍ مِنْ أَبْوَابِ الْجَنَّةِ إِلاَّ وَجَدْتَهُ قَدْ سَبَقَكَ إِلَيْهِ يَفْتَحُهُ لَكَ ‏"‏ ‏.‏ قَالَ يَا نَبِيَّ اللَّهِ بَلْ يَسْبِقُنِي إِلَى بَابِ الْجَنَّةِ فَيَفْتَحُهَا لِي لَهُوَ أَحَبُّ إِلَىَّ ‏.‏ قَالَ ‏"‏ فَذَاكَ لَكَ ‏"‏ ‏.‏\hadithno{2088}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Mu 'awiyah bin Qurrah narrated that his father said:"When the Prophet of Allah sat, some of his Companions would sit with him. Among them was a man who had a little son who used to come to him from behind, and he would make him sit in front of him. He (the child) died, and the man stopped attending the circle because it reminded him of his son, and made him feel sad. The Prophet missed him and said: 'Why do I not see so-and-so?' They said: O Messenger of Allah, his son whom you saw has died.' The Prophet met him and asked him about his son, and he told him that he had died. He offered his condolences and said: 'O son-and-so, which would you like better, to enjoy his company all you life, or to come to any of the gates of Paradise on the Day of Resurrection, and find that he arrived there before you, and he is opening the gate for you?' he said: 'O Prophet of Allah! For him to get to the gate of Paradise before me and open it for me is dearer to me.' He said: 'You will have that}}
\hadithdefcmd{nasai}{2089}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، عَنْ عَبْدِ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُرْسِلَ مَلَكُ الْمَوْتِ إِلَى مُوسَى عَلَيْهِ السَّلاَمُ فَلَمَّا جَاءَهُ صَكَّهُ فَفَقَأَ عَيْنَهُ فَرَجَعَ إِلَى رَبِّهِ فَقَالَ أَرْسَلْتَنِي إِلَى عَبْدٍ لاَ يُرِيدُ الْمَوْتَ ‏.‏ فَرَدَّ اللَّهُ عَزَّ وَجَلَّ إِلَيْهِ عَيْنَهُ وَقَالَ ارْجِعْ إِلَيْهِ فَقُلْ لَهُ يَضَعُ يَدَهُ عَلَى مَتْنِ ثَوْرٍ فَلَهُ بِكُلِّ مَا غَطَّتْ يَدُهُ بِكُلِّ شَعْرَةٍ سَنَةٌ ‏.‏ قَالَ أَىْ رَبِّ ثُمَّ مَهْ قَالَ الْمَوْتُ ‏.‏ قَالَ فَالآنَ ‏.‏ فَسَأَلَ اللَّهَ عَزَّ وَجَلَّ أَنْ يُدْنِيَهُ مِنَ الأَرْضِ الْمُقَدَّسَةِ رَمْيَةً بِحَجَرٍ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَلَوْ كُنْتُ ثَمَّ لأَرَيْتُكُمْ قَبْرَهُ إِلَى جَانِبِ الطَّرِيقِ تَحْتَ الْكَثِيبِ الأَحْمَرِ ‏"‏ ‏.‏\hadithno{2089}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The angel of death was sent to Musa. Peace be upon him, and when he came to him, he slapped him and put his eye out he went back to his Lord and said: 'Go back to him and tell him to put his hand on the back of a bull, and of every hair that his hand covers he will have one year.' He said: 'O Lord, then what?' He said; 'Death.' He said: 'Let me go now.' And he (Musa) asked his Lord to bring him within a stone's throw of the Holy Land, the distance of a stone's throw. The Messenger of Allah said: 'If I where there, I would show you his grave, beside the road beneath a red dune}}
