% Auto-generated chapter 97 for bukhari
% Hadiths in this chapter: 188

\hadithdefcmd{bukhari}{7371}{حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ مُعَاذًا إِلَى الْيَمَنِ‏.‏\hadithno{7371}\hadithtrans{Narrated Ibn 'Abbas (ra):The Prophet (ﷺ) sent Mu'adh to Yemen}}
\hadithdefcmd{bukhari}{7372}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا الْفَضْلُ بْنُ الْعَلاَءِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أُمَيَّةَ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ صَيْفِيٍّ، أَنَّهُ سَمِعَ أَبَا مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ لَمَّا بَعَثَ النَّبِيُّ صلى الله عليه وسلم مُعَاذًا نَحْوَ الْيَمَنِ قَالَ لَهُ ‏ "‏ إِنَّكَ تَقْدَمُ عَلَى قَوْمٍ مِنْ أَهْلِ الْكِتَابِ فَلْيَكُنْ أَوَّلَ مَا تَدْعُوهُمْ إِلَى أَنْ يُوَحِّدُوا اللَّهَ تَعَالَى فَإِذَا عَرَفُوا ذَلِكَ فَأَخْبِرْهُمْ أَنَّ اللَّهَ فَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي يَوْمِهِمْ وَلَيْلَتِهِمْ، فَإِذَا صَلُّوا فَأَخْبِرْهُمْ أَنَّ اللَّهَ افْتَرَضَ عَلَيْهِمْ زَكَاةً فِي أَمْوَالِهِمْ تُؤْخَذُ مِنْ غَنِيِّهِمْ فَتُرَدُّ عَلَى فَقِيرِهِمْ، فَإِذَا أَقَرُّوا بِذَلِكَ فَخُذْ مِنْهُمْ وَتَوَقَّ كَرَائِمَ أَمْوَالِ النَّاسِ ‏"‏‏.‏\hadithno{7372}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) sent Mu`adh to Yemen, he said to him, "You are going to a nation from the people of the Scripture, so let the first thing to which you will invite them, be the Tauhid of Allah. If they learn that, tell them that Allah has enjoined on them, five prayers to be offered in one day and one night. And if they pray, tell them that Allah has enjoined on them Zakat of their properties and it is to be taken from the rich among them and given to the poor. And if they agree to that, then take from them Zakat but avoid the best property of the people}}
\hadithdefcmd{bukhari}{7373}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي حَصِينٍ، وَالأَشْعَثِ بْنِ سُلَيْمٍ، سَمِعَا الأَسْوَدَ بْنَ هِلاَلٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا مُعَاذُ أَتَدْرِي مَا حَقُّ اللَّهِ عَلَى الْعِبَادِ ‏"‏‏.‏ قَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ أَنْ يَعْبُدُوهُ وَلاَ يُشْرِكُوا بِهِ شَيْئًا، أَتَدْرِي مَا حَقُّهُمْ عَلَيْهِ ‏"‏‏.‏ قَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ أَنْ لاَ يُعَذِّبَهُمْ ‏"‏‏.‏\hadithno{7373}\hadithtrans{Narrated Mu`adh bin Jabal:The Prophet (ﷺ) said, "O Mu`adh! Do you know what Allah's Right upon His slaves is?" I said, "Allah and His Apostle know best." The Prophet (ﷺ) said, "To worship Him (Allah) Alone and to join none in worship with Him (Allah). Do you know what their right upon Him is?" I replied, "Allah and His Apostle know best." The Prophet (ﷺ) said, "Not to punish them (if they do so)}}
\hadithdefcmd{bukhari}{7374}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، سَمِعَ رَجُلاً، يَقْرَأُ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ يُرَدِّدُهَا، فَلَمَّا أَصْبَحَ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ لَهُ ذَلِكَ، وَكَأَنَّ الرَّجُلَ يَتَقَالُّهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهَا لَتَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏‏.‏ زَادَ إِسْمَاعِيلُ بْنُ جَعْفَرٍ عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، أَخْبَرَنِي أَخِي، قَتَادَةُ بْنُ النُّعْمَانِ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7374}\hadithtrans{Narrated Abu Sa`id Al-Khudri:A man heard another man reciting (in the prayers): 'Say (O Muhammad): "He is Allah, the One." (112.1) And he recited it repeatedly. When it was morning, he went to the Prophet (ﷺ) and informed him about that as if he considered that the recitation of that Sura by itself was not enough. Allah's Messenger (ﷺ) said, "By Him in Whose Hand my life is, it is equal to one-third of the Qur'an}}
\hadithdefcmd{bukhari}{7375}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا عَمْرٌو، عَنِ ابْنِ أَبِي هِلاَلٍ، أَنَّ أَبَا الرِّجَالِ، مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ حَدَّثَهُ عَنْ أُمِّهِ، عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ وَكَانَتْ فِي حَجْرِ عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنْ عَائِشَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ رَجُلاً عَلَى سَرِيَّةٍ، وَكَانَ يَقْرَأُ لأَصْحَابِهِ فِي صَلاَتِهِ فَيَخْتِمُ بِ ـ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ فَلَمَّا رَجَعُوا ذَكَرُوا ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ سَلُوهُ لأَىِّ شَىْءٍ يَصْنَعُ ذَلِكَ ‏"‏‏.‏ فَسَأَلُوهُ فَقَالَ لأَنَّهَا صِفَةُ الرَّحْمَنِ، وَأَنَا أُحِبُّ أَنْ أَقْرَأَ بِهَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَخْبِرُوهُ أَنَّ اللَّهَ يُحِبُّهُ ‏"‏‏.‏\hadithno{7375}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) sent (an army unit) under the command of a man who used to lead his companions in the prayers and would finish his recitation with (the Sura 112): 'Say (O Muhammad): "He is Allah, the One." ' (112.1) When they returned (from the battle), they mentioned that to the Prophet. He said (to them), "Ask him why he does so." They asked him and he said, "I do so because it mentions the qualities of the Beneficent and I love to recite it (in my prayer)." The Prophet; said (to them), "Tell him that Allah loves him}}
\hadithdefcmd{bukhari}{7376}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، وَأَبِي، ظَبْيَانَ عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَرْحَمُ اللَّهُ مَنْ لاَ يَرْحَمُ النَّاسَ ‏"‏‏.‏\hadithno{7376}\hadithtrans{Narrated Jarir bin `Abdullah:Allah's Messenger (ﷺ) said, "Allah will not be merciful to those who are not merciful to mankind}}
\hadithdefcmd{bukhari}{7377}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ جَاءَهُ رَسُولُ إِحْدَى بَنَاتِهِ يَدْعُوهُ إِلَى ابْنِهَا فِي الْمَوْتِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ارْجِعْ فَأَخْبِرْهَا أَنَّ لِلَّهِ مَا أَخَذَ، وَلَهُ مَا أَعْطَى، وَكُلُّ شَىْءٍ عِنْدَهُ بِأَجَلٍ مُسَمًّى، فَمُرْهَا فَلْتَصْبِرْ وَلْتَحْتَسِبْ ‏"‏‏.‏ فَأَعَادَتِ الرَّسُولَ أَنَّهَا أَقْسَمَتْ لَتَأْتِيَنَّهَا، فَقَامَ النَّبِيُّ صلى الله عليه وسلم وَقَامَ مَعَهُ سَعْدُ بْنُ عُبَادَةَ وَمُعَاذُ بْنُ جَبَلٍ، فَدُفِعَ الصَّبِيُّ إِلَيْهِ وَنَفْسُهُ تَقَعْقَعُ كَأَنَّهَا فِي شَنٍّ فَفَاضَتْ عَيْنَاهُ فَقَالَ لَهُ سَعْدٌ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ هَذِهِ رَحْمَةٌ جَعَلَهَا اللَّهُ فِي قُلُوبِ عِبَادِهِ، وَإِنَّمَا يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ الرُّحَمَاءَ ‏"‏‏.‏\hadithno{7377}\hadithtrans{Narrated Usama bin Zaid:We were with the Prophet (ﷺ) when suddenly there came to him a messenger from one of his daughters who was asking him to come and see her son who was dying. The Prophet (ﷺ) said (to the messenger), "Go back and tell her that whatever Allah takes is His, and whatever He gives is His, and everything with Him has a limited fixed term (in this world). So order her to be patient and hope for Allah's reward." But she sent the messenger to the Prophet (ﷺ) again, swearing that he should come to her. So the Prophet got up, and so did Sa`d bin 'Ubada and Mu`adh bin Jabal (and went to her). When the child was brought to the Prophet (ﷺ) his breath was disturbed in his chest as if it were in a water skin. On that the eyes of the Prophet (ﷺ) became flooded with tears, whereupon Sa`d said to him, "O Allah's Messenger (ﷺ)! What is this?" The Prophet (ﷺ) said, "This is mercy which Allah has put in the heart of His slaves, and Allah bestows His mercy only on those of His slaves who are merciful (to others)}}
\hadithdefcmd{bukhari}{7378}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا أَحَدٌ أَصْبَرُ عَلَى أَذًى سَمِعَهُ مِنَ اللَّهِ، يَدَّعُونَ لَهُ الْوَلَدَ، ثُمَّ يُعَافِيهِمْ وَيَرْزُقُهُمْ ‏"‏‏.‏\hadithno{7378}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) said, "None is more patient than Allah against the harmful and annoying words He hears (from the people): They ascribe children to Him, yet He bestows upon them health and provision}}
\hadithdefcmd{bukhari}{7379}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَفَاتِيحُ الْغَيْبِ خَمْسٌ لاَ يَعْلَمُهَا إِلاَّ اللَّهُ، لاَ يَعْلَمُ مَا تَغِيضُ الأَرْحَامُ إِلاَّ اللَّهُ، وَلاَ يَعْلَمُ مَا فِي غَدٍ إِلاَّ اللَّهُ، وَلاَ يَعْلَمُ مَتَى يَأْتِي الْمَطَرُ أَحَدٌ إِلاَّ اللَّهُ، وَلاَ تَدْرِي نَفْسٌ بِأَىِّ أَرْضٍ تَمُوتُ إِلاَّ اللَّهُ، وَلاَ يَعْلَمُ مَتَى تَقُومُ السَّاعَةُ إِلاَّ اللَّهُ ‏"‏‏.‏\hadithno{7379}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The keys of the unseen are five and none knows them but Allah: (1) None knows (the sex) what is in the womb, but Allah: (2) None knows what will happen tomorrow, but Allah; (3) None knows when it will rain, but Allah; (4) None knows where he will die, but Allah (knows that); (5) and none knows when the Hour will be established, but Allah}}
\hadithdefcmd{bukhari}{7380}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَنْ حَدَّثَكَ أَنَّ مُحَمَّدًا صلى الله عليه وسلم رَأَى رَبَّهُ فَقَدْ كَذَبَ وَهْوَ يَقُولُ ‏\{‏لاَ تُدْرِكُهُ الأَبْصَارُ‏\}‏ وَمَنْ حَدَّثَكَ أَنَّهُ يَعْلَمُ الْغَيْبَ فَقَدْ كَذَبَ، وَهْوَ يَقُولُ لاَ يَعْلَمُ الْغَيْبَ إِلاَّ اللَّهُ‏.‏\hadithno{7380}\hadithtrans{Narrated Masruq:`Aisha said, "If anyone tells you that Muhammad has seen his Lord, he is a liar, for Allah says: 'No vision can grasp Him.' (6.103) And if anyone tells you that Muhammad has seen the Unseen, he is a liar, for Allah says: "None has the knowledge of the Unseen but Allah}}
\hadithdefcmd{bukhari}{7381}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُغِيرَةُ، حَدَّثَنَا شَقِيقُ بْنُ سَلَمَةَ، قَالَ قَالَ عَبْدُ اللَّهِ كُنَّا نُصَلِّي خَلْفَ النَّبِيِّ صلى الله عليه وسلم فَنَقُولُ السَّلاَمُ عَلَى اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ هُوَ السَّلاَمُ وَلَكِنْ قُولُوا التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ، السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ، أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏‏.‏\hadithno{7381}\hadithtrans{Narrated `Abdullah:We used to pray behind the Prophet (ﷺ) and used to say: "As-Salamu 'Al-Allah. The Prophet (ﷺ) said, "Allah himself is As-Salam (Name of Allah), so you should say: 'at-Tahiyatu lil-lahi was-sala-watu wattaiyibatu, as-salamu `alaika aiyyuha-n-nabiyyu wa rahmatu-l-lahi wa barakatuhu, as-salamu `alaina wa `ala `ibadi-l-lahi as-salihin. Ashhadu an la ilaha il-lallah, wa ash-hadu anna Muhammadan `abduhu wa rasuluhu}}
\hadithdefcmd{bukhari}{7382}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَقْبِضُ اللَّهُ الأَرْضَ يَوْمَ الْقِيَامَةِ، وَيَطْوِي السَّمَاءَ بِيَمِينِهِ ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَيْنَ مُلُوكُ الأَرْضِ ‏"‏‏.‏ وَقَالَ شُعَيْبٌ وَالزُّبَيْدِيُّ وَابْنُ مُسَافِرٍ وَإِسْحَاقُ بْنُ يَحْيَى عَنِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ‏.‏\hadithno{7382}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "On the Day of Resurrection Allah will hold the whole earth and fold the heaven with His right hand and say, 'I am the King: where are the kings of the earth?}}
\hadithdefcmd{bukhari}{7383}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ أَعُوذُ بِعِزَّتِكَ الَّذِي لاَ إِلَهَ إِلاَّ أَنْتَ، الَّذِي لاَ يَمُوتُ وَالْجِنُّ وَالإِنْسُ يَمُوتُونَ ‏"‏‏.‏\hadithno{7383}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) used to say, "I seek refuge (with YOU) by Your 'Izzat, None has the right to be worshipped but You Who does not die while the Jinns and the human beings die}}
\hadithdefcmd{bukhari}{7384}{حَدَّثَنَا ابْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا حَرَمِيٌّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُلْقَى فِي النَّارِ ‏"‏‏.‏ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ حَدَّثَنَا سَعِيدٌ عَنْ قَتَادَةَ عَنْ أَنَسٍ‏.‏ وَعَنْ مُعْتَمِرٍ سَمِعْتُ أَبِي عَنْ قَتَادَةَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَزَالُ يُلْقَى فِيهَا وَتَقُولُ هَلْ مِنْ مَزِيدٍ‏.‏ حَتَّى يَضَعَ فِيهَا رَبُّ الْعَالَمِينَ قَدَمَهُ فَيَنْزَوِي بَعْضُهَا إِلَى بَعْضٍ، ثُمَّ تَقُولُ قَدْ قَدْ بِعِزَّتِكَ وَكَرَمِكَ‏.‏ وَلاَ تَزَالُ الْجَنَّةُ تَفْضُلُ حَتَّى يُنْشِئَ اللَّهُ لَهَا خَلْقًا فَيُسْكِنَهُمْ فَضْلَ الْجَنَّةِ ‏"‏‏.‏\hadithno{7384}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "(The people will be thrown into Hell ( Fire) and it will keep on saying, 'Is there any more?' till the Lord of the worlds puts His Foot over it, whereupon its different sides will come close to each other, and it will say, 'Qad! Qad! (enough! enough!) By Your 'Izzat (Honor and Power) and YOUR KARAM (Generosity)!' Paradise will remain spacious enough to accommodate more people until Allah will create some more people and let them dwell in the superfluous space of Paradise}}
\hadithdefcmd{bukhari}{7385}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْعُو مِنَ اللَّيْلِ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ أَنْتَ رَبُّ السَّمَوَاتِ وَالأَرْضِ، لَكَ الْحَمْدُ أَنْتَ قَيِّمُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ، لَكَ الْحَمْدُ أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ، قَوْلُكَ الْحَقُّ، وَوَعْدُكَ الْحَقُّ، وَلِقَاؤُكَ حَقٌّ، وَالْجَنَّةُ حَقٌّ، وَالنَّارُ حَقٌّ، وَالسَّاعَةُ حَقٌّ، اللَّهُمَّ لَكَ أَسْلَمْتُ، وَبِكَ آمَنْتُ، وَعَلَيْكَ تَوَكَّلْتُ، وَإِلَيْكَ أَنَبْتُ، وَبِكَ خَاصَمْتُ، وَإِلَيْكَ حَاكَمْتُ، فَاغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ، وَأَسْرَرْتُ وَأَعْلَنْتُ، أَنْتَ إِلَهِي لاَ إِلَهَ لِي غَيْرُكَ ‏"‏‏.‏ حَدَّثَنَا ثَابِتُ بْنُ مُحَمَّدٍ حَدَّثَنَا سُفْيَانُ بِهَذَا وَقَالَ أَنْتَ الْحَقُّ وَقَوْلُكَ الْحَقُّ‏.‏\hadithno{7385}\hadithtrans{Narrated Ibn 'Abbas: The Prophet (ﷺ) used to invoke Allah at night, saying, "O Allah: All the Praises are for You: You are the Lord of the Heavens and the Earth. All the Praises are for You; You are the Maintainer of the Heaven and the Earth and whatever is in them. All the Praises are for You; You are the Light of the Heavens and the Earth. Your Word is the Truth, and Your Promise is the Truth, and the Meeting with You is the Truth, and Paradise is the Truth, and the (Hell) Fire is the Truth, and the Hour is the Truth. O Allah! I surrender myself to You, and I believe in You and I depend upon You, and I repent to You and with You (Your evidences) I stand against my opponents, and to you I leave the judgment (for those who refuse my message). O Allah! Forgive me my sins that I did in the past or will do in the future, and also the sins I did in secret or in public. You are my only God (Whom I worship) and there is no other God for me (i.e. I worship none but You)." Narrated Sufyan: (regarding the above narration) that the Prophet (ﷺ) added, "You are the Truth, and Your Word is the Truth}}
\hadithdefcmd{bukhari}{7386}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَكُنَّا إِذَا عَلَوْنَا كَبَّرْنَا فَقَالَ ‏"‏ ارْبَعُوا عَلَى أَنْفُسِكُمْ، فَإِنَّكُمْ لاَ تَدْعُونَ أَصَمَّ وَلاَ غَائِبًا، تَدْعُونَ سَمِيعًا بَصِيرًا قَرِيبًا ‏"‏‏.‏ ثُمَّ أَتَى عَلَىَّ وَأَنَا أَقُولُ فِي نَفْسِي لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ‏.‏ فَقَالَ لِي ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ قُلْ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ‏.‏ فَإِنَّهَا كَنْزٌ مِنْ كُنُوزِ الْجَنَّةِ ‏"‏‏.‏ أَوْ قَالَ أَلاَ أَدُلُّكَ بِهِ‏.‏\hadithno{7386}\hadithtrans{Narrated Abu Musa:We were with the Prophet (ﷺ) on a journey, and whenever we ascended a high place, we used to say, "Allahu Akbar." The Prophet (ﷺ) said, "Don't trouble yourselves too much! You are not calling a deaf or an absent person, but you are calling One Who Hears, Sees, and is very near." Then he came to me while I was saying in my heart, "La hawla wala quwwatta illa billah (There is neither might nor power but with Allah)." He said, to me, "O `Abdullah bin Qais! Say, 'La hawla wala quwwata illa billah (There is neither might nor power but with Allah), for it is one of the treasures of Paradise." Or said, "Shall I tell you of it?}}
\hadithdefcmd{bukhari}{7388}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ يَزِيدَ، عَنْ أَبِي الْخَيْرِ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو، أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ ـ رضى الله عنه ـ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ عَلِّمْنِي دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي‏.‏ قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي ظَلَمْتُ نَفْسِي ظُلْمًا كَثِيرًا، وَلاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ، فَاغْفِرْ لِي مِنْ عِنْدِكَ مَغْفِرَةً، إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏‏.‏\hadithno{7388}\hadithtrans{Narrated `Abdullah bin `Amr:Abu Bakr As-Siddiq said to the Prophet (ﷺ) "O Allah's Messenger (ﷺ)! Teach me an invocation with which I may invoke Allah in my prayers." The Prophet (ﷺ) said, "Say: O Allah! I have wronged my soul very much (oppressed myself), and none forgives the sins but You; so please bestow Your Forgiveness upon me. No doubt, You are the Oft-Forgiving, Most Merciful}}
\hadithdefcmd{bukhari}{7389}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ حَدَّثَتْهُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ نَادَانِي قَالَ إِنَّ اللَّهَ قَدْ سَمِعَ قَوْلَ قَوْمِكَ وَمَا رَدُّوا عَلَيْكَ ‏"‏‏.‏\hadithno{7389}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Gabriel called me and said, 'Allah has heard the statement of your people and what they replied to you}}
\hadithdefcmd{bukhari}{7390}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِي، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ الْمُنْكَدِرِ، يُحَدِّثُ عَبْدَ اللَّهِ بْنَ الْحَسَنِ يَقُولُ أَخْبَرَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ السَّلَمِيُّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُ أَصْحَابَهُ الاِسْتِخَارَةَ فِي الأُمُورِ كُلِّهَا، كَمَا يُعَلِّمُ السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ ‏ "‏ إِذَا هَمَّ أَحَدُكُمْ بِالأَمْرِ فَلْيَرْكَعْ رَكْعَتَيْنِ مِنْ غَيْرِ الْفَرِيضَةِ ثُمَّ لِيَقُلِ اللَّهُمَّ إِنِّي أَسْتَخِيرُكَ بِعِلْمِكَ، وَأَسْتَقْدِرُكَ بِقُدْرَتِكَ، وَأَسْأَلُكَ مِنْ فَضْلِكَ، فَإِنَّكَ تَقْدِرُ وَلاَ أَقْدِرُ، وَتَعْلَمُ وَلاَ أَعْلَمُ، وَأَنْتَ عَلاَّمُ الْغُيُوبِ، اللَّهُمَّ فَإِنْ كُنْتَ تَعْلَمُ هَذَا الأَمْرَ ـ ثُمَّ تُسَمِّيهِ بِعَيْنِهِ ـ خَيْرًا لِي فِي عَاجِلِ أَمْرِي وَآجِلِهِ ـ قَالَ أَوْ فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي ـ فَاقْدُرْهُ لِي، وَيَسِّرْهُ لِي، ثُمَّ بَارِكْ لِي فِيهِ، اللَّهُمَّ وَإِنْ كُنْتَ تَعْلَمُ أَنَّهُ شَرٌّ لِي فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي ـ أَوْ قَالَ فِي عَاجِلِ أَمْرِي وَآجِلِهِ ـ فَاصْرِفْنِي عَنْهُ، وَاقْدُرْ لِيَ الْخَيْرَ حَيْثُ كَانَ، ثُمَّ رَضِّنِي بِهِ ‏"‏‏.‏\hadithno{7390}\hadithtrans{Narrated Jabir bin `Abdullah:As-Salami: Allah's Messenger (ﷺ) used to teach his companions to perform the prayer of Istikhara for each and every matter just as he used to teach them the Suras from the Qur'an He used to say, "If anyone of you intends to do something, he should offer a two rak`at prayer other than the compulsory prayers, and after finishing it, he should say: O Allah! I consult You, for You have all knowledge, and appeal to You to support me with Your Power and ask for Your Bounty, for You are able to do things while I am not, and You know while I do not; and You are the Knower of the Unseen. O Allah If You know It this matter (name your matter) is good for me both at present and in the future, (or in my religion), in my this life and in the Hereafter, then fulfill it for me and make it easy for me, and then bestow Your Blessings on me in that matter. O Allah! If You know that this matter is not good for me in my religion, in my this life and in my coming Hereafter (or at present or in the future), then divert me from it and choose for me what is good wherever it may be, and make me be pleased with it." (See Hadith No. 391, Vol)}}
\hadithdefcmd{bukhari}{7391}{حَدَّثَنِي سَعِيدُ بْنُ سُلَيْمَانَ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ، قَالَ أَكْثَرُ مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَحْلِفُ ‏ "‏ لاَ وَمُقَلِّبِ الْقُلُوبِ ‏"‏‏.‏\hadithno{7391}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) frequently used to swear, "No, by the One Who turns the hearts}}
\hadithdefcmd{bukhari}{7392}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِلَّهِ تِسْعَةً وَتِسْعِينَ اسْمًا مِائَةً إِلاَّ وَاحِدًا، مَنْ أَحْصَاهَا دَخَلَ الْجَنَّةَ ‏"‏‏.‏ ‏\{‏أَحْصَيْنَاهُ‏\}‏ حَفِظْنَاهُ‏.‏\hadithno{7392}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah has ninety-nine Names, one-hundred less one; and he who memorized them all by heart will enter Paradise." To count something means to know it by heart}}
\hadithdefcmd{bukhari}{7393}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي مَالِكٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَاءَ أَحَدُكُمْ فِرَاشَهُ فَلْيَنْفُضْهُ بِصَنِفَةِ ثَوْبِهِ ثَلاَثَ مَرَّاتٍ، وَلْيَقُلْ بِاسْمِكَ رَبِّ وَضَعْتُ جَنْبِي وَبِكَ أَرْفَعُهُ، إِنْ أَمْسَكْتَ نَفْسِي فَاغْفِرْ لَهَا، وَإِنْ أَرْسَلْتَهَا فَاحْفَظْهَا بِمَا تَحْفَظُ بِهِ عِبَادَكَ الصَّالِحِينَ ‏"‏‏.‏ تَابَعَهُ يَحْيَى وَبِشْرُ بْنُ الْمُفَضَّلِ عَنْ عُبَيْدِ اللَّهِ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَزَادَ زُهَيْرٌ وَأَبُو ضَمْرَةَ وَإِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ عَنْ عُبَيْدِ اللَّهِ عَنْ سَعِيدٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَرَوَاهُ ابْنُ عَجْلاَنَ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7393}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When anyone of you goes to bed, he should dust it off thrice with the edge of his garment, and say: Bismika Rabbi Wada`tu janbi, wa bika arfa'hu. In amsakta nafsi faghfir laha, wa in arsaltaha fahfazha bima tahfaz bihi 'ibadaka-s-salihin}}
\hadithdefcmd{bukhari}{7394}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَوَى إِلَى فِرَاشِهِ قَالَ ‏"‏ اللَّهُمَّ بِاسْمِكَ أَحْيَا وَأَمُوتُ ‏"‏‏.‏ وَإِذَا أَصْبَحَ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا وَإِلَيْهِ النُّشُورُ ‏"‏‏.‏\hadithno{7394}\hadithtrans{Narrated Hudhaifah:When the Prophet (ﷺ) went to bed, he used to say, "Allahumma bismika ahya wa amut." And when he woke up in the mornings he used to say, "Al-hamdu li l-lahi al-ladhi ahyana ba'da ma amatana wa ilaihi-nnushur}}
\hadithdefcmd{bukhari}{7395}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَخَذَ مَضْجَعَهُ مِنَ اللَّيْلِ قَالَ ‏ "‏ بِاسْمِكَ نَمُوتُ وَنَحْيَا، فَإِذَا اسْتَيْقَظَ قَالَ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَانَا بَعْدَ مَا أَمَاتَنَا وَإِلَيْهِ النُّشُورُ ‏"‏‏.‏\hadithno{7395}\hadithtrans{Narrated Abu Dharr:When the Prophet (ﷺ) went to bed at night, he used to say: "Bismika namutu wa nahya." And when he got up in the morning, he used to say, "Al hamdu li l-lahi al-ladhi ahyana ba'da ma amatana, wa ilaihi-nnushur}}
\hadithdefcmd{bukhari}{7396}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ أَحَدَكُمْ إِذَا أَرَادَ أَنْ يَأْتِيَ أَهْلَهُ فَقَالَ بِاسْمِ اللَّهِ، اللَّهُمَّ جَنِّبْنَا الشَّيْطَانَ، وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنَا‏.‏ فَإِنَّهُ إِنْ يُقَدَّرْ بَيْنَهُمَا وَلَدٌ فِي ذَلِكَ لَمْ يَضُرُّهُ شَيْطَانٌ أَبَدًا ‏"‏‏.‏\hadithno{7396}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) said, "If anyone of you, when intending to have a sexual relation (sleep) with his wife, says: Bismillah, Allahumma jannibna ashShaitan, wa Jannib ash-Shaitana ma razaqtana, Satan would never harm that child, should it be ordained that they will have one. (Because of that sleep)}}
\hadithdefcmd{bukhari}{7397}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا فُضَيْلٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم قُلْتُ أُرْسِلُ كِلاَبِي الْمُعَلَّمَةَ‏.‏ قَالَ ‏ "‏ إِذَا أَرْسَلْتَ كِلاَبَكَ الْمُعَلَّمَةَ وَذَكَرْتَ اسْمَ اللَّهِ فَأَمْسَكْنَ فَكُلْ، وَإِذَا رَمَيْتَ بِالْمِعْرَاضِ فَخَزَقَ فَكُلْ ‏"‏‏.‏\hadithno{7397}\hadithtrans{Narrated `Adi bin Hatim:I asked the Prophet, "I send off (for a game) my trained hunting dogs; (what is your verdict concerning the game they hunt?" He said, "If you send off your trained hunting dogs and mention the Name of Allah, then, if they catch some game, eat (thereof). And if you hit the game with a mi'rad (a hunting tool) and it wounds it, you can eat (it)}}
\hadithdefcmd{bukhari}{7398}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، قَالَ سَمِعْتُ هِشَامَ بْنَ عُرْوَةَ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالُوا يَا رَسُولَ اللَّهِ إِنَّ هُنَا أَقْوَامًا حَدِيثًا عَهْدُهُمْ بِشِرْكٍ، يَأْتُونَا بِلُحْمَانٍ لاَ نَدْرِي يَذْكُرُونَ اسْمَ اللَّهِ عَلَيْهَا أَمْ لاَ‏.‏ قَالَ ‏ "‏ اذْكُرُوا أَنْتُمُ اسْمَ اللَّهِ وَكُلُوا ‏"‏‏.‏ تَابَعَهُ مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ وَالدَّرَاوَرْدِيُّ وَأُسَامَةُ بْنُ حَفْصٍ‏.‏\hadithno{7398}\hadithtrans{Narrated `Aisha:The people said to the Prophet (ﷺ) , "O Allah's Messenger (ﷺ)! Here are people who have recently embraced Islam and they bring meat, and we do not know whether they had mentioned Allah's Name while slaughtering the animals or not." The Prophet (ﷺ) said, "You should mention Allah's Name and eat}}
\hadithdefcmd{bukhari}{7399}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ ضَحَّى النَّبِيُّ صلى الله عليه وسلم بِكَبْشَيْنِ، يُسَمِّي وَيُكَبِّرُ‏.‏\hadithno{7399}\hadithtrans{Narrated Anas:The Prophet (ﷺ) slaughtered two rams as sacrifice and mentioned Allah's Name and said, "Allahu-Akbar" while slaughtering}}
\hadithdefcmd{bukhari}{7400}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ جُنْدَبٍ، أَنَّهُ شَهِدَ النَّبِيَّ صلى الله عليه وسلم يَوْمَ النَّحْرِ صَلَّى ثُمَّ خَطَبَ فَقَالَ ‏ "‏ مَنْ ذَبَحَ قَبْلَ أَنْ يُصَلِّيَ فَلْيَذْبَحْ مَكَانَهَا أُخْرَى، وَمَنْ لَمْ يَذْبَحْ فَلْيَذْبَحْ بِاسْمِ اللَّهِ ‏"‏‏.‏\hadithno{7400}\hadithtrans{Narrated Jundab:That he witnessed the Prophet (ﷺ) on the Day of Nahr. The Prophet (ﷺ) offered prayer and then delivered a sermon saying, "Whoever slaughtered his sacrifice before offering prayer, should slaughter another animal in place of the first; and whoever has not yet slaughtered any, should slaughter a sacrifice and mention Allah's Name while doing so}}
\hadithdefcmd{bukhari}{7401}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا وَرْقَاءُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَحْلِفُوا بِآبَائِكُمْ، وَمَنْ كَانَ حَالِفًا فَلْيَحْلِفْ بِاللَّهِ ‏"‏‏.‏\hadithno{7401}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Do not swear by your fathers; and whoever wants to swear should swear by Allah}}
\hadithdefcmd{bukhari}{7402}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَمْرُو بْنُ أَبِي سُفْيَانَ بْنِ أَسِيدِ بْنِ جَارِيَةَ الثَّقَفِيُّ ـ حَلِيفٌ لِبَنِي زُهْرَةَ وَكَانَ مِنْ أَصْحَابِ أَبِي هُرَيْرَةَ ـ أَنَّ أَبَا هُرَيْرَةَ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشْرَةً مِنْهُمْ خُبَيْبٌ الأَنْصَارِيُّ، فَأَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عِيَاضٍ أَنَّ ابْنَةَ الْحَارِثِ أَخْبَرَتْهُ أَنَّهُمْ حِينَ اجْتَمَعُوا اسْتَعَارَ مِنْهَا مُوسَى يَسْتَحِدُّ بِهَا، فَلَمَّا خَرَجُوا مِنَ الْحَرَمِ لِيَقْتُلُوهُ قَالَ خُبَيْبٌ الأَنْصَارِيُّ وَلَسْتُ أُبَالِي حِينَ أُقْتَلُ مُسْلِمًا ** عَلَى أَيِّ شِقٍّ كَانَ لِلَّهِ مَصْرَعِي وَذَلِكَ فِي ذَاتِ الإِلَهِ وَإِنْ يَشَأْ ** يُبَارِكْ عَلَى أَوْصَالِ شِلْوٍ مُمَزَّعِ فَقَتَلَهُ ابْنُ الْحَارِثِ فَأَخْبَرَ النَّبِيُّ صلى الله عليه وسلم أَصْحَابَهُ خَبَرَهُمْ يَوْمَ أُصِيبُوا‏.‏\hadithno{7402}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) sent ten persons to bring the enemy's secrets and Khubaib Al-Ansari was one of them. 'Ubaidullah bin 'Iyad told me that the daughter of Al-Harith told him that when they gathered (to kill Khubaib Al Ansari) he asked for a razor to clean his pubic region, and when they had taken him outside the sanctuary of Mecca in order to kill him, he said in verse, "I don't care if I am killed as a Muslim, on any side (of my body) I may be killed in Allah's Cause; for that is for the sake of Allah's very Self; and if He will, He will bestow His Blessings upon the torn pieces of my body." Then Ibn Al-Harith killed him, and the Prophet (ﷺ) informed his companions of the death of those (ten men) on the very day they were killed}}
\hadithdefcmd{bukhari}{7403}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ أَحَدٍ أَغْيَرُ مِنَ اللَّهِ، مِنْ أَجْلِ ذَلِكَ حَرَّمَ الْفَوَاحِشَ، وَمَا أَحَدٌ أَحَبَّ إِلَيْهِ الْمَدْحُ مِنَ اللَّهِ ‏"‏‏.‏\hadithno{7403}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "There is none having a greater sense of Ghira than Allah, and for that reason He has forbidden shameful deeds and sins (illegal sexual intercourse etc.) And there is none who likes to be praised more than Allah does." (See Hadith No. 147, Vol)}}
\hadithdefcmd{bukhari}{7404}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَمَّا خَلَقَ اللَّهُ الْخَلْقَ كَتَبَ فِي كِتَابِهِ ـ هُوَ يَكْتُبُ عَلَى نَفْسِهِ، وَهْوَ وَضْعٌ عِنْدَهُ عَلَى الْعَرْشِ ـ إِنَّ رَحْمَتِي تَغْلِبُ غَضَبِي ‏"‏‏.‏\hadithno{7404}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When Allah created the Creation, He wrote in His Book--and He wrote (that) about Himself, and it is placed with Him on the Throne--'Verily My Mercy overcomes My Anger}}
\hadithdefcmd{bukhari}{7405}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، سَمِعْتُ أَبَا صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَقُولُ اللَّهُ تَعَالَى أَنَا عِنْدَ ظَنِّ عَبْدِي بِي، وَأَنَا مَعَهُ إِذَا ذَكَرَنِي، فَإِنْ ذَكَرَنِي فِي نَفْسِهِ ذَكَرْتُهُ فِي نَفْسِي، وَإِنْ ذَكَرَنِي فِي مَلأٍ ذَكَرْتُهُ فِي مَلأٍ خَيْرٍ مِنْهُمْ، وَإِنْ تَقَرَّبَ إِلَىَّ بِشِبْرٍ تَقَرَّبْتُ إِلَيْهِ ذِرَاعًا، وَإِنْ تَقَرَّبَ إِلَىَّ ذِرَاعًا تَقَرَّبْتُ إِلَيْهِ بَاعًا، وَإِنْ أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً ‏"‏‏.‏\hadithno{7405}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah says: 'I am just as My slave thinks I am, (i.e. I am able to do for him what he thinks I can do for him) and I am with him if He remembers Me. If he remembers Me in himself, I too, remember him in Myself; and if he remembers Me in a group of people, I remember him in a group that is better than they; and if he comes one span nearer to Me, I go one cubit nearer to him; and if he comes one cubit nearer to Me, I go a distance of two outstretched arms nearer to him; and if he comes to Me walking, I go to him running}}
\hadithdefcmd{bukhari}{7406}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏قُلْ هُوَ الْقَادِرُ عَلَى أَنْ يَبْعَثَ عَلَيْكُمْ عَذَابًا مِنْ فَوْقِكُمْ‏\}‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَعُوذُ بِوَجْهِكَ ‏"‏‏.‏ فَقَالَ ‏\{‏أَوْ مِنْ تَحْتِ أَرْجُلِكُمْ‏\}‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَعُوذُ بِوَجْهِكَ ‏"‏‏.‏ قَالَ ‏\{‏أَوْ يَلْبِسَكُمْ شِيَعًا‏\}‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَذَا أَيْسَرُ ‏"‏‏.‏\hadithno{7406}\hadithtrans{Narrated Jabir bin `Abdullah:when this Verse:--'Say (O Muhammad!): He has Power to send torments on you from above,' (6.65) was revealed; The Prophet (ﷺ) said, "I take refuge with Your Face." Allah revealed:-- '..or from underneath your feet.' (6.65) The Prophet (ﷺ) then said, "I seek refuge with Your Face!" Then Allah revealed:--'...or confuse you in party-strife.' (6.65) Oh that, the Prophet (ﷺ) said, "This is easier}}
\hadithdefcmd{bukhari}{7407}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ ذُكِرَ الدَّجَّالُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ اللَّهَ لاَ يَخْفَى عَلَيْكُمْ، إِنَّ اللَّهَ لَيْسَ بِأَعْوَرَ ـ وَأَشَارَ بِيَدِهِ إِلَى عَيْنِهِ ـ وَإِنَّ الْمَسِيحَ الدَّجَّالَ أَعْوَرُ الْعَيْنِ الْيُمْنَى كَأَنَّ عَيْنَهُ عِنَبَةٌ طَافِيَةٌ ‏"‏‏.‏\hadithno{7407}\hadithtrans{Narrated `Abdullah:Ad-Dajjal was mentioned in the presence of the Prophet. The Prophet (ﷺ) said, "Allah is not hidden from you; He is not one-eyed," and pointed with his hand towards his eye, adding, "While Al-Masih Ad- Dajjal is blind in the right eye and his eye looks like a protruding grape}}
\hadithdefcmd{bukhari}{7408}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا قَتَادَةُ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَعَثَ اللَّهُ مِنْ نَبِيٍّ إِلاَّ أَنْذَرَ قَوْمَهُ الأَعْوَرَ الْكَذَّابَ، إِنَّهُ أَعْوَرُ، وَإِنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ، مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ ‏"‏‏.‏\hadithno{7408}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Allah did not send any prophet but that he warned his nation of the one-eyed liar (Ad-Dajjal). He is one-eyed while your Lord is not one-eyed, The word 'Kafir' (unbeliever) is written between his two eyes}}
\hadithdefcmd{bukhari}{7409}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مُوسَى ـ هُوَ ابْنُ عُقْبَةَ ـ حَدَّثَنِي مُحَمَّدُ بْنُ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، فِي غَزْوَةِ بَنِي الْمُصْطَلِقِ أَنَّهُمْ أَصَابُوا سَبَايَا فَأَرَادُوا أَنْ يَسْتَمْتِعُوا بِهِنَّ وَلاَ يَحْمِلْنَ فَسَأَلُوا النَّبِيَّ صلى الله عليه وسلم عَنِ الْعَزْلِ فَقَالَ ‏"‏ مَا عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا، فَإِنَّ اللَّهَ قَدْ كَتَبَ مَنْ هُوَ خَالِقٌ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏ وَقَالَ مُجَاهِدٌ عَنْ قَزَعَةَ سَمِعْتُ أَبَا سَعِيدٍ فَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَيْسَتْ نَفْسٌ مَخْلُوقَةٌ إِلاَّ اللَّهُ خَالِقُهَا ‏"‏‏.‏\hadithno{7409}\hadithtrans{Narrated Abu Sa`id Al-Khudri:That during the battle with Bani Al-Mustaliq they (Muslims) captured some females and intended to have sexual relation with them without impregnating them. So they asked the Prophet (ﷺ) about coitus interruptus. The Prophet (ﷺ) said, "It is better that you should not do it, for Allah has written whom He is going to create till the Day of Resurrection." Qaza'a said, "I heard Abu Sa`id saying that the Prophet (ﷺ) said, 'No soul is ordained to be created but Allah will create it}}
\hadithdefcmd{bukhari}{7410}{حَدَّثَنِي مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ يَجْمَعُ اللَّهُ الْمُؤْمِنِينَ يَوْمَ الْقِيَامَةِ كَذَلِكَ فَيَقُولُونَ لَوِ اسْتَشْفَعْنَا إِلَى رَبِّنَا حَتَّى يُرِيحَنَا مِنْ مَكَانِنَا هَذَا‏.‏ فَيَأْتُونَ آدَمَ فَيَقُولُونَ يَا آدَمُ أَمَا تَرَى النَّاسَ خَلَقَكَ اللَّهُ بِيَدِهِ وَأَسْجَدَ لَكَ مَلاَئِكَتَهُ وَعَلَّمَكَ أَسْمَاءَ كُلِّ شَىْءٍ، شَفِّعْ لَنَا إِلَى رَبِّنَا حَتَّى يُرِيحَنَا مِنْ مَكَانِنَا هَذَا‏.‏ فَيَقُولُ لَسْتُ هُنَاكَ ـ وَيَذْكُرُ لَهُمْ خَطِيئَتَهُ الَّتِي أَصَابَ ـ وَلَكِنِ ائْتُوا نُوحًا، فَإِنَّهُ أَوَّلُ رَسُولٍ بَعَثَهُ اللَّهُ إِلَى أَهْلِ الأَرْضِ‏.‏ فَيَأْتُونَ نُوحًا فَيَقُولُ لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ خَطِيئَتَهُ الَّتِي أَصَابَ ـ وَلَكِنِ ائْتُوا إِبْرَاهِيمَ خَلِيلَ الرَّحْمَنِ‏.‏ فَيَأْتُونَ إِبْرَاهِيمَ فَيَقُولُ لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ لَهُمْ خَطَايَاهُ الَّتِي أَصَابَهَا ـ وَلَكِنِ ائْتُوا مُوسَى عَبْدًا أَتَاهُ اللَّهُ التَّوْرَاةَ وَكَلَّمَهُ تَكْلِيمًا ـ فَيَأْتُونَ مُوسَى فَيَقُولُ لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ لَهُمْ خَطِيئَتَهُ الَّتِي أَصَابَ ـ وَلَكِنِ ائْتُوا عِيسَى عَبْدَ اللَّهِ وَرَسُولَهُ وَكَلِمَتَهُ وَرُوحَهُ‏.‏ فَيَأْتُونَ عِيسَى فَيَقُولُ لَسْتُ هُنَاكُمْ وَلَكِنِ ائْتُوا مُحَمَّدًا صلى الله عليه وسلم عَبْدًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ‏.‏ فَيَأْتُونِي فَأَنْطَلِقُ فَأَسْتَأْذِنُ عَلَى رَبِّي فَيُؤْذَنُ لِي عَلَيْهِ، فَإِذَا رَأَيْتُ رَبِّي وَقَعْتُ لَهُ سَاجِدًا فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي ثُمَّ يُقَالُ لِي ارْفَعْ مُحَمَّدُ، وَقُلْ يُسْمَعْ، وَسَلْ تُعْطَهْ، وَاشْفَعْ تُشَفَّعْ‏.‏ فَأَحْمَدُ رَبِّي بِمَحَامِدَ عَلَّمَنِيهَا، ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا فَأُدْخِلُهُمُ الْجَنَّةَ، ثُمَّ أَرْجِعُ فَإِذَا رَأَيْتُ رَبِّي وَقَعْتُ سَاجِدًا، فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي ثُمَّ يُقَالُ ارْفَعْ مُحَمَّدُ، وَقُلْ يُسْمَعْ، وَسَلْ تُعْطَهْ، وَاشْفَعْ تُشَفَّعْ، فَأَحْمَدُ رَبِّي بِمَحَامِدَ عَلَّمَنِيهَا رَبِّي ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا فَأُدْخِلُهُمُ الْجَنَّةَ، ثُمَّ أَرْجِعُ فَإِذَا رَأَيْتُ رَبِّي وَقَعْتُ سَاجِدًا، فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي ثُمَّ يُقَالُ ارْفَعْ مُحَمَّدُ، قُلْ يُسْمَعْ، وَسَلْ تُعْطَهْ، وَاشْفَعْ تُشَفَّعْ، فَأَحْمَدُ رَبِّي بِمَحَامِدَ عَلَّمَنِيهَا، ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا فَأُدْخِلُهُمُ الْجَنَّةَ، ثُمَّ أَرْجِعُ فَأَقُولُ يَا رَبِّ مَا بَقِيَ فِي النَّارِ إِلاَّ مَنْ حَبَسَهُ الْقُرْآنُ وَوَجَبَ عَلَيْهِ الْخُلُودُ ‏"‏‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَخْرُجُ مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ وَكَانَ فِي قَلْبِهِ مِنَ الْخَيْرِ مَا يَزِنُ شَعِيرَةً، ثُمَّ يَخْرُجُ مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ وَكَانَ فِي قَلْبِهِ مِنَ الْخَيْرِ مَا يَزِنُ بُرَّةً، ثُمَّ يَخْرُجُ مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ وَكَانَ فِي قَلْبِهِ مَا يَزِنُ مِنَ الْخَيْرِ ذَرَّةً ‏"‏‏.‏\hadithno{7410}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Allah will gather the believers on the Day of Resurrection in the same way (as they are gathered in this life), and they will say, 'Let us ask someone to intercede for us with our Lord that He may relieve us from this place of ours.' Then they will go to Adam and say, 'O Adam! Don't you see the people (people's condition)? Allah created you with His Own Hands and ordered His angels to prostrate before you, and taught you the names of all the things. Please intercede for us with our Lord so that He may relieve us from this place of ours.' Adam will say, 'I am not fit for this undertaking' and mention to them the mistakes he had committed, and add, "But you d better go to Noah as he was the first Apostle sent by Allah to the people of the Earth.' They will go to Noah who will reply, 'I am not fit for this undertaking,' and mention the mistake which he made, and add, 'But you'd better go to Abraham, Khalil Ar-Rahman.' They will go to Abraham who will reply, 'I am not fit for this undertaking,' and mention to them the mistakes he made, and add, 'But you'd better go to Moses, a slave whom Allah gave the Torah and to whom He spoke directly' They will go to Moses who will reply, 'I am not fit for this undertaking,' and mention to them the mistakes he made, and add, 'You'd better go to Jesus, Allah's slave and His Apostle and His Word (Be: And it was) and a soul created by Him.' They will go to Jesus who will say, 'I am not fit for this undertaking, but you'd better go to Muhammad whose sins of the past and the future had been forgiven (by Allah).' So they will come to me and I will ask the permission of my Lord, and I will be permitted (to present myself) before Him. When I see my Lord, I will fall down in (prostration) before Him and He will leave me (in prostration) as long as He wishes, and then it will be said to me, 'O Muhammad! Raise your head and speak, for you will be listened to; and ask, for you will be granted (your request); and intercede, for your intercession will be accepted.' I will then raise my head and praise my Lord with certain praises which He has taught me, and then I will intercede. Allah will allow me to intercede (for a certain kind of people) and will fix a limit whom I will admit into Paradise. I will come back again, and when I see my Lord (again), I will fall down in prostration before Him, and He will leave me (in prostration) as long as He wishes, and then He will say, 'O Muhammad! Raise your head and speak, for you will be listened to; and ask, for you will be granted (your request); and intercede, for your intercession will be accepted.' I will then praise my Lord with certain praises which He has taught me, and then I will intercede. Allah will allow me to intercede (for a certain kind of people) and will fix a limit to whom I will admit into Paradise, I will return again, and when I see my Lord, I will fall down (in prostration) and He will leave me (in prostration) as long as He wishes, and then He will say, 'O Muhammad! Raise your head and speak, for you will be listened to, and ask, for you will be granted (your request); and intercede, for your intercession will be accepted.' I will then praise my Lord with certain praises which He has taught me, and then I will intercede. Allah will allow me to intercede (for a certain kind of people) and will fix a limit to whom I will admit into Paradise. I will come back and say, 'O my Lord! None remains in Hell (Fire) but those whom Qur'an has imprisoned therein and for whom eternity in Hell (Fire) has become inevitable.' " The Prophet (ﷺ) added, "There will come out of Hell (Fire) everyone who says: 'La ilaha illal-lah,' and has in his heart good equal to the weight of a barley grain. Then there will come out of Hell (Fire) everyone who says: ' La ilaha illal-lah,' and has in his heart good equal to the weight of a wheat grain. Then there will come out of Hell (Fire) everyone who says: 'La ilaha illal-lah,' and has in his heart good equal to the weight of an atom (or a smallest ant)}}
\hadithdefcmd{bukhari}{7411}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَدُ اللَّهِ مَلأَى لاَ يَغِيضُهَا نَفَقَةٌ، سَحَّاءُ اللَّيْلَ وَالنَّهَارَ ـ وَقَالَ ـ أَرَأَيْتُمْ مَا أَنْفَقَ مُنْذُ خَلَقَ السَّمَوَاتِ وَالأَرْضَ، فَإِنَّهُ لَمْ يَغِضْ مَا فِي يَدِهِ ـ وَقَالَ ـ عَرْشُهُ عَلَى الْمَاءِ وَبِيَدِهِ الأُخْرَى الْمِيزَانُ يَخْفِضُ وَيَرْفَعُ ‏"‏‏.‏\hadithno{7411}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah's Hand is full, and (its fullness) is not affected by the continuous spending, day and night." He also said, "Do you see what He has spent since He created the Heavens and the Earth? Yet all that has not decreased what is in His Hand." He also said, "His Throne is over the water and in His other Hand is the balance (of Justice) and He raises and lowers (whomever He will)." (See Hadith No. 206, Vol)}}
\hadithdefcmd{bukhari}{7413}{حَدَّثَنَا مُقَدَّمُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي عَمِّي الْقَاسِمُ بْنُ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنَّ اللَّهَ يَقْبِضُ يَوْمَ الْقِيَامَةِ الأَرْضَ وَتَكُونُ السَّمَوَاتُ بِيَمِينِهِ ثُمَّ يَقُولُ أَنَا الْمَلِكُ ‏"‏‏.‏ رَوَاهُ سَعِيدٌ عَنْ مَالِكٍ‏.‏ وَقَالَ عُمَرُ بْنُ حَمْزَةَ سَمِعْتُ سَالِمًا سَمِعْتُ ابْنَ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا‏.‏ وَقَالَ أَبُو الْيَمَانِ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَقْبِضُ اللَّهُ الأَرْضَ ‏"‏‏.‏\hadithno{7413}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "On the Day of Resurrection, Allah will grasp the whole Earth by His Hand, and all the Heavens in His right, and then He will say, 'I am the King." Abu Huraira said, "Allah's Messenger (ﷺ) said," Allah will grasp the Earth}}
\hadithdefcmd{bukhari}{7414}{حَدَّثَنَا مُسَدَّدٌ، سَمِعَ يَحْيَى بْنَ سَعِيدٍ، عَنْ سُفْيَانَ، حَدَّثَنِي مَنْصُورٌ، وَسُلَيْمَانُ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ يَهُودِيًّا، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ إِنَّ اللَّهَ يُمْسِكُ السَّمَوَاتِ عَلَى إِصْبَعٍ وَالأَرَضِينَ عَلَى إِصْبَعٍ، وَالْجِبَالَ عَلَى إِصْبَعٍ، وَالشَّجَرَ عَلَى إِصْبَعٍ، وَالْخَلاَئِقَ عَلَى إِصْبَعٍ، ثُمَّ يَقُولُ أَنَا الْمَلِكُ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَدَتْ نَوَاجِذُهُ ثُمَّ قَرَأَ ‏\{‏وَمَا قَدَرُوا اللَّهَ حَقَّ قَدْرِهِ‏\}‏‏.‏ قَالَ يَحْيَى بْنُ سَعِيدٍ وَزَادَ فِيهِ فُضَيْلُ بْنُ عِيَاضٍ عَنْ مَنْصُورٍ عَنْ إِبْرَاهِيمَ عَنْ عَبِيدَةَ عَنْ عَبْدِ اللَّهِ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم تَعَجُّبًا وَتَصْدِيقًا لَهُ‏.‏\hadithno{7414}\hadithtrans{Narrated `Abdullah:A Jew came to the Prophet (ﷺ) and said, "O Muhammad! Allah will hold the heavens on a Finger, and the mountains on a Finger, and the trees on a Finger, and all the creation on a Finger, and then He will say, 'I am the King.' " On that Allah's Messenger (ﷺ) smiled till his premolar teeth became visible, and then recited:-- 'No just estimate have they made of Allah such as due to him....(39.67) `Abdullah added: Allah's Apostle smiled (at the Jew's statement) expressing his wonder and belief in what was said}}
\hadithdefcmd{bukhari}{7415}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، سَمِعْتُ إِبْرَاهِيمَ، قَالَ سَمِعْتُ عَلْقَمَةَ، يَقُولُ قَالَ عَبْدُ اللَّهِ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم مِنْ أَهْلِ الْكِتَابِ فَقَالَ يَا أَبَا الْقَاسِمِ إِنَّ اللَّهَ يُمْسِكُ السَّمَوَاتِ عَلَى إِصْبَعٍ، وَالأَرَضِينَ عَلَى إِصْبَعٍ، وَالشَّجَرَ وَالثَّرَى عَلَى إِصْبَعٍ، وَالْخَلاَئِقَ عَلَى إِصْبَعٍ، ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَنَا الْمَلِكُ‏.‏ فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم ضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ ثُمَّ قَرَأَ ‏\{‏وَمَا قَدَرُوا اللَّهَ حَقَّ قَدْرِهِ‏\}‏\hadithno{7415}\hadithtrans{Narrated `Abdullah:A man from the people of the scripture came to the Prophet (ﷺ) and said, "O Abal-Qasim! Allah will hold the Heavens upon a Finger, and the Earth on a Finger and the land on a Finger, and all the creation on a Finger, and will say, 'I am the King! I am the King!' " I saw the Prophet (after hearing that), smiling till his premolar teeth became visible, and he then recited: -- 'No just estimate have they made of Allah such as due to him}}
\hadithdefcmd{bukhari}{7416}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ وَرَّادٍ، كَاتِبِ الْمُغِيرَةِ عَنِ الْمُغِيرَةِ، قَالَ قَالَ سَعْدُ بْنُ عُبَادَةَ لَوْ رَأَيْتُ رَجُلاً مَعَ امْرَأَتِي لَضَرَبْتُهُ بِالسَّيْفِ غَيْرَ مُصْفَحٍ‏.‏ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ تَعْجَبُونَ مِنْ غَيْرَةِ سَعْدٍ، وَاللَّهِ لأَنَا أَغْيَرُ مِنْهُ، وَاللَّهُ أَغْيَرُ مِنِّي، وَمِنْ أَجْلِ غَيْرَةِ اللَّهِ حَرَّمَ الْفَوَاحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ، وَلاَ أَحَدَ أَحَبُّ إِلَيْهِ الْعُذْرُ مِنَ اللَّهِ، وَمِنْ أَجْلِ ذَلِكَ بَعَثَ الْمُبَشِّرِينَ وَالْمُنْذِرِينَ وَلاَ أَحَدَ أَحَبُّ إِلَيْهِ الْمِدْحَةُ مِنَ اللَّهِ وَمِنْ أَجْلِ ذَلِكَ وَعَدَ اللَّهُ الْجَنَّةَ ‏"‏‏.‏ وَقَالَ عُبَيْدُ اللَّهِ بْنُ عَمْرٍو عَنْ عَبْدِ الْمَلِكِ ‏"‏ لاَ شَخْصَ أَغْيَرُ مِنَ اللَّهِ ‏"‏‏.‏\hadithno{7416}\hadithtrans{Narrated Al-Mughira:Sa`d bin 'Ubada said, "If I saw a man with my wife, I would strike him (behead him) with the blade of my sword." This news reached Allah's Messenger (ﷺ) who then said, "You people are astonished at Sa`d's Ghira. By Allah, I have more Ghira than he, and Allah has more Ghira than I, and because of Allah's Ghira, He has made unlawful Shameful deeds and sins (illegal sexual intercourse etc.) done in open and in secret. And there is none who likes that the people should repent to Him and beg His pardon than Allah, and for this reason He sent the warners and the givers of good news. And there is none who likes to be praised more than Allah does, and for this reason, Allah promised to grant Paradise (to the doers of good)." `Abdul Malik said, "No person has more Ghira than Allah}}
\hadithdefcmd{bukhari}{7417}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ النَّبِيُّ صلى الله عليه وسلم لِرَجُلٍ ‏ "‏ أَمَعَكَ مِنَ الْقُرْآنِ شَىْءٌ ‏"‏‏.‏ قَالَ نَعَمْ سُورَةُ كَذَا وَسُورَةُ كَذَا‏.‏ لِسُوَرٍ سَمَّاهَا‏.‏\hadithno{7417}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) said to a man, "Have you got anything of the Qur'an?" The man said, "Yes, such-andsuch Sura, and such-and-such Sura," naming the Suras}}
\hadithdefcmd{bukhari}{7418}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ جَامِعِ بْنِ شَدَّادٍ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ إِنِّي عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ جَاءَهُ قَوْمٌ مِنْ بَنِي تَمِيمٍ فَقَالَ ‏"‏ اقْبَلُوا الْبُشْرَى يَا بَنِي تَمِيمٍ ‏"‏‏.‏ قَالُوا بَشَّرْتَنَا فَأَعْطِنَا‏.‏ فَدَخَلَ نَاسٌ مِنْ أَهْلِ الْيَمَنِ فَقَالَ ‏"‏ اقْبَلُوا الْبُشْرَى يَا أَهْلَ الْيَمَنِ إِذْ لَمْ يَقْبَلْهَا بَنُو تَمِيمٍ ‏"‏‏.‏ قَالُوا قَبِلْنَا‏.‏ جِئْنَاكَ لِنَتَفَقَّهَ فِي الدِّينِ وَلِنَسْأَلَكَ عَنْ أَوَّلِ هَذَا الأَمْرِ مَا كَانَ‏.‏ قَالَ ‏"‏ كَانَ اللَّهُ وَلَمْ يَكُنْ شَىْءٌ قَبْلَهُ، وَكَانَ عَرْشُهُ عَلَى الْمَاءِ، ثُمَّ خَلَقَ السَّمَوَاتِ وَالأَرْضَ، وَكَتَبَ فِي الذِّكْرِ كُلَّ شَىْءٍ ‏"‏‏.‏ ثُمَّ أَتَانِي رَجُلٌ فَقَالَ يَا عِمْرَانُ أَدْرِكْ نَاقَتَكَ فَقَدْ ذَهَبَتْ فَانْطَلَقْتُ أَطْلُبُهَا، فَإِذَا السَّرَابُ يَنْقَطِعُ دُونَهَا، وَايْمُ اللَّهِ لَوَدِدْتُ أَنَّهَا قَدْ ذَهَبَتْ وَلَمْ أَقُمْ‏.‏\hadithno{7418}\hadithtrans{Narrated `Imran bin Hussain:While I was with the Prophet (ﷺ) , some people from Bani Tamim came to him. The Prophet (ﷺ) said, "O Bani Tamim! Accept the good news!" They said, "You have given us the good news; now give us (something)." (After a while) some Yemenites entered, and he said to them, "O the people of Yemen! Accept the good news, as Bani Tamim have refused it. " They said, "We accept it, for we have come to you to learn the Religion. So we ask you what the beginning of this universe was." The Prophet (ﷺ) said "There was Allah and nothing else before Him and His Throne was over the water, and He then created the Heavens and the Earth and wrote everything in the Book." Then a man came to me and said, 'O `Imran! Follow your she-camel for it has run away!" So I set out seeking it, and behold, it was beyond the mirage! By Allah, I wished that it (my she-camel) had gone but that I had not left (the gathering)}}
\hadithdefcmd{bukhari}{7419}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ يَمِينَ اللَّهِ مَلأَى لاَ يَغِيضُهَا نَفَقَةٌ سَحَّاءُ اللَّيْلَ وَالنَّهَارَ، أَرَأَيْتُمْ مَا أَنْفَقَ مُنْذُ خَلَقَ السَّمَوَاتِ وَالأَرْضَ فَإِنَّهُ لَمْ يَنْقُصْ مَا فِي يَمِينِهِ، وَعَرْشُهُ عَلَى الْمَاءِ وَبِيَدِهِ الأُخْرَى الْفَيْضُ ـ أَوِ الْقَبْضُ ـ يَرْفَعُ وَيَخْفِضُ ‏"‏‏.‏\hadithno{7419}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Right (Hand) of Allah Is full, and (Its fullness) is not affected by the continuous spending night and day. Do you see what He has spent since He created the Heavens and the Earth? Yet all that has not decreased what is in His Right Hand. His Throne is over the water and in His other Hand is the Bounty or the Power to bring about death, and He raises some people and brings others down." (See Hadith No)}}
\hadithdefcmd{bukhari}{7420}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ جَاءَ زَيْدُ بْنُ حَارِثَةَ يَشْكُو فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ اتَّقِ اللَّهَ، وَأَمْسِكْ عَلَيْكَ زَوْجَكَ ‏"‏‏.‏ قَالَتْ عَائِشَةُ لَوْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَاتِمًا شَيْئًا لَكَتَمَ هَذِهِ‏.‏ قَالَ فَكَانَتْ زَيْنَبُ تَفْخَرُ عَلَى أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم تَقُولُ زَوَّجَكُنَّ أَهَالِيكُنَّ، وَزَوَّجَنِي اللَّهُ تَعَالَى مِنْ فَوْقِ سَبْعِ سَمَوَاتٍ‏.‏ وَعَنْ ثَابِتٍ ‏\{‏وَتُخْفِي فِي نَفْسِكَ مَا اللَّهُ مُبْدِيهِ وَتَخْشَى النَّاسَ‏\}‏ نَزَلَتْ فِي شَأْنِ زَيْنَبَ وَزَيْدِ بْنِ حَارِثَةَ‏.‏\hadithno{7420}\hadithtrans{Narrated Anas:Zaid bin Haritha came to the Prophet (ﷺ) complaining about his wife. The Prophet (ﷺ) kept on saying (to him), "Be afraid of Allah and keep your wife." Aisha said, "If Allah's Messenger (ﷺ) were to conceal anything (of the Qur'an he would have concealed this Verse." Zainab used to boast before the wives of the Prophet (ﷺ) and used to say, "You were given in marriage by your families, while I was married (to the Prophet) by Allah from over seven Heavens." And Thabit recited, "The Verse:-- 'But (O Muhammad) you did hide in your heart that which Allah was about to make manifest, you did fear the people,' (33.37) was revealed in connection with Zainab and Zaid bin Haritha}}
\hadithdefcmd{bukhari}{7421}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا عِيسَى بْنُ طَهْمَانَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ نَزَلَتْ آيَةُ الْحِجَابِ فِي زَيْنَبَ بِنْتِ جَحْشٍ وَأَطْعَمَ عَلَيْهَا يَوْمَئِذٍ خُبْزًا وَلَحْمًا وَكَانَتْ تَفْخَرُ عَلَى نِسَاءِ النَّبِيِّ صلى الله عليه وسلم وَكَانَتْ تَقُولُ إِنَّ اللَّهَ أَنْكَحَنِي فِي السَّمَاءِ‏.‏\hadithno{7421}\hadithtrans{Narrated Anas bin Malik:The Verse of Al-Hijab (veiling of women) was revealed in connection with Zainab bint Jahsh. (On the day of her marriage with him) the Prophet (ﷺ) gave a wedding banquet with bread and meat; and she used to boast before other wives of the Prophet (ﷺ) and used to say, "Allah married me (to the Prophet (ﷺ) in the Heavens}}
\hadithdefcmd{bukhari}{7422}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ لَمَّا قَضَى الْخَلْقَ كَتَبَ عِنْدَهُ فَوْقَ عَرْشِهِ إِنَّ رَحْمَتِي سَبَقَتْ غَضَبِي ‏"‏‏.‏\hadithno{7422}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When Allah had finished His creation, He wrote over his Throne: 'My Mercy preceded My Anger}}
\hadithdefcmd{bukhari}{7423}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنِي مُحَمَّدُ بْنُ فُلَيْحٍ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنِي هِلاَلٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ آمَنَ بِاللَّهِ وَرَسُولِهِ، وَأَقَامَ الصَّلاَةَ، وَصَامَ رَمَضَانَ، كَانَ حَقًّا عَلَى اللَّهِ أَنْ يُدْخِلَهُ الْجَنَّةَ هَاجَرَ، فِي سَبِيلِ اللَّهِ، أَوْ جَلَسَ فِي أَرْضِهِ الَّتِي وُلِدَ فِيهَا ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَفَلاَ نُنَبِّئُ النَّاسَ بِذَلِكَ‏.‏ قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ مِائَةَ دَرَجَةٍ أَعَدَّهَا اللَّهُ لِلْمُجَاهِدِينَ فِي سَبِيلِهِ، كُلُّ دَرَجَتَيْنِ مَا بَيْنَهُمَا كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ، فَإِذَا سَأَلْتُمُ اللَّهَ فَسَلُوهُ الْفِرْدَوْسَ، فَإِنَّهُ أَوْسَطُ الْجَنَّةِ وَأَعْلَى الْجَنَّةِ، وَفَوْقَهُ عَرْشُ الرَّحْمَنِ، وَمِنْهُ تَفَجَّرُ أَنْهَارُ الْجَنَّةِ ‏"‏‏.‏\hadithno{7423}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever believes in Allah and His Apostle offers prayers perfectly and fasts (the month of) Ramadan then it is incumbent upon Allah to admit him into Paradise, whether he emigrates for Allah's cause or stays in the land where he was born." They (the companions of the Prophet) said, "O Allah's Messenger (ﷺ)! Should we not inform the people of that?" He said, "There are one-hundred degrees in Paradise which Allah has prepared for those who carry on Jihad in His Cause. The distance between every two degrees is like the distance between the sky and the Earth, so if you ask Allah for anything, ask Him for the Firdaus, for it is the last part of Paradise and the highest part of Paradise, and at its top there is the Throne of Beneficent, and from it gush forth the rivers of Paradise}}
\hadithdefcmd{bukhari}{7424}{حَدَّثَنَا يَحْيَى بْنُ جَعْفَرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ ـ هُوَ التَّيْمِيُّ ـ عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ دَخَلْتُ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ، فَلَمَّا غَرَبَتِ الشَّمْسُ قَالَ ‏"‏ يَا أَبَا ذَرٍّ هَلْ تَدْرِي أَيْنَ تَذْهَبُ هَذِهِ ‏"‏‏.‏ قَالَ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ فَإِنَّهَا تَذْهَبُ تَسْتَأْذِنُ فِي السُّجُودِ فَيُؤْذَنُ لَهَا، وَكَأَنَّهَا قَدْ قِيلَ لَهَا ارْجِعِي مِنْ حَيْثُ جِئْتِ‏.‏ فَتَطْلُعُ مِنْ مَغْرِبِهَا ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏ذَلِكَ مُسْتَقَرٌّ لَهَا‏\}‏ فِي قِرَاءَةِ عَبْدِ اللَّهِ‏.‏\hadithno{7424}\hadithtrans{Narrated Abu Dharr:I entered the mosque while Allah's Messenger (ﷺ) was sitting there. When the sun had set, the Prophet (ﷺ) said, "O Abu Dharr! Do you know where this (sun) goes?" I said, "Allah and His Apostle know best." He said, "It goes and asks permission to prostrate, and it is allowed, and (one day) it, as if being ordered to return whence it came, then it will rise from the west." Then the Prophet (ﷺ) recited, "That: "And the sun runs on its fixed course (for a term decreed)," (36.38) as it is recited by `Abdullah}}
\hadithdefcmd{bukhari}{7425}{حَدَّثَنَا مُوسَى، عَنْ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عُبَيْدِ بْنِ السَّبَّاقِ، أَنَّ زَيْدَ بْنَ ثَابِتٍ،‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ السَّبَّاقِ، أَنَّ زَيْدَ بْنَ ثَابِتٍ، حَدَّثَهُ قَالَ أَرْسَلَ إِلَىَّ أَبُو بَكْرٍ فَتَتَبَّعْتُ الْقُرْآنَ حَتَّى وَجَدْتُ آخِرَ سُورَةِ التَّوْبَةِ مَعَ أَبِي خُزَيْمَةَ الأَنْصَارِيِّ لَمْ أَجِدْهَا مَعَ أَحَدٍ غَيْرِهِ ‏\{‏لَقَدْ جَاءَكُمْ رَسُولٌ مِنْ أَنْفُسِكُمْ‏\}‏ حَتَّى خَاتِمَةِ بَرَاءَةٌ‏.‏ حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، بِهَذَا وَقَالَ مَعَ أَبِي خُزَيْمَةَ الأَنْصَارِيِّ‏.‏\hadithno{7425}\hadithtrans{Narrated Zaid bin Thabit:Abu Bakr sent for me, so I collected the Qur'an till I found the last part of Surat-at-Tauba with Abi Khuza`ima Al-Ansari and did not find it with anybody else. (The Verses are): -- 'Verily, there has come to you an Apostle (Muhammad) from amongst yourselves..(till the end of Surat Bara'a) (i.e., at- Tauba).' (9.128-129) Yunus also narrated as above}}
\hadithdefcmd{bukhari}{7426}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ عِنْدَ الْكَرْبِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ الْعَلِيمُ الْحَلِيمُ لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ الْعَرْشِ الْعَظِيمِ لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ السَّمَوَاتِ وَرَبُّ الأَرْضِ رَبُّ الْعَرْشِ الْكَرِيمِ ‏"‏‏.‏\hadithno{7426}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) used to say at the time of difficulty, 'La ilaha il-lallah Al-`Alimul-Halim. La-ilaha illallah Rabul- Arsh-al-Azim, La ilaha-il-lallah Rabus-Samawati Rab-ul-Ard; wa Rab-ul-Arsh Al- Karim.' (See Hadith No. 356 and 357, Vol)}}
\hadithdefcmd{bukhari}{7428}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ النَّاسُ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ فَإِذَا أَنَا بِمُوسَى آخِذٌ بِقَائِمَةٍ مِنْ قَوَائِمِ الْعَرْشِ ‏"‏‏.‏ وَقَالَ الْمَاجِشُونُ عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ فَأَكُونُ أَوَّلَ مَنْ بُعِثَ فَإِذَا مُوسَى آخِذٌ بِالْعَرْشِ ‏"‏‏.‏\hadithno{7428}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "The people will fall unconscious on the Day of Resurrection, then suddenly I will see Moses holding one of the pillars of the Throne." Abu Huraira said: The Prophet (ﷺ) said, "I will be the first person to be resurrected and will see Moses holding the Throne}}
\hadithdefcmd{bukhari}{7429}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَتَعَاقَبُونَ فِيكُمْ مَلاَئِكَةٌ بِاللَّيْلِ وَمَلاَئِكَةٌ بِالنَّهَارِ، وَيَجْتَمِعُونَ فِي صَلاَةِ الْعَصْرِ وَصَلاَةِ الْفَجْرِ، ثُمَّ يَعْرُجُ الَّذِينَ بَاتُوا فِيكُمْ فَيَسْأَلُهُمْ وَهْوَ أَعْلَمُ بِكُمْ فَيَقُولُ كَيْفَ تَرَكْتُمْ عِبَادِي فَيَقُولُونَ تَرَكْنَاهُمْ وَهُمْ يُصَلُّونَ وَأَتَيْنَاهُمْ وَهُمْ يُصَلُّونَ ‏"‏‏.‏\hadithno{7429}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "(A group of) angels stay with you at night and (another group of) angels by daytime, and both groups gather at the time of the 'Asr and Fajr prayers. Then those angels who have stayed with you overnight, ascend (to Heaven) and Allah asks them (about you) ---- and He knows everything about you. "In what state did you leave My slaves?' The angels reply, 'When we left them, they were praying, and when we reached them they were praying}}
\hadithdefcmd{bukhari}{7430}{وَقَالَ خَالِدُ بْنُ مَخْلَدٍ حَدَّثَنَا سُلَيْمَانُ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ تَصَدَّقَ بِعَدْلِ تَمْرَةٍ مِنْ كَسْبٍ طَيِّبٍ، وَلاَ يَصْعَدُ إِلَى اللَّهِ إِلاَّ الطَّيِّبُ، فَإِنَّ اللَّهَ يَتَقَبَّلُهَا بِيَمِينِهِ، ثُمَّ يُرَبِّيهَا لِصَاحِبِهِ كَمَا يُرَبِّي أَحَدُكُمْ فَلُوَّهُ، حَتَّى تَكُونَ مِثْلَ الْجَبَلِ ‏"‏‏.‏ وَرَوَاهُ وَرْقَاءُ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنْ سَعِيدِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ وَلاَ يَصْعَدُ إِلَى اللَّهِ إِلاَّ الطَّيِّبُ ‏"‏‏.‏\hadithno{7430}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "If somebody gives in charity something equal to a date from his honestly earned money ----for nothing ascends to Allah except good---- then Allah will take it in His Right (Hand) and bring it up for its owner as anyone of you brings up a baby horse, till it becomes like a mountain." Abu Huraira said: The Prophet. said, "Nothing ascends to Allah except good}}
\hadithdefcmd{bukhari}{7431}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو بِهِنَّ عِنْدَ الْكَرْبِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ الْعَظِيمُ الْحَلِيمُ، لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ الْعَرْشِ الْعَظِيمِ، لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ السَّمَوَاتِ وَرَبُّ الْعَرْشِ الْكَرِيمِ ‏"‏‏.‏\hadithno{7431}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) used to say at the time of difficulty, "None has the right to be worshipped but Allah, the Majestic, the Most Forbearing. None has the right to be worshipped but Allah, the Lord of the Tremendous Throne. None has the right to be worshipped but Allah, the Lord of the Heavens and the Lord of the Honourable Throne. (See Hadith No. 357, Vol)}}
\hadithdefcmd{bukhari}{7432}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي نُعْمٍ ـ أَوْ أَبِي نُعْمٍ شَكَّ قَبِيصَةُ ـ عَنْ أَبِي سَعِيدٍ، قَالَ بُعِثَ إِلَى النَّبِيِّ صلى الله عليه وسلم بِذُهَيْبَةٍ فَقَسَمَهَا بَيْنَ أَرْبَعَةٍ‏.‏ وَحَدَّثَنِي إِسْحَاقُ بْنُ نَصْرٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ أَخْبَرَنَا سُفْيَانُ عَنْ أَبِيهِ عَنِ ابْنِ أَبِي نُعْمٍ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَ بَعَثَ عَلِيٌّ وَهْوَ بِالْيَمَنِ إِلَى النَّبِيِّ صلى الله عليه وسلم بِذُهَيْبَةٍ فِي تُرْبَتِهَا، فَقَسَمَهَا بَيْنَ الأَقْرَعِ بْنِ حَابِسٍ الْحَنْظَلِيِّ ثُمَّ أَحَدِ بَنِي مُجَاشِعٍ، وَبَيْنَ عُيَيْنَةَ بْنِ بَدْرٍ الْفَزَارِيِّ، وَبَيْنَ عَلْقَمَةَ بْنِ عُلاَثَةَ الْعَامِرِيِّ ثُمَّ أَحَدِ بَنِي كِلاَبٍ، وَبَيْنَ زَيْدِ الْخَيْلِ الطَّائِيِّ ثُمَّ أَحَدِ بَنِي نَبْهَانَ، فَتَغَضَّبَتْ قُرَيْشٌ وَالأَنْصَارُ فَقَالُوا يُعْطِيهِ صَنَادِيدَ أَهْلِ نَجْدٍ وَيَدَعُنَا قَالَ ‏"‏ إِنَّمَا أَتَأَلَّفُهُمْ ‏"‏‏.‏ فَأَقْبَلَ رَجُلٌ غَائِرُ الْعَيْنَيْنِ، نَاتِئُ الْجَبِينِ، كَثُّ اللِّحْيَةِ، مُشْرِفُ الْوَجْنَتَيْنِ، مَحْلُوقُ الرَّأْسِ فَقَالَ يَا مُحَمَّدُ اتَّقِ اللَّهَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَمَنْ يُطِيعُ اللَّهَ إِذَا عَصَيْتُهُ فَيَأْمَنِّي عَلَى أَهْلِ الأَرْضِ، وَلاَ تَأْمَنُونِي ‏"‏‏.‏ فَسَأَلَ رَجُلٌ مِنَ الْقَوْمِ ـ قَتْلَهُ أُرَاهُ خَالِدَ بْنَ الْوَلِيدِ ـ فَمَنَعَهُ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا وَلَّى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ ضِئْضِئِ هَذَا قَوْمًا يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَنَاجِرَهُمْ، يَمْرُقُونَ مِنَ الإِسْلاَمِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ، يَقْتُلُونَ أَهْلَ الإِسْلاَمِ وَيَدَعُونَ أَهْلَ الأَوْثَانِ، لَئِنْ أَدْرَكْتُهُمْ لأَقْتُلَنَّهُمْ قَتْلَ عَادٍ ‏"‏‏.‏\hadithno{7432}\hadithtrans{Narrated Abu Sa`id Al-Khudri:When `Ali was in Yemen, he sent some gold in its ore to the Prophet. The Prophet (ﷺ) distributed it among Al-Aqra' bin H`Abis Al-Hanzali who belonged to Bani Mujashi, 'Uyaina bin Badr Al-Fazari, 'Alqama bin 'Ulatha Al-`Amiri, who belonged to the Bani Kilab tribe and Zaid AI-Khail at-Ta'i who belonged to Bani Nabhan. So the Quraish and the Ansar became angry and said, "He gives to the chiefs of Najd and leaves us!" The Prophet (ﷺ) said, "I just wanted to attract and unite their hearts (make them firm in Islam)." Then there came a man with sunken eyes, bulging forehead, thick beard, fat raised cheeks, and clean-shaven head, and said, "O Muhammad! Be afraid of Allah! " The Prophet (ﷺ) said, "Who would obey Allah if I disobeyed Him? (Allah). He trusts me over the people of the earth, but you do not trust me?" A man from the people (present then), who, I think, was Khalid bin Al- Walid, asked for permission to kill him, but the Prophet (ﷺ) prevented him. When the man went away, the Prophet said, "Out of the offspring of this man, there will be people who will recite the Qur'an but it will not go beyond their throats, and they will go out of Islam as an arrow goes out through the game, and they will kill the Muslims and leave the idolators. Should I live till they appear, I would kill them as the Killing of the nation of 'Ad}}
\hadithdefcmd{bukhari}{7433}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنْ قَوْلِهِ ‏\{‏وَالشَّمْسُ تَجْرِي لِمُسْتَقَرٍّ لَهَا‏\}‏ قَالَ ‏"‏ مُسْتَقَرُّهَا تَحْتَ الْعَرْشِ ‏"‏‏.‏\hadithno{7433}\hadithtrans{Narrated Abu Dharr:I asked the Prophet (ﷺ) regarding the Verse:--'And the sun runs on its fixed course for a term decreed for it.' (36.28) He said, "Its fixed course is underneath Allah's Throne}}
\hadithdefcmd{bukhari}{7434}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا خَالِدٌ، وَهُشَيْمٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ، قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ نَظَرَ إِلَى الْقَمَرِ لَيْلَةَ الْبَدْرِ قَالَ ‏ "‏ إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ كَمَا تَرَوْنَ هَذَا الْقَمَرَ لاَ تُضَامُّونَ فِي رُؤْيَتِهِ، فَإِنِ اسْتَطَعْتُمْ أَنْ لاَ تُغْلَبُوا عَلَى صَلاَةٍ قَبْلَ طُلُوعِ الشَّمْسِ وَصَلاَةٍ قَبْلَ غُرُوبِ الشَّمْسِ، فَافْعَلُوا ‏"‏‏.‏\hadithno{7434}\hadithtrans{Narrated Jarir:We were sitting with the Prophet (ﷺ) and he looked at the moon on the night of the full-moon and said, "You people will see your Lord as you see this full moon, and you will have no trouble in seeing Him, so if you can avoid missing (through sleep or business, etc.) a prayer before sunrise (Fajr) and a prayer before sunset (`Asr) you must do so." (See Hadith No. 529, Vol)}}
\hadithdefcmd{bukhari}{7435}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا عَاصِمُ بْنُ يُوسُفَ الْيَرْبُوعِيُّ، حَدَّثَنَا أَبُو شِهَابٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ عِيَانًا ‏"‏‏.‏\hadithno{7435}\hadithtrans{Narrated Jarir bin `Abdullah:The Prophet (ﷺ) said, "You will definitely see your Lord with your own eyes}}
\hadithdefcmd{bukhari}{7436}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، حَدَّثَنَا بَيَانُ بْنُ بِشْرٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، حَدَّثَنَا جَرِيرٌ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْبَدْرِ فَقَالَ ‏ "‏ إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ يَوْمَ الْقِيَامَةِ كَمَا تَرَوْنَ هَذَا، لاَ تُضَامُّونَ فِي رُؤْيَتِهِ ‏"‏‏.‏\hadithno{7436}\hadithtrans{Narrated Jarir:Allah's Messenger (ﷺ) came out to us on the night of the full moon and said, "You will see your Lord on the Day of Resurrection as you see this (full moon) and you will have no difficulty in seeing Him}}
\hadithdefcmd{bukhari}{7438}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّاسَ، قَالُوا يَا رَسُولَ اللَّهِ هَلْ نَرَى رَبَّنَا يَوْمَ الْقِيَامَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ تُضَارُّونَ فِي الْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَهَلْ تُضَارُّونَ فِي الشَّمْسِ لَيْسَ دُونَهَا سَحَابٌ ‏"‏‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنَّكُمْ تَرَوْنَهُ كَذَلِكَ، يَجْمَعُ اللَّهُ النَّاسَ يَوْمَ الْقِيَامَةِ فَيَقُولُ مَنْ كَانَ يَعْبُدُ شَيْئًا فَلْيَتَّبِعْهُ‏.‏ فَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الشَّمْسَ الشَّمْسَ، وَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الْقَمَرَ الْقَمَرَ، وَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الطَّوَاغِيتَ الطَّوَاغِيتَ، وَتَبْقَى هَذِهِ الأُمَّةُ فِيهَا شَافِعُوهَا ـ أَوْ مُنَافِقُوهَا شَكَّ إِبْرَاهِيمُ ـ فَيَأْتِيهِمُ اللَّهُ فَيَقُولُ أَنَا رَبُّكُمْ‏.‏ فَيَقُولُونَ هَذَا مَكَانُنَا حَتَّى يَأْتِيَنَا رَبُّنَا فَإِذَا جَاءَنَا رَبُّنَا عَرَفْنَاهُ فَيَأْتِيهِمُ اللَّهُ فِي صُورَتِهِ الَّتِي يَعْرِفُونَ فَيَقُولُ أَنَا رَبُّكُمْ‏.‏ فَيَقُولُونَ أَنْتَ رَبُّنَا‏.‏ فَيَتْبَعُونَهُ وَيُضْرَبُ الصِّرَاطُ بَيْنَ ظَهْرَىْ جَهَنَّمَ، فَأَكُونُ أَنَا وَأُمَّتِي أَوَّلَ مَنْ يُجِيزُهَا، وَلاَ يَتَكَلَّمُ يَوْمَئِذٍ إِلاَّ الرُّسُلُ، وَدَعْوَى الرُّسُلِ يَوْمَئِذٍ اللَّهُمَّ سَلِّمْ سَلِّمْ‏.‏ وَفِي جَهَنَّمَ كَلاَلِيبُ مِثْلُ شَوْكِ السَّعْدَانِ، هَلْ رَأَيْتُمُ السَّعْدَانَ ‏"‏‏.‏ قَالُوا نَعَمْ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنَّهَا مِثْلُ شَوْكِ السَّعْدَانِ، غَيْرَ أَنَّهُ لاَ يَعْلَمُ مَا قَدْرُ عِظَمِهَا إِلاَّ اللَّهُ، تَخْطَفُ النَّاسَ بِأَعْمَالِهِمْ، فَمِنْهُمُ الْمُوبَقُ بَقِيَ بِعَمَلِهِ، أَوِ الْمُوثَقُ بِعَمَلِهِ، وَمِنْهُمُ الْمُخَرْدَلُ أَوِ الْمُجَازَى أَوْ نَحْوُهُ، ثُمَّ يَتَجَلَّى حَتَّى إِذَا فَرَغَ اللَّهُ مِنَ الْقَضَاءِ بَيْنَ الْعِبَادِ وَأَرَادَ أَنْ يُخْرِجَ بِرَحْمَتِهِ مَنْ أَرَادَ مِنْ أَهْلِ النَّارِ أَمَرَ الْمَلاَئِكَةَ أَنْ يُخْرِجُوا مِنَ النَّارِ مَنْ كَانَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا، مِمَّنْ أَرَادَ اللَّهُ أَنْ يَرْحَمَهُ مِمَّنْ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، فَيَعْرِفُونَهُمْ فِي النَّارِ بِأَثَرِ السُّجُودِ، تَأْكُلُ النَّارُ ابْنَ آدَمَ إِلاَّ أَثَرَ السُّجُودِ، حَرَّمَ اللَّهُ عَلَى النَّارِ أَنْ تَأْكُلَ أَثَرَ السُّجُودِ، فَيَخْرُجُونَ مِنَ النَّارِ قَدِ امْتُحِشُوا، فَيُصَبُّ عَلَيْهِمْ مَاءُ الْحَيَاةِ فَيَنْبُتُونَ تَحْتَهُ كَمَا تَنْبُتُ الْحِبَّةُ فِي حَمِيلِ السَّيْلِ، ثُمَّ يَفْرُغُ اللَّهُ مِنَ الْقَضَاءِ بَيْنَ الْعِبَادِ، وَيَبْقَى رَجُلٌ مُقْبِلٌ بِوَجْهِهِ عَلَى النَّارِ هُوَ آخِرُ أَهْلِ النَّارِ دُخُولاً الْجَنَّةَ فَيَقُولُ أَىْ رَبِّ اصْرِفْ وَجْهِي عَنِ النَّارِ، فَإِنَّهُ قَدْ قَشَبَنِي رِيحُهَا وَأَحْرَقَنِي ذَكَاؤُهَا‏.‏ فَيَدْعُو اللَّهَ بِمَا شَاءَ أَنْ يَدْعُوَهُ ثُمَّ يَقُولُ اللَّهُ هَلْ عَسَيْتَ إِنْ أُعْطِيتَ ذَلِكَ أَنْ تَسْأَلَنِي غَيْرَهُ‏.‏ فَيَقُولُ لاَ وَعِزَّتِكَ لاَ أَسْأَلُكَ غَيْرَهُ، وَيُعْطِي رَبَّهُ مِنْ عُهُودٍ وَمَوَاثِيقَ مَا شَاءَ، فَيَصْرِفُ اللَّهُ وَجْهَهُ عَنِ النَّارِ، فَإِذَا أَقْبَلَ عَلَى الْجَنَّةِ وَرَآهَا سَكَتَ مَا شَاءَ اللَّهُ أَنْ يَسْكُتَ ثُمَّ يَقُولُ أَىْ رَبِّ قَدِّمْنِي إِلَى باب الْجَنَّةِ‏.‏ فَيَقُولُ اللَّهُ لَهُ أَلَسْتَ قَدْ أَعْطَيْتَ عُهُودَكَ وَمَوَاثِيقَكَ أَنْ لاَ تَسْأَلَنِي غَيْرَ الَّذِي أُعْطِيتَ أَبَدًا، وَيْلَكَ يَا ابْنَ آدَمَ مَا أَغْدَرَكَ‏.‏ فَيَقُولُ أَىْ رَبِّ‏.‏ وَيَدْعُو اللَّهَ حَتَّى يَقُولَ هَلْ عَسَيْتَ إِنْ أُعْطِيتَ ذَلِكَ أَنْ تَسْأَلَ غَيْرَهُ‏.‏ فَيَقُولُ لاَ وَعِزَّتِكَ لاَ أَسْأَلُكَ غَيْرَهُ، وَيُعْطِي مَا شَاءَ مِنْ عُهُودٍ وَمَوَاثِيقَ، فَيُقَدِّمُهُ إِلَى باب الْجَنَّةِ، فَإِذَا قَامَ إِلَى باب الْجَنَّةِ انْفَهَقَتْ لَهُ الْجَنَّةُ فَرَأَى مَا فِيهَا مِنَ الْحَبْرَةِ وَالسُّرُورِ، فَيَسْكُتُ مَا شَاءَ اللَّهُ أَنْ يَسْكُتَ ثُمَّ يَقُولُ أَىْ رَبِّ أَدْخِلْنِي الْجَنَّةَ‏.‏ فَيَقُولُ اللَّهُ أَلَسْتَ قَدْ أَعْطَيْتَ عُهُودَكَ وَمَوَاثِيقَكَ أَنْ لاَ تَسْأَلَ غَيْرَ مَا أُعْطِيتَ ـ فَيَقُولُ ـ وَيْلَكَ يَا ابْنَ آدَمَ مَا أَغْدَرَكَ‏.‏ فَيَقُولُ أَىْ رَبِّ لاَ أَكُونَنَّ أَشْقَى خَلْقِكَ فَلاَ يَزَالُ يَدْعُو حَتَّى يَضْحَكَ اللَّهُ مِنْهُ فَإِذَا ضَحِكَ مِنْهُ قَالَ لَهُ ادْخُلِ الْجَنَّةَ‏.‏ فَإِذَا دَخَلَهَا قَالَ اللَّهُ لَهُ تَمَنَّهْ‏.‏ فَسَأَلَ رَبَّهُ وَتَمَنَّى حَتَّى إِنَّ اللَّهَ لَيُذَكِّرُهُ يَقُولُ كَذَا وَكَذَا، حَتَّى انْقَطَعَتْ بِهِ الأَمَانِيُّ قَالَ اللَّهُ ذَلِكَ لَكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ عَطَاءُ بْنُ يَزِيدَ وَأَبُو سَعِيدٍ الْخُدْرِيُّ مَعَ أَبِي هُرَيْرَةَ لاَ يَرُدُّ عَلَيْهِ مِنْ حَدِيثِهِ شَيْئًا حَتَّى إِذَا حَدَّثَ أَبُو هُرَيْرَةَ أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ ‏"‏ ذَلِكَ لَكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ الْخُدْرِيُّ ‏"‏ وَعَشَرَةُ أَمْثَالِهِ مَعَهُ ‏"‏‏.‏ يَا أَبَا هُرَيْرَةَ‏.‏ قَالَ أَبُو هُرَيْرَةَ مَا حَفِظْتُ إِلاَّ قَوْلَهُ ‏"‏ ذَلِكَ لَكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ الْخُدْرِيُّ أَشْهَدُ أَنِّي حَفِظْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَوْلَهُ ‏"‏ ذَلِكَ لَكَ وَعَشَرَةُ أَمْثَالِهِ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ فَذَلِكَ الرَّجُلُ آخِرُ أَهْلِ الْجَنَّةِ دُخُولاً الْجَنَّةَ‏.‏\hadithno{7438}\hadithtrans{Narrated 'Ata' bin Yazid Al-Laithi: On the authority of Abu Huraira: The people said, "O Allah's Messenger (ﷺ)! Shall we see our Lord on the Day of Resurrection?" The Prophet (ﷺ) said, "Do you have any difficulty in seeing the moon on a full moon night?" They said, "No, O Allah's Messenger (ﷺ)." He said, "Do you have any difficulty in seeing the sun when there are no clouds?" They said, "No, O Allah's Messenger (ﷺ)." He said, "So you will see Him, like that. Allah will gather all the people on the Day of Resurrection, and say, 'Whoever worshipped something (in the world) should follow (that thing),' so, whoever worshipped the sun will follow the sun, and whoever worshiped the moon will follow the moon, and whoever used to worship certain (other false) deities, he will follow those deities. And there will remain only this nation with its good people (or its hypocrites). (The sub-narrator, Ibrahim is in doubt.) Allah will come to them and say, 'I am your Lord.' They will (deny Him and) say, 'We will stay here till our Lord comes, for when our Lord comes, we will recognize Him.' So Allah will come to them in His appearance which they know, and will say, 'I am your Lord.' They will say, 'You are our Lord,' so they will follow Him. Then a bridge will be laid across Hell (Fire)' I and my followers will be the first ones to go across it and none will speak on that Day except the Apostles. And the invocation of the Apostles on that Day will be, 'O Allah, save! Save!' In Hell (or over The Bridge) there will be hooks like the thorns of As-Sa'dan (thorny plant). Have you seen As-Sa'dan? " They replied, "Yes, O Allah's Messenger (ﷺ)!" He said, "So those hooks look like the thorns of As-Sa'dan, but none knows how big they are except Allah. Those hooks will snap the people away according to their deeds. Some of the people will stay in Hell (be destroyed) because of their (evil) deeds, and some will be cut or torn by the hooks (and fall into Hell) and some will be punished and then relieved. When Allah has finished His Judgments among the people, He will take whomever He will out of Hell through His Mercy. He will then order the angels to take out of the Fire all those who used to worship none but Allah from among those whom Allah wanted to be merciful to and those who testified (in the world) that none has the right to be worshipped but Allah. The angels will recognize them in the Fire by the marks of prostration (on their foreheads), for the Fire will eat up all the human body except the mark caused by prostration as Allah has forbidden the Fire to eat the mark of prostration. They will come out of the (Hell) Fire, completely burnt and then the water of life will be poured over them and they will grow under it as does a seed that comes in the mud of the torrent. Then Allah will finish the judgments among the people, and there will remain one man facing the (Hell) Fire and he will be the last person among the people of Hell to enter Paradise. He will say, 'O my Lord! Please turn my face away from the fire because its air has hurt me and its severe heat has burnt me.' So he will invoke Allah in the way Allah will wish him to invoke, and then Allah will say to him, 'If I grant you that, will you then ask for anything else?' He will reply, 'No, by Your Power, (Honor) I will not ask You for anything else.' He will give his Lord whatever promises and covenants Allah will demand. So Allah will turn his face away from Hell (Fire). When he will face Paradise and will see it, he will remain quiet for as long as Allah will wish him to remain quiet, then he will say, 'O my Lord! Bring me near to the gate of Paradise.' Allah will say to him, 'Didn't you give your promises and covenants that you would never ask for anything more than what you had been given? Woe on you, O Adam's son! How treacherous you are!' He will say, 'O my lord,' and will keep on invoking Allah till He says to him, 'If I give what you are asking, will you then ask for anything else?' He will reply, 'No, by Your (Honor) Power, I will not ask for anything else.' Then he will give covenants and promises to Allah and then Allah will bring him near to the gate of Paradise. When he stands at the gate of Paradise, Paradise will be opened and spread before him, and he will see its splendor and pleasures whereupon he will remain quiet as long as Allah will wish him to remain quiet, and then he will say, O my Lord! Admit me into Paradise.' Allah will say, 'Didn't you give your covenants and promises that you would not ask for anything more than what you had been given?' Allah will say, 'Woe on you, O Adam's son! How treacherous you are! ' The man will say, 'O my Lord! Do not make me the most miserable of Your creation,' and he will keep on invoking Allah till Allah will laugh because of his sayings, and when Allah will laugh because of him, He will say to him, 'Enter Paradise,' and when he will enter it, Allah will say to him, 'Wish for anything.' So he will ask his Lord, and he will wish for a great number of things, for Allah Himself will remind him to wish for certain things by saying, '(Wish for) so-and-so.' When there is nothing more to wish for, Allah will say, 'This is for you, and its equal (is for you) as well." 'Ata' bin Yazid added: Abu Sa'id Al-Khudri who was present with Abu Huraira, did not deny whatever the latter said, but when Abu Huraira said that Allah had said, "That is for you and its equal as well," Abu Sa'id Al-Khudri said, "And ten times as much, O Abu Huraira!" Abu Huraira said, "I do not remember, except his saying, 'That is for you and its equal as well.'" Abu Sa'id Al-Khudri then said, "I testify that I remember the Prophet (ﷺ) saying, 'That is for you, and ten times as much.' ' Abu Huraira then added, "That man will be the last person of the people of Paradise to enter Paradise}}
\hadithdefcmd{bukhari}{7439}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ زَيْدٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ هَلْ نَرَى رَبَّنَا يَوْمَ الْقِيَامَةِ قَالَ ‏"‏ هَلْ تُضَارُونَ فِي رُؤْيَةِ الشَّمْسِ وَالْقَمَرِ إِذَا كَانَتْ صَحْوًا ‏"‏‏.‏ قُلْنَا لاَ‏.‏ قَالَ ‏"‏ فَإِنَّكُمْ لاَ تُضَارُونَ فِي رُؤْيَةِ رَبِّكُمْ يَوْمَئِذٍ، إِلاَّ كَمَا تُضَارُونَ فِي رُؤْيَتِهِمَا ـ ثُمَّ قَالَ ـ يُنَادِي مُنَادٍ لِيَذْهَبْ كُلُّ قَوْمٍ إِلَى مَا كَانُوا يَعْبُدُونَ‏.‏ فَيَذْهَبُ أَصْحَابُ الصَّلِيبِ مَعَ صَلِيبِهِمْ، وَأَصْحَابُ الأَوْثَانِ مَعَ أَوْثَانِهِمْ، وَأَصْحَابُ كُلِّ آلِهَةٍ مَعَ آلِهَتِهِمْ حَتَّى يَبْقَى مَنْ كَانَ يَعْبُدُ اللَّهَ مِنْ بَرٍّ أَوْ فَاجِرٍ، وَغُبَّرَاتٌ مِنْ أَهْلِ الْكِتَابِ، ثُمَّ يُؤْتَى بِجَهَنَّمَ تُعْرَضُ كَأَنَّهَا سَرَابٌ فَيُقَالُ لِلْيَهُودِ مَا كُنْتُمْ تَعْبُدُونَ قَالُوا كُنَّا نَعْبُدُ عُزَيْرَ ابْنَ اللَّهِ‏.‏ فَيُقَالُ كَذَبْتُمْ لَمْ يَكُنْ لِلَّهِ صَاحِبَةٌ وَلاَ وَلَدٌ فَمَا تُرِيدُونَ قَالُوا نُرِيدُ أَنْ تَسْقِيَنَا، فَيُقَالُ اشْرَبُوا فَيَتَسَاقَطُونَ فِي جَهَنَّمَ ثُمَّ يُقَالُ لِلنَّصَارَى مَا كُنْتُمْ تَعْبُدُونَ فَيَقُولُونَ كُنَّا نَعْبُدُ الْمَسِيحَ ابْنَ اللَّهِ‏.‏ فَيُقَالُ كَذَبْتُمْ لَمْ يَكُنْ لِلَّهِ صَاحِبَةٌ وَلاَ وَلَدٌ، فَمَا تُرِيدُونَ فَيَقُولُونَ نُرِيدُ أَنْ تَسْقِيَنَا‏.‏ فَيُقَالُ اشْرَبُوا‏.‏ فَيَتَسَاقَطُونَ حَتَّى يَبْقَى مَنْ كَانَ يَعْبُدُ اللَّهَ مِنْ بَرٍّ أَوْ فَاجِرٍ فَيُقَالُ لَهُمْ مَا يَحْبِسُكُمْ وَقَدْ ذَهَبَ النَّاسُ فَيَقُولُونَ فَارَقْنَاهُمْ وَنَحْنُ أَحْوَجُ مِنَّا إِلَيْهِ الْيَوْمَ وَإِنَّا سَمِعْنَا مُنَادِيًا يُنَادِي لِيَلْحَقْ كُلُّ قَوْمٍ بِمَا كَانُوا يَعْبُدُونَ‏.‏ وَإِنَّمَا نَنْتَظِرُ رَبَّنَا ـ قَالَ ـ فَيَأْتِيهِمُ الْجَبَّارُ‏.‏ فَيَقُولُ أَنَا رَبُّكُمْ‏.‏ فَيَقُولُونَ أَنْتَ رَبُّنَا‏.‏ فَلاَ يُكَلِّمُهُ إِلاَّ الأَنْبِيَاءُ فَيَقُولُ هَلْ بَيْنَكُمْ وَبَيْنَهُ آيَةٌ تَعْرِفُونَهُ فَيَقُولُونَ السَّاقُ‏.‏ فَيَكْشِفُ عَنْ سَاقِهِ فَيَسْجُدُ لَهُ كُلُّ مُؤْمِنٍ، وَيَبْقَى مَنْ كَانَ يَسْجُدُ لِلَّهِ رِيَاءً وَسُمْعَةً، فَيَذْهَبُ كَيْمَا يَسْجُدَ فَيَعُودُ ظَهْرُهُ طَبَقًا وَاحِدًا، ثُمَّ يُؤْتَى بِالْجَسْرِ فَيُجْعَلُ بَيْنَ ظَهْرَىْ جَهَنَّمَ ‏"‏‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ وَمَا الْجَسْرُ قَالَ ‏"‏ مَدْحَضَةٌ مَزِلَّةٌ، عَلَيْهِ خَطَاطِيفُ وَكَلاَلِيبُ وَحَسَكَةٌ مُفَلْطَحَةٌ، لَهَا شَوْكَةٌ عُقَيْفَاءُ تَكُونُ بِنَجْدٍ يُقَالُ لَهَا السَّعْدَانُ، الْمُؤْمِنُ عَلَيْهَا كَالطَّرْفِ وَكَالْبَرْقِ وَكَالرِّيحِ وَكَأَجَاوِيدِ الْخَيْلِ وَالرِّكَابِ، فَنَاجٍ مُسَلَّمٌ وَنَاجٍ مَخْدُوشٌ وَمَكْدُوسٌ فِي نَارِ جَهَنَّمَ، حَتَّى يَمُرَّ آخِرُهُمْ يُسْحَبُ سَحْبًا، فَمَا أَنْتُمْ بِأَشَدَّ لِي مُنَاشَدَةً فِي الْحَقِّ، قَدْ تَبَيَّنَ لَكُمْ مِنَ الْمُؤْمِنِ يَوْمَئِذٍ لِلْجَبَّارِ، وَإِذَا رَأَوْا أَنَّهُمْ قَدْ نَجَوْا فِي إِخْوَانِهِمْ يَقُولُونَ رَبَّنَا إِخْوَانُنَا كَانُوا يُصَلُّونَ مَعَنَا وَيَصُومُونَ مَعَنَا وَيَعْمَلُونَ مَعَنَا‏.‏ فَيَقُولُ اللَّهُ تَعَالَى اذْهَبُوا فَمَنْ وَجَدْتُمْ فِي قَلْبِهِ مِثْقَالَ دِينَارٍ مِنْ إِيمَانٍ فَأَخْرِجُوهُ‏.‏ وَيُحَرِّمُ اللَّهُ صُوَرَهُمْ عَلَى النَّارِ، فَيَأْتُونَهُمْ وَبَعْضُهُمْ قَدْ غَابَ فِي النَّارِ إِلَى قَدَمِهِ وَإِلَى أَنْصَافِ سَاقَيْهِ، فَيُخْرِجُونَ مَنْ عَرَفُوا، ثُمَّ يَعُودُونَ فَيَقُولُ اذْهَبُوا فَمَنْ وَجَدْتُمْ فِي قَلْبِهِ مِثْقَالَ نِصْفِ دِينَارٍ فَأَخْرِجُوهُ‏.‏ فَيُخْرِجُونَ مَنْ عَرَفُوا، ثُمَّ يَعُودُونَ فَيَقُولُ اذْهَبُوا فَمَنْ وَجَدْتُمْ فِي قَلْبِهِ مِثْقَالَ ذَرَّةٍ مِنْ إِيمَانٍ فَأَخْرِجُوهُ‏.‏ فَيُخْرِجُونَ مَنْ عَرَفُوا ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ فَإِنْ لَمْ تُصَدِّقُونِي فَاقْرَءُوا ‏\{‏إِنَّ اللَّهَ لاَ يَظْلِمُ مِثْقَالَ ذَرَّةٍ وَإِنْ تَكُ حَسَنَةً يُضَاعِفْهَا‏\}‏ ‏"‏ فَيَشْفَعُ النَّبِيُّونَ وَالْمَلاَئِكَةُ وَالْمُؤْمِنُونَ فَيَقُولُ الْجَبَّارُ بَقِيَتْ شَفَاعَتِي‏.‏ فَيَقْبِضُ قَبْضَةً مِنَ النَّارِ فَيُخْرِجُ أَقْوَامًا قَدِ امْتُحِشُوا، فَيُلْقَوْنَ فِي نَهَرٍ بِأَفْوَاهِ الْجَنَّةِ يُقَالُ لَهُ مَاءُ الْحَيَاةِ، فَيَنْبُتُونَ فِي حَافَتَيْهِ كَمَا تَنْبُتُ الْحِبَّةُ فِي حَمِيلِ السَّيْلِ، قَدْ رَأَيْتُمُوهَا إِلَى جَانِبِ الصَّخْرَةِ إِلَى جَانِبِ الشَّجَرَةِ، فَمَا كَانَ إِلَى الشَّمْسِ مِنْهَا كَانَ أَخْضَرَ، وَمَا كَانَ مِنْهَا إِلَى الظِّلِّ كَانَ أَبْيَضَ، فَيَخْرُجُونَ كَأَنَّهُمُ اللُّؤْلُؤُ، فَيُجْعَلُ فِي رِقَابِهِمُ الْخَوَاتِيمُ فَيَدْخُلُونَ الْجَنَّةَ فَيَقُولُ أَهْلُ الْجَنَّةِ هَؤُلاَءِ عُتَقَاءُ الرَّحْمَنِ أَدْخَلَهُمُ الْجَنَّةَ بِغَيْرِ عَمَلٍ عَمِلُوهُ وَلاَ خَيْرٍ قَدَّمُوهُ‏.‏ فَيُقَالُ لَهُمْ لَكُمْ مَا رَأَيْتُمْ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏\hadithno{7439}\hadithtrans{Narrated Abu Sa'id Al-Khudri: We said, "O Allah's Messenger (ﷺ)! Shall we see our Lord on the Day of Resurrection?" He said, "Do you have any difficulty in seeing the sun and the moon when the sky is clear?" We said, "No." He said, "So you will have no difficulty in seeing your Lord on that Day as you have no difficulty in seeing the sun and the moon (in a clear sky)." The Prophet then said, "Somebody will then announce, 'Let every nation follow what they used to worship.' So the companions of the cross will go with their cross, and the idolators (will go) with their idols, and the companions of every god (false deities) (will go) with their god, till there remain those who used to worship Allah, both the obedient ones and the mischievous ones, and some of the people of the Scripture. Then Hell will be presented to them as if it were a mirage. Then it will be said to the Jews, "What did you use to worship?' They will reply, 'We used to worship Ezra, the son of Allah.' It will be said to them, 'You are liars, for Allah has neither a wife nor a son. What do you want (now)?' They will reply, 'We want You to provide us with water.' Then it will be said to them 'Drink,' and they will fall down in Hell (instead). Then it will be said to the Christians, 'What did you use to worship?' They will reply, 'We used to worship Messiah, the son of Allah.' It will be said, 'You are liars, for Allah has neither a wife nor a son. What: do you want (now)?' They will say, 'We want You to provide us with water.' It will be said to them, 'Drink,' and they will fall down in Hell (instead). When there remain only those who used to worship Allah (Alone), both the obedient ones and the mischievous ones, it will be said to them, 'What keeps you here when all the people have gone?' They will say, 'We parted with them (in the world) when we were in greater need of them than we are today, we heard the call of one proclaiming, 'Let every nation follow what they used to worship,' and now we are waiting for our Lord.' Then the Almighty will come to them in a shape other than the one which they saw the first time, and He will say, 'I am your Lord,' and they will say, 'You are not our Lord.' And none will speak: to Him then but the Prophets, and then it will be said to them, 'Do you know any sign by which you can recognize Him?' They will say. 'The Shin,' and so Allah will then uncover His Shin whereupon every believer will prostrate before Him and there will remain those who used to prostrate before Him just for showing off and for gaining good reputation. These people will try to prostrate but their backs will be rigid like one piece of a wood (and they will not be able to prostrate). Then the bridge will be laid across Hell." We, the companions of the Prophet (ﷺ) said, "O Allah's Messenger (ﷺ)! What is the bridge?' He said, "It is a slippery (bridge) on which there are clamps and (Hooks like) a thorny seed that is wide at one side and narrow at the other and has thorns with bent ends. Such a thorny seed is found in Najd and is called As-Sa'dan. Some of the believers will cross the bridge as quickly as the wink of an eye, some others as quick as lightning, a strong wind, fast horses or she-camels. So some will be safe without any harm; some will be safe after receiving some scratches, and some will fall down into Hell (Fire). The last person will cross by being dragged (over the bridge)." The Prophet (ﷺ) said, "You (Muslims) cannot be more pressing in claiming from me a right that has been clearly proved to be yours than the believers in interceding with Almighty for their (Muslim) brothers on that Day, when they see themselves safe. They will say, 'O Allah! (Save) our brothers (for they) used to pray with us, fast with us and also do good deeds with us.' Allah will say, 'Go and take out (of Hell) anyone in whose heart you find faith equal to the weight of one (gold) Dinar.' Allah will forbid the Fire to burn the faces of those sinners. They will go to them and find some of them in Hell (Fire) up to their feet, and some up to the middle of their legs. So they will take out those whom they will recognize and then they will return, and Allah will say (to them), 'Go and take out (of Hell) anyone in whose heart you find faith equal to the weight of one half Dinar.' They will take out whomever they will recognize and return, and then Allah will say, 'Go and take out (of Hell) anyone in whose heart you find faith equal to the weight of an atom (or a smallest ant), and so they will take out all those whom they will recognize." Abu Sa'id said: If you do not believe me then read the Holy Verse:-- 'Surely! Allah wrongs not even of the weight of an atom (or a smallest ant) but if there is any good (done) He doubles it.' (4.40) The Prophet added, "Then the prophets and Angels and the believers will intercede, and (last of all) the Almighty (Allah) will say, 'Now remains My Intercession. He will then hold a handful of the Fire from which He will take out some people whose bodies have been burnt, and they will be thrown into a river at the entrance of Paradise, called the water of life. They will grow on its banks, as a seed carried by the torrent grows. You have noticed how it grows beside a rock or beside a tree, and how the side facing the sun is usually green while the side facing the shade is white. Those people will come out (of the River of Life) like pearls, and they will have (golden) necklaces, and then they will enter Paradise whereupon the people of Paradise will say, 'These are the people emancipated by the Beneficent. He has admitted them into Paradise without them having done any good deeds and without sending forth any good (for themselves).' Then it will be said to them, 'For you is what you have seen and its equivalent as well}}
\hadithdefcmd{bukhari}{7440}{وَقَالَ حَجَّاجُ بْنُ مِنْهَالٍ حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ يُحْبَسُ الْمُؤْمِنُونَ يَوْمَ الْقِيَامَةِ حَتَّى يُهِمُّوا بِذَلِكَ فَيَقُولُونَ لَوِ اسْتَشْفَعْنَا إِلَى رَبِّنَا فَيُرِيحُنَا مِنْ مَكَانِنَا‏.‏ فَيَأْتُونَ آدَمَ فَيَقُولُونَ أَنْتَ آدَمُ أَبُو النَّاسِ خَلَقَكَ اللَّهُ بِيَدِهِ وَأَسْكَنَكَ جَنَّتَهُ، وَأَسْجَدَ لَكَ مَلاَئِكَتَهُ، وَعَلَّمَكَ أَسْمَاءَ كُلِّ شَىْءٍ، لِتَشْفَعْ لَنَا عِنْدَ رَبِّكَ حَتَّى يُرِيحَنَا مِنْ مَكَانِنَا هَذَا، قَالَ فَيَقُولُ لَسْتُ هُنَاكُمْ ـ قَالَ وَيَذْكُرُ خَطِيئَتَهُ الَّتِي أَصَابَ أَكْلَهُ مِنَ الشَّجَرَةِ وَقَدْ نُهِيَ عَنْهَا ـ وَلَكِنِ ائْتُوا نُوحًا أَوَّلَ نَبِيٍّ بَعَثَهُ اللَّهُ إِلَى أَهْلِ الأَرْضِ‏.‏ فَيَأْتُونَ نُوحًا فَيَقُولُ لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ خَطِيئَتَهُ الَّتِي أَصَابَ سُؤَالَهُ رَبَّهُ بِغَيْرِ عِلْمٍ ـ وَلَكِنِ ائْتُوا إِبْرَاهِيمَ خَلِيلَ الرَّحْمَنِ‏.‏ قَالَ فَيَأْتُونَ إِبْرَاهِيمَ فَيَقُولُ إِنِّي لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ ثَلاَثَ كَلِمَاتٍ كَذَبَهُنَّ ـ وَلَكِنِ ائْتُوا مُوسَى عَبْدًا آتَاهُ اللَّهُ التَّوْرَاةَ وَكَلَّمَهُ وَقَرَّبَهُ نَجِيًّا‏.‏ قَالَ فَيَأْتُونَ مُوسَى فَيَقُولُ إِنِّي لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ خَطِيئَتَهُ الَّتِي أَصَابَ قَتْلَهُ النَّفْسَ ـ وَلَكِنِ ائْتُوا عِيسَى عَبْدَ اللَّهِ وَرَسُولَهُ وَرُوحَ اللَّهِ وَكَلِمَتَهُ‏.‏ قَالَ فَيَأْتُونَ عِيسَى فَيَقُولُ لَسْتُ هُنَاكُمْ وَلَكِنِ ائْتُوا مُحَمَّدًا صلى الله عليه وسلم عَبْدًا غَفَرَ اللَّهُ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ‏.‏ فَيَأْتُونِي فَأَسْتَأْذِنُ عَلَى رَبِّي فِي دَارِهِ فَيُؤْذَنُ لِي عَلَيْهِ، فَإِذَا رَأَيْتُهُ وَقَعْتُ سَاجِدًا فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي فَيَقُولُ ارْفَعْ مُحَمَّدُ، وَقُلْ يُسْمَعْ، وَاشْفَعْ تُشَفَّعْ، وَسَلْ تُعْطَ ـ قَالَ ـ فَأَرْفَعُ رَأْسِي فَأُثْنِي عَلَى رَبِّي بِثَنَاءٍ وَتَحْمِيدٍ يُعَلِّمُنِيهِ، فَيَحُدُّ لِي حَدًّا فَأَخْرُجُ فَأُدْخِلُهُمُ الْجَنَّةَ ‏"‏‏.‏ قَالَ قَتَادَةُ وَسَمِعْتُهُ أَيْضًا يَقُولُ ‏"‏ فَأَخْرُجُ فَأُخْرِجُهُمْ مِنَ النَّارِ وَأُدْخِلُهُمُ الْجَنَّةَ، ثُمَّ أَعُودُ فَأَسْتَأْذِنُ عَلَى رَبِّي فِي دَارِهِ فَيُؤْذَنُ لِي عَلَيْهِ، فَإِذَا رَأَيْتُهُ وَقَعْتُ سَاجِدًا فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي ثُمَّ يَقُولُ ارْفَعْ مُحَمَّدُ، وَقُلْ يُسْمَعْ، وَاشْفَعْ تُشَفَّعْ، وَسَلْ تُعْطَ ـ قَالَ ـ فَأَرْفَعُ رَأْسِي فَأُثْنِي عَلَى رَبِّي بِثَنَاءٍ وَتَحْمِيدٍ يُعَلِّمُنِيهِ ـ قَالَ ـ ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا فَأَخْرُجُ فَأُدْخِلُهُمُ الْجَنَّةَ ‏"‏‏.‏ قَالَ قَتَادَةُ وَسَمِعْتُهُ يَقُولُ ‏"‏ فَأَخْرُجُ فَأُخْرِجُهُمْ مِنَ النَّارِ وَأُدْخِلُهُمُ الْجَنَّةَ، ثُمَّ أَعُودُ الثَّالِثَةَ فَأَسْتَأْذِنُ عَلَى رَبِّي فِي دَارِهِ فَيُؤْذَنُ لِي عَلَيْهِ، فَإِذَا رَأَيْتُهُ وَقَعْتُ سَاجِدًا فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي ثُمَّ يَقُولُ ارْفَعْ مُحَمَّدُ، وَقُلْ يُسْمَعْ، وَاشْفَعْ تُشَفَّعْ، وَسَلْ تُعْطَهْ ـ قَالَ ـ فَأَرْفَعُ رَأْسِي فَأُثْنِي عَلَى رَبِّي بِثَنَاءٍ وَتَحْمِيدٍ يُعَلِّمُنِيهِ ـ قَالَ ـ ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا فَأَخْرُجُ فَأُدْخِلُهُمُ الْجَنَّةَ ‏"‏‏.‏ قَالَ قَتَادَةُ وَقَدْ سَمِعْتُهُ يَقُولُ ‏"‏ فَأَخْرُجُ فَأُخْرِجُهُمْ مِنَ النَّارِ وَأُدْخِلُهُمُ الْجَنَّةَ، حَتَّى مَا يَبْقَى فِي النَّارِ إِلاَّ مَنْ حَبَسَهُ الْقُرْآنُ أَىْ وَجَبَ عَلَيْهِ الْخُلُودُ ـ قَالَ ـ ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏\{‏عَسَى أَنْ يَبْعَثَكَ رَبُّكَ مَقَامًا مَحْمُودًا‏\}‏ قَالَ وَهَذَا الْمَقَامُ الْمَحْمُودُ الَّذِي وُعِدَهُ نَبِيُّكُمْ صلى الله عليه وسلم ‏"‏‏.‏\hadithno{7440}\hadithtrans{Narrated Anas: The Prophet (ﷺ) said, "The believers will be kept (waiting) on the Day of Resurrection so long that they will become worried and say, "Let us ask somebody to intercede far us with our Lord so that He may relieve us from our place. Then they will go to Adam and say, 'You are Adam, the father of the people. Allah created you with His Own Hand and made you reside in His Paradise and ordered His angels to prostrate before you, and taught you the names of all things will you intercede for us with your Lord so that He may relieve us from this place of ours? Adam will say, 'I am not fit for this undertaking.' He will mention his mistakes he had committed, i.e., his eating off the tree though he had been forbidden to do so. He will add, 'Go to Noah, the first prophet sent by Allah to the people of the Earth.' The people will go to Noah who will say, 'I am not fit for this undertaking' He will mention his mistake which he had done, i.e., his asking his Lord without knowledge.' He will say (to them), 'Go to Abraham, Khalil Ar-Rahman.' They will go to Abraham who will say, 'I am not fit for this undertaking. He would mention three words by which he told a lie, and say (to them). 'Go to Moses, a slave whom Allah gave the Torah and spoke to, directly and brought near Him, for conversation.' They will go to Moses who will say, 'I am not fit for this undertaking. He will mention his mistake he made, i.e., killing a person, and will say (to them), 'Go to Jesus, Allah's slave and His Apostle, and a soul created by Him and His Word.' (Be: And it was.) They will go to Jesus who will say, 'I am not fit for this undertaking but you'd better go to Muhammad the slave whose past and future sins have been forgiven by Allah.' So they will come to me, and I will ask my Lord's permission to enter His House and then I will be permitted. When I see Him I will fall down in prostration before Him, and He will leave me (in prostration) as long as He will, and then He will say, 'O Muhammad, lift up your head and speak, for you will be listened to, and intercede, for your intercession will be accepted, and ask (for anything) for it will be granted:' Then I will raise my head and glorify my Lord with certain praises which He has taught me. Allah will put a limit for me (to intercede for a certain type of people) I will take them out and make them enter Paradise." (Qatada said: I heard Anas saying that), the Prophet (ﷺ) said, "I will go out and take them out of Hell (Fire) and let them enter Paradise, and then I will return and ask my Lord for permission to enter His House and I will be permitted. When I will see Him I will fall down in prostration before Him and He will leave me in prostration as long as He will let me (in that state), and then He will say, 'O Muhammad, raise your head and speak, for you will be listened to, and intercede, for your intercession will be accepted, and ask, your request will be granted.' " The Prophet (ﷺ) added, "So I will raise my head and glorify and praise Him as He has taught me. Then I will intercede and He will put a limit for me (to intercede for a certain type of people). I will take them out and let them enter Paradise." (Qatada added: I heard Anas saying that) the Prophet said, 'I will go out and take them out of Hell (Fire) and let them enter Paradise, and I will return for the third time and will ask my Lord for permission to enter His house, and I will be allowed to enter. When I see Him, I will fall down in prostration before Him, and will remain in prostration as long as He will, and then He will say, 'Raise your head, O Muhammad, and speak, for you will be listened to, and intercede, for your intercession will be accepted, and ask, for your request will be granted.' So I will raise my head and praise Allah as He has taught me and then I will intercede and He will put a limit for me (to intercede for a certain type of people). I will take them out and let them enter Paradise." (Qatada said: I heard Anas saying that) the Prophet (ﷺ) said, "So I will go out and take them out of Hell (Fire) and let them enter Paradise, till none will remain in the Fire except those whom Quran will imprison (i.e., those who are destined for eternal life in the fire)." The narrator then recited the Verse:-- "It may be that your Lord will raise you to a Station of Praise and Glory.' (17.79) The narrator added: This is the Station of Praise and Glory which Allah has promised to your Prophet}}
\hadithdefcmd{bukhari}{7441}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، حَدَّثَنِي عَمِّي، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَرْسَلَ إِلَى الأَنْصَارِ فَجَمَعَهُمْ فِي قُبَّةٍ وَقَالَ لَهُمُ ‏ "‏ اصْبِرُوا حَتَّى تَلْقَوُا اللَّهَ وَرَسُولَهُ، فَإِنِّي عَلَى الْحَوْضِ ‏"‏‏.‏\hadithno{7441}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) sent for the Ansar and gathered them in a tent and said to them, "Be patient till you meet Allah and His Apostle, and I will be on the lake-Tank (Al-Kauthar)}}
\hadithdefcmd{bukhari}{7442}{حَدَّثَنِي ثَابِتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا تَهَجَّدَ مِنَ اللَّيْلِ قَالَ ‏ "‏ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ، أَنْتَ قَيِّمُ السَّمَوَاتِ وَالأَرْضِ، وَلَكَ الْحَمْدُ أَنْتَ رَبُّ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ، وَلَكَ الْحَمْدُ أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ، أَنْتَ الْحَقُّ، وَقَوْلُكَ الْحَقُّ، وَوَعْدُكَ الْحَقُّ، وَلِقَاؤُكَ الْحَقُّ، وَالْجَنَّةُ حَقٌّ، وَالنَّارُ حَقٌّ، وَالسَّاعَةُ حَقٌّ، اللَّهُمَّ لَكَ أَسْلَمْتُ، وَبِكَ آمَنْتُ، وَعَلَيْكَ تَوَكَّلْتُ، وَإِلَيْكَ خَاصَمْتُ، وَبِكَ حَاكَمْتُ، فَاغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ، وَأَسْرَرْتُ وَأَعْلَنْتُ، وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي، لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ قَيْسُ بْنُ سَعْدٍ وَأَبُو الزُّبَيْرِ عَنْ طَاوُسٍ قَيَّامٌ‏.‏ وَقَالَ مُجَاهِدٌ الْقَيُّومُ الْقَائِمُ عَلَى كُلِّ شَىْءٍ‏.‏ وَقَرَأَ عُمَرُ الْقَيَّامُ، وَكِلاَهُمَا مَدْحٌ‏.‏\hadithno{7442}\hadithtrans{Narrated Ibn `Abbas:Whenever the Prophet (ﷺ) offered his Tahajjud prayer, he would say, "O Allah, our Lord! All the praises are for You; You are the Keeper (Establisher or the One Who looks after) of the Heavens and the Earth. All the Praises are for You; You are the Light of the Heavens and the Earth and whatever is therein. You are the Truth, and Your saying is the Truth, and Your promise is the Truth, and the meeting with You is the Truth, and Paradise is the Truth, and the (Hell) Fire is the Truth. O Allah! I surrender myself to You, and believe in You, and I put my trust in You (solely depend upon). And to You I complain of my opponents and with Your Evidence I argue. So please forgive the sins which I have done in the past or I will do in the future, and also those (sins) which I did in secret or in public, and that which You know better than I. None has the right to be worshipped but You}}
\hadithdefcmd{bukhari}{7443}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي الأَعْمَشُ، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ سَيُكَلِّمُهُ رَبُّهُ، لَيْسَ بَيْنَهُ وَبَيْنَهُ تُرْجُمَانٌ وَلاَ حِجَابٌ يَحْجُبُهُ ‏"‏‏.‏\hadithno{7443}\hadithtrans{Narrated `Adi bin Hatim:Allah's Messenger (ﷺ) said, "There will be none among you but his Lord will speak to him, and there will be no interpreter between them nor a screen to screen Him}}
\hadithdefcmd{bukhari}{7444}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، عَنْ أَبِي عِمْرَانَ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ جَنَّتَانِ مِنْ فِضَّةٍ آنِيَتُهُمَا وَمَا فِيهِمَا، وَجَنَّتَانِ مِنْ ذَهَبٍ آنِيَتُهُمَا وَمَا فِيهِمَا، وَمَا بَيْنَ الْقَوْمِ وَبَيْنَ أَنْ يَنْظُرُوا إِلَى رَبِّهِمْ إِلاَّ رِدَاءُ الْكِبْرِ عَلَى وَجْهِهِ فِي جَنَّةِ عَدْنٍ ‏"‏‏.‏\hadithno{7444}\hadithtrans{Narrated `Abdullah bin Qais:The Prophet (ﷺ) said, "(There will be) two Paradises of silver and all the utensils and whatever is therein (will be of silver); and two Paradises of gold, and its utensils and whatever therein (will be of gold), and there will be nothing to prevent the people from seeing their Lord except the Cover of Majesty over His Face in the Paradise of Eden (eternal bliss)}}
\hadithdefcmd{bukhari}{7445}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَبْدُ الْمَلِكُ بْنُ أَعْيَنَ، وَجَامِعُ بْنُ أَبِي رَاشِدٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ اقْتَطَعَ مَالَ امْرِئٍ مُسْلِمٍ بِيَمِينٍ كَاذِبَةٍ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ قَالَ عَبْدُ اللَّهِ ثُمَّ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِصْدَاقَهُ مِنْ كِتَابِ اللَّهِ جَلَّ ذِكْرُهُ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً أُولَئِكَ لاَ خَلاَقَ لَهُمْ فِي الآخِرَةِ وَلاَ يُكَلِّمُهُمُ اللَّهُ‏\}‏ الآيَةَ‏.‏\hadithno{7445}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Whoever takes the property of a Muslim by taking a false oath, will meet Allah Who will be angry with him." Then the Prophet (ﷺ) recited the Verse:-- 'Verily those who purchase a small gain at the cost of Allah's Covenant and their oaths, they shall have no portion in the Hereafter, neither will Allah speak to them, nor look at them}}
\hadithdefcmd{bukhari}{7446}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ يَوْمَ الْقِيَامَةِ وَلاَ يَنْظُرُ إِلَيْهِمْ رَجُلٌ حَلَفَ عَلَى سِلْعَةٍ لَقَدْ أَعْطَى بِهَا أَكْثَرَ مِمَّا أَعْطَى وَهْوَ كَاذِبٌ، وَرَجُلٌ حَلَفَ عَلَى يَمِينٍ كَاذِبَةٍ بَعْدَ الْعَصْرِ لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، وَرَجُلٌ مَنَعَ فَضْلَ مَاءٍ فَيَقُولُ اللَّهُ يَوْمَ الْقِيَامَةِ، الْيَوْمَ أَمْنَعُكَ فَضْلِي، كَمَا مَنَعْتَ فَضْلَ مَا لَمْ تَعْمَلْ يَدَاكَ ‏"‏‏.‏\hadithno{7446}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "(There are) three (types of persons to whom) Allah will neither speak to them on the Day of Resurrections, nor look at them (They are):--(1) a man who takes a false oath that he has been offered for a commodity a price greater than what he has actually been offered; (2) and a man who takes a false oath after the `Asr (prayer) in order to grab the property of a Muslim through it; (3) and a man who forbids others to use the remaining superfluous water. To such a man Allah will say on the Day of Resurrection, 'Today I withhold My Blessings from you as you withheld the superfluous part of that (water) which your hands did not create}}
\hadithdefcmd{bukhari}{7447}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الزَّمَانُ قَدِ اسْتَدَارَ كَهَيْئَتِهِ يَوْمَ خَلَقَ اللَّهُ السَّمَوَاتِ وَالأَرْضَ، السَّنَةُ اثْنَا عَشَرَ شَهْرًا، مِنْهَا أَرْبَعَةٌ حُرُمٌ ثَلاَثٌ مُتَوَالِيَاتٌ ذُو الْقَعَدَةِ وَذُو الْحَجَّةِ وَالْمُحَرَّمُ، وَرَجَبُ مُضَرَ الَّذِي بَيْنَ جُمَادَى وَشَعْبَانَ، أَىُّ شَهْرٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ يُسَمِّيهِ بِغَيْرِ اسْمِهِ قَالَ ‏"‏ أَلَيْسَ ذَا الْحَجَّةِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ أَىُّ بَلَدٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ قَالَ ‏"‏ أَلَيْسَ الْبَلْدَةَ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ فَأَىُّ يَوْمٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ قَالَ ‏"‏ أَلَيْسَ يَوْمَ النَّحْرِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ ـ قَالَ مُحَمَّدٌ وَأَحْسِبُهُ قَالَ وَأَعْرَاضَكُمْ ـ عَلَيْكُمْ حَرَامٌ، كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا، وَسَتَلْقَوْنَ رَبَّكُمْ فَيَسْأَلُكُمْ عَنْ أَعْمَالِكُمْ، أَلاَ فَلاَ تَرْجِعُوا بَعْدِي ضُلاَّلاً، يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ، أَلاَ لِيُبَلِّغِ الشَّاهِدُ الْغَائِبَ، فَلَعَلَّ بَعْضَ مَنْ يَبْلُغُهُ أَنْ يَكُونَ أَوْعَى مِنْ بَعْضِ مَنْ سَمِعَهُ ‏"‏‏.‏ فَكَانَ مُحَمَّدٌ إِذَا ذَكَرَهُ قَالَ صَدَقَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ أَلاَ هَلْ بَلَّغْتُ أَلاَ هَلْ بَلَّغْتُ ‏"‏‏.‏\hadithno{7447}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said, "Time has come back to its original state which it had when Allah created the Heavens and the Earth, the year is twelve months, of which four are sacred; (and out of these four) three are in succession, namely, Dhul-Qa'da, Dhul-Hijja and Muharram, and (the fourth one) Rajab Mudar which is between Jumad (Ath-Tham) and Sha'ban." The Prophet (ﷺ) then asked us, "Which month is this?" We said, "Allah and His Apostle know (it) better." He kept quiet so long that we thought he might call it by another name. Then he said, "Isn't it Dhul-Hijja?" We said, "Yes." He asked "What town is this?" We said, "Allah and His Apostle know (it) better.' Then he kept quiet so long that we thought he might call it by another name. He then said, "Isn't it the (forbidden) town (Mecca)?" We said, "Yes." He asked, "What is the day today?" We said, "Allah and His Apostle know (it) better. Then he kept quiet so long that we thought that he might call it by another name. Then he said, "Isn't it the Day of An-Nahr (slaughtering of sacrifices)?" We said, "Yes." Then he said, "Your blood (lives), your properties," (the sub narrator Muhammad, said: I think he also said): "..and your honor) are as sacred to one another like the sanctity of this Day of yours, in this town of yours, in this month of yours. You shall meet your Lord and He will ask you about your deeds. Beware! Don't go astray after me by striking the necks of one another. Lo! It is incumbent upon those who are present to inform it to those who are absent for perhaps the informed one might comprehend it (understand it) better than some of the present audience." Whenever the sub-narrator Muhammad mentioned that statement, he would say, "The Prophet (ﷺ) said the truth.") And then the Prophet (ﷺ) added, "No doubt! Haven't I conveyed Allah's Message to you! No doubt! Haven't I conveyed Allah's Message to you?}}
\hadithdefcmd{bukhari}{7448}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عَاصِمٌ، عَنْ أَبِي عُثْمَانَ، عَنْ أُسَامَةَ، قَالَ كَانَ ابْنٌ لِبَعْضِ بَنَاتِ النَّبِيِّ صلى الله عليه وسلم يَقْضِي، فَأَرْسَلَتْ إِلَيْهِ أَنْ يَأْتِيَهَا فَأَرْسَلَ ‏"‏ إِنَّ لِلَّهِ مَا أَخَذَ، وَلَهُ مَا أَعْطَى، وَكُلٌّ إِلَى أَجَلٍ مُسَمًّى، فَلْتَصْبِرْ وَلْتَحْتَسِبْ ‏"‏‏.‏ فَأَرْسَلَتْ إِلَيْهِ فَأَقْسَمَتْ عَلَيْهِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقُمْتُ مَعَهُ وَمُعَاذُ بْنُ جَبَلٍ وَأُبَىُّ بْنُ كَعْبٍ وَعُبَادَةُ بْنُ الصَّامِتِ، فَلَمَّا دَخَلْنَا نَاوَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم الصَّبِيَّ وَنَفْسُهُ تَقَلْقَلُ فِي صَدْرِهِ ـ حَسِبْتُهُ قَالَ ـ كَأَنَّهَا شَنَّةٌ، فَبَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ سَعْدُ بْنُ عُبَادَةَ أَتَبْكِي فَقَالَ ‏"‏ إِنَّمَا يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ الرُّحَمَاءَ ‏"‏‏.‏\hadithno{7448}\hadithtrans{Narrated Usama:A son of one of the daughters of the Prophet (ﷺ) was dying, so she sent a person to call the Prophet. He sent (her a message), "What ever Allah takes is for Him, and whatever He gives is for Him, and everything has a limited fixed term (in this world) so she should be patient and hope for Allah's reward." She then sent for him again, swearing that he should come. Allah's Messenger (ﷺ) got up, and so did Mu`adh bin Jabal, Ubai bin Ka`b and 'Ubada bin As-Samit. When he entered (the house), they gave the child to Allah's Messenger (ﷺ) while its breath was disturbed in his chest. (The sub-narrator said: I think he said, "...as if it was a water skin.") Allah's Messenger (ﷺ) started weeping whereupon Sa`d bin 'Ubada said, "Do you weep?" The Prophet (ﷺ) said, "Allah is merciful only to those of His slaves who are merciful (to others)}}
\hadithdefcmd{bukhari}{7449}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اخْتَصَمَتِ الْجَنَّةُ وَالنَّارُ إِلَى رَبِّهِمَا فَقَالَتِ الْجَنَّةُ يَا رَبِّ مَا لَهَا لاَ يَدْخُلُهَا إِلاَّ ضُعَفَاءُ النَّاسِ وَسَقَطُهُمْ‏.‏ وَقَالَتِ النَّارُ ـ يَعْنِي ـ أُوثِرْتُ بِالْمُتَكَبِّرِينَ‏.‏ فَقَالَ اللَّهُ تَعَالَى لِلْجَنَّةِ أَنْتِ رَحْمَتِي‏.‏ وَقَالَ لِلنَّارِ أَنْتِ عَذَابِي أُصِيبُ بِكِ مَنْ أَشَاءُ، وَلِكُلِّ وَاحِدَةٍ مِنْكُمَا مِلْؤُهَا ـ قَالَ ـ فَأَمَّا الْجَنَّةُ فَإِنَّ اللَّهَ لاَ يَظْلِمُ مِنْ خَلْقِهِ أَحَدًا، وَإِنَّهُ يُنْشِئُ لِلنَّارِ مَنْ يَشَاءُ فَيُلْقَوْنَ فِيهَا فَتَقُولُ هَلْ مِنْ مَزِيدٍ‏.‏ ثَلاَثًا، حَتَّى يَضَعَ فِيهَا قَدَمَهُ فَتَمْتَلِئُ وَيُرَدُّ بَعْضُهَا إِلَى بَعْضٍ وَتَقُولُ قَطْ قَطْ قَطْ ‏"‏‏.‏\hadithno{7449}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Paradise and Hell (Fire) quarrelled in the presence of their Lord. Paradise said, 'O Lord! What is wrong with me that only the poor and humble people enter me ?' Hell (Fire) said, I have been favored with the arrogant people.' So Allah said to Paradise, 'You are My Mercy,' and said to Hell, 'You are My Punishment which I inflict upon whom I wish, and I shall fill both of you.'" The Prophet added, "As for Paradise, (it will be filled with good people) because Allah does not wrong any of His created things, and He creates for Hell (Fire) whomever He will, and they will be thrown into it, and it will say thrice, 'Is there any more, till Allah (will put) His Foot over it and it will become full and its sides will come close to each other and it will say, 'Qat! Qat! Qat! (Enough! Enough! Enough)}}
\hadithdefcmd{bukhari}{7450}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيُصِيبَنَّ أَقْوَامًا سَفْعٌ مِنَ النَّارِ بِذُنُوبٍ أَصَابُوهَا عُقُوبَةً، ثُمَّ يُدْخِلُهُمُ اللَّهُ الْجَنَّةَ بِفَضْلِ رَحْمَتِهِ يُقَالُ لَهُمُ الْجَهَنَّمِيُّونَ ‏"‏‏.‏ وَقَالَ هَمَّامٌ حَدَّثَنَا قَتَادَةٌ حَدَّثَنَا أَنَسٌ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7450}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Some people will be scorched by Hell (Fire) as a punishment for sins they have committed, and then Allah will admit them into Paradise by the grant of His Mercy. These people will be called, 'Al-Jahannamiyyin' (the people of Hell)}}
\hadithdefcmd{bukhari}{7451}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ جَاءَ حَبْرٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ إِنَّ اللَّهَ يَضَعُ السَّمَاءَ عَلَى إِصْبَعٍ، وَالأَرْضَ عَلَى إِصْبَعٍ، وَالْجِبَالَ عَلَى إِصْبَعٍ، وَالشَّجَرَ وَالأَنْهَارَ عَلَى إِصْبَعٍ، وَسَائِرَ الْخَلْقِ عَلَى إِصْبَعٍ، ثُمَّ يَقُولُ بِيَدِهِ أَنَا الْمَلِكُ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ ‏\{‏وَمَا قَدَرُوا اللَّهَ حَقَّ قَدْرِهِ‏\}‏‏"‏\hadithno{7451}\hadithtrans{Narrated `Abdullah:A Jewish Rabbi came to Allah's Messenger (ﷺ) and said, "O Muhammad! Allah will put the Heavens on one finger and the earth on one finger, and the trees and the rivers on one finger, and the rest of the creation on one finger, and then will say, pointing out with His Hand, 'I am the King.' "On that Allah's Apostle smiled and said, "No just estimate have they made of Allah such as due to Him}}
\hadithdefcmd{bukhari}{7452}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي شَرِيكُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ فِي بَيْتِ مَيْمُونَةَ لَيْلَةً وَالنَّبِيُّ صلى الله عليه وسلم عِنْدَهَا لأَنْظُرَ كَيْفَ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم بِاللَّيْلِ، فَتَحَدَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ أَهْلِهِ سَاعَةً ثُمَّ رَقَدَ، فَلَمَّا كَانَ ثُلُثُ اللَّيْلِ الآخِرُ أَوْ بَعْضُهُ قَعَدَ فَنَظَرَ إِلَى السَّمَاءِ فَقَرَأَ ‏\{‏إِنَّ فِي خَلْقِ السَّمَوَاتِ وَالأَرْضِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏لأُولِي الأَلْبَابِ‏\}‏ ثُمَّ قَامَ فَتَوَضَّأَ وَاسْتَنَّ، ثُمَّ صَلَّى إِحْدَى عَشْرَةَ رَكْعَةً، ثُمَّ أَذَّنَ بِلاَلٌ بِالصَّلاَةِ فَصَلَّى رَكْعَتَيْنِ، ثُمَّ خَرَجَ فَصَلَّى لِلنَّاسِ الصُّبْحَ‏.‏\hadithno{7452}\hadithtrans{Narrated Ibn `Abbas:Once I stayed overnight at the house of (my aunt ) Maimuna while the Prophet (ﷺ) was with her, to see how was the night prayer of Allah's Apostle Allah's Messenger (ﷺ) talked to his wife for a while and then slept. When it was the last third of the night (or part of it), the Prophet (ﷺ) got up and looked towards the sky and recited the Verse:-- 'Verily! In the creation of the Heavens and the Earth....there are indeed signs for the men of understanding.' (3.190) Then He got up and performed the ablution, brushed his teeth and offered eleven rak`at. Then Bilal pronounced the Adhan whereupon the Prophet (ﷺ) offered a two-rak`at (Sunna) prayer and went out to lead the people in Fajr (morning compulsory congregational prayer)}}
\hadithdefcmd{bukhari}{7453}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَمَّا قَضَى اللَّهُ الْخَلْقَ كَتَبَ عِنْدَهُ فَوْقَ عَرْشِهِ، إِنَّ رَحْمَتِي سَبَقَتْ غَضَبِي ‏"‏‏.‏\hadithno{7453}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When Allah created the creations, He wrote with Him on His Throne: 'My Mercy has preceded My Anger}}
\hadithdefcmd{bukhari}{7454}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الأَعْمَشُ، سَمِعْتُ زَيْدَ بْنَ وَهْبٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ ـ رضى الله عنه ـ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ الصَّادِقُ الْمَصْدُوقُ ‏ "‏ إِنَّ خَلْقَ أَحَدِكُمْ يُجْمَعُ فِي بَطْنِ أُمِّهِ أَرْبَعِينَ يَوْمًا وَأَرْبَعِينَ لَيْلَةً، ثُمَّ يَكُونُ عَلَقَةً مِثْلَهُ، ثُمَّ يَكُونُ مُضْغَةً مِثْلَهُ، ثُمَّ يُبْعَثُ إِلَيْهِ الْمَلَكُ فَيُؤْذَنُ بِأَرْبَعِ كَلِمَاتٍ، فَيَكْتُبُ رِزْقَهُ وَأَجَلَهُ وَعَمَلَهُ وَشَقِيٌّ أَمْ سَعِيدٌ ثُمَّ يَنْفُخُ فِيهِ الرُّوحَ، فَإِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ، حَتَّى لاَ يَكُونُ بَيْنَهَا وَبَيْنَهُ إِلاَّ ذِرَاعٌ، فَيَسْبِقُ عَلَيْهِ الْكِتَابُ، فَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ فَيَدْخُلُ النَّارَ، وَإِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ، حَتَّى مَا يَكُونُ بَيْنَهَا وَبَيْنَهُ إِلاَّ ذِرَاعٌ فَيَسْبِقُ عَلَيْهِ الْكِتَابُ، فَيَعْمَلُ عَمَلَ أَهْلِ الْجَنَّةِ فَيَدْخُلُهَا ‏"‏‏.‏\hadithno{7454}\hadithtrans{Narrated `Abdullah bin Mas`ud:Allah's Messenger (ﷺ) the true and truly inspired, narrated to us, "The creation of everyone of you starts with the process of collecting the material for his body within forty days and forty nights in the womb of his mother. Then he becomes a clot of thick blood for a similar period (40 days) and then he becomes like a piece of flesh for a similar period. Then an angel is sent to him (by Allah) and the angel is allowed (ordered) to write four things; his livelihood, his (date of) death, his deeds, and whether he will be a wretched one or a blessed one (in the Hereafter) and then the soul is breathed into him. So one of you may do (good) deeds characteristic of the people of Paradise so much that there is nothing except a cubit between him and Paradise but then what has been written for him decides his behavior and he starts doing (evil) deeds characteristic of the people of Hell (Fire) and (ultimately) enters Hell (Fire); and one of you may do (evil) deeds characteristic of the people of Hell (Fire) so much so that there is nothing except a cubit between him and Hell (Fire), then what has been written for him decides his behavior and he starts doing (good) deeds characteristic of the people of Paradise and ultimately) enters Paradise." (See Hadith No. 430, Vol)}}
\hadithdefcmd{bukhari}{7455}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا عُمَرُ بْنُ ذَرٍّ، سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ يَا جِبْرِيلُ مَا يَمْنَعُكَ أَنْ تَزُورَنَا أَكْثَرَ مِمَّا تَزُورُنَا ‏"‏‏.‏ فَنَزَلَتْ ‏\{‏وَمَا نَتَنَزَّلُ إِلاَّ بِأَمْرِ رَبِّكَ لَهُ مَا بَيْنَ أَيْدِينَا وَمَا خَلْفَنَا‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏ قَالَ هَذَا كَانَ الْجَوَابَ لِمُحَمَّدٍ صلى الله عليه وسلم‏.‏\hadithno{7455}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "O Gabriel, what prevents you. from visiting us more often than you do?" Then this Verse was revealed:--'And we angels descend not but by Command of your Lord. To Him belongs what is before us and what is behind us..' (19.64) So this was the answer to Muhammad}}
\hadithdefcmd{bukhari}{7456}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنْتُ أَمْشِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَرْثٍ بِالْمَدِينَةِ وَهْوَ مُتَّكِئٌ عَلَى عَسِيبٍ، فَمَرَّ بِقَوْمٍ مِنَ الْيَهُودِ فَقَالَ بَعْضُهُمْ لِبَعْضٍ سَلُوهُ عَنِ الرُّوحِ‏.‏ وَقَالَ بَعْضُهُمْ لاَ تَسْأَلُوهُ عَنِ الرُّوحِ‏.‏ فَسَأَلُوهُ فَقَامَ مُتَوَكِّئًا عَلَى الْعَسِيبِ وَأَنَا خَلْفَهُ، فَظَنَنْتُ أَنَّهُ يُوحَى إِلَيْهِ فَقَالَ ‏\{‏وَيَسْأَلُونَكَ عَنِ الرُّوحِ قُلِ الرُّوحُ مِنْ أَمْرِ رَبِّي وَمَا أُوتِيتُمْ مِنَ الْعِلْمِ إِلاَّ قَلِيلاً‏\}‏ فَقَالَ بَعْضُهُمْ لِبَعْضٍ قَدْ قُلْنَا لَكُمْ لاَ تَسْأَلُوهُ‏.‏\hadithno{7456}\hadithtrans{Narrated `Abdullah:While I was walking with Allah's Messenger (ﷺ) in one of the fields of Medina and he was walking leaning on a stick, he passed a group of Jews. Some of them said to the others, "Ask him (the Prophet) about the spirit." Others said, "Do not ask him." But they asked him and he stood leaning on the stick and I was standing behind him and I thought that he was being divinely inspired. Then he said, "They ask you concerning the spirit say: The spirit, its knowledge is with My Lord. And of knowledge you (O men!) have been given only a little." ...(17.85) On that some of the Jews said to the others, "Didn't we tell you not to ask?}}
\hadithdefcmd{bukhari}{7457}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَكَفَّلَ اللَّهُ لِمَنْ جَاهَدَ فِي سَبِيلِهِ، لاَ يُخْرِجُهُ إِلاَّ الْجِهَادُ فِي سَبِيلِهِ، وَتَصْدِيقُ كَلِمَاتِهِ، بِأَنْ يُدْخِلَهُ الْجَنَّةَ، أَوْ يَرْجِعَهُ إِلَى مَسْكَنِهِ الَّذِي خَرَجَ مِنْهُ، مَعَ مَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏‏.‏\hadithno{7457}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah guarantees to the person who carries out Jihad for His Cause and nothing compelled him to go out but the Jihad in His Cause, and belief in His Words, that He will either admit him into Paradise or return him with his reward or the booty he has earned to his residence from where he went out." (See Hadith No)}}
\hadithdefcmd{bukhari}{7458}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ الرَّجُلُ يُقَاتِلُ حَمِيَّةً وَيُقَاتِلُ شَجَاعَةً وَيُقَاتِلُ رِيَاءً، فَأَىُّ ذَلِكَ فِي سَبِيلِ اللَّهِ قَالَ ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ هِيَ الْعُلْيَا، فَهْوَ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{7458}\hadithtrans{Narrated Abu Musa:A man came to the Prophet (ﷺ) and said, "A man fights for pride and haughtiness another fights for bravery, and another fights for showing off; which of these (cases) is in Allah's Cause?" The Prophet (ﷺ) said, "The one who fights that Allah's Word (Islam) should be superior, fights in Allah's Cause." (See Hadith No. 65, Vol)}}
\hadithdefcmd{bukhari}{7459}{حَدَّثَنَا شِهَابُ بْنُ عَبَّادٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حُمَيْدٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَزَالُ مِنْ أُمَّتِي قَوْمٌ ظَاهِرِينَ عَلَى النَّاسِ، حَتَّى يَأْتِيَهُمْ أَمْرُ اللَّهِ ‏"‏‏.‏\hadithno{7459}\hadithtrans{Narrated Al-Mughira bin Shu`ba:I heard the Prophet (ﷺ) saying, "Some people from my followers will continue to be victorious over others till Allah's Order (The Hour) is established." (See Hadith No)}}
\hadithdefcmd{bukhari}{7460}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ابْنُ جَابِرٍ، حَدَّثَنِي عُمَيْرُ بْنُ هَانِئٍ، أَنَّهُ سَمِعَ مُعَاوِيَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَزَالُ مِنْ أُمَّتِي أُمَّةٌ قَائِمَةٌ بِأَمْرِ اللَّهِ، مَا يَضُرُّهُمْ مَنْ كَذَّبَهُمْ، وَلاَ مَنْ خَالَفَهُمْ، حَتَّى يَأْتِيَ أَمْرُ اللَّهِ وَهُمْ عَلَى ذَلِكَ ‏"‏‏.‏ فَقَالَ مَالِكُ بْنُ يُخَامِرَ سَمِعْتُ مُعَاذًا يَقُولُ وَهُمْ بِالشَّأْمِ‏.‏ فَقَالَ مُعَاوِيَةُ هَذَا مَالِكٌ يَزْعُمُ أَنَّهُ سَمِعَ مُعَاذًا يَقُولُ وَهُمْ بِالشَّأْمِ‏.‏\hadithno{7460}\hadithtrans{Narrated Muawiya:I heard the Prophet (ﷺ) saying, "A group of my followers will keep on following Allah's Laws strictly and they will not be harmed by those who will disbelieve them or stand against them till Allah's Order (The Hour) will come while they will be in that state}}
\hadithdefcmd{bukhari}{7461}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنَا نَافِعُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ وَقَفَ النَّبِيُّ صلى الله عليه وسلم عَلَى مُسَيْلِمَةَ فِي أَصْحَابِهِ فَقَالَ ‏ "‏ لَوْ سَأَلْتَنِي هَذِهِ الْقِطْعَةَ مَا أَعْطَيْتُكَهَا، وَلَنْ تَعْدُوَ أَمْرَ اللَّهِ فِيكَ، وَلَئِنْ أَدْبَرْتَ لَيَعْقِرَنَّكَ اللَّهُ ‏"‏‏.‏\hadithno{7461}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) stood before Musailama (the liar) who was sitting with his companions then, and said to him, "If you ask me for this piece (of palm-leaf stalk), even then I would not give it to you. You cannot avoid what Allah has ordained for you, and if you turn away from Islam, Allah will surely ruin you}}
\hadithdefcmd{bukhari}{7462}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ الْوَاحِدِ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ بَيْنَا أَنَا أَمْشِي، مَعَ النَّبِيِّ صلى الله عليه وسلم فِي بَعْضِ حَرْثِ الْمَدِينَةِ وَهْوَ يَتَوَكَّأُ عَلَى عَسِيبٍ مَعَهُ، فَمَرَرْنَا عَلَى نَفَرٍ مِنَ الْيَهُودِ فَقَالَ بَعْضُهُمْ لِبَعْضٍ سَلُوهُ عَنِ الرُّوحِ‏.‏ فَقَالَ بَعْضُهُمْ لاَ تَسْأَلُوهُ أَنْ يَجِيءَ فِيهِ بِشَىْءٍ تَكْرَهُونَهُ‏.‏ فَقَالَ بَعْضُهُمْ لَنَسْأَلَنَّهُ‏.‏ فَقَامَ إِلَيْهِ رَجُلٌ مِنْهُمْ فَقَالَ يَا أَبَا الْقَاسِمِ مَا الرُّوحُ فَسَكَتَ عَنْهُ النَّبِيُّ صلى الله عليه وسلم فَعَلِمْتُ أَنَّهُ يُوحَى إِلَيْهِ فَقَالَ ‏\{‏وَيَسْأَلُونَكَ عَنِ الرُّوحِ قُلِ الرُّوحُ مِنْ أَمْرِ رَبِّي وَمَا أُوتُوا مِنَ الْعِلْمِ إِلاَّ قَلِيلاً‏\}‏‏.‏ قَالَ الأَعْمَشُ هَكَذَا فِي قِرِاءَتِنَا‏.‏\hadithno{7462}\hadithtrans{Narrated Ibn Mas`ud:While I was walking in company with the Prophet (ﷺ) in one of the fields of Medina, the Prophet (ﷺ) was reclining on a palm leave stalk which he carried with him. We passed by a group of Jews. Some of them said to the others, "Ask him about the spirit." The others said, "Do not ask him, lest he would say something that you hate." Some of them said, "We will ask him." So a man from among them stood up and said, 'O Abal-Qasim! What is the spirit?" The Prophet (ﷺ) kept quiet and I knew that he was being divinely inspired. Then he said: "They ask you concerning the Spirit, Say: The Spirit; its knowledge is with my Lord. And of knowledge you (mankind) have been given only a little}}
\hadithdefcmd{bukhari}{7463}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَكَفَّلَ اللَّهُ لِمَنْ جَاهَدَ فِي سَبِيلِهِ، لاَ يُخْرِجُهُ مِنْ بَيْتِهِ إِلاَّ الْجِهَادُ فِي سَبِيلِهِ، وَتَصْدِيقُ كَلِمَتِهِ أَنْ يُدْخِلَهُ الْجَنَّةَ، أَوْ يَرُدَّهُ إِلَى مَسْكَنِهِ بِمَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏‏.‏\hadithno{7463}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah guarantees (the person who carries out Jihad in His Cause and nothing compelled him to go out but Jihad in His Cause and the belief in His Word) that He will either admit him into Paradise (Martyrdom) or return him with reward or booty he has earned to his residence from where he went out}}
\hadithdefcmd{bukhari}{7464}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَعَوْتُمُ اللَّهَ فَاعْزِمُوا فِي الدُّعَاءِ، وَلاَ يَقُولَنَّ أَحَدُكُمْ إِنْ شِئْتَ فَأَعْطِنِي، فَإِنَّ اللَّهَ لاَ مُسْتَكْرِهَ لَهُ ‏"‏‏.‏\hadithno{7464}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "Whenever anyone of you invoke Allah for something, he should be firm in his asking, and he should not say: 'If You wish, give me...' for none can compel Allah to do something against His Will}}
\hadithdefcmd{bukhari}{7465}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ،‏.‏ وَحَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي أَخِي عَبْدُ الْحَمِيدِ، عَنْ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ أَبِي عَتِيقٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، أَنَّ حُسَيْنَ بْنَ عَلِيٍّ ـ عَلَيْهِمَا السَّلاَمُ ـ أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَرَقَهُ وَفَاطِمَةَ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةً فَقَالَ لَهُمْ ‏"‏ أَلاَ تُصَلُّونَ ‏"‏‏.‏ قَالَ عَلِيٌّ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا أَنْفُسُنَا بِيَدِ اللَّهِ، فَإِذَا شَاءَ أَنْ يَبْعَثَنَا بَعَثَنَا، فَانْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ قُلْتُ ذَلِكَ، وَلَمْ يَرْجِعْ إِلَىَّ شَيْئًا، ثُمَّ سَمِعْتُهُ وَهْوَ مُدْبِرٌ يَضْرِبُ فَخِذَهُ وَيَقُولُ ‏"‏ ‏\{‏وَكَانَ الإِنْسَانُ أَكْثَرَ شَىْءٍ جَدَلاً‏\}‏‏"‏\hadithno{7465}\hadithtrans{Narrated `Ali bin Abi Talib:That one night Allah's Messenger (ﷺ) visited him and Fatima, the daughter of Allah's Messenger (ﷺ) and said to them, "Won 't you offer (night) prayer?.. `Ali added: I said, "O Allah's Messenger (ﷺ)! Our souls are in the Hand of Allah and when He Wishes to bring us to life, He does." Then Allah's Messenger (ﷺ) went away when I said so and he did not give any reply. Then I heard him on leaving while he was striking his thighs, saying, 'But man is, more quarrelsome than anything}}
\hadithdefcmd{bukhari}{7466}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا هِلاَلُ بْنُ عَلِيٍّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْمُؤْمِنِ كَمَثَلِ خَامَةِ الزَّرْعِ، يَفِيءُ وَرَقُهُ مِنْ حَيْثُ أَتَتْهَا الرِّيحُ تُكَفِّئُهَا، فَإِذَا سَكَنَتِ اعْتَدَلَتْ، وَكَذَلِكَ الْمُؤْمِنُ يُكَفَّأُ بِالْبَلاَءِ، وَمَثَلُ الْكَافِرِ كَمَثَلِ الأَرْزَةِ صَمَّاءَ مُعْتَدِلَةً حَتَّى يَقْصِمَهَا اللَّهُ إِذَا شَاءَ ‏"‏‏.‏\hadithno{7466}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The example of a believer is that of a fresh green plant the leaves of which move in whatever direction the wind forces them to move and when the wind becomes still, it stand straight. Such is the similitude of the believer: He is disturbed by calamities (but is like the fresh plant he regains his normal state soon). And the example of a disbeliever is that of a pine tree (which remains) hard and straight till Allah cuts it down when He will." (See Hadith No. 546 and 547, Vol)}}
\hadithdefcmd{bukhari}{7467}{حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ قَائِمٌ عَلَى الْمِنْبَرِ ‏ "‏ إِنَّمَا بَقَاؤُكُمْ فِيمَا سَلَفَ قَبْلَكُمْ مِنَ الأُمَمِ، كَمَا بَيْنَ صَلاَةِ الْعَصْرِ إِلَى غُرُوبِ الشَّمْسِ، أُعْطِيَ أَهْلُ التَّوْرَاةِ التَّوْرَاةَ، فَعَمِلُوا بِهَا حَتَّى انْتَصَفَ النَّهَارُ، ثُمَّ عَجَزُوا، فَأُعْطُوا قِيرَاطًا قِيرَاطًا، ثُمَّ أُعْطِيَ أَهْلُ الإِنْجِيلِ الإِنْجِيلَ، فَعَمِلُوا بِهِ حَتَّى صَلاَةِ الْعَصْرِ، ثُمَّ عَجَزُوا، فَأُعْطُوا قِيرَاطًا قِيرَاطًا، ثُمَّ أُعْطِيتُمُ الْقُرْآنَ فَعَمِلْتُمْ بِهِ حَتَّى غُرُوبِ الشَّمْسِ، فَأُعْطِيتُمْ قِيرَاطَيْنِ قِيرَاطَيْنِ، قَالَ أَهْلُ التَّوْرَاةِ رَبَّنَا هَؤُلاَءِ أَقَلُّ عَمَلاً وَأَكْثَرُ أَجْرًا‏.‏ قَالَ هَلْ ظَلَمْتُكُمْ مِنْ أَجْرِكُمْ مِنْ شَىْءٍ قَالُوا لاَ‏.‏ فَقَالَ فَذَلِكَ فَضْلِي أُوتِيهِ مَنْ أَشَاءُ ‏"‏‏.‏\hadithno{7467}\hadithtrans{Narrated `Abdullah bin `Umar:I heard Allah's Messenger (ﷺ) while he was standing on the pulpit, saying, "The remaining period of your stay (on the earth) in comparison to the nations before you, is like the period between the `Asr prayer and sunset. The people of the Torah were given the Torah and they acted upon it till midday, and then they were worn out and were given for their labor, one Qirat each. Then the people of the Gospel were given the Gospel and they acted upon it till the time of the `Asr prayer, and then they were worn out and were given (for their labor), one Qirat each. Then you people were given the Qur'an and you acted upon it till sunset and so you were given two Qirats each (double the reward of the previous nations)." Then the people of the Torah said, 'O our Lord! These people have done a little labor (much less than we) but have taken a greater reward.' Allah said, 'Have I withheld anything from your reward?' They said, 'No.' Then Allah said, 'That is My Favor which I bestow on whom I wish}}
\hadithdefcmd{bukhari}{7468}{حَدَّثَنَا عَبْدُ اللَّهِ الْمُسْنَدِيُّ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ فَقَالَ ‏ "‏ أُبَايِعُكُمْ عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا، وَلاَ تَسْرِقُوا، وَلاَ تَزْنُوا، وَلاَ تَقْتُلُوا أَوْلاَدَكُمْ، وَلاَ تَأْتُوا بِبُهْتَانٍ تَفْتَرُونَهُ بَيْنَ أَيْدِيكُمْ وَأَرْجُلِكُمْ وَلاَ تَعْصُونِي فِي مَعْرُوفٍ، فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ، وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَأُخِذَ بِهِ فِي الدُّنْيَا فَهْوَ لَهُ كَفَّارَةٌ وَطَهُورٌ، وَمَنْ سَتَرَهُ اللَّهُ فَذَلِكَ إِلَى اللَّهِ إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ غَفَرَ لَهُ ‏"‏‏.‏\hadithno{7468}\hadithtrans{Narrated 'Ubada bin As-Samit:I, along with a group of people, gave the pledge of allegiance to Allah's Messenger (ﷺ). He said, "I take your Pledge on the condition that you (1) will not join partners in worship with Allah, (2) will not steal, (3) will not commit illegal sexual intercourse, (4) will not kill your offspring, (5) will not slander, (6) and will not disobey me when I order you to do good. Whoever among you will abide by his pledge, his reward will be with Allah, and whoever commits any of those sins and receives the punishment in this world, that punishment will be an expiation for his sins and purification; but if Allah screens him, then it will be up to Allah to punish him if He will or excuse Him, if He will}}
\hadithdefcmd{bukhari}{7469}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ نَبِيَّ اللَّهِ سُلَيْمَانَ ـ عَلَيْهِ السَّلاَمُ ـ كَانَ لَهُ سِتُّونَ امْرَأَةً فَقَالَ لأَطُوفَنَّ اللَّيْلَةَ عَلَى نِسَائِي، فَلْتَحْمِلْنَ كُلُّ امْرَأَةٍ وَلْتَلِدْنَ فَارِسًا يُقَاتِلُ فِي سَبِيلِ اللَّهِ، فَطَافَ عَلَى نِسَائِهِ، فَمَا وَلَدَتْ مِنْهُنَّ إِلاَّ امْرَأَةٌ وَلَدَتْ شِقَّ غُلاَمٍ‏.‏ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ سُلَيْمَانُ اسْتَثْنَى لَحَمَلَتْ كُلُّ امْرَأَةٍ مِنْهُنَّ، فَوَلَدَتْ فَارِسًا يُقَاتِلُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{7469}\hadithtrans{Narrated Abu Huraira:Allah's Prophet Solomon who had sixty wives, once said, "Tonight I will have sexual relation (sleep) with all my wives so that each of them will become pregnant and bring forth (a boy who will grow into) a cavalier and will fight in Allah's Cause." So he slept with his wives and none of them (conceived and) delivered (a child) except one who brought a half (body) boy (deformed). Allah's Prophet said, "If Solomon had said; 'If Allah Will,' then each of those women would have delivered a (would-be) cavalier to fight in Allah's Cause." (See Hadith No. 74 A, Vol)}}
\hadithdefcmd{bukhari}{7470}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَى أَعْرَابِيٍّ يَعُودُهُ فَقَالَ ‏"‏ لاَ بَأْسَ عَلَيْكَ طَهُورٌ، إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ قَالَ قَالَ الأَعْرَابِيُّ طَهُورٌ، بَلْ هِيَ حُمَّى تَفُورُ عَلَى شَيْخٍ كَبِيرٍ، تُزِيرُهُ الْقُبُورَ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَنَعَمْ إِذًا ‏"‏‏.‏\hadithno{7470}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) entered upon a sick bedouin in whom he went to visit and said to him, "Don't worry, Tahur (i.e., your illness will be a means of cleansing of your sins), if Allah Will." The bedouin said, "Tahur! No, but it is a fever that is burning in the body of an old man and it will make him visit his grave." The Prophet (ﷺ) said, "Then it is so}}
\hadithdefcmd{bukhari}{7471}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا هُشَيْمٌ، عَنْ حُصَيْنٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، حِينَ نَامُوا عَنِ الصَّلاَةِ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ قَبَضَ أَرْوَاحَكُمْ حِينَ شَاءَ، وَرَدَّهَا حِينَ شَاءَ ‏"‏‏.‏ فَقَضَوْا حَوَائِجَهُمْ وَتَوَضَّئُوا إِلَى أَنْ طَلَعَتِ الشَّمْسُ وَابْيَضَّتْ فَقَامَ فَصَلَّى‏.‏\hadithno{7471}\hadithtrans{Narrated Abu Qatada:When the people slept till so late that they did not offer the (morning) prayer, the Prophet (ﷺ) said, "Allah captured your souls (made you sleep) when He willed, and returned them (to your bodies) when He willed." So the people got up and went to answer the call of nature, performed ablution, till the sun had risen and it had become white, then the Prophet (ﷺ) got up and offered the prayer}}
\hadithdefcmd{bukhari}{7472}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَالأَعْرَجِ،‏.‏ وَحَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ أَبِي عَتِيقٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ اسْتَبَّ رَجُلٌ مِنَ الْمُسْلِمِينَ وَرَجُلٌ مِنَ الْيَهُودِ فَقَالَ الْمُسْلِمُ وَالَّذِي اصْطَفَى مُحَمَّدًا عَلَى الْعَالَمِينَ فِي قَسَمٍ يُقْسِمُ بِهِ، فَقَالَ الْيَهُودِيُّ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْعَالَمِينَ، فَرَفَعَ الْمُسْلِمُ يَدَهُ عِنْدَ ذَلِكَ فَلَطَمَ الْيَهُودِيَّ، فَذَهَبَ الْيَهُودِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِالَّذِي كَانَ مِنْ أَمْرِهِ وَأَمْرِ الْمُسْلِمِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُخَيِّرُونِي عَلَى مُوسَى، فَإِنَّ النَّاسَ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ فَأَكُونُ أَوَّلَ مَنْ يُفِيقُ، فَإِذَا مُوسَى بَاطِشٌ بِجَانِبِ الْعَرْشِ، فَلاَ أَدْرِي أَكَانَ فِيمَنْ صَعِقَ فَأَفَاقَ قَبْلِي أَوْ كَانَ مِمَّنِ اسْتَثْنَى اللَّهُ ‏"‏‏.‏\hadithno{7472}\hadithtrans{Narrated Abu Huraira:"A man from the Muslims and a man from the Jews quarrelled, and the Muslim said, "By Him Who gave superiority to Muhammad over all the people!" The Jew said, "By Him Who gave superiority to Moses over all the people!' On that the Muslim lifted his hand and slapped the Jew. The Jew went to Allah's Messenger (ﷺ) and informed him of all that had happened between him and the Muslim. The Prophet (ﷺ) said, "Do not give me superiority over Moses, for the people will fall unconscious on the Day of Resurrection, I will be the first to regain consciousness and behold, Moses will be standing there, holding the side of the Throne. I will not know whether he has been one of those who have fallen unconscious and then regained consciousness before me, or if he has been one of those exempted by Allah (from falling unconscious)." (See Hadith No. 524, Vol)}}
\hadithdefcmd{bukhari}{7473}{حَدَّثَنَا إِسْحَاقُ بْنُ أَبِي عِيسَى، أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَدِينَةُ يَأْتِيهَا الدَّجَّالُ فَيَجِدُ الْمَلاَئِكَةَ يَحْرُسُونَهَا فَلاَ يَقْرَبُهَا الدَّجَّالُ وَلاَ الطَّاعُونُ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏\hadithno{7473}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "Ad-Dajjal will come to Medina and find the angels guarding it. If Allah will, neither Ad-Dajjal nor plague will be able to come near it}}
\hadithdefcmd{bukhari}{7474}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِكُلِّ نَبِيٍّ دَعْوَةٌ، فَأُرِيدُ إِنْ شَاءَ اللَّهُ أَنْ أَخْتَبِيَ دَعْوَتِي شَفَاعَةً لأُمَّتِي يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{7474}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "For every Prophet there is one invocation which is definitely fulfilled by Allah, and I wish, if Allah will, to keep my that (special) invocation as to be the intercession for my followers on the Day of Resurrection}}
\hadithdefcmd{bukhari}{7475}{حَدَّثَنَا يَسَرَةُ بْنُ صَفْوَانَ بْنِ جَمِيلٍ اللَّخْمِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُنِي عَلَى قَلِيبٍ فَنَزَعْتُ مَا شَاءَ اللَّهُ أَنْ أَنْزِعَ، ثُمَّ أَخَذَهَا ابْنُ أَبِي قُحَافَةَ فَنَزَعَ ذَنُوبًا أَوْ ذَنُوبَيْنِ وَفِي نَزْعِهِ ضَعْفٌ، وَاللَّهُ يَغْفِرُ لَهُ، ثُمَّ أَخَذَهَا عُمَرُ فَاسْتَحَالَتْ غَرْبًا، فَلَمْ أَرَ عَبْقَرِيًّا مِنَ النَّاسِ يَفْرِي فَرِيَّهُ، حَتَّى ضَرَبَ النَّاسُ حَوْلَهُ بِعَطَنٍ ‏"‏‏.‏\hadithno{7475}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "While I was sleeping, I saw myself (in a dream) standing by a well. I drew from it as much water as Allah wished me to draw, and then Ibn Quhafa (Abu Bakr) took the bucket from me and drew one or two buckets, and there was weakness in his drawing----may Allah forgive him! Then `Umar took the bucket which turned into something like a big drum. I had never seen a powerful man among the people working as perfectly and vigorously as he did. (He drew so much water that) the people drank to their satisfaction and watered their camels that knelt down there. (See Hadith No. 16, Vol)}}
\hadithdefcmd{bukhari}{7476}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَتَاهُ السَّائِلُ ـ وَرُبَّمَا قَالَ جَاءَهُ السَّائِلُ ـ أَوْ صَاحِبُ الْحَاجَةِ قَالَ ‏ "‏ اشْفَعُوا فَلْتُؤْجَرُوا، وَيَقْضِي اللَّهُ عَلَى لِسَانِ رَسُولِهِ مَا شَاءَ ‏"‏‏.‏\hadithno{7476}\hadithtrans{Narrated Abu Musa:Whenever a beggar or a person in need of something came to the Prophet (ﷺ) , he used to say (to his companions), "Intercede (for him) and you will be rewarded for that, and Allah will fulfill what He will through His Apostle's tongue}}
\hadithdefcmd{bukhari}{7477}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، سَمِعَ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُلْ أَحَدُكُمُ اللَّهُمَّ اغْفِرْ لِي إِنْ شِئْتَ، ارْحَمْنِي إِنْ شِئْتَ، ارْزُقْنِي إِنْ شِئْتَ، وَلْيَعْزِمْ مَسْأَلَتَهُ، إِنَّهُ يَفْعَلُ مَا يَشَاءُ، لاَ مُكْرِهَ لَهُ ‏"‏‏.‏\hadithno{7477}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "None of you should say: 'O Allah! Forgive me if You wish,' or 'Bestow Your Mercy on me if You wish,' or 'Provide me with means of subsistence if You wish,' but he should be firm in his request, for Allah does what He will and nobody can force Him (to do anything)}}
\hadithdefcmd{bukhari}{7478}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو حَفْصٍ، عَمْرٌو حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ تَمَارَى هُوَ وَالْحُرُّ بْنُ قَيْسِ بْنِ حِصْنٍ الْفَزَارِيُّ فِي صَاحِبِ مُوسَى أَهُوَ خَضِرٌ، فَمَرَّ بِهِمَا أُبَىُّ بْنُ كَعْبٍ الأَنْصَارِيُّ، فَدَعَاهُ ابْنُ عَبَّاسٍ فَقَالَ إِنِّي تَمَارَيْتُ أَنَا وَصَاحِبِي هَذَا فِي صَاحِبِ مُوسَى الَّذِي سَأَلَ السَّبِيلَ إِلَى لُقِيِّهِ، هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ شَأْنَهُ قَالَ نَعَمْ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بَيْنَا مُوسَى فِي مَلإِ بَنِي إِسْرَائِيلَ إِذْ جَاءَهُ رَجُلٌ فَقَالَ هَلْ تَعْلَمُ أَحَدًا أَعْلَمَ مِنْكَ فَقَالَ مُوسَى لاَ‏.‏ فَأُوحِيَ إِلَى مُوسَى بَلَى عَبْدُنَا خَضِرٌ‏.‏ فَسَأَلَ مُوسَى السَّبِيلَ إِلَى لُقِيِّهِ، فَجَعَلَ اللَّهُ لَهُ الْحُوتَ آيَةً وَقِيلَ لَهُ إِذَا فَقَدْتَ الْحُوتَ فَارْجِعْ فَإِنَّكَ سَتَلْقَاهُ‏.‏ فَكَانَ مُوسَى يَتْبَعُ أَثَرَ الْحُوتِ فِي الْبَحْرِ فَقَالَ فَتَى مُوسَى لِمُوسَى أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ وَمَا أَنْسَانِيهِ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ، قَالَ مُوسَى ذَلِكَ مَا كُنَّا نَبْغِي، فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا فَوَجَدَا خَضِرًا، وَكَانَ مِنْ شَأْنِهِمَا مَا قَصَّ اللَّهُ ‏"‏‏.‏\hadithno{7478}\hadithtrans{Narrated Ibn `Abbas:That he differed with Al-Hurr bin Qais bin Hisn Al-Fazari about the companion of Moses, (i.e., whether he was Kha,dir or not). Ubai bin Ka`b Al-Ansari passed by them and Ibn `Abbas called him saying, 'My friend (Hur) and I have differed about Moses' Companion whom Moses asked the way to meet. Did you hear Allah's Messenger (ﷺ) mentioning anything about him?" Ubai said, "Yes, I heard Allah's Apostle saying, "While Moses was sitting in the company of some Israelites a man came to him and asked, 'Do you know Someone who is more learned than you (Moses)?' Moses said, 'No.' So Allah sent the Divine inspiration to Moses:-- 'Yes, Our Slave Khadir is more learned than you' Moses asked Allah how to meet him ( Khadir) So Allah made the fish as a sign for him and it was said to him, 'When you lose the fish, go back (to the place where you lose it) and you will meet him.' So Moses went on looking for the sign of the fish in the sea. The boy servant of Moses (who was accompanying him) said to him, 'Do you remember (what happened) when we betook ourselves to the rock? I did indeed forget to tell you (about) the fish. None but Satan made me forget to tell you about it' (18.63) Moses said: 'That is what we have been seeking." Sa they went back retracing their footsteps. (18.64). So they both found Kadir (there) and then happened what Allah mentioned about them (in the Qur'an)!' (See)}}
\hadithdefcmd{bukhari}{7479}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ،‏.‏ وَقَالَ أَحْمَدُ بْنُ صَالِحٍ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نَنْزِلُ غَدًا إِنْ شَاءَ اللَّهُ بِخَيْفِ بَنِي كِنَانَةَ حَيْثُ تَقَاسَمُوا عَلَى الْكُفْرِ ‏"‏‏.‏ يُرِيدُ الْمُحَصَّبَ‏.‏\hadithno{7479}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If Allah wills, tomorrow we will encamp in Khaif Bani Kinana, the place where the pagans took the oath of Kufr (disbelief) against the Prophet. He meant Al-Muhassab. (See Hadith)}}
\hadithdefcmd{bukhari}{7480}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ حَاصَرَ النَّبِيُّ صلى الله عليه وسلم أَهْلَ الطَّائِفِ فَلَمْ يَفْتَحْهَا فَقَالَ ‏"‏ إِنَّا قَافِلُونَ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ فَقَالَ الْمُسْلِمُونَ نَقْفُلُ وَلَمْ نَفْتَحْ‏.‏ قَالَ ‏"‏ فَاغْدُوا عَلَى الْقِتَالِ ‏"‏‏.‏ فَغَدَوْا فَأَصَابَتْهُمْ جِرَاحَاتٌ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّا قَافِلُونَ غَدًا إِنْ شَاءَ اللَّهُ ‏"‏، فَكَأَنَّ ذَلِكَ أَعْجَبَهُمْ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{7480}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) besieged the people of Ta'if, but he did not conquer it. He said, "Tomorrow, if Allah will, we will return home. On this the Muslims said, "Then we return without conquering it?" He said, 'Then carry on fighting tomorrow." The next day many of them were injured. The Prophet (ﷺ) said, "If Allah will, we will return home tomorrow." It seemed that statement pleased them whereupon Allah's Apostle smiled}}
\hadithdefcmd{bukhari}{7481}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَضَى اللَّهُ الأَمْرَ فِي السَّمَاءِ ضَرَبَتِ الْمَلاَئِكَةُ بِأَجْنِحَتِهَا خُضْعَانًا لِقَوْلِهِ، كَأَنَّهُ سِلْسِلَةٌ عَلَى صَفْوَانٍ ـ قَالَ عَلِيٌّ وَقَالَ غَيْرُهُ صَفَوَانٍ ـ يَنْفُذُهُمْ ذَلِكَ، فَإِذَا فُزِّعَ عَنْ قُلُوبِهِمْ قَالُوا مَاذَا قَالَ رَبُّكُمْ قَالُوا الْحَقَّ وَهُوَ الْعَلِيُّ الْكَبِيرُ ‏"‏‏.‏ قَالَ عَلِيٌّ وَحَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، بِهَذَا‏.‏ قَالَ سُفْيَانُ قَالَ عَمْرٌو سَمِعْتُ عِكْرِمَةَ، حَدَّثَنَا أَبُو هُرَيْرَةَ،‏.‏ قَالَ عَلِيٌّ قُلْتُ لِسُفْيَانَ قَالَ سَمِعْتُ عِكْرِمَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ نَعَمْ‏.‏ قُلْتُ لِسُفْيَانَ إِنَّ إِنْسَانًا رَوَى عَنْ عَمْرٍو عَنْ عِكْرِمَةَ عَنْ أَبِي هُرَيْرَةَ يَرْفَعُهُ أَنَّهُ قَرَأَ فُزِّعَ‏.‏ قَالَ سُفْيَانُ هَكَذَا قَرَأَ عَمْرٌو فَلاَ أَدْرِي سَمِعَهُ هَكَذَا أَمْ لاَ، قَالَ سُفْيَانُ وَهْىَ قِرَاءَتُنَا‏.‏\hadithno{7481}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When Allah ordains something on the Heaven the angels beat with their wings in obedience to His Statement which sounds like that of a chain dragged over a rock. His Statement: "Until when the fear is banished from their hearts, the Angels say, 'What was it that your Lord said?' 'They reply, '(He has said) the Truth. And He is the Most High, The Great}}
\hadithdefcmd{bukhari}{7482}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَذِنَ اللَّهُ لِشَىْءٍ مَا أَذِنَ لِلنَّبِيِّ صلى الله عليه وسلم يَتَغَنَّى بِالْقُرْآنِ ‏"‏‏.‏ وَقَالَ صَاحِبٌ لَهُ يُرِيدُ أَنْ يَجْهَرَ بِهِ‏.‏\hadithno{7482}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah never listens to anything as He listens to the Prophet (ﷺ) reciting Qur'an in a pleasant sweet sounding voice." A companion of Abu Huraira said, "He means, reciting the Qur'an aloud}}
\hadithdefcmd{bukhari}{7483}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَقُولُ اللَّهُ يَا آدَمُ‏.‏ فَيَقُولُ لَبَّيْكَ وَسَعْدَيْكَ‏.‏ فَيُنَادَى بِصَوْتٍ إِنَّ اللَّهَ يَأْمُرُكَ أَنْ تُخْرِجَ مِنْ ذُرِّيَّتِكَ بَعْثًا إِلَى النَّارِ ‏"‏‏.‏\hadithno{7483}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Allah will say (on the Day of Resurrection), 'O Adam!' Adam will reply, 'Labbaik wa Sa`daik! ' Then a loud Voice will be heard (Saying) 'Allah Commands you to take out the mission of the Hell Fire from your offspring}}
\hadithdefcmd{bukhari}{7484}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا غِرْتُ عَلَى امْرَأَةٍ مَا غِرْتُ عَلَى خَدِيجَةَ، وَلَقَدْ أَمَرَهُ رَبُّهُ أَنْ يُبَشِّرَهَا بِبَيْتٍ فِي الْجَنَّةِ‏.‏\hadithno{7484}\hadithtrans{Narrated `Aisha:I never felt so jealous of any woman as I felt of Khadija, for Allah ordered him (the Prophet (ﷺ) ) to give Khadija the glad tidings of a palace in Paradise (for her)}}
\hadithdefcmd{bukhari}{7485}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ ـ هُوَ ابْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ ـ عَنْ أَبِيهِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى إِذَا أَحَبَّ عَبْدًا نَادَى جِبْرِيلَ إِنَّ اللَّهَ قَدْ أَحَبَّ فُلاَنًا فَأَحِبَّهُ فَيُحِبُّهُ جِبْرِيلُ، ثُمَّ يُنَادِي جِبْرِيلُ فِي السَّمَاءِ إِنَّ اللَّهَ قَدْ أَحَبَّ فُلاَنًا فَأَحِبُّوهُ، فَيُحِبُّهُ أَهْلُ السَّمَاءِ وَيُوضَعُ لَهُ الْقَبُولُ فِي أَهْلِ الأَرْضِ ‏"‏‏.‏\hadithno{7485}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If Allah loves a person, He calls Gabriel, saying, 'Allah loves so and so, O Gabriel love him' So Gabriel would love him and then would make an announcement in the Heavens: 'Allah has loved so and-so therefore you should love him also.' So all the dwellers of the Heavens would love him, and then he is granted the pleasure of the people on the earth." (See Hadith No. 66, Vol)}}
\hadithdefcmd{bukhari}{7486}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَتَعَاقَبُونَ فِيكُمْ مَلاَئِكَةٌ بِاللَّيْلِ وَمَلاَئِكَةٌ بِالنَّهَارِ، وَيَجْتَمِعُونَ فِي صَلاَةِ الْعَصْرِ وَصَلاَةِ الْفَجْرِ، ثُمَّ يَعْرُجُ الَّذِينَ بَاتُوا فِيكُمْ فَيَسْأَلُهُمْ وَهْوَ أَعْلَمُ كَيْفَ تَرَكْتُمْ عِبَادِي فَيَقُولُونَ تَرَكْنَاهُمْ وَهُمْ يُصَلُّونَ، وَأَتَيْنَاهُمْ وَهُمْ يُصَلُّونَ ‏"‏‏.‏\hadithno{7486}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There are angels coming to you in succession at night, and others during the day, and they all gather at the time of `Asr and Fajr prayers. Then the angels who have stayed with you overnight ascend (to the heaven) and He (Allah) asks them though He perfectly knows their affairs. 'In what state have you left my slaves?' They say, 'When we left them, they were praying and when we came to them they were praying}}
\hadithdefcmd{bukhari}{7487}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ وَاصِلٍ، عَنِ الْمَعْرُورِ، قَالَ سَمِعْتُ أَبَا ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَتَانِي جِبْرِيلُ فَبَشَّرَنِي أَنَّهُ مَنْ مَاتَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ ‏"‏‏.‏ قُلْتُ وَإِنْ سَرَقَ وَإِنْ زَنَى قَالَ ‏"‏ وَإِنْ سَرَقَ وَإِنْ زَنَى ‏"‏‏.‏\hadithno{7487}\hadithtrans{Narrated Abu Dharr:The Prophet (ﷺ) said, Gabriel came to me and gave me the glad tidings that anyone who died without worshipping anything besides Allah, would enter Paradise. I asked (Gabriel), 'Even if he committed theft, and even if he committed illegal sexual intercourse?' He said, '(Yes), even if he committed theft, and even if he Committed illegal sexual intercourse}}
\hadithdefcmd{bukhari}{7488}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا أَبُو إِسْحَاقَ الْهَمْدَانِيُّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا فُلاَنُ إِذَا أَوَيْتَ إِلَى فِرَاشِكَ فَقُلِ اللَّهُمَّ أَسْلَمْتُ نَفْسِي إِلَيْكَ، وَوَجَّهْتُ وَجْهِي إِلَيْكَ وَفَوَّضْتُ أَمْرِي إِلَيْكَ، وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ، رَغْبَةً وَرَهْبَةً إِلَيْكَ، لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ، آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ، وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ‏.‏ فَإِنَّكَ إِنْ مُتَّ فِي لَيْلَتِكَ مُتَّ عَلَى الْفِطْرَةِ، وَإِنْ أَصْبَحْتَ أَصَبْتَ أَجْرًا ‏"‏‏.‏\hadithno{7488}\hadithtrans{Narrated Al-Bara' bin `Azib:Allah's Messenger (ﷺ) said, "O so-and-so, whenever you go to your bed (for sleeping) say, 'O Allah! I have surrendered myself over to you and have turned my face towards You, and leave all my affairs to You and depend on You and put my trust in You expecting Your reward and fearing Your punishment. There is neither fleeing from You nor refuge but with You. I believe in the Book (Qur'an) which You have revealed and in Your Prophet (Muhammad) whom You have sent.' If you then die on that night, then you will die as a Muslim, and if you wake alive in the morning then you will receive the reward." (See Hadith No. 323, Vol)}}
\hadithdefcmd{bukhari}{7489}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَحْزَابِ ‏ "‏ اللَّهُمَّ مُنْزِلَ الْكِتَابِ، سَرِيعَ الْحِسَابِ، اهْزِمِ الأَحْزَابَ وَزَلْزِلْ بِهِمْ ‏"‏‏.‏ زَادَ الْحُمَيْدِيُّ حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ أَبِي خَالِدٍ، سَمِعْتُ عَبْدَ اللَّهِ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{7489}\hadithtrans{Narrated `Abdullah bin Abi `Aufa:Allah's Messenger (ﷺ) said on the Day of (the battle of) the Clans, "O Allah! The Revealer of the Holy Book, The Quick Taker of Accounts! Defeat the clans and shake them}}
\hadithdefcmd{bukhari}{7490}{حَدَّثَنَا مُسَدَّدٌ، عَنْ هُشَيْمٍ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏ قَالَ أُنْزِلَتْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُتَوَارٍ بِمَكَّةَ، فَكَانَ إِذَا رَفَعَ صَوْتَهُ سَمِعَ الْمُشْرِكُونَ فَسَبُّوا الْقُرْآنَ وَمَنْ أَنْزَلَهُ وَمَنْ جَاءَ بِهِ‏.‏ وَقَالَ اللَّهُ تَعَالَى ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏ لاَ تَجْهَرْ بِصَلاَتِكَ حَتَّى يَسْمَعَ الْمُشْرِكُونَ، وَلاَ تُخَافِتْ بِهَا عَنْ أَصْحَابِكَ فَلاَ تُسْمِعُهُمْ ‏\{‏وَابْتَغِ بَيْنَ ذَلِكَ سَبِيلاً‏\}‏ أَسْمِعْهُمْ وَلاَ تَجْهَرْ حَتَّى يَأْخُذُوا عَنْكَ الْقُرْآنَ‏.‏\hadithno{7490}\hadithtrans{Narrated Ibn `Abbas:(regarding the Verse):-- 'Neither say your prayer aloud, nor say it in a low tone.' (17.110) This Verse was revealed while Allah's Messenger (ﷺ) was hiding himself in Mecca, and when he raised his voice while reciting the Qur'an, the pagans would hear him and abuse the Qur'an and its Revealer and to the one who brought it. So Allah said:-- 'Neither say your prayer aloud, nor say it in a low tone.' (17.110) That is, 'Do not say your prayer so loudly that the pagans can hear you, nor say it in such a low tone that your companions do not hear you.' But seek a middle course between those (extremes), i.e., let your companions hear, but do not relate the Qur'an loudly, so that they may learn it from you}}
\hadithdefcmd{bukhari}{7491}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ تَعَالَى يُؤْذِينِي ابْنُ آدَمَ، يَسُبُّ الدَّهْرَ وَأَنَا الدَّهْرُ، بِيَدِي الأَمْرُ، أُقَلِّبُ اللَّيْلَ وَالنَّهَارَ ‏"‏‏.‏\hadithno{7491}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah said: "The son of Adam hurts Me by abusing Time, for I am Time; in My Hands are all things and I cause the revolution of night and day.' " (See Hadith No. 351, Vol)}}
\hadithdefcmd{bukhari}{7492}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ الصَّوْمُ لِي وَأَنَا أَجْزِي بِهِ يَدَعُ شَهْوَتَهُ وَأَكْلَهُ وَشُرْبَهُ مِنْ أَجْلِي، وَالصَّوْمُ جُنَّةٌ، وَلِلصَّائِمِ فَرْحَتَانِ فَرْحَةٌ حِينَ يُفْطِرُ وَفَرْحَةٌ حِينَ يَلْقَى رَبَّهُ، وَلَخَلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏‏.‏\hadithno{7492}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah said: The Fast is for Me and I will give the reward for it, as he (the one who observes the fast) leaves his sexual desire, food and drink for My Sake. Fasting is a screen (from Hell) and there are two pleasures for a fasting person, one at the time of breaking his fast, and the other at the time when he will meet his Lord. And the smell of the mouth of a fasting person is better in Allah's Sight than the smell of musk." (See Hadith No. 128, Vol)}}
\hadithdefcmd{bukhari}{7493}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا أَيُّوبُ يَغْتَسِلُ عُرْيَانًا خَرَّ عَلَيْهِ رِجْلُ جَرَادٍ مِنْ ذَهَبٍ فَجَعَلَ يَحْثِي فِي ثَوْبِهِ، فَنَادَى رَبُّهُ يَا أَيُّوبُ أَلَمْ أَكُنْ أَغْنَيْتُكَ عَمَّا تَرَى قَالَ بَلَى يَا رَبِّ وَلَكِنْ لاَ غِنَى بِي عَنْ بَرَكَتِكَ ‏"‏‏.‏\hadithno{7493}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Once while Job (Aiyub) was taking a bath in a naked state. Suddenly a great number of gold locusts started falling upon him and he started collecting them in his clothes. His Lord called him, 'O Job! Didn't I make you rich enough to dispense with what you see now?' Job said, 'Yes, O Lord! But I cannot dispense with Your Blessings}}
\hadithdefcmd{bukhari}{7494}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَتَنَزَّلُ رَبُّنَا تَبَارَكَ وَتَعَالَى كُلَّ لَيْلَةٍ إِلَى السَّمَاءِ الدُّنْيَا حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ فَيَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ، مَنْ يَسْأَلُنِي فَأُعْطِيَهُ، مَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ ‏"‏‏.‏\hadithno{7494}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Every night when it is the last third of the night, our Lord, the Superior, the Blessed, descends to the nearest heaven and says: Is there anyone to invoke Me that I may respond to his invocation? Is there anyone to ask Me so that I may grant him his request? Is there anyone asking My forgiveness so that I may forgive him?. " (See Hadith No. 246,Vol)}}
\hadithdefcmd{bukhari}{7496}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ وَبِهَذَا الإِسْنَادِ ‏"‏ قَالَ اللَّهُ أَنْفِقْ أُنْفِقْ عَلَيْكَ ‏"‏‏.‏\hadithno{7496}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "We (Muslims) are the last (to come) but will be the foremost on the Day of Resurrection." The narrators of this Hadith said: Allah said (to man), 'Spend (in charity), for then I will compensate you (generously)}}
\hadithdefcmd{bukhari}{7497}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، فَقَالَ ‏ "‏ هَذِهِ خَدِيجَةُ أَتَتْكَ بِإِنَاءٍ فِيهِ طَعَامٌ أَوْ إِنَاءٍ فِيهِ شَرَابٌ فَأَقْرِئْهَا مِنْ رَبِّهَا السَّلاَمَ وَبَشِّرْهَا بِبَيْتٍ مِنْ قَصَبٍ لاَ صَخَبَ فِيهِ وَلاَ نَصَبَ ‏"‏‏.‏\hadithno{7497}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said that Gabriel said, "Here is Khadija coming to you with a dish of food or a tumbler containing something to drink. Convey to her a greeting from her Lord (Allah) and give her the glad tidings that she will have a palace in Paradise built of Qasab wherein there will be neither any noise nor any fatigue (trouble)." (See Hadith No. 168, Vol)}}
\hadithdefcmd{bukhari}{7498}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ أَعْدَدْتُ لِعِبَادِي الصَّالِحِينَ مَا لاَ عَيْنٌ رَأَتْ، وَلاَ أُذُنٌ سَمِعَتْ، وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ ‏"‏‏.‏\hadithno{7498}\hadithtrans{Narrated Abu Huraira:the Prophet (ﷺ) said, "Allah said, "I have prepared for My righteous slaves (such excellent things) as no eye has ever seen, nor an ear has ever heard nor a human heart can ever think of}}
\hadithdefcmd{bukhari}{7499}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي سُلَيْمَانُ الأَحْوَلُ، أَنَّ طَاوُسًا، أَخْبَرَهُ أَنَّهُ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا تَهَجَّدَ مِنَ اللَّيْلِ قَالَ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ، وَلَكَ الْحَمْدُ أَنْتَ قَيِّمُ السَّمَوَاتِ وَالأَرْضِ، وَلَكَ الْحَمْدُ أَنْتَ رَبُّ السَّمَوَاتِ وَالأَرْضِ، وَمَنْ فِيهِنَّ أَنْتَ الْحَقُّ، وَوَعْدُكَ الْحَقُّ وَقَوْلُكَ الْحَقُّ، وَلِقَاؤُكَ الْحَقُّ، وَالْجَنَّةُ حَقٌّ، وَالنَّارُ حَقٌّ، وَالنَّبِيُّونَ حَقٌّ، وَالسَّاعَةُ حَقٌّ، اللَّهُمَّ لَكَ أَسْلَمْتُ، وَبِكَ آمَنْتُ، وَعَلَيْكَ تَوَكَّلْتُ، وَإِلَيْكَ أَنَبْتُ، وَبِكَ خَاصَمْتُ، وَإِلَيْكَ حَاكَمْتُ، فَاغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ، وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ، أَنْتَ إِلَهِي، لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏‏.‏\hadithno{7499}\hadithtrans{Narrated Ibn `Abbas:Whenever the Prophet (ﷺ) offered the night (Tahajjud) prayer, he used to say, "O Allah! All the Praises are for You; You are the Light of the Heavens and the Earth. And all the Praises are for You; You are the Keeper of the Heavens and the Earth. All the Praises are for You; You are the Lord of the Heavens and the Earth and whatever is therein. You are the Truth, and Your Promise is the Truth, and Your Speech is the Truth, and meeting You is the Truth, and Paradise is the Truth and Hell (Fire) is the Truth and all the prophets are the Truth and the Hour is the Truth. O Allah! I surrender to You, and believe in You, and depend upon You, and repent to You, and in Your cause I fight and with Your orders I rule. So please forgive my past and future sins and those sins which I did in secret or in public. It is You Whom I worship, None has the right to be worshipped except You ." (See Hadith No. 329,Vol)}}
\hadithdefcmd{bukhari}{7500}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ النُّمَيْرِيُّ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ الأَيْلِيُّ، قَالَ سَمِعْتُ الزُّهْرِيَّ، قَالَ سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، وَسَعِيدَ بْنَ الْمُسَيَّبِ، وَعَلْقَمَةَ بْنَ وَقَّاصٍ، وَعُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، عَنْ حَدِيثِ، عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ مَا قَالُوا فَبَرَّأَهَا اللَّهُ مِمَّا قَالُوا ـ وَكُلٌّ حَدَّثَنِي طَائِفَةً مِنَ الْحَدِيثِ الَّذِي حَدَّثَنِي ـ عَنْ عَائِشَةَ قَالَتْ وَلَكِنْ وَاللَّهِ مَا كُنْتُ أَظُنُّ أَنَّ اللَّهَ يُنْزِلُ فِي بَرَاءَتِي وَحْيًا يُتْلَى، وَلَشَأْنِي فِي نَفْسِي كَانَ أَحْقَرَ مِنْ أَنْ يَتَكَلَّمَ اللَّهُ فِيَّ بِأَمْرٍ يُتْلَى، وَلَكِنِّي كُنْتُ أَرْجُو أَنْ يَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّوْمِ رُؤْيَا يُبَرِّئُنِي اللَّهُ بِهَا فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ جَاءُوا بِالإِفْكِ‏\}‏ الْعَشْرَ الآيَاتِ‏.‏\hadithno{7500}\hadithtrans{Narrated `Urwa bin Az-Zubair:Sa`id bin Al-Musaiyab, 'Alqama bin Waqqas and 'Ubaidullah bin `Abdullah regarding the narrating of the forged statement against `Aisha, the wife of the Prophet, when the slanderers said what they said and Allah revealed her innocence. `Aisha said, "But by Allah, I did not think that Allah, (to confirm my innocence), would reveal Divine Inspiration which would be recited, for I consider myself too unimportant to be talked about by Allah through Divine Inspiration revealed for recitation, but I hoped that Allah's Messenger (ﷺ) might have a dream in which Allah would reveal my innocence. So Allah revealed:-- 'Verily! Those who spread the slander are a gang among you...' (The ten Verses in Suratan- Nur)}}
\hadithdefcmd{bukhari}{7501}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَقُولُ اللَّهُ إِذَا أَرَادَ عَبْدِي أَنْ يَعْمَلَ سَيِّئَةً فَلاَ تَكْتُبُوهَا عَلَيْهِ حَتَّى يَعْمَلَهَا، فَإِنْ عَمِلَهَا فَاكْتُبُوهَا بِمِثْلِهَا وَإِنْ تَرَكَهَا مِنْ أَجْلِي فَاكْتُبُوهَا لَهُ حَسَنَةً وَإِذَا أَرَادَ أَنْ يَعْمَلَ حَسَنَةً فَلَمْ يَعْمَلْهَا فَاكْتُبُوهَا لَهُ حَسَنَةً، فَإِنْ عَمِلَهَا فَاكْتُبُوهَا لَهُ بِعَشْرِ أَمْثَالِهَا إِلَى سَبْعِمِائَةٍ ‏"‏‏.‏\hadithno{7501}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah says, 'If My slave intends to do a bad deed then (O Angels) do not write it unless he does it; if he does it, then write it as it is, but if he refrains from doing it for My Sake, then write it as a good deed (in his account). (On the other hand) if he intends to do a good deed, but does not do it, then write a good deed (in his account), and if he does it, then write it for him (in his account) as ten good deeds up to seven-hundred times}}
\hadithdefcmd{bukhari}{7502}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ مُعَاوِيَةَ بْنِ أَبِي مُزَرِّدٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ خَلَقَ اللَّهُ الْخَلْقَ فَلَمَّا فَرَغَ مِنْهُ قَامَتِ الرَّحِمُ فَقَالَ مَهْ‏.‏ قَالَتْ هَذَا مَقَامُ الْعَائِذِ بِكَ مِنَ الْقَطِيعَةِ‏.‏ فَقَالَ أَلاَ تَرْضَيْنَ أَنْ أَصِلَ مَنْ وَصَلَكِ، وَأَقْطَعَ مَنْ قَطَعَكِ قَالَتْ بَلَى يَا رَبِّ‏.‏ قَالَ فَذَلِكِ لَكِ ‏"‏‏.‏ ثُمَّ قَالَ أَبُو هُرَيْرَةَ ‏\{‏فَهَلْ عَسَيْتُمْ إِنْ تَوَلَّيْتُمْ أَنْ تُفْسِدُوا فِي الأَرْضِ وَتُقَطِّعُوا أَرْحَامَكُمْ‏\}‏\hadithno{7502}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah created the creation, and when He finished from His creation the Rahm (womb) got up, and Allah said (to it). "Stop! What do you want? It said; "At this place I seek refuge with You from all those who sever me (i.e. sever the ties of Kinship.)" Allah said: "Would you be pleased that I will keep good relation with the one who will keep good relation with you, and I will sever the relation with the one who will sever the relation with you. It said: 'Yes, 'O my Lord.' Allah said (to it), 'That is for you.'' And then Abu Huraira recited the Verse:-- "Would you then if you were given the authority, do mischief in the land, and sever your ties of kinship}}
\hadithdefcmd{bukhari}{7503}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ صَالِحٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ زَيْدِ بْنِ خَالِدٍ، قَالَ مُطِرَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ قَالَ اللَّهُ أَصْبَحَ مِنْ عِبَادِي كَافِرٌ بِي وَمُؤْمِنٌ بِي ‏"‏‏.‏\hadithno{7503}\hadithtrans{Narrated Zaid bin Khalid:It rained (because of the Prophet's invocation for rain) and the Prophet (ﷺ) said, "Allah said, 'Some of My slaves have become disbelievers in Me, and some others, believers in Me}}
\hadithdefcmd{bukhari}{7504}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ إِذَا أَحَبَّ عَبْدِي لِقَائِي أَحْبَبْتُ لِقَاءَهُ، وَإِذَا كَرِهَ لِقَائِي كَرِهْتُ لِقَاءَهُ ‏"‏‏.‏\hadithno{7504}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, 'If My slaves loves the meeting with Me, I too love the meeting with him; and if he dislikes the meeting with Me, I too dislike the meeting with him.' " (See Hadith No. 514, Vol)}}
\hadithdefcmd{bukhari}{7505}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ أَنَا عِنْدَ ظَنِّ عَبْدِي بِي ‏"‏‏.‏\hadithno{7505}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, 'I am to my slave as he thinks of Me, (i.e. I am able to do for him what he thinks I can do for him). (See Hadith No)}}
\hadithdefcmd{bukhari}{7506}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ رَجُلٌ لَمْ يَعْمَلْ خَيْرًا قَطُّ، فَإِذَا مَاتَ فَحَرِّقُوهُ وَاذْرُوا نِصْفَهُ فِي الْبَرِّ وَنِصْفَهُ فِي الْبَحْرِ فَوَاللَّهِ لَئِنْ قَدَرَ اللَّهُ عَلَيْهِ لَيُعَذِّبَنَّهُ عَذَابًا لاَ يُعَذِّبُهُ أَحَدًا مِنَ الْعَالَمِينَ، فَأَمَرَ اللَّهُ الْبَحْرَ فَجَمَعَ مَا فِيهِ، وَأَمَرَ الْبَرَّ فَجَمَعَ مَا فِيهِ ثُمَّ قَالَ لِمَ فَعَلْتَ قَالَ مِنْ خَشْيَتِكَ، وَأَنْتَ أَعْلَمُ، فَغَفَرَ لَهُ ‏"‏‏.‏\hadithno{7506}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A man who never did any good deed, said that if he died, his family should burn him and throw half the ashes of his burnt body in the earth and the other half in the sea, for by Allah, if Allah should get hold of him, He would inflict such punishment on him as He would not inflict on anybody among the people. But Allah ordered the sea to collect what was in it (of his ashes) and similarly ordered the earth to collect what was in it (of his ashes). Then Allah said (to the recreated man ), 'Why did you do so?' The man replied, 'For being afraid of You, and You know it (very well).' So Allah forgave him}}
\hadithdefcmd{bukhari}{7507}{حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ، سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي عَمْرَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ عَبْدًا أَصَابَ ذَنْبًا ـ وَرُبَّمَا قَالَ أَذْنَبَ ذَنْبًا ـ فَقَالَ رَبِّ أَذْنَبْتُ ـ وَرُبَّمَا قَالَ أَصَبْتُ ـ فَاغْفِرْ لِي فَقَالَ رَبُّهُ أَعَلِمَ عَبْدِي أَنَّ لَهُ رَبًّا يَغْفِرُ الذَّنْبَ وَيَأْخُذُ بِهِ غَفَرْتُ لِعَبْدِي‏.‏ ثُمَّ مَكَثَ مَا شَاءَ اللَّهُ، ثُمَّ أَصَابَ ذَنْبًا أَوْ أَذْنَبَ ذَنْبًا، فَقَالَ رَبِّ أَذْنَبْتُ ـ أَوْ أَصَبْتُ ـ آخَرَ فَاغْفِرْهُ‏.‏ فَقَالَ أَعَلِمَ عَبْدِي أَنَّ لَهُ رَبًّا يَغْفِرُ الذَّنْبَ وَيَأْخُذُ بِهِ غَفَرْتُ لِعَبْدِي، ثُمَّ مَكَثَ مَا شَاءَ اللَّهُ ثُمَّ أَذْنَبَ ذَنْبًا ـ وَرُبَّمَا قَالَ أَصَابَ ذَنْبًا ـ قَالَ قَالَ رَبِّ أَصَبْتُ ـ أَوْ أَذْنَبْتُ ـ آخَرَ فَاغْفِرْهُ لِي‏.‏ فَقَالَ أَعَلِمَ عَبْدِي أَنَّ لَهُ رَبًّا يَغْفِرُ الذَّنْبَ وَيَأْخُذُ بِهِ غَفَرْتُ لِعَبْدِي ـ ثَلاَثًا ـ فَلْيَعْمَلْ مَا شَاءَ ‏"‏‏.‏\hadithno{7507}\hadithtrans{Narrated Abu Huraira:I heard the Prophet (ﷺ) saying, "If somebody commits a sin and then says, 'O my Lord! I have sinned, please forgive me!' and his Lord says, 'My slave has known that he has a Lord who forgives sins and punishes for it, I therefore have forgiven my slave (his sins).' Then he remains without committing any sin for a while and then again commits another sin and says, 'O my Lord, I have committed another sin, please forgive me,' and Allah says, 'My slave has known that he has a Lord who forgives sins and punishes for it, I therefore have forgiven my slave (his sin). Then he remains without Committing any another sin for a while and then commits another sin (for the third time) and says, 'O my Lord, I have committed another sin, please forgive me,' and Allah says, 'My slave has known that he has a Lord Who forgives sins and punishes for it I therefore have forgiven My slave (his sin), he can do whatever he likes}}
\hadithdefcmd{bukhari}{7508}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا مُعْتَمِرٌ، سَمِعْتُ أَبِي، حَدَّثَنَا قَتَادَةُ، عَنْ عُقْبَةَ بْنِ عَبْدِ الْغَافِرِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ أَنَّهُ ذَكَرَ رَجُلاً فِيمَنْ سَلَفَ ـ أَوْ فِيمَنْ كَانَ قَبْلَكُمْ قَالَ كَلِمَةً يَعْنِي ـ أَعْطَاهُ اللَّهُ مَالاً وَوَلَدًا ـ فَلَمَّا حَضَرَتِ الْوَفَاةُ قَالَ لِبَنِيهِ أَىَّ أَبٍ كُنْتُ لَكُمْ قَالُوا خَيْرَ أَبٍ‏.‏ قَالَ فَإِنَّهُ لَمْ يَبْتَئِرْ ـ أَوْ لَمْ يَبْتَئِزْ ـ عِنْدَ اللَّهِ خَيْرًا، وَإِنْ يَقْدِرِ اللَّهُ عَلَيْهِ يُعَذِّبْهُ، فَانْظُرُوا إِذَا مُتُّ فَأَحْرِقُونِي حَتَّى إِذَا صِرْتُ فَحْمًا فَاسْحَقُونِي ـ أَوْ قَالَ فَاسْحَكُونِي ـ فَإِذَا كَانَ يَوْمُ رِيحٍ عَاصِفٍ فَأَذْرُونِي فِيهَا ‏"‏ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَخَذَ مَوَاثِيقَهُمْ عَلَى ذَلِكَ وَرَبِّي، فَفَعَلُوا ثُمَّ أَذْرَوْهُ فِي يَوْمٍ عَاصِفٍ، فَقَالَ اللَّهُ عَزَّ وَجَلَّ كُنْ‏.‏ فَإِذَا هُوَ رَجُلٌ قَائِمٌ‏.‏ قَالَ اللَّهُ أَىْ عَبْدِي مَا حَمَلَكَ عَلَى أَنْ فَعَلْتَ مَا فَعَلْتَ قَالَ مَخَافَتُكَ أَوْ فَرَقٌ مِنْكَ قَالَ فَمَا تَلاَفَاهُ أَنْ رَحِمَهُ عِنْدَهَا ـ وَقَالَ مَرَّةً أُخْرَى فَمَا تَلاَفَاهُ غَيْرُهَا ـ ‏"‏‏.‏ فَحَدَّثْتُ بِهِ أَبَا عُثْمَانَ فَقَالَ سَمِعْتُ هَذَا مِنْ سَلْمَانَ غَيْرَ أَنَّهُ زَادَ فِيهِ أَذْرُونِي فِي الْبَحْرِ‏.‏ أَوْ كَمَا حَدَّثَ‏.‏ حَدَّثَنَا مُوسَى، حَدَّثَنَا مُعْتَمِرٌ، وَقَالَ، لَمْ يَبْتَئِرْ‏.‏ وَقَالَ خَلِيفَةُ حَدَّثَنَا مُعْتَمِرٌ، وَقَالَ، لَمْ يَبْتَئِزْ‏.‏ فَسَّرَهُ قَتَادَةُ لَمْ يَدَّخِرْ‏.‏\hadithno{7508}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) mentioned a man from the people of the past or those who preceded you. The Prophet (ﷺ) said a sentence meaning: Allah had given him wealth and children. When his death approached, he said to his sons, "What kind of father have I been to you?" They replied, "You have been a good father." He told them that he had not presented any good deed before Allah, and if Allah should get hold of him He would punish him.' "So look!" he added, "When I die, burn me, and when I turn into coal, crush me, and when there comes a windy day, scatter my ashes in the wind." The Prophet (ﷺ) added, "Then by Allah, he took a firm promise from his children to do so, and they did so. (They burnt him after his death) and threw his ashes on a windy day. Then Allah commanded to his ashes. "Be," and behold! He became a man standing! Allah said, "O My slave! What made you do what you did?" He replied, "For fear of You." Nothing saved him then but Allah's Mercy (So Allah forgave him)}}
\hadithdefcmd{bukhari}{7509}{حَدَّثَنَا يُوسُفُ بْنُ رَاشِدٍ، حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا كَانَ يَوْمُ الْقِيَامَةِ شُفِّعْتُ، فَقُلْتُ يَا رَبِّ أَدْخِلِ الْجَنَّةَ مَنْ كَانَ فِي قَلْبِهِ خَرْدَلَةٌ‏.‏ فَيَدْخُلُونَ، ثُمَّ أَقُولُ أَدْخِلِ الْجَنَّةَ مَنْ كَانَ فِي قَلْبِهِ أَدْنَى شَىْءٍ ‏"‏‏.‏ فَقَالَ أَنَسٌ كَأَنِّي أَنْظُرُ إِلَى أَصَابِعِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{7509}\hadithtrans{Narrated Anas:I heard the Prophet (ﷺ) saying, "On the Day of Resurrection I will intercede and say, "O my Lord! Admit into Paradise (even) those who have faith equal to a mustard seed in their hearts." Such people will enter Paradise, and then I will say, 'O (Allah) admit into Paradise (even) those who have the least amount of faith in their hearts." Anas then said: As if I were just now looking at the fingers of Allah's Apostle}}
\hadithdefcmd{bukhari}{7510}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا مَعْبَدُ بْنُ هِلاَلٍ الْعَنَزِيُّ، قَالَ اجْتَمَعْنَا نَاسٌ مِنْ أَهْلِ الْبَصْرَةِ فَذَهَبْنَا إِلَى أَنَسِ بْنِ مَالِكٍ وَذَهَبْنَا مَعَنَا بِثَابِتٍ إِلَيْهِ يَسْأَلُهُ لَنَا عَنْ حَدِيثِ الشَّفَاعَةِ، فَإِذَا هُوَ فِي قَصْرِهِ فَوَافَقْنَاهُ يُصَلِّي الضُّحَى، فَاسْتَأْذَنَّا، فَأَذِنَ لَنَا وَهْوَ قَاعِدٌ عَلَى فِرَاشِهِ فَقُلْنَا لِثَابِتٍ لاَ تَسْأَلْهُ عَنْ شَىْءٍ أَوَّلَ مِنْ حَدِيثِ الشَّفَاعَةِ فَقَالَ يَا أَبَا حَمْزَةَ هَؤُلاَءِ إِخْوَانُكَ مِنْ أَهْلِ الْبَصْرَةِ جَاءُوكَ يَسْأَلُونَكَ عَنْ حَدِيثِ الشَّفَاعَةِ‏.‏ فَقَالَ حَدَّثَنَا مُحَمَّدٌ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا كَانَ يَوْمُ الْقِيَامَةِ مَاجَ النَّاسُ بَعْضُهُمْ فِي بَعْضٍ فَيَأْتُونَ آدَمَ فَيَقُولُونَ اشْفَعْ لَنَا إِلَى رَبِّكَ‏.‏ فَيَقُولُ لَسْتُ لَهَا وَلَكِنْ عَلَيْكُمْ بِإِبْرَاهِيمَ فَإِنَّهُ خَلِيلُ الرَّحْمَنِ‏.‏ فَيَأْتُونَ إِبْرَاهِيمَ فَيَقُولُ لَسْتُ لَهَا وَلَكِنْ عَلَيْكُمْ بِمُوسَى فَإِنَّهُ كَلِيمُ اللَّهِ‏.‏ فَيَأْتُونَ مُوسَى فَيَقُولُ لَسْتُ لَهَا وَلَكِنْ عَلَيْكُمْ بِعِيسَى فَإِنَّهُ رُوحُ اللَّهِ وَكَلِمَتُهُ‏.‏ فَيَأْتُونَ عِيسَى فَيَقُولُ لَسْتُ لَهَا وَلَكِنْ عَلَيْكُمْ بِمُحَمَّدٍ صلى الله عليه وسلم فَيَأْتُونِي فَأَقُولُ أَنَا لَهَا‏.‏ فَأَسْتَأْذِنُ عَلَى رَبِّي فَيُؤْذَنُ لِي وَيُلْهِمُنِي مَحَامِدَ أَحْمَدُهُ بِهَا لاَ تَحْضُرُنِي الآنَ، فَأَحْمَدُهُ بِتِلْكَ الْمَحَامِدِ وَأَخِرُّ لَهُ سَاجِدًا فَيُقَالُ يَا مُحَمَّدُ ارْفَعْ رَأْسَكَ، وَقُلْ يُسْمَعْ لَكَ، وَسَلْ تُعْطَ، وَاشْفَعْ تُشَفَّعْ‏.‏ فَأَقُولُ يَا رَبِّ أُمَّتِي أُمَّتِي‏.‏ فَيُقَالُ انْطَلِقْ فَأَخْرِجْ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ شَعِيرَةٍ مِنْ إِيمَانٍ‏.‏ فَأَنْطَلِقُ فَأَفْعَلُ ثُمَّ أَعُودُ فَأَحْمَدُهُ بِتِلْكَ الْمَحَامِدِ، ثُمَّ أَخِرُّ لَهُ سَاجِدًا فَيُقَالُ يَا مُحَمَّدُ ارْفَعْ رَأْسَكَ، وَقُلْ يُسْمَعْ لَكَ، وَسَلْ تُعْطَ، وَاشْفَعْ تُشَفَّعْ، فَأَقُولُ يَا رَبِّ أُمَّتِي أُمَّتِي‏.‏ فَيُقَالُ انْطَلِقْ فَأَخْرِجْ مِنْهَا مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ أَوْ خَرْدَلَةٍ مِنْ إِيمَانٍ‏.‏ فَأَنْطَلِقُ فَأَفْعَلُ ثُمَّ أَعُودُ فَأَحْمَدُهُ بِتِلْكَ الْمَحَامِدِ، ثُمَّ أَخِرُّ لَهُ سَاجِدًا فَيُقَالُ يَا مُحَمَّدُ ارْفَعْ رَأْسَكَ، وَقُلْ يُسْمَعْ لَكَ، وَسَلْ تُعْطَ، وَاشْفَعْ تُشَفَّعْ‏.‏ فَأَقُولُ يَا رَبِّ أُمَّتِي أُمَّتِي‏.‏ فَيَقُولُ انْطَلِقْ فَأَخْرِجْ مَنْ كَانَ فِي قَلْبِهِ أَدْنَى أَدْنَى أَدْنَى مِثْقَالِ حَبَّةِ خَرْدَلٍ مِنْ إِيمَانٍ، فَأَخْرِجْهُ مِنَ النَّارِ‏.‏ فَأَنْطَلِقُ فَأَفْعَلُ ‏"‏‏.‏ فَلَمَّا خَرَجْنَا مِنْ عِنْدِ أَنَسٍ قُلْتُ لِبَعْضِ أَصْحَابِنَا لَوْ مَرَرْنَا بِالْحَسَنِ وَهْوَ مُتَوَارٍ فِي مَنْزِلِ أَبِي خَلِيفَةَ فَحَدَّثَنَا بِمَا حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، فَأَتَيْنَاهُ فَسَلَّمْنَا عَلَيْهِ فَأَذِنَ لَنَا فَقُلْنَا لَهُ يَا أَبَا سَعِيدٍ جِئْنَاكَ مِنْ عِنْدِ أَخِيكَ أَنَسِ بْنِ مَالِكٍ فَلَمْ نَرَ مِثْلَ مَا حَدَّثَنَا فِي الشَّفَاعَةِ، فَقَالَ هِيهِ، فَحَدَّثْنَاهُ بِالْحَدِيثِ فَانْتَهَى إِلَى هَذَا الْمَوْضِعِ فَقَالَ هِيهِ، فَقُلْنَا لَمْ يَزِدْ لَنَا عَلَى هَذَا‏.‏ فَقَالَ لَقَدْ حَدَّثَنِي وَهْوَ جَمِيعٌ مُنْذُ عِشْرِينَ سَنَةً فَلاَ أَدْرِي أَنَسِيَ أَمْ كَرِهَ أَنْ تَتَّكِلُوا‏.‏ قُلْنَا يَا أَبَا سَعِيدٍ فَحَدِّثْنَا، فَضَحِكَ وَقَالَ خُلِقَ الإِنْسَانُ عَجُولاً مَا ذَكَرْتُهُ إِلاَّ وَأَنَا أُرِيدُ أَنْ أُحَدِّثَكُمْ حَدَّثَنِي كَمَا حَدَّثَكُمْ بِهِ قَالَ ‏"‏ ثُمَّ أَعُودُ الرَّابِعَةَ فَأَحْمَدُهُ بِتِلْكَ، ثُمَّ أَخِرُّ لَهُ سَاجِدًا فَيُقَالُ يَا مُحَمَّدُ ارْفَعْ رَأْسَكَ وَقُلْ يُسْمَعْ، وَسَلْ تُعْطَهْ، وَاشْفَعْ تُشَفَّعْ‏.‏ فَأَقُولُ يَا رَبِّ ائْذَنْ لِي فِيمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَيَقُولُ وَعِزَّتِي وَجَلاَلِي وَكِبْرِيَائِي وَعَظَمَتِي لأُخْرِجَنَّ مِنْهَا مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏‏.‏\hadithno{7510}\hadithtrans{Narrated Ma`bad bin Hilal Al-`Anzi:We, i.e., some people from Basra gathered and went to Anas bin Malik, and we went in company with Thabit Al-Bunnani so that he might ask him about the Hadith of Intercession on our behalf. Behold, Anas was in his palace, and our arrival coincided with his Duha prayer. We asked permission to enter and he admitted us while he was sitting on his bed. We said to Thabit, "Do not ask him about anything else first but the Hadith of Intercession." He said, "O Abu Hamza! There are your brethren from Basra coming to ask you about the Hadith of Intercession." Anas then said, "Muhammad talked to us saying, 'On the Day of Resurrection the people will surge with each other like waves, and then they will come to Adam and say, 'Please intercede for us with your Lord.' He will say, 'I am not fit for that but you'd better go to Abraham as he is the Khalil of the Beneficent.' They will go to Abraham and he will say, 'I am not fit for that, but you'd better go to Moses as he is the one to whom Allah spoke directly.' So they will go to Moses and he will say, 'I am not fit for that, but you'd better go to Jesus as he is a soul created by Allah and His Word.' (Be: And it was) they will go to Jesus and he will say, 'I am not fit for that, but you'd better go to Muhammad.' They would come to me and I would say, 'I am for that.' Then I will ask for my Lord's permission, and it will be given, and then He will inspire me to praise Him with such praises as I do not know now. So I will praise Him with those praises and will fall down, prostrate before Him. Then it will be said, 'O Muhammad, raise your head and speak, for you will be listened to; and ask, for your will be granted (your request); and intercede, for your intercession will be accepted.' I will say, 'O Lord, my followers! My followers!' And then it will be said, 'Go and take out of Hell (Fire) all those who have faith in their hearts, equal to the weight of a barley grain.' I will go and do so and return to praise Him with the same praises, and fall down (prostrate) before Him. Then it will be said, 'O Muhammad, raise your head and speak, for you will be listened to, and ask, for you will be granted (your request); and intercede, for your intercession will be accepted.' I will say, 'O Lord, my followers! My followers!' It will be said, 'Go and take out of it all those who have faith in their hearts equal to the weight of a small ant or a mustard seed.' I will go and do so and return to praise Him with the same praises, and fall down in prostration before Him. It will be said, 'O, Muhammad, raise your head and speak, for you will be listened to, and ask, for you will be granted (your request); and intercede, for your intercession will be accepted.' I will say, 'O Lord, my followers!' Then He will say, 'Go and take out (all those) in whose hearts there is faith even to the lightest, lightest mustard seed. (Take them) out of the Fire.' I will go and do so."' When we left Anas, I said to some of my companions, "Let's pass by Al-Hasan who is hiding himself in the house of Abi Khalifa and request him to tell us what Anas bin Malik has told us." So we went to him and we greeted him and he admitted us. We said to him, "O Abu Sa`id! We came to you from your brother Anas Bin Malik and he related to us a Hadith about the intercession the like of which I have never heard." He said, "What is that?" Then we told him of the Hadith and said, "He stopped at this point (of the Hadith)." He said, "What then?" We said, "He did not add anything to that." He said, Anas related the Hadith to me twenty years ago when he was a young fellow. I don't know whether he forgot or if he did not like to let you depend on what he might have said." We said, "O Abu Sa`id ! Let us know that." He smiled and said, "Man was created hasty. I did not mention that, but that I wanted to inform you of it. Anas told me the same as he told you and said that the Prophet (ﷺ) added, 'I then return for a fourth time and praise Him similarly and prostrate before Him me the same as he 'O Muhammad, raise your head and speak, for you will be listened to; and ask, for you will be granted (your request): and intercede, for your intercession will be accepted .' I will say, 'O Lord, allow me to intercede for whoever said, 'None has the right to be worshiped except Allah.' Then Allah will say, 'By my Power, and my Majesty, and by My Supremacy, and by My Greatness, I will take out of Hell (Fire) whoever said: 'None has the right to be worshipped except Allah}}
\hadithdefcmd{bukhari}{7511}{حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ آخِرَ أَهْلِ الْجَنَّةِ دُخُولاً الْجَنَّةَ، وَآخِرَ أَهْلِ النَّارِ خُرُوجًا مِنَ النَّارِ رَجُلٌ يَخْرُجُ حَبْوًا فَيَقُولُ لَهُ رَبُّهُ ادْخُلِ الْجَنَّةَ‏.‏ فَيَقُولُ رَبِّ الْجَنَّةُ مَلأَى‏.‏ فَيَقُولُ لَهُ ذَلِكَ ثَلاَثَ مَرَّاتٍ فَكُلُّ ذَلِكَ يُعِيدُ عَلَيْهِ الْجَنَّةُ مَلأَى‏.‏ فَيَقُولُ إِنَّ لَكَ مِثْلَ الدُّنْيَا عَشْرَ مِرَارٍ ‏"‏‏.‏\hadithno{7511}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "The person who will be the last one to enter Paradise and the last to come out of Hell (Fire) will be a man who will come out crawling, and his Lord will say to him, 'Enter Paradise.' He will reply, 'O Lord, Paradise is full.' Allah will give him the same order thrice, and each time the man will give Him the same reply, i.e., 'Paradise is full.' Thereupon Allah will say (to him), 'Ten times of the world is for you}}
\hadithdefcmd{bukhari}{7512}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْكُمْ أَحَدٌ إِلاَّ سَيُكَلِّمُهُ رَبُّهُ، لَيْسَ بَيْنَهُ وَبَيْنَهُ تَرْجُمَانٌ، فَيَنْظُرُ أَيْمَنَ مِنْهُ فَلاَ يَرَى إِلاَّ مَا قَدَّمَ مِنْ عَمَلِهِ، وَيَنْظُرُ أَشْأَمَ مِنْهُ فَلاَ يَرَى إِلاَّ مَا قَدَّمَ، وَيَنْظُرُ بَيْنَ يَدَيْهِ فَلاَ يَرَى إِلاَّ النَّارَ تِلْقَاءَ وَجْهِهِ، فَاتَّقُوا النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ ‏"‏‏.‏ قَالَ الأَعْمَشُ وَحَدَّثَنِي عَمْرُو بْنُ مُرَّةَ عَنْ خَيْثَمَةَ مِثْلَهُ وَزَادَ فِيهِ ‏"‏ وَلَوْ بِكَلِمَةٍ طَيِّبَةٍ ‏"‏‏.‏\hadithno{7512}\hadithtrans{Narrated `Adi bin Hatim:Allah's Messenger (ﷺ) said, "There will be none among you but his Lord will talk to him, and there will be no interpreter between him and Allah. He will look to his right and see nothing but his deeds which he has sent forward, and will look to his left and see nothing but his deeds which he has sent forward, and will look in front of him and see nothing but the (Hell) Fire facing him. So save yourself from the (Hell) Fire even with half a date (given in charity)." Al-A`mash said: `Amr bin Murra said, Khaithama narrated the same and added, '..even with a good word}}
\hadithdefcmd{bukhari}{7513}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ جَاءَ حَبْرٌ مِنَ الْيَهُودِ فَقَالَ إِنَّهُ إِذَا كَانَ يَوْمَ الْقِيَامَةِ جَعَلَ اللَّهُ السَّمَوَاتِ عَلَى إِصْبَعٍ، وَالأَرَضِينَ عَلَى إِصْبَعٍ، وَالْمَاءَ وَالثَّرَى عَلَى إِصْبَعٍ، وَالْخَلاَئِقَ عَلَى إِصْبَعٍ، ثُمَّ يَهُزُّهُنَّ ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَنَا الْمَلِكُ‏.‏ فَلَقَدْ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَضْحَكُ حَتَّى بَدَتْ نَوَاجِذُهُ تَعَجُّبًا وَتَصْدِيقًا، لِقَوْلِهِ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏\{‏وَمَا قَدَرُوا اللَّهَ حَقَّ قَدْرِهِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏يُشْرِكُونَ‏\}‏\hadithno{7513}\hadithtrans{Narrated `Abdullah:A priest from the Jews came (to the Prophet) and said, "On the Day of Resurrection, Allah will place all the heavens on one finger, and the Earth on one finger, and the waters and the land on one finger, and all the creation on one finger, and then He will shake them and say. 'I am the King! I am the King!'" I saw the Prophet (ﷺ) smiling till his premolar teeth became visible expressing his amazement and his belief in what he had said. Then the Prophet (ﷺ) recited: 'No just estimate have they made of Allah such as due to Him (up to)...; High is He above the partners they attribute to Him}}
\hadithdefcmd{bukhari}{7514}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ، أَنَّ رَجُلاً، سَأَلَ ابْنَ عُمَرَ كَيْفَ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي النَّجْوَى قَالَ ‏ "‏ يَدْنُو أَحَدُكُمْ مِنْ رَبِّهِ حَتَّى يَضَعَ كَنَفَهُ عَلَيْهِ فَيَقُولُ أَعَمِلْتَ كَذَا وَكَذَا فَيَقُولُ نَعَمْ‏.‏ وَيَقُولُ عَمِلْتَ كَذَا وَكَذَا فَيَقُولُ نَعَمْ‏.‏ فَيُقَرِّرُهُ، ثُمَّ يَقُولُ إِنِّي سَتَرْتُ عَلَيْكَ فِي الدُّنْيَا، وَأَنَا أَغْفِرُهَا لَكَ الْيَوْمَ ‏"‏‏.‏ وَقَالَ آدَمُ حَدَّثَنَا شَيْبَانُ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا صَفْوَانُ، عَنِ ابْنِ عُمَرَ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم\hadithno{7514}\hadithtrans{Narrated Safwan bin Muhriz:A man asked Ibn `Umar, "What have you heard from Allah's Messenger (ﷺ) regarding An-Najwa?" He said, "Everyone of you will come close to His Lord Who will screen him from the people and say to him, 'Did you do so-and-so?' He will reply, 'Yes.' Then Allah will say, 'Did you do so-and-so?' He will reply, 'Yes.' So Allah will question him and make him confess, and then Allah will say, 'I screened your sins in the world and forgive them for you today}}
\hadithdefcmd{bukhari}{7515}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ احْتَجَّ آدَمُ وَمُوسَى، فَقَالَ مُوسَى أَنْتَ آدَمُ الَّذِي أَخْرَجْتَ ذُرِّيَّتَكَ مِنَ الْجَنَّةِ‏.‏ قَالَ آدَمُ أَنْتَ مُوسَى الَّذِي اصْطَفَاكَ اللَّهُ بِرِسَالاَتِهِ وَكَلاَمِهِ، ثُمَّ تَلُومُنِي عَلَى أَمْرٍ قَدْ قُدِّرَ عَلَىَّ قَبْلَ أَنْ أُخْلَقَ‏.‏ فَحَجَّ آدَمُ مُوسَى ‏"‏‏.‏\hadithno{7515}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Adam and Moses debated with each other and Moses said, 'You are Adam who turned out your offspring from Paradise.' Adam said, "You are Moses whom Allah chose for His Message and for His direct talk, yet you blame me for a matter which had been ordained for me even before my creation?' Thus Adam overcame Moses}}
\hadithdefcmd{bukhari}{7516}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُجْمَعُ الْمُؤْمِنُونَ يَوْمَ الْقِيَامَةِ فَيَقُولُونَ لَوِ اسْتَشْفَعْنَا إِلَى رَبِّنَا، فَيُرِيحُنَا مِنْ مَكَانِنَا هَذَا‏.‏ فَيَأْتُونَ آدَمَ فَيَقُولُونَ لَهُ أَنْتَ آدَمُ أَبُو الْبَشَرِ خَلَقَكَ اللَّهُ بِيَدِهِ وَأَسْجَدَ لَكَ الْمَلاَئِكَةَ وَعَلَّمَكَ أَسْمَاءَ كُلِّ شَىْءٍ، فَاشْفَعْ لَنَا إِلَى رَبِّنَا حَتَّى يُرِيحَنَا‏.‏ فَيَقُولُ لَهُمْ لَسْتُ هُنَاكُمْ‏.‏ فَيَذْكُرُ لَهُمْ خَطِيئَتَهُ الَّتِي أَصَابَ ‏"‏‏.‏\hadithno{7516}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "The believers will be assembled on the Day of Resurrection and they will say, 'Let us look for someone to intercede for us with our Lord so that He may relieve us from this place of ours.' So they will go to Adam and say, 'You are Adam, the father of mankind, and Allah created you with His Own Hands and ordered the Angels to prostrate before you, and He taught you the names of all things; so please intercede for us with our Lord so that He may relieve us.' Adam will say, to them, 'I am not fit for that,' and then he will mention to them his mistake which he has committed}}
\hadithdefcmd{bukhari}{7517}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي سُلَيْمَانُ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ سَمِعْتُ ابْنَ مَالِكٍ، يَقُولُ لَيْلَةَ أُسْرِيَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ مَسْجِدِ الْكَعْبَةِ أَنَّهُ جَاءَهُ ثَلاَثَةُ نَفَرٍ قَبْلَ أَنْ يُوحَى إِلَيْهِ وَهْوَ نَائِمٌ فِي الْمَسْجِدِ الْحَرَامِ، فَقَالَ أَوَّلُهُمْ أَيُّهُمْ هُوَ فَقَالَ أَوْسَطُهُمْ هُوَ خَيْرُهُمْ‏.‏ فَقَالَ آخِرُهُمْ خُذُوا خَيْرَهُمْ‏.‏ فَكَانَتْ تِلْكَ اللَّيْلَةَ، فَلَمْ يَرَهُمْ حَتَّى أَتَوْهُ لَيْلَةً أُخْرَى فِيمَا يَرَى قَلْبُهُ، وَتَنَامُ عَيْنُهُ وَلاَ يَنَامُ قَلْبُهُ وَكَذَلِكَ الأَنْبِيَاءُ تَنَامُ أَعْيُنُهُمْ وَلاَ تَنَامُ قُلُوبُهُمْ، فَلَمْ يُكَلِّمُوهُ حَتَّى احْتَمَلُوهُ فَوَضَعُوهُ عِنْدَ بِئْرِ زَمْزَمَ فَتَوَلاَّهُ مِنْهُمْ جِبْرِيلُ فَشَقَّ جِبْرِيلُ مَا بَيْنَ نَحْرِهِ إِلَى لَبَّتِهِ حَتَّى فَرَغَ مِنْ صَدْرِهِ وَجَوْفِهِ، فَغَسَلَهُ مِنْ مَاءِ زَمْزَمَ بِيَدِهِ، حَتَّى أَنْقَى جَوْفَهُ، ثُمَّ أُتِيَ بِطَسْتٍ مِنْ ذَهَبٍ فِيهِ تَوْرٌ مِنْ ذَهَبٍ مَحْشُوًّا إِيمَانًا وَحِكْمَةً، فَحَشَا بِهِ صَدْرَهُ وَلَغَادِيدَهُ ـ يَعْنِي عُرُوقَ حَلْقِهِ ـ ثُمَّ أَطْبَقَهُ ثُمَّ عَرَجَ بِهِ إِلَى السَّمَاءِ الدُّنْيَا فَضَرَبَ بَابًا مِنْ أَبْوَابِهَا فَنَادَاهُ أَهْلُ السَّمَاءِ مَنْ هَذَا فَقَالَ جِبْرِيلُ‏.‏ قَالُوا وَمَنْ مَعَكَ قَالَ مَعِي مُحَمَّدٌ‏.‏ قَالَ وَقَدْ بُعِثَ قَالَ نَعَمْ‏.‏ قَالُوا فَمَرْحَبًا بِهِ وَأَهْلاً‏.‏ فَيَسْتَبْشِرُ بِهِ أَهْلُ السَّمَاءِ، لاَ يَعْلَمُ أَهْلُ السَّمَاءِ بِمَا يُرِيدُ اللَّهُ بِهِ فِي الأَرْضِ حَتَّى يُعْلِمَهُمْ، فَوَجَدَ فِي السَّمَاءِ الدُّنْيَا آدَمَ فَقَالَ لَهُ جِبْرِيلُ هَذَا أَبُوكَ فَسَلِّمْ عَلَيْهِ‏.‏ فَسَلَّمَ عَلَيْهِ وَرَدَّ عَلَيْهِ آدَمُ وَقَالَ مَرْحَبًا وَأَهْلاً بِابْنِي، نِعْمَ الاِبْنُ أَنْتَ‏.‏ فَإِذَا هُوَ فِي السَّمَاءِ الدُّنْيَا بِنَهَرَيْنِ يَطَّرِدَانِ فَقَالَ مَا هَذَانِ النَّهَرَانِ يَا جِبْرِيلُ قَالَ هَذَا النِّيلُ وَالْفُرَاتُ عُنْصُرُهُمَا‏.‏ ثُمَّ مَضَى بِهِ فِي السَّمَاءِ فَإِذَا هُوَ بِنَهَرٍ آخَرَ عَلَيْهِ قَصْرٌ مِنْ لُؤْلُؤٍ وَزَبَرْجَدٍ فَضَرَبَ يَدَهُ فَإِذَا هُوَ مِسْكٌ قَالَ مَا هَذَا يَا جِبْرِيلُ قَالَ هَذَا الْكَوْثَرُ الَّذِي خَبَأَ لَكَ رَبُّكَ‏.‏ ثُمَّ عَرَجَ إِلَى السَّمَاءِ الثَّانِيَةِ فَقَالَتِ الْمَلاَئِكَةُ لَهُ مِثْلَ مَا قَالَتْ لَهُ الأُولَى مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قَالُوا وَمَنْ مَعَكَ قَالَ مُحَمَّدٌ صلى الله عليه وسلم‏.‏ قَالُوا وَقَدْ بُعِثَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قَالُوا مَرْحَبًا بِهِ وَأَهْلاً‏.‏ ثُمَّ عَرَجَ بِهِ إِلَى السَّمَاءِ الثَّالِثَةِ وَقَالُوا لَهُ مِثْلَ مَا قَالَتِ الأُولَى وَالثَّانِيَةُ، ثُمَّ عَرَجَ بِهِ إِلَى الرَّابِعَةِ فَقَالُوا لَهُ مِثْلَ ذَلِكَ، ثُمَّ عَرَجَ بِهِ إِلَى السَّمَاءِ الْخَامِسَةِ فَقَالُوا مِثْلَ ذَلِكَ، ثُمَّ عَرَجَ بِهِ إِلَى السَّمَاءِ السَّادِسَةِ فَقَالُوا لَهُ مِثْلَ ذَلِكَ، ثُمَّ عَرَجَ بِهِ إِلَى السَّمَاءِ السَّابِعَةِ فَقَالُوا لَهُ مِثْلَ ذَلِكَ، كُلُّ سَمَاءٍ فِيهَا أَنْبِيَاءُ قَدْ سَمَّاهُمْ فَأَوْعَيْتُ مِنْهُمْ إِدْرِيسَ فِي الثَّانِيَةِ، وَهَارُونَ فِي الرَّابِعَةِ، وَآخَرَ فِي الْخَامِسَةِ لَمْ أَحْفَظِ اسْمَهُ، وَإِبْرَاهِيمَ فِي السَّادِسَةِ، وَمُوسَى فِي السَّابِعَةِ بِتَفْضِيلِ كَلاَمِ اللَّهِ، فَقَالَ مُوسَى رَبِّ لَمْ أَظُنَّ أَنْ يُرْفَعَ عَلَىَّ أَحَدٌ‏.‏ ثُمَّ عَلاَ بِهِ فَوْقَ ذَلِكَ بِمَا لاَ يَعْلَمُهُ إِلاَّ اللَّهُ، حَتَّى جَاءَ سِدْرَةَ الْمُنْتَهَى وَدَنَا الْجَبَّارُ رَبُّ الْعِزَّةِ فَتَدَلَّى حَتَّى كَانَ مِنْهُ قَابَ قَوْسَيْنِ أَوْ أَدْنَى فَأَوْحَى اللَّهُ فِيمَا أَوْحَى إِلَيْهِ خَمْسِينَ صَلاَةً عَلَى أُمَّتِكَ كُلَّ يَوْمٍ وَلَيْلَةٍ‏.‏ ثُمَّ هَبَطَ حَتَّى بَلَغَ مُوسَى فَاحْتَبَسَهُ مُوسَى فَقَالَ يَا مُحَمَّدُ مَاذَا عَهِدَ إِلَيْكَ رَبُّكَ قَالَ عَهِدَ إِلَىَّ خَمْسِينَ صَلاَةً كُلَّ يَوْمٍ وَلَيْلَةٍ‏.‏ قَالَ إِنَّ أُمَّتَكَ لاَ تَسْتَطِيعُ ذَلِكَ فَارْجِعْ فَلْيُخَفِّفْ عَنْكَ رَبُّكَ وَعَنْهُمْ‏.‏ فَالْتَفَتَ النَّبِيُّ صلى الله عليه وسلم إِلَى جِبْرِيلَ كَأَنَّهُ يَسْتَشِيرُهُ فِي ذَلِكَ، فَأَشَارَ إِلَيْهِ جِبْرِيلُ أَنْ نَعَمْ إِنْ شِئْتَ‏.‏ فَعَلاَ بِهِ إِلَى الْجَبَّارِ فَقَالَ وَهْوَ مَكَانَهُ يَا رَبِّ خَفِّفْ عَنَّا، فَإِنَّ أُمَّتِي لاَ تَسْتَطِيعُ هَذَا‏.‏ فَوَضَعَ عَنْهُ عَشْرَ صَلَوَاتٍ ثُمَّ رَجَعَ إِلَى مُوسَى فَاحْتَبَسَهُ، فَلَمْ يَزَلْ يُرَدِّدُهُ مُوسَى إِلَى رَبِّهِ حَتَّى صَارَتْ إِلَى خَمْسِ صَلَوَاتٍ، ثُمَّ احْتَبَسَهُ مُوسَى عِنْدَ الْخَمْسِ فَقَالَ يَا مُحَمَّدُ وَاللَّهِ لَقَدْ رَاوَدْتُ بَنِي إِسْرَائِيلَ قَوْمِي عَلَى أَدْنَى مِنْ هَذَا فَضَعُفُوا فَتَرَكُوهُ فَأُمَّتُكَ أَضْعَفُ أَجْسَادًا وَقُلُوبًا وَأَبْدَانًا وَأَبْصَارًا وَأَسْمَاعًا، فَارْجِعْ فَلْيُخَفِّفْ عَنْكَ رَبُّكَ، كُلَّ ذَلِكَ يَلْتَفِتُ النَّبِيُّ صلى الله عليه وسلم إِلَى جِبْرِيلَ لِيُشِيرَ عَلَيْهِ وَلاَ يَكْرَهُ ذَلِكَ جِبْرِيلُ، فَرَفَعَهُ عِنْدَ الْخَامِسَةِ فَقَالَ يَا رَبِّ إِنَّ أُمَّتِي ضُعَفَاءُ أَجْسَادُهُمْ وَقُلُوبُهُمْ وَأَسْمَاعُهُمْ وَأَبْدَانُهُمْ فَخَفِّفْ عَنَّا فَقَالَ الْجَبَّارُ يَا مُحَمَّدُ‏.‏ قَالَ لَبَّيْكَ وَسَعْدَيْكَ‏.‏ قَالَ إِنَّهُ لاَ يُبَدَّلُ الْقَوْلُ لَدَىَّ، كَمَا فَرَضْتُ عَلَيْكَ فِي أُمِّ الْكِتَابِ ـ قَالَ ـ فَكُلُّ حَسَنَةٍ بِعَشْرِ أَمْثَالِهَا، فَهْىَ خَمْسُونَ فِي أُمِّ الْكِتَابِ وَهْىَ خَمْسٌ عَلَيْكَ‏.‏ فَرَجَعَ إِلَى مُوسَى فَقَالَ كَيْفَ فَعَلْتَ فَقَالَ خَفَّفَ عَنَّا أَعْطَانَا بِكُلِّ حَسَنَةٍ عَشْرَ أَمْثَالِهَا‏.‏ قَالَ مُوسَى قَدْ وَاللَّهِ رَاوَدْتُ بَنِي إِسْرَائِيلَ عَلَى أَدْنَى مِنْ ذَلِكَ فَتَرَكُوهُ، ارْجِعْ إِلَى رَبِّكَ فَلْيُخَفِّفْ عَنْكَ أَيْضًا‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَا مُوسَى قَدْ وَاللَّهِ اسْتَحْيَيْتُ مِنْ رَبِّي مِمَّا اخْتَلَفْتُ إِلَيْهِ‏.‏ قَالَ فَاهْبِطْ بِاسْمِ اللَّهِ‏.‏ قَالَ وَاسْتَيْقَظَ وَهْوَ فِي مَسْجِدِ الْحَرَامِ‏.‏\hadithno{7517}\hadithtrans{Narrated Anas bin Malik:The night Allah's Messenger (ﷺ) was taken for a journey from the sacred mosque (of Mecca) Al-Ka`ba: Three persons came to him (in a dreamy while he was sleeping in the Sacred Mosque before the Divine Inspiration was revealed to Him. One of them said, "Which of them is he?" The middle (second) angel said, "He is the best of them." The last (third) angle said, "Take the best of them." Only that much happened on that night and he did not see them till they came on another night, i.e. after The Divine Inspiration was revealed to him. (Fath-ul-Bari Page 258, Vol. 17) and he saw them, his eyes were asleep but his heart was not----and so is the case with the prophets: their eyes sleep while their hearts do not sleep. So those angels did not talk to him till they carried him and placed him beside the well of Zamzam. From among them Gabriel took charge of him. Gabriel cut open (the part of his body) between his throat and the middle of his chest (heart) and took all the material out of his chest and `Abdomen and then washed it with Zamzam water with his own hands till he cleansed the inside of his body, and then a gold tray containing a gold bowl full of belief and wisdom was brought and then Gabriel stuffed his chest and throat blood vessels with it and then closed it (the chest). He then ascended with him to the heaven of the world and knocked on one of its doors. The dwellers of the Heaven asked, 'Who is it?' He said, "Gabriel." They said, "Who is accompanying you?" He said, "Muhammad." They said, "Has he been called?" He said, "Yes" They said, "He is welcomed." So the dwellers of the Heaven became pleased with his arrival, and they did not know what Allah would do to the Prophet (ﷺ) on earth unless Allah informed them. The Prophet (ﷺ) met Adam over the nearest Heaven. Gabriel said to the Prophet, "He is your father; greet him." The Prophet (ﷺ) greeted him and Adam returned his greeting and said, "Welcome, O my Son! O what a good son you are!" Behold, he saw two flowing rivers, while he was in the nearest sky. He asked, "What are these two rivers, O Gabriel?" Gabriel said, "These are the sources of the Nile and the Euphrates." Then Gabriel took him around that Heaven and behold, he saw another river at the bank of which there was a palace built of pearls and emerald. He put his hand into the river and found its mud like musk Adhfar. He asked, "What is this, O Gabriel?" Gabriel said, "This is the Kauthar which your Lord has kept for you." Then Gabriel ascended (with him) to the second Heaven and the angels asked the same questions as those on the first Heaven, i.e., "Who is it?" Gabriel replied, "Gabriel". They asked, "Who is accompanying you?" He said, "Muhammad." They asked, "Has he been sent for?" He said, "Yes." Then they said, "He is welcomed.'' Then he (Gabriel) ascended with the Prophet (ﷺ) to the third Heaven, and the angels said the same as the angels of the first and the second Heavens had said. Then he ascended with him to the fourth Heaven and they said the same; and then he ascended with him to the fifth Heaven and they said the same; and then he ascended with him to the sixth Heaven and they said the same; then he ascended with him to the seventh Heaven and they said the same. On each Heaven there were prophets whose names he had mentioned and of whom I remember Idris on the second Heaven, Aaron on the fourth Heavens another prophet whose name I don't remember, on the fifth Heaven, Abraham on the sixth Heaven, and Moses on the seventh Heaven because of his privilege of talking to Allah directly. Moses said (to Allah), "O Lord! I thought that none would be raised up above me." But Gabriel ascended with him (the Prophet) for a distance above that, the distance of which only Allah knows, till he reached the Lote Tree (beyond which none may pass) and then the Irresistible, the Lord of Honor and Majesty approached and came closer till he (Gabriel) was about two bow lengths or (even) nearer. (It is said that it was Gabriel who approached and came closer to the Prophet. (Fate Al-Bari Page 263, 264, Vol. 17). Among the things which Allah revealed to him then, was: "Fifty prayers were enjoined on his followers in a day and a night." Then the Prophet (ﷺ) descended till he met Moses, and then Moses stopped him and asked, "O Muhammad ! What did your Lord en join upon you?" The Prophet (ﷺ) replied," He enjoined upon me to perform fifty prayers in a day and a night." Moses said, "Your followers cannot do that; Go back so that your Lord may reduce it for you and for them." So the Prophet (ﷺ) turned to Gabriel as if he wanted to consult him about that issue. Gabriel told him of his opinion, saying, "Yes, if you wish." So Gabriel ascended with him to the Irresistible and said while he was in his place, "O Lord, please lighten our burden as my followers cannot do that." So Allah deducted for him ten prayers where upon he returned to Moses who stopped him again and kept on sending him back to his Lord till the enjoined prayers were reduced to only five prayers. Then Moses stopped him when the prayers had been reduced to five and said, "O Muhammad! By Allah, I tried to persuade my nation, Bani Israel to do less than this, but they could not do it and gave it up. However, your followers are weaker in body, heart, sight and hearing, so return to your Lord so that He may lighten your burden." The Prophet (ﷺ) turned towards Gabriel for advice and Gabriel did not disapprove of that. So he ascended with him for the fifth time. The Prophet (ﷺ) said, "O Lord, my followers are weak in their bodies, hearts, hearing and constitution, so lighten our burden." On that the Irresistible said, "O Muhammad!" the Prophet replied, "Labbaik and Sa`daik." Allah said, "The Word that comes from Me does not change, so it will be as I enjoined on you in the Mother of the Book." Allah added, "Every good deed will be rewarded as ten times so it is fifty (prayers) in the Mother of the Book (in reward) but you are to perform only five (in practice)." The Prophet (ﷺ) returned to Moses who asked, "What have you done?" He said, "He has lightened our burden: He has given us for every good deed a tenfold reward." Moses said, "By Allah! I tried to make Bani Israel observe less than that, but they gave it up. So go back to your Lord that He may lighten your burden further." Allah's Messenger (ﷺ) said, "O Moses! By Allah, I feel shy of returning too many times to my Lord." On that Gabriel said, "Descend in Allah's Name." The Prophet (ﷺ) then woke while he was in the Sacred Mosque (at Mecca)}}
\hadithdefcmd{bukhari}{7518}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَقُولُ لأَهْلِ الْجَنَّةِ يَا أَهْلَ الْجَنَّةِ‏.‏ فَيَقُولُونَ لَبَّيْكَ رَبَّنَا وَسَعْدَيْكَ وَالْخَيْرُ فِي يَدَيْكَ‏.‏ فَيَقُولُ هَلْ رَضِيتُمْ فَيَقُولُونَ وَمَا لَنَا لاَ نَرْضَى يَا رَبِّ وَقَدْ أَعْطَيْتَنَا مَا لَمْ تُعْطِ أَحَدًا مِنْ خَلْقِكَ‏.‏ فَيَقُولُ أَلاَ أُعْطِيكُمْ أَفْضَلَ مِنْ ذَلِكَ‏.‏ فَيَقُولُونَ يَا رَبِّ وَأَىُّ شَىْءٍ أَفْضَلُ مِنْ ذَلِكَ فَيَقُولُ أُحِلُّ عَلَيْكُمْ رِضْوَانِي فَلاَ أَسْخَطُ عَلَيْكُمْ بَعْدَهُ أَبَدًا ‏"‏‏.‏\hadithno{7518}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Allah will say to the people of Paradise, "O the people of Paradise!" They will say, 'Labbaik, O our Lord, and Sa`daik, and all the good is in Your Hands!' Allah will say, "Are you satisfied?' They will say, 'Why shouldn't we be satisfied, O our Lord as You have given us what You have not given to any of Your created beings?' He will say, 'Shall I not give you something better than that?' They will say, 'O our Lord! What else could be better than that?' He will say, 'I bestow My Pleasure on you and will never be angry with you after that}}
\hadithdefcmd{bukhari}{7519}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا هِلاَلٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَوْمًا يُحَدِّثُ وَعِنْدَهُ رَجُلٌ مِنْ أَهْلِ الْبَادِيَةِ ‏ "‏ أَنَّ رَجُلاً مِنْ أَهْلِ الْجَنَّةِ اسْتَأْذَنَ رَبَّهُ فِي الزَّرْعِ فَقَالَ أَوَ لَسْتَ فِيمَا شِئْتَ‏.‏ قَالَ بَلَى وَلَكِنِّي أُحِبُّ أَنْ أَزْرَعَ‏.‏ فَأَسْرَعَ وَبَذَرَ فَتَبَادَرَ الطَّرْفَ نَبَاتُهُ وَاسْتِوَاؤُهُ وَاسْتِحْصَادُهُ وَتَكْوِيرُهُ أَمْثَالَ الْجِبَالِ فَيَقُولُ اللَّهُ تَعَالَى دُونَكَ يَا ابْنَ آدَمَ فَإِنَّهُ لاَ يُشْبِعُكَ شَىْءٌ ‏"‏‏.‏ فَقَالَ الأَعْرَابِيُّ يَا رَسُولَ اللَّهِ لاَ تَجِدُ هَذَا إِلاَّ قُرَشِيًّا أَوْ أَنْصَارِيًّا فَإِنَّهُمْ أَصْحَابُ زَرْعٍ، فَأَمَّا نَحْنُ فَلَسْنَا بِأَصْحَابِ زَرْعٍ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{7519}\hadithtrans{Narrated Abu Huraira:Once the Prophet (ﷺ) was preaching while a bedouin was sitting there. The Prophet (ﷺ) said, "A man from among the people of Paradise will request Allah to allow him to cultivate the land Allah will say to him, 'Haven't you got whatever you desire?' He will reply, 'yes, but I like to cultivate the land (Allah will permit him and) he will sow the seeds, and within seconds the plants will grow and ripen and (the yield) will be harvested and piled in heaps like mountains. On that Allah will say (to him), "Take, here you are, O son of Adam, for nothing satisfies you.' "On that the bedouin said, "O Allah's Messenger (ﷺ)! Such man must be either from Quraish or from Ansar, for they are farmers while we are not." On that Allah's Messenger (ﷺ) smiled}}
\hadithdefcmd{bukhari}{7520}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ عَبْدِ اللَّهِ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم أَىُّ الذَّنْبِ أَعْظَمُ عِنْدَ اللَّهِ قَالَ ‏"‏ أَنْ تَجْعَلَ لِلَّهِ نِدًّا وَهْوَ خَلَقَكَ ‏"‏‏.‏ قُلْتُ إِنَّ ذَلِكَ لَعَظِيمٌ‏.‏ قُلْتُ ثُمَّ أَىّ قَالَ ‏"‏ ثُمَّ أَنْ تَقْتُلَ وَلَدَكَ تَخَافُ أَنْ يَطْعَمَ مَعَكَ ‏"‏‏.‏ قُلْتُ ثُمَّ أَىّ قَالَ ‏"‏ ثُمَّ أَنْ تُزَانِيَ بِحَلِيلَةِ جَارِكَ ‏"‏‏.‏\hadithno{7520}\hadithtrans{Narrated `Abdullah:I asked Allah's Messenger (ﷺ) "What is the biggest sin in the sight of Allah?" He said, "To set up rivals unto Allah though He alone created you." I said, "In fact, that is a tremendous sin," and added, "What next?" He said, "To kill your son being afraid that he may share your food with you." I further asked, "What next?" He said, "To commit illegal sexual intercourse with the wife of your neighbor}}
\hadithdefcmd{bukhari}{7521}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ اجْتَمَعَ عِنْدَ الْبَيْتِ ثَقَفِيَّانِ وَقُرَشِيٌّ، أَوْ قُرَشِيَّانِ وَثَقَفِيٌّ، كَثِيرَةٌ شَحْمُ بُطُونِهِمْ قَلِيلَةٌ فِقْهُ قُلُوبِهِمْ فَقَالَ أَحَدُهُمْ أَتَرَوْنَ أَنَّ اللَّهَ يَسْمَعُ مَا نَقُولُ قَالَ الآخَرُ يَسْمَعُ إِنْ جَهَرْنَا وَلاَ يَسْمَعُ إِنْ أَخْفَيْنَا وَقَالَ الآخَرُ إِنْ كَانَ يَسْمَعُ إِذَا جَهَرْنَا فَإِنَّهُ يَسْمَعُ إِذَا أَخْفَيْنَا‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏وَمَا كُنْتُمْ تَسْتَتِرُونَ أَنْ يَشْهَدَ عَلَيْكُمْ سَمْعُكُمْ وَلاَ أَبْصَارُكُمْ وَلاَ جُلُودُكُمْ‏\}‏ الآيَةَ‏.‏\hadithno{7521}\hadithtrans{Narrated `Abdullah:Two person of Bani Thaqif and one from Quraish (or two persons from Quraish and one from Bani Thaqif) who had fat bellies but little wisdom, met near the Ka`ba. One of them said, "Did you see that Allah hears what we say? " The other said, "He hears us if we speak aloud, but He does not hear if we speak in stealthy quietness (softly)." The third fellow said, "If He hears when we speak aloud, then He surely hears us if we speak in stealthy quietness (softly)." So Allah revealed the Verse:-- 'And you have not been screening against yourselves, lest your ears, and your eyes and your skins should testify against you}}
\hadithdefcmd{bukhari}{7522}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَاتِمُ بْنُ وَرْدَانَ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَيْفَ تَسْأَلُونَ أَهْلَ الْكِتَابِ عَنْ كُتُبِهِمْ وَعِنْدَكُمْ كِتَابُ اللَّهِ أَقْرَبُ الْكُتُبِ عَهْدًا بِاللَّهِ، تَقْرَءُونَهُ مَحْضًا لَمْ يُشَبْ\hadithno{7522}\hadithtrans{Narrated `Ikrima:Ibn `Abbas said, "How can you ask the people of the Scriptures about their Books while you have Allah's Book (the Qur'an) which is the most recent of the Books revealed by Allah, and you read it in its pure undistorted form?}}
\hadithdefcmd{bukhari}{7523}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، قَالَ يَا مَعْشَرَ الْمُسْلِمِينَ كَيْفَ تَسْأَلُونَ أَهْلَ الْكِتَابِ عَنْ شَىْءٍ وَكِتَابُكُمُ الَّذِي أَنْزَلَ اللَّهُ عَلَى نَبِيِّكُمْ صلى الله عليه وسلم أَحْدَثُ الأَخْبَارِ بِاللَّهِ مَحْضًا لَمْ يُشَبْ وَقَدْ حَدَّثَكُمُ اللَّهُ أَنَّ أَهْلَ الْكِتَابِ قَدْ بَدَّلُوا مِنْ كُتُبِ اللَّهِ وَغَيَّرُوا فَكَتَبُوا بِأَيْدِيهِمْ، قَالُوا هُوَ مِنْ عِنْدِ اللَّهِ‏.‏ لِيَشْتَرُوا بِذَلِكَ ثَمَنًا قَلِيلاً، أَوَ لاَ يَنْهَاكُمْ مَا جَاءَكُمْ مِنَ الْعِلْمِ عَنْ مَسْأَلَتِهِمْ، فَلاَ وَاللَّهِ مَا رَأَيْنَا رَجُلاً مِنْهُمْ يَسْأَلُكُمْ عَنِ الَّذِي أُنْزِلَ عَلَيْكُمْ‏.‏\hadithno{7523}\hadithtrans{Narrated 'Ubaidullah bin `Abdullah:`Abdullah bin `Abbas said, "O the group of Muslims! How can you ask the people of the Scriptures about anything while your Book which Allah has revealed to your Prophet contains the most recent news from Allah and is pure and not distorted? Allah has told you that the people of the Scriptures have changed some of Allah's Books and distorted it and wrote something with their own hands and said, 'This is from Allah, so as to have a minor gain for it. Won't the knowledge that has come to you stop you from asking them? No, by Allah, we have never seen a man from them asking you about that (the Book Al-Qur'an ) which has been revealed to you}}
\hadithdefcmd{bukhari}{7524}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ تَعَالَى ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ‏\}‏ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعَالِجُ مِنَ التَّنْزِيلِ شِدَّةً، وَكَانَ يُحَرِّكُ شَفَتَيْهِ ـ فَقَالَ لِي ابْنُ عَبَّاسٍ أُحَرِّكُهُمَا لَكَ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحَرِّكُهُمَا فَقَالَ سَعِيدٌ أَنَا أُحَرِّكُهُمَا كَمَا كَانَ ابْنُ عَبَّاسٍ يُحَرِّكُهُمَا فَحَرَّكَ شَفَتَيْهِ ـ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ * إِنَّ عَلَيْنَا جَمْعَهُ وَقُرْآنَهُ‏\}‏ قَالَ جَمْعُهُ فِي صَدْرِكَ ثُمَّ تَقْرَؤُهُ‏.‏ ‏\{‏فَإِذَا قَرَأْنَاهُ فَاتَّبِعْ قُرْآنَهُ‏\}‏ قَالَ فَاسْتَمِعْ لَهُ وَأَنْصِتْ ثُمَّ إِنَّ عَلَيْنَا أَنْ تَقْرَأَهُ‏.‏ قَالَ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَاهُ جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ اسْتَمَعَ فَإِذَا انْطَلَقَ جِبْرِيلُ قَرَأَهُ النَّبِيُّ صلى الله عليه وسلم كَمَا أَقْرَأَهُ‏.‏\hadithno{7524}\hadithtrans{Narrated Musa bin Abi `Aisha:Sa`id bin Jubair reported from Ibn `Abbas (regarding the explanation of the Verse: 'Do not move your tongue concerning (the Qur'an) to make haste therewith) . He said, "The Prophet (ﷺ) used to undergo great difficulty in receiving the Divine Inspiration and used to move his lips.' Ibn `Abbas said (to Sa`id), "I move them (my lips) as Allah's Messenger (ﷺ) used to move his lips." And Sa`id said (to me), "I move my lips as I saw Ibn `Abbas moving his lips," and then he moved his lips. So Allah revealed:-- '(O Muhammad!) Do not move your tongue concerning (the Qur'an) to make haste therewith. It is for Us to collect it and give you (O Muhammad) the ability to recite it. (i.e., to collect it in your chest and then you recite it).' (75.16-17) But when We have recited it, to you (O Muhammad through Gabriel) then follow you its recital.' (75.18) This means, "You should listen to it and keep quiet and then it is upon Us to make you recite it." The narrator added, "So Allah's Messenger (ﷺ) used to listen whenever Gabriel came to him, and when Gabriel left, the Prophet (ﷺ) would recite the Qur'an as Gabriel had recited it to him}}
\hadithdefcmd{bukhari}{7525}{حَدَّثَنِي عَمْرُو بْنُ زُرَارَةَ، عَنْ هُشَيْمٍ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ فِي قَوْلِهِ تَعَالَى ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏ قَالَ نَزَلَتْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُخْتَفٍ بِمَكَّةَ، فَكَانَ إِذَا صَلَّى بِأَصْحَابِهِ رَفَعَ صَوْتَهُ بِالْقُرْآنِ، فَإِذَا سَمِعَهُ الْمُشْرِكُونَ سَبُّوا الْقُرْآنَ وَمَنْ أَنْزَلَهُ وَمَنْ جَاءَ بِهِ، فَقَالَ اللَّهُ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ‏\}‏ أَىْ بِقِرَاءَتِكَ، فَيَسْمَعَ الْمُشْرِكُونَ، فَيَسُبُّوا الْقُرْآنَ ‏\{‏وَلاَ تُخَافِتْ بِهَا‏\}‏ عَنْ أَصْحَابِكَ فَلاَ تُسْمِعُهُمْ ‏\{‏وَابْتَغِ بَيْنَ ذَلِكَ سَبِيلاً‏\}‏\hadithno{7525}\hadithtrans{Narrated Ibn `Abbas:regarding the explanation of the Verse:-- '(O Muhammad!) Neither say your prayer aloud, nor say it in a low tone.' (17.110) This Verse was revealed while Allah's Messenger (ﷺ) was hiding himself at Mecca. At that time, when he led his companions in prayer, he used to raise his voice while reciting the Qur'an; and if the pagans heard him, they would abuse the Qur'an, its Revealer, and the one who brought it. So Allah said to His Prophet: "Neither say your prayer aloud. i.e., your recitation (of Qur'an) lest the pagans should hear (it) and abuse the Qur'an" nor say it in a low tone, "lest your voice should fail to reach your companions, "but follow a way between}}
\hadithdefcmd{bukhari}{7526}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏ فِي الدُّعَاءِ‏.‏\hadithno{7526}\hadithtrans{Narrated `Aisha:The Verse:-- '(O Muhammad!) Neither say your prayer aloud nor say it in a low tone.' (17.110) was revealed in connection with the invocations}}
\hadithdefcmd{bukhari}{7527}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ مِنَّا مَنْ لَمْ يَتَغَنَّ بِالْقُرْآنِ ‏"‏‏.‏ وَزَادَ غَيْرُهُ ‏"‏ يَجْهَرُ بِهِ ‏"‏‏.‏\hadithno{7527}\hadithtrans{Narrated Abu Salama:Abu Huraira said, "Allah's Messenger (ﷺ) said, 'Whoever does not recite Qur'an in a nice voice is not from us,' and others said extra," (that means) to recite it aloud}}
\hadithdefcmd{bukhari}{7528}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحَاسُدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ الْقُرْآنَ فَهْوَ يَتْلُوهُ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ، فَهْوَ يَقُولُ لَوْ أُوتِيتُ مِثْلَ مَا أُوتِيَ هَذَا، لَفَعَلْتُ كَمَا يَفْعَلُ‏.‏ وَرَجُلٌ آتَاهُ اللَّهُ مَالاً فَهْوَ يُنْفِقُهُ فِي حَقِّهِ فَيَقُولُ لَوْ أُوتِيتُ مِثْلَ مَا أُوتِيَ عَمِلْتُ فِيهِ مِثْلَ مَا يَعْمَلُ ‏"‏‏.‏\hadithno{7528}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Not to wish to be the like of except the like of two men: a man whom Allah has given the Qur'an and he recites it during the hours of the night and the hours of the day, in which case one may say, "If I were given the same as this man has been given, I would do the same as he is doing.' The other is a man whom Allah has given wealth and he spends it in the right way, in which case one may say, 'If I were given the same as he has been given, I would do the same as he is doing}}
\hadithdefcmd{bukhari}{7529}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ الْقُرْآنَ فَهْوَ يَتْلُوهُ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ، وَرَجُلٌ آتَاهُ اللَّهُ مَالاً فَهْوَ يُنْفِقُهُ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ ‏"‏‏.‏ سَمِعْتُ سُفْيَانَ مِرَارًا لَمْ أَسْمَعْهُ يَذْكُرُ الْخَبَرَ وَهْوَ مِنْ صَحِيحِ حَدِيثِهِ‏.‏\hadithno{7529}\hadithtrans{Narrated Salim's father:The Prophet (ﷺ) said, "Not to wish to be the like of except the like of two (persons): a man whom Allah has given the knowledge of the Qur'an and he recites it during the hours of the night and the hours of the day; and a man whom Allah has given wealth and he spends it (in Allah's Cause) during the hours of the night and during the hours of the day}}
\hadithdefcmd{bukhari}{7530}{حَدَّثَنَا الْفَضْلُ بْنُ يَعْقُوبَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدِ اللَّهِ الثَّقَفِيُّ، حَدَّثَنَا بَكْرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، وَزِيَادُ بْنُ جُبَيْرِ بْنِ حَيَّةَ، عَنْ جُبَيْرِ بْنِ حَيَّةَ، قَالَ الْمُغِيرَةُ أَخْبَرَنَا نَبِيُّنَا، صلى الله عليه وسلم عَنْ رِسَالَةِ، رَبِّنَا ‏ "‏ أَنَّهُ مَنْ قُتِلَ مِنَّا صَارَ إِلَى الْجَنَّةِ ‏"‏‏.‏\hadithno{7530}\hadithtrans{Narrated Al-Mughira:Our Prophet has informed us our Lord's Message that whoever of us is martyred, will go to Paradise}}
\hadithdefcmd{bukhari}{7531}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَنْ حَدَّثَكَ أَنَّ مُحَمَّدًا صلى الله عليه وسلم كَتَمَ شَيْئًا وَقَالَ مُحَمَّدٌ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ حَدَّثَنَا شُعْبَةُ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ عَنِ الشَّعْبِيِّ عَنْ مَسْرُوقٍ عَنْ عَائِشَةَ قَالَتْ مَنْ حَدَّثَكَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَتَمَ شَيْئًا مِنَ الْوَحْىِ، فَلاَ تُصَدِّقْهُ، إِنَّ اللَّهَ تَعَالَى يَقُولُ ‏\{‏يَا أَيُّهَا الرَّسُولُ بَلِّغْ مَا أُنْزِلَ إِلَيْكَ مِنْ رَبِّكَ وَإِنْ لَمْ تَفْعَلْ فَمَا بَلَّغْتَ رِسَالَتَهُ‏\}‏\hadithno{7531}\hadithtrans{Narrated `Aisha:Whoever tells you that the Prophet (ﷺ) concealed something of the Divine Inspiration, do not believe him, for Allah said: 'O Apostle Muhammad! Proclaim (the Message) which has been sent down to you from your Lord, and if you do it not, then you have not conveyed His Message}}
\hadithdefcmd{bukhari}{7532}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، قَالَ قَالَ عَبْدُ اللَّهِ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَىُّ الذَّنْبِ أَكْبَرُ عِنْدَ اللَّهِ قَالَ ‏"‏ أَنْ تَدْعُوَ لِلَّهِ نِدًّا، وَهْوَ خَلَقَكَ ‏"‏‏.‏ قَالَ ثُمَّ أَىّ قَالَ ‏"‏ ثُمَّ أَنْ تَقْتُلَ وَلَدَكَ، أَنْ يَطْعَمَ مَعَكَ ‏"‏‏.‏ قَالَ ثُمَّ أَىّ قَالَ ‏"‏ أَنْ تُزَانِيَ حَلِيلَةَ جَارِكَ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَهَا ‏\{‏وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَلاَ يَزْنُونَ وَمَنْ يَفْعَلْ ذَلِكَ‏\}‏ الآيَةَ‏.‏\hadithno{7532}\hadithtrans{Narrated `Abdullah:A man said, "O Allah's Messenger (ﷺ)! Which sin is the biggest in Allah's Sight?" The Prophet (ﷺ) said, "To set up rivals unto Allah though He Alone created you." That man said, "What is next?" The Prophet (ﷺ) said, "To kill your son lest he should share your food with you.'' The man said, "What is next?" The Prophet said, "To commit illegal sexual intercourse with the wife of your neighbor." Then Allah revealed in confirmation of that: "And those who invoke not with Allah any other god, nor kill such life as Allah has made sacred except for just cause, nor commit illegal sexual intercourse and whoever does this shall receive the punishment}}
\hadithdefcmd{bukhari}{7533}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا بَقَاؤُكُمْ فِيمَنْ سَلَفَ مِنَ الأُمَمِ كَمَا بَيْنَ صَلاَةِ الْعَصْرِ إِلَى غُرُوبِ الشَّمْسِ، أُوتِيَ أَهْلُ التَّوْرَاةِ التَّوْرَاةَ فَعَمِلُوا بِهَا حَتَّى انْتَصَفَ النَّهَارُ، ثُمَّ عَجَزُوا فَأُعْطُوا قِيرَاطًا قِيرَاطًا، ثُمَّ أُوتِيَ أَهْلُ الإِنْجِيلِ الإِنْجِيلَ فَعَمِلُوا بِهِ حَتَّى صُلِّيَتِ الْعَصْرُ، ثُمَّ عَجَزُوا فَأُعْطُوا قِيرَاطًا قِيرَاطًا، ثُمَّ أُوتِيتُمُ الْقُرْآنَ فَعَمِلْتُمْ بِهِ حَتَّى غَرَبَتِ الشَّمْسُ، فَأُعْطِيتُمْ قِيرَاطَيْنِ قِيرَاطَيْنِ، فَقَالَ أَهْلُ الْكِتَابِ هَؤُلاَءِ أَقَلُّ مِنَّا عَمَلاً وَأَكْثَرُ أَجْرًا‏.‏ قَالَ اللَّهُ هَلْ ظَلَمْتُكُمْ مِنْ حَقِّكُمْ شَيْئًا قَالُوا لاَ‏.‏ قَالَ فَهْوَ فَضْلِي أُوتِيهِ مَنْ أَشَاءُ ‏"‏‏.‏\hadithno{7533}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Your stay (in this world) in comparison to the stay of the nations preceding you, is like the period between `Asr prayer and the sun set (in comparison to a whole day). The people of the Torah were given the Torah and they acted on it till midday and then they were unable to carry on. And they were given (a reward equal to) one Qirat each. Then the people of the Gospel were given the Gospel and they acted on it till `Asr Prayer and then they were unable to carry on, so they were given la reward equal to) one Qirat each. Then you were given the Qur'an and you acted on it till sunset, therefore you were given (a reward equal to) two Qirats each. On that, the people of the Scriptures said, 'These people (Muslims) did less work than we but they took a bigger reward.' Allah said (to them). 'Have I done any oppression to you as regards your rights?' They said, "No." Then Allah said, 'That is My Blessing which I grant to whomsoever I will}}
\hadithdefcmd{bukhari}{7534}{حَدَّثَنِي سُلَيْمَانُ، حَدَّثَنَا شُعْبَةُ، عَنِ الْوَلِيدِ،‏.‏ وَحَدَّثَنِي عَبَّادُ بْنُ يَعْقُوبَ الأَسَدِيُّ، أَخْبَرَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنِ الشَّيْبَانِيِّ، عَنِ الْوَلِيدِ بْنِ الْعَيْزَارِ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏ "‏ الصَّلاَةُ لِوَقْتِهَا، وَبِرُّ الْوَالِدَيْنِ، ثُمَّ الْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{7534}\hadithtrans{Narrated Ibn Mas`ud:A man asked the Prophet (ﷺ) "What deeds are the best?" The Prophet (ﷺ) said: "(1) To perform the (daily compulsory) prayers at their (early) stated fixed times, (2) to be good and dutiful to one's own parents, (3) and to participate in Jihad in Allah's Cause}}
\hadithdefcmd{bukhari}{7535}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنِ الْحَسَنِ، حَدَّثَنَا عَمْرُو بْنُ تَغْلِبَ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم مَالٌ فَأَعْطَى قَوْمًا وَمَنَعَ آخَرِينَ فَبَلَغَهُ أَنَّهُمْ عَتَبُوا فَقَالَ ‏ "‏ إِنِّي أُعْطِي الرَّجُلَ وَأَدَعُ الرَّجُلَ، وَالَّذِي أَدَعُ أَحَبُّ إِلَىَّ مِنَ الَّذِي أُعْطِي، أُعْطِي أَقْوَامًا لِمَا فِي قُلُوبِهِمْ مِنَ الْجَزَعِ وَالْهَلَعِ، وَأَكِلُ أَقْوَامًا إِلَى مَا جَعَلَ اللَّهُ فِي قُلُوبِهِمْ مِنَ الْغِنَى وَالْخَيْرِ مِنْهُمْ عَمْرُو بْنُ تَغْلِبَ ‏"‏‏.‏ فَقَالَ عَمْرٌو مَا أُحِبُّ أَنَّ لِي بِكَلِمَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم حُمْرَ النَّعَمِ‏.‏\hadithno{7535}\hadithtrans{Narrated Al-Hasan:`Amr bin Taghlib said, "Some property was given to the Prophet (ﷺ) and he gave it to some people and withheld it from some others. Then he came to know that they (the latter) were dissatisfied. So the Prophet said, 'I give to one man and leave (do not give) another, and the one to whom I do not give is dearer to me than the one to whom I give. I give to some people because of the impatience and discontent present in their hearts, and leave other people because of the content and goodness Allah has bestowed on them, and one of them is `Amr bin Taghlib." `Amr bin Taghlib said, "The sentence which Allah's Messenger (ﷺ) said in my favor is dearer to me than the possession of nice red camels}}
\hadithdefcmd{bukhari}{7536}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا أَبُو زَيْدٍ، سَعِيدُ بْنُ الرَّبِيعِ الْهَرَوِيُّ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم يَرْوِيهِ عَنْ رَبِّهِ، قَالَ ‏ "‏ إِذَا تَقَرَّبَ الْعَبْدُ إِلَىَّ شِبْرًا تَقَرَّبْتُ إِلَيْهِ ذِرَاعًا، وَإِذَا تَقَرَّبَ مِنِّي ذِرَاعًا تَقَرَّبْتُ مِنْهُ بَاعًا، وَإِذَا أَتَانِي مَشْيًا أَتَيْتُهُ هَرْوَلَةً ‏"‏‏.‏\hadithno{7536}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "My Lord says, 'If My slave comes nearer to me for a span, I go nearer to him for a cubit; and if he comes nearer to Me for a cubit, I go nearer to him for the span of outstretched arms; and if he comes to Me walking, I go to him running}}
\hadithdefcmd{bukhari}{7537}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنِ التَّيْمِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ـ رُبَّمَا ذَكَرَ النَّبِيَّ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا تَقَرَّبَ الْعَبْدُ مِنِّي شِبْرًا تَقَرَّبْتُ مِنْهُ ذِرَاعًا وَإِذَا تَقَرَّبَ مِنِّي ذِرَاعًا تَقَرَّبْتُ مِنْهُ بَاعًا أَوْ بُوعًا ‏"‏‏.‏ وَقَالَ مُعْتَمِرٌ سَمِعْتُ أَبِي، سَمِعْتُ أَنَسًا، ‏\{‏عَنْ أَبِي هُرَيْرَةَ،‏\}‏ عَنِ النَّبِيِّ صلى الله عليه وسلم يَرْوِيهِ عَنْ رَبِّهِ، عَزَّ وَجَلَّ‏.‏\hadithno{7537}\hadithtrans{Narrated Abu Huraira:Perhaps the Prophet (ﷺ) mentioned the following (as Allah's Saying): "If My slave comes nearer to Me for a span, I go nearer to him for a cubit; and if he comes nearer to Me for a cubit; I go nearer to him for the span of outstretched arms. (See Hadith No)}}
\hadithdefcmd{bukhari}{7538}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم يَرْوِيهِ عَنْ رَبِّكُمْ، قَالَ ‏ "‏ لِكُلِّ عَمَلٍ كَفَّارَةٌ، وَالصَّوْمُ لِي وَأَنَا أَجْزِي بِهِ، وَلَخَلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏‏.‏\hadithno{7538}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said that your Lord said, "Every (sinful) deed can be expiated; and the fast is for Me, so I will give the reward for it; and the smell which comes out of the mouth of a fasting person, is better in Allah's Sight than the smell of musk." (See Hadith No)}}
\hadithdefcmd{bukhari}{7539}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ،‏.‏ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم فِيمَا يَرْوِيهِ عَنْ رَبِّهِ قَالَ ‏ "‏ لاَ يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ إِنَّهُ خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏ وَنَسَبَهُ إِلَى أَبِيهِ‏.‏\hadithno{7539}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said that his Lord said: "It does not befit a slave that he should say that he is better than Jonah (Yunus) bin Matta}}
\hadithdefcmd{bukhari}{7540}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي سُرَيْجٍ، أَخْبَرَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ الْمُزَنِيِّ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ عَلَى نَاقَةٍ لَهُ يَقْرَأُ سُورَةَ الْفَتْحِ، أَوْ مِنْ سُورَةِ الْفَتْحِ ـ قَالَ ـ فَرَجَّعَ فِيهَا ـ قَالَ ـ ثُمَّ قَرَأَ مُعَاوِيَةُ يَحْكِي قِرَاءَةَ ابْنِ مُغَفَّلٍ وَقَالَ ‏ "‏ لَوْلاَ أَنْ يَجْتَمِعَ النَّاسُ عَلَيْكُمْ لَرَجَّعْتُ كَمَا رَجَّعَ ابْنُ مُغَفَّلٍ ‏"‏‏.‏ يَحْكِي النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ لِمُعَاوِيَةَ كَيْفَ كَانَ تَرْجِيعُهُ قَالَ آ آ آ ثَلاَثَ مَرَّاتٍ‏.‏\hadithno{7540}\hadithtrans{Narrated Shu`ba:Mu'awiya bin Qurra reported that `Abdullah bin Al-Maghaffal Al-Muzani said, "I saw Allah's Messenger (ﷺ) on the day of the Conquest of Mecca, riding his she-camel and reciting Surat-al-Fath (48) or part of Surat-al-Fath. He recited it in a vibrating and pleasant voice. Then Mu'awiya recited as `Abdullah bin Mughaffal had done and said, "Were I not afraid that the people would crowd around me, I would surely recite in a vibrating pleasant voice as Ibn Mughaffal did, imitating the Prophet." I asked Muawiya, "How did he recite in that tone?" He said thrice, "A, A , A}}
\hadithdefcmd{bukhari}{7541}{وَقَالَ ابْنُ عَبَّاسٍ أَخْبَرَنِي أَبُو سُفْيَانَ بْنُ حَرْبٍ، أَنَّ هِرَقْلَ، دَعَا تَرْجُمَانَهُ، ثُمَّ دَعَا بِكِتَابِ النَّبِيِّ صلى الله عليه وسلم فَقَرَأَهُ ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ مِنْ مُحَمَّدٍ عَبْدِ اللَّهِ وَرَسُولِهِ إِلَى هِرَقْلَ، وَ‏\{‏يَا أَهْلَ الْكِتَابِ تَعَالَوْا إِلَى كَلِمَةٍ سَوَاءٍ بَيْنَنَا وَبَيْنَكُمْ ‏\}‏‏"‏ الآيَةَ‏.‏\hadithno{7541}\hadithtrans{And Ibn 'Abbas narrated:Abu Sufyan bin Harb told me that Heraclius called for his translator and then asked for the letter of the Prophet (ﷺ), and the former read it (thus): "In the Name of Allah, the Most Gracious, the Merciful. (This letter is) from Muhammad bin 'Abdullah, to Heraclius. "...O people of the Scripture (Jews and Christians): Come to a word that is just between us and you that we worship none but Allah..." (V.3:)}}
\hadithdefcmd{bukhari}{7542}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ أَهْلُ الْكِتَابِ يَقْرَءُونَ التَّوْرَاةَ بِالْعِبْرَانِيَّةِ، وَيُفَسِّرُونَهَا بِالْعَرَبِيَّةِ لأَهْلِ الإِسْلاَمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُصَدِّقُوا أَهْلَ الْكِتَابِ، وَلاَ تُكَذِّبُوهُمْ وَ‏\{‏قُولُوا آمَنَّا بِاللَّهِ وَمَا أُنْزِلَ‏\}‏ الآيَةَ ‏"‏‏.‏\hadithno{7542}\hadithtrans{Narrated Abu Huraira:The people of the Scripture used to read the Torah in Hebrew and explain it to the Muslims in Arabic. Then Allah's Messenger (ﷺ) said, "Do not believe the people of the Scripture, and do not disbelieve them, but say, 'We believe in Allah and whatever has been revealed}}
\hadithdefcmd{bukhari}{7543}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِرَجُلٍ وَامْرَأَةٍ مِنَ الْيَهُودِ قَدْ زَنَيَا فَقَالَ لِلْيَهُودِ ‏"‏ مَا تَصْنَعُونَ بِهِمَا ‏"‏‏.‏ قَالُوا نُسَخِّمُ وُجُوهَهُمَا وَنُخْزِيهِمَا‏.‏ قَالَ ‏"‏ ‏\{‏فَأْتُوا بِالتَّوْرَاةِ فَاتْلُوهَا إِنْ كُنْتُمْ صَادِقِينَ‏\}‏ ‏"‏‏.‏ فَجَاءُوا فَقَالُوا لِرَجُلٍ مِمَّنْ يَرْضَوْنَ يَا أَعْوَرُ اقْرَأْ‏.‏ فَقَرَأَ حَتَّى انْتَهَى عَلَى مَوْضِعٍ مِنْهَا فَوَضَعَ يَدَهُ عَلَيْهِ‏.‏ قَالَ ‏"‏ ارْفَعْ يَدَكَ ‏"‏‏.‏ فَرَفَعَ يَدَهُ فَإِذَا فِيهِ آيَةُ الرَّجْمِ تَلُوحُ فَقَالَ يَا مُحَمَّدُ إِنَّ عَلَيْهِمَا الرَّجْمَ‏.‏ وَلَكِنَّا نُكَاتِمُهُ بَيْنَنَا‏.‏ فَأَمَرَ بِهِمَا فَرُجِمَا، فَرَأَيْتُهُ يُجَانِئُ عَلَيْهَا الْحِجَارَةَ‏.‏\hadithno{7543}\hadithtrans{Narrated Ibn `Umar:A Jew and Jewess were brought to the Prophet (ﷺ) on a charge of committing an illegal sexual intercourse. The Prophet (ﷺ) asked the Jews, "What do you (usually) do with them?" They said, "We blacken their faces and disgrace them." He said, "Bring here the Torah and recite it, if you are truthful." They (fetched it and) came and asked a one-eyed man to recite. He went on reciting till he reached a portion on which he put his hand. The Prophet (ﷺ) said, "Lift up your hand!" He lifted his hand up and behold, there appeared the verse of Ar-Rajm (stoning of the adulterers to death). Then he said, "O Muhammad! They should be stoned to death but we conceal this Divine Law among ourselves." Then the Prophet (ﷺ) ordered that the two sinners be stoned to death and, and they were stoned to death, and I saw the man protecting the woman from the stones. (See Hadith No. 809, Vol)}}
\hadithdefcmd{bukhari}{7544}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنِي ابْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا أَذِنَ اللَّهُ لِشَىْءٍ مَا أَذِنَ لِنَبِيٍّ حَسَنِ الصَّوْتِ بِالْقُرْآنِ يَجْهَرُ بِهِ ‏"‏‏.‏\hadithno{7544}\hadithtrans{Narrated Abu Huraira:that he heard the Prophet (ﷺ) saying, "Allah does not listen to anything as He listens to the recitation of the Qur'an by a Prophet who recites it in attractive audible sweet sounding voice}}
\hadithdefcmd{bukhari}{7545}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، وَعَلْقَمَةُ بْنُ وَقَّاصٍ، وَعُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنْ حَدِيثِ، عَائِشَةَ حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ مَا قَالُوا ـ وَكُلٌّ حَدَّثَنِي طَائِفَةً مِنَ الْحَدِيثِ ـ قَالَتْ فَاضْطَجَعْتُ عَلَى فِرَاشِي، وَأَنَا حِينَئِذٍ أَعْلَمُ أَنِّي بَرِيئَةٌ وَأَنَّ اللَّهَ يُبَرِّئُنِي، وَلَكِنْ وَاللَّهِ مَا كُنْتُ أَظُنُّ أَنَّ اللَّهَ يُنْزِلُ فِي شَأْنِي وَحْيًا يُتْلَى، وَلَشَأْنِي فِي نَفْسِي كَانَ أَحْقَرَ مِنْ أَنْ يَتَكَلَّمَ اللَّهُ فِيَّ بِأَمْرٍ يُتْلَى، وَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏إِنَّ الَّذِينَ جَاءُوا بِالإِفْكِ‏\}‏ الْعَشْرَ الآيَاتِ كُلَّهَا‏.‏\hadithno{7545}\hadithtrans{Narrated `Aisha:(when the slanderers said what they said about her): I went to my bed knowing at that time that I was innocent and that Allah would reveal my innocence, but by Allah, I never thought that Allah would reveal in my favor a revelation which would be recited, for I considered myself too unimportant to be talked about by Allah in the Divine Revelation that was to be recited. So Allah revealed the ten Verses (of Surat-an-Nur). 'Those who brought a false charge}}
\hadithdefcmd{bukhari}{7546}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مِسْعَرٌ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، أُرَاهُ عَنِ الْبَرَاءِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْعِشَاءِ ‏\{‏وَالتِّينِ وَالزَّيْتُونِ‏\}‏ فَمَا سَمِعْتُ أَحَدًا أَحْسَنَ صَوْتًا أَوْ قِرَاءَةً مِنْهُ‏.‏\hadithno{7546}\hadithtrans{Narrated Al-Bara':I heard the Prophet (ﷺ) reciting Surat at-Tin waz Zaitun (By the Fig and the Olive) in the `Isha' prayer and I have never heard anybody with a better voice or recitation than his}}
\hadithdefcmd{bukhari}{7547}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم مُتَوَارِيًا بِمَكَّةَ، وَكَانَ يَرْفَعُ صَوْتَهُ، فَإِذَا سَمِعَ الْمُشْرِكُونَ سَبُّوا الْقُرْآنَ وَمَنْ جَاءَ بِهِ، فَقَالَ اللَّهُ عَزَّ وَجَلَّ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏\hadithno{7547}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was hiding himself in Mecca and used to recite the (Qur'an) in a loud voice. When the pagans heard him they would abuse the Qur'an and the one who brought it, so Allah said to His Prophet: 'Neither say your prayer aloud, nor say it in a low tone}}
\hadithdefcmd{bukhari}{7548}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ قَالَ لَهُ ‏ "‏ إِنِّي أَرَاكَ تُحِبُّ الْغَنَمَ وَالْبَادِيَةَ، فَإِذَا كُنْتَ فِي غَنَمِكَ أَوْ بَادِيَتِكَ فَأَذَّنْتَ لِلصَّلاَةِ فَارْفَعْ صَوْتَكَ بِالنِّدَاءِ، فَإِنَّهُ لاَ يَسْمَعُ مَدَى صَوْتِ الْمُؤَذِّنِ جِنٌّ وَلاَ إِنْسٌ وَلاَ شَىْءٌ، إِلاَّ شَهِدَ لَهُ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{7548}\hadithtrans{Narrated `Abdullah bin `Abdur-Rahman:that Abu Sa`id Al-Khudri said to him, "I see that you like sheep and the desert, so when you are looking after your sheep or when you are in the desert and want to pronounce the Adhan, raise your voice, for no Jinn, human being or any other things hear the Mu`adh-dhin's voice but will be a witness for him on the Day of Resurrection." Abu Sa`id added, "I heard this from Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{7549}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ الْقُرْآنَ وَرَأْسُهُ فِي حَجْرِي وَأَنَا حَائِضٌ‏.‏\hadithno{7549}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to recite the Qur'an with his head in my lap while I used to be in my periods (having menses)}}
\hadithdefcmd{bukhari}{7550}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، وَعَبْدَ الرَّحْمَنِ بْنَ عَبْدٍ الْقَارِيَّ، حَدَّثَاهُ أَنَّهُمَا، سَمِعَا عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَمَعْتُ لِقِرَاءَتِهِ، فَإِذَا هُوَ يَقْرَأُ عَلَى حُرُوفٍ كَثِيرَةٍ لَمْ يُقْرِئْنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم، فَكِدْتُ أُسَاوِرُهُ فِي الصَّلاَةِ، فَتَصَبَّرْتُ حَتَّى سَلَّمَ، فَلَبَبْتُهُ بِرِدَائِهِ فَقُلْتُ مَنْ أَقْرَأَكَ هَذِهِ السُّورَةَ الَّتِي سَمِعْتُكَ تَقْرَأُ قَالَ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ كَذَبْتَ، أَقْرَأَنِيهَا عَلَى غَيْرِ مَا قَرَأْتَ‏.‏ فَانْطَلَقْتُ بِهِ أَقُودُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى حُرُوفٍ لَمْ تُقْرِئْنِيهَا‏.‏ فَقَالَ ‏"‏ أَرْسِلْهُ، اقْرَأْ يَا هِشَامُ ‏"‏‏.‏ فَقَرَأَ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَذَلِكَ أُنْزِلَتْ ‏"‏‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ يَا عُمَرُ ‏"‏‏.‏ فَقَرَأْتُ الَّتِي أَقْرَأَنِي فَقَالَ ‏"‏ كَذَلِكَ أُنْزِلَتْ، إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏"‏‏.‏\hadithno{7550}\hadithtrans{Narrated `Umar bin Al-Khattab:I heard Hisham bin Hakim reciting Surat-al-Furqan during the lifetime of Allah's Messenger (ﷺ), I listened to his recitation and noticed that he was reciting in a way that Allah's Messenger (ﷺ) had not taught me. I was about to jump over him while He was still in prayer, but I waited patiently and when he finished his prayer, I put my sheet round his neck (and pulled him) and said, "Who has taught you this Sura which I have heard you reciting?" Hisham said, "Allah's Messenger (ﷺ) taught it to me." I said, "You are telling a lie, for he taught it to me in a way different from the way you have recited it!" Then I started leading (dragged) him to Allah's Messenger (ﷺ) and said (to the Prophet), " I have heard this man reciting Surat-al- Furqan in a way that you have not taught me." The Prophet (ﷺ) said: "(O `Umar) release him! Recite, O Hisham." Hisham recited in the way I heard him reciting. Allah's Messenger (ﷺ) said, "It was revealed like this." Then Allah's Messenger (ﷺ) said, "Recite, O `Umar!" I recited in the way he had taught me, whereupon he said, "It was revealed like this," and added, "The Qur'an has been revealed to be recited in seven different ways, so recite of it whichever is easy for you ." (See Hadith No. 514, Vol)}}
\hadithdefcmd{bukhari}{7551}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ يَزِيدُ حَدَّثَنِي مُطَرِّفُ بْنُ عَبْدِ اللَّهِ، عَنْ عِمْرَانَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ فِيمَا يَعْمَلُ الْعَامِلُونَ قَالَ ‏ "‏ كُلٌّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ ‏"‏‏.‏\hadithno{7551}\hadithtrans{Narrated `Imran:I said, "O Allah's Messenger (ﷺ)! Why should a doer (people) try to do good deeds?' The Prophet (ﷺ) said, "Everybody will find easy to do such deeds as will lead him to his destined place for which he has been created}}
\hadithdefcmd{bukhari}{7552}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، سَمِعَا سَعْدَ بْنَ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ فِي جِنَازَةٍ فَأَخَذَ عُودًا فَجَعَلَ يَنْكُتُ فِي الأَرْضِ فَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ كُتِبَ مَقْعَدُهُ مِنَ النَّارِ أَوْ مِنَ الْجَنَّةِ ‏"‏‏.‏ قَالُوا أَلاَ نَتَّكِلُ‏.‏ قَالَ ‏"‏ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ ‏\{‏فَأَمَّا مَنْ أَعْطَى وَاتَّقَى‏\}‏ ‏"‏‏.‏ الآيَةَ‏.‏\hadithno{7552}\hadithtrans{Narrated `Ali:While the Prophet (ﷺ) was in a funeral procession, he took a stick and started scraping the earth with it and said, "There is none of you but has his place assigned either in Hell or in Paradise." They (the people) said, "Shall we not depend upon that (and give up doing any deeds)?' He said, " Carry on doing (good deeds) for everybody will find it easy to do such deeds as will lead him to his destined place for which he has been created ." (And then the Prophet (ﷺ) recited the Verse):-- 'As for him who gives (in charity) and keeps his duty to Allah}}
\hadithdefcmd{bukhari}{7553}{وَقَالَ لِي خَلِيفَةُ بْنُ خَيَّاطٍ حَدَّثَنَا مُعْتَمِرٌ، سَمِعْتُ أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَمَّا قَضَى اللَّهُ الْخَلْقَ كَتَبَ كِتَابًا عِنْدَهُ غَلَبَتْ ـ أَوْ قَالَ سَبَقَتْ ـ رَحْمَتِي غَضَبِي‏.‏ فَهْوَ عِنْدَهُ فَوْقَ الْعَرْشِ ‏"‏‏.‏\hadithno{7553}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "Before Allah created the creations, He wrote a Book (wherein He has written): My Mercy has preceded my Anger." and that (Book) is written with Him over the Throne}}
\hadithdefcmd{bukhari}{7554}{حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي غَالِبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُعْتَمِرٌ، سَمِعْتُ أَبِي يَقُولُ، حَدَّثَنَا قَتَادَةُ، أَنَّ أَبَا رَافِعٍ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ كَتَبَ كِتَابًا قَبْلَ أَنْ يَخْلُقَ الْخَلْقَ إِنَّ رَحْمَتِي سَبَقَتْ غَضَبِي‏.‏ فَهْوَ مَكْتُوبٌ عِنْدَهُ فَوْقَ الْعَرْشِ ‏"‏‏.‏\hadithno{7554}\hadithtrans{Narrated Abu Hurairah (ra):I heard Allah's Messenger (ﷺ) saying: "Before Allah created the creations, He wrote a Book (wherein He has written): "My Mercy has preceded my Anger.' And that is written with Him over the Throne." (see Hadith)}}
\hadithdefcmd{bukhari}{7555}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، وَالْقَاسِمِ التَّمِيمِيِّ، عَنْ زَهْدَمٍ، قَالَ كَانَ بَيْنَ هَذَا الْحَىِّ مِنْ جُرْمٍ وَبَيْنَ الأَشْعَرِيِّينَ وُدٌّ وَإِخَاءٌ، فَكُنَّا عِنْدَ أَبِي مُوسَى الأَشْعَرِيِّ فَقُرِّبَ إِلَيْهِ الطَّعَامُ فِيهِ لَحْمُ دَجَاجٍ، وَعِنْدَهُ رَجُلٌ مِنْ بَنِي تَيْمِ اللَّهِ كَأَنَّهُ مِنَ الْمَوَالِي، فَدَعَاهُ إِلَيْهِ فَقَالَ إِنِّي رَأَيْتُهُ يَأْكُلُ شَيْئًا ف��قَذِرْتُهُ، فَحَلَفْتُ لاَ آكُلُهُ‏.‏ فَقَالَ هَلُمَّ فَلأُحَدِّثْكَ عَنْ ذَاكَ، إِنِّي أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي نَفَرٍ مِنَ الأَشْعَرِيِّينَ نَسْتَحْمِلُهُ قَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ وَمَا عِنْدِي مَا أَحْمِلُكُمْ ‏"‏‏.‏ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِنَهْبِ إِبِلٍ فَسَأَلَ عَنَّا فَقَالَ ‏"‏ أَيْنَ النَّفَرُ الأَشْعَرِيُّونَ ‏"‏‏.‏ فَأَمَرَ لَنَا بِخَمْسِ ذَوْدٍ غُرِّ الذُّرَى، ثُمَّ انْطَلَقْنَا قُلْنَا مَا صَنَعْنَا حَلَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَحْمِلُنَا، وَمَا عِنْدَهُ مَا يَحْمِلُنَا، ثُمَّ حَمَلَنَا، تَغَفَّلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَمِينَهُ، وَاللَّهِ لاَ نُفْلِحُ أَبَدًا، فَرَجَعْنَا إِلَيْهِ فَقُلْنَا لَهُ فَقَالَ ‏"‏ لَسْتُ أَنَا أَحْمِلُكُمْ، وَلَكِنَّ اللَّهَ حَمَلَكُمْ، إِنِّي وَاللَّهِ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا، إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ مِنْهُ، وَتَحَلَّلْتُهَا ‏"‏‏.‏\hadithno{7555}\hadithtrans{Narrated Zahdam:There were good relations and brotherhood between this tribe of Jurm and the Ash`ariyyin. Once, while we were sitting with Abu Musa Al-Ash`ari, there was brought to him a meal which contained chicken meat, and there was sitting beside him, a man from the tribe of Bani Taimul-lah who looked like one of the Mawali. Abu Musa invited the man to eat but the man said, "I have seen chicken eating some dirty things, and I have taken an oath not to eat chicken." Abu Musa said to him, "Come along, let me tell you something in this regard. Once I went to the Prophet (ﷺ) with a few men from Ash`ariyyin and we asked him for mounts. The Prophet (ﷺ) said, By Allah, I will not mount you on anything; besides I do not have anything to mount you on.' Then a few camels from the war booty were brought to the Prophet, and he asked about us, saying, 'Where are the group of Ash`ariyyin?' So he ordered for five fat camels to be given to us and then we set out. We said, 'What have we done? Allah's Messenger (ﷺ) took an oath that he would not give us anything to ride and that he had nothing for us to ride, yet he provided us with mounts. We made Allah's Messenger (ﷺ) forget his oath! By Allah, we will never be successful.' So we returned to him and reminded him of his oath. He said, 'I have not provided you with the mount, but Allah has done so. By Allah, I may take an oath to do something, but on finding something else which is better, I do that which is better and make the expiation for my oath}}
\hadithdefcmd{bukhari}{7556}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو جَمْرَةَ الضُّبَعِيُّ، قُلْتُ لاِبْنِ عَبَّاسٍ فَقَالَ قَدِمَ وَفْدُ عَبْدِ الْقَيْسِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا إِنَّ بَيْنَنَا وَبَيْنَكَ الْمُشْرِكِينَ مِنْ مُضَرَ، وَإِنَّا لاَ نَصِلُ إِلَيْكَ إِلاَّ فِي أَشْهُرٍ حُرُمٍ، فَمُرْنَا بِجُمَلٍ مِنَ الأَمْرِ، إِنْ عَمِلْنَا بِهِ دَخَلْنَا الْجَنَّةَ، وَنَدْعُو إِلَيْهَا مَنْ وَرَاءَنَا‏.‏ قَالَ ‏ "‏ آمُرُكُمْ بِأَرْبَعٍ وَأَنْهَاكُمْ عَنْ أَرْبَعٍ، آمُرُكُمْ بِالإِيمَانِ بِاللَّهِ، وَهَلْ تَدْرُونَ مَا الإِيمَانُ بِاللَّهِ شَهَادَةُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَإِقَامُ الصَّلاَةِ، وَإِيتَاءُ الزَّكَاةِ، وَتُعْطُوا مِنَ الْمَغْنَمِ الْخُمُسَ، وَأَنْهَاكُمْ عَنْ أَرْبَعٍ لاَ تَشْرَبُوا فِي الدُّبَّاءِ، وَالنَّقِيرِ، وَالظُّرُوفِ الْمُزَفَّتَةِ، وَالْحَنْتَمَةِ ‏"‏‏.‏\hadithno{7556}\hadithtrans{Narrated Ibn `Abbas:The delegates of `Abdul Qais came to Allah's Messenger (ﷺ) and said, "The pagans of the tribe of Mudar intervene between you and us therefore we cannot come to you except in the Holy months. So please order us to do something good (Religious deeds) by which we may enter Paradise (by acting on them) and we may inform our people whom we have left behind to observe it." The Prophet (ﷺ) said, "I order you to do four things and forbid you from four things: I order you to believe in Allah. Do you know what is meant by belief in Allah? It is to testify that none has the right to be worshipped except Allah, to offer prayers perfectly, to give Zakat, and to give Al-Khumus (one-fifth of the war booty) (in Allah's Cause). And I forbid you four things, (i.e., Do not drink alcoholic drinks) Ad-Dubba, An- Naqir, (pitched water skins), Az-Zuruf, Al-Muzaffat and Al--Hantam (names of utensils used for the preparation of alcoholic drinks)." (See Hadith No. 50, Vol)}}
\hadithdefcmd{bukhari}{7557}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ، وَيُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏‏.‏\hadithno{7557}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) said, "The painter of these pictures will be punished on the Day of Resurrection, and it will be said to them, Make alive what you have created}}
\hadithdefcmd{bukhari}{7558}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ، وَيُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏‏.‏\hadithno{7558}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The painters of these pictures will be punished on the Day of Resurrection, and it will be said to them, 'Make alive what you have created}}
\hadithdefcmd{bukhari}{7559}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ وَمَنْ أَظْلَمُ مِمَّنْ ذَهَبَ يَخْلُقُ كَخَلْقِي، فَلْيَخْلُقُوا ذَرَّةً، أَوْ لِيَخْلُقُوا حَبَّةً أَوْ شَعِيرَةً ‏"‏‏.‏\hadithno{7559}\hadithtrans{Narrated Abu Huraira:I heard the Prophet (ﷺ) saying, "Allah said, 'Who are most unjust than those who try to create something like My creation? I challenge them to create even a smallest ant, a wheat grain or a barley grain}}
\hadithdefcmd{bukhari}{7560}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسٌ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْمُؤْمِنِ الَّذِي يَقْرَأُ الْقُرْآنَ كَالأُتْرُجَّةِ، طَعْمُهَا طَيِّبٌ وَرِيحُهَا طَيِّبٌ، وَالَّذِي لاَ يَقْرَأُ كَالتَّمْرَةِ، طَعْمُهَا طَيِّبٌ وَلاَ رِيحَ لَهَا، وَمَثَلُ الْفَاجِرِ الَّذِي يَقْرَأُ الْقُرْآنَ كَمَثَلِ الرَّيْحَانَةِ، رِيحُهَا طَيِّبٌ وَطَعْمُهَا مُرٌّ، وَمَثَلُ الْفَاجِرِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ الْحَنْظَلَةِ، طَعْمُهَا مُرٌّ وَلاَ رِيحَ لَهَا ‏"‏‏.‏\hadithno{7560}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, 'The example of a believer who recites the Qur'an is that of a citron (a citrus fruit) which is good in taste and good in smell. And the believer who does not recite the Qur'an is like a date which has a good taste but no smell. And the example of an impious person who recites the Qur'an is that of Ar-Rihana (an aromatic plant) which smells good but is bitter in taste. And the example of an impious person who does not recite the Qur'an is that of a colocynth which is bitter in taste and has no smell}}
\hadithdefcmd{bukhari}{7561}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنِي أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي يَحْيَى بْنُ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّهُ سَمِعَ عُرْوَةَ بْنَ الزُّبَيْرِ، قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ سَأَلَ أُنَاسٌ النَّبِيَّ صلى الله عليه وسلم عَنِ الْكُهَّانِ فَقَالَ ‏"‏ إِنَّهُمْ لَيْسُوا بِشَىْءٍ ‏"‏‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ فَإِنَّهُمْ يُحَدِّثُونَ بِالشَّىْءِ يَكُونُ حَقًّا‏.‏ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تِلْكَ الْكَلِمَةُ مِنَ الْحَقِّ يَخْطَفُهَا الْجِنِّيُّ فَيُقَرْقِرُهَا فِي أُذُنِ وَلِيِّهِ كَقَرْقَرَةِ الدَّجَاجَةِ، فَيَخْلِطُونَ فِيهِ أَكْثَرَ مِنْ مِائَةِ كَذْبَةٍ ‏"‏‏.‏\hadithno{7561}\hadithtrans{Narrated `Aisha:Some people asked the Prophet (ﷺ) regarding the soothsayers. He said, "They are nothing." They said, "O Allah's Messenger (ﷺ)! Some of their talks come true." The Prophet (ﷺ) said, "That word which happens to be true is what a Jinn snatches away by stealth (from the Heaven) and pours it in the ears of his friend (the foreteller) with a sound like the cackling of a hen. The soothsayers then mix with that word, one hundred lies}}
\hadithdefcmd{bukhari}{7562}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، سَمِعْتُ مُحَمَّدَ بْنَ سِيرِينَ، يُحَدِّثُ عَنْ مَعْبَدِ بْنِ سِيرِينَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يَخْرُجُ نَاسٌ مِنْ قِبَلِ الْمَشْرِقِ وَيَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ، يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، ثُمَّ لاَ يَعُودُونَ فِيهِ حَتَّى يَعُودَ السَّهْمُ إِلَى فُوقِهِ ‏"‏‏.‏ قِيلَ مَا سِيمَاهُمْ‏.‏ قَالَ ‏"‏ سِيمَاهُمُ التَّحْلِيقُ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ التَّسْبِيدُ ‏"‏‏.‏\hadithno{7562}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "There will emerge from the East some people who will recite the Qur'an but it will not exceed their throats and who will go out of (renounce) the religion (Islam) as an arrow passes through the game, and they will never come back to it unless the arrow, comes back to the middle of the bow (by itself) (i.e., impossible). The people asked, "What will their signs be?" He said, "Their sign will be the habit of shaving (of their beards and their heads). (Fath-ul-Bari, Page 322, Vol. 17th)}}
\hadithdefcmd{bukhari}{7563}{حَدَّثَنِي أَحْمَدُ بْنُ إِشْكَابٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كَلِمَتَانِ حَبِيبَتَانِ إِلَى الرَّحْمَنِ، خَفِيفَتَانِ عَلَى اللِّسَانِ، ثَقِيلَتَانِ فِي الْمِيزَانِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ، سُبْحَانَ اللَّهِ الْعَظِيمِ ‏"‏ ‏.‏\hadithno{7563}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "(There are) two words which are dear to the Beneficent (Allah) and very light (easy) for the tongue (to say), but very heavy in weight in the balance. They are: ''Subhan Allah wa-bi hamdihi'' and ''Subhan Allah Al-`Azim." (see Hadith)}}
