% Auto-generated chapter 0 for ibnmajah
% Hadiths in this chapter: 266

\hadithdefcmd{ibnmajah}{1}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالَ: حَدَّثَنَا شَرِيكٌ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ قَالَ: قَالَ رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ: «مَا أَمَرْتُكُمْ بِهِ فَخُذُوهُ وَمَا نَهَيْتُكُمْ عَنْهُ فَانْتَهُوا»\hadithno{1}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "Whatever I have commanded you do it, and whatever I have forbidden you, refrain from it}}
\hadithdefcmd{ibnmajah}{2}{حَدَّثَنَا أَبُو عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ذَرُونِي مَا تَرَكْتُكُمْ فَإِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ بِسُؤَالِهِمْ وَاخْتِلاَفِهِمْ عَلَى أَنْبِيَائِهِمْ فَإِذَا أَمَرْتُكُمْ بِشَىْءٍ فَخُذُوا مِنْهُ مَا اسْتَطَعْتُمْ وَإِذَا نَهَيْتُكُمْ عَنْ شَىْءٍ فَانْتَهُوا ‏"‏ ‏.‏\hadithno{2}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "Leave me as I have left you (Don't ask me the minor things that I have avoided to tell you). For those who came before you were doomed because of their questions and differences with their Prophets. If I commanded you to do something, then do as much of it as you can, and if I forbid you from doing something, then refrain from it}}
\hadithdefcmd{ibnmajah}{3}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ وَمَنْ عَصَانِي فَقَدْ عَصَى اللَّهَ ‏"‏ ‏.‏\hadithno{3}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "Whoever obeys me, obeys Allah; and whoever disobeys me, disobeys Allah}}
\hadithdefcmd{ibnmajah}{4}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا زَكَرِيَّا بْنُ عَدِيٍّ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ أَبِي جَعْفَرٍ، قَالَ كَانَ ابْنُ عُمَرَ إِذَا سَمِعَ مِنْ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَدِيثًا لَمْ يَعْدُهُ وَلَمْ يُقَصِّرْ دُونَهُ ‏.‏\hadithno{4}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Ja'far said:"Whenever Ibn 'Umar heard a Hadith from the Messanger of Allah (ﷺ), he would not do more than it said, and he would not do less}}
\hadithdefcmd{ibnmajah}{5}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ الدِّمَشْقِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى بْنِ سُمَيْعٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سُلَيْمَانَ الأَفْطَسُ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ الْجُرَشِيِّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَحْنُ نَذْكُرُ الْفَقْرَ وَنَتَخَوَّفُهُ فَقَالَ ‏ "‏ آلْفَقْرَ تَخَافُونَ وَالَّذِي نَفْسِي بِيَدِهِ لَتُصَبَّنَّ عَلَيْكُمُ الدُّنْيَا صَبًّا حَتَّى لاَ يُزِيغَ قَلْبَ أَحَدٍ مِنْكُمْ إِزَاغَةً إِلاَّ هِيَهْ وَايْمُ اللَّهِ لَقَدْ تَرَكْتُكُمْ عَلَى مِثْلِ الْبَيْضَاءِ لَيْلُهَا وَنَهَارُهَا سَوَاءٌ ‏"‏ ‏.‏ قَالَ أَبُو الدَّرْدَاءِ صَدَقَ وَاللَّهِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ تَرَكَنَا وَاللَّهِ عَلَى مِثْلِ الْبَيْضَاءِ لَيْلُهَا وَنَهَارُهَا سَوَاءٌ ‏.‏\hadithno{5}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Darda' said:"The Messenger of Allah (ﷺ) came out to us when we were speaking of poverty and how we feared it. He said: 'Is it poverty that you fear? By the One in Whose Hand is my soul, (the delights and luxuries of) this world will come to you in plenty, and nothing will cause the heart of anyone of you to deviate except that. By Allah, I am leaving you upon something like Bayda (white, bright, clear path) the night and day of which are the same}}
\hadithdefcmd{ibnmajah}{6}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي مَنْصُورِينَ لاَ يَضُرُّهُمْ مَنْ خَذَلَهُمْ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏\hadithno{6}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu'awiyah bin Qurrah narrated that his father said:The Messenger of Allah (ﷺ) said: "A group of my Ummah will continue to prevail and they will never be harmed by those who forsake them, until the Hour begins}}
\hadithdefcmd{ibnmajah}{7}{حَدَّثَنَا أَبُو عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، قَالَ حَدَّثَنَا أَبُو عَلْقَمَةَ، نَصْرُ بْنُ عَلْقَمَةَ عَنْ عُمَيْرِ بْنِ الأَسْوَدِ، وَكَثِيرِ بْنِ مُرَّةَ الْحَضْرَمِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي قَوَّامَةً عَلَى أَمْرِ اللَّهِ لاَ يَضُرُّهَا مَنْ خَالَفَهَا ‏"‏ ‏.‏\hadithno{7}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah (ﷺ) said: "A group of my Ummah will continue to adhere steadfastly to the command of Allah and those who oppose them will not be able to harm them}}
\hadithdefcmd{ibnmajah}{8}{حَدَّثَنَا أَبُو عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْجَرَّاحُ بْنُ مَلِيحٍ، حَدَّثَنَا بَكْرُ بْنُ زُرْعَةَ، قَالَ سَمِعْتُ أَبَا عِنَبَةَ الْخَوْلاَنِيَّ، وَكَانَ، قَدْ صَلَّى الْقِبْلَتَيْنِ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ يَزَالُ اللَّهُ يَغْرِسُ فِي هَذَا الدِّينِ غَرْسًا يَسْتَعْمِلُهُمْ فِي طَاعَتِهِ ‏"‏ ‏.‏\hadithno{8}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu 'Inabah Al-Khawlani said that:The Messenger of Allah (ﷺ) said: "Allah will continue to plant new people in this religion and use them in His obedience}}
\hadithdefcmd{ibnmajah}{9}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْقَاسِمُ بْنُ نَافِعٍ، حَدَّثَنَا الْحَجَّاجُ بْنُ أَرْطَاةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، قَالَ قَامَ مُعَاوِيَةُ خَطِيبًا فَقَالَ أَيْنَ عُلَمَاؤُكُمْ أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ تَقُومُ السَّاعَةُ إِلاَّ وَطَائِفَةٌ مِنْ أُمَّتِي ظَاهِرُونَ عَلَى النَّاسِ لاَ يُبَالُونَ مَنْ خَذَلَهُمْ وَلاَ مَنْ نَصَرَهُمْ ‏"‏ ‏.‏\hadithno{9}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Amr bin Shu'aib narrated that:His father said: "Mu'awiyah stood up to deliver a sermon and said: 'Where are your scholars? Where are your scholars? For I heard the Messenger of Allah (ﷺ) say: The Hour will not begin until a group of my Ummah will prevail over the people, and they will not care who lets them down and who supports them}}
\hadithdefcmd{ibnmajah}{10}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، حَدَّثَنَا سَعِيدُ بْنُ بَشِيرٍ، عَنْ قَتَادَةَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَزَالُ طَائِفَةٌ مِنْ أُمَّتِي عَلَى الْحَقِّ مَنْصُورِينَ لاَ يَضُرُّهُمْ مَنْ خَالَفَهُمْ حَتَّى يَأْتِيَ أَمْرُ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{10}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Thawban that:The Messenger of Allah (ﷺ) said: "A group among my Ummah will continue to follow the truth and prevail, and those who oppose them will not be able to harm them, until the command of Allah comes to pass}}
\hadithdefcmd{ibnmajah}{11}{حَدَّثَنَا أَبُو سَعِيدٍ عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، قَالَ سَمِعْتُ مُجَالِدًا، يَذْكُرُ عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَخَطَّ خَطًّا وَخَطَّ خَطَّيْنِ عَنْ يَمِينِهِ وَخَطَّ خَطَّيْنِ عَنْ يَسَارِهِ ثُمَّ وَضَعَ يَدَهُ فِي الْخَطِّ الأَوْسَطِ فَقَالَ ‏"‏ هَذَا سَبِيلُ اللَّهِ ‏"‏ ‏.‏ ثُمَّ تَلاَ هَذِهِ الآيَةَ \{وَأَنَّ هَذَا صِرَاطِي مُسْتَقِيمًا فَاتَّبِعُوهُ وَلاَ تَتَّبِعُوا السُّبُلَ فَتَفَرَّقَ بِكُمْ عَنْ سَبِيلِهِ\}‏ ‏.‏\hadithno{11}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin 'Abdullah said that:We were with the Prophet (ﷺ), and he drew a line (in the sand), then he drew two lines to its right and two to its left. Then he put his hand on the middle line and said : 'This is the path of Allah. Then he recited the Verse: And verily, this (i.e. Allah's Commandments) is My straight path, so follow it and follow not (other) paths, for they will separate you from His path}}
\hadithdefcmd{ibnmajah}{12}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، حَدَّثَنِي الْحَسَنُ بْنُ جَابِرٍ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ الْكِنْدِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يُوشِكُ الرَّجُلُ مُتَّكِئًا عَلَى أَرِيكَتِهِ يُحَدَّثُ بِحَدِيثٍ مِنْ حَدِيثِي فَيَقُولُ بَيْنَنَا وَبَيْنَكُمْ كِتَابُ اللَّهِ عَزَّ وَجَلَّ فَمَا وَجَدْنَا فِيهِ مِنْ حَلاَلٍ اسْتَحْلَلْنَاهُ وَمَا وَجَدْنَا فِيهِ مِنْ حَرَامٍ حَرَّمْنَاهُ ‏.‏ أَلاَ وَإِنَّ مَا حَرَّمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِثْلُ مَا حَرَّمَ اللَّهُ ‏"‏ ‏.‏\hadithno{12}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Miqdam bin Ma'dikarib Al-Kindi narrated that:The Messenger of Allah (ﷺ) said: "Soon there will come a time that a man will be reclining on his pillow, and when one of my Ahadith is narrated he will say: 'The Book of Allah is (sufficient) between us and you. Whatever it states is permissible, we will take as permissible, and whatever it states is forbidden, we will take as forbidden.' Verily, whatever the Messenger of Allah (ﷺ) has forbidden is like that which Allah has forbidden}}
\hadithdefcmd{ibnmajah}{13}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، فِي بَيْتِهِ أَنَا سَأَلْتُهُ، عَنْ سَالِمٍ أَبِي النَّضْرِ، ثُمَّ مَرَّ فِي الْحَدِيثِ قَالَ أَوْ زَيْدِ بْنِ أَسْلَمَ عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ عَنْ أَبِيهِ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ مُتَّكِئًا عَلَى أَرِيكَتِهِ يَأْتِيهِ الأَمْرُ مِمَّا أَمَرْتُ بِهِ أَوْ نَهَيْتُ عَنْهُ فَيَقُولُ لاَ أَدْرِي مَا وَجَدْنَا فِي كِتَابِ اللَّهِ اتَّبَعْنَاهُ ‏"‏ ‏.‏\hadithno{13}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ubaidullah bin Abu Rafi from his father, that:The Messenger of Allah (ﷺ) said: "I do not want to find anyone of you reclining on his pillow, and when bad news comes to him of something that I have commanded or forbidden, he says, 'I do not know, whatever we find in the Book of Allah, we will follow}}
\hadithdefcmd{ibnmajah}{14}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِيهِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَحْدَثَ فِي أَمْرِنَا هَذَا مَا لَيْسَ مِنْهُ فَهُوَ رَدٌّ ‏"‏ ‏.‏\hadithno{14}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Aishah narrated that:The Messenger of Allah (ﷺ) said: "Whoever innovates something in this matter of ours (i.e. Islam) that is not part of it, will have it rejected}}
\hadithdefcmd{ibnmajah}{15}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ رَجُلاً مِنَ الأَنْصَارِ خَاصَمَ الزُّبَيْرَ عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي شِرَاجِ الْحَرَّةِ الَّتِي يَسْقُونَ بِهَا النَّخْلَ فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ يَمُرُّ ‏.‏ فَأَبَى عَلَيْهِ فَاخْتَصَمَا عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلِ الْمَاءَ إِلَى جَارِكَ ‏"‏ ‏.‏ فَغَضِبَ الأَنْصَارِيُّ فَقَالَ يَا رَسُولَ اللَّهِ أَنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ قَالَ ‏"‏ يَا زُبَيْرُ اسْقِ ثُمَّ احْبِسِ الْمَاءَ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏ ‏.‏ قَالَ فَقَالَ الزُّبَيْرُ وَاللَّهِ إِنِّي لأَحْسَبُ هَذِهِ الآيَةَ نَزَلَتْ فِي ذَلِكَ \{فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ ثُمَّ لاَ يَجِدُوا فِي أَنْفُسِهِمْ حَرَجًا مِمَّا قَضَيْتَ وَيُسَلِّمُوا تَسْلِيمًا\}‏ ‏.‏\hadithno{15}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Urwah bin Zubair that 'Abdullah bin Zubair told him that:A man from the Ansar had a dispute with Zubair in the presence of the Messenger of Allah (ﷺ) concerning a stream in the Harrah which they used to irrigate the date-palm trees. The Ansari said: "Let the water flow" but Zubair refused. So they referred that dispute to the Messenger of Allah (ﷺ) who said: "Irrigate (your land), O Zubair., and then let the water flow to your neighbor." The Ansari became angry and said "O Messenger of Allah, is it because he is your cousin?" The face of the Messenger of Allah (ﷺ) changed color (because of anger) and he said: "O Zubair, irrigate (your land) then block the water until it flows back to the walls around the date-palm trees." Zubair said: "By Allah, I think that this verse was revealed concerning this matter. ' But no, by your Lord, they can have no Faith, until they make you (O Muhammad) judge in all disputes between them, and find in themselves no resistance against your decisions, and accept (them) with full submission}}
\hadithdefcmd{ibnmajah}{16}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَمْنَعُوا إِمَاءَ اللَّهِ أَنْ يُصَلِّينَ فِي الْمَسْجِدِ ‏"‏ ‏.‏ فَقَالَ ابْنٌ لَهُ إِنَّا لَنَمْنَعُهُنَّ ‏.‏ فَقَالَ فَغَضِبَ غَضَبًا شَدِيدًا وَقَالَ إِنِّي أُحَدِّثُكَ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَإِنَّكَ تَقُولُ إِنَّا لَنَمْنَعُهُنَّ ‏.‏\hadithno{16}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn Umar that:The Messenger of Allah (ﷺ) said:" Do not prevent the female slaves of Allah from praying in the mosque." A son of his said: We will indeed prevent them!" He got very angry and said: "I tell you a Hadith from the Messenger of Allah (ﷺ) and you say, we will indeed prevent them?}}
\hadithdefcmd{ibnmajah}{17}{حَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، وَأَبُو عُمَرَ حَفْصُ بْنُ عَمْرٍو قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا أَيُّوبُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّهُ كَانَ جَالِسًا إِلَى جَنْبِهِ ابْنُ أَخٍ لَهُ فَخَذَفَ فَنَهَاهُ وَقَالَ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْهَا وَقَالَ ‏ "‏ إِنَّهَا لاَ تَصِيدُ صَيْدًا وَلاَ تَنْكِي عَدُوًّا وَإِنَّهَا تَكْسِرُ السِّنَّ وَتَفْقَأُ الْعَيْنَ ‏"‏ ‏.‏ قَالَ فَعَادَ ابْنُ أَخِيهِ يَخْذِفُ فَقَالَ أُحَدِّثُكَ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْهَا ثُمَّ عُدْتَ تَخْذِفُ لاَ أُكَلِّمُكَ أَبَدًا ‏.‏\hadithno{17}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sa'eed bin Jubair that :Abdullah bin Mughaffal was sitting beside a nephew of his, the nephew hurled a pebble and he told him not to do that, and he said: "The Messenger of Allah (ﷺ) had forbidden that. He (the Prophet) said: 'It cannot be used for hunting and it cannot harm an enemy, but it may break a tooth or put an eye out." He said." His nephew hurled another pebble and he ("Abdullah bin Mughaffal) said: 'I tell you that the Messenger of Allah forbade that (and you go hurl another pebble)? I will never speak to you again}}
\hadithdefcmd{ibnmajah}{18}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي بُرْدُ بْنُ سِنَانٍ، عَنْ إِسْحَاقَ بْنِ قَبِيصَةَ، عَنْ أَبِيهِ، أَنَّ عُبَادَةَ بْنَ الصَّامِتِ الأَنْصَارِيَّ النَّقِيبَ، صَاحِبَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ غَزَا مَعَ مُعَاوِيَةَ أَرْضَ الرُّومِ فَنَظَرَ إِلَى النَّاسِ وَهُمْ يَتَبَايَعُونَ كِسَرَ الذَّهَبِ بِالدَّنَانِيرِ وَكِسَرَ الْفِضَّةِ بِالدَّرَاهِمِ فَقَالَ يَا أَيُّهَا النَّاسُ إِنَّكُمْ تَأْكُلُونَ الرِّبَا سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ تَبْتَاعُوا الذَّهَبَ بِالذَّهَبِ إِلاَّ مِثْلاً بِمِثْلٍ لاَ زِيَادَةَ بَيْنَهُمَا وَلاَ نَظِرَةَ ‏"‏ ‏.‏ فَقَالَ لَهُ مُعَاوِيَةُ يَا أَبَا الْوَلِيدِ لاَ أَرَى الرِّبَا فِي هَذَا إِلاَّ مَا كَانَ مِنْ نَظِرَةٍ ‏.‏ فَقَالَ عُبَادَةُ أُحَدِّثُكَ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَتُحَدِّثُنِي عَنْ رَأْيِكَ لَئِنْ أَخْرَجَنِي اللَّهُ لاَ أُسَاكِنْكَ بِأَرْضٍ لَكَ عَلَىَّ فِيهَا إِمْرَةٌ ‏.‏ فَلَمَّا قَفَلَ لَحِقَ بِالْمَدِينَةِ فَقَالَ لَهُ عُمَرُ بْنُ الْخَطَّابِ مَا أَقْدَمَكَ يَا أَبَا الْوَلِيدِ فَقَصَّ عَلَيْهِ الْقِصَّةَ وَمَا قَالَ مِنْ مُسَاكَنَتِهِ فَقَالَ ارْجِعْ يَا أَبَا الْوَلِيدِ إِلَى أَرْضِكَ فَقَبَحَ اللَّهُ أَرْضًا لَسْتَ فِيهَا وَأَمْثَالُكَ ‏.‏ وَكَتَبَ إِلَى مُعَاوِيَةَ لاَ إِمْرَةَ لَكَ عَلَيْهِ وَاحْمِلِ النَّاسَ عَلَى مَا قَالَ فَإِنَّهُ هُوَ الأَمْرُ ‏.‏\hadithno{18}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ishaq bin Qabisah from his father that :Ubadah bin Samit Al-Ansari, head of the army unit, the Companion of the Messenger of Allah (ﷺ), went on a military campaign with Mu'awiyah in the land of the Byzantines. He saw people trading pieces of gold for Dinar and pieces of silver for Dirham. He said: "O people, you are consuming Riba (usury)! For I heard the Messenger of Allah (ﷺ) say: 'Do not sell gold for gold unless it is like for like; there should be no increase and no delay (between the two transactions).'" Mu'awiyah said to him: "O Abu Walid, I do not think there is any Riba involved in this , except in cases where there is a delay." 'Ubadah said to him: "I tell you a Hadith from the Messenger of Allah (ﷺ) and you tell me your opinion! If Allah brings me back safely I will never live in a land in which you have authority over me." When he returned, he stayed in Al-Madinah, and 'Umar bin Khattab said to him: "What brought you here, O Abu Walid?" So he told him the story, and what he had said about not living in the same land as Mu'awiyah. 'Umar said: "Go back to your land, O Abu Walid, for what a bad land is the land from where you and people like you are absent." Then he wrote to Mu'awiyah and said: "You have no authority over him; make the people follow what he says , for he is right}}
\hadithdefcmd{ibnmajah}{19}{حَدَّثَنَا أَبُو بَكْرِ بْنُ الْخَلاَّدِ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنِ ابْنِ عَجْلاَنَ، أَنْبَأَنَا عَوْنُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ إِذَا حَدَّثْتُكُمْ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَظُنُّوا بِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ الَّذِي هُوَ أَهْنَاهُ وَأَهْدَاهُ وَأَتْقَاهُ ‏.‏\hadithno{19}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud said:"When I tell you of a Hadith from the Messenger of Alllah (ﷺ), then think of the Messenger of Allah (ﷺ) as being the best, the utmost rightly guided and the one with the utmost Taqwa (piety, righteousness)}}
\hadithdefcmd{ibnmajah}{20}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ إِذَا حَدَّثْتُكُمْ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِحَدِيثٍ فَظُنُّوا بِهِ الَّذِي هُوَ أَهْنَاهُ وَأَهْدَاهُ وَأَتْقَاهُ ‏.‏\hadithno{20}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ali bin Abu Talib said :"When I narrate a Hadith from the Messenger of Allah (ﷺ), to you, then think of him as being the best, the most rightly guided and the one with the utmost Taqwa (piety, righteousness)}}
\hadithdefcmd{ibnmajah}{21}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، حَدَّثَنَا الْمَقْبُرِيُّ، عَنْ جَدِّهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ لاَ أَعْرِفَنَّ مَا يُحَدَّثُ أَحَدُكُمْ عَنِّي الْحَدِيثَ وَهُوَ مُتَّكِئٌ عَلَى أَرِيكَتِهِ فَيَقُولُ اقْرَأْ قُرْآنًا ‏.‏ مَا قِيلَ مِنْ قَوْلٍ حَسَنٍ فَأَنَا قُلْتُهُ ‏"‏ ‏.‏\hadithno{21}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that :The Prophet said "I do not want to hear of anyone of you who, upon hearing a Hadith narrated from me, says while reclining on his pillow: 'Recite Qur'an (to verify this Hadith).' (Here the Propher SAW said) Any excellent word that is said, it is I who have said it." [How can you reject what I have said?]}}
\hadithdefcmd{ibnmajah}{22}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادِ بْنِ آدَمَ، حَدَّثَنَا أَبِي، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ لِرَجُلٍ يَا ابْنَ أَخِي إِذَا حَدَّثْتُكَ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَدِيثًا فَلاَ تَضْرِبْ لَهُ الأَمْثَالَ ‏.‏ قَالَ أَبُو الْحَسَنِ حَدَّثَنَا يَحْيَى بْنُ عَبْدِ اللَّهِ الْكَرَابِيسِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، مِثْلَ حَدِيثِ عَلِيٍّ رضى الله تعالى عنه ‏.‏\hadithno{22}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Salamah that :Abu Hurairah said to a man "O son of my brother, when I narrate a Hadith of the Messenger of Allah (ﷺ), to you, then do not try to make any examples for it}}
\hadithdefcmd{ibnmajah}{23}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنِ ابْنِ عَوْنٍ، حَدَّثَنَا مُسْلِمٌ الْبَطِينُ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ مَا أَخْطَأَنِي ابْنُ مَسْعُودٍ عَشِيَّةَ خَمِيسٍ إِلاَّ أَتَيْتُهُ فِيهِ قَالَ فَمَا سَمِعْتُهُ يَقُولُ لِشَىْءٍ قَطُّ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمَّا كَانَ ذَاتَ عَشِيَّةٍ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ - قَالَ فَنَكَسَ ‏.‏ قَالَ فَنَظَرْتُ إِلَيْهِ فَهُوَ قَائِمٌ مُحَلَّلَةً أَزْرَارُ قَمِيصِهِ قَدِ اغْرَوْرَقَتْ عَيْنَاهُ وَانْتَفَخَتْ أَوْدَاجُهُ قَالَ أَوْ دُونَ ذَلِكَ أَوْ فَوْقَ ذَلِكَ أَوْ قَرِيبًا مِنْ ذَلِكَ أَوْ شَبِيهًا بِذَلِكَ ‏.‏\hadithno{23}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Amr bin Maimun said :"I used to visit Ibn Mas'ud every Thursday afternoon but he never uttered the words: 'The Messenger of Allah (ﷺ) said.' Then one evening, he said: 'The Messenger of Allah (ﷺ) said,' then he let his head hang down." He said: "I looked at him and saw his shirt was unfastened; his eyes were filled with tears, and his veins were bulging out (with fear). He said:' Or more than that, or less than that, or close to that or something similar}}
\hadithdefcmd{ibnmajah}{24}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ كَانَ أَنَسُ بْنُ مَالِكٍ إِذَا حَدَّثَ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَدِيثًا فَفَرَغَ مِنْهُ قَالَ أَوْ كَمَا قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{24}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin Sirin said :"Whenever Anas bin Malik finished narrating a Hadith from the Messenger of Allah (ﷺ), he would say, 'Or as the Messenger of Allah (ﷺ) said}}
\hadithdefcmd{ibnmajah}{25}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ قُلْنَا لِزَيْدِ بْنِ أَرْقَمَ حَدِّثْنَا عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ كَبِرْنَا وَنَسِينَا وَالْحَدِيثُ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ شَدِيدٌ ‏.‏\hadithno{25}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdur-Rahman bin Abi Laila said:We said to Zaid bin Arqam: 'Tell us a Hadith from the Messenger of Allah (ﷺ).' He said: 'We have grown old and have forgotten, and (narrating) Ahadith from the Messenger of Allah (ﷺ) is difficult (not a simple matter)}}
\hadithdefcmd{ibnmajah}{26}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو النَّضْرِ، عَنْ شُعْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، قَالَ سَمِعْتُ الشَّعْبِيَّ، يَقُولُ جَالَسْتُ ابْنَ عُمَرَ سَنَةً فَمَا سَمِعْتُهُ يُحَدِّثُ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ شَيْئًا ‏.‏\hadithno{26}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Abdullah bin Abu Safar said:"I heard Ash-Sha'bi saying: 'I sat with Ibn 'Umar for a year and I did not hear him narrate anything from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{ibnmajah}{27}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ إِنَّمَا كُنَّا نَحْفَظُ الْحَدِيثَ وَالْحَدِيثُ يُحْفَظُ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَمَّا إِذَا رَكِبْتُمُ الصَّعْبَ وَالذَّلُولَ فَهَيْهَاتَ ‏.‏\hadithno{27}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Tawus that his father said:"I heard Ibn 'Abbas saying: 'We used to memorize Ahadith, and Ahadith were memorized from the Messenger of Allah (ﷺ). But if you go to the extremes of either exaggeration or negligence (in narrating Ahadith), there is no way we can trust your Ahadith}}
\hadithdefcmd{ibnmajah}{28}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ قَرَظَةَ بْنِ كَعْبٍ، قَالَ بَعَثَنَا عُمَرُ بْنُ الْخَطَّابِ إِلَى الْكُوفَةِ وَشَيَّعَنَا فَمَشَى مَعَنَا إِلَى مَوْضِعٍ يُقَالُ لَهُ صِرَارٌ ‏.‏ فَقَالَ أَتَدْرُونَ لِمَ مَشَيْتُ مَعَكُمْ قَالَ قُلْنَا لِحَقِّ صُحْبَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَلِحَقِّ الأَنْصَارِ ‏.‏ قَالَ لَكِنِّي مَشَيْتُ مَعَكُمْ لِحَدِيثٍ أَرَدْتُ أَنْ أُحَدِّثَكُمْ بِهِ فَأَرَدْتُ أَنْ تَحْفَظُوهُ لِمَمْشَاىَ مَعَكُمْ إِنَّكُمْ تَقْدُمُونَ عَلَى قَوْمٍ لِلْقُرْآنِ فِي صُدُورِهِمْ هَزِيزٌ كَهَزِيزِ الْمِرْجَلِ فَإِذَا رَأَوْكُمْ مَدُّوا إِلَيْكُمْ أَعْنَاقَهُمْ وَقَالُوا أَصْحَابُ مُحَمَّدٍ ‏.‏ فَأَقِلُّوا الرِّوَايَةَ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ أَنَا شَرِيكُكُمْ ‏.‏\hadithno{28}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qarazah bin Ka'b said:"Umar bin Al-Khattab sent us to Kufah, and he accompanied us as far as a place called Sirar. He said: 'Do you know why I walked with you?' We said: 'Because of the rights of the Messenger of Allah (ﷺ) and because of the rights of the Ansar.' He said: 'No, rather it is because of words that I wanted to say to you. I wanted you to memorize it due to my walking with you. You are going to people in whose hearts the Qur'an bubbles like water in a copper cauldron. When they see you, they will look up at you, saying: "The Companions of Muhammad!" But do not recite many reports from the Messenger of Allah (ﷺ), then I will be your partner}}
\hadithdefcmd{ibnmajah}{29}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ صَحِبْتُ سَعْدَ بْنَ مَالِكٍ مِنَ الْمَدِينَةِ إِلَى مَكَّةَ فَمَا سَمِعْتُهُ يُحَدِّثُ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِحَدِيثٍ وَاحِدٍ ‏.‏\hadithno{29}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sa'ib bin Yazid said:"I accompanied Sa'd bin Malik from Al-Madinah to Makkah and I did not hear him narrate a single Hadith from the Prophet (ﷺ)}}
\hadithdefcmd{ibnmajah}{30}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَعَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، وَإِسْمَاعِيلُ بْنُ مُوسَى، قَالُوا حَدَّثَنَا شَرِيكٌ، عَنْ سِمَاكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{30}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin 'Abdullah bin Mas'ud that his father said:"The Messenger of Allah (ﷺ) said: 'Whoever tells lies about me deliberately, let him take his place in Hell}}
\hadithdefcmd{ibnmajah}{31}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، وَإِسْمَاعِيلُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا شَرِيكٌ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَكْذِبُوا عَلَىَّ فَإِنَّ الْكَذِبَ عَلَىَّ يُولِجُ النَّارَ ‏"‏ ‏.‏\hadithno{31}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from that 'Ali said:"The Messenger of Allah (ﷺ) said: 'Do not tell lies about me, for telling lies about me leads to Hell (Fire)}}
\hadithdefcmd{ibnmajah}{32}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَذَبَ عَلَىَّ - حَسِبْتُهُ قَالَ مُتَعَمِّدًا - فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{32}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) said: 'Whoever tells lies about me', I (the narrator) think that he also said 'deliberately', let him take his place in Hell}}
\hadithdefcmd{ibnmajah}{33}{حَدَّثَنَا أَبُو خَيْثَمَةَ، زُهَيْرُ بْنُ حَرْبٍ حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{33}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from that Jabir said:"The Messenger of Allah (ﷺ) said: 'Whoever tells lies about me deliberately, let him take his place in Hell}}
\hadithdefcmd{ibnmajah}{34}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَقَوَّلَ عَلَىَّ مَا لَمْ أَقُلْ فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{34}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'Whoever attributes to me something that I have not said, let him take his place in Hell}}
\hadithdefcmd{ibnmajah}{35}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى التَّيْمِيُّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مَعْبَدِ بْنِ كَعْبٍ، عَنْ أَبِي قَتَادَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ عَلَى هَذَا الْمِنْبَرِ ‏ "‏ إِيَّاكُمْ وَكَثْرَةَ الْحَدِيثِ عَنِّي فَمَنْ قَالَ عَلَىَّ فَلْيَقُلْ حَقًّا أَوْ صِدْقًا وَمَنْ تَقَوَّلَ عَلَىَّ مَا لَمْ أَقُلْ فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{35}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Qatadah said:"While he was on this pulpit, I heard the Messenger of Allah (ﷺ) saying: ' Beware of narrating too many Ahadith from me. Whoever attributes something to me, let him speak the truth faithfully. Whoever attributes to say something that I did not say, let him take his place in Hell}}
\hadithdefcmd{ibnmajah}{36}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا غُنْدَرٌ، مُحَمَّدُ بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ جَامِعِ بْنِ شَدَّادٍ أَبِي صَخْرَةَ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، قَالَ قُلْتُ لِلزُّبَيْرِ بْنِ الْعَوَّامِ مَا لِيَ لاَ أَسْمَعُكَ تُحَدِّثُ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ كَمَا أَسْمَعُ ابْنَ مَسْعُودٍ وَفُلاَنًا وَفُلاَنًا قَالَ أَمَا إِنِّي لَمْ أُفَارِقْهُ مُنْذُ أَسْلَمْتُ وَلَكِنِّي سَمِعْتُ مِنْهُ كَلِمَةً يَقُولُ ‏ "‏ مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{36}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Amir bin 'Abdullah bin Zubair that his father said:"I said to Zubair bin Awwam: 'Why do I not hear you narrating Ahadith from the Messenger of Allah (ﷺ) as I hear Ibn Mas'ud and so-and-so and so-and-so?' He said: 'I never left him from the time I became Muslim, but I heard him say a word: 'Whoever tells a lie about me deliberately, let him take his place in Hell}}
\hadithdefcmd{ibnmajah}{37}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُطَرِّفٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{37}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa'eed said:"The Messenger of Allah (ﷺ) said: 'Whoever tells lies about me deliberately, let him take his place in Hell}}
\hadithdefcmd{ibnmajah}{38}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ هَاشِمٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ حَدَّثَ عَنِّي حَدِيثًا وَهُوَ يُرَى أَنَّهُ كَذِبٌ فَهُوَ أَحَدُ الْكَاذِبَيْنِ ‏"‏ ‏.‏\hadithno{38}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ali that:The Prophet (ﷺ) said: '"Whoever narrates a Hadith from me thinking it to be false, then he is one of the two liars." (Either the one who invents a lie or the one who repeats it; both are liars)}}
\hadithdefcmd{ibnmajah}{39}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ حَدَّثَ عَنِّي حَدِيثًا وَهُوَ يَرَى أَنَّهُ كَذِبٌ فَهُوَ أَحَدُ الْكَاذِبَيْنِ ‏"‏ ‏.‏\hadithno{39}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Samurah bin Jundub that:The Prophet (ﷺ) said: '"Whoever narrated a Hadith from me thinking it to be false, then he is one of the two liars}}
\hadithdefcmd{ibnmajah}{40}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ رَوَى عَنِّي حَدِيثًا وَهُوَ يَرَى أَنَّهُ كَذِبٌ فَهُوَ أَحَدُ الْكَاذِبَيْنِ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، أَنْبَأَنَا الْحَسَنُ بْنُ مُوسَى الأَشْيَبُ، عَنْ شُعْبَةَ، مِثْلَ حَدِيثِ سَمُرَةَ بْنِ جُنْدُبٍ ‏.‏\hadithno{40}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from `Ali that:The Prophet (ﷺ) said: "Whoever narrates a Hadith from me thinking it to be false, then he is one of the two liars." Another chain similar to the narration of Samurah bin Jundub}}
\hadithdefcmd{ibnmajah}{41}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ حَدَّثَ عَنِّي بِحَدِيثٍ وَهُوَ يَرَى أَنَّهُ كَذِبٌ فَهُوَ أَحَدُ الْكَاذِبَيْنِ ‏"‏ ‏.‏\hadithno{41}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Mughirah bin Shu'bah said:The Messenger of Allah (ﷺ) said: '"Whoever narrates a Hadith from me thinking it to be false, then he is one of the two liars}}
\hadithdefcmd{ibnmajah}{42}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ بَشِيرِ بْنِ ذَكْوَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، - يَعْنِي ابْنَ زَبْرٍ - حَدَّثَنِي يَحْيَى بْنُ أَبِي الْمُطَاعِ، قَالَ سَمِعْتُ الْعِرْبَاضَ بْنَ سَارِيَةَ، يَقُولُ قَامَ فِينَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ذَاتَ يَوْمٍ فَوَعَظَنَا مَوْعِظَةً بَلِيغَةً وَجِلَتْ مِنْهَا الْقُلُوبُ وَذَرَفَتْ مِنْهَا الْعُيُونُ فَقِيلَ يَا رَسُولَ اللَّهِ وَعَظْتَنَا مَوْعِظَةَ مُوَدِّعٍ فَاعْهَدْ إِلَيْنَا بِعَهْدٍ فَقَالَ ‏ "‏ عَلَيْكُمْ بِتَقْوَى اللَّهِ وَالسَّمْعِ وَالطَّاعَةِ وَإِنْ عَبْدًا حَبَشِيًّا وَسَتَرَوْنَ مِنْ بَعْدِي اخْتِلاَفًا شَدِيدًا فَعَلَيْكُمْ بِسُنَّتِي وَسُنَّةِ الْخُلَفَاءِ الرَّاشِدِينَ الْمَهْدِيِّينَ عَضُّوا عَلَيْهَا بِالنَّوَاجِذِ وَإِيَّاكُمْ وَالأُمُورَ الْمُحْدَثَاتِ فَإِنَّ كُلَّ بِدْعَةٍ ضَلاَلَةٌ ‏"‏ ‏.‏\hadithno{42}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Yahya bin Abu Muta' said:I heard 'Irbad bin Sariyah say: 'One day, the Messenger of Allah (ﷺ) stood up among us and delivered a deeply moving speech to us that melted our hearts and caused our eyes to overflow with tears. It was said to him: 'O Messenger of Allah, you have delivered a speech of farewell, so enjoin something upon us.' He said: 'I urge you to fear Allah, and to listen and obey, even if (your leader) is an Abyssinian slave. After I am gone, you will see great conflict. I urge you to adhere to my Sunnah and the path of the Rightly-Guided Caliphs, and cling stubbornly to it. And beware of newly-invented matters, for every innovation is a going astray}}
\hadithdefcmd{ibnmajah}{43}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ بِشْرِ بْنِ مَنْصُورٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ السَّوَّاقُ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ ضَمْرَةَ بْنِ حَبِيبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرٍو السَّلَمِيِّ، أَنَّهُ سَمِعَ الْعِرْبَاضَ بْنَ سَارِيَةَ، يَقُولُ وَعَظَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَوْعِظَةً ذَرَفَتْ مِنْهَا الْعُيُونُ وَوَجِلَتْ مِنْهَا الْقُلُوبُ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّ هَذِهِ لَمَوْعِظَةُ مُوَدِّعٍ فَمَاذَا تَعْهَدُ إِلَيْنَا قَالَ ‏ "‏ قَدْ تَرَكْتُكُمْ عَلَى الْبَيْضَاءِ لَيْلُهَا كَنَهَارِهَا لاَ يَزِيغُ عَنْهَا بَعْدِي إِلاَّ هَالِكٌ مَنْ يَعِشْ مِنْكُمْ فَسَيَرَى اخْتِلاَفًا كَثِيرًا فَعَلَيْكُمْ بِمَا عَرَفْتُمْ مِنْ سُنَّتِي وَسُنَّةِ الْخُلَفَاءِ الرَّاشِدِينَ الْمَهْدِيِّينَ عَضُّوا عَلَيْهَا بِالنَّوَاجِذِ وَعَلَيْكُمْ بِالطَّاعَةِ وَإِنْ عَبْدًا حَبَشِيًّا فَإِنَّمَا الْمُؤْمِنُ كَالْجَمَلِ الأَنِفِ حَيْثُمَا قِيدَ انْقَادَ ‏"‏ ‏.‏\hadithno{43}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin 'Amr As-Sulami that:He heard Al-'Irbad bin Sariyah say: "The Messenger of Allah (ﷺ) delivered a moving speech to us which made our eyes flow with tears and made our hearts melt. We said: 'O Messenger of Allah. This is a speech of farewell. What did you enjoin upon us?' He said: 'I am leaving you upon a (path of) brightness whose night is like its day. No one will deviate from it after I am gone but one who is doomed. Whoever among you lives will see great conflict. I urge you to adhere to what you know of my Sunnah and the path of the Rightly-Guided Caliphs, and cling stubbornly to it. And you must obey, even if (your leader is) an Abyssinian leader. For the true believer is like a camel with a ring in its nose; wherever it is driven, it complies}}
\hadithdefcmd{ibnmajah}{44}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الصَّبَّاحِ الْمِسْمَعِيُّ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرٍو، عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَلاَةَ الصُّبْحِ ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَوَعَظَنَا مَوْعِظَةً بَلِيغَةً ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{44}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Irbad bin Sariyah said:"The Messenger of Allah (ﷺ) led us in Fajr (morning) prayer, then he turned to us and delivered an eloquent speech". And he mentioned something similar (as no)}}
\hadithdefcmd{ibnmajah}{45}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، وَأَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا خَطَبَ احْمَرَّتْ عَيْنَاهُ وَعَلاَ صَوْتُهُ وَاشْتَدَّ غَضَبُهُ كَأَنَّهُ مُنْذِرُ جَيْشٍ يَقُولُ ‏"‏ صَبَّحَكُمْ مَسَّاكُمْ ‏"‏ ‏.‏ وَيَقُولُ ‏"‏ بُعِثْتُ أَنَا وَالسَّاعَةَ كَهَاتَيْنِ ‏"‏ ‏.‏ وَيَقْرِنُ بَيْنَ إِصْبَعَيْهِ السَّبَّابَةِ وَالْوُسْطَى ثُمَّ يَقُولُ ‏"‏ أَمَّا بَعْدُ فَإِنَّ خَيْرَ الأُمُورِ كِتَابُ اللَّهِ وَخَيْرَ الْهَدْىِ هَدْىُ مُحَمَّدٍ وَشَرَّ الأُمُورِ مُحْدَثَاتُهَا وَكُلَّ بِدْعَةٍ ضَلاَلَةٌ ‏"‏ ‏.‏ وَكَانَ يَقُولُ ‏"‏ مَنْ تَرَكَ مَالاً فَلأَهْلِهِ وَمَنْ تَرَكَ دَيْنًا أَوْ ضَيَاعًا فَعَلَىَّ وَإِلَىَّ ‏"‏ ‏.‏\hadithno{45}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"When the Messenger of Allah (ﷺ) delivered a sermon, his eyes would turn red, he would raise his voice and he would speak with intensity, as if he were warning of an (enemy) army, saying, 'They will surely attack you in the morning, or they will surely attack you in the evening!' He would say: 'I and the Hour have been sent like these two,' and he would hold his index and middle finger. Then he would say: 'The best of guidance is the guidance of Muhammad. The most evil matters are those that are newly-invented, and every innovation (Bid'ah) is a going astray.' And he used to say: 'Whoever dies and leaves behind some wealth, it is for his family, and whoever leaves behind a debt or dependent children, then they are both my responsibility}}
\hadithdefcmd{ibnmajah}{46}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ الْمَدَنِيُّ أَبُو عُبَيْدٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ أَبِي كَثِيرٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّمَا هُمَا اثْنَتَانِ الْكَلاَمُ وَالْهَدْىُ فَأَحْسَنُ الْكَلاَمِ كَلاَمُ اللَّهِ وَأَحْسَنُ الْهَدْىِ هَدْىُ مُحَمَّدٍ أَلاَ وَإِيَّاكُمْ وَمُحْدَثَاتِ الأُمُورِ فَإِنَّ شَرَّ الأُمُورِ مُحْدَثَاتُهَا وَكُلُّ مُحْدَثَةٍ بِدْعَةٌ وَكُلُّ بِدْعَةٍ ضَلاَلَةٌ أَلاَ لاَ يَطُولَنَّ عَلَيْكُمُ الأَمَدُ فَتَقْسُوَ قُلُوبُكُمْ أَلاَ إِنَّ مَا هُوَ آتٍ قَرِيبٌ وَإِنَّمَا الْبَعِيدُ مَا لَيْسَ بِآتٍ أَلاَ إِنَّ الشَّقِيَّ مَنْ شَقِيَ فِي بَطْنِ أُمِّهِ وَالسَّعِيدَ مَنْ وُعِظَ بِغَيْرِهِ أَلاَ إِنَّ قِتَالَ الْمُؤْمِنِ كُفْرٌ وَسِبَابُهُ فُسُوقٌ وَلاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثٍ أَلاَ وَإِيَّاكُمْ وَالْكَذِبَ فَإِنَّ الْكَذِبَ لاَ يَصْلُحُ بِالْجِدِّ وَلاَ بِالْهَزْلِ وَلاَ يَعِدِ الرَّجُلُ صَبِيَّهُ ثُمَّ لاَ يَفِيَ لَهُ فَإِنَّ الْكَذِبَ يَهْدِي إِلَى الْفُجُورِ وَإِنَّ الْفُجُورَ يَهْدِي إِلَى النَّارِ وَإِنَّ الصِّدْقَ يَهْدِي إِلَى الْبِرِّ وَإِنَّ الْبِرَّ يَهْدِي إِلَى الْجَنَّةِ وَإِنَّهُ يُقَالُ لِلصَّادِقِ صَدَقَ وَبَرَّ ‏.‏ وَيُقَالُ لِلْكَاذِبِ كَذَبَ وَفَجَرَ ‏.‏ أَلاَ وَإِنَّ الْعَبْدَ يَكْذِبُ حَتَّى يُكْتَبَ عِنْدَ اللَّهِ كَذَّابًا ‏"‏ ‏.‏\hadithno{46}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdullah bin Mas'ud that:the Messenger of Allah (ﷺ) said: "Verily there are two things - words and guidance. The best words are the words of Allah, and the best guidance in the guidance of Muhammad. Beware of newly-invented matters, for every newly-invented matter is an innovation (Bid'ah) and every innovation is a going-stray. Do not let the desire for a long life causes your hearts to grow hard. That which is bound to happen is close to you, and the only thing that is far away is that which is not going to happen. The one who is doomed to Hell is doomed from his mother's womb, and the one who is destined for Paradise is the one who learns from the lessons of others. Killing a believer constitutes disbelief (Kufr) and verbally abusing him is immorality (Fusuq). It is not permissible for a Muslim to forsake his brother for more than three days. Beware of lying, for lying is never good, whether it is done seriously or in jest. A man should not make a promise to a child that he will not keep. Lying leads to immorality and immorality leads to Hell. Truthfulness leads to righteousness and righteousness leads to Paradise. It will be said of the truthful person: 'He spoke the truth and was righteous', and it will be said of the liar, 'He told lies and was immoral.' "For a person continues to tell lies until he is recorded with Allah as a liar}}
\hadithdefcmd{ibnmajah}{47}{حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خِدَاشٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، وَيَحْيَى بْنُ حَكِيمٍ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ تَلاَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ هَذِهِ الآيَةَ \{هُوَ الَّذِي أَنْزَلَ عَلَيْكَ الْكِتَابَ مِنْهُ آيَاتٌ مُحْكَمَاتٌ هُنَّ أُمُّ الْكِتَابِ وَأُخَرُ مُتَشَابِهَاتٌ\}‏ إِلَى قَوْلِهِ \{‏وَمَا يَذَّكَّرُ إِلاَّ أُولُو الأَلْبَابِ‏\}‏ ‏.‏ فَقَالَ ‏"‏ يَا عَائِشَةُ إِذَا رَأَيْتُمُ الَّذِينَ يُجَادِلُونَ فِيهِ فَهُمُ الَّذِينَ عَنَاهُمُ اللَّهُ فَاحْذَرُوهُمْ ‏"‏ ‏.‏\hadithno{47}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) recited the following Verse: 'It is He Who has sent down to you (Muhammad) the Book (this Qur'an). In it are verses that are entirely clear, they are the foundations of the Book; and others not entirely clear (up to His saying: ) 'And none receive admonition except men of understanding.' Then he said: 'O 'Aishah, if you see those who dispute concerning it (the Qur'an), they are those whom Allah has referred to here, so beware of them}}
\hadithdefcmd{ibnmajah}{48}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، ح وَحَدَّثَنَا حَوْثَرَةُ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ دِينَارٍ، عَنْ أَبِي غَالِبٍ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَا ضَلَّ قَوْمٌ بَعْدَ هُدًى كَانُوا عَلَيْهِ إِلاَّ أُوتُوا الْجَدَلَ ‏"‏ ‏.‏ ثُمَّ تَلاَ هَذِهِ الآيَةَ \{بَلْ هُمْ قَوْمٌ خَصِمُونَ\}‏ ‏.‏\hadithno{48}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Umamah said:"The Messenger of Allah (ﷺ) said: 'No people go astray after having followed right guidance, but those who indulge in disputes.' Then he recited the Verse: "Nay! But they are a quarrelsome people}}
\hadithdefcmd{ibnmajah}{49}{حَدَّثَنَا دَاوُدُ بْنُ سُلَيْمَانَ الْعَسْكَرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَلِيٍّ أَبُو هَاشِمٍ بْنُ أَبِي خِدَاشٍ الْمَوْصِلِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مِحْصَنٍ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي عَبْلَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الدَّيْلَمِيِّ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَقْبَلُ اللَّهُ لِصَاحِبِ بِدْعَةٍ صَوْمًا وَلاَ صَلاَةً وَلاَ صَدَقَةً وَلاَ حَجًّا وَلاَ عُمْرَةً وَلاَ جِهَادًا وَلاَ صَرْفًا وَلاَ عَدْلاً يَخْرُجُ مِنَ الإِسْلاَمِ كَمَا تَخْرُجُ الشَّعَرَةُ مِنَ الْعَجِينِ ‏"‏ ‏.‏\hadithno{49}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Hudhaifah said:"The Messenger of Allah (ﷺ) said: 'Allah will not accept any fasting, prayer, charity, Hajj, 'Umrah, Jihad, or any other obligatory or voluntary action from a person who follows innovation (Bid'ah). He comes out of Islam like a hair pulled out of dough}}
\hadithdefcmd{ibnmajah}{50}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا بِشْرُ بْنُ مَنْصُورٍ الْخَيَّاطُ، عَنْ أَبِي زَيْدٍ، عَنْ أَبِي الْمُغِيرَةِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَبَى اللَّهُ أَنْ يَقْبَلَ عَمَلَ صَاحِبِ بِدْعَةٍ حَتَّى يَدَعَ بِدْعَتَهُ ‏"‏ ‏.‏\hadithno{50}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin 'Abbas said:"The Messenger of Allah (ﷺ) said: 'Allah refuses to accept the good deeds of one who follows innovation until he gives up that innovation}}
\hadithdefcmd{ibnmajah}{51}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، وَهَارُونُ بْنُ إِسْحَاقَ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ سَلَمَةَ بْنِ وَرْدَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَرَكَ الْكَذِبَ وَهُوَ بَاطِلٌ بُنِيَ لَهُ قَصْرٌ فِي رَبَضِ الْجَنَّةِ وَمَنْ تَرَكَ الْمِرَاءَ وَهُوَ مُحِقٌّ بُنِيَ لَهُ فِي وَسَطِهَا وَمَنْ حَسَّنَ خُلُقَهُ بُنِيَ لَهُ فِي أَعْلاَهَا ‏"‏ ‏.‏\hadithno{51}\hadithgrade{Al-Albani: Sanad Daif; Muhammad Fouad Abd al-Baqi: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ans bin Malik said:"The Messenger of Allah (ﷺ) said: 'Whoever gives up telling lies in support of a false claim, a palace will be built for him in the outskirts of Paradise. Whoever gives up argument when he is in the right, a palace will be built from him in the middle (of Paradise). And whoever had good behavior, a palace will be built for him in the highest reaches (of Paradise)}}
\hadithdefcmd{ibnmajah}{52}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَعَبْدَةُ، وَأَبُو مُعَاوِيَةَ وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ وَمُحَمَّدُ بْنُ بِشْرٍ ح وَحَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَمَالِكُ بْنُ أَنَسٍ، وَحَفْصُ بْنُ مَيْسَرَةَ، وَشُعَيْبُ بْنُ إِسْحَاقَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ لاَ يَقْبِضُ الْعِلْمَ انْتِزَاعًا يَنْتَزِعُهُ مِنَ النَّاسِ وَلَكِنْ يَقْبِضُ الْعِلْمَ بِقَبْضِ الْعُلَمَاءِ فَإِذَا لَمْ يُبْقِ عَالِمًا اتَّخَذَ النَّاسُ رُءُوسًا جُهَّالاً فَسُئِلُوا فَأَفْتَوْا بِغَيْرِ عِلْمٍ فَضَلُّوا وَأَضَلُّوا ‏"‏ ‏.‏\hadithno{52}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Amr bin 'As that:the Messenger of Allah (ﷺ) said: 'Allah will not take away knowledge by removing it from people (from their hearts). Rather He will take away knowledge by taking away the scholars, then when there are no scholars left, the people will take the ignorant as their leaders. They will be asked questions and they will issue verdicts without knowledge, thus they will go astray and lead others astray}}
\hadithdefcmd{ibnmajah}{53}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، حَدَّثَنِي أَبُو هَانِئٍ، حُمَيْدُ بْنُ هَانِئٍ الْخَوْلاَنِيُّ عَنْ أَبِي عُثْمَانَ، مُسْلِمِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أُفْتِيَ بِفُتْيَا غَيْرَ ثَبَتٍ فَإِنَّمَا إِثْمُهُ عَلَى مَنْ أَفْتَاهُ ‏"‏ ‏.‏\hadithno{53}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'Whoever is given a Fatwa (verdict) that has no basis, then his sin will be upon the one who issued that Fatwa}}
\hadithdefcmd{ibnmajah}{54}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، حَدَّثَنِي رِشْدِينُ بْنُ سَعْدٍ، وَجَعْفَرُ بْنُ عَوْنٍ، عَنِ ابْنِ أَنْعُمٍ، - هُوَ الإِفْرِيقِيُّ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْعِلْمُ ثَلاَثَةٌ فَمَا وَرَاءَ ذَلِكَ فَهُوَ فَضْلٌ آيَةٌ مُحْكَمَةٌ أَوْ سُنَّةٌ قَائِمَةٌ أَوْ فَرِيضَةٌ عَادِلَةٌ ‏"‏ ‏.‏\hadithno{54}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah (ﷺ) said: 'Knowledge is based on three things, and anything beyond that is superfluous: a clear Verse, an established Sunnah, or the rulings by which the inheritance is divided fairly}}
\hadithdefcmd{ibnmajah}{55}{حَدَّثَنَا الْحَسَنُ بْنُ حَمَّادٍ، سَجَّادَةُ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الأَمَوِيُّ، عَنْ مُحَمَّدِ بْنِ سَعِيدِ بْنِ حَسَّانَ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، حَدَّثَنَا مُعَاذُ بْنُ جَبَلٍ، قَالَ لَمَّا بَعَثَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى الْيَمَنِ قَالَ ‏ "‏ لاَ تَقْضِيَنَّ وَلاَ تَفْصِلَنَّ إِلاَّ بِمَا تَعْلَمُ فَإِنْ أَشْكَلَ عَلَيْكَ أَمْرٌ فَقِفْ حَتَّى تُبَيِّنَهُ أَوْ تَكْتُبَ إِلَىَّ فِيهِ ‏"‏ ‏.‏\hadithno{55}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh bin Jabal said:"When the Messenger of Allah (ﷺ) sent me to Yemen, he said: 'Do not pass any judgment or make any decision except on the basis of what you know. If you are uncertain about a matter, wait until you understand it fully, or write to me concerning it.'" (Maudu)}}
\hadithdefcmd{ibnmajah}{56}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي الرِّجَالِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرٍو الأَوْزَاعِيِّ، عَنْ عَبْدَةَ بْنِ أَبِي لُبَابَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لَمْ يَزَلْ أَمْرُ بَنِي إِسْرَائِيلَ مُعْتَدِلاً حَتَّى نَشَأَ فِيهِمُ الْمُوَلَّدُونَ أَبْنَاءُ سَبَايَا الأُمَمِ فَقَالُوا بِالرَّأْىِ فَضَلُّوا وَأَضَلُّوا ‏"‏ ‏.‏\hadithno{56}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin 'Amr bin 'As said:"I heard the Messenger of Allah (ﷺ) say: 'The affairs of the Children of Israel remained fair until Muwalladun emerged among them - the children of female slaves from other nations. They spoke of their own opinions (in religious matters) and so they went astray and led others astray}}
\hadithdefcmd{ibnmajah}{57}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ الطَّنَافِسِيُّ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الإِيمَانُ بِضْعٌ وَسِتُّونَ أَوْ سَبْعُونَ بَابًا أَدْنَاهَا إِمَاطَةُ الأَذَى عَنِ الطَّرِيقِ وَأَرْفَعُهَا قَوْلُ لاَ إِلَهَ إِلاَّ اللَّهُ وَالْحَيَاءُ شُعْبَةٌ مِنَ الإِيمَانِ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، ح وَحَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، جَمِيعًا عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{57}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'Faith has sixty-some or seventy parts, the least of which is to remove a harmful thing from the road and the greatest of which is to say La ilaha illalah (none has the right to be worshipped but Allah). And modesty is a branch of faith.'" Another chain from Abu Hurairah, from the Prophet (ﷺ) with similar wording}}
\hadithdefcmd{ibnmajah}{58}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعَ النَّبِيُّ ـ صلى الله عليه وسلم ـ رَجُلاً يَعِظُ أَخَاهُ فِي الْحَيَاءِ فَقَالَ ‏ "‏ إِنَّ الْحَيَاءَ شُعْبَةٌ مِنَ الإِيمَانِ ‏"‏ ‏.‏\hadithno{58}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim that his father said:"The Messenger of Allah (ﷺ) said heard a man urging his brother to be modest. He said: 'Indeed modesty is a branch of faith}}
\hadithdefcmd{ibnmajah}{59}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا سَعِيدُ بْنُ مَسْلَمَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ مِنْ كِبْرٍ وَلاَ يَدْخُلُ النَّارَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏\hadithno{59}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abdullah said:"The Messenger of Allah (ﷺ) said: 'No one will enter Paradise who has even a mustard-seed's weight of arrogance in his heart, and no one will enter Hell who has even a mustard-seed's weight of faith in his heart}}
\hadithdefcmd{ibnmajah}{60}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِذَا خَلَّصَ اللَّهُ الْمُؤْمِنِينَ مِنَ النَّارِ وَأَمِنُوا فَمَا مُجَادَلَةُ أَحَدِكُمْ لِصَاحِبِهِ فِي الْحَقِّ يَكُونُ لَهُ فِي الدُّنْيَا أَشَدَّ مُجَادَلَةً مِنَ الْمُؤْمِنِينَ لِرَبِّهِمْ فِي إِخْوَانِهِمُ الَّذِينَ أُدْخِلُوا النَّارَ ‏.‏ قَالَ يَقُولُونَ رَبَّنَا إِخْوَانُنَا كَانُوا يُصَلُّونَ مَعَنَا وَيَصُومُونَ مَعَنَا وَيَحُجُّونَ مَعَنَا فَأَدْخَلْتَهُمُ النَّارَ ‏.‏ فَيَقُولُ اذْهَبُوا فَأَخْرِجُوا مَنْ عَرَفْتُمْ مِنْهُمْ فَيَأْتُونَهُمْ فَيَعْرِفُونَهُمْ بِصُوَرِهِمْ لاَ تَأْكُلُ النَّارُ صُوَرَهُمْ فَمِنْهُمْ مَنْ أَخَذَتْهُ النَّارُ إِلَى أَنْصَافِ سَاقَيْهِ وَمِنْهُمْ مَنْ أَخَذَتْهُ إِلَى كَعْبَيْهِ فَيُخْرِجُونَهُمْ فَيَقُولُونَ رَبَّنَا أَخْرَجْنَا مَنْ قَدْ أَمَرْتَنَا ‏.‏ ثُمَّ يَقُولُ أَخْرِجُوا مَنْ كَانَ فِي قَلْبِهِ وَزْنُ دِينَارٍ مِنَ الإِيمَانِ ثُمَّ مَنْ كَانَ فِي قَلْبِهِ وَزْنُ نِصْفِ دِينَارٍ ثُمَّ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ فَمَنْ لَمْ يُصَدِّقْ هَذَا فَلْيَقْرَأْ \{إِنَّ اللَّهَ لاَ يَظْلِمُ مِثْقَالَ ذَرَّةٍ وَإِنْ تَكُ حَسَنَةً يُضَاعِفْهَا وَيُؤْتِ مِنْ لَدُنْهُ أَجْرًا عَظِيمًا\}‏ ‏.‏\hadithno{60}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Sa'eed Khudri said:"The Messenger of Allah (ﷺ) said: 'When Allah has saved the believers from Hell and they are safe, none of you will dispute with his companion more vehemently for some right of his in this world than the believers will dispute with their Lord on behalf of their brothers in faith who have entered Hell. They will say: " Our Lord! They are our brothers, they used to pray with us, fast with us and perform Hajj with us, and you have admitted them to Hell." He will say: "Go and bring forth those whom you recognize among them." So they will come to them , and they will recognize them by their faces. The Fire will not consume their faces, although there will be some whom the Fire will seize halfway up their shins, and others whom it will seize up to their ankles. They will bring them forth, and will say. "Our Lord, we have brought forth those whom You commanded us to bring forth." Then He will say: "Bring forth those who have a Dinar's weight of faith in their hearts, then those who have half a Dinar's weight in their hearts, then those who have a mustard-seed's weight." Abu Sa'eed said. :"He who does not believe this, let him recite, 'Surely, Allah wrongs not even of the weight of an atom (or a small ant), but is there is any good (done), He doubles it, and gives from Him a great reward}}
\hadithdefcmd{ibnmajah}{61}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا حَمَّادُ بْنُ نَجِيحٍ، - وَكَانَ ثِقَةً - عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ جُنْدُبِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَنَحْنُ فِتْيَانٌ حَزَاوِرَةٌ فَتَعَلَّمْنَا الإِيمَانَ قَبْلَ أَنْ نَتَعَلَّمَ الْقُرْآنَ ثُمَّ تَعَلَّمْنَا الْقُرْآنَ فَازْدَدْنَا بِهِ إِيمَانًا ‏"‏ ‏.‏\hadithno{61}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jundub bin 'Abdullah said:"We were with the Prophet (ﷺ), and we were strong youths, so we learned faith before we learned Qur'an. Then we learned Qur'an and our faith increased thereby}}
\hadithdefcmd{ibnmajah}{62}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عَلِيُّ بْنُ نِزَارٍ، عَنْ أَبِيهِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صِنْفَانِ مِنْ هَذِهِ الأُمَّةِ لَيْسَ لَهُمَا فِي الإِسْلاَمِ نَصِيبٌ الْمُرْجِئَةُ وَالْقَدَرِيَّةُ ‏"‏ ‏.‏\hadithno{62}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) said: 'There are two types of people among this Ummah who have no share of Islam: The Murji'ah and the Qadariyyah}}
\hadithdefcmd{ibnmajah}{63}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ كَهْمَسِ بْنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَجَاءَ رَجُلٌ شَدِيدُ بَيَاضِ الثِّيَابِ شَدِيدُ سَوَادِ شَعَرِ الرَّأْسِ لاَ يُرَى عَلَيْهِ أَثَرُ السَّفَرِ وَلاَ يَعْرِفُهُ مِنَّا أَحَدٌ ‏.‏ قَالَ فَجَلَسَ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَسْنَدَ رُكْبَتَهُ إِلَى رُكْبَتِهِ وَوَضَعَ يَدَيْهِ عَلَى فَخِذَيْهِ ‏.‏ ثُمَّ قَالَ يَا مُحَمَّدُ مَا الإِسْلاَمُ قَالَ ‏"‏ شَهَادَةُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ وَإِقَامُ الصَّلاَةِ وَإِيتَاءُ الزَّكَاةِ وَصَوْمُ رَمَضَانَ وَحَجُّ الْبَيْتِ ‏"‏ ‏.‏ قَالَ صَدَقْتَ ‏.‏ فَعَجِبْنَا مِنْهُ يَسْأَلُهُ وَيُصَدِّقُهُ ‏.‏ ثُمَّ قَالَ يَا مُحَمَّدُ مَا الإِيمَانُ قَالَ ‏"‏ أَنْ تُؤْمِنَ بِاللَّهِ وَمَلاَئِكَتِهِ وَرُسُلِهِ وَكُتُبِهِ وَالْيَوْمِ الآخِرِ وَالْقَدَرِ خَيْرِهِ وَشَرِّهِ ‏"‏ ‏.‏ قَالَ صَدَقْتَ ‏.‏ فَعَجِبْنَا مِنْهُ يَسْأَلُهُ وَيُصَدِّقُهُ ‏.‏ ثُمَّ قَالَ يَا مُحَمَّدُ مَا الإِحْسَانُ قَالَ ‏"‏ أَنْ تَعْبُدَ اللَّهَ كَأَنَّكَ تَرَاهُ فَإِنَّكَ إِنْ لاَ تَرَاهُ فَإِنَّهُ يَرَاكَ ‏"‏ ‏.‏ قَالَ فَمَتَى السَّاعَةُ قَالَ ‏"‏ مَا الْمَسْئُولُ عَنْهَا بِأَعْلَمَ مِنَ السَّائِلِ ‏"‏ ‏.‏ قَالَ فَمَا أَمَارَتُهَا قَالَ ‏"‏ أَنْ تَلِدَ الأَمَةُ رَبَّتَهَا ‏"‏ ‏.‏ قَالَ وَكِيعٌ يَعْنِي تَلِدُ الْعَجَمُ الْعَرَبَ ‏"‏ وَأَنْ تَرَى الْحُفَاةَ الْعُرَاةَ الْعَالَةَ رِعَاءَ الشَّاءِ يَتَطَاوَلُونَ فِي الْبِنَاءِ ‏"‏ ‏.‏ قَالَ ثُمَّ قَالَ فَلَقِيَنِي النَّبِيُّ ـ صلى الله عليه وسلم ـ بَعْدَ ثَلاَثٍ فَقَالَ ‏"‏ أَتَدْرِي مَنِ الرَّجُلُ ‏"‏ ‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ ذَاكَ جِبْرِيلُ أَتَاكُمْ يُعَلِّمُكُمْ مَعَالِمَ دِينِكُمْ ‏"‏ ‏.‏\hadithno{63}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Umar said:"We were sitting with the Prophet (ﷺ) when a man came to him whose clothes were intensely white and whose hair was intensely black; no signs of travel could be seen upon him, and none of us recognized him. He sat down facing the Prophet (ﷺ), with his knees touching his, and he put his hands on his thighs, and said: 'O Muhammad, what is Islam?' He said: 'To testify that none has the right to be worshipped but Allah, and that I am the Messenger of Allah, to establish regular prayer, to pay Zakat, to fast in Ramadan, and to perform Hajj to the House (the Ka'bah).' He said: 'You have spoken the truth.' We were amazed by him: He asked a question, then told him that he had spoken the truth. Then he said: 'O Muhammad, what is Iman faith? He said: 'To believe in Allah, His angels, His Messengers, His books, the Last day, and the Divine Decree (Qadar), both the good of it and the bad of it.' He said' You have spoken the truth.' We were amazed by him. He asked a question, then told him that he had spoken the truth. Then he said: 'O Muhammad, what is Ihsan (right action, goodness, sincerity)? He said: 'To worship Allah as if you see Him, for even though you do not see Him, He sees you.' He asked: "When will the Hour be?' He said: 'The one who is being asked about it does not know more than the one who is asking.' He asked: 'Then what are its signs?' he said: 'When the slave woman gives birth to her mistress' (Waki' said: This means when non-Arabs will give birth to Arabs") 'and when you see barefoot, naked, destitute shepherds competing in constructing tall buildings.' The Prophet (ﷺ) met me three days later and asked me: 'Do you know who that man was? I said" 'Allah and his Messenger know best.' He said: 'That was Jibril, who came to you to teach you your religion}}
\hadithdefcmd{ibnmajah}{64}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَبِي حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمًا بَارِزًا لِلنَّاسِ ‏.‏ فَأَتَاهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ مَا الإِيمَانُ قَالَ ‏"‏ أَنْ تُؤْمِنَ بِاللَّهِ وَمَلاَئِكَتِهِ وَكُتُبِهِ وَرُسُلِهِ وَلِقَائِهِ وَتُؤْمِنَ بِالْبَعْثِ الآخِرِ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَا الإِسْلاَمُ قَالَ ‏"‏ أَنْ تَعْبُدَ اللَّهَ وَلاَ تُشْرِكَ بِهِ شَيْئًا وَتُقِيمَ الصَّلاَةَ الْمَكْتُوبَةَ وَتُؤْتِيَ الزَّكَاةَ الْمَفْرُوضَةَ وَتَصُومَ رَمَضَانَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَا الإِحْسَانُ قَالَ ‏"‏ أَنْ تَعْبُدَ اللَّهَ كَأَنَّكَ تَرَاهُ فَإِنَّكَ إِنْ لاَ تَرَاهُ فَإِنَّهُ يَرَاكَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَتَى السَّاعَةُ قَالَ ‏"‏ مَا الْمَسْئُولُ عَنْهَا بِأَعْلَمَ مِنَ السَّائِلِ وَلَكِنْ سَأُحَدِّثُكَ عَنْ أَشْرَاطِهَا إِذَا وَلَدَتِ الأَمَةُ رَبَّتَهَا فَذَلِكَ مِنْ أَشْرَاطِهَا وَإِذَا تَطَاوَلَ رِعَاءُ الْغَنَمِ فِي الْبُنْيَانِ فَذَلِكَ مِنْ أَشْرَاطِهَا فِي خَمْسٍ لاَ يَعْلَمُهُنَّ إِلاَّ اللَّهُ ‏"‏ ‏.‏ فَتَلاَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ \{إِنَّ اللَّهَ عِنْدَهُ عِلْمُ السَّاعَةِ وَيُنَزِّلُ الْغَيْثَ وَيَعْلَمُ مَا فِي الأَرْحَامِ وَمَا تَدْرِي نَفْسٌ مَاذَا تَكْسِبُ غَدًا وَمَا تَدْرِي نَفْسٌ بِأَىِّ أَرْضٍ تَمُوتُ إِنَّ اللَّهَ عَلِيمٌ خَبِيرٌ‏\}‏ ‏.‏\hadithno{64}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"One day the Prophet (ﷺ) appeared among the people. A man came to him and said: 'O messenger of Allah, what is Iman (faith)?' He said: 'To believe in Allah, His angels, His books, His Messengers and the meeting with, and to believe in the Final Resurrection.' He said: 'O Messenger of Allah, what is Islam?' He said: 'To worship Allah (alone) and not to associate anything with Him; to establish the prescribed prayers, to pay the obligatory Zakat, and to fast Ramadan.' He said: 'O Messenger of Allah, what is Ihsan? He said: 'To worship Allah as if you see Him, for even though you do not see Him, He sees you.' He said: "O Messenger of Allah, when will the Hour be?' He said: 'The one who is being asked about it does not know more than the one who is asking. But I will tell you about its signs. When the slave woman gives birth to her mistress that is one of its signs. When the shepherds compete in constructing tall buildings that is one of its signs. And there are five things which no one knows except Allah.' Then the Messenger of Allah (ﷺ) recited the Verse: "Verily, Allah, with Him (Alone) is the knowledge of the Hour, He sends down the rain, and knows that which is in the wombs. No person knows what he will earn tomorrow, and no person knows in what land he will die. Verily, Allah is All-Knower, All-Aware (of things)}}
\hadithdefcmd{ibnmajah}{65}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ صَالِحٍ أَبُو الصَّلْتِ الْهَرَوِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُوسَى الرِّضَا، عَنْ أَبِيهِ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الإِيمَانُ مَعْرِفَةٌ بِالْقَلْبِ وَقَوْلٌ بِاللِّسَانِ وَعَمَلٌ بِالأَرْكَانِ ‏"‏ ‏.‏ قَالَ أَبُو الصَّلْتِ لَوْ قُرِئَ هَذَا الإِسْنَادُ عَلَى مَجْنُونٍ لَبَرَأَ ‏.‏\hadithno{65}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali bin Abu Talib said:"The Messenger of Allah (ﷺ) said: 'Faith is knowledge in the heart, words on the tongue and action with the physical faculties. (limbs of the body).'" (Maudu)}}
\hadithdefcmd{ibnmajah}{66}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يُؤْمِنُ أَحَدُكُمْ حَتَّى يُحِبَّ لأَخِيهِ - أَوْ قَالَ لِجَارِهِ - مَا يُحِبُّ لِنَفْسِهِ ‏"‏ ‏.‏\hadithno{66}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that:"The Messenger of Allah (ﷺ) said: 'None of you truly believes until he loves for his brother" or he said "for his neighbor, what he loves for himself}}
\hadithdefcmd{ibnmajah}{67}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يُؤْمِنُ أَحَدُكُمْ حَتَّى أَكُونَ أَحَبَّ إِلَيْهِ مِنْ وَلَدِهِ وَوَالِدِهِ وَالنَّاسِ أَجْمَعِينَ ‏"‏ ‏.‏\hadithno{67}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) said: 'None of you truly believes until I am more beloved to him than his child, his father and all the people}}
\hadithdefcmd{ibnmajah}{68}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَدْخُلُوا الْجَنَّةَ حَتَّى تُؤْمِنُوا وَلاَ تُؤْمِنُوا حَتَّى تَحَابُّوا أَوَلاَ أَدُلُّكُمْ عَلَى شَىْءٍ إِذَا فَعَلْتُمُوهُ تَحَابَبْتُمْ أَفْشُوا السَّلاَمَ بَيْنَكُمْ ‏"‏ ‏.‏\hadithno{68}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'By the One in whose Hand is my soul! You will not enter Paradise until you believe, and you will not (truly) believe until you love one another. Shall I not tell you of something which, if you do it, you will love one another? Spread the greetings of Salam amongst yourselves}}
\hadithdefcmd{ibnmajah}{69}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏\hadithno{69}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah (ﷺ) said: 'Verbally abusing a Muslim is immorality and fighting him is Kufr (disbelief)}}
\hadithdefcmd{ibnmajah}{70}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا أَبُو جَعْفَرٍ الرَّازِيُّ، عَنِ الرَّبِيعِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ فَارَقَ الدُّنْيَا عَلَى الإِخْلاَصِ لِلَّهِ وَحْدَهُ وَعِبَادَتِهِ لاَ شَرِيكَ لَهُ وَإِقَامِ الصَّلاَةِ وَإِيتَاءِ الزَّكَاةِ مَاتَ وَاللَّهُ عَنْهُ رَاضٍ ‏"‏ ‏.‏ قَالَ أَنَسٌ وَهُوَ دِينُ اللَّهِ الَّذِي جَاءَتْ بِهِ الرُّسُلُ وَبَلَّغُوهُ عَنْ رَبِّهِمْ قَبْلَ هَرْجِ الأَحَادِيثِ وَاخْتِلاَفِ الأَهْوَاءِ وَتَصْدِيقُ ذَلِكَ فِي كِتَابِ اللَّهِ فِي آخِرِ مَا نَزَلَ يَقُولُ اللَّهُ \{فَإِنْ تَابُوا\}‏ قَالَ خَلَعُوا الأَوْثَانَ وَعِبَادَتَهَا \{وَأَقَامُوا الصَّلاَةَ وَآتَوُا الزَّكَاةَ\}‏ وَقَالَ فِي آيَةٍ أُخْرَى ‏\{فَإِنْ تَابُوا وَأَقَامُوا الصَّلاَةَ وَآتَوُا الزَّكَاةَ فَإِخْوَانُكُمْ فِي الدِّينِ\}‏ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى الْعَبْسِيُّ، حَدَّثَنَا أَبُو جَعْفَرٍ الرَّازِيُّ، عَنِ الرَّبِيعِ بْنِ أَنَسٍ، مِثْلَهُ ‏.‏\hadithno{70}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) said: 'Whoever departs this world with sincerity towards Allah, worshipping Him alone with no partner, establishing regular prayer and paying Zakat, he dies while Allah is pleased with him.'" Anas said: "This is the religion of Allah which was brought by the Messengers, and which they conveyed from their Lord before there arose the confusion of people's chattering and conflicting desires. This is confirmed in the Book of Allah, in one of the Last Verses to be revealed, where Allah says: "But if they repent." Renounce their idols and worshipping them; "And establish Salat and give Zakat." And Allah says in another Verse." But if they repent, perform Salat and give Zakat, then they are your brethren in religion." (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{71}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا أَبُو جَعْفَرٍ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ وَيُقِيمُوا الصَّلاَةَ وَيُؤْتُوا الزَّكَاةَ ‏"‏ ‏.‏\hadithno{71}\hadithgrade{Al-Albani: Sahih Mutawatir; Muhammad Fouad Abd al-Baqi: Sahih Mutawatir; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'I have been commanded to fight the people until they testify to La ilaha ill-allah (none has the right to be worshipped but Allah) and that I am the Messenger of Allah, and establish regular prayers and pay Zakat}}
\hadithdefcmd{ibnmajah}{72}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ بَهْرَامَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ وَيُقِيمُوا الصَّلاَةَ وَيُؤْتُوا الزَّكَاةَ ‏"‏ ‏.‏\hadithno{72}\hadithgrade{Al-Albani: Sahih Mutawatir; Muhammad Fouad Abd al-Baqi: Sahih Mutawatir; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mu'adh bin Jabal said:"The Messenger of Allah (ﷺ) said: 'I have been commanded to fight the people until they testify to La ilaha ill-allah (none has the right to be worshipped but Allah) and that I am the Messenger of Allah, and establish regular prayers and pay Zakat}}
\hadithdefcmd{ibnmajah}{73}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ الرَّازِيُّ، أَنْبَأَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ اللَّيْثِيُّ، حَدَّثَنَا نِزَارُ بْنُ حَيَّانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالاَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صِنْفَانِ مِنْ أُمَّتِي لَيْسَ لَهُمَا فِي الإِسْلاَمِ نَصِيبٌ أَهْلُ الإِرْجَاءِ وَأَهْلُ الْقَدَرِ ‏"‏ ‏.‏\hadithno{73}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas and Jabir bin 'Abdullah said:"The Messenger of Allah (ﷺ) said: 'There are two types among my Ummah who have no share of Islam: the people of Irja' and the people of Qadar}}
\hadithdefcmd{ibnmajah}{74}{حَدَّثَنَا أَبُو عُثْمَانَ الْبُخَارِيُّ، سَعِيدُ بْنُ سَعْدٍ قَالَ حَدَّثَنَا الْهَيْثَمُ بْنُ خَارِجَةَ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عَيَّاشٍ - عَنْ عَبْدِ الْوَهَّابِ بْنِ مُجَاهِدٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي هُرَيْرَةَ، وَابْنِ، عَبَّاسٍ قَالاَ الإِيمَانُ يَزِيدُ وَيَنْقُصُ ‏.‏\hadithno{74}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah and Ibn 'Abbas said:"Faith increases and decreases}}
\hadithdefcmd{ibnmajah}{75}{حَدَّثَنَا أَبُو عُثْمَانَ الْبُخَارِيُّ، حَدَّثَنَا الْهَيْثَمُ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ جَرِيرِ بْنِ عُثْمَانَ، عَنِ الْحَارِثِ، - أَظُنُّهُ - عَنْ مُجَاهِدٍ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ الإِيمَانُ يَزْدَادُ وَيَنْقُصُ ‏.‏\hadithno{75}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Darda' said:"Faith increases and decreases}}
\hadithdefcmd{ibnmajah}{76}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، وَمُحَمَّدُ بْنُ فُضَيْلٍ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَمُحَمَّدُ بْنُ عُبَيْدٍ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ حَدَّثَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ الصَّادِقُ الْمَصْدُوقُ قَالَ ‏ "‏ يُجْمَعُ خَلْقُ أَحَدِكُمْ فِي بَطْنِ أُمِّهِ أَرْبَعِينَ يَوْمًا ثُمَّ يَكُونُ عَلَقَةً مِثْلَ ذَلِكَ ثُمَّ يَكُونُ مُضْغَةً مِثْلَ ذَلِكَ ثُمَّ يَبْعَثُ اللَّهُ إِلَيْهِ الْمَلَكَ فَيُؤْمَرُ بِأَرْبَعِ كَلِمَاتٍ فَيَقُولُ اكْتُبْ عَمَلَهُ وَأَجَلَهُ وَرِزْقَهُ وَشَقِيٌّ أَمْ سَعِيدٌ ‏.‏ فَوَالَّذِي نَفْسِي بِيَدِهِ إِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ فَيَسْبِقُ عَلَيْهِ الْكِتَابُ فَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ فَيَدْخُلُهَا وَإِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ فَيَسْبِقُ عَلَيْهِ الْكِتَابُ فَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ فَيَدْخُلُهَا ‏"‏ ‏.‏\hadithno{76}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abdullah bin Mas'ud said:"The Messenger of Allah (ﷺ), the true and truly inspired one, told us that: 'The creation of one of you is put together in his mother's womb for forty days, then it becomes a clot for a similar length of time, then it becomes a chewed lump of flesh for a similar length of time. Then Allah sends the angel to him and commands him to write down four things. He says: "Write down his deeds, his life span, his provision, and whether he is doomed (destined for Hell) or blessed (destined for Paradise)." By the One in Whose Hand is my soul! One of you may do the deeds of the people of Paradise until there is no more than a forearm's length between him and it, then the decree overtakes him and he does the deeds of the people of Hell until there is no more than a forearm's length between him and it, then the decree overtakes him and he does the deeds of the people of Paradise until he enters therein}}
\hadithdefcmd{ibnmajah}{77}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبَا سِنَانٍ، عَنْ وَهْبِ بْنِ خَالِدٍ الْحِمْصِيِّ، عَنِ ابْنِ الدَّيْلَمِيِّ، قَالَ وَقَعَ فِي نَفْسِي شَىْءٌ مِنْ هَذَا الْقَدَرِ خَشِيتُ أَنْ يُفْسِدَ عَلَىَّ دِينِي وَأَمْرِي فَأَتَيْتُ أُبَىَّ بْنَ كَعْبٍ فَقَلْتُ أَبَا الْمُنْذِرِ إِنَّهُ قَدْ وَقَعَ فِي قَلْبِي شَىْءٌ مِنْ هَذَا الْقَدَرِ فَخَشِيتُ عَلَى دِينِي وَأَمْرِي فَحَدِّثْنِي مِنْ ذَلِكَ بِشَىْءٍ لَعَلَّ اللَّهَ أَنْ يَنْفَعَنِي بِهِ ‏.‏ فَقَالَ لَوْ أَنَّ اللَّهَ عَذَّبَ أَهْلَ سَمَوَاتِهِ وَأَهْلَ أَرْضِهِ لَعَذَّبَهُمْ وَهُوَ غَيْرُ ظَالِمٍ لَهُمْ وَلَوْ رَحِمَهُمْ لَكَانَتْ رَحْمَتُهُ خَيْرًا لَهُمْ مِنْ أَعْمَالِهِمْ ‏.‏ وَلَوْ كَانَ لَكَ مِثْلُ جَبَلِ أُحُدٍ ذَهَبًا أَوْ مِثْلُ جَبَلِ أُحُدٍ تُنْفِقُهُ فِي سَبِيلِ اللَّهِ مَا قُبِلَ مِنْكَ حَتَّى تُؤْمِنَ بِالْقَدَرِ ‏.‏ فَتَعْلَمَ أَنَّ مَا أَصَابَكَ لَمْ يَكُنْ لِيُخْطِئَكَ وَأَنَّ مَا أَخْطَأَكَ لَمْ يَكُنْ لِيُصِيبَكَ ‏.‏ وَأَنَّكَ إِنْ مُتَّ عَلَى غَيْرِ هَذَا دَخَلْتَ النَّارَ وَلاَ عَلَيْكَ أَنْ تَأْتِيَ أَخِي عَبْدَ اللَّهِ بْنَ مَسْعُودٍ فَتَسْأَلَهُ ‏.‏ فَأَتَيْتُ عَبْدَ اللَّهِ فَسَأَلْتُهُ فَذَكَرَ مِثْلَ مَا قَالَ أُبَىٌّ وَقَالَ لِي وَلاَ عَلَيْكَ أَنْ تَأْتِيَ حُذَيْفَةَ ‏.‏ فَأَتَيْتُ حُذَيْفَةَ فَسَأَلْتُهُ فَقَالَ مِثْلَ مَا قَالاَ وَقَالَ ائْتِ زَيْدَ بْنَ ثَابِتٍ فَاسْأَلْهُ ‏.‏ فَأَتَيْتُ زَيْدَ بْنَ ثَابِتٍ فَسَأَلْتُهُ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لَوْ أَنَّ اللَّهَ عَذَّبَ أَهْلَ سَمَوَاتِهِ وَأَهْلَ أَرْضِهِ لَعَذَّبَهُمْ وَهُوَ غَيْرُ ظَالِمٍ لَهُمْ وَلَوْ رَحِمَهُمْ لَكَانَتْ رَحْمَتُهُ خَيْرًا لَهُمْ مِنْ أَعْمَالِهِمْ وَلَوْ كَانَ لَكَ مِثْلُ أُحُدٍ ذَهَبًا أَوْ مِثْلُ جَبَلِ أُحُدٍ ذَهَبًا تُنْفِقُهُ فِي سَبِيلِ اللَّهِ مَا قَبِلَهُ مِنْكَ حَتَّى تُؤْمِنَ بِالْقَدَرِ كُلِّهِ فَتَعْلَمَ أَنَّ مَا أَصَابَكَ لَمْ يَكُنْ لِيُخْطِئَكَ وَمَا أَخْطَأَكَ لَمْ يَكُنْ لِيُصِيبَكَ وَأَنَّكَ إِنْ مُتَّ عَلَى غَيْرِ هَذَا دَخَلْتَ النَّارَ ‏"‏ ‏.‏\hadithno{77}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Dailami said:"I was confused about this Divine Decree (Qadar), and I was afraid lest that adversely affect my religion and my affairs. So I went to Ubayy bin Ka'b and said: 'O Abu Mundhir! I am confused about the Divine Decree, and I fear for my religion and my affairs, so tell me something about that through which Allah may benefit me.' He said: 'If Allah were to punish the inhabitants of His heavens and of his earth, He would do so and He would not be unjust towards them. And if He were to have mercy on them, His mercy would be better for them than their own deeds. If you had the equivalent of Mount Uhud which you spent in the cause of Allah, that would not be accepted from you until you believed in the Divine Decree and you know that whatever has befallen you, could not have passed you by; and whatever has passed you by, could not have befallen you; and that if you were to die believing anything other than this, you would enter Hell. And it will not harm you to go to my brother, 'Abdullah bin Mas'ud, and ask him (about this).' So I went to 'Abdullah and asked him , and he said something similar to what Ubayy had said, and he told me: 'It will not harm you to go to Hudhaifah.' So I went to Hudhaifah and asked him, and he said something similar to what they had said. And he told me: 'Go to Zaid bin Thabit and ask him.' So I went to Zaid bun Thabit and asked him, and he said: 'I heard the Messenger of Allah (ﷺ) say: "If Allah were to punish the inhabitants of His heavens and of His earth, he would do so and He would not be unjust towards them. And if He were to have mercy on them, His mercy would be better for them than their own deeds. If you had the equivalent of Mount Uhud which you spent in the cause of Allah, that would not be accepted from you until you believed in the Divine Decree and you know that whatever has befallen you, could not have passed you by; and whatever has passed you by, could not have befallen you; and that if you were to die believing anything other than this, you would enter Hell}}
\hadithdefcmd{ibnmajah}{78}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَبِيَدِهِ عُودٌ فَنَكَتَ فِي الأَرْضِ ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ وَقَدْ كُتِبَ مَقْعَدُهُ مِنَ الْجَنَّةِ وَمَقْعَدُهُ مِنَ النَّارِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ أَفَلاَ نَتَّكِلُ قَالَ ‏"‏ لاَ اعْمَلُوا وَلاَ تَتَّكِلُوا فَكُلٌّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ \{فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى * فَسَنُيَسِّرُهُ لِلْيُسْرَى * وَأَمَّا مَنْ بَخِلَ وَاسْتَغْنَى * وَكَذَّبَ بِالْحُسْنَى * فَسَنُيَسِّرُهُ لِلْعُسْرَى\}‏ ‏.‏\hadithno{78}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Ali said:"We were sitting with the Prophet (ﷺ) and he had a stick in his hand. He scratched in the ground with it, then raised his head and said: 'There is no one among you but his place in Paradise or Hell has already been decreed.' He was asked: 'O Messenger of Allah, should we not then rely upon that?' He said: 'No, strive and do not rely upon that, for it will be made easy for each person to do that for which he was created.' Then he recited: "As for him who gives (in charity) and keeps his duty to Allah and fears Him, and believes in Al-Husna. We will make smooth for him the path of ease (goodness). But he who is a greedy miser and thinks himself self-sufficient. And denies Al-Husna. We will make smooth for him the path for evil}}
\hadithdefcmd{ibnmajah}{79}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ الطَّنَافِسِيُّ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ رَبِيعَةَ بْنِ عُثْمَانَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ الْمُؤْمِنُ الْقَوِيُّ خَيْرٌ وَأَحَبُّ إِلَى اللَّهِ مِنَ الْمُؤْمِنِ الضَّعِيفِ وَفِي كُلٍّ خَيْرٌ احْرِصْ عَلَى مَا يَنْفَعُكَ وَاسْتَعِنْ بِاللَّهِ وَلاَ تَعْجِزْ فَإِنْ أَصَابَكَ شَىْءٌ فَلاَ تَقُلْ لَوْ أَنِّي فَعَلْتُ كَذَا وَكَذَا ‏.‏ وَلَكِنْ قُلْ قَدَّرَ اللَّهُ وَمَا شَاءَ فَعَلَ فَإِنَّ ‏"‏ لَوْ ‏"‏ تَفْتَحُ عَمَلَ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{79}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The strong believer is better and more beloved to Allah than the weak believer, although both are good. Strive for that which will benefit you, seek the help of Allah, and do not feel helpless. If anything befalls you, do not say, "if only I had done such and such" rather say "Qaddara Allahu wa ma sha'a fa'ala (Allah has decreed and whatever he wills, He does)." For (saying) 'If' opens (the door) to the deeds of Satan}}
\hadithdefcmd{ibnmajah}{80}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، سَمِعَ طَاوُسًا، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يُخْبِرُ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ احْتَجَّ آدَمُ وَمُوسَى فَقَالَ لَهُ مُوسَى يَا آدَمُ أَنْتَ أَبُونَا خَيَّبْتَنَا وَأَخْرَجْتَنَا مِنَ الْجَنَّةِ بِذَنْبِكَ ‏.‏ فَقَالَ لَهُ آدَمُ يَا مُوسَى اصْطَفَاكَ اللَّهُ بِكَلاَمِهِ وَخَطَّ لَكَ التَّوْرَاةَ بِيَدِهِ أَتَلُومُنِي عَلَى أَمْرٍ قَدَّرَهُ اللَّهُ عَلَىَّ قَبْلَ أَنْ يَخْلُقَنِي بِأَرْبَعِينَ سَنَةً فَحَجَّ آدَمُ مُوسَى فَحَجَّ آدَمُ مُوسَى فَحَجَّ آدَمُ مُوسَى ‏"‏ ‏.‏ ثَلاَثًا ‏.‏\hadithno{80}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Amr bin Dinar heard Tawus say:"I heard Abu Hurairah narrating that the Prophet (ﷺ) said: 'Adam and Musa debated, and Musa said to him: "O Adam, you are our father but have deprived us and caused us to be expelled from Paradise because of your sin." Adam said to him: "O Musa, Allah chose you to speak with, and he wrote the Tawrah for you with His own Hand. Are you blaming me for something which Allah decreed for me forty years before He created me?" Thus Adam won the argument with Musa, thus Adam won the argument with Musa}}
\hadithdefcmd{ibnmajah}{81}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يُؤْمِنُ عَبْدٌ حَتَّى يُؤْمِنَ بِأَرْبَعٍ بِاللَّهِ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنِّي رَسُولُ اللَّهِ وَبِالْبَعْثِ بَعْدَ الْمَوْتِ وَالْقَدَرِ ‏"‏ ‏.‏\hadithno{81}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah (ﷺ) said: 'No slave truly believes until he believes in four things: in Allah alone with no partner; that I am the Messenger of Allah; in the resurrection after death; and in the Divine Decree (Qadar)}}
\hadithdefcmd{ibnmajah}{82}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى بْنِ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَمَّتِهِ، عَائِشَةَ بِنْتِ طَلْحَةَ عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ دُعِيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى جِنَازَةِ غُلاَمٍ مِنَ الأَنْصَارِ فَقُلْتُ يَا رَسُولَ اللَّهِ طُوبَى لِهَذَا عُصْفُورٌ مِنْ عَصَافِيرِ الْجَنَّةِ لَمْ يَعْمَلِ السُّوءَ وَلَمْ يُدْرِكْهُ ‏.‏ قَالَ ‏ "‏ أَوَ غَيْرُ ذَلِكَ يَا عَائِشَةُ إِنَّ اللَّهَ خَلَقَ لِلْجَنَّةِ أَهْلاً خَلَقَهُمْ لَهَا وَهُمْ فِي أَصْلاَبِ آبَائِهِمْ وَخَلَقَ لِلنَّارِ أَهْلاً خَلَقَهُمْ لَهَا وَهُمْ فِي أَصْلاَبِ آبَائِهِمْ ‏"‏ ‏.‏\hadithno{82}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah the Mother of the Believers said:"The Messenger of Allah (ﷺ) was called to the funeral of a child from among the Ansar. I said: 'O Messenger of Allah, glad tidings for him! He is one of the little birds of Paradise, who never did evil or reached the age of doing evil (i.e, the age of accountability).' He said: 'It may not be so, O 'Aishah! For Allah created people for Paradise, He created them for it when they were still in their father's loins, And He has created people for Hell, He created them for it when they were still in their fathers' loins}}
\hadithdefcmd{ibnmajah}{83}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ زِيَادِ بْنِ إِسْمَاعِيلَ الْمَخْزُومِيِّ، عَنْ مُحَمَّدِ بْنِ عَبَّادِ بْنِ جَعْفَرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ مُشْرِكُو قُرَيْشٍ يُخَاصِمُونَ النَّبِيَّ ـ صلى الله عليه وسلم ـ فِي الْقَدَرِ فَنَزَلَتْ هَذِهِ الآيَةُ \{يَوْمَ يُسْحَبُونَ فِي النَّارِ عَلَى وُجُوهِهِمْ ذُوقُوا مَسَّ سَقَرَ * إِنَّا كُلَّ شَىْءٍ خَلَقْنَاهُ بِقَدَرٍ ‏\}‏ ‏.‏\hadithno{83}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The idolators and Quraish came and disputed with the Prophet (ﷺ) concerning the Divine Decree. Then the following verse was revealed: 'The Day they will be dragged on their faces into the Fire (it will be said to them): "Taste you the touch of Hell!" Verily We have created all things with Qadar. (Divine Decree)}}
\hadithdefcmd{ibnmajah}{84}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ، مَوْلَى أَبِي بَكْرٍ حَدَّثَنَا يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ أَبِيهِ، أَنَّهُ دَخَلَ عَلَى عَائِشَةَ فَذَكَرَ لَهَا شَيْئًا مِنَ الْقَدَرِ فَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ تَكَلَّمَ فِي شَىْءٍ مِنَ الْقَدَرِ سُئِلَ عَنْهُ يَوْمَ الْقِيَامَةِ وَمَنْ لَمْ يَتَكَلَّمْ فِيهِ لَمْ يُسْأَلْ عَنْهُ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ الْقَطَّانُ حَدَّثَنَاهُ خَازِمُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شَيْبَانَ، حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{84}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Abi Mulaikah narrated that his father entered upon `A'ishah and said something to her about the Divine Decree:She said: "I heard The Messenger of Allah (ﷺ) say: 'Whoever says anything about the Divine decree will be questioned about that on the Day of Resurrection, and whoever does not say anything about it will not be questioned about it.'" Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{85}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى أَصْحَابِهِ وَهُمْ يَخْتَصِمُونَ فِي الْقَدَرِ فَكَأَنَّمَا يُفْقَأُ فِي وَجْهِهِ حَبُّ الرُّمَّانِ مِنَ الْغَضَبِ فَقَالَ ‏ "‏ بِهَذَا أُمِرْتُمْ أَوْ لِهَذَا خُلِقْتُمْ تَضْرِبُونَ الْقُرْآنَ بَعْضَهُ بِبَعْضٍ ‏.‏ بِهَذَا هَلَكَتِ الأُمَمُ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ فَقَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو مَا غَبَطْتُ نَفْسِي بِمَجْلِسٍ تَخَلَّفْتُ فِيهِ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مَا غَبَطْتُ نَفْسِي بِذَلِكَ الْمَجْلِسِ وَتَخَلُّفِي عَنْهُ.‏\hadithno{85}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr in Shu'aib narrated from his father that his grandfather said:"The Messenger of Allah (ﷺ) came out to his Companions when they were disputing about the Divine Decree, and it was as if pomegranate seeds had burst on his face (i.e. turned red) because of anger. He said: 'Have you been commanded to do this, or were you created for this purpose? You are using one part of the Qur'an against another part, and this is what led to the doom of the nations who came before you.'" 'Abdullah bin 'Amr said: "I was never happy to have missed a gathering with the Messenger of Allah (ﷺ) as I was to have missed that gathering}}
\hadithdefcmd{ibnmajah}{86}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا يَحْيَى بْنُ أَبِي حَيَّةَ أَبُو جَنَابٍ الْكَلْبِيُّ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَلاَ هَامَةَ ‏"‏ ‏.‏ فَقَامَ إِلَيْهِ رَجُلٌ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ الْبَعِيرَ يَكُونُ بِهِ الْجَرَبُ فَيُجْرِبُ الإِبِلَ كُلَّهَا قَالَ ‏"‏ ذَلِكُمُ الْقَدَرُ فَمَنْ أَجْرَبَ الأَوَّلَ ‏"‏ ‏.‏\hadithno{86}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) said: 'There is no 'Adwa (contagion), no Tiyarah (evil omen) and no Hamah.' A Bedouin man stood up and said: 'O Messenger of Allah, what do you think about a camel that suffers from mange and then all other camels get mange?' He said: 'That is because of the Divine Decree. How else did the first one get mange?'" Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{ibnmajah}{87}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ عِيسَى الْجَرَّارُ، عَنْ عَبْدِ الأَعْلَى بْنِ أَبِي الْمُسَاوِرِ، عَنِ الشَّعْبِيِّ، قَالَ لَمَّا قَدِمَ عَدِيُّ بْنُ حَاتِمٍ الْكُوفَةَ أَتَيْنَاهُ فِي نَفَرٍ مِنْ فُقَهَاءِ أَهْلِ الْكُوفَةِ ‏.‏ فَقُلْنَا لَهُ حَدِّثْنَا مَا سَمِعْتَ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقَالَ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ يَا عَدِيَّ بْنَ حَاتِمٍ أَسْلِمْ تَسْلَمْ ‏"‏ ‏.‏ قُلْتُ وَمَا الإِسْلاَمُ فَقَالَ ‏"‏ تَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ وَتُؤْمِنُ بِالأَقْدَارِ كُلِّهَا خَيْرِهَا وَشَرِّهَا حُلْوِهَا وَمُرِّهَا ‏"‏ ‏.‏\hadithno{87}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Sha'bi said:"When 'Adi bin Hatim came to Kufah, we came to him with a delegation of the Fuqaha of Kufah and said to him: 'Tell us of something that you heard from the Messenger of Allah (ﷺ).' He said: 'I came to the Prophet (ﷺ) and he said: "O 'Adi bin Hatim, enter Islam and you will be safe." I said, "What is Islam?" He said: "To testify to La ilaha illallah (none has the right to be worshipped but Allah) and that I am the Messenger of Allah, and to believe in all the Divine Decrees, the good of them and the bad of them, the sweet of them and the bitter of them}}
\hadithdefcmd{ibnmajah}{88}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ غُنَيْمِ بْنِ قَيْسٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَثَلُ الْقَلْبِ مَثَلُ الرِّيشَةِ تُقَلِّبُهَا الرِّيَاحُ بِفَلاَةٍ ‏"‏ ‏.‏\hadithno{88}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Musa Al-Ash'ari said:"The Messenger of Allah (ﷺ) said: 'The likeness of the heart is that of a feather blown about by the wind in the desert}}
\hadithdefcmd{ibnmajah}{89}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا خَالِي، يَعْلَى عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرٍ، قَالَ جَاءَ رَجُلٌ مِنَ الأَنْصَارِ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي جَارِيَةً أَعْزِلُ عَنْهَا قَالَ ‏"‏ سَيَأْتِيهَا مَا قُدِّرَ لَهَا ‏"‏ ‏.‏ فَأَتَاهُ بَعْدَ ذَلِكَ فَقَالَ قَدْ حَمَلَتِ الْجَارِيَةُ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مَا قُدِّرَ لِنَفْسٍ شَىْءٌ إِلاَّ هِيَ كَائِنَةٌ ‏"‏ ‏.‏\hadithno{89}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"A man from among the Ansar came to the Prophet (ﷺ) and said: 'O Messenger of Allah (ﷺ), I have a slave girl. Should I do 'Azl (coitus interruptus) with her?' He said 'Whatever is decreed for her shall come to her." He (the Ansari) came to him later on and said: "The slave girl has become pregnant." The Prophet (ﷺ) said: "Nothing is decreed for a person but it will surely come to pass}}
\hadithdefcmd{ibnmajah}{90}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْجَعْدِ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَزِيدُ فِي الْعُمْرِ إِلاَّ الْبِرُّ وَلاَ يَرُدُّ الْقَدَرَ إِلاَّ الدُّعَاءُ وَإِنَّ الرَّجُلَ لَيُحْرَمُ الرِّزْقَ لِلْخَطِيئَةِ يَعْمَلُهَا ‏"‏ ‏.‏\hadithno{90}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Thawban said:"The Messenger of Allah (ﷺ) said: 'Nothing extends one's life span but righteousness, nothing averts the Divine Decree but supplication, and nothing deprives a man of provision but the sin that he commits}}
\hadithdefcmd{ibnmajah}{91}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَطَاءُ بْنُ مُسْلِمٍ الْخَفَّافُ، حَدَّثَنَا الأَعْمَشُ، عَنْ مُجَاهِدٍ، عَنْ سُرَاقَةَ بْنِ جُعْشُمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ الْعَمَلُ فِيمَا جَفَّ بِهِ الْقَلَمُ وَجَرَتْ بِهِ الْمَقَادِيرُ أَوْ فِي أَمْرٍ مُسْتَقْبَلٍ قَالَ ‏ "‏ بَلْ فِيمَا جَفَّ بِهِ الْقَلَمُ وَجَرَتْ بِهِ الْمَقَادِيرُ وَكُلٌّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ ‏"‏ ‏.‏\hadithno{91}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Suraqah bin Ju'shum said:"I said: 'O Messenger of Allah (ﷺ), is one's deed in that which has already dried of the Pen and what has passed of the Divine Decree, or is it in the future?' He said: 'No, it is in that which he already dried of the Pen and what has passed of the Divine Decree, and each person is facilitated for what he has been created}}
\hadithdefcmd{ibnmajah}{92}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنِ الأَوْزَاعِيِّ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مَجُوسَ هَذِهِ الأُمَّةِ الْمُكَذِّبُونَ بِأَقْدَارِ اللَّهِ إِنْ مَرِضُوا فَلاَ تَعُودُوهُمْ وَإِنْ مَاتُوا فَلاَ تَشْهَدُوهُمْ وَإِنْ لَقِيتُمُوهُمْ فَلاَ تُسَلِّمُوا عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{92}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah (ﷺ) said: 'The Magicians of this Ummah are those who deny the decrees of Allah. If they fall sick, do not visit them; if they die, do not attend their funerals; and if you meet them, do not greet them with Salam}}
\hadithdefcmd{ibnmajah}{93}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَلاَ إِنِّي أَبْرَأُ إِلَى كُلِّ خَلِيلٍ مِنْ خُلَّتِهِ وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ أَبَا بَكْرٍ خَلِيلاً إِنَّ صَاحِبَكُمْ خَلِيلُ اللَّهِ ‏"‏ ‏.‏ قَالَ وَكِيعٌ يَعْنِي نَفْسَهُ ‏.‏\hadithno{93}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah said: 'I have no need of the friendship of any Khalil (close friend) but if I were to have taken anyone as a close friend, I would have taken Abu Bakr as a close friend, but your companion is the close friend of Allah,'" (One of the narrators) Waki' said: (by the phrase 'your companion'), he was referring to himself}}
\hadithdefcmd{ibnmajah}{94}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا نَفَعَنِي مَالٌ قَطُّ مَا نَفَعَنِي مَالُ أَبِي بَكْرٍ ‏"‏ ‏.‏ قَالَ فَبَكَى أَبُو بَكْرٍ وَقَالَ هَلْ أَنَا وَمَالِي إِلاَّ لَكَ يَا رَسُولَ اللَّهِ\hadithno{94}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The wealth of none of you has benefited me as much as the wealth of Abu Bakr.'" Abu Bakr wept and said: 'O Messenger of Allah, I and my wealth are only for you, O Messenger of Allah}}
\hadithdefcmd{ibnmajah}{95}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الْحَسَنِ بْنِ عُمَارَةَ، عَنْ فِرَاسٍ، عَنِ الشَّعْبِيِّ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَبُو بَكْرٍ وَعُمَرُ سَيِّدَا كُهُولِ أَهْلِ الْجَنَّةِ مِنَ الأَوَّلِينَ وَالآخِرِينَ إِلاَّ النَّبِيِّينَ وَالْمُرْسَلِينَ لاَ تُخْبِرْهُمَا يَا عَلِيُّ مَا دَامَا حَيَّيْنِ ‏"‏ ‏.‏\hadithno{95}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah said: 'Abu Bakr and 'Umar are the leaders of the mature people of Paradise, and the first and the last, except for the Prophets and Messengers, but do not tell them about that, O 'Ali, as long as they are still alive}}
\hadithdefcmd{ibnmajah}{96}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَطِيَّةَ بْنِ سَعْدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَهْلَ الدَّرَجَاتِ الْعُلَى يَرَاهُمْ مَنْ أَسْفَلَ مِنْهُمْ كَمَا يُرَى الْكَوْكَبُ الطَّالِعُ فِي الأُفُقِ مِنْ آفَاقِ السَّمَاءِ وَإِنَّ أَبَا بَكْرٍ وَعُمَرَ مِنْهُمْ وَأَنْعَمَا ‏"‏ ‏.‏\hadithno{96}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah said: 'The people of the highest degrees of Paradise will be seen by those beneath them as a rising star is seen on the horizon. Abu Bakr and 'Umar will be among them, and how blessed they are}}
\hadithdefcmd{ibnmajah}{97}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُؤَمَّلٌ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مَوْلًى، لِرِبْعِيِّ بْنِ حِرَاشٍ عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي لاَ أَدْرِي قَدْرَ بَقَائِي فِيكُمْ فَاقْتَدُوا بِاللَّذَيْنِ مِنْ بَعْدِي ‏"‏ ‏.‏ وَأَشَارَ إِلَى أَبِي بَكْرٍ وَعُمَرَ ‏.‏\hadithno{97}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hudhaifah bin Yaman said:"The Messenger of Allah (ﷺ) said: 'I do not know how long I will stay among you, so follow the example of these two after I am gone,' and he pointed to Abu Bakr and `Umar}}
\hadithdefcmd{ibnmajah}{98}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ لَمَّا وُضِعَ عُمَرُ عَلَى سَرِيرِهِ اكْتَنَفَهُ النَّاسُ يَدْعُونَ وَيُصَلُّونَ - أَوْ قَالَ يُثْنُونَ وَيُصَلُّونَ - عَلَيْهِ قَبْلَ أَنْ يُرْفَعَ وَأَنَا فِيهِمْ فَلَمْ يَرُعْنِي إِلاَّ رَجُلٌ قَدْ زَحَمَنِي وَأَخَذَ بِمَنْكِبِي فَالْتَفَتُّ فَإِذَا عَلِيُّ بْنُ أَبِي طَالِبٍ فَتَرَحَّمَ عَلَى عُمَرَ ثُمَّ قَالَ مَا خَلَّفْتُ أَحَدًا أَحَبَّ إِلَىَّ أَنْ أَلْقَى اللَّهَ بِمِثْلِ عَمَلِهِ مِنْكَ وَايْمُ اللَّهِ إِنْ كُنْتُ لأَظُنُّ لَيَجْعَلَنَّكَ اللَّهُ عَزَّ وَجَلَّ مَعَ صَاحِبَيْكَ وَذَلِكَ أَنِّي كُنْتُ أَكْثَرُ أَنْ أَسْمَعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ ذَهَبْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ وَدَخَلْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ وَخَرَجْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ ‏.‏ فَكُنْتُ أَظُنُّ لَيَجْعَلَنَّكَ اللَّهُ مَعَ صَاحِبَيْكَ ‏.‏\hadithno{98}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn Abi Mulaikah said:"I heard Ibn 'Abbas say: 'When 'Umar was placed on his bed (i.e., his bier), the people around him gathered around him, praying and invoking blessings upon him,' or he said, 'praising him and invoking blessings upon him before (the bier) was lifted up, and I was among them. No one alarmed me except a man who crowded against me and seized me by the shoulder. I turned and saw that it was 'Ali bin Abu Talib. He prayed for mercy for 'Umar, then he said: "You have not left behind anyone who it is more beloved to me to meet Allah with the like of his deeds than yourself. By Allah, I think that Allah will most certainly unite you with your two companions, and that is because I often heard the Messenger of Allah saying: 'Abu Bakr, 'Umar and I went; Abu Bakr, 'Umar and I came in; Abu Bakr, 'Umar and I went out.' So I think that Allah will most certainly join you to your two companions}}
\hadithdefcmd{ibnmajah}{99}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا سَعِيدُ بْنُ مَسْلَمَةَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَيْنَ أَبِي بَكْرٍ وَعُمَرَ فَقَالَ ‏ "‏ هَكَذَا نُبْعَثُ ‏"‏ ‏.‏\hadithno{99}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah came out standing between Abu Bakr and 'Umar and said: 'Thus will I be resurrected}}
\hadithdefcmd{ibnmajah}{100}{حَدَّثَنَا أَبُو شُعَيْبٍ، صَالِحُ بْنُ الْهَيْثَمِ الْوَاسِطِيُّ حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ بَكْرِ بْنِ خُنَيْسٍ، حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَبُو بَكْرٍ وَعُمَرُ سَيِّدَا كُهُولِ أَهْلِ الْجَنَّةِ مِنَ الأَوَّلِينَ وَالآخِرِينَ إِلاَّ النَّبِيِّينَ وَالْمُرْسَلِينَ ‏"‏ ‏.‏\hadithno{100}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Awn bin Abi Juhaifah that his father said:"The Messenger of Allah said: 'Abu Bakr and 'Umar are the leaders of the mature people of Paradise, the first and the last, except for the Prophets and the Messengers}}
\hadithdefcmd{ibnmajah}{101}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، وَالْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، قَالاَ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ أَىُّ النَّاسِ أَحَبُّ إِلَيْكَ قَالَ ‏"‏ عَائِشَةُ ‏"‏ ‏.‏ قِيلَ مِنَ الرِّجَالِ قَالَ ‏"‏ أَبُوهَا ‏"‏ ‏.‏\hadithno{101}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"It was said: 'O Messenger of Allah, which of the people is most beloved to you?' He said: "Aishah.' It was asked, 'And among men?' He said: 'Her father}}
\hadithdefcmd{ibnmajah}{102}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، أَخْبَرَنِي الْجُرَيْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ أَىُّ أَصْحَابِهِ كَانَ أَحَبَّ إِلَيْهِ قَالَتْ أَبُو بَكْرٍ ‏.‏ قُلْتُ ثُمَّ أَيُّهُمْ قَالَتْ عُمَرُ ‏.‏ قُلْتُ ثُمَّ أَيُّهُمْ قَالَتْ أَبُو عُبَيْدَةَ ‏.‏\hadithno{102}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Shaqiq said:"I said to 'Aishah: 'Which of the (Prophet's) Companions was most beloved to him?' She said: 'Abu Bakr.' I said: 'Then which of them?' She said: ''Umar.' I said: 'Then which of them?' She said: 'Abu 'Ubaidah}}
\hadithdefcmd{ibnmajah}{103}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُحَمَّدٍ الطَّلْحِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ خِرَاشٍ الْحَوْشَبِيُّ، عَنِ الْعَوَّامِ بْنِ حَوْشَبٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا أَسْلَمَ عُمَرُ نَزَلَ جِبْرِيلُ فَقَالَ يَا مُحَمَّدُ لَقَدِ اسْتَبْشَرَ أَهْلُ السَّمَاءِ بِإِسْلاَمِ عُمَرَ ‏.‏\hadithno{103}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"When 'Umar became Muslim, Jibril came down and said: 'O Muhammed! The people of heaven are rejoicing because of 'Umar's Islam}}
\hadithdefcmd{ibnmajah}{104}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُحَمَّدٍ الطَّلْحِيُّ، أَنْبَأَنَا دَاوُدُ بْنُ عَطَاءٍ الْمَدِينِيُّ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَوَّلُ مَنْ يُصَافِحُهُ الْحَقُّ عُمَرُ وَأَوَّلُ مَنْ يُسَلِّمُ عَلَيْهِ وَأَوَّلُ مَنْ يَأْخُذُ بِيَدِهِ فَيُدْخِلُهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{104}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrted that Ubayy bin Ka'b said:"The Messenger of Allah said: 'The first person with whom Allah will shake hands will be 'Umar, (and he is) the first person to be greeted with the Salam, and the first person who will be taken by the hand and admitted into Paradise}}
\hadithdefcmd{ibnmajah}{105}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ أَبُو عُبَيْدٍ الْمَدِينِيُّ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الْمَاجِشُونِ، حَدَّثَنِي الزَّنْجِيُّ بْنُ خَالِدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُمَّ أَعِزَّ الإِسْلاَمَ بِعُمَرَ بْنِ الْخَطَّابِ خَاصَّةً ‏"‏ ‏.‏\hadithno{105}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'O Allah! Strengthen Islam with 'Umar bin Khattab in particular}}
\hadithdefcmd{ibnmajah}{106}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلَمَةَ، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ خَيْرُ النَّاسِ بَعْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَبُو بَكْرٍ وَخَيْرُ النَّاسِ بَعْدَ أَبِي بَكْرٍ عُمَرُ ‏.‏\hadithno{106}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Salimah said:"I heard 'Ali say: 'The best of people after the Messenger of Allah is Abu Bakr, and the best of people after Abu Bakr is 'Umar}}
\hadithdefcmd{ibnmajah}{107}{حَدَّثَنَا مُحَمَّدُ بْنُ الْحَارِثِ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُنِي فِي الْجَنَّةِ فَإِذَا أَنَا بِامْرَأَةٍ تَتَوَضَّأُ إِلَى جَانِبِ قَصْرٍ فَقُلْتُ لِمَنْ هَذَا الْقَصْرُ فَقَالَتْ لِعُمَرَ ‏.‏ فَذَكَرْتَ غَيْرَتَهُ فَوَلَّيْتُ مُدْبِرًا ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَبَكَى عُمَرُ فَقَالَ أَعَلَيْكَ بِأَبِي وَأُمِّي يَا رَسُولَ اللَّهِ أَغَارُ\hadithno{107}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah said:"We were sitting with the Prophet and he said: 'While I was sleeping I saw myself in Paradise (in a dream), and I saw a woman performing ablution beside a palace. I asked: "Whose palace is this?" She said: "'Umar's." I remembered his protective jealousy, so I turned away and left.'" Abu Hurairah said: ''Umar wept and said: 'May my father and mother be sacrificed for you, O Messenger of Allah! Would I feel any protective jealousy against you?}}
\hadithdefcmd{ibnmajah}{108}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مَكْحُولٍ، عَنْ غُضَيْفِ بْنِ الْحَارِثِ، عَنْ أَبِي ذَرٍّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ اللَّهَ وَضَعَ الْحَقَّ عَلَى لِسَانِ عُمَرَ يَقُولُ بِهِ ‏"‏ ‏.‏\hadithno{108}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Dharr said:"I heard the Messenger of Allah say: 'Allah has placed the truth on the tongue of 'Umar, and he speaks with that (truth)}}
\hadithdefcmd{ibnmajah}{109}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا أَبِي عُثْمَانُ بْنُ خَالِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لِكُلِّ نَبِيٍّ رَفِيقٌ فِي الْجَنَّةِ وَرَفِيقِي فِيهَا عُثْمَانُ بْنُ عَفَّانَ ‏"‏ ‏.‏\hadithno{109}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "Every Prophet will have a friend in Paradise, and my friend there will be 'Uthman bin 'Affan}}
\hadithdefcmd{ibnmajah}{110}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا أَبِي عُثْمَانُ بْنُ خَالِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الزِّنَادِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ لَقِيَ عُثْمَانَ عِنْدَ بَابِ الْمَسْجِدِ فَقَالَ ‏ "‏ يَا عُثْمَانُ هَذَا جِبْرِيلُ أَخْبَرَنِي أَنَّ اللَّهَ قَدْ زَوَّجَكَ أُمَّ كُلْثُومٍ بِمِثْلِ صَدَاقِ رُقَيَّةَ عَلَى مِثْلِ صُحْبَتِهَا ‏"‏ ‏.‏\hadithno{110}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet met 'Uthman at the door of the mosque and said: "O 'Uthman! Jibril has told me that Allah married you to Umm Kulthum for a dowry like that of Ruqayyah, provided that you treat her as you treated Ruqayyah}}
\hadithdefcmd{ibnmajah}{111}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ ذَكَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِتْنَةً فَقَرَّبَهَا فَمَرَّ رَجُلٌ مُقَنَّعٌ رَأْسُهُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ هَذَا يَوْمَئِذٍ عَلَى الْهُدَى ‏"‏ ‏.‏ فَوَثَبْتُ فَأَخَذْتُ بِضَبْعَىْ عُثْمَانَ ثُمَّ اسْتَقْبَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقُلْتُ هَذَا قَالَ ‏"‏ هَذَا ‏"‏ ‏.‏\hadithno{111}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ka'b bin 'Ujrah said:"The Messenger of Allah mentioned a Fitnah (tribulation) that had drawn nigh. Then a man passed by with his head covered. The Messenger of Allah said: 'On that day, this man will be following right guidance.' I leapt up and took hold of 'Uthman's arms, then I turned to face the Messenger of Allah and said: 'This man?' He said: 'This man}}
\hadithdefcmd{ibnmajah}{112}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الْفَرَجُ بْنُ فَضَالَةَ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ الدِّمَشْقِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا عُثْمَانُ إِنْ وَلاَّكَ اللَّهُ هَذَا الأَمْرَ يَوْمًا فَأَرَادَكَ الْمُنَافِقُونَ أَنْ تَخْلَعَ قَمِيصَكَ الَّذِي قَمَّصَكَ اللَّهُ فَلاَ تَخْلَعْهُ ‏"‏ ‏.‏ يَقُولُ ذَلِكَ ثَلاَثَ مَرَّاتٍ ‏.‏ قَالَ النُّعْمَانُ فَقُلْتُ لِعَائِشَةَ مَا مَنَعَكِ أَنْ تُعْلِمِي النَّاسَ بِهَذَا قَالَتْ أُنْسِيتُهُ وَاللَّهِ ‏.‏\hadithno{112}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:The Messenger of Allah said: "O 'Uthman, if Allah places you in authority over this matter (as the caliph) some day and the hypocrites want to rid you of the garment with which Allah has clothed you (i.e., the position of caliph), do not take it off." He said that three times. (One of the narrators) Nu'man said: "I said to 'Aishah: 'What kept you from telling the people that?' She said: 'I was made to forget it}}
\hadithdefcmd{ibnmajah}{113}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي مَرَضِهِ ‏"‏ وَدِدْتُ أَنَّ عِنْدِي بَعْضَ أَصْحَابِي ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ أَلاَ نَدْعُو لَكَ أَبَا بَكْرٍ فَسَكَتَ قُلْنَا أَلاَ نَدْعُو لَكَ عُمَرَ فَسَكَتَ قُلْنَا أَلاَ نَدْعُو لَكَ عُثْمَانَ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَجَاءَ عُثْمَانُ فَخَلاَ بِهِ فَجَعَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُكَلِّمُهُ وَوَجْهُ عُثْمَانَ يَتَغَيَّرُ ‏.‏ قَالَ قَيْسٌ فَحَدَّثَنِي أَبُو سَهْلَةَ مَوْلَى عُثْمَانَ أَنَّ عُثْمَانَ بْنَ عَفَّانَ قَالَ يَوْمَ الدَّارِ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَهِدَ إِلَىَّ عَهْدًا وَأَنَا صَائِرٌ إِلَيْهِ ‏.‏ وَقَالَ عَلِيٌّ فِي حَدِيثِهِ وَأَنَا صَابِرٌ عَلَيْهِ ‏.‏ قَالَ قَيْسٌ فَكَانُوا يُرَوْنَهُ ذَلِكَ الْيَوْمَ ‏.‏\hadithno{113}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"When he was ill, the Messenger of Allah said: 'I would like to have some of my Companions with me.' We said: 'O Messenger of Allah! Shall we call Abu Bakr for you?' But he remained silent. We said: 'Shall we call 'Umar for you?' But he remained silent. We said: 'Shall we call 'Uthman for you?' He said: 'Yes.' So 'Uthman came and he spoke to him in private. The Prophet started to speak to him and 'Uthman's expression changed." Qais said: "Abu Sahlah, the freed slave of 'Uthman, narrated to me that on the Day of the House, 'Uthman bin 'Affan said: 'The Messenger of Allah told me what would come to pass and now I am coming to that day.'"In his narration of the Hadith, 'Ali (one of the narrators) said (that he said): "And I am going to bear it with patience." Qais said: "They used to think that that was the Day of the House}}
\hadithdefcmd{ibnmajah}{114}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ عَنِ الأَعْمَشِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ عَلِيٍّ، قَالَ عَهِدَ إِلَىَّ النَّبِيُّ الأُمِّيُّ ـ صلى الله عليه وسلم ـ أَنَّهُ لاَ يُحِبُّنِي إِلاَّ مُؤْمِنٌ وَلاَ يُبْغِضُنِي إِلاَّ مُنَافِقٌ ‏.‏\hadithno{114}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ali said:"The Unlettered Prophet informed me (saying) that none but a believer would love me and none but a hypocrite would hate me}}
\hadithdefcmd{ibnmajah}{115}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ سَمِعْتُ إِبْرَاهِيمَ بْنَ سَعْدِ بْنِ أَبِي وَقَّاصٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ لِعَلِيٍّ ‏ "‏ أَلاَ تَرْضَى أَنْ تَكُونَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى ‏"‏ ‏.‏\hadithno{115}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Sa'd bin Abu Waqqas narrated from his father that:The Prophet said to 'Ali: "Would it not please you to be to me as Harun was to Musa?}}
\hadithdefcmd{ibnmajah}{116}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو الْحُسَيْنِ، أَخَبَرَنِي حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدِ بْنِ جُدْعَانَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَقْبَلْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي حَجَّتِهِ الَّتِي حَجَّ فَنَزَلَ فِي الطَّرِيقِ فَأَمَرَ الصَّلاَةَ جَامِعَةً فَأَخَذَ بِيَدِ عَلِيٍّ فَقَالَ ‏"‏ أَلَسْتُ أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ أَلَسْتُ أَوْلَى بِكُلِّ مُؤْمِنٍ مِنْ نَفْسِهِ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ فَهَذَا وَلِيُّ مَنْ أَنَا مَوْلاَهُ اللَّهُمَّ وَالِ مَنْ وَالاَهُ اللَّهُمَّ عَادِ مَنْ عَادَاهُ ‏"‏ ‏.‏\hadithno{116}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Bara' bin 'Azib said:"We returned with the Messenger of Allah from his Hajj that he had performed, and we stopped at some point on the road. He commanded that prayer should be performed in congregation, then he took the hand of 'Ali and said: 'Am I not dearer to the believers than their own selves?' They said: 'Yes indeed.' He said: 'Am I not dearer to every believer than his own self?' They said: 'Yes indeed.' He said: 'This man is the friend of those whose master I am.' O Allah, take as friends those who take him as a friend, and take as enemies those who take him as an enemy}}
\hadithdefcmd{ibnmajah}{117}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا ابْنُ أَبِي لَيْلَى، حَدَّثَنَا الْحَكَمُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ كَانَ أَبُو لَيْلَى يَسْمُرُ مَعَ عَلِيٍّ فَكَانَ يَلْبَسُ ثِيَابَ الصَّيْفِ فِي الشِّتَاءِ وَثِيَابَ الشِّتَاءِ فِي الصَّيْفِ فَقُلْنَا لَوْ سَأَلْتَهُ فَقَالَ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بَعَثَ إِلَىَّ وَأَنَا أَرْمَدُ الْعَيْنِ يَوْمَ خَيْبَرَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَرْمَدُ الْعَيْنِ ‏.‏ فَتَفَلَ فِي عَيْنِي ثُمَّ قَالَ ‏"‏ اللَّهُمَّ أَذْهِبْ عَنْهُ الْحَرَّ وَالْبَرْدَ ‏"‏ ‏.‏ قَالَ فَمَا وَجَدْتُ حَرًّا وَلاَ بَرْدًا بَعْدَ يَوْمِئِذٍ ‏.‏ وَقَالَ ‏"‏ لأَبْعَثَنَّ رَجُلاً يُحِبُّ اللَّهَ وَرَسُولَهُ وَيُحِبُّهُ اللَّهُ وَرَسُولُهُ لَيْسَ بِفَرَّارٍ ‏"‏ ‏.‏ فَتَشَوَّفَ لَهَا النَّاسُ فَبَعَثَ إِلَى عَلِيٍّ فَأَعْطَاهَا إِيَّاهُ ‏.‏\hadithno{117}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdur-Rahman bin Abu laila said:"Abu Laila used to travel with 'Ali, and he used to wear summer clothes in winter and winter clothes in summer. We said: 'Why don't you ask him (about that)?' He said: "The Messenger of Allah sent for me and my eyes were sore, on the Day of Khaibar. I said: 'O Messenger of Allah, my eyes are sore.' He put some spittle into my eyes, then he said: 'O Allah, take heat and cold away from him.' I never felt hot or cold again after that day. He (the Prophet) said: 'I will send a man who loves Allah and His Messenger, and whom Allah and His Messenger love, and he is not one who flees from the battlefield.' The people craned their necks to see, and he sent for 'Ali and gave it (the banner) to him}}
\hadithdefcmd{ibnmajah}{118}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْوَاسِطِيُّ، حَدَّثَنَا الْمُعَلَّى بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْحَسَنُ وَالْحُسَيْنُ سَيِّدَا شَبَابِ أَهْلِ الْجَنَّةِ وَأَبُوهُمَا خَيْرٌ مِنْهُمَا ‏"‏ ‏.‏\hadithno{118}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'Hasan and Husain will be the leaders of the youth of Paradise, and their father is better than them}}
\hadithdefcmd{ibnmajah}{119}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَإِسْمَاعِيلُ بْنُ مُوسَى، قَالُوا حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ حُبْشِيِّ بْنِ جُنَادَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ عَلِيٌّ مِنِّي وَأَنَا مِنْهُ وَلاَ يُؤَدِّي عَنِّي إِلاَّ عَلِيٌّ ‏"‏ ‏.‏\hadithno{119}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hubshi bin Junadah said:"I heard the Messenger of Allah say: ''Ali is part of me and I am part of him, and no one will represent me except 'Ali}}
\hadithdefcmd{ibnmajah}{120}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ الرَّازِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا الْعَلاَءُ بْنُ صَالِحٍ، عَنِ الْمِنْهَالِ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ عَلِيٌّ أَنَا عَبْدُ اللَّهِ، وَأَخُو، رَسُولِهِ ـ صلى الله عليه وسلم ـ وَأَنَا الصِّدِّيقُ الأَكْبَرُ، لاَ يَقُولُهَا بَعْدِي إِلاَّ كَذَّابٌ صَلَّيْتُ قَبْلَ النَّاسِ لِسَبْعِ سِنِينَ ‏.‏\hadithno{120}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Batil; Shuaib Al Arnaut: Batil; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abbad bin 'Abdullah said:"'Ali said: 'I am the slave of Allah and the brother of His Messenger. I am the greatest teller of the truth (Siddiq Akbar), and no one will say this after me except a liar. I prayed seven years before the people}}
\hadithdefcmd{ibnmajah}{121}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا مُوسَى بْنُ مُسْلِمٍ، عَنِ ابْنِ سَابِطٍ، - وَهُوَ عَبْدُ الرَّحْمَنِ - عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ قَدِمَ مُعَاوِيَةُ فِي بَعْضِ حَجَّاتِهِ فَدَخَلَ عَلَيْهِ سَعْدٌ فَذَكَرُوا عَلِيًّا فَنَالَ مِنْهُ فَغَضِبَ سَعْدٌ وَقَالَ تَقُولُ هَذَا لِرَجُلٍ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ مَنْ كُنْتُ مَوْلاَهُ فَعَلِيٌّ مَوْلاَهُ ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ أَنْتَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى إِلاَّ أَنَّهُ لاَ نَبِيَّ بَعْدِي ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ لأُعْطِيَنَّ الرَّايَةَ الْيَوْمَ رَجُلاً يُحِبُّ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏\hadithno{121}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa`d bin Waqqas said:"Mu`awiyah came on one of his pilgrimages and Sa`d entered upon him. They mentioned `Ali, and Mu`awiyah criticized him. Sa`d became angry and said: 'Are you saying this of a man of whom I heard the Messenger of Allah (ﷺ) say: "If I am a person's close friend, `Ali is also his close friend." And I heard him say: "You are to me like Harun was to Musa, except that there will be no Prophet after me." And I heard him say: "I will give the banner today to a man who loves Allah and His Messenger}}
\hadithdefcmd{ibnmajah}{122}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ قُرَيْظَةَ ‏"‏ مَنْ يَأْتِينَا بِخَبَرِ الْقَوْمِ ‏"‏ ‏.‏ فَقَالَ الزُّبَيْرُ أَنَا ‏.‏ فَقَالَ ‏"‏ مَنْ يَأْتِينَا بِخَبَرِ الْقَوْمِ ‏"‏ ‏.‏ قَالَ الزُّبَيْرُ أَنَا ‏.‏ ثَلاَثًا فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ لِكُلِّ نَبِيٍّ حَوَارِيٌّ وَإِنَّ حَوَارِيَّ الزُّبَيْرُ ‏"‏ ‏.‏\hadithno{122}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah said on the Day of Quraizah: 'Who will bring us news of the people?' Zubair said: 'I will.' The Prophet said: 'Who will bring us news of the people?' Zubair said: 'I will,' three times. Every Prophet has a Hawari (sincere supporter or disciple) and my Hawari is Zubair}}
\hadithdefcmd{ibnmajah}{123}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنِ الزُّبَيْرِ، قَالَ لَقَدْ جَمَعَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَبَوَيْهِ يَوْمَ أُحُدٍ ‏.‏\hadithno{123}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Zubair said:"The Messenger of Allah named his parents together for me on the Day of Uhud}}
\hadithdefcmd{ibnmajah}{124}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَهَدِيَّةُ بْنُ عَبْدِ الْوَهَّابِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ قَالَتْ لِي عَائِشَةُ يَا عُرْوَةُ كَانَ أَبَوَاكَ مِنَ الَّذِينَ اسْتَجَابُوا لِلَّهِ وَالرَّسُولِ مِنْ بَعْدِ مَا أَصَابَهُمُ الْقَرْحُ أَبُو بَكْرٍ وَالزُّبَيْرُ ‏.‏\hadithno{124}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Hisham bin 'Urwah that his father said:''Aishah said to me: 'O 'Urwah, your two fathers were of those who answered (the Call of) Allah and the Messenger (Muhammed) after being wounded," (they were) Abu Bakr and Zubair}}
\hadithdefcmd{ibnmajah}{125}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ الأَوْدِيُّ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الصَّلْتُ الأَزْدِيُّ، حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ جَابِرٍ، أَنَّ طَلْحَةَ، مَرَّ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ شَهِيدٌ يَمْشِي عَلَى وَجْهِ الأَرْضِ ‏"‏ ‏.‏\hadithno{125}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that:Talhah passed by the Prophet and he said: "A martyr walking upon the face of the earth}}
\hadithdefcmd{ibnmajah}{126}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، حَدَّثَنِي إِسْحَاقُ بْنُ يَحْيَى بْنِ طَلْحَةَ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، قَالَ نَظَرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِلَى طَلْحَةَ فَقَالَ ‏ "‏ هَذَا مِمَّنْ قَضَى نَحْبَهُ ‏"‏ ‏.‏\hadithno{126}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mu'awiyah bin Abu Sufyan said:"The Prophet looked at Talhah and said: 'This is one of those who fulfilled their covenant}}
\hadithdefcmd{ibnmajah}{127}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا إِسْحَاقُ، عَنْ مُوسَى بْنِ طَلْحَةَ، قَالَ كُنَّا عِنْدَ مُعَاوِيَةَ فَقَالَ أَشْهَدُ لَسَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ طَلْحَةُ مِمَّنْ قَضَى نَحْبَهُ ‏"‏ ‏.‏\hadithno{127}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Musa bin Talhah said:We were with Mu'awiyah and he said: "I heard the Messenger of Allah say: 'Talhah is one of those who fulfilled their covenant}}
\hadithdefcmd{ibnmajah}{128}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ رَأَيْتُ يَدَ طَلْحَةَ شَلاَّءَ وَقَى بِهَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ أُحُدٍ ‏.‏\hadithno{128}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qais said:"I saw the paralyzed hand of Talhah, with which he had defended the Messenger of Allah on the Day of Uhud}}
\hadithdefcmd{ibnmajah}{129}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ عَلِيٍّ، قَالَ مَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ جَمَعَ أَبَوَيْهِ لأَحَدٍ غَيْرِ سَعْدِ بْنِ مَالِكٍ فَإِنَّهُ قَالَ لَهُ يَوْمَ أُحُدٍ ‏ "‏ ارْمِ سَعْدُ فِدَاكَ أَبِي وَأُمِّي ‏"‏ ‏.‏\hadithno{129}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Ali said:"I never saw the Messenger of Allah mention his parents together for anyone except Sa'd bin Malik. He said to him on the Day of Uhud: 'Shoot, Sa'd! May my father and mother be sacrificed for you}}
\hadithdefcmd{ibnmajah}{130}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، ح وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، وَإِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ سَمِعْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ لَقَدْ جَمَعَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ أُحُدٍ أَبَوَيْهِ فَقَالَ ‏ "‏ ارْمِ سَعْدُ فِدَاكَ أَبِي وَأُمِّي ‏"‏ ‏.‏\hadithno{130}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Sa'eed bin Musayyab said:"I heard Sa'd bin Abu Waqqas say: 'The Messenger of Allah mentioned his parents together for me on the Day of Uhud. He said: 'Shoot, Sa'd! May my father and mother be sacrificed for you}}
\hadithdefcmd{ibnmajah}{131}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَخَالِي، يَعْلَى وَوَكِيعٌ عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ إِنِّي لأَوَّلُ الْعَرَبِ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ ‏.‏\hadithno{131}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Qais said:"I heard Sa'd bin Abu Waqqas say: 'I am the first of the Arabs to shoot an arrow in the cause of Allah}}
\hadithdefcmd{ibnmajah}{132}{حَدَّثَنَا مَسْرُوقُ بْنُ الْمَرْزُبَانِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي زَائِدَةَ، عَنْ هَاشِمِ بْنِ هَاشِمٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ قَالَ سَعْدُ بْنُ أَبِي وَقَّاصٍ مَا أَسْلَمَ أَحَدٌ فِي الْيَوْمِ الَّذِي أَسْلَمْتُ فِيهِ وَلَقَدْ مَكَثْتُ سَبْعَةَ أَيَّامٍ وَإِنِّي لَثُلُثُ الإِسْلاَمِ ‏.‏\hadithno{132}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hashim bin Hashim said:"I heard Sa'eed bin Musayyab say: 'Sa'd bin Abu Waqqas said: 'No one else became Muslim on the same day as I did; for seven days I was one-third of Islam}}
\hadithdefcmd{ibnmajah}{133}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا صَدَقَةُ بْنُ الْمُثَنَّى أَبُو الْمُثَنَّى النَّخَعِيُّ، عَنْ جَدِّهِ، رِيَاحِ بْنِ الْحَارِثِ سَمِعَ جَدَّهُ، سَعِيدَ بْنَ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَاشِرَ عَشَرَةٍ فَقَالَ ‏ "‏ أَبُو بَكْرٍ فِي الْجَنَّةِ وَعُمَرُ فِي الْجَنَّةِ وَعُثْمَانُ فِي الْجَنَّةِ وَعَلِيٌّ فِي الْجَنَّةِ وَطَلْحَةُ فِي الْجَنَّةِ وَالزُّبَيْرُ فِي الْجَنَّةِ وَسَعْدٌ فِي الْجَنَّةِ وَعَبْدُ الرَّحْمَنِ فِي الْجَنَّةِ ‏"‏ ‏.‏ فَقِيلَ لَهُ مَنِ التَّاسِعُ قَالَ أَنَا ‏.‏\hadithno{133}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sa'eed bin Zaid bin 'Amr bin Nufail said:"The Messenger of Allah was one of the Ten (given glad tidings of Paradise). He said: 'Abu Bakr will be in Paradise; 'Umar will be in Paradise; 'Uthman will be in Paradise; 'Ali will be in Paradise; Talhah will be in Paradise; Zubair will be in Paradise; Sa'd will be in Paradise; 'Abdur-Rahman will be in Paradise." He was asked: 'Who will be the ninth?' He said: 'I will}}
\hadithdefcmd{ibnmajah}{134}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ حُصَيْنٍ، عَنْ هِلاَلِ بْنِ يَسَافٍ، عَنْ عَبْدِ اللَّهِ بْنِ ظَالِمٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، قَالَ أَشْهَدُ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنِّي سَمِعْتُهُ يَقُولُ ‏ "‏ اثْبُتْ حِرَاءُ فَمَا عَلَيْكَ إِلاَّ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدٌ ‏"‏ ‏.‏ وَعَدَّهُمْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَطَلْحَةُ وَالزُّبَيْرُ وَسَعْدٌ وَابْنُ عَوْفٍ وَسَعِيدُ بْنُ زَيْدٍ ‏.‏\hadithno{134}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Sa'eed bin Zaid:'I bear witness that I heard the Messenger of Allah say: 'Stand firm, O (mountain of) Hira', for there is no one upon you but a Prophet, a Siddiq or a martyr.' " Then he listed them as follows: "The Messenger of Allah, Abu Bakr, 'Umar, 'Uthman, 'Ali, Talhah, Zubair, Sa'd, Ibn 'Awf and Sa'eed bin Zaid}}
\hadithdefcmd{ibnmajah}{135}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، جَمِيعًا عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لأَهْلِ نَجْرَانَ ‏ "‏ سَأَبْعَثُ مَعَكُمْ رَجُلاً أَمِينًا حَقَّ أَمِينٍ ‏"‏ ‏.‏ قَالَ فَتَشَوَّفَ لَهَا النَّاسُ فَبَعَثَ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ ‏.‏\hadithno{135}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Hudhaifah that:The Messenger of Allah said to the people of Najran: "I will send you a trustworthy man with you, who is indeed trustworthy." The people craned their necks to see, and he sent Abu 'Ubaidah bin Jarrah}}
\hadithdefcmd{ibnmajah}{136}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لأَبِي عُبَيْدَةَ بْنِ الْجَرَّاحِ ‏ "‏ هَذَا أَمِينُ هَذِهِ الأُمَّةِ ‏"‏ ‏.‏\hadithno{136}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah that:The Messenger of Allah said to Abu 'Ubaidah bin Jarrah: "This is the trustworthy man of this Ummah}}
\hadithdefcmd{ibnmajah}{137}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْ كُنْتُ مُسْتَخْلِفًا أَحَدًا عَنْ غَيْرِ مَشُورَةٍ لاَسْتَخْلَفْتُ ابْنَ أُمِّ عَبْدٍ ‏"‏ ‏.‏\hadithno{137}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah said: 'If I were to appoint anyone as my successor without consulting anyone, I would have appointed Ibn Umm 'Abd}}
\hadithdefcmd{ibnmajah}{138}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، ‏.‏ أَنَّ أَبَا بَكْرٍ، وَعُمَرَ، بَشَّرَاهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَحَبَّ أَنْ يَقْرَأَ الْقُرْآنَ غَضًّا كَمَا أُنْزِلَ فَلْيَقْرَأْهُ عَلَى قِرَاءَةِ ابْنِ أُمِّ عَبْدٍ ‏"‏ ‏.‏\hadithno{138}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Mas'ud that:Abu Bakr and 'Umar gave him the glad tidings that the Messenger of Allah had said: "Whoever would like to recite the Qur'an as fresh as when it was revealed, let him recite it like Ibn Umm 'Abd}}
\hadithdefcmd{ibnmajah}{139}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ سُوَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذْنُكَ عَلَىَّ أَنْ تَرْفَعَ الْحِجَابَ وَأَنْ تَسْمَعَ سِوَادِي حَتَّى أَنْهَاكَ ‏"‏ ‏.‏\hadithno{139}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah said to me: 'The sign that you have been permitted to come in is that you raise the curtain and that you hear me speaking quietly, until I forbid you.' (i.e. unless I forbid you)}}
\hadithdefcmd{ibnmajah}{140}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سَبْرَةَ النَّخَعِيِّ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، قَالَ كُنَّا نَلْقَى النَّفَرَ مِنْ قُرَيْشٍ وَهُمْ يَتَحَدَّثُونَ فَيَقْطَعُونَ حَدِيثَهُمْ فَذَكَرْنَا ذَلِكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ مَا بَالُ أَقْوَامٍ يَتَحَدَّثُونَ فَإِذَا رَأَوُا الرَّجُلَ مِنْ أَهْلِ بَيْتِي قَطَعُوا حَدِيثَهُمْ وَاللَّهِ لاَ يَدْخُلُ قَلْبَ رَجُلٍ الإِيمَانُ حَتَّى يُحِبَّهُمْ لِلَّهِ وَلِقَرَابَتِهِمْ مِنِّي ‏"‏ ‏.‏\hadithno{140}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abbas bin 'Abdul-Muttalib said:"We used to come across groups of Quraish who would be talking, but they would stop talking (when we approached). We mentioned that to the Messenger of Allah and he said: 'What is the matter with people who talk, then when they see a man from my family they stop talking? By Allah, faith will not enter a person's heart until he loves them for the sake of Allah and because of their closeness to me}}
\hadithdefcmd{ibnmajah}{141}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ الضَّحَّاكِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ صَفْوَانَ بْنِ عَمْرٍو، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ الْحَضْرَمِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ اتَّخَذَنِي خَلِيلاً كَمَا اتَّخَذَ إِبْرَاهِيمَ خَلِيلاً فَمَنْزِلِي وَمَنْزِلُ إِبْرَاهِيمَ فِي الْجَنَّةِ يَوْمَ الْقِيَامَةِ تِجَاهَيْنِ وَالْعَبَّاسُ بَيْنَنَا مُؤْمِنٌ بَيْنَ خَلِيلَيْنِ ‏"‏ ‏.‏\hadithno{141}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah said: 'Allah has taken me as a close friend (Khalil) as He took Ibrahim as a close friend. So my house and the house of Ibrahim will be opposite to one another on the Day of Resurrection, and 'Abbas will be in between us, a believer between two close friends.'" (Maudu)}}
\hadithdefcmd{ibnmajah}{142}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ لِلْحَسَنِ ‏ "‏ اللَّهُمَّ إِنِّي أُحِبُّهُ فَأَحِبَّهُ وَأَحِبَّ مَنْ يُحِبُّهُ ‏"‏ ‏.‏ قَالَ وَضَمَّهُ إِلَى صَدْرِهِ ‏.‏\hadithno{142}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said to Hasan: "O Allah, I love him, so love him and love those who love him." He said: "And he hugged him to his chest}}
\hadithdefcmd{ibnmajah}{143}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ دَاوُدَ بْنِ أَبِي عَوْفٍ أَبِي الْجَحَّافِ، - وَكَانَ مَرْضِيًّا - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَحَبَّ الْحَسَنَ وَالْحُسَيْنَ فَقَدْ أَحَبَّنِي وَمَنْ أَبْغَضَهُمَا فَقَدْ أَبْغَضَنِي ‏"‏ ‏.‏\hadithno{143}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever loves Hasan and Husain, loves me; and whoever hates them, hates me}}
\hadithdefcmd{ibnmajah}{144}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ أَبِي رَاشِدٍ، أَنَّ يَعْلَى بْنَ مُرَّةَ، حَدَّثَهُمْ أَنَّهُمْ، خَرَجُوا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ إِلَى طَعَامٍ دُعُوا لَهُ فَإِذَا حُسَيْنٌ يَلْعَبُ فِي السِّكَّةِ قَالَ فَتَقَدَّمَ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَمَامَ الْقَوْمِ وَبَسَطَ يَدَيْهِ فَجَعَلَ الْغُلاَمُ يَفِرُّ هَا هُنَا وَهَا هُنَا وَيُضَاحِكُهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ حَتَّى أَخَذَهُ فَجَعَلَ إِحْدَى يَدَيْهِ تَحْتَ ذَقَنِهِ وَالأُخْرَى فِي فَأْسِ رَأْسِهِ فَقَبَّلَهُ وَقَالَ ‏ "‏ حُسَيْنٌ مِنِّي وَأَنَا مِنْ حُسَيْنٍ أَحَبَّ اللَّهُ مَنْ أَحَبَّ حُسَيْنًا حُسَيْنٌ سِبْطٌ مِنَ الأَسْبَاطِ ‏"‏ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ حَدَّثَنَا وَكِيعٌ عَنْ سُفْيَانَ مِثْلَهُ ‏.‏\hadithno{144}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sa'eed bin Abu Rashid that Ya'la bin Murrah told them that:They had gone out with the Prophet to a meal to which they had been invited, and Husain was there playing in the street. The Prophet came in front of the people and stretched out his hands, and the child started to run here and there. The Prophet made him laugh until he caught him, then he put one hand under his chin and the other on his head and kissed him, and said, "Husain is part of me and I am part of him. May Allah love those who love Husain. Husain is a tribe among tribes." (Hasan)(Another chain with similar meaning)}}
\hadithdefcmd{ibnmajah}{145}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَعَلِيُّ بْنُ الْمُنْذِرِ، قَالاَ حَدَّثَنَا أَبُو غَسَّانَ، حَدَّثَنَا أَسْبَاطُ بْنُ نَصْرٍ، عَنِ السُّدِّيِّ، عَنْ صُبَيْحٍ، مَوْلَى أُمِّ سَلَمَةَ عَنْ زَيْدِ بْنِ أَرْقَمٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِعَلِيٍّ وَفَاطِمَةَ وَالْحَسَنِ وَالْحُسَيْنِ ‏ "‏ أَنَا سِلْمٌ لِمَنْ سَالَمْتُمْ وَحَرْبٌ لِمَنْ حَارَبْتُمْ ‏"‏ ‏.‏\hadithno{145}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Zaid bin Arqam said:"The Messenger of Allah said to 'Ali, Fatimah, Hasan and Husain: 'I am peace for those with whom you make peace, and I am war for those with whom you make war}}
\hadithdefcmd{ibnmajah}{146}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ هَانِئِ بْنِ هَانِئٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كُنْتُ جَالِسًا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَاسْتَأْذَنَ عَمَّارُ بْنُ يَاسِرٍ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ ائْذَنُوا لَهُ مَرْحَبًا بِالطَّيِّبِ الْمُطَيَّبِ ‏"‏ ‏.‏\hadithno{146}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali bin Abu Talib said:"I was sitting with the Prophet, and 'Ammar bin Yasir asked permission to enter. The Prophet said: 'Let him in, welcome to the good and the purified}}
\hadithdefcmd{ibnmajah}{147}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَثَّامُ بْنُ عَلِيٍّ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ هَانِئِ بْنِ هَانِئٍ، قَالَ دَخَلَ عَمَّارٌ عَلَى عَلِيٍّ فَقَالَ مَرْحَبًا بِالطَّيِّبِ الْمُطَيَّبِ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مُلِئَ عَمَّارٌ إِيمَانًا إِلَى مُشَاشِهِ ‏"‏ ‏.‏\hadithno{147}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Hani bin Hani said that:'Ammar entered upon 'Ali and he said: "Welcome to the good and the purified. I heard the Messenger of Allah say: 'Ammar's heart overflows with faith (Literally, up to the top of his bones)}}
\hadithdefcmd{ibnmajah}{148}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ جَمِيعًا حَدَّثَنَا وَكِيعٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ سِيَاهٍ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عَمَّارٌ مَا عُرِضَ عَلَيْهِ أَمْرَانِ إِلاَّ اخْتَارَ الأَرْشَدَ مِنْهُمَا ‏"‏ ‏.‏\hadithno{148}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:'The Messenger of Allah said: ''Ammar- no two things were shown to him but he chose the better of the two}}
\hadithdefcmd{ibnmajah}{149}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي رَبِيعَةَ الإِيَادِيِّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي بِحُبِّ أَرْبَعَةٍ وَأَخْبَرَنِي أَنَّهُ يُحِبُّهُمْ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ مَنْ هُمْ قَالَ ‏"‏ عَلِيٌّ مِنْهُمْ ‏"‏ ‏.‏ يَقُولُ ذَلِكَ ثَلاَثًا ‏"‏ وَأَبُو ذَرٍّ وَسَلْمَانُ وَالْمِقْدَادُ ‏"‏ ‏.‏\hadithno{149}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Buraidah narrated that his father said:"The Messenger of Allah said: 'Allah has commanded me to love four people, and He told me that He also loves them.' He was asked: 'O Messenger of Allah, who are they?' He said: ''Ali is one of them,' and he said that three times, 'and Abu Dharr, Salman and Miqdad}}
\hadithdefcmd{ibnmajah}{150}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زَائِدَةُ بْنُ قُدَامَةَ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ أَوَّلَ مَنْ أَظْهَرَ إِسْلاَمَهُ سَبْعَةٌ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبُو بَكْرٍ وَعَمَّارٌ وَأُمُّهُ سُمَيَّةُ وَصُهَيْبٌ وَبِلاَلٌ وَالْمِقْدَادُ فَأَمَّا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَمَنَعَهُ اللَّهُ بِعَمِّهِ أَبِي طَالِبٍ وَأَمَّا أَبُو بَكْرٍ فَمَنَعَهُ اللَّهُ بِقَوْمِهِ وَأَمَّا سَائِرُهُمْ فَأَخَذَهُمُ الْمُشْرِكُونَ وَأَلْبَسُوهُمْ أَدْرَاعَ الْحَدِيدِ وَصَهَرُوهُمْ فِي الشَّمْسِ فَمَا مِنْهُمْ مِنْ أَحَدٍ إِلاَّ وَقَدْ وَاتَاهُمْ عَلَى مَا أَرَادُوا إِلاَّ بِلاَلاً فَإِنَّهُ قَدْ هَانَتْ عَلَيْهِ نَفْسُهُ فِي اللَّهِ وَهَانَ عَلَى قَوْمِهِ فَأَخَذُوهُ فَأَعْطَوْهُ الْوِلْدَانَ فَجَعَلُوا يَطُوفُونَ بِهِ فِي شِعَابِ مَكَّةَ وَهُوَ يَقُولُ أَحَدٌ أَحَدٌ ‏.‏\hadithno{150}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"The first people to declare their Islam publicly were seven: The Messenger of Allah, Abu Bakr, 'Ammar and his mother Sumayyah, Suhaib, Bilal and Miqdad. With regard to the Messenger of Allah, Allah protected him through his paternal uncle Abu Talib. With regard to Abu Bakr, Allah protected him through his people. As for the rest, the idolators seized them and made them wear coats of chain-mail and exposed them to the intense heat of the sun. There was none of them who did not do what they wanted them to do, except for Bilal. He did not care what happened to him for the sake of Allah, and his people did not care what happened to him. Then they gave him to the children who took him around in the streets of Makkah while he was saying, 'Ahad, Ahad (One, One)}}
\hadithdefcmd{ibnmajah}{151}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَقَدْ أُوذِيتُ فِي اللَّهِ وَمَا يُؤْذَى أَحَدٌ وَلَقَدْ أُخِفْتُ فِي اللَّهِ وَمَا يُخَافُ أَحَدٌ وَلَقَدْ أَتَتْ عَلَىَّ ثَالِثَةٌ وَمَا لِيَ وَلِبِلاَلٍ طَعَامٌ يَأْكُلُهُ ذُو كَبِدٍ إِلاَّ مَا وَارَى إِبِطُ بِلاَلٍ ‏"‏ ‏.‏\hadithno{151}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'I have been tortured for the sake of Allah as no one else has, and I have suffered fear for the sake of Allah as no one else has. I have spent three days when Bilal and I had no food that any living being could eat but that which could be concealed in the armpit of Bilal}}
\hadithdefcmd{ibnmajah}{152}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُمَرَ بْنِ حَمْزَةَ، عَنْ سَالِمٍ، أَنَّ شَاعِرًا، مَدَحَ بِلاَلَ بْنَ عَبْدِ اللَّهِ فَقَالَ بِلاَلُ بْنُ عَبْدِ اللَّهِ خَيْرُ بِلاَلٍ ‏.‏ فَقَالَ ابْنُ عُمَرَ كَذَبْتَ لاَ بَلْ بِلاَلُ رَسُولِ اللَّهِ خَيْرُ بِلاَلٍ ‏.‏\hadithno{152}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Salim that:A poet praised Bilal bin 'Abdullah and said: "Bilal bin 'Abdullah is better than any other Bilal." Ibn 'Umar said: 'You are lying. The Bilal of the Messenger of Allah is better than any other Bilal}}
\hadithdefcmd{ibnmajah}{153}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي لَيْلَى الْكِنْدِيِّ، قَالَ جَاءَ خَبَّابٌ إِلَى عُمَرَ فَقَالَ ادْنُ فَمَا أَحَدٌ أَحَقَّ بِهَذَا الْمَجْلِسِ مِنْكَ إِلاَّ عَمَّارٌ ‏.‏ فَجَعَلَ خَبَّابٌ يُرِيهِ آثَارًا بِظَهْرِهِ مِمَّا عَذَّبَهُ الْمُشْرِكُونَ ‏.‏\hadithno{153}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Laila Al-Kindi said:"Khabbab came to `Umar and said: 'Come close, for no one deserves this meeting more than you, except `Ammar.' Then Khabbab started to show him the marks on his back where the idolaters had tortured him}}
\hadithdefcmd{ibnmajah}{154}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَرْحَمُ أُمَّتِي بِأُمَّتِي أَبُو بَكْرٍ وَأَشَدُّهُمْ فِي دِينِ اللَّهِ عُمَرُ وَأَصْدَقُهُمْ حَيَاءً عُثْمَانُ وَأَقْضَاهُمْ عَلِيُّ بْنُ أَبِي طَالِبٍ وَأَقْرَؤُهُمْ لِكِتَابِ اللَّهِ أُبَىُّ بْنُ كَعْبٍ وَأَعْلَمُهُمْ بِالْحَلاَلِ وَالْحَرَامِ مُعَاذُ بْنُ جَبَلٍ وَأَفْرَضُهُمْ زَيْدُ بْنُ ثَابِتٍ أَلاَ وَإِنَّ لِكُلِّ أُمَّةٍ أَمِينًا وَأَمِينُ هَذِهِ الأُمَّةِ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ ‏"‏ ‏.‏\hadithno{154}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Anas bin Malik that:The Messenger of Allah said: The most merciful of my Ummah towards my Ummah is Abu Bakr; the one who adheres most sternly to the religion of Allah is 'Umar; the most sincere of them in shyness and modesty is 'Uthman; the best judge is 'Ali bin Abu Talib; the best in reciting the Book of Allah is Ubayy bin Ka'b; the most knowledgeable of what is lawful and unlawful is Mu'adh bin Jabal; and the most knowledgeable of the rules of inheritance (Fara'id) is Zaid bin Thabit. And every nation has a trustworthy guardian, and the trustworthy guardian of this Ummah is Abu 'Ubaidah bin Jarrah}}
\hadithdefcmd{ibnmajah}{155}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ مثله عند إبن قدامة. غير أنه يقول في حق زيد (وَأَعْلَمُهُمْ بِالْفَرَائِضِ)\hadithno{155}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Another chain with similar wording (as no. 154) but he said that:Zaid was: "The most knowledgeable of them concerning the rules of inheritance}}
\hadithdefcmd{ibnmajah}{156}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ عُثْمَانَ بْنِ عُمَيْرٍ، عَنْ أَبِي حَرْبِ بْنِ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا أَقَلَّتِ الْغَبْرَاءُ وَلاَ أَظَلَّتِ الْخَضْرَاءُ مِنْ رَجُلٍ أَصْدَقَ لَهْجَةً مِنْ أَبِي ذَرٍّ ‏"‏ ‏.‏\hadithno{156}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"I heard the Messenger of Allah say: 'There is no one on earth, or under the sky, who speaks more truthfully than Abu Dharr}}
\hadithdefcmd{ibnmajah}{157}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أُهْدِيَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ سَرَقَةٌ مِنْ حَرِيرٍ فَجَعَلَ الْقَوْمُ يَتَدَاوَلُونَهَا بَيْنَهُمْ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَتَعْجَبُونَ مِنْ هَذَا ‏"‏ ‏.‏ فَقَالُوا لَهُ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَمَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ خَيْرٌ مِنْ هَذَا ‏"‏ ‏.‏\hadithno{157}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Bara' bin 'Azib said:"The Messenger of Allah was given a gift of a length of silk fabric. The people started passing it around to one another. The Messenger of Allah said: 'Are you admiring this?' They said: 'Yes, O Messenger of Allah.' He said: 'By the One in Whose Hand is my soul! The handkerchief of Sa'd bin Mu'adh in Paradise is better than this}}
\hadithdefcmd{ibnmajah}{158}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اهْتَزَّ عَرْشُ اللَّهِ عَزَّ وَجَلَّ لِمَوْتِ سَعْدِ بْنِ مُعَاذٍ ‏"‏ ‏.‏\hadithno{158}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah said: 'The Throne of The Most Merciful trembled upon the death of Sa'd bin Mu'adh}}
\hadithdefcmd{ibnmajah}{159}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ، قَالَ مَا حَجَبَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مُنْذُ أَسْلَمْتُ وَلاَ رَآنِي إِلاَّ تَبَسَّمَ فِي وَجْهِي وَلَقَدْ شَكَوْتُ إِلَيْهِ أَنِّي لاَ أَثْبُتُ عَلَى الْخَيْلِ فَضَرَبَ بِيَدِهِ فِي صَدْرِي فَقَالَ ‏ "‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏ ‏.‏\hadithno{159}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Jarir bin 'Abdullah Al-Bajali said:"The Messenger of Allah never refused to see me from the time I became Muslim, and whenever he saw me he would smile at me. I complained to him that I could not sit firmly on a horse, so he struck me on the chest with his hand and said: 'O Allah, make him firm and cause him to guide others and be rightly-guided}}
\hadithdefcmd{ibnmajah}{160}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ جَاءَ جِبْرِيلُ - أَوْ مَلَكٌ - إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ مَا تَعُدُّونَ مَنْ شَهِدَ بَدْرًا فِيكُمْ قَالُوا خِيَارَنَا ‏.‏ قَالَ كَذَلِكَ هُمْ عِنْدَنَا خِيَارُ الْمَلاَئِكَةِ ‏"‏ ‏.‏\hadithno{160}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Rafi' bin Khadij said:"Jibril or an angel came to the Prophet and said: 'How do you regard those among you who were present at Badr?' He said: 'They are the best among us.' He said: 'We think the same (of the angels who were present at Badr), they are the best of the angels}}
\hadithdefcmd{ibnmajah}{161}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، جَمِيعًا عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَسُبُّوا أَصْحَابِي فَوَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَنَّ أَحَدَكُمْ أَنْفَقَ مِثْلَ أُحُدٍ ذَهَبًا مَا أَدْرَكَ مُدَّ أَحَدِهِمْ وَلاَ نَصِيفَهُ ‏"‏ ‏.‏\hadithno{161}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Do not revile my Companions, for by The One in Whose Hand is my soul! If any one of you were to spend the equivalent of Mount Uhud in gold, it would not equal a Mudd spent by anyone of them, nor even half a Mudd}}
\hadithdefcmd{ibnmajah}{162}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ نُسَيْرِ بْنِ ذُعْلُوقٍ، قَالَ كَانَ ابْنُ عُمَرَ يَقُولُ لاَ تَسُبُّوا أَصْحَابَ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ فَلَمَقَامُ أَحَدِهِمْ سَاعَةً خَيْرٌ مِنْ عَمَلِ أَحَدِكُمْ عُمْرَهُ ‏.‏\hadithno{162}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Nusair bin Dhu'luq said:"Ibn 'Umar used to say: 'Do not revile the Companions of Muhammed, for the stay of anyone of them for a brief period (with the Prophet) is better than all the good deeds that anyone of you does in his lifetime}}
\hadithdefcmd{ibnmajah}{163}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَمْرُو بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَحَبَّ الأَنْصَارَ أَحَبَّهُ اللَّهُ وَمَنْ أَبْغَضَ الأَنْصَارَ أَبْغَضَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ شُعْبَةُ قُلْتُ لِعَدِيٍّ أَسَمِعْتَهُ مِنَ الْبَرَاءِ بْنِ عَازِبٍ قَالَ إِيَّاىَ حَدَّثَ ‏.‏\hadithno{163}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Bara' bin 'Azib said:"The Messenger of Allah said: 'Whoever loves the Ansar, Allah will love him, and whoever hates the Ansar, Allah will hate him.' " (One of the narrators) Shu'bah said: "I said to 'Adi: 'Did you hear that from Bara' bin 'Azib?' He said: 'It was to me that he narrated it}}
\hadithdefcmd{ibnmajah}{164}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ الْمُهَيْمِنِ بْنِ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الأَنْصَارُ شِعَارٌ وَالنَّاسُ دِثَارٌ وَلَوْ أَنَّ النَّاسَ اسْتَقْبَلُوا وَادِيًا - أَوْ شِعْبًا - وَاسْتَقْبَلَتِ الأَنْصَارُ وَادِيًا لَسَلَكْتُ وَادِيَ الأَنْصَارِ وَلَوْلاَ الْهِجْرَةُ لَكُنْتُ امْرَأً مِنَ الأَنْصَارِ ‏"‏ ‏.‏\hadithno{164}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdul-Muhaimin bin 'Abbas bin Sahl bin Sa'd from his father, from his grandfather, that:The Messenger of Allah said: "The Ansar are an inner garment and the people are an outer garment. If the people were to head towards one valley or a narrow mountain pass and the Ansar towards another, I would travel to the valley of the Ansar, and were it not for the Hijrah, I would have been a man from among the Ansar}}
\hadithdefcmd{ibnmajah}{165}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ رَحِمَ اللَّهُ الأَنْصَارَ وَأَبْنَاءَ الأَنْصَارِ وَأَبْنَاءَ أَبْنَاءِ الأَنْصَارِ ‏"‏ ‏.‏\hadithno{165}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin 'Abdullah bin 'Amr bin 'Awf narrated from his father:That his grandfather said: "The Messenger of Allah said: 'May Allah have mercy on the Ansar, and the children of the Ansar, and the grandchildren of the Ansar}}
\hadithdefcmd{ibnmajah}{166}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ضَمَّنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَيْهِ وَقَالَ ‏ "‏ اللَّهُمَّ عَلِّمْهُ الْحِكْمَةَ وَتَأْوِيلَ الْكِتَابِ ‏"‏ ‏.‏\hadithno{166}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah embraced me and said: 'O Allah, teach him wisdom and the (correct) interpretation of the Book}}
\hadithdefcmd{ibnmajah}{167}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبِيدَةَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ وَذَكَرَ الْخَوَارِجَ فَقَالَ فِيهِمْ رَجُلٌ مُخْدَجُ الْيَدِ أَوْ مُودَنُ الْيَدِ أَوْ مُثْدَنُ الْيَدِ وَلَوْلاَ أَنْ تَبْطَرُوا لَحَدَّثْتُكُمْ بِمَا وَعَدَ اللَّهُ الَّذِينَ يَقْتُلُونَهُمْ عَلَى لِسَانِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ ‏.‏ قُلْتُ أَنْتَ سَمِعْتَهُ مِنْ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ قَالَ إِي وَرَبِّ الْكَعْبَةِ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{167}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ubaidah narrated from 'Ali bin Abu Talib,:That he mentioned the Khawarij, and said: "Among them there will be a man with a defective hand, or a short hand, or small hand. If you were to exercise restraint (i.e., not become overjoyed), I would tell you of what Allah has promised upon the lips of Muhammed for those who kill them." I ('Ubaidah) said: "Did you hear that from Muhammed?" He said: "Yes, by the Lord of the Ka'bah!' - three times}}
\hadithdefcmd{ibnmajah}{168}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، قَالاَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَخْرُجُ فِي آخِرِ الزَّمَانِ قَوْمٌ أَحْدَاثُ الأَسْنَانِ سُفَهَاءُ الأَحْلاَمِ يَقُولُونَ مِنْ خَيْرِ قَوْلِ النَّاسِ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ فَمَنْ لَقِيَهُمْ فَلْيَقْتُلْهُمْ فَإِنَّ قَتْلَهُمْ أَجْرٌ عِنْدَ اللَّهِ لِمَنْ قَتَلَهُمْ ‏"‏ ‏.‏\hadithno{168}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"The Messenger of Allah said: 'At the end of time there will appear a people with new teeth (i.e., young in age), with foolish minds. They will speak the best words ever uttered by mankind and they will recite the Qur'an, but it will not go any deeper than their collarbones. They will pass through Islam like an arrow passes through its target. Whoever meets them, let him kill them, for killing them will bring a reward from Allah for those who kill them}}
\hadithdefcmd{ibnmajah}{169}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، قَالَ قُلْتُ لأَبِي سَعِيدٍ الْخُدْرِيِّ هَلْ سَمِعْتَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَذْكُرُ فِي الْحَرُورِيَّةِ شَيْئًا فَقَالَ سَمِعْتُهُ يَذْكُرُ قَوْمًا يَتَعَبَّدُونَ ‏"‏ يَحْقِرُ أَحَدُكُمْ صَلاَتَهُ مَعَ صَلاَتِهِمْ وَصَوْمَهُ مَعَ صَوْمِهِمْ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ‏"‏ ‏.‏ أَخَذَ سَهْمَهُ فَنَظَرَ فِي نَصْلِهِ فَلَمْ يَرَ شَيْئًا فَنَظَرَ فِي رِصَافِهِ فَلَمْ يَرَ شَيْئًا فَنَظَرَ فِي قِدْحِهِ فَلَمْ يَرَ شَيْئًا فَنَظَرَ فِي الْقُذَذِ فَتَمَارَى هَلْ يَرَى شَيْئًا أَمْ لاَ ‏"‏ ‏.‏\hadithno{169}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Salamah said:"I said to Abu Sa'eed Khudri: 'Did you hear the Messenger of Allah mention anything about the Haruriyyah (a sect of Khawarij)?' He said: 'I heard him mention a people who would appear to be devoted worshippers: "Such that anyone of you would regard his own prayer and fasting as insignificant when compared to theirs. But they will pass through Islam like an arrow passing through its target, then he (the archer) picks up his arrow and looks at its iron head but does not see anything, then he looks at the shaft and does not see anything, then he looks at the band: that which is wrapped around the iron head where it is connected to the shaft, then he looks at the feather and is not sure whether he sees anything or not}}
\hadithdefcmd{ibnmajah}{170}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ بَعْدِي مِنْ أُمَّتِي - أَوْ سَيَكُونُ بَعْدِي مِنْ أُمَّتِي - قَوْمًا يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حُلُوقَهُمْ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ثُمَّ لاَ يَعُودُونَ فِيهِ هُمْ شِرَارُ الْخَلْقِ وَالْخَلِيقَةِ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ الصَّامِتِ فَذَكَرْتُ ذَلِكَ لِرَافِعِ بْنِ عَمْرٍو أَخِي الْحَكَمِ بْنِ عَمْرٍو الْغِفَارِيِّ فَقَالَ وَأَنَا أَيْضًا قَدْ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{170}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah said: 'There will be people among my Ummah (nation) after me who will recite the Qur'an, but it will not go any deeper than their throats. They will pass through Islam like an arrow passing through its target, then they will never return to it. They are the most evil of mankind and of all creation.' " 'Abdullah bin Samit said: "I mentioned to Rafi' bin 'Amr, the brother of Hakam bin 'Amr Ghifari and he said: 'I also heard that from the Messenger of Allah}}
\hadithdefcmd{ibnmajah}{171}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيَقْرَأَنَّ الْقُرْآنَ نَاسٌ مِنْ أُمَّتِي يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ‏"‏ ‏.‏\hadithno{171}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said: 'There are those who recite the Qur'an but it does not go any deeper than their collarbones. They will pass through Islam like an arrow passing through its target}}
\hadithdefcmd{ibnmajah}{172}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِالْجِعِرَّانَةِ وَهُوَ يَقْسِمُ التِّبْرَ وَالْغَنَائِمَ وَهُوَ فِي حِجْرِ بِلاَلٍ فَقَالَ رَجُلٌ اعْدِلْ يَا مُحَمَّدُ فَإِنَّكَ لَمْ تَعْدِلْ ‏.‏ فَقَالَ ‏"‏ وَيْلَكَ وَمَنْ يَعْدِلُ بَعْدِي إِذَا لَمْ أَعْدِلْ ‏"‏ ‏.‏ فَقَالَ عُمَرُ دَعْنِي يَا رَسُولَ اللَّهِ حَتَّى أَضْرِبَ عُنُقَ هَذَا الْمُنَافِقِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ هَذَا فِي أَصْحَابٍ - أَوْ أُصَيْحَابٍ - لَهُ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ‏"‏ ‏.‏\hadithno{172}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Zubair that Jabir bin 'Abdullah said:"The Messenger of Allah was in Ji'ranah and he was distributing gold nuggets and spoils of war which were in Bilal's lap. A man said: 'Do justice, O Muhammed!' He said: 'Woe to you! Who will do justice after me if I do not do justice?' 'Umar said: 'O Messenger of Allah! Let me strike the neck of this hypocrite!' The Messenger of Allah said: 'This man has some companions who recite the Qur'an but it does not go any deeper than their collarbones. They will pass through Islam like an arrow passing through its target}}
\hadithdefcmd{ibnmajah}{173}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، عَنِ الأَعْمَشِ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْخَوَارِجُ كِلاَبُ النَّارِ ‏"‏ ‏.‏\hadithno{173}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Awfa said:"The Messenger of Allah said: 'The Khawarij are the dogs of Hell}}
\hadithdefcmd{ibnmajah}{174}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ يَنْشَأُ نَشْءٌ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ كُلَّمَا خَرَجَ قَرْنٌ قُطِعَ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ كُلَّمَا خَرَجَ قَرْنٌ قُطِعَ ‏"‏ ‏.‏ أَكْثَرَ مِنْ عِشْرِينَ مَرَّةً ‏"‏ حَتَّى يَخْرُجَ فِي عِرَاضِهِمُ الدَّجَّالُ ‏"‏ ‏.‏\hadithno{174}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah said: "There will emerge people who will recite the Qur'an but it will not go any deeper than their collarbones. Whenever a group of them appears, they should be cut off (i.e. killed)." Ibn 'Umar said: "I heard the Messenger of Allah say: 'Whenever a group of them appears, they should be killed' - (he said it) more than twenty times- 'until Dajjal emerges among them}}
\hadithdefcmd{ibnmajah}{175}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَخْرُجُ قَوْمٌ فِي آخِرِ الزَّمَانِ - أَوْ فِي هَذِهِ الأُمَّةِ - يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ - أَوْ حُلْقُومَهُمْ سِيمَاهُمُ التَّحْلِيقُ إِذَا رَأَيْتُمُوهُمْ - أَوْ إِذَا لَقِيتُمُوهُمْ - فَاقْتُلُوهُمْ ‏"‏ ‏.‏\hadithno{175}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'At the end of time or among this nation (Ummah) there will appear people who will recite the Qur'an but it will not go any deeper than their collarbones or their throats. Their distinguishing feature will be their shaved heads. If you see them, or meet them, then kill them}}
\hadithdefcmd{ibnmajah}{176}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي غَالِبٍ، عَنْ أَبِي أُمَامَةَ، يَقُولُ شَرُّ قَتْلَى قُتِلُوا تَحْتَ أَدِيمِ السَّمَاءِ وَخَيْرُ قَتْلَى مَنْ قَتَلُوا كِلاَبُ أَهْلِ النَّارِ قَدْ كَانَ هَؤُلاَءِ مُسْلِمِينَ فَصَارُوا كُفَّارًا ‏.‏ قُلْتُ يَا أَبَا أُمَامَةَ هَذَا شَىْءٌ تَقُولُهُ قَالَ بَلْ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{176}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Ghalib narrated that Abu Umamah said:"(The Khawarij) are the worst of the slain who are killed under heaven, and the best of the slain are those who were killed by them. Those (Khawarij) are the dogs of Hell. Those people were Muslims but they became disbelievers." I said: "O Abu Umamah, is that your opinion?" He said: "Rather I heard it from the Messenger of Allah}}
\hadithdefcmd{ibnmajah}{177}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَوَكِيعٌ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا خَالِي، يَعْلَى وَوَكِيعٌ وَأَبُو مُعَاوِيَةَ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا جُلُوسًا عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَنَظَرَ إِلَى الْقَمَرِ لَيْلَةَ الْبَدْرِ فَقَالَ ‏"‏ إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ كَمَا تَرَوْنَ هَذَا الْقَمَرَ لاَ تَضَامُّونَ فِي رُؤْيَتِهِ فَإِنِ اسْتَطَعْتُمْ أَنْ لاَ تُغْلَبُوا عَلَى صَلاَةٍ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا فَافْعَلُوا ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{وَسَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ الْغُرُوبِ\}‏ ‏.‏\hadithno{177}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Jarir bin 'Abdullah said:"We were sitting with the Messenger of Allah. He looked at the moon, which was full, and said, 'Indeed, you will see your Lord as you see this moon. You will not feel the slightest inconvenience and overcrowding in seeing Him. If you have the power not to be overcome and to say this prayer before the sun rises and before it sets, then do that.' Then he recited: "And glorify the praises of your Lord, before the rising of the sun and before (its) setting}}
\hadithdefcmd{ibnmajah}{178}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يَحْيَى بْنُ عِيسَى الرَّمْلِيُّ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ تَضَامُّونَ فِي رُؤْيَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَكَذَلِكَ لاَ تَضَامُّونَ فِي رُؤْيَةِ رَبِّكُمْ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{178}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Do you crowd one another in order to see the moon on the night when it is full?' They said: 'No.' He said: 'And you will not crowd one another in order to see your Lord on the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{179}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي سَعِيدٍ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ أَنَرَى رَبَّنَا قَالَ ‏"‏ تَضَامُّونَ فِي رُؤْيَةِ الشَّمْسِ فِي الظَّهِيرَةِ فِي غَيْرِ سَحَابٍ ‏"‏ ‏.‏ قُلْنَا لاَ ‏.‏ قَالَ ‏"‏ فَتَضَارُّونَ فِي رُؤْيَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ فِي غَيْرِ سَحَابٍ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ إِنَّكُمْ لاَ تَضَارُّونَ فِي رُؤْيَتِهِ إِلاَّ كَمَا تَضَارُّونَ فِي رُؤْيَتِهِمَا ‏"‏ ‏.‏\hadithno{179}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed said:"We said: 'O Messenger of Allah! Will we see our Lord?' He said: 'Do you crowd one another to see the sun at mid-day when there are no clouds?' We said: 'No.' He said: 'Do you crowd one another to see the moon on the night when it is full and there are no clouds?' We said: 'No.' He said: 'You will not crowd one another to see Him, just as you do not crowd to see these two things}}
\hadithdefcmd{ibnmajah}{180}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ وَكِيعِ بْنِ حُدُسٍ، عَنْ عَمِّهِ أَبِي رَزِينٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَكُلُّنَا يَرَى اللَّهَ يَوْمَ الْقِيَامَةِ وَمَا آيَةُ ذَلِكَ فِي خَلْقِهِ قَالَ ‏"‏ يَا أَبَا رَزِينٍ أَلَيْسَ كُلُّكُمْ يَرَى الْقَمَرَ مُخْلِيًا بِهِ ‏"‏ ‏.‏ قَالَ قُلْتُ بَلَى ‏.‏ قَالَ ‏"‏ فَاللَّهُ أَعْظَمُ وَذَلِكَ آيَتُهُ فِي خَلْقِهِ ‏"‏ ‏.‏\hadithno{180}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Waki' bin Hudus narrated that his paternal uncle Abu Razin said:"I said: 'O Messenger of Allah, will we see Allah on the Day of Resurrection? And what is the sign of that in His creation?' He said: 'O Abu Razin, do each of you not see the moon individually?' I said: 'Of course.' He said: 'Allah is Greater, and that is His sign in His creation}}
\hadithdefcmd{ibnmajah}{181}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ وَكِيعِ بْنِ حُدُسٍ، عَنْ عَمِّهِ أَبِي رَزِينٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ ضَحِكَ رَبُّنَا مِنْ قُنُوطِ عِبَادِهِ وَقُرْبِ غِيَرِهِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَوَ يَضْحَكُ الرَّبُّ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قُلْتُ لَنْ نَعْدِمَ مِنْ رَبٍّ يَضْحَكُ خَيْرًا ‏.‏\hadithno{181}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Waki' bin Hudus narrated that his paternal uncle Abu Razin said:"The Messenger of Allah said: 'Allah laughs at the despair of His slaves although He soon changes it.' I said: 'O Messenger of Allah, does the Lord laugh?' He said: 'Yes.' I said: 'We shall never be deprived of good by a Lord Who laughs}}
\hadithdefcmd{ibnmajah}{182}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ وَكِيعِ بْنِ حُدُسٍ، عَنْ عَمِّهِ أَبِي رَزِينٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَيْنَ كَانَ رَبُّنَا قَبْلَ أَنْ يَخْلُقَ خَلْقَهُ قَالَ ‏ "‏ كَانَ فِي عَمَاءٍ مَا تَحْتَهُ هَوَاءٌ وَمَا فَوْقَهُ هَوَاءٌ ثُمَّ خَلَقَ الْعَرْشَ عَلَى الْمَاءِ ‏"‏ ‏.‏\hadithno{182}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Waki' bin Hudus narrated that his paternal uncle Abu Razin said:"I said: 'O Messenger of Allah, where was our Lord before He created His creation?' He said: He was above the clouds, below which was air, and above which was air and water. Then He created His Throne above the water}}
\hadithdefcmd{ibnmajah}{183}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ الْمَازِنِيِّ، قَالَ بَيْنَمَا نَحْنُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ وَهُوَ يَطُوفُ بِالْبَيْتِ إِذْ عَرَضَ لَهُ رَجُلٌ فَقَالَ يَا ابْنَ عُمَرَ كَيْفَ سَمِعْتَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَذْكُرُ فِي النَّجْوَى قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ يُدْنَى الْمُؤْمِنُ مِنْ رَبِّهِ يَوْمَ الْقِيَامَةِ حَتَّى يَضَعَ عَلَيْهِ كَنَفَهُ ثُمَّ يُقَرِّرُهُ بِذُنُوبِهِ فَيَقُولُ هَلْ تَعْرِفُ فَيَقُولُ يَا رَبِّ أَعْرِفُ ‏.‏ حَتَّى إِذَا بَلَغَ مِنْهُ مَا شَاءَ اللَّهُ أَنْ يَبْلُغَ قَالَ إِنِّي سَتَرْتُهَا عَلَيْكَ فِي الدُّنْيَا وَأَنَا أَغْفِرُهَا لَكَ الْيَوْمَ ‏.‏ قَالَ ثُمَّ يُعْطَى صَحِيفَةَ حَسَنَاتِهِ أَوْ كِتَابَهُ بِيَمِينِهِ ‏.‏ قَالَ وَأَمَّا الْكَافِرُ أَوِ الْمُنَافِقُ فَيُنَادَى عَلَى رُءُوسِ الأَشْهَادِ ‏"‏ ‏.‏ قَالَ خَالِدٌ فِي ‏"‏ الأَشْهَادِ ‏"‏ ‏.‏ شَىْءٌ مِنِ انْقِطَاعٍ ‏.‏ ‏\{هَؤُلاَءِ الَّذِينَ كَذَبُوا عَلَى رَبِّهِمْ أَلاَ لَعْنَةُ اللَّهِ عَلَى الظَّالِمِينَ\}‏ ‏.‏\hadithno{183}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Safwan bin Muhriz Al-Mazini said:"We were with 'Abdullah bin 'Umar when he was circumambulating the House; a man came up to him and said: 'O Ibn 'Umar, what did you hear the Messenger of Allah say about the Najwa?' He said: 'I heard the Messenger of Allah say: 'On the Day of Resurrection, the believer will be brought close to his Lord until He will cover him with His screen, then He will make him confess his sins. He will ask him: "Do you confess?" He will say: "O Lord, I confess." This will continue as long as Allah wills, then He will say: "I concealed them for you in the world, and I forgive you for them today." Then he will be given the scroll of his good deeds, or his record, in his right hand. But as for the disbeliever or the hypocrite, (his sins) will be announced before the witnesses.' " (One of the narrators) Khalid said: "At: 'before the witnesses' there is something missing." "These are the ones who lied against their Lord!' No doubt! The curse of Allah is on the wrongdoers}}
\hadithdefcmd{ibnmajah}{184}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَاصِمٍ الْعَبَّادَانِيُّ، حَدَّثَنَا الْفَضْلُ الرَّقَاشِيُّ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ بَيْنَا أَهْلُ الْجَنَّةِ فِي نَعِيمِهِمْ إِذْ سَطَعَ لَهُمْ نُورٌ فَرَفَعُوا رُءُوسَهُمْ فَإِذَا الرَّبُّ قَدْ أَشْرَفَ عَلَيْهِمْ مِنْ فَوْقِهِمْ فَقَالَ السَّلاَمُ عَلَيْكُمْ يَا أَهْلَ الْجَنَّةِ ‏.‏ قَالَ وَذَلِكَ قَوْلُ اللَّهِ ‏\{سَلاَمٌ قَوْلاً مِنْ رَبٍّ رَحِيمٍ\}‏ قَالَ فَيَنْظُرُ إِلَيْهِمْ وَيَنْظُرُونَ إِلَيْهِ فَلاَ يَلْتَفِتُونَ إِلَى شَىْءٍ مِنَ النَّعِيمِ مَا دَامُوا يَنْظُرُونَ إِلَيْهِ حَتَّى يَحْتَجِبَ عَنْهُمْ وَيَبْقَى نُورُهُ وَبَرَكَتُهُ عَلَيْهِمْ فِي دِيَارِهِمْ ‏"‏ ‏.‏\hadithno{184}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabor bin 'Abdullah said:"The Messenger of Allah said: 'While the people of Paradise are enjoying their blessings, a light will shine upon them, and they will raise their heads, and they will see their Lord looking upon them from above. He will say: "Peace be upon you, O people of Paradise." This is what Allah says in the Verse: "Salam (peace be upon you) - a Word from the Lord (Allah), The Most Merciful." He will look at them, and they will look at Him, and they will not pay any attention to the delights (of Paradise) so long as they look at Him, until He will screen Himself from them. But His light and blessing will remain with them in their bodies}}
\hadithdefcmd{ibnmajah}{185}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ سَيُكَلِّمُهُ رَبُّهُ لَيْسَ بَيْنَهُ وَبَيْنَهُ تَرْجُمَانٌ فَيَنْظُرُ عَنْ أَيْمَنَ مِنْهُ فَلاَ يَرَى إِلاَّ شَيْئًا قَدَّمَهُ ثُمَّ يَنْظُرُ عَنْ أَيْسَرَ مِنْهُ فَلاَ يَرَى إِلاَّ شَيْئًا قَدَّمَهُ ثُمَّ يَنْظُرُ أَمَامَهُ فَتَسْتَقْبِلُهُ النَّارُ فَمَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَتَّقِيَ النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{185}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Adi bin Hatim said:"The Messenger of Allah said: 'There is no one among you but his Lord will speak to him without any intermediary between them. He will look to his right and will not see anything but that which he sent forth. He will look to his left and will not see anything but that which he sent forth. Then he will look in front of him and will be faced with the Fire. So whoever among you can protect himself from fire, even by means of half a date, let him do so}}
\hadithdefcmd{ibnmajah}{186}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَبْدِ الصَّمَدِ عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ الأَشْعَرِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ جَنَّتَانِ مِنْ فِضَّةٍ آنِيَتُهُمَا وَمَا فِيهِمَا وَجَنَّتَانِ مِنْ ذَهَبٍ آنِيَتُهُمَا وَمَا فِيهِمَا وَمَا بَيْنَ الْقَوْمِ وَبَيْنَ أَنْ يَنْظُرُوا إِلَى رَبِّهِمْ تَبَارَكَ وَتَعَالَى إِلاَّ رِدَاءُ الْكِبْرِيَاءِ عَلَى وَجْهِهِ فِي جَنَّةِ عَدْنٍ ‏"‏ ‏.‏\hadithno{186}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Bakr bin Qais Al-Ash'ari narrated that his father said:"The Messenger of Allah said: 'Two gardens of silver, their vessels and everything in them; and two gardens of gold, their vessels and everything in them, and nothing between the people and their seeing their Lord, the Blessed and Exalted, except the Veil of Pride covering His Face in the Garden of Eden (Jannat 'Adn)}}
\hadithdefcmd{ibnmajah}{187}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ صُهَيْبٍ، قَالَ تَلاَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ هَذِهِ الآيَةَ ‏\{لِلَّذِينَ أَحْسَنُوا الْحُسْنَى وَزِيَادَةٌ\}‏ وَقَالَ ‏"‏ إِذَا دَخَلَ أَهْلُ الْجَنَّةِ الْجَنَّةَ وَأَهْلُ النَّارِ النَّارَ نَادَى مُنَادٍ يَا أَهْلَ الْجَنَّةِ إِنَّ لَكُمْ عِنْدَ اللَّهِ مَوْعِدًا يُرِيدُ أَنْ يُنْجِزَكُمُوهُ ‏.‏ فَيَقُولُونَ وَمَا هُوَ أَلَمْ يُثَقِّلِ اللَّهُ مَوَازِينَنَا وَيُبَيِّضْ وُجُوهَنَا وَيُدْخِلْنَا الْجَنَّةَ وَيُنْجِنَا مِنَ النَّارِ قَالَ فَيَكْشِفُ الْحِجَابَ فَيَنْظُرُونَ إِلَيْهِ فَوَاللَّهِ مَا أَعْطَاهُمُ اللَّهُ شَيْئًا أَحَبَّ إِلَيْهِمْ مِنَ النَّظَرِ إِلَيْهِ وَلاَ أَقَرَّ لأَعْيُنِهِمْ ‏"‏ ‏.‏\hadithno{187}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Suhaib said:"The Messenger of Allah recited this Verse: 'For those who have done good is the best reward and even more.' Then he said: 'When the people of Paradise enter Paradise, and the people of the Fire enter the Fire, a caller will cry out: "O people of Paradise! You have a covenant with Allah and He wants to fulfill it." They will say: "What is it?" Has Allah not made the Balance (of our good deeds) heavy, and made our faces bright, and admitted us to Paradise and saved us from Hell?" Then the Veil will be lifted and they will look upon Him, and by Allah, Allah will not give them anything that is more beloved to them or delightful, than looking upon Him}}
\hadithdefcmd{ibnmajah}{188}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتِ الْحَمْدُ لِلَّهِ الَّذِي وَسِعَ سَمْعُهُ الأَصْوَاتَ، لَقَدْ جَاءَتِ الْمُجَادِلَةُ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَأَنَا فِي نَاحِيَةِ الْبَيْتِ تَشْكُو زَوْجَهَا وَمَا أَسْمَعُ مَا تَقُولُ فَأَنْزَلَ اللَّهُ ‏\{قَدْ سَمِعَ اللَّهُ قَوْلَ الَّتِي تُجَادِلُكَ فِي زَوْجِهَا\}‏ ‏.‏\hadithno{188}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"Praise is to Allah Whose hearing encompasses all voices. The woman who disputed concerning her husband (Al-Mujadilah) came to the Prophet when I was (sitting) in a corner of the house, and she complained about her husband, but I did not hear what she said. The Allah revealed: 'Indeed Allah has heard the statement of her that disputes with you concerning her husband}}
\hadithdefcmd{ibnmajah}{189}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كَتَبَ رَبُّكُمْ عَلَى نَفْسِهِ بِيَدِهِ قَبْلَ أَنْ يَخْلُقَ الْخَلْقَ رَحْمَتِي سَبَقَتْ غَضَبِي ‏"‏ ‏.‏\hadithno{189}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Your Lord wrote for Himself with His Own Hand before He created the creation: "My mercy precedes My wrath}}
\hadithdefcmd{ibnmajah}{190}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، وَيَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالاَ حَدَّثَنَا مُوسَى بْنُ إِبْرَاهِيمَ بْنِ كَثِيرٍ الأَنْصَارِيُّ الْحَرَامِيُّ، قَالَ سَمِعْتُ طَلْحَةَ بْنَ خِرَاشٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ لَمَّا قُتِلَ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ حَرَامٍ يَوْمَ أُحُدٍ لَقِيَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ يَا جَابِرُ أَلاَ أُخْبِرُكَ مَا قَالَ اللَّهُ لأَبِيكَ ‏"‏ ‏.‏ وَقَالَ يَحْيَى فِي حَدِيثِهِ فَقَالَ ‏"‏ يَا جَابِرُ مَالِي أَرَاكَ مُنْكَسِرًا ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ اسْتُشْهِدَ أَبِي وَتَرَكَ عِيَالاً وَدَيْنًا ‏.‏ قَالَ ‏"‏ أَفَلاَ أُبَشِّرُكَ بِمَا لَقِيَ اللَّهُ بِهِ أَبَاكَ ‏"‏ ‏.‏ قَالَ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ مَا كَلَّمَ اللَّهُ أَحَدًا قَطُّ إِلاَّ مِنْ وَرَاءِ حِجَابٍ وَكَلَّمَ أَبَاكَ كِفَاحًا ‏.‏ فَقَالَ يَا عَبْدِي تَمَنَّ عَلَىَّ أُعْطِكَ ‏.‏ قَالَ يَا رَبِّ تُحْيِينِي فَأُقْتَلُ فِيكَ ثَانِيَةً ‏.‏ فَقَالَ الرَّبُّ سُبْحَانَهُ إِنَّهُ سَبَقَ مِنِّي أَنَّهُمْ إِلَيْهَا لاَ يَرْجِعُونَ ‏.‏ قَالَ يَا رَبِّ فَأَبْلِغْ مَنْ وَرَائِي ‏.‏ قَالَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{وَلاَ تَحْسَبَنَّ الَّذِينَ قُتِلُوا فِي سَبِيلِ اللَّهِ أَمْوَاتًا بَلْ أَحْيَاءٌ عِنْدَ رَبِّهِمْ يُرْزَقُونَ\}‏ ‏"‏ ‏.‏\hadithno{190}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Talhah bin Khirash said:"I head Jabir bin 'Abdullah say" 'When 'Abdullah bin 'Amr bin )Haram) was killed on the Day of Uhud, the Messenger of Allah met me, and said: "O Jabir, shall I not tell you what Allah has said to your father?" Yahya said in his Hadith: "And he said: 'O Jabir, why do I see you broken-hearted?' I (Jabir) said: 'O Messenger of Allah, my father has been martyred and he has left behind dependents and debts.' He said: 'Shall I not give you the glad tidings of that with which Allah met your father?' I said: 'Yes, O Messenger of Allah.' He said: 'Allah never spoke to anyone except from behind a screen, but He spoke to your father directly, and He said: "O My slave! Ask something from Me and I shall give it to you." He said: "O Lord, bring me back to life so that I may be killed in Your cause a second time." The Lord, Glorified is He, said: "I have already decreed that they will not return to life." He said: "My Lord, then convey (this news) to those whom I have left behind." Allah said: "Think not of those as dead who are killed in the way of Allah, Nay, they are alive, with their Lord, and they have provision}}
\hadithdefcmd{ibnmajah}{191}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ يَضْحَكُ إِلَى رَجُلَيْنِ يَقْتُلُ أَحَدُهُمَا الآخَرَ كِلاَهُمَا دَخَلَ الْجَنَّةَ يُقَاتِلُ هَذَا فِي سَبِيلِ اللَّهِ فَيُسْتَشْهَدُ ثُمَّ يَتُوبُ اللَّهُ عَلَى قَاتِلِهِ فَيُسْلِمُ فَيُقَاتِلُ فِي سَبِيلِ اللَّهِ فَيُسْتَشْهَدُ ‏"‏ ‏.‏\hadithno{191}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Allah will laugh at two persons- one of them kills the other, and both of them enter Paradise, for the first one fought in the cause of Allah and was martyred, then his killer repented to Allah and became Muslim, then he also fought in the cause of Allah and was martyred}}
\hadithdefcmd{ibnmajah}{192}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، كَانَ يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَقْبِضُ اللَّهُ الأَرْضَ يَوْمَ الْقِيَامَةِ وَيَطْوِي السَّمَاءَ بِيَمِينِهِ ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَيْنَ مُلُوكُ الأَرْضِ ‏"‏ ‏.‏\hadithno{192}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Sa'eed bin Musayyab narrated that Abu Hurairah used to say:"The Messenger of Allah said: Allah will seize the earth on the Day of Ressurection, and He will roll up the heavens in his Right Hand, then He will say, "I am the Sovereign. Where are the kings of the earth?}}
\hadithdefcmd{ibnmajah}{193}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا الْوَلِيدُ بْنُ أَبِي ثَوْرٍ الْهَمْدَانِيُّ، عَنْ سِمَاكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمِيرَةَ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، قَالَ كُنْتُ بِالْبَطْحَاءِ فِي عِصَابَةٍ وَفِيهِمْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَمَرَّتْ بِهِ سَحَابَةٌ فَنَظَرَ إِلَيْهَا فَقَالَ ‏"‏ مَا تُسَمُّونَ هَذِهِ ‏"‏ ‏.‏ قَالُوا السَّحَابُ ‏.‏ قَالَ ‏"‏ وَالْمُزْنُ ‏"‏ ‏.‏ قَالُوا وَالْمُزْنُ ‏.‏ قَالَ ‏"‏ وَالْعَنَانُ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ قَالُوا وَالْعَنَانُ ‏.‏ قَالَ ‏"‏ كَمْ تَرَوْنَ بَيْنَكُمْ وَبَيْنَ السَّمَاءِ ‏"‏ ‏.‏ قَالُوا لاَ نَدْرِي ‏.‏ قَالَ ‏"‏ فَإِنَّ بَيْنَكُمْ وَبَيْنَهَا إِمَّا وَاحِدًا أَوِ اثْنَيْنِ أَوْ ثَلاَثًا وَسَبْعِينَ سَنَةً وَالسَّمَاءُ فَوْقَهَا كَذَلِكَ ‏"‏ ‏.‏ حَتَّى عَدَّ سَبْعَ سَمَاوَاتٍ ‏"‏ ثُمَّ فَوْقَ السَّمَاءِ السَّابِعَةِ بَحْرٌ بَيْنَ أَعْلاَهُ وَأَسْفَلِهِ كَمَا بَيْنَ سَمَاءٍ إِلَى سَمَاءٍ ثُمَّ فَوْقَ ذَلِكَ ثَمَانِيَةُ أَوْعَالٍ بَيْنَ أَظْلاَفِهِنَّ وَرُكَبِهِنَّ كَمَا بَيْنَ سَمَاءٍ إِلَى سَمَاءٍ ثُمَّ عَلَى ظُهُورِهِنَّ الْعَرْشُ بَيْنَ أَعْلاَهُ وَأَسْفَلِهِ كَمَا بَيْنَ سَمَاءٍ إِلَى سَمَاءٍ ثُمَّ اللَّهُ فَوْقَ ذَلِكَ تَبَارَكَ وَتَعَالَى ‏"‏ ‏.‏\hadithno{193}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abbas bin 'Abdul-Mutallib said:"I was in Batha with a group of people, among them whom was the Messenger of Allah. A cloud passed over him, and he looked at it and said: 'What do you call this?' They said: 'Sahab (a cloud).' He said: 'And Muzn (rain cloud).' They said: 'And Muzn.' He said: 'And 'Anan (clouds).' Abu Bakr said: "They said: 'And 'Anan.'" He said: 'How much (distance) do you think there is between you and the heavens?' They said: 'We do not know.' He said: 'Between you and it is seventy-one, or seventy-two, or seventy-three years, and there is a similar distance between it and the heaven above it (and so on)' until he counted seven heavens. 'Then above the seventh heaven there is a sea, between whose top and bottom is a distance like that between one heaven and another. Then above that there are eight (angels in the form of) mountain goats. The distance between their hooves and their knees is like the distance between one heaven and the next. Then on their backs is the Throne, and the distance between the top and the bottom of the Throne is like the distance between one heaven and another. Then Allah is above that, the Blessed and Exalted}}
\hadithdefcmd{ibnmajah}{194}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا قَضَى اللَّهُ أَمْرًا فِي السَّمَاءِ ضَرَبَتِ الْمَلاَئِكَةُ أَجْنِحَتَهَا خِضْعَانًا لِقَوْلِهِ كَأَنَّهُ سِلْسِلَةٌ عَلَى صَفْوَانٍ فَإِذَا فُزِّعَ عَنْ قُلُوبِهِمْ قَالُوا مَاذَا قَالَ رَبُّكُمْ قَالُوا الْحَقَّ وَهُوَ الْعَلِيُّ الْكَبِيرُ قَالَ فَيَسْمَعُهَا مُسْتَرِقُو السَّمْعِ بَعْضُهُمْ فَوْقَ بَعْضٍ فَيَسْمَعُ الْكَلِمَةَ فَيُلْقِيهَا إِلَى مَنْ تَحْتَهُ فَرُبَّمَا أَدْرَكَهُ الشِّهَابُ قَبْلَ أَنْ يُلْقِيَهَا إِلَى الَّذِي تَحْتَهُ فَيُلْقِيهَا عَلَى لِسَانِ الْكَاهِنِ أَوِ السَّاحِرِ فَرُبَّمَا لَمْ يُدْرَكْ حَتَّى يُلْقِيَهَا فَيَكْذِبُ مَعَهَا مِائَةَ كَذْبَةٍ فَتَصْدُقُ تِلْكَ الْكَلِمَةُ الَّتِي سُمِعَتْ مِنَ السَّمَاءِ ‏"‏ ‏.‏\hadithno{194}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "When Allah decrees a matter in heaven, the angels beat their wings in submission to his decree (with a sound) like a chain beating a rock. Then "When fear is banished from their hearts, they say: 'What is it that your Lord has said?' They say: 'The truth. And He is The Most High, The Most Great." He said: 'Then the eavesdroppers (from among the jinn) listen out for that, one above the other, so (one of them) hears the words and passes it on to the one beneath him. The Shihab (shooting star) may strike him before he can pass it on to the one beneath him and the latter can pass it on to the soothsayer or sorcerer, or it may not strike him until he has passed it on. And he ads one hundred lies to it, and only that word which was overheard from the heavens is true}}
\hadithdefcmd{ibnmajah}{195}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَامَ فِينَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِخَمْسِ كَلِمَاتٍ فَقَالَ ‏ "‏ إِنَّ اللَّهَ لاَ يَنَامُ وَلاَ يَنْبَغِي لَهُ أَنْ يَنَامَ يَخْفِضُ الْقِسْطَ وَيَرْفَعُهُ يُرْفَعُ إِلَيْهِ عَمَلُ اللَّيْلِ قَبْلَ عَمَلِ النَّهَارِ وَعَمَلُ النَّهَارِ قَبْلَ عَمَلِ اللَّيْلِ حِجَابُهُ النُّورُ لَوْ كَشَفَهُ لأَحْرَقَتْ سُبُحَاتُ وَجْهِهِ مَا انْتَهَى إِلَيْهِ بَصَرُهُ مِنْ خَلْقِهِ ‏"‏ ‏.‏\hadithno{195}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah stood up among us and said five things. He said: 'Allah does not sleep, and it is not befitting that He should sleep. He lowers the Scales and raises them. The deed done during the day is taken up to Him before the deed done during the night, and the deed done during the night before the deed done during the day. His Veil is Light, and if He were to remove it, the glory of his Face would burn everything of His creation, as far as His gaze reaches}}
\hadithdefcmd{ibnmajah}{196}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ اللَّهَ لاَ يَنَامُ وَلاَ يَنْبَغِي لَهُ أَنْ يَنَامَ يَخْفِضُ الْقِسْطَ وَيَرْفَعُهُ حِجَابُهُ النُّورُ لَوْ كَشَفَهَا لأَحْرَقَتْ سُبُحَاتُ وَجْهِهِ كُلَّ شَىْءٍ أَدْرَكَهُ بَصَرُهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ أَبُو عُبَيْدَةَ ‏\{أَنْ بُورِكَ مَنْ فِي النَّارِ وَمَنْ حَوْلَهَا وَسُبْحَانَ اللَّهِ رَبِّ الْعَالَمِينَ\}‏ ‏.‏\hadithno{196}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah said: 'Allah does not sleep, and it is not befitting that He should sleep. He lowers the Scales and raises them. His Veil is Light, and if He were to remove it, the glory of his Face would burn everything of His creation, as far as His gaze reaches.' " Then Abu 'Ubaidah recited the verse: 'Blessed is whosoever is in the fire, (i.e. the light of Allah) and whosoever is round about it! And Glorified is Allah, the Lord of all that exists}}
\hadithdefcmd{ibnmajah}{197}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يَمِينُ اللَّهِ مَلأَى لاَ يَغِيضُهَا شَىْءٌ سَحَّاءُ اللَّيْلَ وَالنَّهَارَ وَبِيَدِهِ الأُخْرَى الْمِيزَانُ يَرْفَعُ الْقِسْطَ وَيَخْفِضُهُ قَالَ أَرَأَيْتَ مَا أَنْفَقَ مُنْذُ خَلَقَ اللَّهُ السَّمَوَاتِ وَالأَرْضَ فَإِنَّهُ لَمْ يَنْقُصْ مِمَّا فِي يَدَيْهِ شَيْئًا ‏"‏ ‏.‏\hadithno{197}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "The Right Hand of Allah is full and that is never affected by the continuous spending, night and day. In His other Hand, is the Scale, which He raises and lowers. Have you seen what Allah has spent since He created the heavens and the earth? And that has not decreased what is in His Hands in the slightest}}
\hadithdefcmd{ibnmajah}{198}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي، عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ يَأْخُذُ الْجَبَّارُ سَمَوَاتِهِ وَأَرْضَهُ بِيَدِهِ - وَقَبَضَ بِيَدِهِ فَجَعَلَ يَقْبِضُهَا وَيَبْسُطُهَا - ثُمَّ يَقُولُ أَنَا الْجَبَّارُ أَيْنَ الْجَبَّارُونَ أَيْنَ الْمُتَكَبِّرُونَ ‏"‏ ‏.‏ قَالَ وَيَتَمَيَّلُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ حَتَّى نَظَرْتُ إِلَى الْمِنْبَرِ يَتَحَرَّكُ مِنْ أَسْفَلِ شَىْءٍ مِنْهُ حَتَّى إِنِّي أَقُولُ أَسَاقِطٌ هُوَ بِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ\hadithno{198}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"I heard the Messenger of Allah say, when he was on the pulpit: 'The Compeller will seize the heavens and the earth in His Hand' and he clenched his fist and began to open and close it. Then He will say: "I am the Compeller! Where are the tyrants? Where are the arrogant?" He said, the Messenger of Allah was turning to his right and to his left, until he saw the pulpit moving from below and I thought: 'What if it falls with the Messenger of Allah on it?}}
\hadithdefcmd{ibnmajah}{199}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا ابْنُ جَابِرٍ، قَالَ سَمِعْتُ بُسْرَ بْنَ عُبَيْدِ اللَّهِ، يَقُولُ سَمِعْتُ أَبَا إِدْرِيسَ الْخَوْلاَنِيَّ، يَقُولُ حَدَّثَنِي النَّوَّاسُ بْنُ سَمْعَانَ الْكِلاَبِيُّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ مَا مِنْ قَلْبٍ إِلاَّ بَيْنَ إِصْبَعَيْنِ مِنْ أَصَابِعِ الرَّحْمَنِ إِنْ شَاءَ أَقَامَهُ وَإِنْ شَاءَ أَزَاغَهُ ‏"‏ ‏.‏ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ يَا مُثَبِّتَ الْقُلُوبِ ثَبِّتْ قُلُوبَنَا عَلَى دِينِكَ ‏"‏ ‏.‏ قَالَ ‏"‏ وَالْمِيزَانُ بِيَدِ الرَّحْمَنِ يَرْفَعُ أَقْوَامًا وَيَخْفِضُ آخَرِينَ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{199}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nawwas bin Sam'an Al-Kilabi said:"I heard the Messenger of Allah say: 'There is no heart that is not between two of the Fingers of the Most Merciful. If He wills, He guides it and if He wills, He sends it astray.' The Messenger of Allah used to say: 'O You Who makes hearts steadfast make our hearts steadfast in adhering to Your religion.' And he said: 'The Scale is in the Hand of the Most Merciful; He will cause some peoples to rise and others to fall until the day of Resurrection}}
\hadithdefcmd{ibnmajah}{200}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِسْمَاعِيلَ، عَنْ مُجَالِدٍ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ لَيَضْحَكُ إِلَى ثَلاَثَةٍ لِلصَّفِّ فِي الصَّلاَةِ وَلِلرَّجُلِ يُصَلِّي فِي جَوْفِ اللَّيْلِ وَلِلرَّجُلِ يُقَاتِلُ - أُرَاهُ قَالَ - خَلْفَ الْكَتِيبَةِ ‏"‏ ‏.‏\hadithno{200}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah said: 'Allah smiles at three things: a row in the prayer, a man who prays in the depths of the night, and a man who fights' I think he said, 'behind the battalion}}
\hadithdefcmd{ibnmajah}{201}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ عُثْمَانَ، - يَعْنِي ابْنَ الْمُغِيرَةِ الثَّقَفِيَّ - عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَعْرِضُ نَفْسَهُ عَلَى النَّاسِ فِي الْمَوْسِمِ فَيَقُولُ ‏ "‏ أَلاَ رَجَلٌ يَحْمِلُنِي إِلَى قَوْمِهِ فَإِنَّ قُرَيْشًا قَدْ مَنَعُونِي أَنْ أُبَلِّغَ كَلاَمَ رَبِّي ‏"‏ ‏.‏\hadithno{201}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:The Messenger of Allah used to appear before the people during the Hajj season and say: 'Is there any man who can take me to his people, for the Quraish have prevented me from conveying the speech (i.e. the Message) of my Lord}}
\hadithdefcmd{ibnmajah}{202}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَزِيرُ بْنُ صَبِيحٍ، حَدَّثَنَا يُونُسُ بْنُ حَلْبَسٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي قَوْلِهِ تَعَالَى ‏\{كُلَّ يَوْمٍ هُوَ فِي شَأْنٍ\}‏ ‏.‏ قَالَ ‏"‏ مِنْ شَأْنِهِ أَنْ يَغْفِرَ ذَنْبًا وَيُفَرِّجَ كَرْبًا وَيَرْفَعَ قَوْمًا وَيَخْفِضَ آخَرِينَ ‏"‏ ‏.‏\hadithno{202}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Darda' that:The Prophet said concerning the Verse: "Every day He is (engaged) in some affair." "His affairs include forgiving sins, relieving distress, raising some people and bringing others low}}
\hadithdefcmd{ibnmajah}{203}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، عَنِ الْمُنْذِرِ بْنِ جَرِيرٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ سَنَّ سُنَّةً حَسَنَةً فَعُمِلَ بِهَا كَانَ لَهُ أَجْرُهَا وَمِثْلُ أَجْرِ مَنْ عَمِلَ بِهَا لاَ يَنْقُصُ مِنْ أُجُورِهِمْ شَيْئًا وَمَنْ سَنَّ سُنَّةً سَيِّئَةً فَعُمِلَ بِهَا كَانَ عَلَيْهِ وِزْرُهَا وَوِزْرُ مَنْ عَمِلَ بِهَا مِنْ بَعْدِهِ لاَ يَنْقُصُ مِنْ أَوْزَارِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{203}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Mundhir bin Jarir that his father said:"The Messenger of Allah said: 'Whoever introduces a good practice that is followed, he will receive its reward and a reward equivalent to that of those who follow it, without that detracting from their reward in their slightest. And whoever introduces a bad practice that is followed, he will receive its sin and a burden of sin equivalent to that of those who follow it, without that detracting from their burden in the slightest}}
\hadithdefcmd{ibnmajah}{204}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، حَدَّثَنِي أَبِي، حَدَّثَنِي أَبِي، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَحَثَّ عَلَيْهِ فَقَالَ رَجُلٌ عِنْدِي كَذَا وَكَذَا ‏.‏ قَالَ فَمَا بَقِيَ فِي الْمَجْلِسِ رَجُلٌ إِلاَّ تَصَدَّقَ عَلَيْهِ بِمَا قَلَّ أَوْ كَثُرَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنِ اسْتَنَّ خَيْرًا فَاسْتُنَّ بِهِ كَانَ لَهُ أَجْرُهُ كَامِلاً وَمِنْ أُجُورِ مَنِ اسْتَنَّ بِهِ وَلاَ يَنْقُصُ مِنْ أُجُورِهِمْ شَيْئًا وَمَنِ اسْتَنَّ سُنَّةً سَيِّئَةً فَاسْتُنَّ بِهِ فَعَلَيْهِ وِزْرُهُ كَامِلاً وَمِنْ أَوْزَارِ الَّذِينَ اسْتَنَّ بِهِ وَلاَ يَنْقُصُ مِنْ أَوْزَارِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{204}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"A man came to the Prophet, who encouraged the people to give charity to him. A man said: 'I have such and such,' and there was no one left in that gathering who did not give him something in charity, to a greater or lesser extent. The Messenger of Allah said: 'Whoever initiates a good practice that is followed, he will receive a perfect reward for that, and a reward equivalent to that of those who follow it, without that detracting from their reward in the slightest. And whoever introduces a bad practice that is followed, he will receive the complete burden of sin for that, and a burden of sin equivalent to that of those who follow it without that detracting from their burden in the slightest}}
\hadithdefcmd{ibnmajah}{205}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ أَيُّمَا دَاعٍ دَعَا إِلَى ضَلاَلَةٍ فَاتُّبِعَ فَإِنَّ لَهُ مِثْلَ أَوْزَارِ مَنِ اتَّبَعَهُ وَلاَ يَنْقُصُ مِنْ أَوْزَارِهِمْ شَيْئًا وَأَيُّمَا دَاعٍ دَعَا إِلَى هُدًى فَاتُّبِعَ فَإِنَّ لَهُ مِثْلَ أُجُورِ مَنِ اتَّبَعَهُ وَلاَ يَنْقُصُ مِنْ أُجُورِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{205}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Anas bin Malik that:The Messenger of Allah said: "Every caller who invites people to misguidance and is followed, will have a burden of sin equal to that of those who follow him, without that detracting from their burden in the slightest. And every caller who invites people to true guidance and is followed, will have a reward equal to that of those who follow him, without that detracting from their reward in the slightest}}
\hadithdefcmd{ibnmajah}{206}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ دَعَا إِلَى هُدًى كَانَ لَهُ مِنَ الأَجْرِ مِثْلُ أُجُورِ مَنِ اتَّبَعَهُ لاَ يَنْقُصُ ذَلِكَ مِنْ أُجُورِهِمْ شَيْئًا وَمَنْ دَعَا إِلَى ضَلاَلَةٍ فَعَلَيْهِ مِنَ الإِثْمِ مِثْلُ آثَامِ مَنِ اتَّبَعَهُ لاَ يَنْقُصُ ذَلِكَ مِنْ آثَامِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{206}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "Whoever calls people to true guidance, will have a reward equal to that of those who follow him, without that detracting from their reward in the slightest. And whoever calls people to misguidance, will have a (burden of) sin equal to that of those who follow him, without that detracting from their sins in the slightest}}
\hadithdefcmd{ibnmajah}{207}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا أَبُو إِسْرَائِيلَ، عَنِ الْحَكَمِ، عَنْ أَبِي جُحَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ سَنَّ سُنَّةً حَسَنَةً فَعُمِلَ بِهَا بَعْدَهُ كَانَ لَهُ أَجْرُهَا وَمِثْلُ أُجُورِهِمْ مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أُجُورِهِمْ شَيْئًا وَمَنْ سَنَّ سُنَّةً سَيِّئَةً فَعُمِلَ بِهَا بَعْدَهُ كَانَ عَلَيْهِ وِزْرُهُ وَمِثْلُ أَوْزَارِهِمْ مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أَوْزَارِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{207}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Juhaifah said:"The Messenger of Allah said: 'Whoever introduces a good practice that is followed after him, will have a reward for that and the equivalent of their reward, without that detracting from their reward in the slightest. Whoever introduces an evil practice that is followed after him, will bear the burden of sin for that and the equivalent of their burden of sin, without that detracting from their burden in the slightest}}
\hadithdefcmd{ibnmajah}{208}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ لَيْثٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ دَاعٍ يَدْعُو إِلَى شَىْءٍ إِلاَّ وُقِفَ يَوْمَ الْقِيَامَةِ لاَزِمًا لِدَعْوَتِهِ مَا دَعَا إِلَيْهِ وَإِنْ دَعَا رَجُلٌ رَجُلاً ‏"‏ ‏.‏\hadithno{208}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'There is no caller who invites people to a thing but on the Day of Resurrection he will be made to stand next to that to which he called others, even if he only called one another person}}
\hadithdefcmd{ibnmajah}{209}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ الْمُزَنِيُّ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَحْيَا سُنَّةً مِنْ سُنَّتِي فَعَمِلَ بِهَا النَّاسُ كَانَ لَهُ مِثْلُ أَجْرِ مَنْ عَمِلَ بِهَا لاَ يَنْقُصُ مِنْ أُجُورِهِمْ شَيْئًا وَمَنِ ابْتَدَعَ بِدْعَةً فَعُمِلَ بِهَا كَانَ عَلَيْهِ أَوْزَارُ مَنْ عَمِلَ بِهَا لاَ يَنْقُصُ مِنْ أَوْزَارِ مَنْ عَمِلَ بِهَا شَيْئًا ‏"‏ ‏.‏\hadithno{209}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin 'Abdullah bin 'Amr bin 'Awf Al-Muzani said:"My father told me narrating from my grandfather, that the Messenger of Allah said: 'Whoever revives a Sunnah of mine, which people then act upon, will have a reward equivalent to that of those who act upon it, without that detracting from their reward in the slightest. And whoever introduces an innovation (Bid'ah) that is acted upon, will have a burden of sins equivalent to that of those who act upon it, withot that detracting from the burden of those who act upon it in the slightest}}
\hadithdefcmd{ibnmajah}{210}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي كَثِيرُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ أَحْيَا سُنَّةً مِنْ سُنَّتِي قَدْ أُمِيتَتْ بَعْدِي فَإِنَّ لَهُ مِنَ الأَجْرِ مِثْلَ أَجْرِ مَنْ عَمِلَ بِهَا مِنَ النَّاسِ لاَ يَنْقُصُ مِنْ أُجُورِ النَّاسِ شَيْئًا وَمَنِ ابْتَدَعَ بِدْعَةً لاَ يَرْضَاهَا اللَّهُ وَرَسُولُهُ فَإِنَّ عَلَيْهِ مِثْلَ إِثْمِ مَنْ عَمِلَ بِهَا مِنَ النَّاسِ لاَ يَنْقُصُ مِنْ آثَامِ النَّاسِ شَيْئًا ‏"‏ ‏.‏\hadithno{210}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin 'Abdullah narrated from his father, that his grandfather said:"I heard the Messenger of Allah say: 'Whoever revives a Sunnah of mine that dies out after I am gone, he will have a reward equivalent to that of those among the people who act upon it, without that detracting from their reward in the slightest. Whoever introduces an innovation (Bid'ah) with which Allah and his Messenger are not pleased, he will have a (burden of) sin equivalent to that of those among the people who act upon it, without that detracting from their sins in the slightest}}
\hadithdefcmd{ibnmajah}{211}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا شُعْبَةُ، وَسُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ شُعْبَةُ ‏"‏ خَيْرُكُمْ ‏"‏ ‏.‏ وَقَالَ سُفْيَانُ ‏"‏ أَفْضَلُكُمْ مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏ ‏.‏\hadithno{211}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Uthman bin 'Affan said that:The Messenger of Allah said: (According to one of the narrators) Shu'bah (he) said: 'The best of you' (and according to) Sufyan (he) said: "The most excellent of you is the one who learns the Qur'an and teaches it}}
\hadithdefcmd{ibnmajah}{212}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَفْضَلُكُمْ مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏ ‏.‏\hadithno{212}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Uthmaan bin 'Affan said:"The Messenger of Allah said: 'The most excellent of you is the one who learns the Qur'an and teaches it}}
\hadithdefcmd{ibnmajah}{213}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا الْحَارِثُ بْنُ نَبْهَانَ، حَدَّثَنَا عَاصِمُ بْنُ بَهْدَلَةَ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خِيَارُكُمْ مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏ ‏.‏ قَالَ وَأَخَذَ بِيَدِي فَأَقْعَدَنِي مَقْعَدِي هَذَا أُقْرِئُ ‏.‏\hadithno{213}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Mus'ab bin Sa'd narrated that his father said:"The Messenger of Allah said: 'The best of you is the one who learns the Qur'an and teaches it.' " 'Then he (Mus'ab) took me (the narrator) by the hand and made me sit here, and I started to teach Qur'an}}
\hadithdefcmd{ibnmajah}{214}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَثَلُ الْمُؤْمِنِ الَّذِي يَقْرَأُ الْقُرْآنَ كَمَثَلِ الأُتْرُجَّةِ طَعْمُهَا طَيِّبٌ وَرِيحُهَا طَيِّبٌ وَمَثَلُ الْمُؤْمِنِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ التَّمْرَةِ طَعْمُهَا طَيِّبٌ وَلاَ رِيحَ لَهَا وَمَثَلُ الْمُنَافِقِ الَّذِي يَقْرَأُ الْقُرْآنَ كَمَثَلِ الرَّيْحَانَةِ رِيحُهَا طَيِّبٌ وَطَعْمُهَا مُرٌّ وَمَثَلُ الْمُنَافِقِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ الْحَنْظَلَةِ طَعْمُهَا مُرٌّ وَلاَ رِيحَ لَهَا ‏"‏ ‏.‏\hadithno{214}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Musa Al-Ash'ari that:The Prophet said: "The likeness of the believer who recites the Qur'an is that of a citron, the taste and smell of which are good. The likeness of a believer who does not read the Qur'an is that of a date, the taste of which is good but it has no smell. The likeness of a hypocrite who reads the Qur'an is that of a sweet basil, the smell of which is good but its taste is bitter. And the likeness of a hypocrite who does not read the Qur'an is that of a colocynth (bitter apple), the taste of which is bitter and it has no smell}}
\hadithdefcmd{ibnmajah}{215}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بُدَيْلٍ، عَنْ أَبِيهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ لِلَّهِ أَهْلِينَ مِنَ النَّاسِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَنْ هُمْ قَالَ ‏"‏ هُمْ أَهْلُ الْقُرْآنِ أَهْلُ اللَّهِ وَخَاصَّتُهُ ‏"‏ ‏.‏\hadithno{215}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'Allah has His own people among mankind.' They said: 'O Messenger of Allah, who are they?' He said: 'The people of the Qur'an, the people of Allah and those who are closest to Him}}
\hadithdefcmd{ibnmajah}{216}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنْ أَبِي عُمَرَ، عَنْ كَثِيرِ بْنِ زَاذَانَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ قَرَأَ الْقُرْآنَ وَحَفِظَهُ أَدْخَلَهُ اللَّهُ الْجَنَّةَ وَشَفَّعَهُ فِي عَشَرَةٍ مِنْ أَهْلِ بَيْتِهِ كُلُّهُمْ قَدِ اسْتَوْجَبُوا النَّارَ ‏"‏ ‏.‏\hadithno{216}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali bin Abu Talib said:"The Messenger of Allah said: 'Whoever reads the Qur'an and memorizes it, Allah will admit him to Paradise and allow him to intercede for ten of his family members who all deserved to enter Hell}}
\hadithdefcmd{ibnmajah}{217}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ الأَوْدِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنِ الْمَقْبُرِيِّ، عَنْ عَطَاءٍ، مَوْلَى أَبِي أَحْمَدَ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَعَلَّمُوا الْقُرْآنَ وَاقْرَءُوهُ وَارْقُدُوا فَإِنَّ مَثَلَ الْقُرْآنِ وَمَنْ تَعَلَّمَهُ فَقَامَ بِهِ كَمَثَلِ جِرَابٍ مَحْشُوٍّ مِسْكًا يَفُوحُ رِيحُهُ كُلَّ مَكَانٍ وَمَثَلُ مَنْ تَعَلَّمَهُ فَرَقَدَ وَهُوَ فِي جَوْفِهِ كَمَثَلِ جِرَابٍ أُوكِيَ عَلَى مِسْكٍ ‏"‏ ‏.‏\hadithno{217}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Learn the Qur'an, recite it and go to bed, for the likeness of the Qur'an and the one who learns it and acts upon it is that of a sack filled with musk, which spreads its fragrance everywhere. And the likeness of one who learns it then goes to bed with it in his heart is that of a sack that is tied up from which no fragrance comes out}}
\hadithdefcmd{ibnmajah}{218}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَامِرِ بْنِ وَاثِلَةَ أَبِي الطُّفَيْلِ، أَنَّ نَافِعَ بْنَ عَبْدِ الْحَارِثِ، لَقِيَ عُمَرَ بْنَ الْخَطَّابِ بِعُسْفَانَ - وَكَانَ عُمَرُ اسْتَعْمَلَهُ عَلَى مَكَّةَ - فَقَالَ عُمَرُ مَنِ اسْتَخْلَفْتَ عَلَى أَهْلِ الْوَادِي قَالَ اسْتَخْلَفْتُ عَلَيْهِمُ ابْنَ أَبْزَى ‏.‏ قَالَ وَمَنِ ابْنُ أَبْزَى قَالَ رَجُلٌ مِنْ مَوَالِينَا ‏.‏ قَالَ عُمَرُ فَاسْتَخْلَفْتَ عَلَيْهِمْ مَوْلًى قَالَ إِنَّهُ قَارِئٌ لِكِتَابِ اللَّهِ تَعَالَى عَالِمٌ بِالْفَرَائِضِ قَاضٍ ‏.‏ قَالَ عُمَرُ أَمَا إِنَّ نَبِيَّكُمْ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ يَرْفَعُ بِهَذَا الْكِتَابِ أَقْوَامًا وَيَضَعُ بِهِ آخَرِينَ ‏"‏ ‏.‏\hadithno{218}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Nafi' bin 'Abdul-Harith met 'Umar bin Khattab in 'Usfan, when 'Umar had appointed him as his governer in Makkah.:'Umar asked: "Whom have you appointed as your deputy over the people of the valley?" He said: "I have appointed Ibn Abza over them." 'Umar said: "Who is Ibn Abza?" Nafi' said: "One of our freed slaves." 'Umar said: "Have you appointed a freed slave over them?" Nafi' said: "He has great knowledge of the Book of Allah, is well versed in the rules of inheritance (Fara'id) and is a (good) judge." 'Umar said: "Did not your prophet say: 'Allah raises some people (in status) because of this book and brings others low because of it?}}
\hadithdefcmd{ibnmajah}{219}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ غَالِبٍ الْعَبَّادَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ زِيَادٍ الْبَحْرَانِيِّ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا أَبَا ذَرٍّ لأَنْ تَغْدُوَ فَتَعَلَّمَ آيَةً مِنْ كِتَابِ اللَّهِ خَيْرٌ لَكَ مِنْ أَنْ تُصَلِّيَ مِائَةَ رَكْعَةٍ وَلأَنْ تَغْدُوَ فَتَعَلَّمَ بَابًا مِنَ الْعِلْمِ عُمِلَ بِهِ أَوْ لَمْ يُعْمَلْ خَيْرٌ لَكَ مِنْ أَنْ تُصَلِّيَ أَلْفَ رَكْعَةٍ ‏"‏ ‏.‏\hadithno{219}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah said to me: 'O Abu Dharr! For you to come out in the morning and learn one Verse from the Book of Allah is better for you than praying one hundred Rak'ah, and for you to come out and learn a matter of knowledge, whether it is acted upon or not, is better for you than praying one thousand Rak'ah}}
\hadithdefcmd{ibnmajah}{220}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ ‏"‏ ‏.‏\hadithno{220}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'When Allah wills good for a person, He causes him to understand the religion}}
\hadithdefcmd{ibnmajah}{221}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مَرْوَانُ بْنُ جَنَاحٍ، عَنْ يُونُسَ بْنِ مَيْسَرَةَ بْنِ حَلْبَسٍ، أَنَّهُ حَدَّثَهُ قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ الْخَيْرُ عَادَةٌ وَالشَّرُّ لَجَاجَةٌ وَمَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ ‏"‏ ‏.‏\hadithno{221}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Yunus bin Maisarah bin Halbas said:"I heard Mu'awiyah bin Abu Sufyan narrating that the Messenger of Allah said: "Goodness is a (natural) habit while evil is a stubbornness (constant prodding from Satan). When Allah wills good for a person, He causes him to understand the religion}}
\hadithdefcmd{ibnmajah}{222}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا رَوْحُ بْنُ جَنَاحٍ أَبُو سَعْدٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ فَقِيهٌ وَاحِدٌ أَشَدُّ عَلَى الشَّيْطَانِ مِنْ أَلْفِ عَابِدٍ ‏"‏ ‏.‏\hadithno{222}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said: 'One Faqih (knowledgeable man) is more formidable against the Shaitan than one thousand devoted worshippers}}
\hadithdefcmd{ibnmajah}{223}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ عَاصِمِ بْنِ رَجَاءِ بْنِ حَيْوَةَ، عَنْ دَاوُدَ بْنِ جَمِيلٍ، عَنْ كَثِيرِ بْنِ قَيْسٍ، قَالَ كُنْتُ جَالِسًا عِنْدَ أَبِي الدَّرْدَاءِ فِي مَسْجِدِ دِمَشْقَ فَأَتَاهُ رَجُلٌ فَقَالَ يَا أَبَا الدَّرْدَاءِ أَتَيْتُكَ مِنَ الْمَدِينَةِ مَدِينَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لِحَدِيثٍ بَلَغَنِي أَنَّكَ تُحَدِّثُ بِهِ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ فَمَا جَاءَ بِكَ تِجَارَةٌ قَالَ لاَ ‏.‏ قَالَ وَلاَ جَاءَ بِكَ غَيْرُهُ قَالَ لاَ ‏.‏ قَالَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ سَلَكَ طَرِيقًا يَلْتَمِسُ فِيهِ عِلْمًا سَهَّلَ اللَّهُ لَهُ طَرِيقًا إِلَى الْجَنَّةِ وَإِنَّ الْمَلاَئِكَةَ لَتَضَعُ أَجْنِحَتَهَا رِضًا لِطَالِبِ الْعِلْمِ وَإِنَّ طَالِبَ الْعِلْمِ يَسْتَغْفِرُ لَهُ مَنْ فِي السَّمَاءِ وَالأَرْضِ حَتَّى الْحِيتَانِ فِي الْمَاءِ وَإِنَّ فَضْلَ الْعَالِمِ عَلَى الْعَابِدِ كَفَضْلِ الْقَمَرِ عَلَى سَائِرِ الْكَوَاكِبِ إِنَّ الْعُلَمَاءَ هُمْ وَرَثَةُ الأَنْبِيَاءِ إِنَّ الأَنْبِيَاءَ لَمْ يُوَرِّثُوا دِينَارًا وَلاَ دِرْهَمًا إِنَّمَا وَرَّثُوا الْعِلْمَ فَمَنْ أَخَذَهُ أَخَذَ بِحَظٍّ وَافِرٍ ‏"‏ ‏.‏\hadithno{223}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Kathir bin Qais said:"I was sitting with Abu Darda' in the mosque of Damascus when a man came to him and said: 'O Abu Darda', I have come to you from Al-Madinah, the city of the Messenger of Allah, for a Hadith which I have heard that you narrate from the Prophet.' He said: 'Did you not come for trade?' He said: 'No.' He said: 'Did you not come for anything else?' He said: 'No.' He said: 'I heard the Messenger of Allah say: "Whoever follows a path in the pursuit of knowledge, Allah will make easy for him a path to Paradise. The angels lower their wings in approval of the seeker of knowledge, and everyone in the heavens and on earth prays for forgiveness for the seeker of knowledge, even the fish in the sea. The superiority of the scholar over the worshipper is like the superiority of the moon above all other heavenly bodies. The scholars are the heirs of the Prophets, for the Prophets did not leave behind a Dinar or Dirham, rather they left behind knowledge, so whoever takes it has taken a great share}}
\hadithdefcmd{ibnmajah}{224}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَفْصُ بْنُ سُلَيْمَانَ، حَدَّثَنَا كَثِيرُ بْنُ شِنْظِيرٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ طَلَبُ الْعِلْمِ فَرِيضَةٌ عَلَى كُلِّ مُسْلِمٍ وَوَاضِعُ الْعِلْمِ عِنْدَ غَيْرِ أَهْلِهِ كَمُقَلِّدِ الْخَنَازِيرِ الْجَوْهَرَ وَاللُّؤْلُؤَ وَالذَّهَبَ ‏"‏ ‏.‏\hadithno{224}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:"Seeking knowledge is a duty upon every Muslim, and he who imparts knowledge to those who do not deserve it, is like one who puts a necklace of jewels, pearls and gold around the neck of swines}}
\hadithdefcmd{ibnmajah}{225}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ نَفَّسَ عَنْ مُؤْمِنٍ كُرْبَةً مِنْ كُرَبِ الدُّنْيَا نَفَّسَ اللَّهُ عَنْهُ كُرْبَةً مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ وَمَنْ سَتَرَ مُسْلِمًا سَتَرَهُ اللَّهُ فِي الدُّنْيَا وَالآخِرَةِ وَمَنْ يَسَّرَ عَلَى مُعْسِرٍ يَسَّرَ اللَّهُ عَلَيْهِ فِي الدُّنْيَا وَالآخِرَةِ وَاللَّهُ فِي عَوْنِ الْعَبْدِ مَا كَانَ الْعَبْدُ فِي عَوْنِ أَخِيهِ وَمَنْ سَلَكَ طَرِيقًا يَلْتَمِسُ فِيهِ عِلْمًا سَهَّلَ اللَّهُ لَهُ بِهِ طَرِيقًا إِلَى الْجَنَّةِ وَمَا اجْتَمَعَ قَوْمٌ فِي بَيْتٍ مِنْ بُيُوتِ اللَّهِ يَتْلُونَ كِتَابَ اللَّهِ وَيَتَدَارَسُونَهُ بَيْنَهُمْ إِلاَّ حَفَّتْهُمُ الْمَلاَئِكَةُ وَنَزَلَتْ عَلَيْهِمُ السَّكِينَةُ وَغَشِيَتْهُمُ الرَّحْمَةُ وَذَكَرَهُمُ اللَّهُ فِيمَنْ عِنْدَهُ وَمَنْ أَبْطَأَ بِهِ عَمَلُهُ لَمْ يُسْرِعْ بِهِ نَسَبُهُ ‏"‏ ‏.‏\hadithno{225}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever relieves a Muslim of some worldly distress, Allah will relieve him of some of the distress of the Day of Resurrection, and whoever conceals (the faults of) a Muslim, Allah will conceal him (his faults) in this world and the Day of Resurrection. And whoever relives the burden from a destitute person, Allah will relieve him in this world and the next. Allah will help His slave so long as His slave helps his brother. Whoever follows a path in pursuit of knowledge, Allah will make easy fro him a path to paradise. No people gather in one of the houses of Allah, reciting the Book of Allah and teaching it to one another, but the angels will surround them, tranquility will descend upon them, mercy will envelop them and Allah will mention them to those who are with Him. And whoever is hindered because of his bad deeds, his lineage will be of no avail to him}}
\hadithdefcmd{ibnmajah}{226}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ زِرِّ بْنِ حُبَيْشٍ، قَالَ أَتَيْتُ صَفْوَانَ بْنَ عَسَّالٍ الْمُرَادِيَّ فَقَالَ مَا جَاءَ بِكَ قُلْتُ أُنْبِطُ الْعِلْمَ ‏.‏ قَالَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا مِنْ خَارِجٍ خَرَجَ مِنْ بَيْتِهِ فِي طَلَبِ الْعِلْمِ إِلاَّ وَضَعَتْ لَهُ الْمَلاَئِكَةُ أَجْنِحَتَهَا رِضًا بِمَا يَصْنَعُ ‏"‏ ‏.‏\hadithno{226}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Zirr bin Hubaish said:"I went to Safwan bin 'Assal Al-Muradi and he said: 'What brought you here?' I said: 'I am seeking knowledge.' He said: 'I heard the Messenger of Allah say: "There is no one who goes out of his house in order to seek knowledge, but the angels lower their wings in approval of his action}}
\hadithdefcmd{ibnmajah}{227}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ حُمَيْدِ بْنِ صَخْرٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ جَاءَ مَسْجِدِي هَذَا لَمْ يَأْتِهِ إِلاَّ لِخَيْرٍ يَتَعَلَّمُهُ أَوْ يُعَلِّمُهُ فَهُوَ بِمَنْزِلَةِ الْمُجَاهِدِ فِي سَبِيلِ اللَّهِ وَمَنْ جَاءَ لِغَيْرِ ذَلِكَ فَهُوَ بِمَنْزِلَةِ الرَّجُلِ يَنْظُرُ إِلَى مَتَاعِ غَيْرِهِ ‏"‏ ‏.‏\hadithno{227}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"I heard the Messenger of Allah say: 'Whoever comes to this mosque of mine, and only comes for a good purpose, such as to learn or to teach, his status is like that of one who fights in Jihad in the cause of Allah. Whoever comes for any other purpose, his status is that of a man who is keeping an eye on other people's property}}
\hadithdefcmd{ibnmajah}{228}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا عُثْمَانُ بْنُ أَبِي عَاتِكَةَ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ عَلَيْكُمْ بِهَذَا الْعِلْمِ قَبْلَ أَنْ يُقْبَضَ وَقَبْضُهُ أَنْ يُرْفَعَ ‏"‏ ‏.‏ وَجَمَعَ بَيْنَ إِصْبَعَيْهِ الْوُسْطَى وَالَّتِي تَلِي الإِبْهَامَ هَكَذَا ثُمَّ قَالَ ‏"‏ الْعَالِمُ وَالْمُتَعَلِّمُ شَرِيكَانِ فِي الأَجْرِ وَلاَ خَيْرَ فِي سَائِرِ النَّاسِ ‏"‏ ‏.‏\hadithno{228}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah said:"The Messenger of Allah said: 'You must acquire this knowledge before it is taken away, and its taking away means that it will be lifted up.' He joined his middle finger and the one that next to the thumb like this, and said: 'The scholar and the seeker of knowledge will share the reward, and there is no good in the rest of the people}}
\hadithdefcmd{ibnmajah}{229}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا دَاوُدُ بْنُ الزِّبْرِقَانِ، عَنْ بَكْرِ بْنِ خُنَيْسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ذَاتَ يَوْمٍ مِنْ بَعْضِ حُجَرِهِ فَدَخَلَ الْمَسْجِدَ فَإِذَا هُوَ بِحَلْقَتَيْنِ إِحْدَاهُمَا يَقْرَءُونَ الْقُرْآنَ وَيَدْعُونَ اللَّهَ وَالأُخْرَى يَتَعَلَّمُونَ وَيُعَلِّمُونَ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلٌّ عَلَى خَيْرٍ هَؤُلاَءِ يَقْرَءُونَ الْقُرْآنَ وَيَدْعُونَ اللَّهَ فَإِنْ شَاءَ أَعْطَاهُمْ وَإِنْ شَاءَ مَنَعَهُمْ وَهَؤُلاَءِ يَتَعَلَّمُونَ وَيُعَلِّمُونَ وَإِنَّمَا بُعِثْتُ مُعَلِّمًا ‏"‏ ‏.‏ فَجَلَسَ مَعَهُمْ ‏.‏\hadithno{229}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah came out of one of his apartments one day and entered the mosque, where he saw two circles, one reciting Qur'an and supplicating to Allah, and the other learning and teaching. The Prophet said: 'Both of them are good. These people are reciting the Qur'an and supplicating to Allah, and if He wills He will give them, and if He wills He will withhold from them. And these people are learning and teaching. Verily I have been sent as a teacher.' Then he sat down with them}}
\hadithdefcmd{ibnmajah}{230}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا لَيْثُ بْنُ أَبِي سُلَيْمٍ، عَنْ يَحْيَى بْنِ عَبَّادٍ أَبِي هُبَيْرَةَ الأَنْصَارِيِّ، عَنْ أَبِيهِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ نَضَّرَ اللَّهُ امْرَأً سَمِعَ مَقَالَتِي فَبَلَّغَهَا فَرُبَّ حَامِلِ فِقْهٍ غَيْرِ فَقِيهٍ وَرُبَّ حَامِلِ فِقْهٍ إِلَى مَنْ هُوَ أَفْقَهُ مِنْهُ ‏"‏ ‏.‏ زَادَ فِيهِ عَلِيُّ بْنُ مُحَمَّدٍ ‏"‏ ثَلاَثٌ لاَ يُغِلُّ عَلَيْهِنَّ قَلْبُ امْرِئٍ مُسْلِمٍ إِخْلاَصُ الْعَمَلِ لِلَّهِ وَالنُّصْحُ لأَئِمَّةِ الْمُسْلِمِينَ وَلُزُومُ جَمَاعَتِهِمْ ‏"‏ ‏.‏\hadithno{230}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zaid bin Thabit that:The Messenger of Allah said: "May Allah cause his face to shine, the man who hears what I say and conveys it (to others). There are those who have knowledge but no understanding, and there may be those who convey knowledge to those who have more understanding of it than they do.' " (One of the narrators) 'Ali bin Muhammed added to it: "There are three things because of which hatred does not enter the heart of a Muslim: Sincerity in doing an action for the sake of Allah; being sincere towards the rulers of the Muslims; and adhering to the Jama'ah (main body of the Muslims)}}
\hadithdefcmd{ibnmajah}{231}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ السَّلاَمِ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ قَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِالْخَيْفِ مِنْ مِنًى فَقَالَ ‏ "‏ نَضَّرَ اللَّهُ امْرَأً سَمِعَ مَقَالَتِي فَبَلَّغَهَا فَرُبَّ حَامِلِ فِقْهٍ غَيْرِ فَقِيهٍ وَرُبَّ حَامِلِ فِقْهٍ إِلَى مَنْ هُوَ أَفْقَهُ مِنْهُ ‏"‏ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا خَالِي، يَعْلَى ح وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏\hadithno{231}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Muhammed bin Jubair bin Mut'im narrated that his father said:"The Messenger of Allah stood up at Khaif in Mina and said: 'May Allah cause his face to shine, the man who hears what I say and conveys it (to others). There are those who have knowledge but no understanding, and there may be those who convey knowledge to those who have more understanding of it than they do.'" (Hasan)Other chains with similar wording}}
\hadithdefcmd{ibnmajah}{232}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ نَضَّرَ اللَّهُ امْرَأً سَمِعَ مِنَّا حَدِيثًا فَبَلَّغَهُ فَرُبَّ مُبَلَّغٍ أَحْفَظُ مِنْ سَامِعٍ ‏"‏ ‏.‏\hadithno{232}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdur-Rahman bin 'Abdullah narrated from his father that:The Prophet said: "May Allah cause his face to shine, the man who hears a Hadith from us and conveys it, for perhaps the one to whom it is conveyed may remember it better than the one who (first) hears it}}
\hadithdefcmd{ibnmajah}{233}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، - أَمْلاَهُ عَلَيْنَا - حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، وَعَنْ رَجُلٍ، آخَرَ هُوَ أَفْضَلُ فِي نَفْسِي مِنْ عَبْدِ الرَّحْمَنِ عَنْ أَبِي بَكْرَةَ قَالَ خَطَبَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ النَّحْرِ فَقَالَ ‏ "‏ لِيُبَلِّغِ الشَّاهِدُ الْغَائِبَ فَإِنَّهُ رُبَّ مُبَلَّغٍ يُبَلَّغُهُ أَوْعَى لَهُ مِنْ سَامِعٍ ‏"‏ ‏.‏\hadithno{233}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Bakrah said:"The Messenger of Allah delivered a religious speech on the Day of Sacrifice and said: 'Let those who are present convey to those who are absent. For perhaps the one to whom it is conveyed will understand it better than the one who (first) hears it}}
\hadithdefcmd{ibnmajah}{234}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا النَّضْرُ بْنُ شُمَيْلٍ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، مُعَاوِيَةَ الْقُشَيْرِيِّ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَلاَ لِيُبَلِّغِ الشَّاهِدُ الْغَائِبَ ‏"‏ ‏.‏\hadithno{234}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father that his grandfather Mu'awiyah Al-Qushairi said:"The Messenger of Allah said: 'Let the one who is present convey to the one who is absent}}
\hadithdefcmd{ibnmajah}{235}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، حَدَّثَنِي قُدَامَةُ بْنُ مُوسَى، عَنْ مُحَمَّدِ بْنِ الْحُصَيْنِ التَّمِيمِيِّ، عَنْ أَبِي عَلْقَمَةَ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ يَسَارٍ، مَوْلَى ابْنِ عُمَرَ عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لِيُبَلِّغْ شَاهِدُكُمْ غَائِبَكُمْ ‏"‏ ‏.‏\hadithno{235}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah said: "Let those of you who are present convey it to those of you who are absent}}
\hadithdefcmd{ibnmajah}{236}{حَدَّثَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا مُبَشِّرُ بْنُ إِسْمَاعِيلَ الْحَلَبِيُّ، عَنْ مُعَانِ بْنِ رِفَاعَةَ، عَنْ عَبْدِ الْوَهَّابِ بْنِ بُخْتٍ الْمَكِّيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نَضَّرَ اللَّهُ عَبْدًا سَمِعَ مَقَالَتِي فَوَعَاهَا ثُمَّ بَلَّغَهَا عَنِّي فَرُبَّ حَامِلِ فِقْهٍ غَيْرِ فَقِيهٍ وَرُبَّ حَامِلِ فِقْهٍ إِلَى مَنْ هُوَ أَفْقَهُ مِنْهُ ‏"‏ ‏.‏\hadithno{236}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'May Allah cause to flourish a slave (of His) who hears my words and understands them, then he conveys them from me. There are those who have knowledge but no understanding, and there may be those who convey knowledge to those who may have more understanding of it than they do}}
\hadithdefcmd{ibnmajah}{237}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، أَنْبَأَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حُمَيْدٍ، حَدَّثَنَا حَفْصُ بْنُ عُبَيْدِ اللَّهِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِنَ النَّاسِ مَفَاتِيحَ لِلْخَيْرِ مَغَالِيقَ لِلشَّرِّ وَإِنَّ مِنَ النَّاسِ مَفَاتِيحَ لِلشَّرِّ مَغَالِيقَ لِلْخَيْرِ فَطُوبَى لِمَنْ جَعَلَ اللَّهُ مَفَاتِيحَ الْخَيْرِ عَلَى يَدَيْهِ وَوَيْلٌ لِمَنْ جَعَلَ اللَّهُ مَفَاتِيحَ الشَّرِّ عَلَى يَدَيْهِ ‏"‏ ‏.‏\hadithno{237}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'Some people open the door to good and close the door to evil, and some people open the door to evil and close the door to good. Glad tidings to those in whose hands Allah places they keys to good, and woe to those in whose hands Allah places the keys to evil}}
\hadithdefcmd{ibnmajah}{238}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ أَبُو جَعْفَرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ هَذَا الْخَيْرَ خَزَائِنُ وَلِتِلْكَ الْخَزَائِنِ مَفَاتِيحُ فَطُوبَى لِعَبْدٍ جَعَلَهُ اللَّهُ مِفْتَاحًا لِلْخَيْرِ مِغْلاَقًا لِلشَّرِّ وَوَيْلٌ لِعَبْدٍ جَعَلَهُ اللَّهُ مِفْتَاحًا لِلشَّرِّ مِغْلاَقًا لِلْخَيْرِ ‏"‏ ‏.‏\hadithno{238}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sahl bin Sa'd that:The Messenger of Allah said: "This goodness contains many treasures, and for those there are keys. So glad tidings to the one whom Allah makes a key to good and a lock for evil, and woe to the one whom Allah makes a key to evil and a lock to good}}
\hadithdefcmd{ibnmajah}{239}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، عَنْ عُثْمَانَ بْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّهُ لَيَسْتَغْفِرُ لِلْعَالِمِ مَنْ فِي السَّمَوَاتِ وَمَنْ فِي الأَرْضِ حَتَّى الْحِيتَانِ فِي الْبَحْرِ ‏"‏ ‏.‏\hadithno{239}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Dharr said:"I heard the Messenger of Allah say: 'Everyone in the universe, in the heavens and on earth, prays for forgiveness for the scholar, even the fish in the sea}}
\hadithdefcmd{ibnmajah}{240}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ عَلَّمَ عِلْمًا فَلَهُ أَجْرُ مَنْ عَمِلَ بِهِ لاَ يَنْقُصُ مِنْ أَجْرِ الْعَامِلِ ‏"‏ ‏.‏\hadithno{240}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sahl bin Mu'adh bin Anas narrated from his father that:The Prophet said: "Whoever teaches some knowledge will have the reward of the one who acts upon it, without that detracting from his reward in the slightest}}
\hadithdefcmd{ibnmajah}{241}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي كَرِيمَةَ الْحَرَّانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَيْرُ مَا يُخَلِّفُ الرَّجُلُ مِنْ بَعْدِهِ ثَلاَثٌ وَلَدٌ صَالِحٌ يَدْعُو لَهُ وَصَدَقَةٌ تَجْرِي يَبْلُغُهُ أَجْرُهَا وَعِلْمٌ يُعْمَلُ بِهِ مِنْ بَعْدِهِ ‏"‏ ‏. ‏ قَالَ أَبُو الْحَسَنِ وَحَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ بْنِ سِنَانٍ الرَّهَاوِيُّ، حَدَّثَنَا يَزِيدُ بْنُ سِنَانٍ، - يَعْنِي أَبَاهُ - حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ فُلَيْحِ بْنِ سُلَيْمَانَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{241}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Abu Qatadah narrated that his father said:"The Messenger of Allah said: 'The best things that a man can leave behind are three: A righteous son who will pray for him, ongoing charity whose reward will reach him, and knowledge which is acted upon after his death.'" (Hasan) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{242}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ وَهْبِ بْنِ عَطِيَّةَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مَرْزُوقُ بْنُ أَبِي الْهُذَيْلِ، حَدَّثَنِي الزُّهْرِيُّ، حَدَّثَنِي أَبُو عَبْدِ اللَّهِ الأَغَرُّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِمَّا يَلْحَقُ الْمُؤْمِنَ مِنْ عَمَلِهِ وَحَسَنَاتِهِ بَعْدَ مَوْتِهِ عِلْمًا عَلَّمَهُ وَنَشَرَهُ وَوَلَدًا صَالِحًا تَرَكَهُ وَمُصْحَفًا وَرَّثَهُ أَوْ مَسْجِدًا بَنَاهُ أَوْ بَيْتًا لاِبْنِ السَّبِيلِ بَنَاهُ أَوْ نَهْرًا أَجْرَاهُ أَوْ صَدَقَةً أَخْرَجَهَا مِنْ مَالِهِ فِي صِحَّتِهِ وَحَيَاتِهِ يَلْحَقُهُ مِنْ بَعْدِ مَوْتِهِ ‏"‏ ‏.‏\hadithno{242}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The rewards of the good deeds that will reach a believer after his death are: Knowledge which he taught and spread; a righteous son whom he leaves behind; a copy of the Qur'an that he leaves as a legacy; a mosque that he built; a house that he built for wayfarers; a canal that he dug; or charity that he gave during his lifetime when he was in good health. These deeds will reach him after his death}}
\hadithdefcmd{ibnmajah}{243}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ الْمَدَنِيُّ، حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ طَلْحَةَ، عَنِ الْحَسَنِ الْبَصْرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَفْضَلُ الصَّدَقَةِ أَنْ يَتَعَلَّمَ الْمَرْءُ الْمُسْلِمُ عِلْمًا ثُمَّ يُعَلِّمَهُ أَخَاهُ الْمُسْلِمَ ‏"‏ ‏.‏\hadithno{243}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "The best of charity is when a Muslim man gains knowledge, then he teaches it to his Muslim brother}}
\hadithdefcmd{ibnmajah}{244}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُوَيْدُ بْنُ عَمْرٍو، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ شُعَيْبِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِيهِ، قَالَ مَا رُئِيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْكُلُ مُتَّكِئًا قَطُّ وَلاَ يَطَأُ عَقِبَيْهِ رَجُلاَنِ ‏.‏ قَالَ أَبُو الْحَسَنِ وَحَدَّثَنَا خَازِمُ بْنُ يَحْيَى، حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْحَجَّاجِ السَّامِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، قَالَ أَبُو الْحَسَنِ وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ نَصْرٍ الْهَمْدَانِيُّ، صَاحِبُ الْقَفِيزِ حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، ‏.‏\hadithno{244}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Shu'aib bin 'Abdullah bin 'Amr that his father said:"The Messenger of Allah was never seen eating while reclining or making two men walk behind him." (Sahih) Other chains with the same meanings}}
\hadithdefcmd{ibnmajah}{245}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا مُعَانُ بْنُ رِفَاعَةَ، حَدَّثَنِي عَلِيُّ بْنُ يَزِيدَ، قَالَ سَمِعْتُ الْقَاسِمَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ أَبِي أُمَامَةَ، قَالَ مَرَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ فِي يَوْمٍ شَدِيدِ الْحَرِّ نَحْوَ بَقِيعِ الْغَرْقَدِ وَكَانَ النَّاسُ يَمْشُونَ خَلْفَهُ فَلَمَّا سَمِعَ صَوْتَ النِّعَالِ وَقَرَ ذَلِكَ فِي نَفْسِهِ فَجَلَسَ حَتَّى قَدَّمَهُمْ أَمَامَهُ لِئَلاَّ يَقَعَ فِي نَفْسِهِ شَىْءٌ مِنَ الْكِبْرِ ‏.‏\hadithno{245}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah said:"The Prophet walked on a very hot day towards Baqi' Al-Gharqad (graveyard of Al-Madinah), and the people were walking behind him. When he heard the sound of their shoes, it affected his soul so he sat down until he made them go ahead of him, lest that make him feel too proud}}
\hadithdefcmd{ibnmajah}{246}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ نُبَيْحٍ الْعَنَزِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا مَشَى مَشَى أَصْحَابُهُ أَمَامَهُ وَتَرَكُوا ظَهْرَهُ لِلْمَلاَئِكَةِ ‏.‏\hadithno{246}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrarted that Jabir bin 'Abdullah said:"When the Prophet walked, his Companions would walk in front of him, and he would leave his back for the angels}}
\hadithdefcmd{ibnmajah}{247}{حَدَّثَنَا مُحَمَّدُ بْنُ الْحَارِثِ بْنِ رَاشِدٍ الْمِصْرِيُّ، حَدَّثَنَا الْحَكَمُ بْنُ عَبْدَةَ، عَنْ أَبِي هَارُونَ الْعَبْدِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ سَيَأْتِيكُمْ أَقْوَامٌ يَطْلُبُونَ الْعِلْمَ فَإِذَا رَأَيْتُمُوهُمْ فَقُولُوا لَهُمْ مَرْحَبًا مَرْحَبًا بِوَصِيَّةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَاقْنُوهُمْ ‏"‏ ‏.‏ قُلْتُ لِلْحَكَمِ مَا اقْنُوهُمْ قَالَ عَلِّمُوهُمْ ‏.‏\hadithno{247}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri narrated that:The Messenger of Allah said: "People will come to you seeking knowledge. When you see them say to them, 'Welcome, welcome,' in obedience to the injunctions of the Messenger of Allah and instruct them in knowledge."(One of the narrators said) "I said to Al-Hakam: 'What is 'Iqnuhum?' He said: 'Instruct them}}
\hadithdefcmd{ibnmajah}{248}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا الْمُعَلَّى بْنُ هِلاَلٍ، عَنْ إِسْمَاعِيلَ، قَالَ دَخَلْنَا عَلَى الْحَسَنِ نَعُودُهُ حَتَّى مَلأْنَا الْبَيْتَ فَقَبَضَ رِجْلَيْهِ ثُمَّ قَالَ دَخَلْنَا عَلَى أَبِي هُرَيْرَةَ نَعُودُهُ حَتَّى مَلأْنَا الْبَيْتَ فَقَبَضَ رِجْلَيْهِ ثُمَّ قَالَ دَخَلْنَا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَتَّى مَلأْنَا الْبَيْتَ وَهُوَ مُضْطَجِعٌ لِجَنْبِهِ فَلَمَّا رَآنَا قَبَضَ رِجْلَيْهِ ثُمَّ قَالَ ‏ "‏ إِنَّهُ سَيَأْتِيكُمْ أَقْوَامٌ مِنْ بَعْدِي يَطْلُبُونَ الْعِلْمَ فَرَحِّبُوا بِهِمْ وَحَيُّوهُمْ وَعَلِّمُوهُمْ ‏"‏ ‏.‏ قَالَ فَأَدْرَكْنَا وَاللَّهِ أَقْوَامًا مَا رَحَّبُوا بِنَا وَلاَ حَيَّوْنَا وَلاَ عَلَّمُونَا إِلاَّ بَعْدَ أَنْ كُنَّا نَذْهَبُ إِلَيْهِمْ فَيَجْفُونَا ‏.‏\hadithno{248}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Isma'il said:"We entered upon Hasan to inquire after him until we filled the house. He tucked up his legs, the he (hasan) said: 'We entered upon Abu Hurairah to inquire after him until we filled the house. He (Abu Hurairah) tucked up his legs and said: "We entered upon the Messenger of Allah until we filled the house. He was lying on his side, but when he saw us he tucked up his legs then he said: 'After I am gone, there will come to you people seeking knowledge. Welcome them, greet them and teach them.'" (Maudu')A narrator said: By Allah! We came across some people who did not welcome us, greet us, nor teach us unil we used to go to them, then they treated us rudely}}
\hadithdefcmd{ibnmajah}{249}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ الْعَنْقَزِيُّ، أَنْبَأَنَا سُفْيَانُ، عَنْ أَبِي هَارُونَ الْعَبْدِيِّ، قَالَ كُنَّا إِذَا أَتَيْنَا أَبَا سَعِيدٍ الْخُدْرِيَّ قَالَ مَرْحَبًا بِوَصِيَّةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لَنَا ‏ "‏ إِنَّ النَّاسَ لَكُمْ تَبَعٌ وَإِنَّهُمْ سَيَأْتُونَكُمْ مِنْ أَقْطَارِ الأَرْضِ يَتَفَقَّهُونَ فِي الدِّينِ فَإِذَا جَاءُوكُمْ فَاسْتَوْصُوا بِهِمْ خَيْرًا ‏"‏ ‏.‏\hadithno{249}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Harun Al-'Abdi said:"When we came to Abu Sa'eed Al-Khudri, he would say: 'Welcome, in accordance with the injunction of the Messenger of Allah, for the Messenger of Allah said to us: "The people will follow you; they will come to you from all parts of the earth seeking to understand the religion. So when they come to you, take care of them}}
\hadithdefcmd{ibnmajah}{250}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ مِنْ دُعَاءِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عِلْمٍ لاَ يَنْفَعُ وَمِنْ دُعَاءٍ لاَ يُسْمَعُ وَمَنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ ‏"‏ ‏.‏\hadithno{250}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"One of the supplications that the Prophet used to say was: 'Allahumma, inni a'udhu bika min 'ilmin la yanfa'u, wa mindu'a'in la yusma'u, wa min qalbin la yakhsha'u, wa min nafsin la tashba'u [O Allah, I seek refuge with You from knowledge that is of no benefit, from a supplication that is not heard, from a heart that does not fear (You) and from a soul that is not satisfied}}
\hadithdefcmd{ibnmajah}{251}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ مُحَمَّدِ بْنِ ثَابِتٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ اللَّهُمَّ انْفَعْنِي بِمَا عَلَّمْتَنِي وَعَلِّمْنِي مَا يَنْفَعُنِي وَزِدْنِي عِلْمًا وَالْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ ‏"‏ ‏.‏\hadithno{251}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah used to say: 'Allahummanfa'ni bima 'allamtani, wa 'allimnima yanfa'uni, wa zidni 'ilman. Wal-hamdu Lillahi 'ala kulli hal. [O Allah, benefit me by that which You have taught me, and teach me that which will benefit me, and increase my knowledge. Praise is to Allah in all circumstances]}}
\hadithdefcmd{ibnmajah}{252}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، وَسُرَيْجُ بْنُ النُّعْمَانِ، قَالاَ حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَعْمَرٍ أَبِي طُوَالَةَ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَعَلَّمَ عِلْمًا مِمَّا يُبْتَغَى بِهِ وَجْهُ اللَّهِ لاَ يَتَعَلَّمُهُ إِلاَّ لِيُصِيبَ بِهِ عَرَضًا مِنَ الدُّنْيَا لَمْ يَجِدْ عَرْفَ الْجَنَّةِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ يَعْنِي رِيحَهَا ‏.‏ قَالَ أَبُو الْحَسَنِ أَنْبَأَنَا أَبُو حَاتِمٍ، حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{252}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever acquires knowledge by which the pleasure of Allah is sought, but he only acquires it for the purpose of worldly gain, will not smell the fragrance of Paradise on the Day of Resurrection.'" (Hasan) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{253}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَمَّادُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا أَبُو كَرِبٍ الأَزْدِيُّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ طَلَبَ الْعِلْمَ لِيُمَارِيَ بِهِ السُّفَهَاءَ أَوْ لِيُبَاهِيَ بِهِ الْعُلَمَاءَ أَوْ لِيَصْرِفَ وُجُوهَ النَّاسِ إِلَيْهِ فَهُوَ فِي النَّارِ ‏"‏ ‏.‏\hadithno{253}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah said: "Whoever seeks knowledge in order to argue with the foolish, or to show off before the scholars, or to attract people's attention, will be in Hell}}
\hadithdefcmd{ibnmajah}{254}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَنْبَأَنَا يَحْيَى بْنُ أَيُّوبَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَعَلَّمُوا الْعِلْمَ لِتُبَاهُوا بِهِ الْعُلَمَاءَ وَلاَ لِتُمَارُوا بِهِ السُّفَهَاءَ وَلاَ تَخَيَّرُوا بِهِ الْمَجَالِسَ فَمَنْ فَعَلَ ذَلِكَ فَالنَّارُ النَّارُ ‏"‏ ‏.‏\hadithno{254}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:The Prophet said: "Do not seek knowledge in order to show off in front of the scholars, or to argue with the foolish, and do not choose the best seat in a gathering, due to it (i.e. the knowledge which you have learned) for whoever does that, the Fire, the Fire (awaits him)}}
\hadithdefcmd{ibnmajah}{255}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ الْكِنْدِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ أُنَاسًا مِنْ أُمَّتِي سَيَتَفَقَّهُونَ فِي الدِّينِ وَيَقْرَءُونَ الْقُرْآنَ وَيَقُولُونَ نَأْتِي الأُمَرَاءَ فَنُصِيبُ مِنْ دُنْيَاهُمْ وَنَعْتَزِلُهُمْ بِدِينِنَا ‏.‏ وَلاَ يَكُونُ ذَلِكَ كَمَا لاَ يُجْتَنَى مِنَ الْقَتَادِ إِلاَّ الشَّوْكُ كَذَلِكَ لاَ يُجْتَنَى مِنْ قُرْبِهِمْ إِلاَّ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ الصَّبَّاحِ كَأَنَّهُ يَعْنِي الْخَطَايَا ‏.‏\hadithno{255}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that:The Prophet said: "There will be some people among my Ummah (nation) who will gain knowledge of the religion, and they will recite Qur'an, and will say: 'We come to the rulers so that we may have some share of their worldly wealth, and we will make sure that our religious commitment is not affected,' but that will not be the case. Just as nothing can be harvested from the Qatad except thorns, so nothing can be gained from being close to them except (sins).'" (Da'if)(One of the narrators) Muhammed bin As-Sabbah said: "It is as if he meant, 'except sins}}
\hadithdefcmd{ibnmajah}{256}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدٍ الْمُحَارِبِيُّ، حَدَّثَنَا عَمَّارُ بْنُ سَيْفٍ، عَنْ أَبِي مُعَاذٍ الْبَصْرِيِّ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ عَمَّارِ بْنِ سَيْفٍ، عَنْ أَبِي مُعَاذٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ تَعَوَّذُوا بِاللَّهِ مِنْ جُبِّ الْحُزْنِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا جُبُّ الْحُزْنِ قَالَ ‏"‏ وَادٍ فِي جَهَنَّمَ يَتَعَوَّذُ مِنْهُ جَهَنَّمُ كُلَّ يَوْمٍ أَرْبَعَمِائَةِ مَرَّةٍ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَنْ يَدْخُلُهُ قَالَ ‏"‏ أُعِدَّ لِلْقُرَّاءِ الْمُرَائِينَ بِأَعْمَالِهِمْ وَإِنَّ مِنْ أَبْغَضِ الْقُرَّاءِ إِلَى اللَّهِ الَّذِينَ يَزُورُونَ الأُمَرَاءَ ‏"‏ ‏.‏ قَالَ الْمُحَارِبِيُّ الْجَوَرَةَ ‏.‏ قَالَ أَبُو الْحَسَنِ حَدَّثَنَا حَازِمُ بْنُ يَحْيَى حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَمُحَمَّدُ بْنُ نُمَيْرٍ قَالَا حَدَّثَنَا ابْنُ نُمَيْرٍ عَنْ مُعَاوِيَةَ النَّصْرِيِّ وَكَانَ ثِقَةً ثُمَّ ذَكَرَ الْحَدِيثَ نَحْوَهُ بِإِسْنَادِهِ ‏.‏ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَصْرٍ، حَدَّثَنَا أَبُو غَسَّانَ، مَالِكُ بْنُ إِسْمَاعِيلَ حَدَّثَنَا عَمَّارُ بْنُ سَيْفٍ، عَنْ أَبِي مُعَاذٍ، ‏.‏ قَالَ مَالِكُ بْنُ إِسْمَاعِيلَ قَالَ عَمَّارٌ لاَ أَدْرِي مُحَمَّدٌ أَوْ أَنَسُ بْنُ سِيرِينَ ‏.‏\hadithno{256}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Seek refuge with Allah from the pit of grief.' They said: 'O Messenger of Allah, what is the pit of grief?' He said: 'A valley in Hell from which Hell itself seeks refuge four hundred times each day.' It was said: 'O Messenger of Allah, who will enter it?' He said: 'It has been prepared for reciters of the Qur'an who want to show off their deeds. The most hateful of reciters of the Qur'an to Allah are those who visit the rulers.'" (Da'if) Other chains of narrators}}
\hadithdefcmd{ibnmajah}{257}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَالْحُسَيْنُ بْنُ عَبْدِ الرَّحْمَنِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُعَاوِيَةَ النَّصْرِيِّ، عَنْ نَهْشَلٍ، عَنِ الضَّحَّاكِ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ لَوْ أَنَّ أَهْلَ الْعِلْمِ، صَانُوا الْعِلْمَ وَوَضَعُوهُ عِنْدَ أَهْلِهِ لَسَادُوا بِهِ أَهْلَ زَمَانِهِمْ وَلَكِنَّهُمْ بَذَلُوهُ لأَهْلِ الدُّنْيَا لِيَنَالُوا بِهِ مِنْ دُنْيَاهُمْ فَهَانُوا عَلَيْهِمْ سَمِعْتُ نَبِيَّكُمْ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ جَعَلَ الْهُمُومَ هَمًّا وَاحِدًا هَمَّ آخِرَتِهِ كَفَاهُ اللَّهُ هَمَّ دُنْيَاهُ وَمَنْ تَشَعَّبَتْ بِهِ الْهُمُومُ فِي أَحْوَالِ الدُّنْيَا لَمْ يُبَالِ اللَّهُ فِي أَىِّ أَوْدِيَتِهَا هَلَكَ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ حَدَّثَنَا خَازِمُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ مُعَاوِيَةَ النَّصْرِيِّ، - وَكَانَ ثِقَةً - ثُمَّ ذَكَرَ الْحَدِيثَ نَحْوَهُ بِإِسْنَادِهِ ‏.‏\hadithno{257}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"If the people of knowledge had taken care of it and presented it only to those who cared for it, they would have become the leaders of their age by virtue of that. But they squandered it on the people of wealth and status in this world in order to gain some worldly benefit, so the people of wealth and status began to look down on them. I heard your Prophet say: 'Whoever focuses all his concerns on one issue, the concerns of the Hereafter, Allah will suffice him and spare him the worries of this world. But whoever wanders off in concern over different worldly issues, Allah will not care in which of these valleys he is destroyed.'" (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{258}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ، وَأَبُو بَدْرٍ عَبَّادُ بْنُ الْوَلِيدِ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ الْهُنَائِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ الْهُنَائِيُّ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ خَالِدِ بْنِ دُرَيْكٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ طَلَبَ الْعِلْمَ لِغَيْرِ اللَّهِ أَوْ أَرَادَ بِهِ غَيْرَ اللَّهِ فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{258}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that:The Prophet said: "Whoever seeks knowledge for a reason other than the sake of Allah, or intends it for a purpose other than for the sake of Allah, let him take his place in hell}}
\hadithdefcmd{ibnmajah}{259}{حَدَّثَنَا أَحْمَدُ بْنُ عَاصِمٍ الْعَبَّادَانِيُّ، حَدَّثَنَا بَشِيرُ بْنُ مَيْمُونٍ، قَالَ سَمِعْتُ أَشْعَثَ بْنَ سَوَّارٍ، عَنِ ابْنِ سِيرِينَ، عَنْ حُذَيْفَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ تَعَلَّمُوا الْعِلْمَ لِتُبَاهُوا بِهِ الْعُلَمَاءَ أَوْ لِتُمَارُوا بِهِ السُّفَهَاءَ أَوْ لِتَصْرِفُوا وُجُوهَ النَّاسِ إِلَيْكُمْ فَمَنْ فَعَلَ ذَلِكَ فَهُوَ فِي النَّارِ ‏"‏ ‏.‏\hadithno{259}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Hudhaifah said:"I heard the Messenger of Allah say: 'Do not acquire knowledge in order to show off before the scholars, or to argue with the foolish, or to attract people's attention, for whoever does that will be in Hell}}
\hadithdefcmd{ibnmajah}{260}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، أَنْبَأَنَا وَهْبُ بْنُ إِسْمَاعِيلَ الأَسَدِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْمَقْبُرِيُّ، عَنْ جَدِّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَعَلَّمَ الْعِلْمَ لِيُبَاهِيَ بِهِ الْعُلَمَاءَ وَيُمَارِيَ بِهِ السُّفَهَاءَ وَيَصْرِفَ بِهِ وُجُوهَ النَّاسِ إِلَيْهِ أَدْخَلَهُ اللَّهُ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{260}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever seeks knowledge in order to argue with the foolish, or to show off before the scholars, or to attract people's attention, Allah will admit him to Hell}}
\hadithdefcmd{ibnmajah}{261}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا عِمَارَةُ بْنُ زَاذَانَ، حَدَّثَنَا عَلِيُّ بْنُ الْحَكَمِ، حَدَّثَنَا عَطَاءٌ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا مِنْ رَجُلٍ يَحْفَظُ عِلْمًا فَيَكْتُمُهُ إِلاَّ أُتِيَ بِهِ يَوْمَ الْقِيَامَةِ مُلْجَمًا بِلِجَامٍ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ - أَىِ الْقَطَّانُ - وَحَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا عِمَارَةُ بْنُ زَاذَانَ، فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو الْحَسَنِ أَيْضًا وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا عِمَارَةُ بْنُ زَاذَانَ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{261}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "There is no man who memorizes knowledge then conceals it, but he will be brought forth on the Day of Resurrection bridled with reins of fire." (Hasan) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{262}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، مُحَمَّدُ بْنُ عُثْمَانَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ الأَعْرَجِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ وَاللَّهِ لَوْلاَ آيَتَانِ فِي كِتَابِ اللَّهِ تَعَالَى مَا حَدَّثْتُ عَنْهُ - يَعْنِي عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ - شَيْئًا أَبَدًا لَوْلاَ قَوْلُ اللَّهِ ‏\{إِنَّ الَّذِينَ يَكْتُمُونَ مَا أَنْزَلَ اللَّهُ مِنَ الْكِتَابِ\}‏ إِلَى آخِرِ الآيَتَيْنِ ‏.‏\hadithno{262}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Abdur-Rahman bin Hurmuz Al-A'raj heard Abu Hurairah say:"By Allah, were it not for two Verses in the Book of Allah, I would never have narrated anything from him, meaning from the Prophet, were it not for the Words of Allah: Verily, those who conceal what Allah has sent down of the Book, and purchase a small gain therewith (of worldly things), they eat into their bellies nothing but fire. Allah will not speak to them on the Day of Resurrection, nor purify them, and theirs will be a painful torment. Those are they who have purchased error at the price of guidance, and torment at the price of forgiveness. So how bold they are (for evil deeds which will push them) to the Fire}}
\hadithdefcmd{ibnmajah}{263}{حَدَّثَنَا الْحُسَيْنُ بْنُ أَبِي السَّرِيِّ الْعَسْقَلاَنِيُّ، حَدَّثَنَا خَلَفُ بْنُ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ السَّرِيِّ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا لَعَنَ آخِرُ هَذِهِ الأُمَّةِ أَوَّلَهَا فَمَنْ كَتَمَ حَدِيثًا فَقَدْ كَتَمَ مَا أَنْزَلَ اللَّهُ ‏"‏ ‏.‏\hadithno{263}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah said: 'When the last people of this Ummah curse the first, (at that time) whoever conceals a Hadith will be concealing what Allah has revealed.'" (Maudu)}}
\hadithdefcmd{ibnmajah}{264}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا الْهَيْثَمُ بْنُ جَمِيلٍ، حَدَّثَنِي عُمَرُ بْنُ سُلَيْمٍ، حَدَّثَنَا يُوسُفُ بْنُ إِبْرَاهِيمَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ سُئِلَ عَنْ عِلْمٍ فَكَتَمَهُ أُلْجِمَ يَوْمَ الْقِيَامَةِ بِلِجَامٍ مِنْ نَارٍ ‏"‏ ‏.‏\hadithno{264}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Yusuf bin Ibrahim said:'I heard Anas bin Malik say: "I heard the Messenger of Allah say: "Whoever is asked about knowledge and conceals it, it will be bridled on the Day of Resurrection with reins of fire}}
\hadithdefcmd{ibnmajah}{265}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ حِبَّانَ بْنِ وَاقِدٍ الثَّقَفِيُّ أَبُو إِسْحَاقَ الْوَاسِطِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَاصِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ دَابٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَتَمَ عِلْمًا مِمَّا يَنْفَعُ اللَّهُ بِهِ فِي أَمْرِ النَّاسِ فِي الدِّينِ أَلْجَمَهُ اللَّهُ يَوْمَ الْقِيَامَةِ بِلِجَامٍ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{265}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah said: 'Whoever conceals knowledge which Allah has made beneficial for mankind's affairs of religion, Allah will bridle him with reins of fire on the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{266}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَفْصِ بْنِ هِشَامِ بْنِ زَيْدِ بْنِ أَنَسِ بْنِ مَالِكٍ، حَدَّثَنَا أَبُو إِبْرَاهِيمَ، إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الْكَرَابِيسِيُّ عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ سُئِلَ عَنْ عِلْمٍ يَعْلَمُهُ فَكَتَمَهُ أُلْجِمَ يَوْمَ الْقِيَامَةِ بِلِجَامٍ مِنْ نَارٍ ‏"‏ ‏.‏\hadithno{266}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever is asked about knowledge that he has and he conceals it, will be bridled on the Day of Resurrection with reins of fire}}
