% Auto-generated chapter 1 for tirmidhi
% Hadiths in this chapter: 148

\hadithdefcmd{tirmidhi}{1}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، ح وَحَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُقْبَلُ صَلاَةٌ بِغَيْرِ طُهُورٍ وَلاَ صَدَقَةٌ مِنْ غُلُولٍ ‏"‏ ‏.‏ قَالَ هَنَّادٌ فِي حَدِيثِهِ ‏"‏ إِلاَّ بِطُهُورٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا الْحَدِيثُ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ وَأَحْسَنُ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي الْمَلِيحِ عَنْ أَبِيهِ وَأَبِي هُرَيْرَةَ وَأَنَسٍ ‏.‏ وَأَبُو الْمَلِيحِ بْنُ أُسَامَةَ اسْمُهُ عَامِرٌ وَيُقَالُ زَيْدُ بْنُ أُسَامَةَ بْنِ عُمَيْرٍ الْهُذَلِيُّ ‏.‏\hadithno{1}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn `Umar narrated that:the Prophet said: "Salat will not be accepted without purification, nor Charity from Ghulul." Hannad said in his narration, "except with purification" [Abu `Eisa said: This Hadith is the most correct thing on this topic, and the best. There are also narrations on this topic from Abu Al-Malih, from his father; and Abu Hurairah and Anas. And Abu Al-Malih bin Usamah's name is `Amir, and they also say it was Zaid bin Usamah bin `Umair Al-Hudhali]}}
\hadithdefcmd{tirmidhi}{2}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى الْقَزَّازُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، ح وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا تَوَضَّأَ الْعَبْدُ الْمُسْلِمُ أَوِ الْمُؤْمِنُ فَغَسَلَ وَجْهَهُ خَرَجَتْ مِنْ وَجْهِهِ كُلُّ خَطِيئَةٍ نَظَرَ إِلَيْهَا بِعَيْنَيْهِ مَعَ الْمَاءِ أَوْ مَعَ آخِرِ قَطْرِ الْمَاءِ أَوْ نَحْوِ هَذَا وَإِذَا غَسَلَ يَدَيْهِ خَرَجَتْ مِنْ يَدَيْهِ كُلُّ خَطِيئَةٍ بَطَشَتْهَا يَدَاهُ مَعَ الْمَاءِ أَوْ مَعَ آخِرِ قَطْرِ الْمَاءِ حَتَّى يَخْرُجَ نَقِيًّا مِنَ الذُّنُوبِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ حَدِيثُ مَالِكٍ عَنْ سُهَيْلٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَأَبُو صَالِحٍ وَالِدُ سُهَيْلٍ هُوَ أَبُو صَالِحٍ السَّمَّانُ وَاسْمُهُ ذَكْوَانُ ‏.‏ وَأَبُو هُرَيْرَةَ اخْتُلِفَ فِي اسْمِهِ فَقَالُوا عَبْدُ شَمْسٍ وَقَالُوا عَبْدُ اللَّهِ بْنُ عَمْرٍو وَهَكَذَا قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ وَهُوَ الأَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُثْمَانَ بْنِ عَفَّانَ وَثَوْبَانَ وَالصُّنَابِحِيِّ وَعَمْرِو بْنِ عَبَسَةَ وَسَلْمَانَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَالصُّنَابِحِيُّ الَّذِي رَوَى عَنْ أَبِي بَكْرٍ الصِّدِّيقِ لَيْسَ لَهُ سَمَاعٌ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ عُسَيْلَةَ وَيُكْنَى أَبَا عَبْدِ اللَّهِ رَحَلَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُبِضَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ فِي الطَّرِيقِ وَقَدْ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَحَادِيثَ ‏.‏ وَالصُّنَابِحُ بْنُ الأَعْسَرِ الأَحْمَسِيُّ صَاحِبُ النَّبِيِّ صلى الله عليه وسلم يُقَالُ لَهُ الصُّنَابِحِيُّ أَيْضًا وَإِنَّمَا حَدِيثُهُ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنِّي مُكَاثِرٌ بِكُمُ الأُمَمَ فَلاَ تَقْتَتِلُنَّ بَعْدِي ‏"‏ ‏.‏\hadithno{2}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "When a Muslim, or believer, performs Wudu', washing his face, every evil that he looked at with his eyes leaves with the water - or with the last drop of water, or an expression similar to that - and when he washes his hands, every evil he did with his hands leaves with the water - or with the last drop of water - until he becomes free of sin}}
\hadithdefcmd{tirmidhi}{3}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مِفْتَاحُ الصَّلاَةِ الطُّهُورُ وَتَحْرِيمُهَا التَّكْبِيرُ وَتَحْلِيلُهَا التَّسْلِيمُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا الْحَدِيثُ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ وَأَحْسَنُ ‏.‏ وَعَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَقِيلٍ هُوَ صَدُوقٌ وَقَدْ تَكَلَّمَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ مِنْ قِبَلِ حِفْظِهِ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ كَانَ أَحْمَدُ بْنُ حَنْبَلٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ وَالْحُمَيْدِيُّ يَحْتَجُّونَ بِحَدِيثِ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ ‏.‏ قَالَ مُحَمَّدٌ وَهُوَ مُقَارِبُ الْحَدِيثِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي سَعِيدٍ ‏.‏\hadithno{3}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ali narrated that :the Prophet, said: "The key to Salat is the purification, its Tahrlm is the Takblr, and its Tahlil is the Taslim}}
\hadithdefcmd{tirmidhi}{4}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ زَنْجَوَيْهِ الْبَغْدَادِيُّ وَغَيْرُ وَاحِدٍ قَالَ حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ قَرْمٍ، عَنْ أَبِي يَحْيَى الْقَتَّاتِ، عَنْ مُجَاهِدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، رضى الله عنهما قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِفْتَاحُ الْجَنَّةِ الصَّلاَةُ وَمِفْتَاحُ الصَّلاَةِ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{4}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin 'Abdullah, may Allah be pleased with them, narrated that :Allah's Messenger said: "The key to Paradise is Salat, and the key to Salat is Wudu}}
\hadithdefcmd{tirmidhi}{5}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ قَالَ شُعْبَةُ وَقَدْ قَالَ مَرَّةً أُخْرَى أَعُوذُ بِكَ مِنَ الْخُبْثِ وَالْخَبِيثِ أَوِ الْخُبُثِ وَالْخَبَائِثِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَزَيْدِ بْنِ أَرْقَمَ وَجَابِرٍ وَابْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ وَأَحْسَنُ ‏.‏ وَحَدِيثُ زَيْدِ بْنِ أَرْقَمَ فِي إِسْنَادِهِ اضْطِرَابٌ رَوَى هِشَامٌ الدَّسْتَوَائِيُّ وَسَعِيدُ بْنُ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ فَقَالَ سَعِيدٌ عَنِ الْقَاسِمِ بْنِ عَوْفٍ الشَّيْبَانِيِّ عَنْ زَيْدِ بْنِ أَرْقَمَ ‏.‏ وَقَالَ هِشَامٌ الدَّسْتَوَائِيُّ عَنْ قَتَادَةَ عَنْ زَيْدِ بْنِ أَرْقَمَ ‏.‏ وَرَوَاهُ شُعْبَةُ وَمَعْمَرٌ عَنْ قَتَادَةَ عَنِ النَّضْرِ بْنِ أَنَسٍ فَقَالَ شُعْبَةُ عَنْ زَيْدِ بْنِ أَرْقَمَ ‏.‏ وَقَالَ مَعْمَرٌ عَنِ النَّضْرِ بْنِ أَنَسٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى سَأَلْتُ مُحَمَّدًا عَنْ هَذَا فَقَالَ يُحْتَمَلُ أَنْ يَكُونَ قَتَادَةُ رَوَى عَنْهُمَا جَمِيعًا ‏.‏\hadithno{5}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih Bukhari And Muslim}\hadithtrans{Anas bin Malik said:"When the Prophet entered the toilet he would say: 'O Allah Indeed I seek refuge in You.'" Shu'bah (one of the narrators) said: "Another time he said: 'I seek refuge in You from AI-Khubthi and al-Khablth.' Or: 'Al-Khubthi and Al-Khaba'ith}}
\hadithdefcmd{tirmidhi}{6}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ الْبَصْرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ الْخَلاَءَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْخُبْثِ وَالْخَبَائِثِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{6}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik said:"When the Prophet would enter the toilet 'He said: "O Allah! Indeed I seek refuge in You from Al-Khubith and Al- Khaba'ith}}
\hadithdefcmd{tirmidhi}{7}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، عَنْ إِسْرَائِيلَ بْنِ يُونُسَ، عَنْ يُوسُفَ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا خَرَجَ مِنَ الْخَلاَءِ قَالَ ‏ "‏ غُفْرَانَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِسْرَائِيلَ عَنْ يُوسُفَ بْنِ أَبِي بُرْدَةَ ‏.‏ وَأَبُو بُرْدَةَ بْنُ أَبِي مُوسَى اسْمُهُ عَامِرُ بْنُ عَبْدِ اللَّهِ بْنِ قَيْسٍ الأَشْعَرِيُّ ‏.‏ وَلاَ نَعْرِفُ فِي هَذَا الْبَابِ إِلاَّ حَدِيثَ عَائِشَةَ رضى الله عنها عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{7}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah, [may Allah be pleased with her] said:"When the Prophet would exit the toilet he would say: 'Ghufranak}}
\hadithdefcmd{tirmidhi}{8}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَتَيْتُمُ الْغَائِطَ فَلاَ تَسْتَقْبِلُوا الْقِبْلَةَ بِغَائِطٍ وَلاَ بَوْلٍ وَلاَ تَسْتَدْبِرُوهَا وَلَكِنْ شَرِّقُوا أَوْ غَرِّبُوا ‏"‏ ‏.‏ فَقَالَ أَبُو أَيُّوبَ فَقَدِمْنَا الشَّأْمَ فَوَجَدْنَا مَرَاحِيضَ قَدْ بُنِيَتْ مُسْتَقْبَلَ الْقِبْلَةِ فَنَنْحَرِفُ عَنْهَا وَنَسْتَغْفِرُ اللَّهَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ جَزْءٍ الزُّبَيْدِيِّ وَمَعْقِلِ بْنِ أَبِي الْهَيْثَمِ وَيُقَالُ مَعْقِلُ بْنُ أَبِي مَعْقِلٍ وَأَبِي أُمَامَةَ وَأَبِي هُرَيْرَةَ وَسَهْلِ بْنِ حُنَيْفٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي أَيُّوبَ أَحْسَنُ شَيْءٍ فِي هَذَا الْبَابِ وَأَصَحُّ ‏.‏ وَأَبُو أَيُّوبَ اسْمُهُ خَالِدُ بْنُ زَيْدٍ ‏.‏ وَالزُّهْرِيُّ اسْمُهُ مُحَمَّدُ بْنُ مُسْلِمِ بْنِ عُبَيْدِ اللَّهِ بْنِ شِهَابٍ الزُّهْرِيُّ وَكُنْيَتُهُ أَبُو بَكْرٍ ‏.‏ قَالَ أَبُو الْوَلِيدِ الْمَكِّيُّ قَالَ أَبُو عَبْدِ اللَّهِ مُحَمَّدُ بْنُ إِدْرِيسَ الشَّافِعِيُّ إِنَّمَا مَعْنَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ تَسْتَقْبِلُوا الْقِبْلَةَ بِغَائِطٍ وَلاَ بِبَوْلٍ وَلاَ تَسْتَدْبِرُوهَا ‏"‏ ‏.‏ إِنَّمَا هَذَا فِي الْفَيَافِي وَأَمَّا فِي الْكُنُفِ الْمَبْنِيَّةِ لَهُ رُخْصَةٌ فِي أَنْ يَسْتَقْبِلَهَا ‏.‏ وَهَكَذَا قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ ‏.‏ وَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ رَحِمَهُ اللَّهُ إِنَّمَا الرُّخْصَةُ مِنَ النَّبِيِّ صلى الله عليه وسلم فِي اسْتِدْبَارِ الْقِبْلَةِ بِغَائِطٍ أَوْ بَوْلٍ وَأَمَّا اسْتِقْبَالُ الْقِبْلَةِ فَلاَ يَسْتَقْبِلُهَا ‏.‏ كَأَنَّهُ لَمْ يَرَ فِي الصَّحْرَاءِ وَلاَ فِي الْكُنُفِ أَنْ يَسْتَقْبِلَ الْقِبْلَةَ ‏.‏\hadithno{8}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Ayyub Al-Ansari narrated that :Allah's Messenger said: "When one of you arrives to defecate, then let none of you face the Qiblah while defecating, nor while urinating. And do not have your back towards it, but have it east of you or west of you}}
\hadithdefcmd{tirmidhi}{9}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ أَبَانَ بْنِ صَالِحٍ، عَنْ مُجَاهِدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ نَسْتَقْبِلَ الْقِبْلَةَ بِبَوْلٍ فَرَأَيْتُهُ قَبْلَ أَنْ يُقْبَضَ بِعَامٍ يَسْتَقْبِلُهَا ‏.‏ وَفِي الْبَابِ عَنْ أَبِي قَتَادَةَ وَعَائِشَةَ وَعَمَّارِ بْنِ يَاسِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ فِي هَذَا الْبَابِ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{9}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Jabir bin Abdullah said:"The Prophet prohibited us from facing the Qiblah while urinating. Then i saw him facing it a year before he died}}
\hadithdefcmd{tirmidhi}{10}{وَقَدْ رَوَى هَذَا الْحَدِيثَ ابْنُ لَهِيعَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ أَبِي قَتَادَةَ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يَبُولُ مُسْتَقْبِلَ الْقِبْلَةِ ‏.‏ حَدَّثَنَا بِذَلِكَ قُتَيْبَةُ حَدَّثَنَا ابْنُ لَهِيعَةَ ‏.‏ وَحَدِيثُ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَصَحُّ مِنْ حَدِيثِ ابْنِ لَهِيعَةَ ‏.‏ وَابْنُ لَهِيعَةَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ضَعَّفَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَغَيْرُهُ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{10}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Qatadah narrated that :he saw the Prophet urinating while facing the Qiblah. Qutaibah narrated that to us, he said: "Ibn Lahi'ah informed us." Jabir's Hadlth about the Prophet is more correct than the Hadith of Ibn Lahi'ah. Ibn Lahi'ah is weak according to the scholars of Hadith. He was graded weak by Yahya bin Sa'eed Al-Qattan, and others, [due to his memorization]}}
\hadithdefcmd{tirmidhi}{11}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنِ ابْنِ عُمَرَ، قَالَ رَقِيتُ يَوْمًا عَلَى بَيْتِ حَفْصَةَ فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى حَاجَتِهِ مُسْتَقْبِلَ الشَّأْمِ مُسْتَدْبِرَ الْكَعْبَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{11}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Umar said:"One day I climbed on Hafsah's house, and I saw the Prophet relieving himself while facing Ash-Sham, with his back toward the Ka'bah}}
\hadithdefcmd{tirmidhi}{12}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَنْ حَدَّثَكُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَبُولُ قَائِمًا فَلاَ تُصَدِّقُوهُ مَا كَانَ يَبُولُ إِلاَّ قَاعِدًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَبُرَيْدَةَ وَعَبْدِ الرَّحْمَنِ بْنِ حَسَنَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ أَحْسَنُ شَيْءٍ فِي هَذَا الْبَابِ وَأَصَحُّ ‏.‏ وَحَدِيثُ عُمَرَ إِنَّمَا رُوِيَ مِنْ حَدِيثِ عَبْدِ الْكَرِيمِ بْنِ أَبِي الْمُخَارِقِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنْ عُمَرَ قَالَ رَآنِي النَّبِيُّ صلى الله عليه وسلم وَأَنَا أَبُولُ قَائِمًا فَقَالَ ‏ "‏ يَا عُمَرُ لاَ تَبُلْ قَائِمًا ‏"‏ ‏.‏ فَمَا بُلْتُ قَائِمًا بَعْدُ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا رَفَعَ هَذَا الْحَدِيثَ عَبْدُ الْكَرِيمِ بْنُ أَبِي الْمُخَارِقِ وَهُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ضَعَّفَهُ أَيُّوبُ السَّخْتِيَانِيُّ وَتَكَلَّمَ فِيهِ ‏.‏ وَرَوَى عُبَيْدُ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ قَالَ قَالَ عُمَرُ رضى الله عنه مَا بُلْتُ قَائِمًا مُنْذُ أَسْلَمْتُ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ عَبْدِ الْكَرِيمِ وَحَدِيثُ بُرَيْدَةَ فِي هَذَا غَيْرُ مَحْفُوظٍ ‏.‏ وَمَعْنَى النَّهْىِ عَنِ الْبَوْلِ قَائِمًا عَلَى التَّأْدِيبِ لاَ عَلَى التَّحْرِيمِ ‏.‏ وَقَدْ رُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ قَالَ إِنَّ مِنَ الْجَفَاءِ أَنْ تَبُولَ وَأَنْتَ قَائِمٌ ‏.‏\hadithno{12}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah said:"Whoever narrated to you that the Prophet would urinate while standing; then do not believe him. He would not urinate except while squatting." [He said:] There are narrations on this topic from Umar, Buraidah, [and Abdur-Rahman bin Hasanah]}}
\hadithdefcmd{tirmidhi}{13}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَتَى سُبَاطَةَ قَوْمٍ فَبَالَ عَلَيْهَا قَائِمًا فَأَتَيْتُهُ بِوَضُوءٍ فَذَهَبْتُ لأَتَأَخَّرَ عَنْهُ فَدَعَانِي حَتَّى كُنْتُ عِنْدَ عَقِبَيْهِ فَتَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يُحَدِّثُ بِهَذَا الْحَدِيثِ عَنِ الأَعْمَشِ ‏.‏ ثُمَّ قَالَ وَكِيعٌ هَذَا أَصَحُّ حَدِيثٍ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْمَسْحِ ‏.‏ وَسَمِعْتُ أَبَا عَمَّارٍ الْحُسَيْنَ بْنَ حُرَيْثٍ يَقُولُ سَمِعْتُ وَكِيعًا فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَى مَنْصُورٌ وَعُبَيْدَةُ الضَّبِّيُّ عَنْ أَبِي وَائِلٍ عَنْ حُذَيْفَةَ مِثْلَ رِوَايَةِ الأَعْمَشِ ‏.‏ وَرَوَى حَمَّادُ بْنُ أَبِي سُلَيْمَانَ وَعَاصِمُ بْنُ بَهْدَلَةَ عَنْ أَبِي وَائِلٍ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَحَدِيثُ أَبِي وَائِلٍ عَنْ حُذَيْفَةَ أَصَحُّ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ فِي الْبَوْلِ قَائِمًا ‏.‏ قَالَ أَبُو عِيسَى وَعَبِيدَةُ بْنُ عَمْرٍو السَّلْمَانِيُّ رَوَى عَنْهُ إِبْرَاهِيمُ النَّخَعِيُّ ‏.‏ وَعَبِيدَةُ مِنْ كِبَارِ التَّابِعِينَ يُرْوَى عَنْ عَبِيدَةَ أَنَّهُ قَالَ أَسْلَمْتُ قَبْلَ وَفَاةِ النَّبِيِّ صلى الله عليه وسلم بِسَنَتَيْنِ ‏.‏ وَعُبَيْدَةُ الضَّبِّيُّ صَاحِبُ إِبْرَاهِيمَ هُوَ عُبَيْدَةُ بْنُ مُعَتِّبٍ الضَّبِّيُّ وَيُكْنَى أَبَا عَبْدِ الْكَرِيمِ ‏.‏\hadithno{13}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Hudhaifah narrated:"Allah's Messenger came to a waste area used by people, so he urinated on it while standing. I brought him the (water for) Wudu. Then I left to be away from him, but he called me until I was behind him. So he performed Wudu and wiped (Masaba) over his Khuff}}
\hadithdefcmd{tirmidhi}{14}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ الْمُلاَئِيُّ، عَنِ الأَعْمَشِ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَرَادَ الْحَاجَةَ لَمْ يَرْفَعْ ثَوْبَهُ حَتَّى يَدْنُوَ مِنَ الأَرْضِ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى مُحَمَّدُ بْنُ رَبِيعَةَ عَنِ الأَعْمَشِ عَنْ أَنَسٍ هَذَا الْحَدِيثَ ‏.‏ وَرَوَى وَكِيعٌ وَأَبُو يَحْيَى الْحِمَّانِيُّ عَنِ الأَعْمَشِ قَالَ قَالَ ابْنُ عُمَرَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَرَادَ الْحَاجَةَ لَمْ يَرْفَعْ ثَوْبَهُ حَتَّى يَدْنُوَ مِنَ الأَرْضِ ‏.‏ وَكِلاَ الْحَدِيثَيْنِ مُرْسَلٌ ‏.‏ وَيُقَالُ لَمْ يَسْمَعِ الأَعْمَشُ مِنْ أَنَسٍ وَلاَ مِنْ أَحَدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَقَدْ نَظَرَ إِلَى أَنَسِ بْنِ مَالِكٍ قَالَ رَأَيْتُهُ يُصَلِّي ‏.‏ فَذَكَرَ عَنْهُ حِكَايَةً فِي الصَّلاَةِ ‏.‏ وَالأَعْمَشُ اسْمُهُ سُلَيْمَانُ بْنُ مِهْرَانَ أَبُو مُحَمَّدٍ الْكَاهِلِيُّ وَهُوَ مَوْلًى لَهُمْ ‏.‏ قَالَ الأَعْمَشُ كَانَ أَبِي حَمِيلاً فَوَرَّثَهُ مَسْرُوقٌ ‏.‏\hadithno{14}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas, may Allah Most High be pleased with him, said:"When the Prophet wanted to relieve himself, he would not raise his garment until he was close to the ground}}
\hadithdefcmd{tirmidhi}{15}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَعْمَرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَمَسَّ الرَّجُلُ ذَكَرَهُ بِيَمِينِهِ ‏.‏ وَفِي هَذَا الْبَابِ عَنْ عَائِشَةَ وَسَلْمَانَ وَأَبِي هُرَيْرَةَ وَسَهْلِ بْنِ حُنَيْفٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو قَتَادَةَ الأَنْصَارِيُّ اسْمُهُ الْحَارِثُ بْنُ رِبْعِيٍّ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ كَرِهُوا الاِسْتِنْجَاءَ بِالْيَمِينِ ‏.‏\hadithno{15}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Abu Qatadah narrated from his father:"The Prophet prohibited that a man should touch his penis with his right hand}}
\hadithdefcmd{tirmidhi}{16}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ قِيلَ لِسَلْمَانَ قَدْ عَلَّمَكُمْ نَبِيُّكُمْ صلى الله عليه وسلم كُلَّ شَيْءٍ حَتَّى الْخِرَاءَةَ فَقَالَ سَلْمَانُ أَجَلْ نَهَانَا أَنْ نَسْتَقْبِلَ الْقِبْلَةَ بِغَائِطٍ أَوْ بَوْلٍ وَأَنْ نَسْتَنْجِيَ بِالْيَمِينِ أَوْ أَنْ يَسْتَنْجِيَ أَحَدُنَا بِأَقَلَّ مِنْ ثَلاَثَةِ أَحْجَارٍ أَوْ أَنْ نَسْتَنْجِيَ بِرَجِيعٍ أَوْ بِعَظْمٍ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَخُزَيْمَةَ بْنِ ثَابِتٍ وَجَابِرٍ وَخَلاَّدِ بْنِ السَّائِبِ عَنْ أَبِيهِ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ سَلْمَانَ فِي هَذَا الْبَابِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ رَأَوْا أَنَّ الاِسْتِنْجَاءَ بِالْحِجَارَةِ يُجْزِئُ وَإِنْ لَمْ يَسْتَنْجِ بِالْمَاءِ إِذَا أَنْقَى أَثَرَ الْغَائِطِ وَالْبَوْلِ وَبِهِ يَقُولُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{16}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdur-Rahman bin Yazld said, :"They said to Salman, 'Your Prophet taught you about everything, even defecating?' So Salman said, 'Yes. He prohibited us from facing the Qiblah when defecating and urinating, performing Istinja with the right hand, using less than three stones for Istinja, and using dung or bones for Istinja}}
\hadithdefcmd{tirmidhi}{17}{حَدَّثَنَا هَنَّادٌ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم لِحَاجَتِهِ فَقَالَ ‏"‏ الْتَمِسْ لِي ثَلاَثَةَ أَحْجَارٍ ‏"‏ ‏.‏ قَالَ فَأَتَيْتُهُ بِحَجَرَيْنِ وَرَوْثَةٍ فَأَخَذَ الْحَجَرَيْنِ وَأَلْقَى الرَّوْثَةَ وَقَالَ ‏"‏ إِنَّهَا رِكْسٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَى قَيْسُ بْنُ الرَّبِيعِ هَذَا الْحَدِيثَ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي عُبَيْدَةَ عَنْ عَبْدِ اللَّهِ نَحْوَ حَدِيثِ إِسْرَائِيلَ ‏.‏ وَرَوَى مَعْمَرٌ وَعَمَّارُ بْنُ رُزَيْقٍ عَنْ أَبِي إِسْحَاقَ عَنْ عَلْقَمَةَ عَنْ عَبْدِ اللَّهِ ‏.‏ وَرَوَى زُهَيْرٌ عَنْ أَبِي إِسْحَاقَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ عَنْ أَبِيهِ الأَسْوَدِ بْنِ يَزِيدَ عَنْ عَبْدِ اللَّهِ ‏.‏ وَرَوَى زَكَرِيَّا بْنُ أَبِي زَائِدَةَ عَنْ أَبِي إِسْحَاقَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ عَنِ الأَسْوَدِ بْنِ يَزِيدَ عَنْ عَبْدِ اللَّهِ ‏.‏ وَهَذَا حَدِيثٌ فِيهِ اضْطِرَابٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ الْعَبْدِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ عَنْ عَمْرِو بْنِ مُرَّةَ قَالَ سَأَلْتُ أَبَا عُبَيْدَةَ بْنَ عَبْدِ اللَّهِ هَلْ تَذْكُرُ مِنْ عَبْدِ اللَّهِ شَيْئًا قَالَ لاَ ‏.‏\hadithno{17}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah said:"Allah's Messenger went out to relieve himself. So he said: 'Bring me tree stones.'" He said, "So I came with two stones and a piece of dung. So he took the two stones, and left the dung. He said: 'It is Riks (a degenerative or filthy thing)}}
\hadithdefcmd{tirmidhi}{18}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَسْتَنْجُوا بِالرَّوْثِ وَلاَ بِالْعِظَامِ فَإِنَّهُ زَادُ إِخْوَانِكُمْ مِنَ الْجِنِّ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَسَلْمَانَ وَجَابِرٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى هَذَا الْحَدِيثَ إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ وَغَيْرُهُ عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ عَنِ الشَّعْبِيِّ عَنْ عَلْقَمَةَ عَنْ عَبْدِ اللَّهِ أَنَّهُ كَانَ مَعَ النَّبِيِّ صلى الله عليه وسلم لَيْلَةَ الْجِنِّ - الْحَدِيثَ بِطُولِهِ - فَقَالَ الشَّعْبِيُّ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَسْتَنْجُوا بِالرَّوْثِ وَلاَ بِالْعِظَامِ فَإِنَّهُ زَادُ إِخْوَانِكُمْ مِنَ الْجِنِّ ‏"‏ ‏.‏ وَكَأَنَّ رِوَايَةَ إِسْمَاعِيلَ أَصَحُّ مِنْ رِوَايَةِ حَفْصِ بْنِ غِيَاثٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ وَابْنِ عُمَرَ رضى الله عنهما ‏.‏\hadithno{18}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abdullah bin Mas'ud narrated that :Allah's Messenger said: "Do not perform Istinja, with dung, nor with bones. For indeed it is provisions for your brothers among the Jinn}}
\hadithdefcmd{tirmidhi}{19}{حَدَّثَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ الْبَصْرِيُّ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ مُعَاذَةَ، عَنْ عَائِشَةَ، قَالَتْ مُرْنَ أَزْوَاجَكُنَّ أَنْ يَسْتَطِيبُوا، بِالْمَاءِ فَإِنِّي أَسْتَحْيِيهِمْ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ وَأَنَسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلَيْهِ الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ يَخْتَارُونَ الاِسْتِنْجَاءَ بِالْمَاءِ وَإِنْ كَانَ الاِسْتِنْجَاءُ بِالْحِجَارَةِ يُجْزِئُ عِنْدَهُمْ فَإِنَّهُمُ اسْتَحَبُّوا الاِسْتِنْجَاءَ بِالْمَاءِ وَرَأَوْهُ أَفْضَلَ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{19}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said:"Encourage your Husbands to clean themselves with water, for I am too shy of them, and Allah's Messenger would do that}}
\hadithdefcmd{tirmidhi}{20}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَأَتَى النَّبِيُّ صلى الله عليه وسلم حَاجَتَهُ فَأَبْعَدَ فِي الْمَذْهَبِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي قُرَادٍ وَأَبِي قَتَادَةَ وَجَابِرٍ وَيَحْيَى بْنِ عُبَيْدٍ عَنْ أَبِيهِ وَأَبِي مُوسَى وَابْنِ عَبَّاسٍ وَبِلاَلِ بْنِ الْحَارِثِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُرْوَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَرْتَادُ لِبَوْلِهِ مَكَانًا كَمَا يَرْتَادُ مَنْزِلاً ‏.‏ وَأَبُو سَلَمَةَ اسْمُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ الزُّهْرِيُّ ‏.‏\hadithno{20}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Mughirah bin Shu'bah said:I was with the Prophet on a journey. The Prophet had to relieve himself, so he went far away}}
\hadithdefcmd{tirmidhi}{21}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، وَأَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، مَرْدَوَيْهِ قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ أَشْعَثَ بْنِ عَبْدِ اللَّهِ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَبُولَ الرَّجُلُ فِي مُسْتَحَمِّهِ ‏.‏ وَقَالَ ‏ "‏ إِنَّ عَامَّةَ الْوَسْوَاسِ مِنْهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ رَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ أَشْعَثَ بْنِ عَبْدِ اللَّهِ وَيُقَالُ لَهُ أَشْعَثُ الأَعْمَى ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ الْبَوْلَ فِي الْمُغْتَسَلِ وَقَالُوا عَامَّةُ الْوَسْوَاسِ مِنْهُ ‏.‏ وَرَخَّصَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ مِنْهُمُ ابْنُ سِيرِينَ وَقِيلَ لَهُ إِنَّهُ يُقَالُ إِنَّ عَامَّةَ الْوَسْوَاسِ مِنْهُ فَقَالَ رَبُّنَا اللَّهُ لاَ شَرِيكَ لَهُ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ قَدْ وُسِّعَ فِي الْبَوْلِ فِي الْمُغْتَسَلِ إِذَا جَرَى فِيهِ الْمَاءُ ‏.‏ قَالَ أَبُو عِيسَى حَدَّثَنَا بِذَلِكَ أَحْمَدُ بْنُ عَبْدَةَ الآمُلِيُّ عَنْ حِبَّانَ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ ‏.‏\hadithno{21}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mughaffal narrated that :the Prophet prohibited that a man should urinate in his bathing area. And he said: "It will only cause misgivings." [He said:] There are narrations on This topic from "a man from among the Companions of the Prophet}}
\hadithdefcmd{tirmidhi}{22}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِالسِّوَاكِ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى هَذَا الْحَدِيثَ مُحَمَّدُ بْنُ إِسْحَاقَ عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ عَنْ أَبِي سَلَمَةَ عَنْ زَيْدِ بْنِ خَالِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَحَدِيثُ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم كِلاَهُمَا عِنْدِي صَحِيحٌ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثُ ‏.‏ وَحَدِيثُ أَبِي هُرَيْرَةَ إِنَّمَا صَحَّ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَأَمَّا مُحَمَّدُ بْنُ إِسْمَاعِيلَ فَزَعَمَ أَنَّ حَدِيثَ أَبِي سَلَمَةَ عَنْ زَيْدِ بْنِ خَالِدٍ أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَعَلِيٍّ وَعَائِشَةَ وَابْنِ عَبَّاسٍ وَحُذَيْفَةَ وَزَيْدِ بْنِ خَالِدٍ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عُمَرَ وَأُمِّ حَبِيبَةَ وَأَبِي أُمَامَةَ وَأَبِي أَيُّوبَ وَتَمَّامِ بْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ حَنْظَلَةَ وَأُمِّ سَلَمَةَ وَوَاثِلَةَ بْنِ الأَسْقَعِ وَأَبِي مُوسَى ‏.‏\hadithno{22}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "If it were not that it would be difficult on my nation, then I would have ordered them to use the Siwak for each prayer}}
\hadithdefcmd{tirmidhi}{23}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِالسِّوَاكِ عِنْدَ كُلِّ صَلاَةٍ وَلأَخَّرْتُ صَلاَةَ الْعِشَاءِ إِلَى ثُلُثِ اللَّيْلِ ‏"‏ ‏.‏ قَالَ فَكَانَ زَيْدُ بْنُ خَالِدٍ يَشْهَدُ الصَّلَوَاتِ فِي الْمَسْجِدِ وَسِوَاكُهُ عَلَى أُذُنِهِ مَوْضِعَ الْقَلَمِ مِنْ أُذُنِ الْكَاتِبِ لاَ يَقُومُ إِلَى الصَّلاَةِ إِلاَّ اسْتَنَّ ثُمَّ رَدَّهُ إِلَى مَوْضِعِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{23}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Zaid bin Khalid Al-Juhani said :'I heard Allah's Messenger saying: 'If it were not that it would be difficult on my nation then, I would have ordered them to use the Siwak for each prayer and to delay the Isha prayer until the third of the night.'"He [Abu Salamah, one of the narrators] said: Zaid bin Khalid wouId attend the prayer in the Masjid and his Siwak would be on his ear in the location of the pen on the ear of a writer. He would not get up to pray without cleaning his teeth, then returning it to its location}}
\hadithdefcmd{tirmidhi}{24}{حَدَّثَنَا أَبُو الْوَلِيدِ، أَحْمَدُ بْنُ بَكَّارٍ الدِّمَشْقِيُّ - يُقَالُ هُوَ مِنْ وَلَدِ بُسْرِ بْنِ أَرْطَاةَ صَاحِبِ النَّبِيِّ صلى الله عليه وسلم حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ عَنِ الأَوْزَاعِيِّ عَنِ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ وَأَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنَ اللَّيْلِ فَلاَ يُدْخِلْ يَدَهُ فِي الإِنَاءِ حَتَّى يُفْرِغَ عَلَيْهَا مَرَّتَيْنِ أَوْ ثَلاَثًا فَإِنَّهُ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَجَابِرٍ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ الشَّافِعِيُّ وَأُحِبُّ لِكُلِّ مَنِ اسْتَيْقَظَ مِنَ النَّوْمِ قَائِلَةً كَانَتْ أَوْ غَيْرَهَا أَنْ لاَ يُدْخِلَ يَدَهُ فِي وَضُوئِهِ حَتَّى يَغْسِلَهَا فَإِنْ أَدْخَلَ يَدَهُ قَبْلَ أَنْ يَغْسِلَهَا كَرِهْتُ ذَلِكَ لَهُ وَلَمْ يُفْسِدْ ذَلِكَ الْمَاءَ إِذَا لَمْ يَكُنْ عَلَى يَدِهِ نَجَاسَةٌ ‏.‏ وَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ إِذَا اسْتَيْقَظَ مِنَ النَّوْمِ مِنَ اللَّيْلِ فَأَدْخَلَ يَدَهُ فِي وَضُوئِهِ قَبْلَ أَنْ يَغْسِلَهَا فَأَعْجَبُ إِلَىَّ أَنْ يُهَرِيقَ الْمَاءَ ‏.‏ وَقَالَ إِسْحَاقُ إِذَا اسْتَيْقَظَ مِنَ النَّوْمِ بِاللَّيْلِ أَوْ بِالنَّهَارِ فَلاَ يُدْخِلْ يَدَهُ فِي وَضُوئِهِ حَتَّى يَغْسِلَهَا ‏.‏\hadithno{24}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported that the :Prophet said: "When on of you awakens in the night, then let him not put his hand into the vessel until he has poured water on two times, or three times, for indeed he does not know where his hand has spent the night}}
\hadithdefcmd{tirmidhi}{25}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَبِشْرُ بْنُ مُعَاذٍ الْعَقَدِيُّ، قَالاَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، عَنْ أَبِي ثِفَالٍ الْمُرِّيِّ، عَنْ رَبَاحِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سُفْيَانَ بْنِ حُوَيْطِبٍ، عَنْ جَدَّتِهِ، عَنْ أَبِيهَا، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ وُضُوءَ لِمَنْ لَمْ يَذْكُرِ اسْمَ اللَّهِ عَلَيْهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَسَهْلِ بْنِ سَعْدٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى قَالَ أَحْمَدُ بْنُ حَنْبَلٍ لاَ أَعْلَمُ فِي هَذَا الْبَابِ حَدِيثًا لَهُ إِسْنَادٌ جَيِّدٌ ‏.‏ وَقَالَ إِسْحَاقُ إِنْ تَرَكَ التَّسْمِيَةَ عَامِدًا أَعَادَ الْوُضُوءَ وَإِنْ كَانَ نَاسِيًا أَوْ مُتَأَوِّلاً أَجْزَأَهُ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ أَحْسَنُ شَيْءٍ فِي هَذَا الْبَابِ حَدِيثُ رَبَاحِ بْنِ عَبْدِ الرَّحْمَنِ ‏.‏ قَالَ أَبُو عِيسَى وَرَبَاحُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ جَدَّتِهِ عَنْ أَبِيهَا ‏.‏ وَأَبُوهَا سَعِيدُ بْنُ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ ‏.‏ وَأَبُو ثِفَالٍ الْمُرِّيُّ اسْمُهُ ثُمَامَةُ بْنُ حُصَيْنٍ ‏.‏ وَرَبَاحُ بْنُ عَبْدِ الرَّحْمَنِ هُوَ أَبُو بَكْرِ بْنُ حُوَيْطِبٍ ‏.‏ مِنْهُمْ مَنْ رَوَى هَذَا الْحَدِيثَ فَقَالَ عَنْ أَبِي بَكْرِ بْنِ حُوَيْطِبٍ فَنَسَبَهُ إِلَى جَدِّهِ ‏.‏\hadithno{25}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Rabah bin Abdur-Rahman bin Abi Sufyan bin Huwaitib narrated from his grandmother, from her father; she said (that he said):"I heard Allah's Messenger saying: there is no Wudu for one who does not mention Allah's Name over it}}
\hadithdefcmd{tirmidhi}{26}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ يَزِيدَ بْنِ عِيَاضٍ، عَنْ أَبِي ثِفَالٍ الْمُرِّيِّ، عَنْ رَبَاحِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سُفْيَانَ بْنِ حُوَيْطِبٍ، عَنْ جَدَّتِهِ بِنْتِ سَعِيدِ بْنِ زَيْدٍ، عَنْ أَبِيهَا، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{26}\hadithgrade{Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Rabah Bin Abdur-Rahman bin Abu Sufyan bin Huwaitib narrated :the same from his grandmother the daughter of Sa'eed bin Zaid, from her father, from the Prophet}}
\hadithdefcmd{tirmidhi}{27}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، وَجَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ سَلَمَةَ بْنِ قَيْسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَوَضَّأْتَ فَانْتَثِرْ وَإِذَا اسْتَجْمَرْتَ فَأَوْتِرْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُثْمَانَ وَلَقِيطِ بْنِ صَبِرَةَ وَابْنِ عَبَّاسٍ وَالْمِقْدَامِ بْنِ مَعْدِيكَرِبَ وَوَائِلِ بْنِ حُجْرٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَلَمَةَ بْنِ قَيْسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِيمَنْ تَرَكَ الْمَضْمَضَةَ وَالاِسْتِنْشَاقَ فَقَالَتْ طَائِفَةٌ مِنْهُمْ إِذَا تَرَكَهُمَا فِي الْوُضُوءِ حَتَّى صَلَّى أَعَادَ الصَّلاَةَ وَرَأَوْا ذَلِكَ فِي الْوُضُوءِ وَالْجَنَابَةِ سَوَاءً ‏.‏ وَبِهِ يَقُولُ ابْنُ أَبِي لَيْلَى وَعَبْدُ اللَّهِ بْنُ الْمُبَارَكِ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ أَحْمَدُ الاِسْتِنْشَاقُ أَوْكَدُ مِنَ الْمَضْمَضَةِ ‏.‏ قَالَ أَبُو عِيسَى وَقَالَتْ طَائِفَةٌ مِنْ أَهْلِ الْعِلْمِ يُعِيدُ فِي الْجَنَابَةِ وَلاَ يُعِيدُ فِي الْوُضُوءِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَبَعْضِ أَهْلِ الْكُوفَةِ ‏.‏ وَقَالَتْ طَائِفَةٌ لاَ يُعِيدُ فِي الْوُضُوءِ وَلاَ فِي الْجَنَابَةِ لأَنَّهُمَا سُنَّةٌ مِنَ النَّبِيِّ صلى الله عليه وسلم فَلاَ تَجِبُ الإِعَادَةُ عَلَى مَنْ تَرَكَهُمَا فِي الْوُضُوءِ وَلاَ فِي الْجَنَابَةِ ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ فِي آخِرَةٍ ‏.‏\hadithno{27}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Salamah bin Qais narrated that :Allah's Messenger said: "When you perform Wudu then sniff water in the nose and blow it out, and when you use small stones (to remove filth) then make it odd (numbered)}}
\hadithdefcmd{tirmidhi}{28}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم مَضْمَضَ وَاسْتَنْشَقَ مِنْ كَفٍّ وَاحِدٍ فَعَلَ ذَلِكَ ثَلاَثًا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ عَبْدِ اللَّهِ بْنِ زَيْدٍ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى مَالِكٌ وَابْنُ عُيَيْنَةَ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ عَمْرِو بْنِ يَحْيَى وَلَمْ يَذْكُرُوا هَذَا الْحَرْفَ أَنَّ النَّبِيَّ صلى الله عليه وسلم مَضْمَضَ وَاسْتَنْشَقَ مِنْ كَفٍّ وَاحِدٍ ‏.‏ وَإِنَّمَا ذَكَرَهُ خَالِدُ بْنُ عَبْدِ اللَّهِ ‏.‏ وَخَالِدُ بْنُ عَبْدِ اللَّهِ ثِقَةٌ حَافِظٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ الْمَضْمَضَةُ وَالاِسْتِنْشَاقُ مِنْ كَفٍّ وَاحِدٍ يُجْزِئُ وَقَالَ بَعْضُهُمْ تَفْرِيقُهُمَا أَحَبُّ إِلَيْنَا ‏.‏ وَقَالَ الشَّافِعِيُّ إِنْ جَمَعَهُمَا فِي كَفٍّ وَاحِدٍ فَهُوَ جَائِزٌ وَإِنْ فَرَّقَهُمَا فَهُوَ أَحَبُّ إِلَيْنَا ‏.‏\hadithno{28}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Zaid said:"1 saw the Prophet rinse his mouth and sniff water in his nose using one hand, he did that thrice}}
\hadithdefcmd{tirmidhi}{29}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْكَرِيمِ بْنِ أَبِي الْمُخَارِقِ أَبِي أُمَيَّةَ، عَنْ حَسَّانَ بْنِ بِلاَلٍ، قَالَ رَأَيْتُ عَمَّارَ بْنَ يَاسِرٍ تَوَضَّأَ فَخَلَّلَ لِحْيَتَهُ فَقِيلَ لَهُ أَوْ قَالَ فَقُلْتُ لَهُ أَتُخَلِّلُ لِحْيَتَكَ قَالَ وَمَا يَمْنَعُنِي وَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُخَلِّلُ لِحْيَتَهُ ‏.‏\hadithno{29}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Hassan bin Bilal said:"1 saw Ammar bin Yasir performing Wudu, so he went through his beard (with his hand). It was said to him" - or he said - "1 said: 'You go through your beard?' He said: 'And what is there to prevent me? Indeed I saw Allah's Messenger going through his beard}}
\hadithdefcmd{tirmidhi}{30}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ حَسَّانَ بْنِ بِلاَلٍ، عَنْ عَمَّارٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُثْمَانَ وَعَائِشَةَ وَأُمِّ سَلَمَةَ وَأَنَسٍ وَابْنِ أَبِي أَوْفَى وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ إِسْحَاقَ بْنَ مَنْصُورٍ يَقُولُ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ قَالَ ابْنُ عُيَيْنَةَ لَمْ يَسْمَعْ عَبْدُ الْكَرِيمِ مِنْ حَسَّانَ بْنِ بِلاَلٍ حَدِيثَ التَّخْلِيلِ ‏.‏ وَقَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ حَدِيثُ عَامِرِ بْنِ شَقِيقٍ عَنْ أَبِي وَائِلٍ عَنْ عُثْمَانَ ‏.‏ قَالَ أَبُو عِيسَى وَقَالَ بِهَذَا أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ رَأَوْا تَخْلِيلَ اللِّحْيَةِ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ ‏.‏ وَقَالَ أَحْمَدُ إِنْ سَهَا عَنْ تَخْلِيلِ اللِّحْيَةِ فَهُوَ جَائِزٌ ‏.‏ وَقَالَ إِسْحَاقُ إِنْ تَرَكَهُ نَاسِيًا أَوْ مُتَأَوِّلاً أَجْزَأَهُ وَإِنْ تَرَكَهُ عَامِدًا أَعَادَ ‏.‏\hadithno{30}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{(In another narration) Ammar narrated :the same from the Prophet}}
\hadithdefcmd{tirmidhi}{31}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ إِسْرَائِيلَ، عَنْ عَامِرِ بْنِ شَقِيقٍ، عَنْ أَبِي وَائِلٍ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُخَلِّلُ لِحْيَتَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{31}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Uthman bin Affan narrated that :the Prophet would go through his beard}}
\hadithdefcmd{tirmidhi}{32}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى الْقَزَّازُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَسَحَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ بَدَأَ بِمُقَدَّمِ رَأْسِهِ ثُمَّ ذَهَبَ بِهِمَا إِلَى قَفَاهُ ثُمَّ رَدَّهُمَا حَتَّى رَجَعَ إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ ثُمَّ غَسَلَ رِجْلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ مُعَاوِيَةَ وَالْمِقْدَامِ بْنِ مَعْدِيكَرِبَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ زَيْدٍ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ وَأَحْسَنُ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{32}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Zaid narrated that:"Allah's Messenger wiped over his head with his hands, going over the front with them and the rear. He began with the front of his head until they went to the nape of his neck. Then he brought them back again to the place where he began. Then he washed his feet}}
\hadithdefcmd{tirmidhi}{33}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ بْنِ عَفْرَاءَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَسَحَ بِرَأْسِهِ مَرَّتَيْنِ بَدَأَ بِمُؤَخَّرِ رَأْسِهِ ثُمَّ بِمُقَدَّمِهِ وَبِأُذُنَيْهِ كِلْتَيْهِمَا ظُهُورِهِمَا وَبُطُونِهِمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَحَدِيثُ عَبْدِ اللَّهِ بْنِ زَيْدٍ أَصَحُّ مِنْ هَذَا وَأَجْوَدُ إِسْنَادًا ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْكُوفَةِ إِلَى هَذَا الْحَدِيثِ مِنْهُمْ وَكِيعُ بْنُ الْجَرَّاحِ ‏.‏\hadithno{33}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ar-Rubay' bint Mu'awwidh bin Afra' narrated:"The Prophet wiped his head two times: He began with the rear of his head, then with the front of his head and with both of his ears, outside and Inside of them}}
\hadithdefcmd{tirmidhi}{34}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ بْنِ عَفْرَاءَ، أَنَّهَا رَأَتِ النَّبِيَّ صلى الله عليه وسلم يَتَوَضَّأُ قَالَتْ مَسَحَ رَأْسَهُ وَمَسَحَ مَا أَقْبَلَ مِنْهُ وَمَا أَدْبَرَ وَصُدْغَيْهِ وَأُذُنَيْهِ مَرَّةً وَاحِدَةً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَدِّ طَلْحَةَ بْنِ مُصَرِّفِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ الرُّبَيِّعِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ مَسَحَ بِرَأْسِهِ مَرَّةً ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ ‏.‏ وَبِهِ يَقُولُ جَعْفَرُ بْنُ مُحَمَّدٍ وَسُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ رَأَوْا مَسْحَ الرَّأْسِ مَرَّةً وَاحِدَةً ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الْمَكِّيُّ قَالَ سَمِعْتُ سُفْيَانَ بْنَ عُيَيْنَةَ يَقُولُ سَأَلْتُ جَعْفَرَ بْنَ مُحَمَّدٍ عَنْ مَسْحِ الرَّأْسِ أَيُجْزِئُ مَرَّةً فَقَالَ إِي وَاللَّهِ ‏.‏\hadithno{34}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ar-Rubayy bint Mu'awidh bin Afra narrated that :she saw the Prophet performing Wudu. She said: "He wiped his head, and what is in the front of it and what is in its rear, and his temples and his ears one time}}
\hadithdefcmd{tirmidhi}{35}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، عَنْ حَبَّانَ بْنِ وَاسِعٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ وَأَنَّهُ مَسَحَ رَأْسَهُ بِمَاءٍ غَيْرِ فَضْلِ يَدَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى ابْنُ لَهِيعَةَ هَذَا الْحَدِيثَ عَنْ حَبَّانَ بْنِ وَاسِعٍ عَنْ أَبِيهِ عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ وَأَنَّهُ مَسَحَ رَأْسَهُ بِمَاءٍ غَبَرَ مِنْ فَضْلِ يَدَيْهِ ‏"‏ ‏.‏ وَرِوَايَةُ عَمْرِو بْنِ الْحَارِثِ عَنْ حَبَّانَ أَصَحُّ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ هَذَا الْحَدِيثُ عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ وَغَيْرِهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَخَذَ لِرَأْسِهِ مَاءً جَدِيدًا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ رَأَوْا أَنْ يَأْخُذَ لِرَأْسِهِ مَاءً جَدِيدًا ‏.‏\hadithno{35}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Zaid narrated that :he saw the Prophet performing Wudu, and that he wiped his head with water that was not left over from his hands}}
\hadithdefcmd{tirmidhi}{36}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَسَحَ بِرَأْسِهِ وَأُذُنَيْهِ ظَاهِرِهِمَا وَبَاطِنِهِمَا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ الرُّبَيِّعِ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ يَرَوْنَ مَسْحَ الأُذُنَيْنِ ظُهُورِهِمَا وَبُطُونِهِمَا ‏.‏\hadithno{36}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Abbas narrated:"The Prophet wiped his head and his ears: the outside and the inside of them." ($ahih)}}
\hadithdefcmd{tirmidhi}{37}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ سِنَانِ بْنِ رَبِيعَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي أُمَامَةَ، قَالَ تَوَضَّأَ النَّبِيُّ صلى الله عليه وسلم فَغَسَلَ وَجْهَهُ ثَلاَثًا وَيَدَيْهِ ثَلاَثًا وَمَسَحَ بِرَأْسِهِ وَقَالَ ‏ "‏ الأُذُنَانِ مِنَ الرَّأْسِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى قَالَ قُتَيْبَةُ قَالَ حَمَّادٌ لاَ أَدْرِي هَذَا مِنْ قَوْلِ النَّبِيِّ صلى الله عليه وسلم أَوْ مِنْ قَوْلِ أَبِي أُمَامَةَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ لَيْسَ إِسْنَادُهُ بِذَاكَ الْقَائِمِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ أَنَّ الأُذُنَيْنِ مِنَ الرَّأْسِ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مَا أَقْبَلَ مِنَ الأُذُنَيْنِ فَمِنَ الْوَجْهِ وَمَا أَدْبَرَ فَمِنَ الرَّأْسِ ‏.‏ قَالَ إِسْحَاقُ وَأَخْتَارُ أَنْ يَمْسَحَ مُقَدَّمَهُمَا مَعَ الْوَجْهِ وَمُؤَخَّرَهُمَا مَعَ رَأْسِهِ ‏.‏ وَقَالَ الشَّافِعِيُّ هُمَا سُنَّةٌ عَلَى حِيَالِهِمَا يَمْسَحُهُمَا بِمَاءٍ جَدِيدٍ ‏.‏\hadithno{37}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Umamah narrated:"The Prophet performed Wudu; so he washed his face three times, and his hands three times, and wiped his head, and he said: "The ears are part of the head}}
\hadithdefcmd{tirmidhi}{38}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي هَاشِمٍ، عَنْ عَاصِمِ بْنِ لَقِيطِ بْنِ صَبِرَةَ، عَنْ أَبِيهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا تَوَضَّأْتَ فَخَلِّلِ الأَصَابِعَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَالْمُسْتَوْرِدِ وَهُوَ ابْنُ شَدَّادٍ الْفِهْرِيُّ وَأَبِي أَيُّوبَ الأَنْصَارِيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ يُخَلِّلُ أَصَابِعَ رِجْلَيْهِ فِي الْوُضُوءِ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ إِسْحَاقُ يُخَلِّلُ أَصَابِعَ يَدَيْهِ وَرِجْلَيْهِ فِي الْوُضُوءِ ‏.‏ وَأَبُو هَاشِمٍ اسْمُهُ إِسْمَاعِيلُ بْنُ كَثِيرٍ الْمَكِّيُّ ‏.‏\hadithno{38}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Asim bin Laqit bin Sabirah narrated from his father that :the Prophet Muhammad said: "When performing Wudu go between the fingers}}
\hadithdefcmd{tirmidhi}{39}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ، هُوَ الْجَوْهَرِيُّ حَدَّثَنَا سَعْدُ بْنُ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ صَالِحٍ، مَوْلَى التَّوْأَمَةِ عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأْتَ فَخَلِّلْ بَيْنَ أَصَابِعِ يَدَيْكَ وَرِجْلَيْكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{39}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Abbas narrated that :Allah's Messenger said: "When performing Wudu go between the fingers of your hands and (toes of) your feet}}
\hadithdefcmd{tirmidhi}{40}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ عَمْرٍو، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنِ الْمُسْتَوْرِدِ بْنِ شَدَّادٍ الْفِهْرِيِّ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم إِذَا تَوَضَّأَ دَلَكَ أَصَابِعَ رِجْلَيْهِ بِخِنْصَرِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ لَهِيعَةَ ‏.‏\hadithno{40}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Al-Mustawrid bin Shaddad Al-Fihri said :"I saw the Prophet when he was performing Wudu doing that to the toes on his feet with his pinky}}
\hadithdefcmd{tirmidhi}{41}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَائِشَةَ وَجَابِرٍ وَعَبْدِ اللَّهِ بْنِ الْحَارِثِ هُوَ ابْنُ جَزْءٍ الزُّبَيْدِيُّ وَمُعَيْقِيبٍ وَخَالِدِ بْنِ الْوَلِيدِ وَشُرَحْبِيلَ بْنِ حَسَنَةَ وَعَمْرِو بْنِ الْعَاصِ وَيَزِيدَ بْنِ أَبِي سُفْيَانَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ وَيْلٌ لِلأَعْقَابِ وَبُطُونِ الأَقْدَامِ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ وَفِقْهُ هَذَا الْحَدِيثِ أَنَّهُ لاَ يَجُوزُ الْمَسْحُ عَلَى الْقَدَمَيْنِ إِذَا لَمْ يَكُنْ عَلَيْهِمَا خُفَّانِ أَوْ جَوْرَبَانِ ‏.‏\hadithno{41}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Protect the heels from the Fire}}
\hadithdefcmd{tirmidhi}{42}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَهَنَّادٌ، وَقُتَيْبَةُ، قَالُوا حَدَّثَنَا وِكِيعٌ، عَنْ سُفْيَانَ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ مَرَّةً مَرَّةً ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَجَابِرٍ وَبُرَيْدَةَ وَأَبِي رَافِعٍ وَابْنِ الْفَاكِهِ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ ابْنِ عَبَّاسٍ أَحْسَنُ شَيْءٍ فِي هَذَا الْبَابِ وَأَصَحُّ ‏.‏ وَرَوَى رِشْدِينُ بْنُ سَعْدٍ وَغَيْرُهُ هَذَا الْحَدِيثَ عَنِ الضَّحَّاكِ بْنِ شُرَحْبِيلَ عَنْ زَيْدِ بْنِ أَسْلَمَ عَنْ أَبِيهِ عَنْ عُمَرَ بْنِ الْخَطَّابِ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ مَرَّةً مَرَّةً ‏.‏ قَالَ وَلَيْسَ هَذَا بِشَيْءٍ وَالصَّحِيحُ مَا رَوَى ابْنُ عَجْلاَنَ وَهِشَامُ بْنُ سَعْدٍ وَسُفْيَانُ الثَّوْرِيُّ وَعَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ عَنْ زَيْدِ بْنِ أَسْلَمَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{42}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn Abbas narrated:"The Prophet performed Wudu one time (for each limb)}}
\hadithdefcmd{tirmidhi}{43}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ ثَابِتِ بْنِ ثَوْبَانَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ الْفَضْلِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، هُوَ الأَعْرَجُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ مَرَّتَيْنِ مَرَّتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ ثَوْبَانَ عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ وَهُوَ إِسْنَادٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى هَمَّامٌ عَنْ عَامِرٍ الأَحْوَلِ عَنْ عَطَاءٍ عَنْ أَبِي هُرَيْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ ثَلاَثًا ثَلاَثًا ‏"‏ ‏.‏\hadithno{43}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated:"The Prophet performed Wudu two time (for each limb)}}
\hadithdefcmd{tirmidhi}{44}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ ثَلاَثًا ثَلاَثًا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُثْمَانَ وَعَائِشَةَ وَالرُّبَيِّعِ وَابْنِ عُمَرَ وَأَبِي أُمَامَةَ وَأَبِي رَافِعٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَمُعَاوِيَةَ وَأَبِي هُرَيْرَةَ وَجَابِرٍ وَعَبْدِ اللَّهِ بْنِ زَيْدٍ وَأُبَىِّ بْنِ كَعْبٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ أَحْسَنُ شَيْءٍ فِي هَذَا الْبَابِ وَأَصَحُّ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَلِيٍّ رِضْوَانُ اللَّهِ عَلَيْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ أَنَّ الْوُضُوءَ يُجْزِئُ مَرَّةً مَرَّةً وَمَرَّتَيْنِ أَفْضَلُ وَأَفْضَلُهُ ثَلاَثٌ وَلَيْسَ بَعْدَهُ شَيْءٌ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ لاَ آمَنُ إِذَا زَادَ فِي الْوُضُوءِ عَلَى الثَّلاَثِ أَنْ يَأْثَمَ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ لاَ يَزِيدُ عَلَى الثَّلاَثِ إِلاَّ رَجُلٌ مُبْتَلًى ‏.‏\hadithno{44}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali narrated that:"The Prophet performed Wudu three times (for each limb)}}
\hadithdefcmd{tirmidhi}{45}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ ثَابِتِ بْنِ أَبِي صَفِيَّةَ، قَالَ قُلْتُ لأَبِي جَعْفَرٍ حَدَّثَكَ جَابِرٌ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ مَرَّةً مَرَّةً وَمَرَّتَيْنِ مَرَّتَيْنِ وَثَلاَثًا ثَلاَثًا قَالَ نَعَمْ ‏.‏\hadithno{45}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Thabit bin Abi Safiyyah said, :"I asked Abu Ja'far: 'Did Jabir narrate to you that: "The Prophet performed Wudu one time each, and two times, and three times?" He said: "Yes}}
\hadithdefcmd{tirmidhi}{46}{قَالَ أَبُو عِيسَى وَرَوَى وَكِيعٌ، هَذَا الْحَدِيثَ عَنْ ثَابِتِ بْنِ أَبِي صَفِيَّةَ، قَالَ قُلْتُ لأَبِي جَعْفَرٍ حَدَّثَكَ جَابِرٌ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ مَرَّةً مَرَّةً قَالَ نَعَمْ ‏.‏ حَدَّثَنَا بِذَلِكَ هَنَّادٌ وَقُتَيْبَةُ قَالاَ حَدَّثَنَا وَكِيعٌ عَنْ ثَابِتِ بْنِ أَبِي صَفِيَّةَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ شَرِيكٍ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ هَذَا عَنْ ثَابِتٍ نَحْوَ رِوَايَةِ وَكِيعٍ ‏.‏ وَشَرِيكٌ كَثِيرُ الْغَلَطِ وَثَابِتُ بْنُ أَبِي صَفِيَّةَ هُوَ أَبُو حَمْزَةَ الثُّمَالِيُّ ‏.‏\hadithno{46}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Thabit bin Abi Safiyyah said, :"1 asked Abu Ja'far: 'Did Jabir narrate to you that: "The Prophet performed Wudu one time each?" He said: "Yes}}
\hadithdefcmd{tirmidhi}{47}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ فَغَسَلَ وَجْهَهُ ثَلاَثًا وَغَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ وَمَسَحَ بِرَأْسِهِ وَغَسَلَ رِجْلَيْهِ مَرَّتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذُكِرَ فِي غَيْرِ حَدِيثٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ بَعْضَ وُضُوئِهِ مَرَّةً وَبَعْضَهُ ثَلاَثًا ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي ذَلِكَ لَمْ يَرَوْا بَأْسًا أَنْ يَتَوَضَّأَ الرَّجْلُ بَعْضَ وُضُوئِهِ ثَلاَثًا وَبَعْضَهُ مَرَّتَيْنِ أَوْ مَرَّةً ‏.‏\hadithno{47}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Zaid narrated that:"The Prophet performed Wudu. So he washed his face three times, and washed his hands two times each, and wiped his head, and washed his feet [two times]}}
\hadithdefcmd{tirmidhi}{48}{حَدَّثَنَا هَنَّادٌ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ، قَالَ رَأَيْتُ عَلِيًّا تَوَضَّأَ فَغَسَلَ كَفَّيْهِ حَتَّى أَنْقَاهُمَا ثُمَّ مَضْمَضَ ثَلاَثًا وَاسْتَنْشَقَ ثَلاَثًا وَغَسَلَ وَجْهَهُ ثَلاَثًا وَذِرَاعَيْهِ ثَلاَثًا وَمَسَحَ بِرَأْسِهِ مَرَّةً ثُمَّ غَسَلَ قَدَمَيْهِ إِلَى الْكَعْبَيْنِ ثُمَّ قَامَ فَأَخَذَ فَضْلَ طَهُورِهِ فَشَرِبَهُ وَهُوَ قَائِمٌ ثُمَّ قَالَ أَحْبَبْتُ أَنْ أُرِيَكُمْ كَيْفَ كَانَ طُهُورُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُثْمَانَ وَعَبْدِ اللَّهِ بْنِ زَيْدٍ وَابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَالرُّبَيِّعِ وَعَبْدِ اللَّهِ بْنِ أُنَيْسٍ وَعَائِشَةَ رِضْوَانُ اللَّهِ عَلَيْهِمْ ‏.‏\hadithno{48}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hayyah narrated:"I saw Ali performing Wudu. He washed his hands until he cleaned them, then he rinsed out his mouth three times, sniffed water into his nose and blew it out three times, washed his face three times, and his forearms three times. He wiped his head once, then he washed his feet up to the ankles. Then he stood up, taking what was left over from his purification (water) and drank it while he was standing. Then he said, 'I wanted to show you how Allah's Messenger purified himself}}
\hadithdefcmd{tirmidhi}{49}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ خَيْرٍ، ذَكَرَ عَنْ عَلِيٍّ، مِثْلَ حَدِيثِ أَبِي حَيَّةَ إِلاَّ أَنَّ عَبْدَ خَيْرٍ، قَالَ كَانَ إِذَا فَرَغَ مِنْ طُهُورِهِ أَخَذَ مِنْ فَضْلِ طَهُورِهِ بِكَفِّهِ فَشَرِبَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ رَوَاهُ أَبُو إِسْحَاقَ الْهَمْدَانِيُّ عَنْ أَبِي حَيَّةَ وَعَبْدِ خَيْرٍ وَالْحَارِثِ عَنْ عَلِيٍّ وَقَدْ رَوَى زَائِدَةُ بْنُ قُدَامَةَ وَغَيْرُ وَاحِدٍ عَنْ خَالِدِ بْنِ عَلْقَمَةَ عَنْ عَبْدِ خَيْرٍ عَنْ عَلِيٍّ رضى الله عنه حَدِيثَ الْوُضُوءِ بِطُولِهِ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ خَالِدِ بْنِ عَلْقَمَةَ فَأَخْطَأَ فِي اسْمِهِ وَاسْمِ أَبِيهِ فَقَالَ مَالِكُ بْنُ عُرْفُطَةَ عَنْ عَبْدِ خَيْرٍ عَنْ عَلِيٍّ ‏.‏ قَالَ وَرُوِيَ عَنْ أَبِي عَوَانَةَ عَنْ خَالِدِ بْنِ عَلْقَمَةَ عَنْ عَبْدِ خَيْرٍ عَنْ عَلِيٍّ ‏.‏ قَالَ وَرُوِيَ عَنْهُ عَنْ مَالِكِ بْنِ عُرْفُطَةَ مِثْلَ رِوَايَةِ شُعْبَةَ وَالصَّحِيحُ خَالِدُ بْنُ عَلْقَمَةَ ‏.‏\hadithno{49}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abd Khair related a narration similar to that of Abu Hayyah, :from Ali (no. 48). Except that Abd Khair's version includes the following additions: "When he was finished from his purification, he would take what was left over from his purification with his hand to drink it}}
\hadithdefcmd{tirmidhi}{50}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَأَحْمَدُ بْنُ أَبِي عُبَيْدِ اللَّهِ السَّلِيمِيُّ الْبَصْرِيُّ، قَالاَ حَدَّثَنَا أَبُو قُتَيْبَةَ، سَلْمُ بْنُ قُتَيْبَةَ عَنِ الْحَسَنِ بْنِ عَلِيٍّ الْهَاشِمِيِّ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ جَاءَنِي جِبْرِيلُ فَقَالَ يَا مُحَمَّدُ إِذَا تَوَضَّأْتَ فَانْتَضِحْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَقُولُ الْحَسَنُ بْنُ عَلِيٍّ الْهَاشِمِيُّ مُنْكَرُ الْحَدِيثِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي الْحَكَمِ بْنِ سُفْيَانَ وَابْنِ عَبَّاسٍ وَزَيْدِ بْنِ حَارِثَةَ وَأَبِي سَعِيدٍ الْخُدْرِيِّ ‏.‏ وَقَالَ بَعْضُهُمْ سُفْيَانُ بْنُ الْحَكَمِ أَوِ الْحَكَمُ بْنُ سُفْيَانَ وَاضْطَرَبُوا فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{50}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Jibril came to me and he said: 'O Muhammad! When you perform wudu then perform Nadh}}
\hadithdefcmd{tirmidhi}{51}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنِ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلاَ أَدُلُّكُمْ عَلَى مَا يَمْحُو اللَّهُ بِهِ الْخَطَايَا وَيَرْفَعُ بِهِ الدَّرَجَاتِ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِسْبَاغُ الْوُضُوءِ عَلَى الْمَكَارِهِ وَكَثْرَةُ الْخُطَا إِلَى الْمَسَاجِدِ وَانْتِظَارُ الصَّلاَةِ بَعْدَ الصَّلاَةِ فَذَلِكُمُ الرِّبَاطُ ‏"‏ ‏.‏\hadithno{51}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Shall I tell you that for which Allah will wipe out your sins, and raise your ranks?" They said, "Of course Allah's Messenger!" He said: "Performing Wudu well in difficulty, and taking many steps to the Masajid, and waiting for Salat after Salat, That is the Ribat}}
\hadithdefcmd{tirmidhi}{52}{وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ، نَحْوَهُ ‏.‏ وَقَالَ قُتَيْبَةُ فِي حَدِيثِهِ ‏ "‏ فَذَلِكُمُ الرِّبَاطُ فَذَلِكُمُ الرِّبَاطُ فَذَلِكُمُ الرِّبَاطُ ‏"‏ ‏.‏ ثَلاَثًا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عَبَّاسٍ وَعَبِيدَةَ وَيُقَالُ عُبَيْدَةُ بْنِ عَمْرٍو وَعَائِشَةَ وَعَبْدِ الرَّحْمَنِ بْنِ عَائِشٍ الْحَضْرَمِيِّ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي هُرَيْرَةَ فِي هَذَا الْبَابِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ هُوَ ابْنُ يَعْقُوبَ الْجُهَنِيُّ الْحُرَقِيُّ وَهُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{52}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Qutaibah said in his narration:"For that is the Ribat, that is the Ribat, that is the Ribat" three times}}
\hadithdefcmd{tirmidhi}{53}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعِ بْنِ الْجَرَّاحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ زَيْدِ بْنِ حُبَابٍ، عَنْ أَبِي مُعَاذٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خِرْقَةٌ يُنَشِّفُ بِهَا بَعْدَ الْوُضُوءِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ لَيْسَ بِالْقَائِمِ وَلاَ يَصِحُّ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ شَيْءٌ ‏.‏ وَأَبُو مُعَاذٍ يَقُولُونَ هُوَ سُلَيْمَانُ بْنُ أَرْقَمَ وَهُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ مُعَاذِ بْنِ جَبَلٍ ‏.‏\hadithno{53}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"Allah's Messenger had a cloth that he would use to dry off with after Wudu}}
\hadithdefcmd{tirmidhi}{54}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادِ بْنِ أَنْعُمٍ، عَنْ عُتْبَةَ بْنِ حُمَيْدٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم إِذَا تَوَضَّأَ مَسَحَ وَجْهَهُ بِطَرَفِ ثَوْبِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَإِسْنَادُهُ ضَعِيفٌ ‏.‏ وَرِشْدِينُ بْنُ سَعْدٍ وَعَبْدُ الرَّحْمَنِ بْنُ زِيَادِ بْنِ أَنْعُمٍ الإِفْرِيقِيُّ يُضَعَّفَانِ فِي الْحَدِيثِ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ فِي التَّمَنْدُلِ بَعْدَ الْوُضُوءِ وَمَنْ كَرِهَهُ إِنَّمَا كَرِهَهُ مِنْ قِبَلِ أَنَّهُ قِيلَ إِنَّ الْوَضُوءَ يُوزَنُ ‏.‏ وَرُوِيَ ذَلِكَ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ وَالزُّهْرِيِّ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ حَدَّثَنَا جَرِيرٌ قَالَ حَدَّثَنِيهِ عَلِيُّ بْنُ مُجَاهِدٍ عَنِّي وَهُوَ عِنْدِي ثِقَةٌ عَنْ ثَعْلَبَةَ عَنِ الزُّهْرِيِّ قَالَ إِنَّمَا كُرِهَ الْمِنْدِيلُ بَعْدَ الْوُضُوءِ لأَنَّ الْوَضُوءَ يُوزَنُ ‏.‏\hadithno{54}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muadh bin Jabal narrated:"I saw the Prophet when he performed Wudu, he wiped his face with the edge of his garment." Abu Eisa said: This Hadith is gharib, and its chain is weak. Rishdin bin Sa'd and Abdur- Rahman bin Ziyad bin An'um Al Ifriqi [narrators in the chain of this Hadith] are weak in Hadith. Some people of knowledge among the Companions of the Prophet and those after them, permitted using a towel after Wudu. Those who disliked it, only disliked it from the view of the saying: "Wudu is weighed." That as reported from Sa'eed bin Al- Musayyab and Az-Zuhri. Muhammad bin Humaid [Ar-Razi] narrated to us, Jarir narrated to us, he said: Ali bin Mujahid narrated to me, and he is trustworthy to me, from me, from: Tha'labah from Az-Zuhri, he said: "The towel is only disliked after Wudu because Wudu is weighed}}
\hadithdefcmd{tirmidhi}{55}{حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدِ بْنِ عِمْرَانَ الثَّعْلَبِيُّ الْكُوفِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ الدِّمَشْقِيِّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، وَأَبِي، عُثْمَانَ عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ اللَّهُمَّ اجْعَلْنِي مِنَ التَّوَّابِينَ وَاجْعَلْنِي مِنَ الْمُتَطَهِّرِينَ فُتِحَتْ لَهُ ثَمَانِيَةُ أَبْوَابِ الْجَنَّةِ يَدْخُلُ مِنْ أَيِّهَا شَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ وَعُقْبَةَ بْنِ عَامِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ قَدْ خُولِفَ زَيْدُ بْنُ حُبَابٍ فِي هَذَا الْحَدِيثِ ‏.‏ قَالَ وَرَوَى عَبْدُ اللَّهِ بْنُ صَالِحٍ وَغَيْرُهُ عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ عَنْ رَبِيعَةَ بْنِ يَزِيدَ عَنْ أَبِي إِدْرِيسَ عَنْ عُقْبَةَ بْنِ عَامِرٍ عَنْ عُمَرَ ‏.‏ وَعَنْ رَبِيعَةَ عَنْ أَبِي عُثْمَانَ عَنْ جُبَيْرِ بْنِ نُفَيْرٍ عَنْ عُمَرَ ‏.‏ وَهَذَا حَدِيثٌ فِي إِسْنَادِهِ اضْطِرَابٌ وَلاَ يَصِحُّ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ كَبِيرُ شَيْءٍ ‏.‏ قَالَ مُحَمَّدٌ وَأَبُو إِدْرِيسَ لَمْ يَسْمَعْ مِنْ عُمَرَ شَيْئًا ‏.‏\hadithno{55}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Umar bin Al-Khattab narrated that :Allah's Messenger said: 'Whoever performs Wudu, making Wudu well, then says: (Ashhadu an la ilaha illallah, wahdahu la sharika lahu, wa ashhadu anna Muhammadan-abduhu wa rasuluhu, Allahummajalni minat tawwabin, waj'alni minal mutatahhirin) 'I testify that none has the right to be worshipped but Allah Alone, there are no partners for Him. And I testify that Muhammad is His servant and Messenger. O Allah! Make me among the repentant, and make me among those who purify themselves.' Then eight gates of Paradise are opened for him, that may enter by whichever of them wishes}}
\hadithdefcmd{tirmidhi}{56}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَبِي رَيْحَانَةَ، عَنْ سَفِينَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَوَضَّأُ بِالْمُدِّ وَيَغْتَسِلُ بِالصَّاعِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَجَابِرٍ وَأَنَسِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَفِينَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو رَيْحَانَةَ اسْمُهُ عَبْدُ اللَّهِ بْنُ مَطَرٍ ‏.‏ وَهَكَذَا رَأَى بَعْضُ أَهْلِ الْعِلْمِ الْوُضُوءَ بِالْمُدِّ وَالْغُسْلَ بِالصَّاعِ ‏.‏ وَقَالَ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ لَيْسَ مَعْنَى هَذَا الْحَدِيثِ عَلَى التَّوْقِيتِ أَنَّهُ لاَ يَجُوزُ أَكْثَرُ مِنْهُ وَلاَ أَقَلُّ مِنْهُ وَهُوَ قَدْرُ مَا يَكْفِي ‏.‏\hadithno{56}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Safinah narrated:"The Prophet would perform Wudu with a Mudd, and he would perform Ghusl with a Sa}}
\hadithdefcmd{tirmidhi}{57}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا خَارِجَةُ بْنُ مُصْعَبٍ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنْ عُتَىِّ بْنِ ضَمْرَةَ السَّعْدِيِّ، عَنْ أُبَىِّ بْنِ كَعْبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِلْوُضُوءِ شَيْطَانًا يُقَالُ لَهُ الْوَلْهَانُ فَاتَّقُوا وَسْوَاسَ الْمَاءِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُبَىِّ بْنِ كَعْبٍ حَدِيثٌ غَرِيبٌ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ وَالصَّحِيحِ عِنْدَ أَهْلِ الْحَدِيثِ لأَنَّا لاَ نَعْلَمُ أَحَدًا أَسْنَدَهُ غَيْرَ خَارِجَةَ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ الْحَسَنِ قَوْلَهُ وَلاَ يَصِحُّ فِي هَذَا الْبَابِ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْءٌ ‏.‏ وَخَارِجَةُ لَيْسَ بِالْقَوِيِّ عِنْدَ أَصْحَابِنَا وَضَعَّفَهُ ابْنُ الْمُبَارَكِ ‏.‏\hadithno{57}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ubayy bin Ka'b narrated that :the Prophet said: "Indeed there is a Shaitan for Wudu' who is called "AI-Walahan." So beware of having misgivings about water}}
\hadithdefcmd{tirmidhi}{58}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ بْنُ الْفَضْلِ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَوَضَّأُ لِكُلِّ صَلاَةٍ طَاهِرًا أَوْ غَيْرَ طَاهِرٍ ‏.‏ قَالَ قُلْتُ لأَنَسٍ فَكَيْفَ كُنْتُمْ تَصْنَعُونَ أَنْتُمْ قَالَ كُنَّا نَتَوَضَّأُ وُضُوءًا وَاحِدًا ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ حُمَيْدٍ عَنْ أَنَسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَالْمَشْهُورُ عِنْدَ أَهْلِ الْحَدِيثِ حَدِيثُ عَمْرِو بْنِ عَامِرٍ الأَنْصَارِيِّ عَنْ أَنَسٍ ‏.‏ وَقَدْ كَانَ بَعْضُ أَهْلِ الْعِلْمِ يَرَى الْوُضُوءَ لِكُلِّ صَلاَةٍ اسْتِحْبَابًا لاَ عَلَى الْوُجُوبِ ‏.‏\hadithno{58}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that :"The Prophet would perform wudu for every Salat, whether he was in state of purity or not in a state of purity}}
\hadithdefcmd{tirmidhi}{59}{وَقَدْ رُوِيَ فِي، حَدِيثٍ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ تَوَضَّأَ عَلَى طُهْرٍ كَتَبَ اللَّهُ لَهُ بِهِ عَشْرَ حَسَنَاتٍ ‏"‏ ‏.‏ قَالَ وَرَوَى هَذَا الْحَدِيثَ الإِفْرِيقِيُّ عَنْ أَبِي غُطَيْفٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا بِذَلِكَ الْحُسَيْنُ بْنُ حُرَيْثٍ الْمَرْوَزِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ الْوَاسِطِيُّ عَنِ الإِفْرِيقِيِّ ‏.‏ وَهُوَ إِسْنَادٌ ضَعِيفٌ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ ذُكِرَ لِهِشَامِ بْنِ عُرْوَةَ هَذَا الْحَدِيثُ فَقَالَ هَذَا إِسْنَادٌ مَشْرِقِيٌّ ‏.‏ قَالَ سَمِعْتُ أَحْمَدَ بْنَ الْحَسَنِ يَقُولُ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ مَا رَأَيْتُ بِعَيْنِي مِثْلَ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ ‏.‏\hadithno{59}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{It has been related in a narration from Ibn Umar that :the Prophet said: "Whoever performs Wudu while in a state of purity, Allah writes for him on account of it ten good merits}}
\hadithdefcmd{tirmidhi}{60}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ، هُوَ ابْنُ مَهْدِيٍّ قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ سَعِيدٍ، عَنْ عَمْرِو بْنِ عَامِرٍ الأَنْصَارِيِّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَوَضَّأُ عِنْدَ كُلِّ صَلاَةٍ ‏.‏ قُلْتُ فَأَنْتُمْ مَا كُنْتُمْ تَصْنَعُونَ قَالَ كُنَّا نُصَلِّي الصَّلَوَاتِ كُلَّهَا بِوُضُوءٍ وَاحِدٍ مَا لَمْ نُحْدِثْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{60}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Amr bin Amir Al-Ansari narrated that he heard Anas bin Malik saying:"The Prophet would perform Wudu for every Salat." I said, "So what about you, what would you do?" He said I wouId pray all of the prayers with one Wudu, as long as we had not committed Hadath (anything that invalidates Wudu)}}
\hadithdefcmd{tirmidhi}{61}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَوَضَّأُ لِكُلِّ صَلاَةٍ فَلَمَّا كَانَ عَامُ الْفَتْحِ صَلَّى الصَّلَوَاتِ كُلَّهَا بِوُضُوءٍ وَاحِدٍ وَمَسَحَ عَلَى خُفَّيْهِ ‏.‏ فَقَالَ عُمَرُ إِنَّكَ فَعَلْتَ شَيْئًا لَمْ تَكُنْ فَعَلْتَهُ ‏.‏ قَالَ ‏"‏ عَمْدًا فَعَلْتُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى هَذَا الْحَدِيثَ عَلِيُّ بْنُ قَادِمٍ عَنْ سُفْيَانَ الثَّوْرِيِّ وَزَادَ فِيهِ ‏"‏ تَوَضَّأَ مَرَّةً مَرَّةً ‏"‏ ‏.‏ قَالَ وَرَوَى سُفْيَانُ الثَّوْرِيُّ هَذَا الْحَدِيثَ أَيْضًا عَنْ مُحَارِبِ بْنِ دِثَارٍ عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَوَضَّأُ لِكُلِّ صَلاَةٍ ‏.‏ وَرَوَاهُ وَكِيعٌ عَنْ سُفْيَانَ عَنْ مُحَارِبِ بْنِ دِثَارٍ عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ عَنْ أَبِيهِ ‏.‏ قَالَ وَرَوَاهُ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ وَغَيْرُهُ عَنْ سُفْيَانَ عَنْ مُحَارِبِ بْنِ دِثَارٍ عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَهَذَا أَصَحُّ مِنْ حَدِيثِ وَكِيعٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ يُصَلِّي الصَّلَوَاتِ بِوُضُوءٍ وَاحِدٍ مَا لَمْ يُحْدِثْ وَكَانَ بَعْضُهُمْ يَتَوَضَّأُ لِكُلِّ صَلاَةٍ اسْتِحْبَابًا وَإِرَادَةَ الْفَضْلِ ‏.‏ وَيُرْوَى عَنِ الإِفْرِيقِيِّ عَنْ أَبِي غُطَيْفٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ تَوَضَّأَ عَلَى طُهْرٍ كَتَبَ اللَّهُ لَهُ بِهِ عَشْرَ حَسَنَاتٍ ‏"‏ ‏.‏ وَهَذَا إِسْنَادٌ ضَعِيفٌ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ وَالْعَصْرَ بِوُضُوءٍ وَاحِدٍ ‏.‏\hadithno{61}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sulaiman bin Buraidah narrated that his father said:"The Prophet would perform Wudu for every Salat. So during the year of the Conquest, he performed all of the prayers with one Wudu, and he wiped over his Khuff. So Umar said, 'You did something that you have not done before?' He replied: "I did it on purpose}}
\hadithdefcmd{tirmidhi}{62}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَتْنِي مَيْمُونَةُ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ مِنَ الْجَنَابَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ عَامَّةِ الْفُقَهَاءِ أَنْ لاَ بَأْسَ أَنْ يَغْتَسِلَ الرَّجُلُ وَالْمَرْأَةُ مِنْ إِنَاءٍ وَاحِدٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ وَأَنَسٍ وَأُمِّ هَانِئٍ وَأُمِّ صُبَيَّةَ الْجُهَنِيَّةِ وَأُمِّ سَلَمَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو الشَّعْثَاءِ اسْمُهُ جَابِرُ بْنُ زَيْدٍ ‏.‏\hadithno{62}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Maimunah said:"I and Allah's Messenger would perform Ghusl for Janabah from one vessel}}
\hadithdefcmd{tirmidhi}{63}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي حَاجِبٍ، عَنْ رَجُلٍ، مِنْ بَنِي غِفَارٍ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ فَضْلِ طَهُورِ الْمَرْأَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ ‏.‏ قَالَ أَبُو عِيسَى وَكَرِهَ بَعْضُ الْفُقَهَاءِ الْوُضُوءَ بِفَضْلِ طَهُورِ الْمَرْأَةِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ كَرِهَا فَضْلَ طَهُورِهَا وَلَمْ يَرَيَا بِفَضْلِ سُؤْرِهَا بَأْسًا ‏.‏\hadithno{63}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hajib narrated from a man from Banu Ghifar who said:"The Prophet prohibited using the leftover (water) of a woman's Purification}}
\hadithdefcmd{tirmidhi}{64}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنْ عَاصِمٍ، قَالَ سَمِعْتُ أَبَا حَاجِبٍ، يُحَدِّثُ عَنِ الْحَكَمِ بْنِ عَمْرٍو الْغِفَارِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَتَوَضَّأَ الرَّجُلُ بِفَضْلِ طَهُورِ الْمَرْأَةِ ‏.‏ أَوْ قَالَ ‏ "‏ بِسُؤْرِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو حَاجِبٍ اسْمُهُ سَوَادَةُ بْنُ عَاصِمٍ ‏.‏ وَقَالَ مُحَمَّدُ بْنُ بَشَّارٍ فِي حَدِيثِهِ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَتَوَضَّأَ الرَّجُلُ بِفَضْلِ طَهُورِ الْمَرْأَةِ ‏.‏ وَلَمْ يَشُكَّ فِيهِ مُحَمَّدُ بْنُ بَشَّارٍ ‏.‏\hadithno{64}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{A1-Hakim bin Amr AI-Ghifari narrated that:"The Prophet forbade that a man should perform Wudu with the leftover (water) from a woman's purifcation." Or, he said: "from her drinking}}
\hadithdefcmd{tirmidhi}{65}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ اغْتَسَلَ بَعْضُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم فِي جَفْنَةٍ فَأَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَتَوَضَّأَ مِنْهُ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ جُنُبًا ‏.‏ فَقَالَ ‏ "‏ إِنَّ الْمَاءَ لاَ يُجْنِبُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكٍ وَالشَّافِعِيِّ ‏.‏\hadithno{65}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{[Ibn Abbas narrated:"One of the wives of the Prophet performed Ghusl with a bowl. Allah's Messenger wanted to perform Wudu with it, so she said: 'O Messenger of Allah! Indeed I am ]unub.' So he said: 'Indeed, water does not become Junub}}
\hadithdefcmd{tirmidhi}{66}{حَدَّثَنَا هَنَّادٌ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ رَافِعِ بْنِ خَدِيجٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ أَنَتَوَضَّأُ مِنْ بِئْرِ بُضَاعَةَ وَهِيَ بِئْرٌ يُلْقَى فِيهَا الْحِيَضُ وَلُحُومُ الْكِلاَبِ وَالنَّتْنُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَاءَ طَهُورٌ لاَ يُنَجِّسُهُ شَيْءٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ جَوَّدَ أَبُو أُسَامَةَ هَذَا الْحَدِيثَ فَلَمْ يَرْوِ أَحَدٌ حَدِيثَ أَبِي سَعِيدٍ فِي بِئْرِ بُضَاعَةَ أَحْسَنَ مِمَّا رَوَى أَبُو أُسَامَةَ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي سَعِيدٍ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَعَائِشَةَ ‏.‏\hadithno{66}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eed AI-Khudri narrated:"It was said, 'O Allah's Messenger! Shall we use the water of Buda'ah well to perform ablution while it is a well in which menstruation rags, flesh of dogs and the putrid are dumped?" Allah's Messenger said: 'Indeed water is pure, nothing makes it impure}}
\hadithdefcmd{tirmidhi}{67}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يُسْأَلُ عَنِ الْمَاءِ يَكُونُ فِي الْفَلاَةِ مِنَ الأَرْضِ وَمَا يَنُوبُهُ مِنَ السِّبَاعِ وَالدَّوَابِّ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ الْمَاءُ قُلَّتَيْنِ لَمْ يَحْمِلِ الْخَبَثَ ‏"‏ ‏.‏ قَالَ عَبْدَةُ قَالَ مُحَمَّدُ بْنُ إِسْحَاقَ الْقُلَّةُ هِيَ الْجِرَارُ وَالْقُلَّةُ الَّتِي يُسْتَقَى فِيهَا ‏.‏ قَالَ أَبُو عِيسَى وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ قَالُوا إِذَا كَانَ الْمَاءُ قُلَّتَيْنِ لَمْ يُنَجِّسْهُ شَيْءٌ مَا لَمْ يَتَغَيَّرْ رِيحُهُ أَوْ طَعْمُهُ وَقَالُوا يَكُونُ نَحْوًا مِنْ خَمْسِ قِرَبٍ ‏.‏\hadithno{67}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Umar narrated:"I heard AlIah's Messenger while he was being asked about water in open areas of the land, and predators and beasts come to it." He said: 'So Allah's Messenger said: 'When the water is two Qullah it does not carry filth}}
\hadithdefcmd{tirmidhi}{68}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ ثُمَّ يَتَوَضَّأُ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏\hadithno{68}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Let none of you urinate [in still water, then perform Wudu with it]}}
\hadithdefcmd{tirmidhi}{69}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا الأَنْصَارِيُّ، إِسْحَاقُ بْنُ مُوسَى حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ سَلَمَةَ، مِنْ آلِ ابْنِ الأَزْرَقِ أَنَّ الْمُغِيرَةَ بْنَ أَبِي بُرْدَةَ، وَهُوَ مِنْ بَنِي عَبْدِ الدَّارِ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نَرْكَبُ الْبَحْرَ وَنَحْمِلُ مَعَنَا الْقَلِيلَ مِنَ الْمَاءِ فَإِنْ تَوَضَّأْنَا بِهِ عَطِشْنَا أَفَنَتَوَضَّأُ مِنْ مَاءِ الْبَحْرِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَالْفِرَاسِيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ الْفُقَهَاءِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ وَعُمَرُ وَابْنُ عَبَّاسٍ لَمْ يَرَوْا بَأْسًا بِمَاءِ الْبَحْرِ ‏.‏ وَقَدْ كَرِهَ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم الْوُضُوءَ بِمَاءِ الْبَحْرِ مِنْهُمُ ابْنُ عُمَرَ وَعَبْدُ اللَّهِ بْنُ عَمْرٍو ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو هُوَ نَارٌ ‏.‏\hadithno{69}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated:"A man asked Allah's Messenger 'O Messenger of Allah! We sail the seas, and we only carry a little water with us. If we use it for Wudu then we will go thirsty. So shall we perform Wudu from the (water of the) sea?' Allah's Messenger said: 'Its water is pure, and its dead are lawful}}
\hadithdefcmd{tirmidhi}{70}{حَدَّثَنَا هَنَّادٌ، وَقُتَيْبَةُ، وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ مُجَاهِدًا، يُحَدِّثُ عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ عَلَى قَبْرَيْنِ فَقَالَ ‏ "‏ إِنَّهُمَا يُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا هَذَا فَكَانَ لاَ يَسْتَتِرُ مِنْ بَوْلِهِ وَأَمَّا هَذَا فَكَانَ يَمْشِي بِالنَّمِيمَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي مُوسَى وَعَبْدِ الرَّحْمَنِ ابْنِ حَسَنَةَ وَزَيْدِ بْنِ ثَابِتٍ وَأَبِي بَكْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى مَنْصُورٌ هَذَا الْحَدِيثَ عَنْ مُجَاهِدٍ عَنِ ابْنِ عَبَّاسٍ وَلَمْ يَذْكُرْ فِيهِ عَنْ طَاوُسٍ ‏.‏ وَرِوَايَةُ الأَعْمَشِ أَصَحُّ ‏.‏ قَالَ وَسَمِعْتُ أَبَا بَكْرٍ مُحَمَّدَ بْنَ أَبَانَ الْبَلْخِيَّ مُسْتَمْلِي وَكِيعٍ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ الأَعْمَشُ أَحْفَظُ لإِسْنَادِ إِبْرَاهِيمَ مِنْ مَنْصُورٍ ‏.‏\hadithno{70}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"The Prophet passed by two graves. He said: 'These two are being punished. And they are not being punished for something major. As for this one, he would not protect himself from his urine. As for this one, he used to spread Namimah (slander)}}
\hadithdefcmd{tirmidhi}{71}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ مَنِيعٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، قَالَتْ دَخَلْتُ بِابْنٍ لِي عَلَى النَّبِيِّ صلى الله عليه وسلم لَمْ يَأْكُلِ الطَّعَامَ فَبَالَ عَلَيْهِ فَدَعَا بِمَاءٍ فَرَشَّهُ عَلَيْهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ وَزَيْنَبَ وَلُبَابَةَ بِنْتِ الْحَارِثِ وَهِيَ أُمُّ الْفَضْلِ بْنِ عَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ وَأَبِي السَّمْحِ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي لَيْلَى وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ مِثْلِ أَحْمَدَ وَإِسْحَاقَ قَالُوا يُنْضَحُ بَوْلُ الْغُلاَمِ وَيُغْسَلُ بَوْلُ الْجَارِيَةِ وَهَذَا مَا لَمْ يَطْعَمَا فَإِذَا طَعِمَا غُسِلاَ جَمِيعًا ‏.‏\hadithno{71}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{Umm Qais bin Mihsan narrated:"I entered upon the Prophet with a son of mine who was not yet eating food. He urinated on him, so he called for water which he sprinkled over it}}
\hadithdefcmd{tirmidhi}{72}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا حُمَيْدٌ، وَقَتَادَةُ، وَثَابِتٌ، عَنْ أَنَسٍ، أَنَّ نَاسًا، مِنْ عُرَيْنَةَ قَدِمُوا الْمَدِينَةَ فَاجْتَوَوْهَا فَبَعَثَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي إِبِلِ الصَّدَقَةِ وَقَالَ ‏ "‏ اشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏ ‏.‏ فَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاسْتَاقُوا الإِبِلَ وَارْتَدُّوا عَنِ الإِسْلاَمِ فَأُتِيَ بِهِمُ النَّبِيُّ صلى الله عليه وسلم فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ مِنْ خِلاَفٍ وَسَمَرَ أَعْيُنَهُمْ وَأَلْقَاهُمْ بِالْحَرَّةِ ‏.‏ قَالَ أَنَسٌ فَكُنْتُ أَرَى أَحَدَهُمْ يَكُدُّ الأَرْضَ بِفِيهِ حَتَّى مَاتُوا ‏.‏ وَرُبَّمَا قَالَ حَمَّادٌ يَكْدُمُ الأَرْضَ بِفِيهِ حَتَّى مَاتُوا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ قَالُوا لاَ بَأْسَ بِبَوْلِ مَا يُؤْكَلُ لَحْمُهُ ‏.‏\hadithno{72}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas narrated:"Some people from Urainah arrived in Al-Madinah, and they were uncomfortable (and ill from the climate). So Allah's Messenger sent them some camels from charity. He told them: "Drink from their milk and urine." So they killed the camel driver that Allah's Messenger sent, and they violently drove off the camels, and apostatized from Islam. So the Prophet came to them, he cut off their hands and feet on opposite side, and branded their eyes, and threw them in Al-Harrah." Anas said, "So I saw one of them working over the ground with his mouth, until they died}}
\hadithdefcmd{tirmidhi}{73}{حَدَّثَنَا الْفَضْلُ بْنُ سَهْلٍ الأَعْرَجُ الْبَغْدَادِيُّ، حَدَّثَنَا يَحْيَى بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ إِنَّمَا سَمَلَ النَّبِيُّ صلى الله عليه وسلم أَعْيُنَهُمْ لأَنَّهُمْ سَمَلُوا أَعْيُنَ الرُّعَاةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْلَمُ أَحَدًا ذَكَرَهُ غَيْرَ هَذَا الشَّيْخِ عَنْ يَزِيدَ بْنِ زُرَيْعٍ ‏.‏ وَهُوَ مَعْنَى قَوْلِهِ ‏:‏ ‏(‏ وَالْجُرُوحَ قِصَاصٌ ‏)‏ ‏.‏ وَقَدْ رُوِيَ عَنْ مُحَمَّدِ بْنِ سِيرِينَ قَالَ إِنَّمَا فَعَلَ بِهِمُ النَّبِيُّ صلى الله عليه وسلم هَذَا قَبْلَ أَنْ تَنْزِلَ الْحُدُودُ ‏.‏\hadithno{73}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Anas bin Malik narrated:"Allah's Messenger only poked out their eyes because they had poked out the eyes of the camel driver." Abu 'Eisa said: This Hadfth is Gharib. We do not know anyone who mentioned it other than this shaikh, from Yazid bin Zurai. And it is in accordance with the meaning of Allah's saying: "And wounds equal for equal" It has been reported that Muhammad bin Sirin said: "The Prophet only did this to them before the legislated punishments were revealed}}
\hadithdefcmd{tirmidhi}{74}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ وُضُوءَ إِلاَّ مِنْ صَوْتٍ أَوْ رِيحٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{74}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "There no Wudu except for a sound or a smell}}
\hadithdefcmd{tirmidhi}{75}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ فِي الْمَسْجِدِ فَوَجَدَ رِيحًا بَيْنَ أَلْيَتَيْهِ فَلاَ يَخْرُجْ حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ وَعَلِيِّ بْنِ طَلْقٍ وَعَائِشَةَ وَابْنِ عَبَّاسٍ وَابْنِ مَسْعُودٍ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ الْعُلَمَاءِ أَنْ لاَ يَجِبَ عَلَيْهِ الْوُضُوءُ إِلاَّ مِنْ حَدَثٍ يَسْمَعُ صَوْتًا أَوْ يَجِدُ رِيحًا ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ إِذَا شَكَّ فِي الْحَدَثِ فَإِنَّهُ لاَ يَجِبُ عَلَيْهِ الْوُضُوءُ حَتَّى يَسْتَيْقِنَ اسْتِيقَانًا يَقْدِرُ أَنْ يَحْلِفَ عَلَيْهِ ‏.‏ وَقَالَ إِذَا خَرَجَ مِنْ قُبُلِ الْمَرْأَةِ الرِّيحُ وَجَبَ عَلَيْهَا الْوُضُوءُ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَإِسْحَاقَ ‏.‏\hadithno{75}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "When one of you is in the Masjid, and he senses wind between his buttocks then he should not exit until he hears a sound or smells an odor}}
\hadithdefcmd{tirmidhi}{76}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ لاَ يَقْبَلُ صَلاَةَ أَحَدِكُمْ إِذَا أَحْدَثَ حَتَّى يَتَوَضَّأَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{76}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Indeed Allah does not accept the prayer of one of you when he commits Hadath, until he performs Wudu}}
\hadithdefcmd{tirmidhi}{77}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، - كُوفِيٌّ - وَهَنَّادٌ وَمُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ الْمَعْنَى وَاحِدٌ قَالُوا حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ الْمُلاَئِيُّ، عَنْ أَبِي خَالِدٍ الدَّالاَنِيِّ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم نَامَ وَهُوَ سَاجِدٌ حَتَّى غَطَّ أَوْ نَفَخَ ثُمَّ قَامَ يُصَلِّي ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ قَدْ نِمْتَ قَالَ ‏ "‏ إِنَّ الْوُضُوءَ لاَ يَجِبُ إِلاَّ عَلَى مَنْ نَامَ مُضْطَجِعًا فَإِنَّهُ إِذَا اضْطَجَعَ اسْتَرْخَتْ مَفَاصِلُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو خَالِدٍ اسْمُهُ يَزِيدُ بْنُ عَبْدِ الرَّحْمَنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{77}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that :he saw the Prophet sleeping, while in the prostration position, until he snored or snorted. Then he stoodup to pray. So I said: "O Messenger of Allah! You were sleeping?" He said: "Wudu is not required except for sleeping while reclining. For when one reclines, joints relax}}
\hadithdefcmd{tirmidhi}{78}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَنَامُونَ ثُمَّ يَقُومُونَ فَيُصَلُّونَ وَلاَ يَتَوَضَّئُونَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَسَمِعْتُ صَالِحَ بْنَ عَبْدِ اللَّهِ يَقُولُ سَأَلْتُ عَبْدَ اللَّهِ بْنَ الْمُبَارَكِ عَمَّنْ نَامَ قَاعِدًا مُعْتَمِدًا فَقَالَ لاَ وُضُوءَ عَلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى حَدِيثَ ابْنِ عَبَّاسٍ سَعِيدُ بْنُ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ عَنِ ابْنِ عَبَّاسٍ قَوْلَهُ وَلَمْ يَذْكُرْ فِيهِ أَبَا الْعَالِيَةِ وَلَمْ يَرْفَعْهُ ‏.‏ وَاخْتَلَفَ الْعُلَمَاءُ فِي الْوُضُوءِ مِنَ النَّوْمِ فَرَأَى أَكْثَرُهُمْ أَنْ لاَ يَجِبَ عَلَيْهِ الْوُضُوءُ إِذَا نَامَ قَاعِدًا أَوْ قَائِمًا حَتَّى يَنَامَ مُضْطَجِعًا ‏.‏ وَبِهِ يَقُولُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَأَحْمَدُ ‏.‏ قَالَ وَقَالَ بَعْضُهُمْ إِذَا نَامَ حَتَّى غُلِبَ عَلَى عَقْلِهِ وَجَبَ عَلَيْهِ الْوُضُوءُ وَبِهِ يَقُولُ إِسْحَاقُ ‏.‏ وَقَالَ الشَّافِعِيُّ مَنْ نَامَ قَاعِدًا فَرَأَى رُؤْيَا أَوْ زَالَتْ مَقْعَدَتُهُ لِوَسَنِ النَّوْمِ فَعَلَيْهِ الْوُضُوءُ ‏.‏\hadithno{78}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Anas bin Malik narrated:"The companions of Allah's Messenger would sleep, then stand to pray, They would not perform Wudu}}
\hadithdefcmd{tirmidhi}{79}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوُضُوءُ مِمَّا مَسَّتِ النَّارُ وَلَوْ مِنْ ثَوْرِ أَقِطٍ ‏"‏ ‏.‏ قَالَ فَقَالَ لَهُ ابْنُ عَبَّاسٍ يَا أَبَا هُرَيْرَةَ أَنَتَوَضَّأُ مِنَ الدُّهْنِ أَنَتَوَضَّأُ مِنَ الْحَمِيمِ قَالَ فَقَالَ أَبُو هُرَيْرَةَ يَا ابْنَ أَخِي إِذَا سَمِعْتَ حَدِيثًا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلاَ تَضْرِبْ لَهُ مَثَلاً ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ حَبِيبَةَ وَأُمِّ سَلَمَةَ وَزَيْدِ بْنِ ثَابِتٍ وَأَبِي طَلْحَةَ وَأَبِي أَيُّوبَ وَأَبِي مُوسَى ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَأَى بَعْضُ أَهْلِ الْعِلْمِ الْوُضُوءَ مِمَّا غَيَّرَتِ النَّارُ وَأَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ عَلَى تَرْكِ الْوُضُوءِ مِمَّا غَيَّرَتِ النَّارُ ‏.‏\hadithno{79}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Wudu is (required) from what fire has touched, even if it be a piece of cheese}}
\hadithdefcmd{tirmidhi}{80}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَقِيلٍ، سَمِعَ جَابِرًا، ‏.‏ قَالَ سُفْيَانُ وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَعَهُ فَدَخَلَ عَلَى امْرَأَةٍ مِنَ الأَنْصَارِ فَذَبَحَتْ لَهُ شَاةً فَأَكَلَ وَأَتَتْهُ بِقِنَاعٍ مِنْ رُطَبٍ فَأَكَلَ مِنْهُ ثُمَّ تَوَضَّأَ لِلظُّهْرِ وَصَلَّى ثُمَّ انْصَرَفَ فَأَتَتْهُ بِعُلاَلَةٍ مِنْ عُلاَلَةِ الشَّاةِ فَأَكَلَ ثُمَّ صَلَّى الْعَصْرَ وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَابْنِ مَسْعُودٍ وَأَبِي رَافِعٍ وَأُمِّ الْحَكَمِ وَعَمْرِو بْنِ أُمَيَّةَ وَأُمِّ عَامِرٍ وَسُوَيْدِ بْنِ النُّعْمَانِ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى وَلاَ يَصِحُّ حَدِيثُ أَبِي بَكْرٍ فِي هَذَا الْبَابِ مِنْ قِبَلِ إِسْنَادِهِ إِنَّمَا رَوَاهُ حُسَامُ بْنُ مِصَكٍّ عَنِ ابْنِ سِيرِينَ عَنِ ابْنِ عَبَّاسٍ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالصَّحِيحُ إِنَّمَا هُوَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ هَكَذَا رَوَى الْحُفَّاظُ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ مِثْلِ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ رَأَوْا تَرْكَ الْوُضُوءِ مِمَّا مَسَّتِ النَّارُ ‏.‏ وَهَذَا آخِرُ الأَمْرَيْنِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَكَأَنَّ هَذَا الْحَدِيثَ نَاسِخٌ لِلْحَدِيثِ الأَوَّلِ حَدِيثِ الْوُضُوءِ مِمَّا مَسَّتِ النَّارُ ‏.‏\hadithno{80}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir narrated:"Allah's Messenger went out and I went with him. He entered upon a woman from the Ansar. She slaughtered a sheep and he ate from it; and she brought a basket with ripe dates and he ate from it. Then he performed Wudu for Zuhr and prayed. Then he finished, so she brought him something from the remainder of the sheep. So he ate it, then prayed Asr and did not perform Wudu}}
\hadithdefcmd{tirmidhi}{81}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ الرَّازِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوُضُوءِ مِنْ لُحُومِ الإِبِلِ فَقَالَ ‏"‏ تَوَضَّئُوا مِنْهَا ‏"‏ ‏.‏ وَسُئِلَ عَنِ الْوُضُوءِ مِنْ لُحُومِ الْغَنَمِ فَقَالَ ‏"‏ لاَ تَتَوَضَّئُوا مِنْهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرِ بْنِ سَمُرَةَ وَأُسَيْدِ بْنِ حُضَيْرٍ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى الْحَجَّاجُ بْنُ أَرْطَاةَ هَذَا الْحَدِيثَ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى عَنْ أُسَيْدِ بْنِ حُضَيْرٍ ‏.‏ وَالصَّحِيحُ حَدِيثُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى عَنِ الْبَرَاءِ بْنِ عَازِبٍ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَقَدْ رُوِيَ عَنْ بَعْضِ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ وَغَيْرِهِمْ أَنَّهُمْ لَمْ يَرَوُا الْوُضُوءَ مِنْ لُحُومِ الإِبِلِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{81}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Bara bin Azib narrated:Allah's Messenger was asked about performing Wudu for camel meat. He said: "Perform Wudu for it." He Was asked about Wudu after eating goat meat. So he said: "Do not perform Wudu for it}}
\hadithdefcmd{tirmidhi}{82}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي، عَنْ بُسْرَةَ بِنْتِ صَفْوَانَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَسَّ ذَكَرَهُ فَلاَ يُصَلِّ حَتَّى يَتَوَضَّأَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ حَبِيبَةَ وَأَبِي أَيُّوبَ وَأَبِي هُرَيْرَةَ وَأَرْوَى ابْنَةِ أُنَيْسٍ وَعَائِشَةَ وَجَابِرٍ وَزَيْدِ بْنِ خَالِدٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ هَكَذَا رَوَاهُ غَيْرُ وَاحِدٍ مِثْلَ هَذَا عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ بُسْرَةَ ‏.‏\hadithno{82}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Busrah bint Safwan narrated that :the Prophet said: "Whoever touches his penis, then he is not to pray until he performs Wudu}}
\hadithdefcmd{tirmidhi}{83}{وَرَوَى أَبُو أُسَامَةَ، وَغَيْرُ، وَاحِدٍ، هَذَا الْحَدِيثَ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ مَرْوَانَ، عَنْ بُسْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ حَدَّثَنَا بِذَلِكَ، إِسْحَاقُ بْنُ مَنْصُورٍ حَدَّثَنَا أَبُو أُسَامَةَ، بِهَذَا ‏.‏\hadithno{83}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Busrah narrated :a similar report (as no. 82) from the Prophet}}
\hadithdefcmd{tirmidhi}{84}{وَرَوَى هَذَا الْحَدِيثَ أَبُو الزِّنَادِ، عَنْ عُرْوَةَ، عَنْ بُسْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا بِذَلِكَ، عَلِيُّ بْنُ حُجْرٍ قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ بُسْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَبِهِ يَقُولُ الأَوْزَاعِيُّ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ قَالَ مُحَمَّدٌ وَأَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ حَدِيثُ بُسْرَةَ ‏.‏ وَقَالَ أَبُو زُرْعَةَ حَدِيثُ أُمِّ حَبِيبَةَ فِي هَذَا الْبَابِ صَحِيحٌ وَهُوَ حَدِيثُ الْعَلاَءِ بْنِ الْحَارِثِ عَنْ مَكْحُولٍ عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ عَنْ أُمِّ حَبِيبَةَ ‏.‏ وَقَالَ مُحَمَّدٌ لَمْ يَسْمَعْ مَكْحُولٌ مِنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ وَرَوَى مَكْحُولٌ عَنْ رَجُلٍ عَنْ عَنْبَسَةَ غَيْرَ هَذَا الْحَدِيثِ ‏.‏ وَكَأَنَّهُ لَمْ يَرَ هَذَا الْحَدِيثَ صَحِيحًا ‏.‏\hadithno{84}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Busrah narrated that :the Prophet said a similar Hadith}}
\hadithdefcmd{tirmidhi}{85}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ بَدْرٍ، عَنْ قَيْسِ بْنِ طَلْقِ بْنِ عَلِيٍّ، هُوَ الْحَنَفِيُّ عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَهَلْ هُوَ إِلاَّ مُضْغَةٌ مِنْهُ أَوْ بَضْعَةٌ مِنْهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَبَعْضِ التَّابِعِينَ أَنَّهُمْ لَمْ يَرَوُا الْوُضُوءَ مِنْ مَسِّ الذَّكَرِ وَهُوَ قَوْلُ أَهْلِ الْكُوفَةِ وَابْنِ الْمُبَارَكِ ‏.‏ وَهَذَا الْحَدِيثُ أَحْسَنُ شَيْءٍ رُوِيَ فِي هَذَا الْبَابِ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ أَيُّوبُ بْنُ عُتْبَةَ وَمُحَمَّدُ بْنُ جَابِرٍ عَنْ قَيْسِ بْنِ طَلْقٍ عَنْ أَبِيهِ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْحَدِيثِ فِي مُحَمَّدِ بْنِ جَابِرٍ وَأَيُّوبَ بْنِ عُتْبَةَ ‏.‏ وَحَدِيثُ مُلاَزِمِ بْنِ عَمْرٍو عَنْ عَبْدِ اللَّهِ بْنِ بَدْرٍ أَصَحُّ وَأَحْسَنُ ‏.‏\hadithno{85}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Qais bin Talq bin Ali - [and he is] Al-Hanafi narrated from his father, that:the Prophet said: 'Is it other than a piece of his flesh?" Or: "part of him?}}
\hadithdefcmd{tirmidhi}{86}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، وَأَبُو كُرَيْبٍ وَأَحْمَدُ بْنُ مَنِيعٍ وَمَحْمُودُ بْنُ غَيْلاَنَ وَأَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ قَالُوا حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَبَّلَ بَعْضَ نِسَائِهِ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ قُلْتُ مَنْ هِيَ إِلاَّ أَنْتِ قَالَ فَضَحِكَتْ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ نَحْوُ هَذَا عَنْ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ قَالُوا لَيْسَ فِي الْقُبْلَةِ وُضُوءٌ ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ وَالأَوْزَاعِيُّ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ فِي الْقُبْلَةِ وُضُوءٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ ‏.‏ وَإِنَّمَا تَرَكَ أَصْحَابُنَا حَدِيثَ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا لأَنَّهُ لاَ يَصِحُّ عِنْدَهُمْ لِحَالِ الإِسْنَادِ ‏.‏ قَالَ وَسَمِعْتُ أَبَا بَكْرٍ الْعَطَّارَ الْبَصْرِيَّ يَذْكُرُ عَنْ عَلِيِّ بْنِ الْمَدِينِيِّ قَالَ ضَعَّفَ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ هَذَا الْحَدِيثَ جِدًّا ‏.‏ وَقَالَ هُوَ شِبْهُ لاَ شَىْءَ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يُضَعِّفُ هَذَا الْحَدِيثَ وَقَالَ حَبِيبُ بْنُ أَبِي ثَابِتٍ لَمْ يَسْمَعْ مِنْ عُرْوَةَ ‏.‏ وَقَدْ رُوِيَ عَنْ إِبْرَاهِيمَ التَّيْمِيِّ عَنْ عَائِشَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَبَّلَهَا وَلَمْ يَتَوَضَّأْ ‏.‏ وَهَذَا لاَ يَصِحُّ أَيْضًا ‏.‏ وَلاَ نَعْرِفُ لإِبْرَاهِيمَ التَّيْمِيِّ سَمَاعًا مِنْ عَائِشَةَ ‏.‏ وَلَيْسَ يَصِحُّ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ شَيْءٌ ‏.‏\hadithno{86}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Urwah narrated from Aishah that:"The Prophet kissed one of his wives, then he went to the prayer and did not perform Wudu." He (Urwah) said: "I said 'Who was it except you?'" [He said:] "So she laughed}}
\hadithdefcmd{tirmidhi}{87}{حَدَّثَنَا أَبُو عُبَيْدَةَ بْنُ أَبِي السَّفَرِ، - وَهُوَ أَحْمَدُ بْنُ عَبْدِ اللَّهِ الْهَمْدَانِيُّ الْكُوفِيُّ وَإِسْحَاقُ بْنُ مَنْصُورٍ قَالَ أَبُو عُبَيْدَةَ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنِي أَبِي، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو الأَوْزَاعِيُّ، عَنْ يَعِيشَ بْنِ الْوَلِيدِ الْمَخْزُومِيِّ، عَنْ أَبِيهِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي الدَّرْدَاءِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَاءَ فَأَفْطَرَ فَتَوَضَّأَ ‏.‏ فَلَقِيتُ ثَوْبَانَ فِي مَسْجِدِ دِمَشْقَ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ صَدَقَ أَنَا صَبَبْتُ لَهُ وَضُوءَهُ ‏.‏ قَالَ أَبُو عِيسَى وَقَالَ إِسْحَاقُ بْنُ مَنْصُورٍ مَعْدَانُ بْنُ طَلْحَةَ ‏.‏ قَالَ أَبُو عِيسَى وَابْنُ أَبِي طَلْحَةَ أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَأَى غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ مِنَ التَّابِعِينَ الْوُضُوءَ مِنَ الْقَىْءِ وَالرُّعَافِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لَيْسَ فِي الْقَىْءِ وَالرُّعَافِ وُضُوءٌ ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ ‏.‏ وَقَدْ جَوَّدَ حُسَيْنٌ الْمُعَلِّمُ هَذَا الْحَدِيثَ ‏.‏ وَحَدِيثُ حُسَيْنٍ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ ‏.‏ وَرَوَى مَعْمَرٌ هَذَا الْحَدِيثَ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ فَأَخْطَأَ فِيهِ فَقَالَ عَنْ يَعِيشَ بْنِ الْوَلِيدِ عَنْ خَالِدِ بْنِ مَعْدَانَ عَنْ أَبِي الدَّرْدَاءِ وَلَمْ يَذْكُرْ فِيهِ الأَوْزَاعِيَّ وَقَالَ عَنْ خَالِدِ بْنِ مَعْدَانَ وَإِنَّمَا هُوَ مَعْدَانُ بْنُ أَبِي طَلْحَةَ ‏.‏\hadithno{87}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Madan bin Abi Talhah narrated from Abu Ad-Darda that :"Allah's Messenger vomited [so he broke fast] so he performed Wudu." So I met Thawban in a Masjid in Damascus, and I mentioned that to him. He said: 'He told the truth, I poured the water for his Wudu}}
\hadithdefcmd{tirmidhi}{88}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي فَزَارَةَ، عَنْ أَبِي زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ سَأَلَنِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا فِي إِدَاوَتِكَ ‏"‏ ‏.‏ فَقُلْتُ نَبِيذٌ ‏.‏ فَقَالَ ‏"‏ تَمْرَةٌ طَيِّبَةٌ وَمَاءٌ طَهُورٌ ‏"‏ ‏.‏ قَالَ فَتَوَضَّأَ مِنْهُ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا رُوِيَ هَذَا الْحَدِيثُ عَنْ أَبِي زَيْدٍ عَنْ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَبُو زَيْدٍ رَجُلٌ مَجْهُولٌ عِنْدَ أَهْلِ الْحَدِيثِ لاَ يُعْرَفُ لَهُ رِوَايَةٌ غَيْرُ هَذَا الْحَدِيثِ ‏.‏ وَقَدْ رَأَى بَعْضُ أَهْلِ الْعِلْمِ الْوُضُوءَ بِالنَّبِيذِ مِنْهُمْ سُفْيَانُ الثَّوْرِيُّ وَغَيْرُهُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يُتَوَضَّأُ بِالنَّبِيذِ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ إِسْحَاقُ إِنِ ابْتُلِيَ رَجُلٌ بِهَذَا فَتَوَضَّأَ بِالنَّبِيذِ وَتَيَمَّمَ أَحَبُّ إِلَىَّ ‏.‏ قَالَ أَبُو عِيسَى وَقَوْلُ مَنْ يَقُولُ لاَ يُتَوَضَّأُ بِالنَّبِيذِ أَقْرَبُ إِلَى الْكِتَابِ وَأَشْبَهُ لأَنَّ اللَّهَ تَعَالَى قَالَ‏:‏ ‏"‏فإِن لَمْ تَجِدُوا مَاءً فَتَيَمَّمُوا صَعِيدًا طَيِّبًا ‏"‏‏.‏\hadithno{88}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated:"The Prophet asked me: "What is in your Idawah (water skin)?" I said: "Nabidh." He said: "Dates are wholesome and water is pure." He said: "So he performed Wudu with it}}
\hadithdefcmd{tirmidhi}{89}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم شَرِبَ لَبَنًا فَدَعَا بِمَاءٍ فَمَضْمَضَ وَقَالَ ‏ "‏ إِنَّ لَهُ دَسَمًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَأَى بَعْضُ أَهْلِ الْعِلْمِ الْمَضْمَضَةَ مِنَ اللَّبَنِ وَهَذَا عِنْدَنَا عَلَى الاِسْتِحْبَابِ وَلَمْ يَرَ بَعْضُهُمُ الْمَضْمَضَةَ مِنَ اللَّبَنِ ‏.‏\hadithno{89}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated :the Prophet drank milk. Then he called for water to rinse out his mouth. Then he said: "Indeed it has fat." [He said:] There are narrations on this topic from Sahl bin Sa'd As-Sa'idi and Umm Salamah. Abu Eisa said: [And] this Hadith is Hasan Sahih. Some of the people of knowledge held the view that one is to wash the mouth after drinking milk and this is recommended according us. Some others did not hold the view that one is to wash out the mouth after drinking milk}}
\hadithdefcmd{tirmidhi}{90}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا أَبُو أَحْمَدَ، مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الزُّبَيْرِيُّ عَنْ سُفْيَانَ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، سَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَبُولُ فَلَمْ يَرُدَّ عَلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِنَّمَا يُكْرَهُ هَذَا عِنْدَنَا إِذَا كَانَ عَلَى الْغَائِطِ وَالْبَوْلِ ‏.‏ وَقَدْ فَسَّرَ بَعْضُ أَهْلِ الْعِلْمِ ذَلِكَ ‏.‏ وَهَذَا أَحْسَنُ شَيْءٍ رُوِيَ فِي هَذَا الْبَابِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ الْمُهَاجِرِ بْنِ قُنْفُذٍ وَعَبْدِ اللَّهِ بْنِ حَنْظَلَةَ وَعَلْقَمَةَ بْنِ الْفَغْوَاءِ وَجَابِرٍ وَالْبَرَاءِ ‏.‏\hadithno{90}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Umar narrated:"A man greeted the Prophet (with Salam), and he was urinating, so he did not respond to him}}
\hadithdefcmd{tirmidhi}{91}{حَدَّثَنَا سَوَّارُ بْنُ عَبْدِ اللَّهِ الْعَنْبَرِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَيُّوبَ، يُحَدِّثُ عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ يُغْسَلُ الإِنَاءُ إِذَا وَلَغَ فِيهِ الْكَلْبُ سَبْعَ مَرَّاتٍ أُولاَهُنَّ أَوْ أُخْرَاهُنَّ بِالتُّرَابِ وَإِذَا وَلَغَتْ فِيهِ الْهِرَّةُ غُسِلَ مَرَّةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا وَلَمْ يُذْكَرْ فِيهِ ‏"‏ إِذَا وَلَغَتْ فِيهِ الْهِرَّةُ غُسِلَ مَرَّةً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ ‏.‏\hadithno{91}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Wash the vessel the dog has drunk from seven times: the first or the last of them with dirt. And when the cat drinks out of it, wash it once}}
\hadithdefcmd{tirmidhi}{92}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ حُمَيْدَةَ بِنْتِ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ كَبْشَةَ بِنْتِ كَعْبِ بْنِ مَالِكٍ، وَكَانَتْ، عِنْدَ ابْنِ أَبِي قَتَادَةَ أَنَّ أَبَا قَتَادَةَ، دَخَلَ عَلَيْهَا ‏.‏ قَالَتْ فَسَكَبْتُ لَهُ وَضُوءًا قَالَتْ فَجَاءَتْ هِرَّةٌ تَشْرَبُ فَأَصْغَى لَهَا الإِنَاءَ حَتَّى شَرِبَتْ قَالَتْ كَبْشَةُ فَرَآنِي أَنْظُرُ إِلَيْهِ فَقَالَ أَتَعْجَبِينَ يَا بِنْتَ أَخِي فَقُلْتُ نَعَمْ ‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهَا لَيْسَتْ بِنَجَسٍ إِنَّمَا هِيَ مِنَ الطَّوَّافِينَ عَلَيْكُمْ أَوِ الطَّوَّافَاتِ ‏"‏ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ الْعُلَمَاءِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ مِثْلِ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ لَمْ يَرَوْا بِسُؤْرِ الْهِرَّةِ بَأْسًا ‏.‏ وَهَذَا أَحَسَنُ شَيْءٍ رُوِيَ فِي هَذَا الْبَابِ ‏.‏ وَقَدْ جَوَّدَ مَالِكٌ هَذَا الْحَدِيثَ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ وَلَمْ يَأْتِ بِهِ أَحَدٌ أَتَمَّ مِنْ مَالِكٍ ‏.‏\hadithno{92}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Humaidah bint Ubaid bin Rifa'ah narrated:"Kabshah bint Ka'b bin Malik - she was (married) with Ibn Abi Qatadah - narrated "That Abu Qatadah visited her, [so she said:] 'So I poured water for him to use for Wudu.' She said: 'A cat came to drink, so he lowered he container until it drank.' Kabshah said: 'So he saw me looking at it and said, "O my niece! Are you surprised at that?" So I said yes. He said: "Indeed Allah's Messenger said 'It is not impure, it is only one of those roam around among you}}
\hadithdefcmd{tirmidhi}{93}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، قَالَ بَالَ جَرِيرُ بْنُ عَبْدِ اللَّهِ ثُمَّ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ فَقِيلَ لَهُ أَتَفْعَلُ هَذَا قَالَ وَمَا يَمْنَعُنِي وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ ‏.‏ قَالَ إِبْرَاهِيمُ وَكَانَ يُعْجِبُهُمْ حَدِيثُ جَرِيرٍ لأَنَّ إِسْلاَمَهُ كَانَ بَعْدَ نُزُولِ الْمَائِدَةِ ‏.‏ هَذَا قَوْلُ إِبْرَاهِيمَ يَعْنِي كَانَ يُعْجِبُهُمْ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَحُذَيْفَةَ وَالْمُغِيرَةِ وَبِلاَلٍ وَسَعْدٍ وَأَبِي أَيُّوبَ وَسَلْمَانَ وَبُرَيْدَةَ وَعَمْرِو بْنِ أُمَيَّةَ وَأَنَسٍ وَسَهْلِ بْنِ سَعْدٍ وَيَعْلَى بْنِ مُرَّةَ وَعُبَادَةَ بْنِ الصَّامِتِ وَأُسَامَةَ بْنِ شَرِيكٍ وَأَبِي أُمَامَةَ وَجَابِرٍ وَأُسَامَةَ بْنِ زَيْدٍ وَابْنِ عُبَادَةَ وَيُقَالُ ابْنُ عِمَارَةَ وَأُبَىُّ بْنُ عِمَارَةَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ جَرِيرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{93}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Hammam bin AI-Harith narrated:"Jarir bin Abdullah urinated, then he performed Wudu, wiping over his Khuff. So he was asked, 'You do this?' He replied, 'What prevents me, when I have seen Allah's Messenger doing it?" He [Ibrahim] said "And they were impressed by the narration of Jarir since he accepted Islam after the revelation Sural Al-Ma'idah." [This is the saying of lbrahim, that is, "They were impressed."] [He said:] There are narrations on this topic from Umar, Ali, Hudhaifah, AI-Mughirah, Bilil, Sa'd, Abu Ayyub, Salman, Buraidah, Amr bin Umayyah, Anas, Sahl bin Sa'd, Ya'la bin Murrah, Ubadah bin As-Samit, Usamah bin Shank, Abu Umamah, Jabir, Usamah bin Zaid, and Ibn Ubadah. They call him Ibn Imarah and Ubayy bin Imarah}}
\hadithdefcmd{tirmidhi}{94}{وَيُرْوَى عَنْ شَهْرِ بْنِ حَوْشَبٍ، قَالَ رَأَيْتُ جَرِيرَ بْنَ عَبْدِ اللَّهِ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ فَقُلْتُ لَهُ فِي ذَلِكَ فَقَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ ‏.‏ فَقُلْتُ لَهُ أَقَبْلَ الْمَائِدَةِ أَمْ بَعْدَ الْمَائِدَةِ فَقَالَ مَا أَسْلَمْتُ إِلاَّ بَعْدَ الْمَائِدَةِ ‏.‏ حَدَّثَنَا بِذَلِكَ قُتَيْبَةُ حَدَّثَنَا خَالِدُ بْنُ زِيَادٍ التِّرْمِذِيُّ عَنْ مُقَاتِلِ بْنِ حَيَّانَ عَنْ شَهْرِ بْنِ حَوْشَبٍ عَنْ جَرِيرٍ ‏.‏ قَالَ وَرَوَى بَقِيَّةُ عَنْ إِبْرَاهِيمَ بْنِ أَدْهَمَ عَنْ مُقَاتِلِ بْنِ حَيَّانَ عَنْ شَهْرِ بْنِ حَوْشَبٍ عَنْ جَرِيرٍ ‏.‏ وَهَذَا حَدِيثٌ مُفَسِّرٌ لأَنَّ بَعْضَ مَنْ أَنْكَرَ الْمَسْحَ عَلَى الْخُفَّيْنِ تَأَوَّلَ أَنَّ مَسْحَ النَّبِيِّ صلى الله عليه وسلم عَلَى الْخُفَّيْنِ كَانَ قَبْلَ نُزُولِ الْمَائِدَةِ وَذَكَرَ جَرِيرٌ فِي حَدِيثِهِ أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم مَسَحَ عَلَى الْخُفَّيْنِ بَعْدَ نُزُولِ الْمَائِدَةِ ‏.‏\hadithno{94}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It has been related from Sahr bin Hawshah that he said:"I saw Jarir bin 'Abdullah performing Wudu and he wiped over his Khuff. I asked him about that. He replied, 'I saw 'I saw Allah's Messenger performing Wudu and he wiped over his Khuff.' So I said to him, before Surah AI-Ma'idah (was revealed) or after AI-Ma'idah?' So he replied, 'I did not acceot Islam until after Al-Ma'idah.'" Qutaibah narrated this to us; (saying) Khalid bin Ziyad At-Tirmidhi narrated it to us, from Muqatil bin Hayyan, from Shahr bin Hawshah, from Jarir. He said: Baqiyyah related it from Ibrahim bin Adham from Muqatil bin Hayyan, from Shahr bin Hawshah, from Jarir. This Hadith is explanatory, because some who dislike wiping over the Khuff give the interpretation that the Prophet's wiping over the two Khuff was before the revelation of Sural Al-Ma'idah. But in his Hadlth, Jarir mentions that he saw the Prophet wiping over his Khuff after the revelation of Surat Al-Ma'idah}}
\hadithdefcmd{tirmidhi}{95}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ أَبِي عَبْدِ اللَّهِ الْجَدَلِيِّ، عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ سُئِلَ عَنِ الْمَسْحِ عَلَى الْخُفَّيْنِ فَقَالَ ‏ "‏ لِلْمُسَافِرِ ثَلاَثَةٌ وَلِلْمُقِيمِ يَوْمٌ ‏"‏ ‏.‏ وَذُكِرَ عَنْ يَحْيَى بْنِ مَعِينٍ أَنَّهُ صَحَّحَ حَدِيثَ خُزَيْمَةَ بْنِ ثَابِتٍ فِي الْمَسْحِ ‏.‏ وَأَبُو عَبْدِ اللَّهِ الْجَدَلِيُّ اسْمُهُ عَبْدُ بْنُ عَبْدٍ وَيُقَالُ عَبْدُ الرَّحْمَنِ بْنُ عَبْدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي بَكْرَةَ وَأَبِي هُرَيْرَةَ وَصَفْوَانَ بْنِ عَسَّالٍ وَعَوْفِ بْنِ مَالِكٍ وَابْنِ عُمَرَ وَجَرِيرٍ ‏.‏\hadithno{95}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Khuzaimah bin Thabit narrated:"The Prophet was asked about wiping over the Khuff. So he said: "Three (days) for the traveler, and one day for the resident}}
\hadithdefcmd{tirmidhi}{96}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا إِذَا كُنَّا سَفْرًا أَنْ لاَ نَنْزِعَ خِفَافَنَا ثَلاَثَةَ أَيَّامٍ وَلَيَالِيَهُنَّ إِلاَّ مِنْ جَنَابَةٍ وَلَكِنْ مِنْ غَائِطٍ وَبَوْلٍ وَنَوْمٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى الْحَكَمُ بْنُ عُتَيْبَةَ وَحَمَّادٌ عَنْ إِبْرَاهِيمَ النَّخَعِيِّ عَنْ أَبِي عَبْدِ اللَّهِ الْجَدَلِيِّ عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ وَلاَ يَصِحُّ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ قَالَ شُعْبَةُ لَمْ يَسْمَعْ إِبْرَاهِيمُ النَّخَعِيُّ مِنْ أَبِي عَبْدِ اللَّهِ الْجَدَلِيِّ حَدِيثَ الْمَسْحِ ‏.‏ وَقَالَ زَائِدَةُ عَنْ مَنْصُورٍ كُنَّا فِي حُجْرَةِ إِبْرَاهِيمَ التَّيْمِيِّ وَمَعَنَا إِبْرَاهِيمُ النَّخَعِيُّ فَحَدَّثَنَا إِبْرَاهِيمُ التَّيْمِيُّ عَنْ عَمْرِو بْنِ مَيْمُونٍ عَنْ أَبِي عَبْدِ اللَّهِ الْجَدَلِيِّ عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْمَسْحِ عَلَى الْخُفَّيْنِ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ أَحْسَنُ شَيْءٍ فِي هَذَا الْبَابِ حَدِيثُ صَفْوَانَ بْنِ عَسَّالٍ الْمُرَادِيِّ ‏.‏ قَالَ أَبُو عِيسَى وَهُوَ قَوْلُ أَكْثَرِ الْعُلَمَاءِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ مِنَ الْفُقَهَاءِ مِثْلِ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ قَالُوا يَمْسَحُ الْمُقِيمُ يَوْمًا وَلَيْلَةً وَالْمُسَافِرُ ثَلاَثَةَ أَيَّامٍ وَلَيَالِيَهُنَّ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ بَعْضِ أَهْلِ الْعِلْمِ أَنَّهُمْ لَمْ يُوَقِّتُوا فِي الْمَسْحِ عَلَى الْخُفَّيْنِ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى وَالتَّوْقِيتُ أَصَحُّ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ صَفْوَانَ بْنِ عَسَّالٍ أَيْضًا مِنْ غَيْرِ حَدِيثِ عَاصِمٍ ‏.‏\hadithno{96}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Safwan bin Assal narrated:'When we were traveling, Allah's Messenger would order us not to remove our Khuff for three days and nights, except for Janabah, but not for defecating, urinating, and sleep}}
\hadithdefcmd{tirmidhi}{97}{حَدَّثَنَا أَبُو الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، أَخْبَرَنِي ثَوْرُ بْنُ يَزِيدَ، عَنْ رَجَاءِ بْنِ حَيْوَةَ، عَنْ كَاتِبِ الْمُغِيرَةِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَسَحَ أَعْلَى الْخُفِّ وَأَسْفَلَهُ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ مِنَ الْفُقَهَاءِ وَبِهِ يَقُولُ مَالِكٌ وَالشَّافِعِيُّ وَإِسْحَاقُ ‏.‏ وَهَذَا حَدِيثٌ مَعْلُولٌ لَمْ يُسْنِدْهُ عَنْ ثَوْرِ بْنِ يَزِيدَ غَيْرُ الْوَلِيدِ بْنِ مُسْلِمٍ ‏.‏ قَالَ أَبُو عِيسَى وَسَأَلْتُ أَبَا زُرْعَةَ وَمُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا الْحَدِيثِ فَقَالاَ لَيْسَ بِصَحِيحٍ لأَنَّ ابْنَ الْمُبَارَكِ رَوَى هَذَا عَنْ ثَوْرٍ عَنْ رَجَاءِ بْنِ حَيْوَةَ قَالَ حُدِّثْتُ عَنْ كَاتِبِ الْمُغِيرَةِ مُرْسَلٌ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ فِيهِ الْمُغِيرَةَ ‏.‏\hadithno{97}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{AI-Mughirah bin Shu'bah narrated:"The Prophet wiped over the Khuff and its bottom}}
\hadithdefcmd{tirmidhi}{98}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَمْسَحُ عَلَى الْخُفَّيْنِ عَلَى ظَاهِرِهِمَا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْمُغِيرَةِ حَدِيثٌ حَسَنٌ وَهُوَ حَدِيثُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الزِّنَادِ عَنْ أَبِيهِ عَنْ عُرْوَةَ عَنِ الْمُغِيرَةِ وَلاَ نَعْلَمُ أَحَدًا يَذْكُرُ عَنْ عُرْوَةَ عَنِ الْمُغِيرَةِ ‏ "‏ عَلَى ظَاهِرِهِمَا ‏"‏ ‏.‏ غَيْرَهُ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَأَحْمَدُ ‏.‏ قَالَ مُحَمَّدٌ وَكَانَ مَالِكُ بْنُ أَنَسٍ يُشِيرُ بِعَبْدِ الرَّحْمَنِ بْنِ أَبِي الزِّنَادِ ‏.‏\hadithno{98}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{AI-Mughirah bin Shu'bah narrated:"I saw the Prophet wiping over the Khuff: on the tops of them}}
\hadithdefcmd{tirmidhi}{99}{حَدَّثَنَا هَنَّادٌ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي قَيْسٍ، عَنْ هُزَيْلِ بْنِ شُرَحْبِيلَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ تَوَضَّأَ النَّبِيُّ صلى الله عليه وسلم وَمَسَحَ عَلَى الْجَوْرَبَيْنِ وَالنَّعْلَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ قَالُوا يَمْسَحُ عَلَى الْجَوْرَبَيْنِ وَإِنْ لَمْ تَكُنْ نَعْلَيْنِ إِذَا كَانَا ثَخِينَيْنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي مُوسَى ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ صَالِحَ بْنَ مُحَمَّدٍ التِّرْمِذِيَّ قَالَ سَمِعْتُ أَبَا مُقَاتِلٍ السَّمَرْقَنْدِيَّ يَقُولُ دَخَلْتُ عَلَى أَبِي حَنِيفَةَ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ فَدَعَا بِمَاءٍ فَتَوَضَّأَ وَعَلَيْهِ جَوْرَبَانِ فَمَسَحَ عَلَيْهِمَا ثُمَّ قَالَ فَعَلْتُ الْيَوْمَ شَيْئًا لَمْ أَكُنْ أَفْعَلُهُ مَسَحْتُ عَلَى الْجَوْرَبَيْنِ وَهُمَا غَيْرُ مُنَعَّلَيْنِ ‏.‏\hadithno{99}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Al-Mughirah bin Shu`bah narrated:"The Prophet performed Wudu' and wiped over his socks and sandals}}
\hadithdefcmd{tirmidhi}{100}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنِ الْحَسَنِ، عَنِ ابْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أَبِيهِ، قَالَ تَوَضَّأَ النَّبِيُّ صلى الله عليه وسلم وَمَسَحَ عَلَى الْخُفَّيْنِ وَالْعِمَامَةِ ‏.‏ قَالَ بَكْرٌ وَقَدْ سَمِعْتُ مِنِ ابْنِ الْمُغِيرَةِ ‏.‏ قَالَ وَذَكَرَ مُحَمَّدُ بْنُ بَشَّارٍ فِي هَذَا الْحَدِيثِ فِي مَوْضِعٍ آخَرَ أَنَّهُ مَسَحَ عَلَى نَاصِيَتِهِ وَعِمَامَتِهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ ذَكَرَ بَعْضُهُمُ الْمَسْحَ عَلَى النَّاصِيَةِ وَالْعِمَامَةِ وَلَمْ يَذْكُرْ بَعْضُهُمُ النَّاصِيَةَ ‏.‏ وَسَمِعْتُ أَحْمَدَ بْنَ الْحَسَنِ يَقُولُ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ مَا رَأَيْتُ بِعَيْنِي مِثْلَ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَمْرِو بْنِ أُمَيَّةَ وَسَلْمَانَ وَثَوْبَانَ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْمُغِيرَةِ بْنِ شُعْبَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ وَعُمَرُ وَأَنَسٌ ‏.‏ وَبِهِ يَقُولُ الأَوْزَاعِيُّ وَأَحْمَدُ وَإِسْحَاقُ قَالُوا يَمْسَحُ عَلَى الْعِمَامَةِ ‏.‏ وَقَالَ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ لاَ يَمْسَحُ عَلَى الْعِمَامَةِ إِلاَّ أَنْ يَمْسَحَ بِرَأْسِهِ مَعَ الْعِمَامَةِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ الْجَارُودَ بْنَ مُعَاذٍ يَقُولُ سَمِعْتُ وَكِيعَ بْنَ الْجَرَّاحِ يَقُولُ إِنْ مَسَحَ عَلَى الْعِمَامَةِ يُجْزِئُهُ لِلأَثَرِ ‏.‏\hadithno{100}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn Al-Mughirah bin Shu'bah narrated from his father:"The Prophet performed Wudu and wiped over the Khuff and 'Imamah." Abu Bakr (one of the narrators) said: "And indeed I heard it from Ibn Al Mughirah}}
\hadithdefcmd{tirmidhi}{101}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنْ بِلاَلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَسَحَ عَلَى الْخُفَّيْنِ وَالْخِمَارِ ‏.‏\hadithno{101}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{BilaI narrated:"The Prophet wiped over the Khuff and the Khimar}}
\hadithdefcmd{tirmidhi}{102}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، هُوَ الْقُرَشِيُّ عَنْ أَبِي عُبَيْدَةَ بْنِ مُحَمَّدِ بْنِ عَمَّارِ بْنِ يَاسِرٍ، قَالَ سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ عَنِ الْمَسْحِ، عَلَى الْخُفَّيْنِ فَقَالَ السُّنَّةُ يَا ابْنَ أَخِي ‏.‏ قَالَ وَسَأَلْتُهُ عَنِ الْمَسْحِ، عَلَى الْعِمَامَةِ فَقَالَ أَمِسَّ الشَّعَرَ الْمَاءَ ‏.‏\hadithno{102}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Ubaidah bin Muttammad bin Ammar bin Yasir said:"I asked Jabir bin Abdullah about wiping over the Khuff. He said, 'O my nephew! It is the Sunnah.'" [He said:] "And I asked him about wiping over the lmamah. He said, '[Wipe1 the hair [with water]}}
\hadithdefcmd{tirmidhi}{103}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ خَالَتِهِ، مَيْمُونَةَ قَالَتْ وَضَعْتُ لِلنَّبِيِّ صلى الله عليه وسلم غُسْلاً فَاغْتَسَلَ مِنَ الْجَنَابَةِ فَأَكْفَأَ الإِنَاءَ بِشِمَالِهِ عَلَى يَمِينِهِ فَغَسَلَ كَفَّيْهِ ثُمَّ أَدْخَلَ يَدَهُ فِي الإِنَاءِ فَأَفَاضَ عَلَى فَرْجِهِ ثُمَّ دَلَكَ بِيَدِهِ الْحَائِطَ أَوِ الأَرْضَ ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ وَغَسَلَ وَجْهَهُ وَذِرَاعَيْهِ ثُمَّ أَفَاضَ عَلَى رَأْسِهِ ثَلاَثًا ثُمَّ أَفَاضَ عَلَى سَائِرِ جَسَدِهِ ثُمَّ تَنَحَّى فَغَسَلَ رِجْلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ وَجَابِرٍ وَأَبِي سَعِيدٍ وَجُبَيْرِ بْنِ مُطْعِمٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{103}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abbas narrated that his maternal aunt Maimunah said:"I prepared some water for the Prophet to perform Ghusl for Janabah with. So he turned the vessel with his left hand, (pouring some water) over his right. Then he washed his hands. Then he entered his hand into the vessel to pour water over his private area, then he rubbed his hands on the wall, or the ground. Then he rinsed out his mouth and washed his nose by putting water in and blowing it out, and washed his face and forearms. Then he poured water over his head three times, then he poured water over the remainder of his body, then he moved from where he was and washed his feet}}
\hadithdefcmd{tirmidhi}{104}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَغْتَسِلَ مِنَ الْجَنَابَةِ بَدَأَ فَغَسَلَ يَدَيْهِ قَبْلَ أَنْ يُدْخِلَهُمَا الإِنَاءَ ثُمَّ غَسَلَ فَرْجَهُ وَيَتَوَضَّأُ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ يُشَرِّبُ شَعْرَهُ الْمَاءَ ثُمَّ يَحْثِي عَلَى رَأْسِهِ ثَلاَثَ حَثَيَاتٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ أَهْلُ الْعِلْمِ فِي الْغُسْلِ مِنَ الْجَنَابَةِ أَنَّهُ يَتَوَضَّأُ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ يُفْرِغُ عَلَى رَأْسِهِ ثَلاَثَ مَرَّاتٍ ثُمَّ يُفِيضُ الْمَاءَ عَلَى سَائِرِ جَسَدِهِ ثُمَّ يَغْسِلُ قَدَمَيْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَقَالُوا إِنِ انْغَمَسَ الْجُنُبُ فِي الْمَاءِ وَلَمْ يَتَوَضَّأْ أَجْزَأَهُ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{104}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"When AlIah's Messenger wanted to perform Ghusl for Janabah, he would begin by washing his hands before putting them into the vessel. Then he would wash his private area, and perform the Wudu (as one does) for Salat. Then he would wet his hair with the water, then he would pour water over his head with his hands three times}}
\hadithdefcmd{tirmidhi}{105}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أَشُدُّ ضَفْرَ رَأْسِي أَفَأَنْقُضُهُ لِغُسْلِ الْجَنَابَةِ قَالَ ‏"‏ لاَ إِنَّمَا يَكْفِيكِ أَنْ تَحْثِينَ عَلَى رَأْسِكِ ثَلاَثَ حَثَيَاتٍ مِنْ مَاءٍ ثُمَّ تُفِيضِينَ عَلَى سَائِرِ جَسَدِكِ الْمَاءَ فَتَطْهُرِينَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فَإِذَا أَنْتِ قَدْ تَطَهَّرْتِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الْمَرْأَةَ إِذَا اغْتَسَلَتْ مِنَ الْجَنَابَةِ فَلَمْ تَنْقُضْ شَعْرَهَا أَنَّ ذَلِكَ يُجْزِئُهَا بَعْدَ أَنْ تُفِيضَ الْمَاءَ عَلَى رَأْسِهَا ‏.‏\hadithno{105}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Umm Salamah narrated :"I said: 'O Messenger of Allah! I am woman with tight braids on my head, should I undo it to perform Ghusl for Janabah? He said: 'No. It is sufficient that you only pour three scoops of water (with hands held together) over your head, then pour water over the rest of your body, to be purified.'" Or he said: "Then you will be purified}}
\hadithdefcmd{tirmidhi}{106}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا الْحَارِثُ بْنُ وَجِيهٍ، قَالَ حَدَّثَنَا مَالِكُ بْنُ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَحْتَ كُلِّ شَعْرَةٍ جَنَابَةٌ فَاغْسِلُوا الشَّعَرَ وَأَنْقُوا الْبَشَرَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْحَارِثِ بْنِ وَجِيهٍ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِهِ وَهُوَ شَيْخٌ لَيْسَ بِذَاكَ وَقَدْ رَوَى عَنْهُ غَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ ‏.‏ وَقَدْ تَفَرَّدَ بِهَذَا الْحَدِيثِ عَنْ مَالِكِ بْنِ دِينَارٍ وَيُقَالُ الْحَارِثُ بْنُ وَجِيهٍ وَيُقَالُ ابْنُ وَجْبَةَ ‏.‏\hadithno{106}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Under every hair is sexual impurity so wash (all of) the hair and cleanse the skin}}
\hadithdefcmd{tirmidhi}{107}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَتَوَضَّأُ بَعْدَ الْغُسْلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ أَنْ لاَ يَتَوَضَّأَ بَعْدَ الْغُسْلِ ‏.‏\hadithno{107}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"The Prophet would not perform Wudu after the Ghusl}}
\hadithdefcmd{tirmidhi}{108}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِذَا جَاوَزَ الْخِتَانُ الْخِتَانَ فَقَدْ وَجَبَ الْغُسْلُ فَعَلْتُهُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم فَاغْتَسَلْنَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَرَافِعِ بْنِ خَدِيجٍ ‏.‏\hadithno{108}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:"When the circumcised meets the circumcised, then indeed Ghusl is required. Myself and Allah's Messenger did that, so we performed Ghusl}}
\hadithdefcmd{tirmidhi}{109}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِذَا جَاوَزَ الْخِتَانُ الْخِتَانَ وَجَبَ الْغُسْلُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ ‏"‏ إِذَا جَاوَزَ الْخِتَانُ الْخِتَانَ فَقَدْ وَجَبَ الْغُسْلُ ‏"‏ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَعَائِشَةُ وَالْفُقَهَاءِ مِنَ التَّابِعِينَ وَمَنْ بَعْدَهُمْ مِثْلِ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ قَالُوا إِذَا الْتَقَى الْخِتَانَانِ وَجَبَ الْغُسْلُ ‏.‏\hadithno{109}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated that :the Prophet said: "When the circumcised meets the circumcised then Ghusl is required}}
\hadithdefcmd{tirmidhi}{110}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا يُونُسُ بْنُ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ إِنَّمَا كَانَ الْمَاءُ مِنَ الْمَاءِ رُخْصَةً فِي أَوَّلِ الإِسْلاَمِ ثُمَّ نُهِيَ عَنْهَا ‏.‏\hadithno{110}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ubayy bin Ka'b narrated:"Water is for water,' was only permitted in the beginning of Islam. Then it was prohibited}}
\hadithdefcmd{tirmidhi}{111}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِنَّمَا كَانَ الْمَاءُ مِنَ الْمَاءِ فِي أَوَّلِ الإِسْلاَمِ ثُمَّ نُسِخَ بَعْدَ ذَلِكَ ‏.‏ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أُبَىُّ بْنُ كَعْبٍ وَرَافِعُ بْنُ خَدِيجٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ عَلَى أَنَّهُ إِذَا جَامَعَ الرَّجُلُ امْرَأَتَهُ فِي الْفَرْجِ وَجَبَ عَلَيْهِمَا الْغُسْلُ وَإِنْ لَمْ يُنْزِلاَ ‏.‏\hadithno{111}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ma'mar narrated :a similar narration (as Hadith no. 110) from, Az-Zuhri, with this chain}}
\hadithdefcmd{tirmidhi}{112}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ أَبِي الْجَحَّافِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّمَا الْمَاءُ مِنَ الْمَاءِ فِي الاِحْتِلاَمِ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ لَمْ نَجِدْ هَذَا الْحَدِيثَ إِلاَّ عِنْدَ شَرِيكٍ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو الْجَحَّافِ اسْمُهُ دَاوُدُ بْنُ أَبِي عَوْفٍ ‏.‏ وَيُرْوَى عَنْ سُفْيَانَ الثَّوْرِيِّ قَالَ حَدَّثَنَا أَبُو الْجَحَّافِ وَكَانَ مَرْضِيًّا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُثْمَانَ بْنِ عَفَّانَ وَعَلِيِّ بْنِ أَبِي طَالِبٍ وَالزُّبَيْرِ وَطَلْحَةَ وَأَبِي أَيُّوبَ وَأَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْمَاءُ مِنَ الْمَاءِ ‏"‏ ‏.‏\hadithno{112}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas said:"Water is for water' is only about the wet dream}}
\hadithdefcmd{tirmidhi}{113}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ الْخَيَّاطُ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، هُوَ الْعُمَرِيُّ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ يَجِدُ الْبَلَلَ وَلاَ يَذْكُرُ احْتِلاَمًا قَالَ ‏"‏ يَغْتَسِلُ ‏"‏ ‏.‏ وَعَنِ الرَّجُلِ يَرَى أَنَّهُ قَدِ احْتَلَمَ وَلَمْ يَجِدْ بَلَلاً قَالَ ‏"‏ لاَ غُسْلَ عَلَيْهِ ‏"‏ ‏.‏ قَالَتْ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ هَلْ عَلَى الْمَرْأَةِ تَرَى ذَلِكَ غُسْلٌ قَالَ ‏"‏ نَعَمْ إِنَّ النِّسَاءَ شَقَائِقُ الرِّجَالِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا رَوَى هَذَا الْحَدِيثَ عَبْدُ اللَّهِ بْنُ عُمَرَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ حَدِيثَ عَائِشَةَ فِي الرَّجُلِ يَجِدُ الْبَلَلَ وَلاَ يَذْكُرُ احْتِلاَمًا ‏.‏ وَعَبْدُ اللَّهِ بْنُ عُمَرَ ضَعَّفَهُ يَحْيَى بْنُ سَعِيدٍ مِنْ قِبَلِ حِفْظِهِ فِي الْحَدِيثِ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ إِذَا اسْتَيْقَظَ الرَّجُلُ فَرَأَى بِلَّةً أَنَّهُ يَغْتَسِلُ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَحْمَدَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ إِنَّمَا يَجِبُ عَلَيْهِ الْغُسْلُ إِذَا كَانَتِ الْبِلَّةُ بِلَّةَ نُطْفَةٍ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَإِسْحَاقَ ‏.‏ وَإِذَا رَأَى احْتِلاَمًا وَلَمْ يَرَ بِلَّةً فَلاَ غُسْلَ عَلَيْهِ عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ\hadithno{113}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"The Prophet was asked about a man who finds wetness and he does not remember having a wet dream. So he said: 'He is to perform Ghusl. And (he was asked) about a man who had a wet dream but does not find any wetness, so he said: 'No Ghusl is required of him.' Umm Salamah said: 'O Messenger of Allah! Is the woman required to perform Ghusl if she sees that?' He replied: 'Yes. Indeed women are the partners of men}}
\hadithdefcmd{tirmidhi}{114}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو السَّوَّاقُ الْبَلْخِيُّ، حَدَّثَنَا هُشَيْمٌ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، ح قَالَ وَحَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنِ الْمَذْىِ فَقَالَ ‏"‏ مِنَ الْمَذْىِ الْوُضُوءُ وَمِنَ الْمَنِيِّ الْغُسْلُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ وَأُبَىِّ بْنِ كَعْبٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ ‏"‏ مِنَ الْمَذْىِ الْوُضُوءُ وَمِنَ الْمَنِيِّ الْغُسْلُ ‏"‏ ‏.‏ وَهُوَ قَوْلُ عَامَّةِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ وَبِهِ يَقُولُ سُفْيَانُ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{114}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated:"I asked the Prophet about Al-Madhi. He said: "For Al-Madhi is Wudu, and for AI-Mani is Ghusl}}
\hadithdefcmd{tirmidhi}{115}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ عُبَيْدٍ، هُوَ ابْنُ السَّبَّاقِ عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ حُنَيْفٍ، قَالَ كُنْتُ أَلْقَى مِنَ الْمَذْىِ شِدَّةً وَعَنَاءً فَكُنْتُ أُكْثِرُ مِنْهُ الْغُسْلَ فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَسَأَلْتُهُ عَنْهُ فَقَالَ ‏"‏ إِنَّمَا يُجْزِئُكَ مِنْ ذَلِكَ الْوُضُوءُ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ بِمَا يُصِيبُ ثَوْبِي مِنْهُ قَالَ ‏"‏ يَكْفِيكَ أَنْ تَأْخُذَ كَفًّا مِنْ مَاءٍ فَتَنْضَحَ بِهِ ثَوْبَكَ حَيْثُ تَرَى أَنَّهُ أَصَابَ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ إِسْحَاقَ فِي الْمَذْىِ مِثْلَ هَذَا ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْمَذْىِ يُصِيبُ الثَّوْبَ فَقَالَ بَعْضُهُمْ لاَ يُجْزِئُ إِلاَّ الْغَسْلُ وَهُوَ قَوْلُ الشَّافِعِيِّ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ يُجْزِئُهُ النَّضْحُ ‏.‏ وَقَالَ أَحْمَدُ أَرْجُو أَنْ يُجْزِئَهُ النَّضْحُ بِالْمَاءِ ‏.‏\hadithno{115}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Sahl bin Hunaif said:"I suffered from a severe and troubling case of Al-Madhi. I was performing Ghusl often because of it. So I mentioned that to Allah's Messenger and asked him about it. He said: "You only need to perform Wudu for that." I said: "O Messenger of Allah! How about when it gets on my clothes?" He said: "It is sufficient for you to take a handful of water and sprinkle it n your garment wherever you see that it has touched it}}
\hadithdefcmd{tirmidhi}{116}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، قَالَ ضَافَ عَائِشَةَ ضَيْفٌ فَأَمَرَتْ لَهُ بِمِلْحَفَةٍ صَفْرَاءَ فَنَامَ فِيهَا فَاحْتَلَمَ فَاسْتَحْيَا أَنْ يُرْسِلَ بِهَا وَبِهَا أَثَرُ الاِحْتِلاَمِ فَغَمَسَهَا فِي الْمَاءِ ثُمَّ أَرْسَلَ بِهَا فَقَالَتْ عَائِشَةُ لِمَ أَفْسَدَ عَلَيْنَا ثَوْبَنَا إِنَّمَا كَانَ يَكْفِيهِ أَنْ يَفْرُكَهُ بِأَصَابِعِهِ وَرُبَّمَا فَرَكْتُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِأَصَابِعِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ مِنَ الْفُقَهَاءِ مِثْلِ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ قَالُوا فِي الْمَنِيِّ يُصِيبُ الثَّوْبَ يُجْزِئُهُ الْفَرْكُ وَإِنْ لَمْ يُغْسَلْ ‏.‏ وَهَكَذَا رُوِيَ عَنْ مَنْصُورٍ عَنْ إِبْرَاهِيمَ عَنْ هَمَّامِ بْنِ الْحَارِثِ عَنْ عَائِشَةَ مِثْلَ رِوَايَةِ الأَعْمَشِ ‏.‏ وَرَوَى أَبُو مَعْشَرٍ هَذَا الْحَدِيثَ عَنْ إِبْرَاهِيمَ عَنِ الأَسْوَدِ عَنْ عَائِشَةَ وَحَدِيثُ الأَعْمَشِ أَصَحُّ ‏.‏\hadithno{116}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hammam bin AI-Harith narrated:"Aishah had a guest to whom she lent a yellow wrap for him to sleep in. He had a wet dream, and was too embarrassed to send it to her while the traces of the wet dream were present on it. So he submerged it (washing it) in water, then he sent it to her. Aishah said, "Why did he ruin our garment? It would have been sufficient for him to scrape it off with his fingers. Sometimes I would scrape it off of the garment of Allah's Messenger with my fingers}}
\hadithdefcmd{tirmidhi}{117}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَمْرِو بْنِ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَائِشَةَ، أَنَّهَا غَسَلَتْ مَنِيًّا مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَحَدِيثُ عَائِشَةَ أَنَّهَا غَسَلَتْ مَنِيًّا مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم - لَيْسَ بِمُخَالِفٍ لِحَدِيثِ الْفَرْكِ لأَنَّهُ وَإِنْ كَانَ الْفَرْكُ يُجْزِئُ فَقَدْ يُسْتَحَبُّ لِلرَّجُلِ أَنْ لاَ يُرَى عَلَى ثَوْبِهِ أَثَرُهُ ‏.‏ قَالَ ابْنُ عَبَّاسٍ الْمَنِيُّ بِمَنْزِلَةِ الْمُخَاطِ فَأَمِطْهُ عَنْكَ وَلَوْ بِإِذْخِرَةٍ ‏.‏\hadithno{117}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sulaiman bin Yasar narrated from Aishah, that :she washed Mani from the garment of Allah's Messenger}}
\hadithdefcmd{tirmidhi}{118}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنَامُ وَهُوَ جُنُبٌ وَلاَ يَمَسُّ مَاءً ‏.‏\hadithno{118}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"Allah's Messenger would sleep while he was Junub, and without touching water (performing Ghusl)}}
\hadithdefcmd{tirmidhi}{119}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا قَوْلُ سَعِيدِ بْنِ الْمُسَيَّبِ وَغَيْرِهِ ‏.‏ وَقَدْ رَوَى غَيْرُ، وَاحِدٍ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَتَوَضَّأُ قَبْلَ أَنْ يَنَامَ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ أَبِي إِسْحَاقَ عَنِ الأَسْوَدِ ‏.‏ وَقَدْ رَوَى عَنْ أَبِي إِسْحَاقَ هَذَا الْحَدِيثَ شُعْبَةُ وَالثَّوْرِيُّ وَغَيْرُ وَاحِدٍ ‏.‏ وَيَرَوْنَ أَنَّ هَذَا غَلَطٌ مِنْ أَبِي إِسْحَاقَ ‏.‏\hadithno{119}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Abu Ishaq:There is a similar report (as no. 1I8) narrated via Abu Ishaq}}
\hadithdefcmd{tirmidhi}{120}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، أَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم أَيَنَامُ أَحَدُنَا وَهُوَ جُنُبٌ قَالَ ‏ "‏ نَعَمْ إِذَا تَوَضَّأَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَمَّارٍ وَعَائِشَةَ وَجَابِرٍ وَأَبِي سَعِيدٍ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ أَحْسَنُ شَيْءٍ فِي هَذَا الْبَابِ وَأَصَحُّ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ قَالُوا إِذَا أَرَادَ الْجُنُبُ أَنْ يَنَامَ تَوَضَّأَ قَبْلَ أَنْ يَنَامَ ‏.‏\hadithno{120}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umar narrated that :he asked the Prophet: "Can one of us sleep while he is Junub?" So he replied: "Yes, when he performs Wudu}}
\hadithdefcmd{tirmidhi}{121}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَقِيَهُ وَهُوَ جُنُبٌ قَالَ فَانْبَجَسْتُ أَىْ فَانْخَنَسْتُ فَاغْتَسَلْتُ ثُمَّ جِئْتُ فَقَالَ ‏"‏ أَيْنَ كُنْتَ أَوْ أَيْنَ ذَهَبْتَ ‏"‏ ‏.‏ قُلْتُ إِنِّي كُنْتُ جُنُبًا ‏.‏ قَالَ ‏"‏ إِنَّ الْمُسْلِمَ لاَ يَنْجُسُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ حُذَيْفَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي هُرَيْرَةَ أَنَّهُ لَقِيَ النَّبِيَّ صلى الله عليه وسلم وَهُوَ جُنُبٌ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَخَّصَ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ فِي مُصَافَحَةِ الْجُنُبِ وَلَمْ يَرَوْا بِعَرَقِ الْجُنُبِ وَالْحَائِضِ بَأْسًا ‏.‏ وَمَعْنَى قَوْلِهِ فَانْخَنَسْتُ يَعْنِي تَنَحَّيْتُ عَنْهُ ‏.‏\hadithno{121}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet met him while he was Junub. He said: "[So I slipped away from him - meaning:] I withdrew - to perform Ghusl. Then he returned, so he said: 'Where have you been?' Or: 'Where did you go?' I replied: 'I was Junub.' So he said: 'Indeed the believer is not defiled}}
\hadithdefcmd{tirmidhi}{122}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ جَاءَتْ أُمُّ سُلَيْمٍ بِنْتُ مِلْحَانَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ فَهَلْ عَلَى الْمَرْأَةِ تَعْنِي غُسْلاً إِذَا هِيَ رَأَتْ فِي الْمَنَامِ مِثْلَ مَا يَرَى الرَّجُلُ قَالَ ‏ "‏ نَعَمْ إِذَا هِيَ رَأَتِ الْمَاءَ فَلْتَغْتَسِلْ ‏"‏ ‏.‏ قَالَتْ أُمُّ سَلَمَةَ قُلْتُ لَهَا فَضَحْتِ النِّسَاءَ يَا أُمَّ سُلَيْمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ عَامَّةِ الْفُقَهَاءِ أَنَّ الْمَرْأَةَ إِذَا رَأَتْ فِي الْمَنَامِ مِثْلَ مَا يَرَى الرَّجُلُ فَأَنْزَلَتْ أَنَّ عَلَيْهَا الْغُسْلَ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَالشَّافِعِيُّ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سُلَيْمٍ وَخَوْلَةَ وَعَائِشَةَ وَأَنَسٍ ‏.‏\hadithno{122}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umm Salamah narrated:Umm Sulaim bint Milhan came to the Prophet and she said: 'O Messenger of Allah! Indeed Allah is not embarrassed of the truth. So is it required of a woman - meaning Ghusl - when she sees in her sleep similar to what a man sees?' He replied: 'Yes. When she finds water (wetness), then she is perform Ghusl.'" Umm Salamah said: "I said to her: 'O Umm SuIaim! You have disgraced the women}}
\hadithdefcmd{tirmidhi}{123}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ حُرَيْثٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ رُبَّمَا اغْتَسَلَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْجَنَابَةِ ثُمَّ جَاءَ فَاسْتَدْفَأَ بِي فَضَمَمْتُهُ إِلَىَّ وَلَمْ أَغْتَسِلْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ بِإِسْنَادِهِ بَأْسٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ أَنَّ الرَّجُلَ إِذَا اغْتَسَلَ فَلاَ بَأْسَ بِأَنْ يَسْتَدْفِئَ بِامْرَأَتِهِ وَيَنَامَ مَعَهَا قَبْلَ أَنْ تَغْتَسِلَ الْمَرْأَةُ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{123}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"Sometimes the Prophet would perform Ghusl from Janabah then come to seek warmth from me, he would hold me and not perform Ghusl}}
\hadithdefcmd{tirmidhi}{124}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَمْرِو بْنِ بُجْدَانَ، عَنْ أَبِي ذَرٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الصَّعِيدَ الطَّيِّبَ طَهُورُ الْمُسْلِمِ وَإِنْ لَمْ يَجِدِ الْمَاءَ عَشْرَ سِنِينَ فَإِذَا وَجَدَ الْمَاءَ فَلْيُمِسَّهُ بَشَرَتَهُ فَإِنَّ ذَلِكَ خَيْرٌ ‏"‏ ‏.‏ وَقَالَ مَحْمُودٌ فِي حَدِيثِهِ ‏"‏ إِنَّ الصَّعِيدَ الطَّيِّبَ وَضُوءُ الْمُسْلِمِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنْ خَالِدٍ الْحَذَّاءِ عَنْ أَبِي قِلاَبَةَ عَنْ عَمْرِو بْنِ بُجْدَانَ عَنْ أَبِي ذَرٍّ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ أَيُّوبُ عَنْ أَبِي قِلاَبَةَ عَنْ رَجُلٍ مِنْ بَنِي عَامِرٍ عَنْ أَبِي ذَرٍّ وَلَمْ يُسَمِّهِ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ عَامَّةِ الْفُقَهَاءِ أَنَّ الْجُنُبَ وَالْحَائِضَ إِذَا لَمْ يَجِدَا الْمَاءَ تَيَمَّمَا وَصَلَّيَا ‏.‏ وَيُرْوَى عَنِ ابْنِ مَسْعُودٍ أَنَّهُ كَانَ لاَ يَرَى التَّيَمُّمَ لِلْجُنُبِ وَإِنْ لَمْ يَجِدِ الْمَاءَ ‏.‏ وَيُرْوَى عَنْهُ أَنَّهُ رَجَعَ عَنْ قَوْلِهِ فَقَالَ يَتَيَمَّمُ إِذَا لَمْ يَجِدِ الْمَاءَ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَمَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{124}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Dharr narrated that :AlIah's Messenger said: "Pure clean earth is a purifier for the Muslim; even if he did not find water for ten years. Then if he finds water, then let him use it (for purification) on his skin. For, that is better}}
\hadithdefcmd{tirmidhi}{125}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، وَعَبْدَةُ، وَأَبُو مُعَاوِيَةَ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ ‏"‏ لاَ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏ قَالَ أَبُو مُعَاوِيَةَ فِي حَدِيثِهِ وَقَالَ ‏"‏ تَوَضَّئِي لِكُلِّ صَلاَةٍ حَتَّى يَجِيءَ ذَلِكَ الْوَقْتُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ جَاءَتْ فَاطِمَةُ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَمَالِكٌ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ أَنَّ الْمُسْتَحَاضَةَ إِذَا جَاوَزَتْ أَيَّامَ أَقْرَائِهَا اغْتَسَلَتْ وَتَوَضَّأَتْ لِكُلِّ صَلاَةٍ ‏.‏\hadithno{125}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"Fatimah bint Abi-Hubaish came to the Prophet and said: 'O Messenger of Allah! I am a woman who suffers from persistent bleeding and I do not become clean. Shall I give up Salat?' He said: 'No. That is only a bIood vessel, it is not menstruation. When your menstruation begins then leave the Salat. And when it ends, then wash the blood from you and perform Salat}}
\hadithdefcmd{tirmidhi}{126}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي الْيَقْظَانِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ فِي الْمُسْتَحَاضَةِ ‏ "‏ تَدَعُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا الَّتِي كَانَتْ تَحِيضُ فِيهَا ثُمَّ تَغْتَسِلُ وَتَتَوَضَّأُ عِنْدَ كُلِّ صَلاَةٍ وَتَصُومُ وَتُصَلِّي ‏"‏ ‏.‏\hadithno{126}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Adiyy bin Thabit narrated from his father, that :the Prophet said about the Mustahadah that she should: "Leave the Salat for the days of her period which she menstruates in, then perform Ghusl, and perform Wudu for every Salat, and observe Saum and perform Salat}}
\hadithdefcmd{tirmidhi}{127}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ قَدْ تَفَرَّدَ بِهِ شَرِيكٌ عَنْ أَبِي الْيَقْظَانِ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقُلْتُ عَدِيُّ بْنُ ثَابِتٍ عَنْ أَبِيهِ عَنْ جَدِّهِ جَدُّ عَدِيٍّ مَا اسْمُهُ فَلَمْ يَعْرِفْ مُحَمَّدٌ اسْمَهُ وَذَكَرْتُ لِمُحَمَّدٍ قَوْلَ يَحْيَى بْنِ مَعِينٍ أَنَّ اسْمَهُ دِينَارٌ فَلَمْ يَعْبَأْ بِهِ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ فِي الْمُسْتَحَاضَةِ إِنِ اغْتَسَلَتْ لِكُلِّ صَلاَةٍ هُوَ أَحْوَطُ لَهَا وَإِنْ تَوَضَّأَتْ لِكُلِّ صَلاَةٍ أَجْزَأَهَا وَإِنْ جَمَعَتْ بَيْنَ الصَّلاَتَيْنِ بِغُسْلٍ وَاحِدٍ أَجْزَأَهَا ‏.‏\hadithno{127}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{A similar narration as no. 120. :Abu Eisa said: Sharik is alone in narrating this Hadith from Abu Al Yaqzan.[He said:] I asked Muhammad (ibn Isma'il AI-Bukhari) about this Hadlth. I said: "Adiyy bin Thabit from his father, from his grandfather; what is the name of Adiyy's grandfather?" But Muhammad did not know his name. And I mentioned to Muhammad that Yahya bin Ma'in said his name is Dinar, and he did not contradict him. Ahmad and 1shaq said ahout the Mustahadah: If she performs Ghusl for every prayer that is more prudent for her, and if she performs Wudu for each prayer, then that is acceptable from her, and if she combines between two prayers with (one) Ghusl then that is acceptable}}
\hadithdefcmd{tirmidhi}{128}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ، عَنْ عَمِّهِ، عِمْرَانَ بْنِ طَلْحَةَ عَنْ أُمِّهِ، حَمْنَةَ بِنْتِ جَحْشٍ قَالَتْ كُنْتُ أُسْتَحَاضُ حَيْضَةً كَثِيرَةً شَدِيدَةً فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم أَسْتَفْتِيهِ وَأُخْبِرُهُ فَوَجَدْتُهُ فِي بَيْتِ أُخْتِي زَيْنَبَ بِنْتِ جَحْشٍ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُسْتَحَاضُ حَيْضَةً كَثِيرَةً شَدِيدَةً فَمَا تَأْمُرُنِي فِيهَا قَدْ مَنَعَتْنِي الصِّيَامَ وَالصَّلاَةَ قَالَ ‏"‏ أَنْعَتُ لَكِ الْكُرْسُفَ فَإِنَّهُ يُذْهِبُ الدَّمَ ‏"‏ ‏.‏ قَالَتْ هُوَ أَكْثَرُ مِنْ ذَلِكَ قَالَ ‏"‏ فَتَلَجَّمِي ‏"‏ ‏.‏ قَالَتْ هُوَ أَكْثَرُ مِنْ ذَلِكَ قَالَ ‏"‏ فَاتَّخِذِي ثَوْبًا ‏"‏ ‏.‏ قَالَتْ هُوَ أَكْثَرُ مِنْ ذَلِكَ إِنَّمَا أَثُجُّ ثَجًّا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ سَآمُرُكِ بِأَمْرَيْنِ أَيَّهُمَا صَنَعْتِ أَجْزَأَ عَنْكِ فَإِنْ قَوِيتِ عَلَيْهِمَا فَأَنْتِ أَعْلَمُ ‏"‏ ‏.‏ فَقَالَ ‏"‏ إِنَّمَا هِيَ رَكْضَةٌ مِنَ الشَّيْطَانِ فَتَحَيَّضِي سِتَّةَ أَيَّامٍ أَوْ سَبْعَةَ أَيَّامٍ فِي عِلْمِ اللَّهِ ثُمَّ اغْتَسِلِي فَإِذَا رَأَيْتِ أَنَّكِ قَدْ طَهُرْتِ وَاسْتَنْقَأْتِ فَصَلِّي أَرْبَعًا وَعِشْرِينَ لَيْلَةً أَوْ ثَلاَثًا وَعِشْرِينَ لَيْلَةً وَأَيَّامَهَا وَصُومِي وَصَلِّي فَإِنَّ ذَلِكِ يُجْزِئُكِ وَكَذَلِكِ فَافْعَلِي كَمَا تَحِيضُ النِّسَاءُ وَكَمَا يَطْهُرْنَ لِمِيقَاتِ حَيْضِهِنَّ وَطُهْرِهِنَّ فَإِنْ قَوِيتِ عَلَى أَنْ تُؤَخِّرِي الظُّهْرَ وَتُعَجِّلِي الْعَصْرَ ثُمَّ تَغْتَسِلِينَ حِينَ تَطْهُرِينَ وَتُصَلِّينَ الظُّهْرَ وَالْعَصْرَ جَمِيعًا ثُمَّ تُؤَخِّرِينَ الْمَغْرِبَ وَتُعَجِّلِينَ الْعِشَاءَ ثُمَّ تَغْتَسِلِينَ وَتَجْمَعِينَ بَيْنَ الصَّلاَتَيْنِ فَافْعَلِي وَتَغْتَسِلِينَ مَعَ الصُّبْحِ وَتُصَلِّينَ وَكَذَلِكِ فَافْعَلِي وَصُومِي إِنْ قَوِيتِ عَلَى ذَلِكِ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَهُوَ أَعْجَبُ الأَمْرَيْنِ إِلَىَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَاهُ عُبَيْدُ اللَّهِ بْنُ عَمْرٍو الرَّقِّيُّ وَابْنُ جُرَيْجٍ وَشَرِيكٌ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ عَنْ عَمِّهِ عِمْرَانَ عَنْ أُمِّهِ حَمْنَةَ إِلاَّ أَنَّ ابْنَ جُرَيْجٍ يَقُولُ عُمَرُ بْنُ طَلْحَةَ وَالصَّحِيحُ عِمْرَانُ بْنُ طَلْحَةَ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ هُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا قَالَ أَحْمَدُ بْنُ حَنْبَلٍ هُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ فِي الْمُسْتَحَاضَةِ إِذَا كَانَتْ تَعْرِفُ حَيْضَهَا بِإِقْبَالِ الدَّمِ وَإِدْبَارِهِ وَإِقْبَالُهُ أَنْ يَكُونَ أَسْوَدَ ‏.‏ وَإِدْبَارُهُ أَنْ يَتَغَيَّرَ إِلَى الصُّفْرَةِ فَالْحُكْمُ لَهَا عَلَى حَدِيثِ فَاطِمَةَ بِنْتِ أَبِي حُبَيْشٍ وَإِنْ كَانَتِ الْمُسْتَحَاضَةُ لَهَا أَيَّامٌ مَعْرُوفَةٌ قَبْلَ أَنْ تُسْتَحَاضَ فَإِنَّهَا تَدَعُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلُ وَتَتَوَضَّأُ لِكُلِّ صَلاَةٍ وَتُصَلِّي وَإِذَا اسْتَمَرَّ بِهَا الدَّمُ وَلَمْ يَكُنْ لَهَا أَيَّامٌ مَعْرُوفَةٌ وَلَمْ تَعْرِفِ الْحَيْضَ بِإِقْبَالِ الدَّمِ وَإِدْبَارِهِ فَالْحُكْمُ لَهَا عَلَى حَدِيثِ حَمْنَةَ بِنْتِ جَحْشٍ ‏.‏ وَكَذَلِكَ قَالَ أَبُو عُبَيْدٍ ‏.‏ وَقَالَ الشَّافِعِيُّ الْمُسْتَحَاضَةُ إِذَا اسْتَمَرَّ بِهَا الدَّمُ فِي أَوَّلِ مَا رَأَتْ فَدَامَتْ عَلَى ذَلِكَ فَإِنَّهَا تَدَعُ الصَّلاَةَ مَا بَيْنَهَا وَبَيْنَ خَمْسَةَ عَشَرَ يَوْمًا فَإِذَا طَهُرَتْ فِي خَمْسَةَ عَشَرَ يَوْمًا أَوْ قَبْلَ ذَلِكَ فَإِنَّهَا أَيَّامُ حَيْضٍ فَإِذَا رَأَتِ الدَّمَ أَكْثَرَ مِنْ خَمْسَةَ عَشَرَ يَوْمًا فَإِنَّهَا تَقْضِي صَلاَةَ أَرْبَعَةَ عَشَرَ يَوْمًا ثُمَّ تَدَعُ الصَّلاَةَ بَعْدَ ذَلِكَ أَقَلَّ مَا تَحِيضُ النِّسَاءُ وَهُوَ يَوْمٌ وَلَيْلَةٌ ‏.‏ قَالَ أَبُو عِيسَى وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي أَقَلِّ الْحَيْضِ وَأَكْثَرِهِ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ أَقَلُّ الْحَيْضِ ثَلاَثَةٌ وَأَكْثَرُهُ عَشَرَةٌ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَبِهِ يَأْخُذُ ابْنُ الْمُبَارَكِ وَرُوِيَ عَنْهُ خِلاَفُ هَذَا ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْهُمْ عَطَاءُ بْنُ أَبِي رَبَاحٍ أَقَلُّ الْحَيْضِ يَوْمٌ وَلَيْلَةٌ وَأَكْثَرُهُ خَمْسَةَ عَشَرَ يَوْمًا ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَالأَوْزَاعِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ وَأَبِي عُبَيْدٍ ‏.‏\hadithno{128}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Hamnah bint Jahsh narrated:"I had a case of blood flow that was severe and excessive. So I went to the Prophet to inform him and ask him about it. I found him in the house of my sister Zainab bint Jahsh. I said, 'O Messenger of Allah! I suffer from a case of severe and excessive blood flow. So what do you order me to do for it, and does this prevent me from fasting and performing Salat?' He said: 'Tie a cotton rag around yourself and the bIood will go away.' I said, 'It is more than that.' He said: 'Make it tight.' I said, 'It is more than that.' He said: 'Then use a cloth (to bind it).' I said, it is more than that. It flows too much.' So the Prophet said: 'I will order you to do one of two things, which ever of them you do, it will be acceptable for you. You should know which of them you are able to do.' Then he said: 'This is only a blow from Shaitan. Menstruate for six or seven days, which Allah knows, then perform Ghusl. When you see that you have become pure and clean, then perform Salat for twenty-three or twenty-four nights and their days. Perform Salat and fast, and that will be acceptable for you. So do this (if you can) just as (other) women who menstruate and become pure during their periods of menstruation and purity. If (not, and) you are able to delay Zuhr and hasten Asr then perform Ghusl when you have become pure, and pray Zuhr and Asr together. Then delay Maghrib and hasten Isha, then perform Ghusl and combine the two prayers. So do this (if you are able). Then perform Ghusl with the dawn and pray. Do this, and fast if you are able to do so.' Then Allah's Messenger said: 'That is what is preferable to me of the two}}
\hadithdefcmd{tirmidhi}{129}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتِ اسْتَفْتَتْ أُمُّ حَبِيبَةَ ابْنَةُ جَحْشٍ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ فَقَالَ ‏ "‏ لاَ إِنَّمَا ذَلِكِ عِرْقٌ فَاغْتَسِلِي ثُمَّ صَلِّي ‏"‏ ‏.‏ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ ‏.‏ قَالَ قُتَيْبَةُ قَالَ اللَّيْثُ لَمْ يَذْكُرِ ابْنُ شِهَابٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أُمَّ حَبِيبَةَ أَنْ تَغْتَسِلَ عِنْدَ كُلِّ صَلاَةٍ وَلَكِنَّهُ شَيْءٌ فَعَلَتْهُ هِيَ ‏.‏ قَالَ أَبُو عِيسَى وَيُرْوَى هَذَا الْحَدِيثُ عَنِ الزُّهْرِيِّ عَنْ عَمْرَةَ عَنْ عَائِشَةَ قَالَتِ اسْتَفْتَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ الْمُسْتَحَاضَةُ تَغْتَسِلُ عِنْدَ كُلِّ صَلاَةٍ ‏.‏ وَرَوَى الأَوْزَاعِيُّ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ وَعَمْرَةَ عَنْ عَائِشَةَ ‏.‏\hadithno{129}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"Umm Habibah hint Jahsh sought a verdict from Allah's Messenger. She said 'I suffer from persistent bleeding such that I do not become pere. Shall I give up the Salat?' He said: 'No, that is only a blood vessel. So perform Ghusl then pray.' So she would perform Ghusl for each prayer}}
\hadithdefcmd{tirmidhi}{130}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ مُعَاذَةَ، أَنَّ امْرَأَةً، سَأَلَتْ عَائِشَةَ قَالَتْ أَتَقْضِي إِحْدَانَا صَلاَتَهَا أَيَّامَ مَحِيضِهَا فَقَالَتْ أَحَرُورِيَّةٌ أَنْتِ قَدْ كَانَتْ إِحْدَانَا تَحِيضُ فَلاَ تُؤْمَرُ بِقَضَاءٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ عَائِشَةَ مِنْ غَيْرِ وَجْهٍ أَنَّ الْحَائِضَ لاَ تَقْضِي الصَّلاَةَ ‏.‏ وَهُوَ قَوْلُ عَامَّةِ الْفُقَهَاءِ لاَ اخْتِلاَفَ بَيْنَهُمْ فِي أَنَّ الْحَائِضَ تَقْضِي الصَّوْمَ وَلاَ تَقْضِي الصَّلاَةَ ‏.‏\hadithno{130}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Mu'adhah narrated that :a woman asked Aishah: "Shouldn't one of us make up her prayers the days of her menstruation?" So she said, "Are you one of the Haruriyyah? Indeed we would menstruate, and we were not ordered to make up}}
\hadithdefcmd{tirmidhi}{131}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، وَالْحَسَنُ بْنُ عَرَفَةَ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقْرَإِ الْحَائِضُ وَلاَ الْجُنُبُ شَيْئًا مِنَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِسْمَاعِيلَ بْنِ عَيَّاشٍ عَنْ مُوسَى بْنِ عُقْبَةَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَقْرَإِ الْجُنُبُ وَلاَ الْحَائِضُ ‏"‏ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ مِثْلِ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ قَالُوا لاَ تَقْرَأُ الْحَائِضُ وَلاَ الْجُنُبُ مِنَ الْقُرْآنِ شَيْئًا إِلاَّ طَرَفَ الآيَةِ وَالْحَرْفَ وَنَحْوَ ذَلِكَ وَرَخَّصُوا لِلْجُنُبِ وَالْحَائِضِ فِي التَّسْبِيحِ وَالتَّهْلِيلِ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ إِنَّ إِسْمَاعِيلَ بْنَ عَيَّاشٍ يَرْوِي عَنْ أَهْلِ الْحِجَازِ وَأَهْلِ الْعِرَاقِ أَحَادِيثَ مَنَاكِيرَ ‏.‏ كَأَنَّهُ ضَعَّفَ رِوَايَتَهُ عَنْهُمْ فِيمَا يَنْفَرِدُ بِهِ ‏.‏ وَقَالَ إِنَّمَا حَدِيثُ إِسْمَاعِيلَ بْنِ عَيَّاشٍ عَنْ أَهْلِ الشَّأْمِ ‏.‏ وَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ إِسْمَاعِيلُ بْنُ عَيَّاشٍ أَصْلَحُ مِنْ بَقِيَّةَ وَلِبَقِيَّةَ أَحَادِيثُ مَنَاكِيرُ عَنِ الثِّقَاتِ ‏.‏ قَالَ أَبُو عِيسَى حَدَّثَنِي أَحْمَدُ بْنُ الْحَسَنِ قَالَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ ذَلِكَ ‏.‏\hadithno{131}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated that :the Prophet said: "The menstruating woman does not recite - nor the Junub - anything from the Qur'an." [He said:] There is narration on this topic from Ali}}
\hadithdefcmd{tirmidhi}{132}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا حِضْتُ يَأْمُرُنِي أَنْ أَتَّزِرَ ثُمَّ يُبَاشِرُنِي ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ وَمَيْمُونَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{132}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated that:"When I would menstruate, Allah's Messenger ordered me to wear a waist wrap, then he would fondle me}}
\hadithdefcmd{tirmidhi}{133}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ حَرَامِ بْنِ مُعَاوِيَةَ، عَنْ عَمِّهِ عَبْدِ اللَّهِ بْنِ سَعْدٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنْ مُوَاكَلَةِ الْحَائِضِ فَقَالَ ‏ "‏ وَاكِلْهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ سَعْدٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَهُوَ قَوْلُ عَامَّةِ أَهْلِ الْعِلْمِ لَمْ يَرَوْا بِمُوَاكَلَةِ الْحَائِضِ بَأْسًا ‏.‏ وَاخْتَلَفُوا فِي فَضْلِ وَضُوئِهَا فَرَخَّصَ فِي ذَلِكَ بَعْضُهُمْ وَكَرِهَ بَعْضُهُمْ فَضْلَ طَهُورِهَا ‏.‏\hadithno{133}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Sa'd narrated:I asked the Prophet about eating with a menstruating woman. He said: "Eat with her}}
\hadithdefcmd{tirmidhi}{134}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنِ الأَعْمَشِ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ قَالَتْ لِي عَائِشَةُ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَاوِلِينِي الْخُمْرَةَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ قَالَتْ قُلْتُ إِنِّي حَائِضٌ ‏.‏ قَالَ ‏"‏ إِنَّ حَيْضَتَكِ لَيْسَتْ فِي يَدِكِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ عَامَّةِ أَهْلِ الْعِلْمِ لاَ نَعْلَمُ بَيْنَهُمُ اخْتِلاَفًا فِي ذَلِكَ بِأَنْ لاَ بَأْسَ أَنْ تَتَنَاوَلَ الْحَائِضُ شَيْئًا مِنَ الْمَسْجِدِ ‏.‏\hadithno{134}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"Allah's Messenger said to me: 'Bring me the Khumrah from the Masjid.' She said: "I said: 'I am menstruating.' He said: 'Indeed your menstruation is not in your hand}}
\hadithdefcmd{tirmidhi}{135}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَبَهْزُ بْنُ أَسَدٍ، قَالُوا حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حَكِيمٍ الأَثْرَمِ، عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَتَى حَائِضًا أَوِ امْرَأَةً فِي دُبُرِهَا أَوْ كَاهِنًا فَقَدْ كَفَرَ بِمَا أُنْزِلَ عَلَى مُحَمَّدٍ صلى الله عليه وسلم ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى لاَ نَعْرِفُ هَذَا الْحَدِيثَ إِلاَّ مِنْ حَدِيثِ حَكِيمٍ الأَثْرَمِ عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَإِنَّمَا مَعْنَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ عَلَى التَّغْلِيظِ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَتَى حَائِضًا فَلْيَتَصَدَّقْ بِدِينَارٍ ‏"‏ ‏.‏ فَلَوْ كَانَ إِتْيَانُ الْحَائِضِ كُفْرًا لَمْ يُؤْمَرْ فِيهِ بِالْكَفَّارَةِ ‏.‏ وَضَعَّفَ مُحَمَّدٌ هَذَا الْحَدِيثَ مِنْ قِبَلِ إِسْنَادِهِ ‏.‏ وَأَبُو تَمِيمَةَ الْهُجَيْمِيُّ اسْمُهُ طَرِيفُ بْنُ مُجَالِدٍ ‏.‏\hadithno{135}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Whoever engages in sexual intercourse with a menstruating woman, or a woman in her anus, consults a soothsayer, then he has disbelieved in what was revealed to Muhammad}}
\hadithdefcmd{tirmidhi}{136}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ خُصَيْفٍ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرَّجُلِ يَقَعُ عَلَى امْرَأَتِهِ وَهِيَ حَائِضٌ قَالَ ‏ "‏ يَتَصَدَّقُ بِنِصْفِ دِينَارٍ ‏"‏ ‏.‏\hadithno{136}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that :the Prophet said about a man who had sexual intercourse with his wife while she is menstruating: "He should give half a Dinar in charity}}
\hadithdefcmd{tirmidhi}{137}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ أَبِي حَمْزَةَ السُّكَّرِيِّ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ دَمًا أَحْمَرَ فَدِينَارٌ وَإِذَا كَانَ دَمًا أَصْفَرَ فَنِصْفُ دِينَارٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْكَفَّارَةِ فِي إِتْيَانِ الْحَائِضِ قَدْ رُوِيَ عَنِ ابْنِ عَبَّاسٍ مَوْقُوفًا وَمَرْفُوعًا ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ يَسْتَغْفِرُ رَبَّهُ وَلاَ كَفَّارَةَ عَلَيْهِ ‏.‏ وَقَدْ رُوِيَ نَحْوُ قَوْلِ ابْنِ الْمُبَارَكِ عَنْ بَعْضِ التَّابِعِينَ مِنْهُمْ سَعِيدُ بْنُ جُبَيْرٍ وَإِبْرَاهِيمُ النَّخَعِيُّ وَهُوَ قَوْلُ عَامَّةِ عُلَمَاءِ الأَمْصَارِ ‏.‏\hadithno{137}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that :the Prophet said: "When the blood is red then (give) a Dinar. And when the blood is yellow then half Dinar}}
\hadithdefcmd{tirmidhi}{138}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّ امْرَأَةً، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم عَنِ الثَّوْبِ يُصِيبُهُ الدَّمُ مِنَ الْحَيْضَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حُتِّيهِ ثُمَّ اقْرُصِيهِ بِالْمَاءِ ثُمَّ رُشِّيهِ وَصَلِّي فِيهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَسْمَاءَ فِي غَسْلِ الدَّمِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الدَّمِ يَكُونُ عَلَى الثَّوْبِ فَيُصَلِّي فِيهِ قَبْلَ أَنْ يَغْسِلَهُ قَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ إِذَا كَانَ الدَّمُ مِقْدَارَ الدِّرْهَمِ فَلَمْ يَغْسِلْهُ وَصَلَّى فِيهِ أَعَادَ الصَّلاَةَ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا كَانَ الدَّمُ أَكْثَرَ مِنْ قَدْرِ الدِّرْهَمِ أَعَادَ الصَّلاَةَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ ‏.‏ وَلَمْ يُوجِبْ بَعْضُ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ وَغَيْرِهِمْ عَلَيْهِ الإِعَادَةَ وَإِنْ كَانَ أَكْثَرَ مِنْ قَدْرِ الدِّرْهَمِ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ الشَّافِعِيُّ يَجِبُ عَلَيْهِ الْغَسْلُ وَإِنْ كَانَ أَقَلَّ مِنْ قَدْرِ الدِّرْهَمِ وَشَدَّدَ فِي ذَلِكَ ‏.‏\hadithno{138}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Asma' bint Abu Bakr narrated that :a woman asked the Prophet about a garment that was touched by some menstrual blood. So Allah's Messenger said: "Remove it, and scrub it, then rinse it and pray in it}}
\hadithdefcmd{tirmidhi}{139}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا شُجَاعُ بْنُ الْوَلِيدِ أَبُو بَدْرٍ، عَنْ عَلِيِّ بْنِ عَبْدِ الأَعْلَى، عَنْ أَبِي سَهْلٍ، عَنْ مُسَّةَ الأَزْدِيَّةِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَتِ النُّفَسَاءُ تَجْلِسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْبَعِينَ يَوْمًا فَكُنَّا نَطْلِي وُجُوهَنَا بِالْوَرْسِ مِنَ الْكَلَفِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي سَهْلٍ عَنْ مُسَّةَ الأَزْدِيَّةِ عَنْ أُمِّ سَلَمَةَ ‏.‏ وَاسْمُ أَبِي سَهْلٍ كَثِيرُ بْنُ زِيَادٍ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ عَلِيُّ بْنُ عَبْدِ الأَعْلَى ثِقَةٌ وَأَبُو سَهْلٍ ثِقَةٌ ‏.‏ وَلَمْ يَعْرِفْ مُحَمَّدٌ هَذَا الْحَدِيثَ إِلاَّ مِنْ حَدِيثِ أَبِي سَهْلٍ ‏.‏ وَقَدْ أَجْمَعَ أَهْلُ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ عَلَى أَنَّ النُّفَسَاءَ تَدَعُ الصَّلاَةَ أَرْبَعِينَ يَوْمًا إِلاَّ أَنْ تَرَى الطُّهْرَ قَبْلَ ذَلِكَ فَإِنَّهَا تَغْتَسِلُ وَتُصَلِّي ‏.‏ فَإِذَا رَأَتِ الدَّمَ بَعْدَ الأَرْبَعِينَ فَإِنَّ أَكْثَرَ أَهْلِ الْعِلْمِ قَالُوا لاَ تَدَعُ الصَّلاَةَ بَعْدَ الأَرْبَعِينَ وَهُوَ قَوْلُ أَكْثَرِ الْفُقَهَاءِ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَيُرْوَى عَنِ الْحَسَنِ الْبَصْرِيِّ أَنَّهُ قَالَ إِنَّهَا تَدَعُ الصَّلاَةَ خَمْسِينَ يَوْمًا إِذَا لَمْ تَرَ الطُّهْرَ ‏.‏ وَيُرْوَى عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ وَالشَّعْبِيِّ سِتِّينَ يَوْمًا ‏.‏\hadithno{139}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Umm Salamah narrated:"The time of waiting for Nifas during the time of AIlah's Messenger was forty days. We used to cover our faces with reddish-brown Wars}}
\hadithdefcmd{tirmidhi}{140}{حَدَّثَنَا بُنْدَارٌ، مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَطُوفُ عَلَى نِسَائِهِ فِي غُسْلٍ وَاحِدٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي رَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَطُوفُ عَلَى نِسَائِهِ بِغُسْلٍ وَاحِدٍ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْهُمُ الْحَسَنُ الْبَصْرِيُّ أَنْ لاَ بَأْسَ أَنْ يَعُودَ قَبْلَ أَنْ يَتَوَضَّأَ ‏.‏ وَقَدْ رَوَى مُحَمَّدُ بْنُ يُوسُفَ هَذَا عَنْ سُفْيَانَ فَقَالَ عَنْ أَبِي عُرْوَةَ عَنْ أَبِي الْخَطَّابِ عَنْ أَنَسٍ ‏.‏ وَأَبُو عُرْوَةَ هُوَ مَعْمَرُ بْنُ رَاشِدٍ ‏.‏ وَأَبُو الْخَطَّابِ قَتَادَةُ بْنُ دِعَامَةَ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَاهُ بَعْضُهُمْ عَنْ مُحَمَّدِ بْنِ يُوسُفَ عَنْ سُفْيَانَ عَنِ ابْنِ أَبِي عُرْوَةَ عَنْ أَبِي الْخَطَّابِ ‏.‏ وَهُوَ خَطَأٌ وَالصَّحِيحُ عَنْ أَبِي عُرْوَةَ ‏.‏\hadithno{140}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated:"Allah's Messenger would go around to his women with one Ghusl}}
\hadithdefcmd{tirmidhi}{141}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَتَى أَحَدُكُمْ أَهْلَهُ ثُمَّ أَرَادَ أَنْ يَعُودَ فَلْيَتَوَضَّأْ بَيْنَهُمَا وُضُوءًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ عُمَرَ بْنِ الْخَطَّابِ وَقَالَ بِهِ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ قَالُوا إِذَا جَامَعَ الرَّجُلُ امْرَأَتَهُ ثُمَّ أَرَادَ أَنْ يَعُودَ فَلْيَتَوَضَّأْ قَبْلَ أَنْ يَعُودَ ‏.‏ وَأَبُو الْمُتَوَكِّلِ اسْمُهُ عَلِيُّ بْنُ دَاوُدَ ‏.‏ وَأَبُو سَعِيدٍ الْخُدْرِيُّ اسْمُهُ سَعْدُ بْنُ مَالِكِ بْنِ سِنَانٍ ‏.‏\hadithno{141}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :the Prophet said: When one of you comes to his wife, then he wants to repeat (it), let him perform Wudu between them}}
\hadithdefcmd{tirmidhi}{142}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الأَرْقَمِ، قَالَ أُقِيمَتِ الصَّلاَةُ فَأَخَذَ بِيَدِ رَجُلٍ فَقَدَّمَهُ وَكَانَ إِمَامَ قَوْمِهِ وَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ وَوَجَدَ أَحَدُكُمُ الْخَلاَءَ فَلْيَبْدَأْ بِالْخَلاَءِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي هُرَيْرَةَ وَثَوْبَانَ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ الأَرْقَمِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ هَكَذَا رَوَى مَالِكُ بْنُ أَنَسٍ وَيَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَغَيْرُ وَاحِدٍ مِنَ الْحُفَّاظِ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَبْدِ اللَّهِ بْنِ الأَرْقَمِ ‏.‏ وَرَوَى وُهَيْبٌ وَغَيْرُهُ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ رَجُلٍ عَنْ عَبْدِ اللَّهِ بْنِ الأَرْقَمِ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ قَالاَ لاَ يَقُومُ إِلَى الصَّلاَةِ وَهُوَ يَجِدُ شَيْئًا مِنَ الْغَائِطِ وَالْبَوْلِ ‏.‏ وَقَالاَ إِنْ دَخَلَ فِي الصَّلاَةِ فَوَجَدَ شَيْئًا مِنْ ذَلِكَ فَلاَ يَنْصَرِفْ مَا لَمْ يَشْغَلْهُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ بَأْسَ أَنْ يُصَلِّيَ وَبِهِ غَائِطٌ أَوْ بَوْلٌ مَا لَمْ يَشْغَلْهُ ذَلِكَ عَنِ الصَّلاَةِ ‏.‏\hadithno{142}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hisham bin Urwah narrated from his father, (Urwah) from Abdullah bin AI-Arqam. :He (Urwah) said: "While standing for the prayer he (Abdullah bin Al-Arqam) took a man by the hand leading him forward, he (Abdullah) was in front of the people, and he said: 'I heard Allah's Messenger say: "When standing for the prayer and one of you finds that he has to relieve himself then let him relieve himself first}}
\hadithdefcmd{tirmidhi}{143}{حَدَّثَنَا أَبُو رَجَاءٍ، قُتَيْبَةُ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ مُحَمَّدِ بْنِ عُمَارَةَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أُمِّ وَلَدٍ، لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ قَالَتْ قُلْتُ لأُمِّ سَلَمَةَ إِنِّي امْرَأَةٌ أُطِيلُ ذَيْلِي وَأَمْشِي فِي الْمَكَانِ الْقَذِرِ فَقَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُطَهِّرُهُ مَا بَعْدَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نَتَوَضَّأُ مِنَ الْمَوْطَإِ ‏.‏ قَالَ أَبُو عِيسَى وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ قَالُوا إِذَا وَطِئَ الرَّجُلُ عَلَى الْمَكَانِ الْقَذِرِ أَنَّهُ لاَ يَجِبُ عَلَيْهِ غَسْلُ الْقَدَمِ إِلاَّ أَنْ يَكُونَ رَطْبًا فَيَغْسِلَ مَا أَصَابَهُ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ هَذَا الْحَدِيثَ عَنْ مَالِكِ بْنِ أَنَسٍ عَنْ مُحَمَّدِ بْنِ عُمَارَةَ عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ عَنْ أُمِّ وَلَدٍ لِهُودِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ عَنْ أُمِّ سَلَمَةَ ‏.‏ وَهُوَ وَهَمٌ وَلَيْسَ لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ ابْنٌ يُقَالُ لَهُ هُودٌ وَإِنَّمَا هُوَ عَنْ أُمِّ وَلَدٍ لإِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ عَنْ أُمِّ سَلَمَةَ ‏.‏ وَهَذَا الصَّحِيحُ ‏.‏\hadithno{143}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur-Rahman bin Awf's Umm Walad said, :"I said to Umm Salamah: 'Indeed I am a woman with lengthy hems, and I walk in places of filth.' So she said: 'Allah's Messenger said: "It is purified by what comes after it}}
\hadithdefcmd{tirmidhi}{144}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ الْفَلاَّسُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ بِالتَّيَمُّمِ لِلْوَجْهِ وَالْكَفَّيْنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَمَّارٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ عَمَّارٍ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عَلِيٌّ وَعَمَّارٌ وَابْنُ عَبَّاسٍ وَغَيْرِ وَاحِدٍ مِنَ التَّابِعِينَ مِنْهُمُ الشَّعْبِيُّ وَعَطَاءٌ وَمَكْحُولٌ قَالُوا التَّيَمُّمُ ضَرْبَةٌ لِلْوَجْهِ وَالْكَفَّيْنِ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْهُمُ ابْنُ عُمَرَ وَجَابِرٌ وَإِبْرَاهِيمُ وَالْحَسَنُ قَالُوا التَّيَمُّمُ ضَرْبَةٌ لِلْوَجْهِ وَضَرْبَةٌ لِلْيَدَيْنِ إِلَى الْمِرْفَقَيْنِ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَمَالِكٌ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَمَّارٍ فِي التَّيَمُّمِ أَنَّهُ قَالَ لِلْوَجْهِ وَالْكَفَّيْنِ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَقَدْ رُوِيَ عَنْ عَمَّارٍ أَنَّهُ قَالَ تَيَمَّمْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم إِلَى الْمَنَاكِبِ وَالآبَاطِ ‏.‏ فَضَعَّفَ بَعْضُ أَهْلِ الْعِلْمِ حَدِيثَ عَمَّارٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي التَّيَمُّمِ لِلْوَجْهِ وَالْكَفَّيْنِ لَمَّا رُوِيَ عَنْهُ حَدِيثُ الْمَنَاكِبِ وَالآبَاطِ ‏.‏ قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ مَخْلَدٍ الْحَنْظَلِيُّ حَدِيثُ عَمَّارٍ فِي التَّيَمُّمِ لِلْوَجْهِ وَالْكَفَّيْنِ هُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَدِيثُ عَمَّارٍ تَيَمَّمْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم إِلَى الْمَنَاكِبِ وَالآبَاطِ لَيْسَ هُوَ بِمُخَالِفٍ لِحَدِيثِ الْوَجْهِ وَالْكَفَّيْنِ لأَنَّ عَمَّارًا لَمْ يَذْكُرْ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُمْ بِذَلِكَ وَإِنَّمَا قَالَ فَعَلْنَا كَذَا وَكَذَا فَلَمَّا سَأَلَ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ بِالْوَجْهِ وَالْكَفَّيْنِ فَانْتَهَى إِلَى مَا عَلَّمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَجْهِ وَالْكَفَّيْنِ وَالدَّلِيلُ عَلَى ذَلِكَ مَا أَفْتَى بِهِ عَمَّارٌ بَعْدَ النَّبِيِّ صلى الله عليه وسلم فِي التَّيَمُّمِ أَنَّهُ قَالَ الْوَجْهِ وَالْكَفَّيْنِ فَفِي هَذَا دَلاَلَةٌ أَنَّهُ انْتَهَى إِلَى مَا عَلَّمَهُ النَّبِيُّ صلى الله عليه وسلم فَعَلَّمَهُ إِلَى الْوَجْهِ وَالْكَفَّيْنِ ‏.‏ قَالَ وَسَمِعْتُ أَبَا زُرْعَةَ عُبَيْدَ اللَّهِ بْنَ عَبْدِ الْكَرِيمِ يَقُولُ لَمْ أَرَ بِالْبَصْرَةِ أَحْفَظَ مِنْ هَؤُلاَءِ الثَّلاَثَةِ عَلِيِّ بْنِ الْمَدِينِيِّ وَابْنِ الشَّاذَكُونِيِّ وَعَمْرِو بْنِ عَلِيٍّ الْفَلاَّسِ ‏.‏ قَالَ أَبُو زُرْعَةَ وَرَوَى عَفَّانُ بْنُ مُسْلِمٍ عَنْ عَمْرِو بْنِ عَلِيٍّ حَدِيثًا ‏.‏\hadithno{144}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ammar bin Yasir narrated that :the Prophet ordered him to perform Tayammum by rubbing his face and two palms}}
\hadithdefcmd{tirmidhi}{145}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هُشَيْمٌ، عَنْ مُحَمَّدِ بْنِ خَالِدٍ الْقُرَشِيِّ، عَنْ دَاوُدَ بْنِ حُصَيْنٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ سُئِلَ عَنِ التَّيَمُّمِ، فَقَالَ إِنَّ اللَّهَ قَالَ فِي كِتَابِهِ حِينَ ذَكَرَ الْوُضُوءَ‏:‏ ‏(‏فَاغْسِلُوا وُجُوهَكُمْ وَأَيْدِيَكُمْ إلى المَرَافِقِ‏)‏، وَقَالَ في التَّيَمُّمِ‏:‏ ‏(‏فَامْسَحُوا بِوُجُوهِكُمْ وَأَيْدِيكُمْ‏)‏ وَقَالَ‏:‏ ‏(‏وَالسَّارِقُ وَالسَّارِقَةُ فَاقْطَعُوا أَيْدِيِهْمَا‏)‏ فَكَانَتِ السُّنَّةُ في القَطْعِ الكَفَّينِ، إِنَّمَا هُوَ الوَجْهُ وَالكَفَّانِ، يَعْنِي التَّيَمُّمَ‏"‏‏.‏\hadithno{145}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ikrimah narrated that :Ibn Abbas was asked ahout Tayammum. He said: "When Allah mentioned Wudu in His Book, He said: "So wash your faces and your hands (forearms) up to the elbows." And He said about Tayammum: "And rub therewith your faces and hands" And He said: "And the male thief and the female thief; cut off their hands." So the Sunnah for cutting is the two hands. So it is only the face and the hands, meaning, Tayammum}}
\hadithdefcmd{tirmidhi}{146}{حَدَّثَنَا أَبُو سَعِيدٍ عَبْدُ اللَّهِ بْنُ سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، وَعُقْبَةُ بْنُ خَالِدٍ، قَالاَ حَدَّثَنَا الأَعْمَشُ، وَابْنُ أَبِي لَيْلَى، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، عَنْ عَلِيٍّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقْرِئُنَا الْقُرْآنَ عَلَى كُلِّ حَالٍ مَا لَمْ يَكُنْ جُنُبًا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهِ قَالَ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ ‏.‏ قَالُوا يَقْرَأُ الرَّجُلُ الْقُرْآنَ عَلَى غَيْرِ وُضُوءٍ وَلاَ يَقْرَأُ فِي الْمُصْحَفِ إِلاَّ وَهُوَ طَاهِرٌ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{146}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ali narrated:"Allah's Messenger would recite the Qur'an in all conditions, as long as he was not Junub}}
\hadithdefcmd{tirmidhi}{147}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ دَخَلَ أَعْرَابِيٌّ الْمَسْجِدَ وَالنَّبِيُّ صلى الله عليه وسلم جَالِسٌ فَصَلَّى فَلَمَّا فَرَغَ قَالَ اللَّهُمَّ ارْحَمْنِي وَمُحَمَّدًا وَلاَ تَرْحَمْ مَعَنَا أَحَدًا ‏.‏ فَالْتَفَتَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ لَقَدْ تَحَجَّرْتَ وَاسِعًا ‏"‏ ‏.‏ فَلَمْ يَلْبَثْ أَنْ بَالَ فِي الْمَسْجِدِ فَأَسْرَعَ إِلَيْهِ النَّاسُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَهْرِيقُوا عَلَيْ��ِ سَجْلاً مِنْ مَاءٍ أَوْ دَلْوًا مِنْ مَاءٍ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّمَا بُعِثْتُمْ مُيَسِّرِينَ وَلَمْ تُبْعَثُوا مُعَسِّرِينَ ‏"‏ ‏.‏\hadithno{147}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated:"A Bedouin entered the Masjid while the Prophet was sitting. He prayed, then when he was finished, he said: 'O Allah! Have mercy upon me and Muhammad, and do not have mercy on anyone along with us.' The Prophet turned, towards him and said: 'You have restricted something that is unrestricted.' It was not long before he was urinating in the Masjid. So the people rushed to him. But Prophet said: 'Pour a bucket of water over it - or - a tumbler of water over it.' Then he said: 'You have been sent to make things easy (for the people); you have not been sent to make things difficult for them}}
\hadithdefcmd{tirmidhi}{148}{قَالَ سَعِيدٌ قَالَ سُفْيَانُ وَحَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، نَحْوَ هَذَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، وَابْنِ، عَبَّاسٍ وَوَاثِلَةَ بْنِ الأَسْقَعِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ رَوَى يُونُسُ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{148}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated similar to this (no. 147).:[He said:] There are narrations on this topic from 'Abdullah bin Mas'ud, Ibn Abbas, and Wathilah bin AI-Asqa}}
