% Auto-generated chapter 60 for bukhari
% Hadiths in this chapter: 154

\hadithdefcmd{bukhari}{3326}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَلَقَ اللَّهُ آدَمَ وَطُولُهُ سِتُّونَ ذِرَاعًا، ثُمَّ قَالَ اذْهَبْ فَسَلِّمْ عَلَى أُولَئِكَ مِنَ الْمَلاَئِكَةِ، فَاسْتَمِعْ مَا يُحَيُّونَكَ، تَحِيَّتُكَ وَتَحِيَّةُ ذُرِّيَّتِكَ‏.‏ فَقَالَ السَّلاَمُ عَلَيْكُمْ‏.‏ فَقَالُوا السَّلاَمُ عَلَيْكَ وَرَحْمَةُ اللَّهِ‏.‏ فَزَادُوهُ وَرَحْمَةُ اللَّهِ‏.‏ فَكُلُّ مَنْ يَدْخُلُ الْجَنَّةَ عَلَى صُورَةِ آدَمَ، فَلَمْ يَزَلِ الْخَلْقُ يَنْقُصُ حَتَّى الآنَ ‏"‏‏.‏\hadithno{3326}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah created Adam, making him 60 cubits tall. When He created him, He said to him, "Go and greet that group of angels, and listen to their reply, for it will be your greeting (salutation) and the greeting (salutations of your offspring." So, Adam said (to the angels), As-Salamu Alaikum (i.e. Peace be upon you). The angels said, "As-salamu Alaika wa Rahmatu-l-lahi" (i.e. Peace and Allah's Mercy be upon you). Thus the angels added to Adam's salutation the expression, 'Wa Rahmatu-l-lahi,' Any person who will enter Paradise will resemble Adam (in appearance and figure). People have been decreasing in stature since Adam's creation}}
\hadithdefcmd{bukhari}{3327}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَوَّلَ زُمْرَةٍ يَدْخُلُونَ الْجَنَّةَ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ، ثُمَّ الَّذِينَ يَلُونَهُمْ عَلَى أَشَدِّ كَوْكَبٍ دُرِّيٍّ فِي السَّمَاءِ إِضَاءَةً، لاَ يَبُولُونَ وَلاَ يَتَغَوَّطُونَ وَلاَ يَتْفِلُونَ وَلاَ يَمْتَخِطُونَ، أَمْشَاطُهُمُ الذَّهَبُ، وَرَشْحُهُمُ الْمِسْكُ، وَمَجَامِرُهُمُ الأَلُوَّةُ الأَنْجُوجُ عُودُ الطِّيبِ، وَأَزْوَاجُهُمُ الْحُورُ الْعِينُ، عَلَى خَلْقِ رَجُلٍ وَاحِدٍ عَلَى صُورَةِ أَبِيهِمْ آدَمَ، سِتُّونَ ذِرَاعًا فِي السَّمَاءِ ‏"‏‏.‏\hadithno{3327}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The first group of people who will enter Paradise, will be glittering like the full moon and those who will follow them, will glitter like the most brilliant star in the sky. They will not urinate, relieve nature, spit, or have any nasal secretions. Their combs will be of gold, and their sweat will smell like musk. The aloes-wood will be used in their centers. Their wives will be houris. All of them will look alike and will resemble their father Adam (in stature), sixty cubits tall}}
\hadithdefcmd{bukhari}{3328}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ أُمَّ سُلَيْمٍ، قَالَتْ يَا رَسُولَ اللَّهِ، إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ، فَهَلْ عَلَى الْمَرْأَةِ الْغُسْلُ إِذَا احْتَلَمَتْ قَالَ ‏"‏ نَعَمْ، إِذَا رَأَتِ الْمَاءَ ‏"‏‏.‏ فَضَحِكَتْ أُمُّ سَلَمَةَ، فَقَالَتْ تَحْتَلِمُ الْمَرْأَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَبِمَا يُشْبِهُ الْوَلَدُ ‏"‏‏.‏\hadithno{3328}\hadithtrans{Narrated Zainab bint Abi Salama:Um Salama said, "Um Sulaim said, 'O Allah's Messenger (ﷺ)! Allah does not refrain from saying the truth! Is it obligatory for a woman to take a bath after she gets nocturnal discharge?' He said, 'Yes, if she notices the water (i.e. discharge).' Um Salama smiled and said, 'Does a woman get discharge?' Allah's Apostle said. 'Then why does a child resemble (its mother)?}}
\hadithdefcmd{bukhari}{3329}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا الْفَزَارِيُّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ بَلَغَ عَبْدَ اللَّهِ بْنَ سَلاَمٍ مَقْدَمُ رَسُولِ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ، فَأَتَاهُ، فَقَالَ إِنِّي سَائِلُكَ عَنْ ثَلاَثٍ لاَ يَعْلَمُهُنَّ إِلاَّ نَبِيٌّ، ‏\{‏قَالَ مَا‏\}‏ أَوَّلُ أَشْرَاطِ السَّاعَةِ وَمَا أَوَّلُ طَعَامٍ يَأْكُلُهُ أَهْلُ الْجَنَّةِ وَمِنْ أَىِّ شَىْءٍ يَنْزِعُ الْوَلَدُ إِلَى أَبِيهِ وَمِنْ أَىِّ شَىْءٍ يَنْزِعُ إِلَى أَخْوَالِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَبَّرَنِي بِهِنَّ آنِفًا جِبْرِيلُ ‏"‏‏.‏ قَالَ فَقَالَ عَبْدُ اللَّهِ ذَاكَ عَدُوُّ الْيَهُودِ مِنَ الْمَلاَئِكَةِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا أَوَّلُ أَشْرَاطِ السَّاعَةِ فَنَارٌ تَحْشُرُ النَّاسَ مِنَ الْمَشْرِقِ إِلَى الْمَغْرِبِ‏.‏ وَأَمَّا أَوَّلُ طَعَامٍ يَأْكُلُهُ أَهْلُ الْجَنَّةِ فَزِيَادَةُ كَبِدِ حُوتٍ‏.‏ وَأَمَّا الشَّبَهُ فِي الْوَلَدِ فَإِنَّ الرَّجُلَ إِذَا غَشِيَ الْمَرْأَةَ فَسَبَقَهَا مَاؤُهُ كَانَ الشَّبَهُ لَهُ، وَإِذَا سَبَقَ مَاؤُهَا كَانَ الشَّبَهُ لَهَا ‏"‏‏.‏ قَالَ أَشْهَدُ أَنَّكَ رَسُولُ اللَّهِ‏.‏ ثُمَّ قَالَ يَا رَسُولَ اللَّهِ إِنَّ الْيَهُودَ قَوْمٌ بُهُتٌ، إِنْ عَلِمُوا بِإِسْلاَمِي قَبْلَ أَنْ تَسْأَلَهُمْ بَهَتُونِي عِنْدَكَ، فَجَاءَتِ الْيَهُودُ وَدَخَلَ عَبْدُ اللَّهِ الْبَيْتَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَىُّ رَجُلٍ فِيكُمْ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ‏"‏‏.‏ قَالُوا أَعْلَمُنَا وَابْنُ أَعْلَمِنَا وَأَخْبَرُنَا وَابْنُ أَخْيَرِنَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفَرَأَيْتُمْ إِنْ أَسْلَمَ عَبْدُ اللَّهِ ‏"‏‏.‏ قَالُوا أَعَاذَهُ اللَّهُ مِنْ ذَلِكَ‏.‏ فَخَرَجَ عَبْدُ اللَّهِ إِلَيْهِمْ فَقَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ‏.‏ فَقَالُوا شَرُّنَا وَابْنُ شَرِّنَا‏.‏ وَوَقَعُوا فِيهِ‏.‏\hadithno{3329}\hadithtrans{Narrated Anas:When `Abdullah bin Salam heard the arrival of the Prophet (ﷺ) at Medina, he came to him and said, "I am going to ask you about three things which nobody knows except a prophet: What is the first portent of the Hour? What will be the first meal taken by the people of Paradise? Why does a child resemble its father, and why does it resemble its maternal uncle" Allah's Messenger (ﷺ) said, "Gabriel has just now told me of their answers." `Abdullah said, "He (i.e. Gabriel), from amongst all the angels, is the enemy of the Jews." Allah's Messenger (ﷺ) said, "The first portent of the Hour will be a fire that will bring together the people from the east to the west; the first meal of the people of Paradise will be Extra-lobe (caudate lobe) of fish-liver. As for the resemblance of the child to its parents: If a man has sexual intercourse with his wife and gets discharge first, the child will resemble the father, and if the woman gets discharge first, the child will resemble her." On that `Abdullah bin Salam said, "I testify that you are the Messenger of Allah." `Abdullah bin Salam further said, "O Allah's Messenger (ﷺ)! The Jews are liars, and if they should come to know about my conversion to Islam before you ask them (about me), they would tell a lie about me." The Jews came to Allah's Messenger (ﷺ) and `Abdullah went inside the house. Allah's Apostle asked (the Jews), "What kind of man is `Abdullah bin Salam amongst you?" They replied, "He is the most learned person amongst us, and the best amongst us, and the son of the best amongst us." Allah's Messenger (ﷺ) said, "What do you think if he embraces Islam (will you do as he does)?" The Jews said, "May Allah save him from it." Then `Abdullah bin Salam came out in front of them saying, "I testify that None has the right to be worshipped but Allah and that Muhammad is the Apostle of Allah." Thereupon they said, "He is the evilest among us, and the son of the evilest amongst us," and continued talking badly of him}}
\hadithdefcmd{bukhari}{3330}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ يَعْنِي ‏ "‏ لَوْلاَ بَنُو إِسْرَائِيلَ لَمْ يَخْنَزِ اللَّحْمُ، وَلَوْلاَ حَوَّاءُ لَمْ تَخُنْ أُنْثَى زَوْجَهَا ‏"‏‏.‏\hadithno{3330}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "But for the Israelis, meat would not decay and but for Eve, wives would never betray their husbands}}
\hadithdefcmd{bukhari}{3331}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَمُوسَى بْنُ حِزَامٍ، قَالاَ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ مَيْسَرَةَ الأَشْجَعِيِّ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْتَوْصُوا بِالنِّسَاءِ، فَإِنَّ الْمَرْأَةَ خُلِقَتْ مِنْ ضِلَعٍ، وَإِنَّ أَعْوَجَ شَىْءٍ فِي الضِّلَعِ أَعْلاَهُ، فَإِنْ ذَهَبْتَ تُقِيمُهُ كَسَرْتَهُ، وَإِنْ تَرَكْتَهُ لَمْ يَزَلْ أَعْوَجَ، فَاسْتَوْصُوا بِالنِّسَاءِ ‏"‏‏.‏\hadithno{3331}\hadithtrans{Narrated Abu Huraira:Allah's Apostle said, "Treat women nicely, for a woman is created from a rib, and the most curved portion of the rib is its upper portion, so, if you should try to straighten it, it will break, but if you leave it as it is, it will remain crooked. So treat women nicely}}
\hadithdefcmd{bukhari}{3332}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا زَيْدُ بْنُ وَهْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ، حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ الصَّادِقُ الْمَصْدُوقُ ‏ "‏ إِنَّ أَحَدَكُمْ يُجْمَعُ فِي بَطْنِ أُمِّهِ أَرْبَعِينَ يَوْمًا، ثُمَّ يَكُونُ عَلَقَةً مِثْلَ ذَلِكَ، ثُمَّ يَكُونُ مُضْغَةً مِثْلَ ذَلِكَ، ثُمَّ يَبْعَثُ اللَّهُ إِلَيْهِ مَلَكًا بِأَرْبَعِ كَلِمَاتٍ، فَيُكْتَبُ عَمَلُهُ وَأَجَلُهُ وَرِزْقُهُ وَشَقِيٌّ أَوْ سَعِيدٌ، ثُمَّ يُنْفَخُ فِيهِ الرُّوحُ، فَإِنَّ الرَّجُلَ لَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ، فَيَسْبِقُ عَلَيْهِ الْكِتَابُ فَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ، فَيَدْخُلُ الْجَنَّةَ، وَإِنَّ الرَّجُلَ لَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ، حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ فَيَسْبِقُ عَلَيْهِ الْكِتَابُ، فَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ فَيَدْخُلُ النَّارَ ‏"‏‏.‏\hadithno{3332}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ), the true and truly inspired said, "(as regards your creation), every one of you is collected in the womb of his mother for the first forty days, and then he becomes a clot for another forty days, and then a piece of flesh for another forty days. Then Allah sends an angel to write four items: He writes his deeds, time of his death, means of his livelihood, and whether he will be wretched or blessed (in religion). Then the soul is breathed into his body. So a man may do deeds characteristic of the people of the (Hell) Fire, so much so that there is only the distance of a cubit between him and it, and then what has been written (by the angel) surpasses, and so he starts doing deeds characteristic of the people of Paradise and enters Paradise. Similarly, a person may do deeds characteristic of the people of Paradise, so much so that there is only the distance of a cubit between him and it, and then what has been written (by the angel) surpasses, and he starts doing deeds of the people of the (Hell) Fire and enters the (Hell) Fire}}
\hadithdefcmd{bukhari}{3333}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ وَكَّلَ فِي الرَّحِمِ مَلَكًا فَيَقُولُ يَا رَبِّ نُطْفَةٌ، يَا رَبِّ عَلَقَةٌ، يَا رَبِّ مُضْغَةٌ، فَإِذَا أَرَادَ أَنْ يَخْلُقَهَا قَالَ يَا رَبِّ، أَذَكَرٌ أَمْ يَا رَبِّ أُنْثَى يَا رَبِّ شَقِيٌّ أَمْ سَعِيدٌ فَمَا الرِّزْقُ فَمَا الأَجَلُ فَيُكْتَبُ كَذَلِكَ فِي بَطْنِ أُمِّهِ ‏"‏‏.‏\hadithno{3333}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Allah has appointed an angel in the womb, and the angel says, 'O Lord! A drop of discharge (i.e. of semen), O Lord! a clot, O Lord! a piece of flesh.' And then, if Allah wishes to complete the child's creation, the angel will say. 'O Lord! A male or a female? O Lord! wretched or blessed (in religion)? What will his livelihood be? What will his age be?' The angel writes all this while the child is in the womb of its mother}}
\hadithdefcmd{bukhari}{3334}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَنَسٍ، يَرْفَعُهُ ‏ "‏ أَنَّ اللَّهَ، يَقُولُ لأَهْوَنِ أَهْلِ النَّارِ عَذَابًا لَوْ أَنَّ لَكَ مَا فِي الأَرْضِ مِنْ شَىْءٍ كُنْتَ تَفْتَدِي بِهِ قَالَ نَعَمْ‏.‏ قَالَ فَقَدْ سَأَلْتُكَ مَا هُوَ أَهْوَنُ مِنْ هَذَا وَأَنْتَ فِي صُلْبِ آدَمَ أَنْ لاَ تُشْرِكَ بِي‏.‏ فَأَبَيْتَ إِلاَّ الشِّرْكَ ‏"‏‏.‏\hadithno{3334}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Allah will say to that person of the (Hell) Fire who will receive the least punishment, 'If you had everything on the earth, would you give it as a ransom to free yourself (i.e. save yourself from this Fire)?' He will say, 'Yes.' Then Allah will say, 'While you were in the backbone of Adam, I asked you much less than this, i.e. not to worship others besides Me, but you insisted on worshipping others besides me}}
\hadithdefcmd{bukhari}{3335}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقْتَلُ نَفْسٌ ظُلْمًا إِلاَّ كَانَ عَلَى ابْنِ آدَمَ الأَوَّلِ كِفْلٌ مِنْ دَمِهَا، لأَنَّهُ أَوَّلُ مَنْ سَنَّ الْقَتْلَ ‏"‏‏.‏\hadithno{3335}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "Whenever a person is murdered unjustly, there is a share from the burden of the crime on the first son of Adam for he was the first to start the tradition of murdering}}
\hadithdefcmd{bukhari}{3336}{قَالَ قَالَ اللَّيْثُ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الأَرْوَاحُ جُنُودٌ مُجَنَّدَةٌ، فَمَا تَعَارَفَ مِنْهَا ائْتَلَفَ، وَمَا تَنَاكَرَ مِنْهَا اخْتَلَفَ ‏"‏‏.‏ وَقَالَ يَحْيَى بْنُ أَيُّوبَ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ بِهَذَا‏.‏\hadithno{3336}\hadithtrans{Narrated Aishah (ra):I heard the Prophet (ﷺ), "Souls are like recruited troops: Those who are like qualities are inclined to each other, but those who have dissimilar qualities, differ}}
\hadithdefcmd{bukhari}{3337}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ سَالِمٌ وَقَالَ ابْنُ عُمَرَ ـ رضى الله عنهما قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ ذَكَرَ الدَّجَّالَ، فَقَالَ ‏ "‏ إِنِّي لأُنْذِرُكُمُوهُ، وَمَا مِنْ نَبِيٍّ إِلاَّ أَنْذَرَهُ قَوْمَهُ، لَقَدْ أَنْذَرَ نُوحٌ قَوْمَهُ، وَلَكِنِّي أَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ، تَعْلَمُونَ أَنَّهُ أَعْوَرُ، وَأَنَّ اللَّهَ لَيْسَ بِأَعْوَرَ ‏"‏‏.‏\hadithno{3337}\hadithtrans{Narrated Ibn `Umar:Once Allah's Messenger (ﷺ) stood amongst the people, glorified and praised Allah as He deserved and then mentioned the Dajjal saying, "I warn you against him (i.e. the Dajjal) and there was no prophet but warned his nation against him. No doubt, Noah warned his nation against him but I tell you about him something of which no prophet told his nation before me. You should know that he is one-eyed, and Allah is not one-eyed}}
\hadithdefcmd{bukhari}{3338}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أُحَدِّثُكُمْ حَدِيثًا عَنِ الدَّجَّالِ مَا حَدَّثَ بِهِ نَبِيٌّ قَوْمَهُ، إِنَّهُ أَعْوَرُ، وَإِنَّهُ يَجِيءُ مَعَهُ بِمِثَالِ الْجَنَّةِ وَالنَّارِ، فَالَّتِي يَقُولُ إِنَّهَا الْجَنَّةُ‏.‏ هِيَ النَّارُ، وَإِنِّي أُنْذِرُكُمْ كَمَا أَنْذَرَ بِهِ نُوحٌ قَوْمَهُ ‏"‏‏.‏\hadithno{3338}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Shall I not tell you about the Dajjal a story of which no prophet told his nation? The Dajjall is one-eyed and will bring with him what will resemble Hell and Paradise, and what he will call Paradise will be actually Hell; so I warn you (against him) as Noah warned his nation against him}}
\hadithdefcmd{bukhari}{3339}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَجِيءُ نُوحٌ وَأُمَّتُهُ فَيَقُولُ اللَّهُ تَعَالَى هَلْ بَلَّغْتَ فَيَقُولُ نَعَمْ، أَىْ رَبِّ‏.‏ فَيَقُولُ لأُمَّتِهِ هَلْ بَلَّغَكُمْ فَيَقُولُونَ لاَ، مَا جَاءَنَا مِنْ نَبِيٍّ‏.‏ فَيَقُولُ لِنُوحٍ مَنْ يَشْهَدُ لَكَ فَيَقُولُ مُحَمَّدٌ صلى الله عليه وسلم وَأُمَّتُهُ، فَنَشْهَدُ أَنَّهُ قَدْ بَلَّغَ، وَهْوَ قَوْلُهُ جَلَّ ذِكْرُهُ ‏\{‏وَكَذَلِكَ جَعَلْنَاكُمْ أُمَّةً وَسَطًا لِتَكُونُوا شُهَدَاءَ عَلَى النَّاسِ‏\}‏ وَالْوَسَطُ الْعَدْلُ ‏"‏‏.‏\hadithno{3339}\hadithtrans{Narrated Abu Sa`id:Allah's Messenger (ﷺ) said, "Noah and his nation will come (on the Day of Resurrection and Allah will ask (Noah), "Did you convey (the Message)?' He will reply, 'Yes, O my Lord!' Then Allah will ask Noah's nation, 'Did Noah convey My Message to you?' They will reply, 'No, no prophet came to us.' Then Allah will ask Noah, 'Who will stand a witness for you?' He will reply, 'Muhammad and his followers (will stand witness for me).' So, I and my followers will stand as witnesses for him (that he conveyed Allah's Message)." That is, (the interpretation) of the Statement of Allah: "Thus we have made you a just and the best nation that you might be witnesses Over mankind}}
\hadithdefcmd{bukhari}{3340}{حَدَّثَنِي إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا أَبُو حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي دَعْوَةٍ، فَرُفِعَ إِلَيْهِ الذِّرَاعُ، وَكَانَتْ تُعْجِبُهُ، فَنَهَسَ مِنْهَا نَهْسَةً وَقَالَ ‏ "‏ أَنَا سَيِّدُ الْقَوْمِ يَوْمَ الْقِيَامَةِ، هَلْ تَدْرُونَ بِمَنْ يَجْمَعُ اللَّهُ الأَوَّلِينَ وَالآخِرِينَ فِي صَعِيدٍ وَاحِدٍ فَيُبْصِرُهُمُ النَّاظِرُ وَيُسْمِعُهُمُ الدَّاعِي، وَتَدْنُو مِنْهُمُ الشَّمْسُ، فَيَقُولُ بَعْضُ النَّاسِ أَلاَ تَرَوْنَ إِلَى مَا أَنْتُمْ فِيهِ، إِلَى مَا بَلَغَكُمْ، أَلاَ تَنْظُرُونَ إِلَى مَنْ يَشْفَعُ لَكُمْ إِلَى رَبِّكُمْ فَيَقُولُ بَعْضُ النَّاسِ أَبُوكُمْ آدَمُ، فَيَأْتُونَهُ فَيَقُولُونَ يَا آدَمُ أَنْتَ أَبُو الْبَشَرِ، خَلَقَكَ اللَّهُ بِيَدِهِ وَنَفَخَ فِيكَ مِنْ رُوحِهِ، وَأَمَرَ الْمَلاَئِكَةَ فَسَجَدُوا لَكَ، وَأَسْكَنَكَ الْجَنَّةَ، أَلاَ تَشْفَعُ لَنَا إِلَى رَبِّكَ أَلاَ تَرَى مَا نَحْنُ فِيهِ وَمَا بَلَغَنَا فَيَقُولُ رَبِّي غَضِبَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ، وَلاَ يَغْضَبُ بَعْدَهُ مِثْلَهُ، وَنَهَانِي عَنِ الشَّجَرَةِ فَعَصَيْتُهُ، نَفْسِي نَفْسِي، اذْهَبُوا إِلَى غَيْرِي، اذْهَبُوا إِلَى نُوحٍ‏.‏ فَيَأْتُونَ نُوحًا فَيَقُولُونَ يَا نُوحُ أَنْتَ أَوَّلُ الرُّسُلِ إِلَى أَهْلِ الأَرْضِ، وَسَمَّاكَ اللَّهُ عَبْدًا شَكُورًا، أَمَا تَرَى إِلَى مَا نَحْنُ فِيهِ أَلاَ تَرَى إِلَى مَا بَلَغَنَا أَلاَ تَشْفَعُ لَنَا إِلَى رَبِّكَ فَيَقُولُ رَبِّي غَضِبَ الْيَوْمَ غَضَبًا لَمْ يَغْضَبْ قَبْلَهُ مِثْلَهُ، وَلاَ يَغْضَبُ بَعْدَهُ مِثْلَهُ، نَفْسِي نَفْسِي، ائْتُوا النَّبِيَّ صلى الله عليه وسلم، فَيَأْتُونِي، فَأَسْجُدُ تَحْتَ الْعَرْشِ فَيُقَالُ يَا مُحَمَّدُ ارْفَعْ رَأْسَكَ وَاشْفَعْ تُشَفَّعْ، وَسَلْ تُعْطَهُ ‏"‏‏.‏ قَالَ مُحَمَّدُ بْنُ عُبَيْدٍ لاَ أَحْفَظُ سَائِرَهُ‏.‏\hadithno{3340}\hadithtrans{Narrated Abu Huraira:We were in the company of the Prophet (ﷺ) at a banquet and a cooked (mutton) forearm was set before him, and he used to like it. He ate a morsel of it and said, "I will be the chief of all the people on the Day of Resurrection. Do you know how Allah will gather all the first and the last (people) in one level place where an observer will be able to see (all) of them and they will be able to hear the announcer, and the sun will come near to them. Some People will say: Don't you see, in what condition you are and the state to which you have reached? Why don't you look for a person who can intercede for you with your Lord? Some people will say: Appeal to your father, Adam.' They will go to him and say: 'O Adam! You are the father of all mankind, and Allah created you with His Own Hands, and ordered the angels to prostrate for you, and made you live in Paradise. Will you not intercede for us with your Lord? Don't you see in what (miserable) state we are, and to what condition we have reached?' On that Adam will reply, 'My Lord is so angry as He has never been before and will never be in the future; (besides), He forbade me (to eat from) the tree, but I disobeyed (Him), (I am worried about) myself! Myself! Go to somebody else; go to Noah.' They will go to Noah and say; 'O Noah! You are the first amongst the messengers of Allah to the people of the earth, and Allah named you a thankful slave. Don't you see in what a (miserable) state we are and to what condition we have reached? Will you not intercede for us with your Lord? Noah will reply: 'Today my Lord has become so angry as He had never been before and will never be in the future. Myself! Myself! Go to the Prophet (Muhammad). The people will come to me, and I will prostrate myself underneath Allah's Throne. Then I will be addressed: 'O Muhammad! Raise your head; intercede, for your intercession will be accepted, and ask (for anything) for you will be given}}
\hadithdefcmd{bukhari}{3341}{حَدَّثَنَا نَصْرُ بْنُ عَلِيِّ بْنِ نَصْرٍ، أَخْبَرَنَا أَبُو أَحْمَدَ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ‏\}‏ مِثْلَ قِرَاءَةِ الْعَامَّةِ‏.‏\hadithno{3341}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) recited the following Verse) in the usual tone: 'Fahal-Min-Muddalkir}}
\hadithdefcmd{bukhari}{3342}{قَالَ عَبْدَانُ أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، ح حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ أَنَسٌ كَانَ أَبُو ذَرٍّ ـ رضى الله عنه ـ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ فُرِجَ سَقْفُ بَيْتِي وَأَنَا بِمَكَّةَ، فَنَزَلَ جِبْرِيلُ، فَفَرَجَ صَدْرِي، ثُمَّ غَسَلَهُ بِمَاءِ زَمْزَمَ، ثُمَّ جَاءَ بِطَسْتٍ مِنْ ذَهَبٍ مُمْتَلِئٍ حِكْمَةً وَإِيمَانًا فَأَفْرَغَهَا فِي صَدْرِي، ثُمَّ أَطْبَقَهُ ثُمَّ أَخَذَ بِيَدِي، فَعَرَجَ بِي إِلَى السَّمَاءِ، فَلَمَّا جَاءَ إِلَى السَّمَاءِ الدُّنْيَا، قَالَ جِبْرِيلُ لِخَازِنِ السَّمَاءِ افْتَحْ‏.‏ قَالَ مَنْ هَذَا قَالَ هَذَا جِبْرِيلُ‏.‏ قَالَ مَعَكَ أَحَدٌ قَالَ مَعِيَ مُحَمَّدٌ‏.‏ قَالَ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ، فَافْتَحْ‏.‏ فَلَمَّا عَلَوْنَا السَّمَاءَ إِذَا رَجُلٌ عَنْ يَمِينِهِ أَسْوِدَةٌ، وَعَنْ يَسَارِهِ أَسْوِدَةٌ، فَإِذَا نَظَرَ قِبَلَ يَمِينِهِ ضَحِكَ، وَإِذَا نَظَرَ قِبَلَ شِمَالِهِ بَكَى فَقَالَ مَرْحَبًا بِالنَّبِيِّ الصَّالِحِ وَالاِبْنِ الصَّالِحِ‏.‏ قُلْتُ مَنْ هَذَا يَا جِبْرِيلُ قَالَ هَذَا آدَمُ، وَهَذِهِ الأَسْوِدَةُ عَنْ يَمِينِهِ، وَعَنْ شِمَالِهِ نَسَمُ بَنِيهِ، فَأَهْلُ الْيَمِينِ مِنْهُمْ أَهْلُ الْجَنَّةِ، وَالأَسْوِدَةُ الَّتِي عَنْ شِمَالِهِ أَهْلُ النَّارِ، فَإِذَا نَظَرَ قِبَلَ يَمِينِهِ ضَحِكَ، وَإِذَا نَظَرَ قِبَلَ شِمَالِهِ بَكَى، ثُمَّ عَرَجَ بِي جِبْرِيلُ، حَتَّى أَتَى السَّمَاءَ الثَّانِيَةَ، فَقَالَ لِخَازِنِهَا افْتَحْ‏.‏ فَقَالَ لَهُ خَازِنُهَا مِثْلَ مَا قَالَ الأَوَّلُ، فَفَتَحَ ‏"‏‏.‏ قَالَ أَنَسٌ فَذَكَرَ أَنَّهُ وَجَدَ فِي السَّمَوَاتِ إِدْرِيسَ وَمُوسَى وَعِيسَى وَإِبْرَاهِيمَ، وَلَمْ يُثْبِتْ لِي كَيْفَ مَنَازِلُهُمْ، غَيْرَ أَنَّهُ قَدْ ذَكَرَ أَنَّهُ وَجَدَ آدَمَ فِي السَّمَاءِ الدُّنْيَا، وَإِبْرَاهِيمَ فِي السَّادِسَةِ‏.‏ وَقَالَ أَنَسٌ فَلَمَّا مَرَّ جِبْرِيلُ بِإِدْرِيسَ‏.‏ قَالَ مَرْحَبًا بِالنَّبِيِّ الصَّالِحِ وَالأَخِ الصَّالِحِ‏.‏ فَقُلْتُ مَنْ هَذَا قَالَ هَذَا إِدْرِيسُ، ثُمَّ مَرَرْتُ بِمُوسَى فَقَالَ مَرْحَبًا بِالنَّبِيِّ الصَّالِحِ وَالأَخِ الصَّالِحِ‏.‏ قُلْتُ مَنْ هَذَا قَالَ هَذَا مُوسَى‏.‏ ثُمَّ مَرَرْتُ بِعِيسَى، فَقَالَ مَرْحَبًا بِالنَّبِيِّ الصَّالِحِ وَالأَخِ الصَّالِحِ‏.‏ قُلْتُ مَنْ هَذَا قَالَ عِيسَى‏.‏ ثُمَّ مَرَرْتُ بِإِبْرَاهِيمَ، فَقَالَ مَرْحَبًا بِالنَّبِيِّ الصَّالِحِ وَالاِبْنِ الصَّالِحِ‏.‏ قُلْتُ مَنْ هَذَا قَالَ هَذَا إِبْرَاهِيمُ‏.‏ قَالَ وَأَخْبَرَنِي ابْنُ حَزْمٍ أَنَّ ابْنَ عَبَّاسٍ وَأَبَا حَبَّةَ الأَنْصَارِيَّ كَانَا يَقُولاَنِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ثُمَّ عُرِجَ بِي حَتَّى ظَهَرْتُ لِمُسْتَوًى أَسْمَعُ صَرِيفَ الأَقْلاَمِ ‏"‏‏.‏ قَالَ ابْنُ حَزْمٍ وَأَنَسُ بْنُ مَالِكٍ ـ رضى الله عنهما ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَفَرَضَ اللَّهُ عَلَىَّ خَمْسِينَ صَلاَةً، فَرَجَعْتُ بِذَلِكَ حَتَّى أَمُرَّ بِمُوسَى، فَقَالَ مُوسَى مَا الَّذِي فُرِضَ عَلَى أُمَّتِكَ قُلْتُ فَرَضَ عَلَيْهِمْ خَمْسِينَ صَلاَةً‏.‏ قَالَ فَرَاجِعْ رَبَّكَ، فَإِنَّ أُمَّتَكَ لاَ تُطِيقُ ذَلِكَ‏.‏ فَرَجَعْتُ فَرَاجَعْتُ رَبِّي فَوَضَعَ شَطْرَهَا، فَرَجَعْتُ إِلَى مُوسَى، فَقَالَ رَاجِعْ رَبَّكَ، فَذَكَرَ مِثْلَهُ، فَوَضَعَ شَطْرَهَا، فَرَجَعْتُ إِلَى مُوسَى، فَأَخْبَرْتُهُ فَقَالَ رَاجِعْ رَبَّكَ، فَإِنَّ أُمَّتَكَ لاَ تُطِيقُ ذَلِكَ، فَرَجَعْتُ فَرَاجَعْتُ رَبِّي فَقَالَ هِيَ خَمْسٌ، وَهْىَ خَمْسُونَ، لاَ يُبَدَّلُ الْقَوْلُ لَدَىَّ‏.‏ فَرَجَعْتُ إِلَى مُوسَى، فَقَالَ رَاجِعْ رَبَّكَ‏.‏ فَقُلْتُ قَدِ اسْتَحْيَيْتُ مِنْ رَبِّي، ثُمَّ انْطَلَقَ، حَتَّى أَتَى السِّدْرَةَ الْمُنْتَهَى، فَغَشِيَهَا أَلْوَانٌ لاَ أَدْرِي مَا هِيَ، ثُمَّ أُدْخِلْتُ ‏\{‏الْجَنَّةَ‏\}‏ فَإِذَا فِيهَا جَنَابِذُ اللُّؤْلُؤِ وَإِذَا تُرَابُهَا الْمِسْكُ ‏"‏‏.‏\hadithno{3342}\hadithtrans{Narrated Anas (ra):Abu Dhar (ra) used to say that Allah's Messenger (ﷺ) said, "While I was at Makkah, the roof of my house was opened and Jibril descended, opened my chest, and washed it with Zamzam water. Then he brought a golden tray full of wisdom and faith, and having poured its contents into my chest, he closed it. Then he took my hand and ascended with me to the heaven. When Jibril reached the nearest heaven, he said to the gatekeeper of the heaven, 'Open (the gate).' The gatekeeper asked, 'who is it?' Jibril answered, 'Jibril'. He asked, 'Is there anyone with you?' Jibril replied, 'Muhammad (ﷺ) is with me.' He asked, 'Has he been called?', Jibril said, 'Yes'. So, the gate was opened and we went over the nearest heaven, and there we saw a man sitting with Aswida (a large number of people) on his right and Aswida on his left. When he looked towards his right, he laughed and when he looked towards his left he wept. He said (to me), 'Welcome, O pious Prophet and pious son'. I said, 'Who is this man O Jibril?' Jibril replied, 'He is Adam, and the people on his right and left are the souls of his offspring. Those on the right are the people of Paradise, and those on the left are the people of the (Hell) Fire. So, when he looks to the right, he laughs, and when he looks to the left he weeps.' Then Jibril ascended with me till he reached the second heaven and said to the gatekeeper, 'Open (the gate).' The gatekeeper said to him the same as the gatekeeper of the first heaven had said, and he opened the gate." Anas added: Abu Dhar mentioned that the Prophet (ﷺ) met Idris, Musa (Moses), 'Isa (Jesus) and Ibrahim (Abraham) over the heavens, but he did not specify their places (i.e., on which heavens each of them was), but he mentioned that he (the Prophet (ﷺ)) had met Adam on the nearest heaven, and Ibrahim on the sixth. Anas said, "When Jibril and the Prophet (ﷺ) passed by Idris, the latter said, 'Welcome, O pious Prophet and pious brother!' the Prophet (ﷺ) asked, 'Who is he?' Jibril said, 'He is Idris.' " The Prophet (ﷺ) added, "Then I passed by Musa who said, 'Welcome, O pious Prophet and pious brother!' I said, 'Who is he?' Jibril said, 'He is Musa.' Then I passed by 'Isa who said, 'Welcome, O pious Prophet and pious brother!' I said, 'Who is he?' He replied, 'He is 'Isa.' Then I passed by the Prophet (ﷺ) Ibrahim who said, 'Welcome, O pious Prophet and pious son!' I said, 'Who is he?' Jibril replied, 'He is Ibrahim'." Narrated Ibn 'Abbas and Abu Haiyya Al-Ansari: The Prophet (ﷺ) said, "Then Jibril ascended with me to a place where I heard the creaking of pens." Ibn Hazm and Anas bin Malik state that the Prophet (ﷺ) said, "Allah enjoined fifty Salat (prayers) on me. When I returned with this order of Allah, I passed by Musa who asked me, 'What has Allah enjoined on your followers?' I replied, 'He has enjoined fifty Salat (prayers) on them.' On that Musa said to me, 'Go back to your Lord (and appeal for reduction), for your followers will not be able to bear it.' So, I returned to my Lord and asked for some reduction, and He reduced it to half. When I passed by Musa again and informed him about it, he once more said to me, 'Go back to your Lord, for your followers will not be able to bear it.' So, I returned to my Lord similarly as before, and half of it was reduced. I again passed by Musa and he said to me, 'Go back to your Lord, for your followers will not be able to bear it.' I again returned to my Lord and He said, 'These are five (Salat-prayers) and they are all (equal to) fifty (in reward), for My Word does not change.' I returned to Musa, he again told me to return to my Lord (for further reduction) but I said to him 'I feel shy of asking my Lord now.' Then Jibril took me till we reached Sidrat-ul-Muntaha (i.e., lote tree of utmost boundary) which was shrouded in colors indescribable. Then I was admitted into Paradise where I found small tents (made) of pearls and its earth was musk (a kind of perfume)}}
\hadithdefcmd{bukhari}{3343}{حَدَّثَنِي مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نُصِرْتُ بِالصَّبَا، وَأُهْلِكَتْ عَادٌ بِالدَّبُورِ ‏"‏‏.‏\hadithno{3343}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "I have been made victorious with As-Saba (i.e. an easterly wind) and the people of 'Ad were destroyed by Ad-Dabur (i.e. a westerly wind)}}
\hadithdefcmd{bukhari}{3344}{قَالَ وَقَالَ ابْنُ كَثِيرٍ عَنْ سُفْيَانَ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ بَعَثَ عَلِيٌّ ـ رضى الله عنه ـ إِلَى النَّبِيِّ صلى الله عليه وسلم بِذُهَيْبَةٍ فَقَسَمَهَا بَيْنَ الأَرْبَعَةِ الأَقْرَعِ بْنِ حَابِسٍ الْحَنْظَلِيِّ ثُمَّ الْمُجَاشِعِيِّ، وَعُيَيْنَةَ بْنِ بَدْرٍ الْفَزَارِيِّ، وَزَيْدٍ الطَّائِيِّ ثُمَّ أَحَدِ بَنِي نَبْهَانَ، وَعَلْقَمَةَ بْنِ عُلاَثَةَ الْعَامِرِيِّ ثُمَّ أَحَدِ بَنِي كِلاَبٍ، فَغَضِبَتْ قُرَيْشٌ وَالأَنْصَارُ، قَالُوا يُعْطِي صَنَادِيدَ أَهْلِ نَجْدٍ وَيَدَعُنَا‏.‏ قَالَ ‏"‏ إِنَّمَا أَتَأَلَّفُهُمْ ‏"‏‏.‏ فَأَقْبَلَ رَجُلٌ غَائِرُ الْعَيْنَيْنِ مُشْرِفُ الْوَجْنَتَيْنِ، نَاتِئُ الْجَبِينِ، كَثُّ اللِّحْيَةِ، مَحْلُوقٌ فَقَالَ اتَّقِ اللَّهَ يَا مُحَمَّدُ‏.‏ فَقَالَ ‏"‏ مَنْ يُطِعِ اللَّهَ إِذَا عَصَيْتُ، أَيَأْمَنُنِي اللَّهُ عَلَى أَهْلِ الأَرْضِ فَلاَ تَأْمَنُونِي ‏"‏‏.‏ فَسَأَلَهُ رَجُلٌ قَتْلَهُ ـ أَحْسِبُهُ خَالِدَ بْنَ الْوَلِيدِ ـ فَمَنَعَهُ، فَلَمَّا وَلَّى قَالَ ‏"‏ إِنَّ مِنْ ضِئْضِئِ هَذَا ـ أَوْ فِي عَقِبِ هَذَا ـ قَوْمٌ يَقْرَءُونَ الْقُرْآنَ، لاَ يُجَاوِزُ حَنَاجِرَهُمْ، يَمْرُقُونَ مِنَ الدِّينِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ، يَقْتُلُونَ أَهْلَ الإِسْلاَمِ، وَيَدَعُونَ أَهْلَ الأَوْثَانِ، لَئِنْ أَنَا أَدْرَكْتُهُمْ لأَقْتُلَنَّهُمْ قَتْلَ عَادٍ ‏"‏‏.‏\hadithno{3344}\hadithtrans{Narrated Abu Sa`id:`Ali sent a piece of gold to the Prophet (ﷺ) who distributed it among four persons: Al-Aqra' bin H`Abis Al-Hanzali from the tribe of Mujashi, 'Uyaina bin Badr Al-Fazari, Zaid at-Ta'i who belonged to (the tribe of) Bani Nabhan, and 'Alqama bin Ulatha Al-`Amiri who belonged to (the tribe of) Bani Kilab. So the Quraish and the Ansar became angry and said, "He (i.e. the Prophet, ) gives the chief of Najd and does not give us." The Prophet (ﷺ) said, "I give them) so as to attract their hearts (to Islam)." Then a man with sunken eyes, prominent cheeks, a raised forehead, a thick beard and a shaven head, came (in front of the Prophet (ﷺ) ) and said, "Be afraid of Allah, O Muhammad!" The Prophet (ﷺ) ' said "Who would obey Allah if I disobeyed Him? (Is it fair that) Allah has trusted all the people of the earth to me while, you do not trust me?" Somebody who, I think was Khalid bin Al-Walid, requested the Prophet (ﷺ) to let him chop that man's head off, but he prevented him. When the man left, the Prophet (ﷺ) said, "Among the off-spring of this man will be some who will recite the Qur'an but the Qur'an will not reach beyond their throats (i.e. they will recite like parrots and will not understand it nor act on it), and they will renegade from the religion as an arrow goes through the game's body. They will kill the Muslims but will not disturb the idolaters. If I should live up to their time' I will kill them as the people of 'Ad were killed (i.e. I will kill all of them)}}
\hadithdefcmd{bukhari}{3345}{حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ ‏\{‏فَهَلْ مِنْ مُدَّكِرٍ ‏\}‏‏.‏\hadithno{3345}\hadithtrans{Narrated `Abdullah:I heard the Prophet (ﷺ) reciting: "Fahal Min Muddakir." (See Hadith No)}}
\hadithdefcmd{bukhari}{3346}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ، حَدَّثَتْهُ عَنْ أُمِّ حَبِيبَةَ بِنْتِ أَبِي سُفْيَانَ، عَنْ زَيْنَبَ ابْنَةِ جَحْشٍ ـ رضى الله عنهن أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا فَزِعًا يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلُ هَذِهِ ‏"‏‏.‏ وَحَلَّقَ بِإِصْبَعِهِ الإِبْهَامِ وَالَّتِي تَلِيهَا‏.‏ قَالَتْ زَيْنَبُ ابْنَةُ جَحْشٍ فَقُلْتُ يَا رَسُولَ اللَّهِ أَنَهْلِكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ نَعَمْ، إِذَا كَثُرَ الْخُبْثُ ‏"‏‏.‏\hadithno{3346}\hadithtrans{Narrated Zainab bint Jahsh:That the Prophet (ﷺ) once came to her in a state of fear and said, "None has the right to be worshipped but Allah. Woe unto the Arabs from a danger that has come near. An opening has been made in the wall of Gog and Magog like this," making a circle with his thumb and index finger. Zainab bint Jahsh said, "O Allah's Messenger (ﷺ)! Shall we be destroyed even though there are pious persons among us?" He said, "Yes, when the evil persons will increase}}
\hadithdefcmd{bukhari}{3347}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فَتَحَ اللَّهُ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلَ هَذَا ‏"‏‏.‏ وَعَقَدَ بِيَدِهِ تِسْعِينَ‏.‏\hadithno{3347}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah has made an opening in the wall of the Gog and Magog (people) like this, and he made with his hand (with the help of his fingers)}}
\hadithdefcmd{bukhari}{3348}{حَدَّثَنِي إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الأَعْمَشِ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يَقُولُ اللَّهُ تَعَالَى يَا آدَمُ‏.‏ فَيَقُولُ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ فِي يَدَيْكَ‏.‏ فَيَقُولُ أَخْرِجْ بَعْثَ النَّارِ‏.‏ قَالَ وَمَا بَعْثُ النَّارِ قَالَ مِنْ كُلِّ أَلْفٍ تِسْعَمِائَةٍ وَتِسْعَةً وَتِسْعِينَ، فَعِنْدَهُ يَشِيبُ الصَّغِيرُ، وَتَضَعُ كُلُّ ذَاتِ حَمْلٍ حَمْلَهَا، وَتَرَى النَّاسَ سُكَارَى، وَمَا هُمْ بِسُكَارَى، وَلَكِنَّ عَذَابَ اللَّهِ شَدِيدٌ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَأَيُّنَا ذَلِكَ الْوَاحِدُ قَالَ ‏"‏ أَبْشِرُوا فَإِنَّ مِنْكُمْ رَجُلٌ، وَمِنْ يَأْجُوجَ وَمَأْجُوجَ أَلْفٌ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ، إِنِّي أَرْجُو أَنْ تَكُونُوا رُبُعَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ فَكَبَّرْنَا‏.‏ فَقَالَ ‏"‏ أَرْجُو أَنْ تَكُونُوا ثُلُثَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ فَكَبَّرْنَا‏.‏ فَقَالَ ‏"‏ أَرْجُو أَنْ تَكُونُوا نِصْفَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ فَكَبَّرْنَا‏.‏ فَقَالَ ‏"‏ مَا أَنْتُمْ فِي النَّاسِ إِلاَّ كَالشَّعَرَةِ السَّوْدَاءِ فِي جِلْدِ ثَوْرٍ أَبْيَضَ، أَوْ كَشَعَرَةٍ بَيْضَاءَ فِي جِلْدِ ثَوْرٍ أَسْوَدَ ‏"‏‏.‏\hadithno{3348}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Allah will say (on the Day of Resurrection), 'O Adam.' Adam will reply, 'Labbaik wa Sa`daik', and all the good is in Your Hand.' Allah will say: 'Bring out the people of the fire.' Adam will say: 'O Allah! How many are the people of the Fire?' Allah will reply: 'From every one thousand, take out nine-hundred-and ninety-nine.' At that time children will become hoary headed, every pregnant female will have a miscarriage, and one will see mankind as drunken, yet they will not be drunken, but dreadful will be the Wrath of Allah." The companions of the Prophet (ﷺ) asked, "O Allah's Apostle! Who is that (excepted) one?" He said, "Rejoice with glad tidings; one person will be from you and one-thousand will be from Gog and Magog." The Prophet (ﷺ) further said, "By Him in Whose Hands my life is, I hope that you will be one-fourth of the people of Paradise." We shouted, "Allahu Akbar!" He added, "I hope that you will be one-third of the people of Paradise." We shouted, "Allahu Akbar!" He said, "I hope that you will be half of the people of Paradise." We shouted, "Allahu Akbar!" He further said, "You (Muslims) (compared with non Muslims) are like a black hair in the skin of a white ox or like a white hair in the skin of a black ox (i.e. your number is very small as compared with theirs)}}
\hadithdefcmd{bukhari}{3349}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا الْمُغِيرَةُ بْنُ النُّعْمَانِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّكُمْ مَحْشُورُونَ حُفَاةً عُرَاةً غُرْلاً ـ ثُمَّ قَرَأَ – ‏\{‏كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ وَعْدًا عَلَيْنَا إِنَّا كُنَّا فَاعِلِينَ‏\}‏ وَأَوَّلُ مَنْ يُكْسَى يَوْمَ الْقِيَامَةِ إِبْرَاهِيمُ، وَإِنَّ أُنَاسًا مِنْ أَصْحَابِي يُؤْخَذُ بِهِمْ ذَاتَ الشِّمَالِ فَأَقُولُ أَصْحَابِي أَصْحَابِي‏.‏ فَيَقُولُ، إِنَّهُمْ لَمْ يَزَالُوا مُرْتَدِّينَ عَلَى أَعْقَابِهِمْ مُنْذُ فَارَقْتَهُمْ‏.‏ فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُ ‏\{‏وَكُنْتُ عَلَيْهِمْ شَهِيدًا مَا دُمْتُ فِيهِمْ‏\}‏ إِلَى قَوْلِهِ ‏\{‏الْحَكِيمُ ‏\}‏‏"‏\hadithno{3349}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "You will be gathered (on the Day of Judgment), bare-footed, naked and not circumcised." He then recited:--'As We began the first creation, We, shall repeat it: A Promise We have undertaken: Truly We shall do it.' (21.104) He added, "The first to be dressed on the Day of Resurrection, will be Abraham, and some of my companions will be taken towards the left side (i.e. to the (Hell) Fire), and I will say: 'My companions! My companions!' It will be said: 'They renegade from Islam after you left them.' Then I will say as the Pious slave of Allah (i.e. Jesus) said. 'And I was a witness Over them while I dwelt amongst them. When You took me up You were the Watcher over them, And You are a witness to all things. If You punish them. They are Your slaves And if You forgive them, Verily you, only You are the All-Mighty, the All-Wise}}
\hadithdefcmd{bukhari}{3350}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ أَخْبَرَنِي أَخِي عَبْدُ الْحَمِيدِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَلْقَى إِبْرَاهِيمُ أَبَاهُ آزَرَ يَوْمَ الْقِيَامَةِ، وَعَلَى وَجْهِ آزَرَ قَتَرَةٌ وَغَبَرَةٌ، فَيَقُولُ لَهُ إِبْرَاهِيمُ أَلَمْ أَقُلْ لَكَ لاَ تَعْصِنِي فَيَقُولُ أَبُوهُ فَالْيَوْمَ لاَ أَعْصِيكَ‏.‏ فَيَقُولُ إِبْرَاهِيمُ يَا رَبِّ، إِنَّكَ وَعَدْتَنِي أَنْ لاَ تُخْزِيَنِي يَوْمَ يُبْعَثُونَ، فَأَىُّ خِزْىٍ أَخْزَى مِنْ أَبِي الأَبْعَدِ فَيَقُولُ اللَّهُ تَعَالَى إِنِّي حَرَّمْتُ الْجَنَّةَ عَلَى الْكَافِرِينَ، ثُمَّ يُقَالُ يَا إِبْرَاهِيمُ مَا تَحْتَ رِجْلَيْكَ فَيَنْظُرُ فَإِذَا هُوَ بِذِيخٍ مُلْتَطِخٍ، فَيُؤْخَذُ بِقَوَائِمِهِ فَيُلْقَى فِي النَّارِ ‏"‏‏.‏\hadithno{3350}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "On the Day of Resurrection Abraham will meet his father Azar whose face will be dark and covered with dust.(The Prophet Abraham (ﷺ) will say to him): 'Didn't I tell you not to disobey me?' His father will reply: 'Today I will not disobey you.' 'Abraham will say: 'O Lord! You promised me not to disgrace me on the Day of Resurrection; and what will be more disgraceful to me than cursing and dishonoring my father?' Then Allah will say (to him):' 'I have forbidden Paradise for the disbelievers." Then he will be addressed, 'O Abraham! Look! What is underneath your feet?' He will look and there he will see a Dhabh (an animal,) blood-stained, which will be caught by the legs and thrown in the (Hell) Fire}}
\hadithdefcmd{bukhari}{3351}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ بُكَيْرًا، حَدَّثَهُ عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم الْبَيْتَ فَوَجَدَ فِيهِ صُورَةَ إِبْرَاهِيمَ وَصُورَةَ مَرْيَمَ فَقَالَ ‏ "‏ أَمَا لَهُمْ، فَقَدْ سَمِعُوا أَنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ صُورَةٌ، هَذَا إِبْرَاهِيمُ مُصَوَّرٌ فَمَا لَهُ يَسْتَقْسِمُ ‏"‏‏.‏\hadithno{3351}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) entered the Ka`ba and found in it the pictures of (Prophet) Abraham and Mary. On that he said' "What is the matter with them ( i.e. Quraish)? They have already heard that angels do not enter a house in which there are pictures; yet this is the picture of Abraham. And why is he depicted as practicing divination by arrows?}}
\hadithdefcmd{bukhari}{3352}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا رَأَى الصُّوَرَ فِي الْبَيْتِ لَمْ يَدْخُلْ، حَتَّى أَمَرَ بِهَا فَمُحِيَتْ، وَرَأَى إِبْرَاهِيمَ وَإِسْمَاعِيلَ ـ عَلَيْهِمَا السَّلاَمُ ـ بِأَيْدِيهِمَا الأَزْلاَمُ فَقَالَ ‏ "‏ قَاتَلَهُمُ اللَّهُ، وَاللَّهِ إِنِ اسْتَقْسَمَا بِالأَزْلاَمِ قَطُّ ‏"‏‏.‏\hadithno{3352}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) saw pictures in the Ka`ba, he did not enter it till he ordered them to be erased. When he saw (the pictures of Abraham and Ishmael carrying the arrows of divination, he said, "May Allah curse them (i.e. the Quraish)! By Allah, neither Abraham nor Ishmael practiced divination by arrows}}
\hadithdefcmd{bukhari}{3353}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه قِيلَ يَا رَسُولَ اللَّهِ، مَنْ أَكْرَمُ النَّاسِ قَالَ ‏"‏ أَتْقَاهُمْ ‏"‏‏.‏ فَقَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَيُوسُفُ نَبِيُّ اللَّهِ ابْنُ نَبِيِّ اللَّهِ ابْنِ نَبِيِّ اللَّهِ ابْنِ خَلِيلِ اللَّهِ ‏"‏‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَعَنْ مَعَادِنِ الْعَرَبِ تَسْأَلُونَ خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقُهُوا ‏"‏‏.‏ قَالَ أَبُو أُسَامَةَ وَمُعْتَمِرٌ عَنْ عُبَيْدِ اللَّهِ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3353}\hadithtrans{Narrated Abu Huraira:The people said, "O Allah's Messenger (ﷺ)! Who is the most honorable amongst the people (in Allah's Sight)?" He said, "The most righteous amongst them." They said, "We do not ask you, about this. " He said, "Then Joseph, Allah's Prophet, the son of Allah's Prophet, The son of Allah's Prophet the son of Allah's Khalil (i.e. Abraham)." They said, "We do not want to ask about this," He said' "Then you want to ask about the descent of the Arabs. Those who were the best in the pre-Islamic period of ignorance will be the best in Islam provided they comprehend the religious knowledge}}
\hadithdefcmd{bukhari}{3354}{حَدَّثَنَا مُؤَمَّلٌ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا عَوْفٌ، حَدَّثَنَا أَبُو رَجَاءٍ، حَدَّثَنَا سَمُرَةُ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتَانِي اللَّيْلَةَ آتِيَانِ، فَأَتَيْنَا عَلَى رَجُلٍ طَوِيلٍ، لاَ أَكَادُ أَرَى رَأْسَهُ طُولاً، وَإِنَّهُ إِبْرَاهِيمُ صلى الله عليه وسلم ‏"‏‏.‏\hadithno{3354}\hadithtrans{Narrated Samura:Allah's Messenger (ﷺ) said, "Two persons came to me at night (in dream) (and took me along with them). We passed by a tall man who was so tall that I was not able to see his head and that person was Abraham}}
\hadithdefcmd{bukhari}{3355}{حَدَّثَنِي بَيَانُ بْنُ عَمْرٍو، حَدَّثَنَا النَّضْرُ، أَخْبَرَنَا ابْنُ عَوْنٍ، عَنْ مُجَاهِدٍ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ وَذَكَرُوا لَهُ الدَّجَّالَ بَيْنَ عَيْنَيْهِ مَكْتُوبٌ كَافِرٌ أَوْ ك ف ر‏.‏ قَالَ لَمْ أَسْمَعْهُ وَلَكِنَّهُ قَالَ ‏ "‏ أَمَّا إِبْرَاهِيمُ فَانْظُرُوا إِلَى صَاحِبِكُمْ، وَأَمَّا مُوسَى فَجَعْدٌ آدَمُ عَلَى جَمَلٍ أَحْمَرَ مَخْطُومٍ بِخُلْبَةٍ، كَأَنِّي أَنْظُرُ إِلَيْهِ انْحَدَرَ فِي الْوَادِي ‏"‏‏.‏\hadithno{3355}\hadithtrans{Narrated Mujahid:That when the people mentioned before Ibn `Abbas that the Dajjal would have the word Kafir, (i.e. unbeliever) or the letters Kafir (the root of the Arabic verb 'disbelieve') written on his forehead, I heard Ibn `Abbas saying, "I did not hear this, but the Prophet (ﷺ) said, 'If you want to see Abraham, then look at your companion (i.e. the Prophet) but Moses was a curly-haired, brown man (who used to ride) a red camel, the reins of which was made of fibres of date-palms. As if I were now looking down a valley}}
\hadithdefcmd{bukhari}{3356}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْقُرَشِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْتَتَنَ إِبْرَاهِيمُ ـ عَلَيْهِ السَّلاَمُ ـ وَهْوَ ابْنُ ثَمَانِينَ سَنَةً بِالْقَدُّومِ ‏"‏‏.‏ حَدَّثَنَا أَبُو الْيَمَانِ أَخْبَرَنَا شُعَيْبٌ حَدَّثَنَا أَبُو الزِّنَادِ ‏"‏ بِالْقَدُومِ ‏"‏‏.‏ مُخَفَّفَةً‏.‏ تَابَعَهُ عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ عَنْ أَبِي الزِّنَادِ‏.‏ تَابَعَهُ عَجْلاَنُ عَنْ أَبِي هُرَيْرَةَ‏.‏ وَرَوَاهُ مُحَمَّدُ بْنُ عَمْرٍو عَنْ أَبِي سَلَمَةَ‏.‏\hadithno{3356}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Abraham did his circumcision with an adze* at the age of eighty." Narrated Abu Az-Zinad: (as above) With an adze*. * a type of curved blade axe}}
\hadithdefcmd{bukhari}{3357}{حَدَّثَنَا سَعِيدُ بْنُ تَلِيدٍ الرُّعَيْنِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَمْ يَكْذِبْ إِبْرَاهِيمُ إِلاَّ ثَلاَثًا ‏"‏‏.‏\hadithno{3357}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Abraham did not tell a lie except on three occasions}}
\hadithdefcmd{bukhari}{3358}{حَدَّثَنَا مُحَمَّدُ بْنُ مَحْبُوبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ لَمْ يَكْذِبْ إِبْرَاهِيمُ ـ عَلَيْهِ السَّلاَمُ ـ إِلاَّ ثَلاَثَ كَذَبَاتٍ ثِنْتَيْنِ مِنْهُنَّ فِي ذَاتِ اللَّهِ عَزَّ وَجَلَّ، قَوْلُهُ ‏\{‏إِنِّي سَقِيمٌ ‏\}‏ وَقَوْلُهُ ‏\{‏بَلْ فَعَلَهُ كَبِيرُهُمْ هَذَا‏\}‏، وَقَالَ بَيْنَا هُوَ ذَاتَ يَوْمٍ وَسَارَةُ إِذْ أَتَى عَلَى جَبَّارٍ مِنَ الْجَبَابِرَةِ فَقِيلَ لَهُ إِنَّ هَا هُنَا رَجُلاً مَعَهُ امْرَأَةٌ مِنْ أَحْسَنِ النَّاسِ، فَأَرْسَلَ إِلَيْهِ، فَسَأَلَهُ عَنْهَا‏.‏ فَقَالَ مَنْ هَذِهِ قَالَ أُخْتِي، فَأَتَى سَارَةَ قَالَ يَا سَارَةُ، لَيْسَ عَلَى وَجْهِ الأَرْضِ مُؤْمِنٌ غَيْرِي وَغَيْرُكِ، وَإِنَّ هَذَا سَأَلَنِي، فَأَخْبَرْتُهُ أَنَّكِ أُخْتِي فَلاَ تُكَذِّبِينِي‏.‏ فَأَرْسَلَ إِلَيْهَا، فَلَمَّا دَخَلَتْ عَلَيْهِ ذَهَبَ يَتَنَاوَلُهَا بِيَدِهِ، فَأُخِذَ فَقَالَ ادْعِي اللَّهَ لِي وَلاَ أَضُرُّكِ‏.‏ فَدَعَتِ اللَّهَ فَأُطْلِقَ، ثُمَّ تَنَاوَلَهَا الثَّانِيَةَ، فَأُخِذَ مِثْلَهَا أَوْ أَشَدَّ فَقَالَ ادْعِي اللَّهَ لِي وَلاَ أَضُرُّكِ‏.‏ فَدَعَتْ فَأُطْلِقَ‏.‏ فَدَعَا بَعْضَ حَجَبَتِهِ فَقَالَ إِنَّكُمْ لَمْ تَأْتُونِي بِإِنْسَانٍ، إِنَّمَا أَتَيْتُمُونِي بِشَيْطَانٍ‏.‏ فَأَخْدَمَهَا هَاجَرَ فَأَتَتْهُ، وَهُوَ قَائِمٌ يُصَلِّي، فَأَوْمَأَ بِيَدِهِ مَهْيَا قَالَتْ رَدَّ اللَّهُ كَيْدَ الْكَافِرِ ـ أَوِ الْفَاجِرِ ـ فِي نَحْرِهِ، وَأَخْدَمَ هَاجَرَ‏.‏ قَالَ أَبُو هُرَيْرَةَ تِلْكَ أُمُّكُمْ يَا بَنِي مَاءِ السَّمَاءِ‏.‏\hadithno{3358}\hadithtrans{Narrated Abu Huraira:Abraham did not tell a lie except on three occasion. Twice for the Sake of Allah when he said, "I am sick," and he said, "(I have not done this but) the big idol has done it." The (third was) that while Abraham and Sarah (his wife) were going (on a journey) they passed by (the territory of) a tyrant. Someone said to the tyrant, "This man (i.e. Abraham) is accompanied by a very charming lady." So, he sent for Abraham and asked him about Sarah saying, "Who is this lady?" Abraham said, "She is my sister." Abraham went to Sarah and said, "O Sarah! There are no believers on the surface of the earth except you and I. This man asked me about you and I have told him that you are my sister, so don't contradict my statement." The tyrant then called Sarah and when she went to him, he tried to take hold of her with his hand, but (his hand got stiff and) he was confounded. He asked Sarah. "Pray to Allah for me, and I shall not harm you." So Sarah asked Allah to cure him and he got cured. He tried to take hold of her for the second time, but (his hand got as stiff as or stiffer than before and) was more confounded. He again requested Sarah, "Pray to Allah for me, and I will not harm you." Sarah asked Allah again and he became alright. He then called one of his guards (who had brought her) and said, "You have not brought me a human being but have brought me a devil." The tyrant then gave Hajar as a girl-servant to Sarah. Sarah came back (to Abraham) while he was praying. Abraham, gesturing with his hand, asked, "What has happened?" She replied, "Allah has spoiled the evil plot of the infidel (or immoral person) and gave me Hajar for service." (Abu Huraira then addressed his listeners saying, "That (Hajar) was your mother, O Bani Ma-is-Sama (i.e. the Arabs, the descendants of Ishmael, Hajar's son)}}
\hadithdefcmd{bukhari}{3359}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَوِ ابْنُ سَلاَمٍ عَنْهُ أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جُبَيْرٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ شَرِيكٍ ـ رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْوَزَغِ وَقَالَ ‏ "‏ كَانَ يَنْفُخُ عَلَى إِبْرَاهِيمَ عَلَيْهِ السَّلاَمُ ‏"‏‏.‏\hadithno{3359}\hadithtrans{Narrated Um Sharik:Allah's Messenger (ﷺ) ordered that the salamander should be killed and said, "It (i.e. the salamander) blew (the fire) on Abraham}}
\hadithdefcmd{bukhari}{3360}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتِ ‏\{‏الَّذِينَ آمَنُوا وَلَمْ يَلْبِسُوا إِيمَانَهُمْ بِظُلْمٍ‏\}‏ قُلْنَا يَا رَسُولَ اللَّهِ أَيُّنَا لاَ يَظْلِمُ نَفْسَهُ قَالَ ‏"‏ لَيْسَ كَمَا تَقُولُونَ ‏\{‏لَمْ يَلْبِسُوا إِيمَانَهُمْ بِظُلْمٍ‏\}‏ بِشِرْكٍ، أَوَلَمْ تَسْمَعُوا إِلَى قَوْلِ لُقْمَانَ لاِبْنِهِ ‏\{‏يَا بُنَىَّ لاَ تُشْرِكْ بِاللَّهِ إِنَّ الشِّرْكَ لَظُلْمٌ عَظِيمٌ ‏\}‏‏"‏‏.‏\hadithno{3360}\hadithtrans{Narrated `Abdullah:When the Verse:--"It is those who believe and do not confuse their belief with wrong ( i.e. joining others in worship with Allah" (6.83) was revealed, we said, "O Allah's Messenger (ﷺ)! Who is there amongst us who has not done wrong to himself?" He replied, "It is not as you say, for 'wrong' in the Verse and 'do not confuse their belief, with wrong means 'SHIRK' (i.e. joining others in worship with Allah). Haven't you heard Luqman's saying to his son, 'O my son! Join not others in worship with Allah, verily joining others in worship with Allah is a great wrong indeed}}
\hadithdefcmd{bukhari}{3361}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ نَصْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ أَبِي حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا بِلَحْمٍ فَقَالَ ‏ "‏ إِنَّ اللَّهَ يَجْمَعُ يَوْمَ الْقِيَامَةِ الأَوَّلِينَ وَالآخِرِينَ فِي صَعِيدٍ وَاحِدٍ، فَيُسْمِعُهُمُ الدَّاعِي، وَيُنْفِدُهُمُ الْبَصَرُ، وَتَدْنُو الشَّمْسُ مِنْهُمْ ـ فَذَكَرَ حَدِيثَ الشَّفَاعَةِ ـ فَيَأْتُونَ إِبْرَاهِيمَ فَيَقُولُونَ أَنْتَ نَبِيُّ اللَّهِ وَخَلِيلُهُ مِنَ الأَرْضِ، اشْفَعْ لَنَا إِلَى رَبِّكَ‏.‏ فَيَقُولُ ـ فَذَكَرَ كَذَبَاتِهِ ـ نَفْسِي نَفْسِي اذْهَبُوا إِلَى مُوسَى ‏"‏‏.‏ تَابَعَهُ أَنَسٌ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3361}\hadithtrans{Narrated Abu Huraira:One day some meat was given to the Prophet (ﷺ) and he said, "On the Day of Resurrection Allah will gather all the first and the last (people) in one plain, and the voice of the announcer will reach all of them, and one will be able to see them all, and the sun will come closer to them." (The narrator then mentioned the narration of intercession): "The people will go to Abraham and say: 'You are Allah's Prophet and His Khalil on the earth. Will you intercede for us with your Lord?' Abraham will then remember his lies and say: 'Myself! Myself! Go to Moses}}
\hadithdefcmd{bukhari}{3363}{حَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ أَبُو عَبْدِ اللَّهِ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، عَنْ أَبِيهِ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَرْحَمُ اللَّهُ أُمَّ إِسْمَاعِيلَ، لَوْلاَ أَنَّهَا عَجِلَتْ لَكَانَ زَمْزَمُ عَيْنًا مَعِينًا ‏"‏‏.‏ قَالَ الأَنْصَارِيُّ حَدَّثَنَا ابْنُ جُرَيْجٍ، أَمَّا كَثِيرُ بْنُ كَثِيرٍ فَحَدَّثَنِي قَالَ إِنِّي وَعُثْمَانَ بْنَ أَبِي سُلَيْمَانَ جُلُوسٌ مَعَ سَعِيدِ بْنِ جُبَيْرٍ، فَقَالَ مَا هَكَذَا حَدَّثَنِي ابْنُ عَبَّاسٍ، قَالَ أَقْبَلَ إِبْرَاهِيمُ بِإِسْمَاعِيلَ وَأُمِّهِ عَلَيْهِمُ السَّلاَمُ وَهْىَ تُرْضِعُهُ، مَعَهَا شَنَّةٌ ـ لَمْ يَرْفَعْهُ ـ ثُمَّ جَاءَ بِهَا إِبْرَاهِيمُ وَبِابْنِهَا إِسْمَاعِيلَ‏.‏\hadithno{3363}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "May Allah bestow His Mercy on the mother of Ishmael! Had she not hastened (to fill her water-skin with water from the Zamzam well). Zamzam would have been a stream flowing on the surface of the earth." Ibn `Abbas further added, "(The Prophet) Abraham brought Ishmael and his mother (to Mecca) and she was suckling Ishmael and she had a water-skin with her}}
\hadithdefcmd{bukhari}{3364}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، وَكَثِيرِ بْنِ كَثِيرِ بْنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ،، يَزِيدُ أَحَدُهُمَا عَلَى الآخَرِ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ ابْنُ عَبَّاسٍ أَوَّلَ مَا اتَّخَذَ النِّسَاءُ الْمِنْطَقَ مِنْ قِبَلِ أُمِّ إِسْمَاعِيلَ، اتَّخَذَتْ مِنْطَقًا لَتُعَفِّيَ أَثَرَهَا عَلَى سَارَةَ، ثُمَّ جَاءَ بِهَا إِبْرَاهِيمُ، وَبِابْنِهَا إِسْمَاعِيلَ وَهْىَ تُرْضِعُهُ حَتَّى وَضَعَهُمَا عِنْدَ الْبَيْتِ عِنْدَ دَوْحَةٍ، فَوْقَ زَمْزَمَ فِي أَعْلَى الْمَسْجِدِ، وَلَيْسَ بِمَكَّةَ يَوْمَئِذٍ أَحَدٌ، وَلَيْسَ بِهَا مَاءٌ، فَوَضَعَهُمَا هُنَالِكَ، وَوَضَعَ عِنْدَهُمَا جِرَابًا فِيهِ تَمْرٌ وَسِقَاءً فِيهِ مَاءٌ، ثُمَّ قَفَّى إِبْرَاهِيمُ مُنْطَلِقًا فَتَبِعَتْهُ أُمُّ إِسْمَاعِيلَ فَقَالَتْ يَا إِبْرَاهِيمُ أَيْنَ تَذْهَبُ وَتَتْرُكُنَا بِهَذَا الْوَادِي الَّذِي لَيْسَ فِيهِ إِنْسٌ وَلاَ شَىْءٌ فَقَالَتْ لَهُ ذَلِكَ مِرَارًا، وَجَعَلَ لاَ يَلْتَفِتُ إِلَيْهَا فَقَالَتْ لَهُ آللَّهُ الَّذِي أَمَرَكَ بِهَذَا قَالَ نَعَمْ‏.‏ قَالَتْ إِذًا لاَ يُضَيِّعُنَا‏.‏ ثُمَّ رَجَعَتْ، فَانْطَلَقَ إِبْرَاهِيمُ حَتَّى إِذَا كَانَ عِنْدَ الثَّنِيَّةِ حَيْثُ لاَ يَرَوْنَهُ اسْتَقْبَلَ بِوَجْهِهِ الْبَيْتَ، ثُمَّ دَعَا بِهَؤُلاَءِ الْكَلِمَاتِ وَرَفَعَ يَدَيْهِ، فَقَالَ ‏\{‏رَبَّنَا إِنِّي أَسْكَنْتُ مِنْ ذُرِّيَّتِي بِوَادٍ غَيْرِ ذِي زَرْعٍ‏\}‏ حَتَّى بَلَغَ ‏\{‏يَشْكُرُونَ‏\}‏‏.‏ وَجَعَلَتْ أُمُّ إِسْمَاعِيلَ تُرْضِعُ إِسْمَاعِيلَ، وَتَشْرَبُ مِنْ ذَلِكَ الْمَاءِ، حَتَّى إِذَا نَفِدَ مَا فِي السِّقَاءِ عَطِشَتْ وَعَطِشَ ابْنُهَا، وَجَعَلَتْ تَنْظُرُ إِلَيْهِ يَتَلَوَّى ـ أَوْ قَالَ يَتَلَبَّطُ ـ فَانْطَلَقَتْ كَرَاهِيَةَ أَنْ تَنْظُرَ إِلَيْهِ، فَوَجَدَتِ الصَّفَا أَقْرَبَ جَبَلٍ فِي الأَرْضِ يَلِيهَا، فَقَامَتْ عَلَيْهِ ثُمَّ اسْتَقْبَلَتِ الْوَادِيَ تَنْظُرُ هَلْ تَرَى أَحَدًا فَلَمْ تَرَ أَحَدًا، فَهَبَطَتْ مِنَ، الصَّفَا حَتَّى إِذَا بَلَغَتِ الْوَادِيَ رَفَعَتْ طَرَفَ دِرْعِهَا، ثُمَّ سَعَتْ سَعْىَ الإِنْسَانِ الْمَجْهُودِ، حَتَّى جَاوَزَتِ الْوَادِيَ، ثُمَّ أَتَتِ الْمَرْوَةَ، فَقَامَتْ عَلَيْهَا وَنَظَرَتْ هَلْ تَرَى أَحَدًا، فَلَمْ تَرَ أَحَدًا، فَفَعَلَتْ ذَلِكَ سَبْعَ مَرَّاتٍ ـ قَالَ ابْنُ عَبَّاسٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَذَلِكَ سَعْىُ النَّاسِ بَيْنَهُمَا ‏"‏‏.‏ ـ فَلَمَّا أَشْرَفَتْ عَلَى الْمَرْوَةِ سَمِعَتْ صَوْتًا، فَقَالَتْ صَهٍ‏.‏ تُرِيدَ نَفْسَهَا، ثُمَّ تَسَمَّعَتْ، فَسَمِعَتْ أَيْضًا، فَقَالَتْ قَدْ أَسْمَعْتَ، إِنْ كَانَ عِنْدَكَ غِوَاثٌ‏.‏ فَإِذَا هِيَ بِالْمَلَكِ، عِنْدَ مَوْضِعِ زَمْزَمَ، فَبَحَثَ بِعَقِبِهِ ـ أَوْ قَالَ بِجَنَاحِهِ ـ حَتَّى ظَهَرَ الْمَاءُ، فَجَعَلَتْ تُحَوِّضُهُ وَتَقُولُ بِيَدِهَا هَكَذَا، وَجَعَلَتْ تَغْرِفُ مِنَ الْمَاءِ فِي سِقَائِهَا، وَهْوَ يَفُورُ بَعْدَ مَا تَغْرِفُ ـ قَالَ ابْنُ عَبَّاسٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَرْحَمُ اللَّهُ أُمَّ إِسْمَاعِيلَ لَوْ تَرَكَتْ زَمْزَمَ ـ أَوْ قَالَ لَوْ لَمْ تَغْرِفْ مِنَ الْمَاءِ ـ لَكَانَتْ زَمْزَمُ عَيْنًا مَعِينًا ‏"‏‏.‏ ـ قَالَ فَشَرِبَتْ وَأَرْضَعَتْ وَلَدَهَا، فَقَالَ لَهَا الْمَلَكُ لاَ تَخَافُوا الضَّيْعَةَ، فَإِنَّ هَا هُنَا بَيْتَ اللَّهِ، يَبْنِي هَذَا الْغُلاَمُ، وَأَبُوهُ، وَإِنَّ اللَّهَ لاَ يُضِيعُ أَهْلَهُ‏.‏ وَكَانَ الْبَيْتُ مُرْتَفِعًا مِنَ الأَرْضِ كَالرَّابِيَةِ، تَأْتِيهِ السُّيُولُ فَتَأْخُذُ عَنْ يَمِينِهِ وَشِمَالِهِ، فَكَانَتْ كَذَلِكَ، حَتَّى مَرَّتْ بِهِمْ رُفْقَةٌ مِنْ جُرْهُمَ ـ أَوْ أَهْلُ بَيْتٍ مِنْ جُرْهُمَ ـ مُقْبِلِينَ مِنْ طَرِيقِ كَدَاءٍ فَنَزَلُوا فِي أَسْفَلِ مَكَّةَ، فَرَأَوْا طَائِرًا عَائِفًا‏.‏ فَقَالُوا إِنَّ هَذَا الطَّائِرَ لَيَدُورُ عَلَى مَاءٍ، لَعَهْدُنَا بِهَذَا الْوَادِي وَمَا فِيهِ مَاءٌ، فَأَرْسَلُوا جَرِيًّا أَوْ جَرِيَّيْنِ، فَإِذَا هُمْ بِالْمَاءِ، فَرَجَعُوا فَأَخْبَرُوهُمْ بِالْمَاءِ، فَأَقْبَلُوا، قَالَ وَأُمُّ إِسْمَاعِيلَ عِنْدَ الْمَاءِ فَقَالُوا أَتَأْذَنِينَ لَنَا أَنْ نَنْزِلَ عِنْدَكِ فَقَالَتْ نَعَمْ، وَلَكِنْ لاَ حَقَّ لَكُمْ فِي الْمَاءِ‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ابْنُ عَبَّاسٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَأَلْفَى ذَلِكَ أُمَّ إِسْمَاعِيلَ، وَهْىَ تُحِبُّ الإِنْسَ ‏"‏ فَنَزَلُوا وَأَرْسَلُوا إِلَى أَهْلِيهِمْ، فَنَزَلُوا مَعَهُمْ حَتَّى إِذَا كَانَ بِهَا أَهْلُ أَبْيَاتٍ مِنْهُمْ، وَشَبَّ الْغُلاَمُ، وَتَعَلَّمَ الْعَرَبِيَّةَ مِنْهُمْ، وَأَنْفَسَهُمْ وَأَعْجَبَهُمْ حِينَ شَبَّ، فَلَمَّا أَدْرَكَ زَوَّجُوهُ امْرَأَةً مِنْهُمْ، وَمَاتَتْ أُمُّ إِسْمَاعِيلَ، فَجَاءَ إِبْرَاهِيمُ، بَعْدَ مَا تَزَوَّجَ إِسْمَاعِيلُ يُطَالِعُ تَرِكَتَهُ، فَلَمْ يَجِدْ إِسْمَاعِيلَ، فَسَأَلَ امْرَأَتَهُ عَنْهُ فَقَالَتْ خَرَجَ يَبْتَغِي لَنَا‏.‏ ثُمَّ سَأَلَهَا عَنْ عَيْشِهِمْ وَهَيْئَتِهِمْ فَقَالَتْ نَحْنُ بِشَرٍّ، نَحْنُ فِي ضِيقٍ وَشِدَّةٍ‏.‏ فَشَكَتْ إِلَيْهِ‏.‏ قَالَ فَإِذَا جَاءَ زَوْجُكِ فَاقْرَئِي عَلَيْهِ السَّلاَمَ، وَقُولِي لَهُ يُغَيِّرْ عَتَبَةَ بَابِهِ‏.‏ فَلَمَّا جَاءَ إِسْمَاعِيلُ، كَأَنَّهُ آنَسَ شَيْئًا، فَقَالَ هَلْ جَاءَكُمْ مِنْ أَحَدٍ قَالَتْ نَعَمْ، جَاءَنَا شَيْخٌ كَذَا وَكَذَا، فَسَأَلَنَا عَنْكَ فَأَخْبَرْتُهُ، وَسَأَلَنِي كَيْفَ عَيْشُنَا فَأَخْبَرْتُهُ أَنَّا فِي جَهْدٍ وَشِدَّةٍ‏.‏ قَالَ فَهَلْ أَوْصَاكِ بِشَىْءٍ قَالَتْ نَعَمْ، أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ السَّلاَمَ، وَيَقُولُ غَيِّرْ عَتَبَةَ بَابِكَ‏.‏ قَالَ ذَاكِ أَبِي وَقَدْ أَمَرَنِي أَنْ أُفَارِقَكِ الْحَقِي بِأَهْلِكِ‏.‏ فَطَلَّقَهَا، وَتَزَوَّجَ مِنْهُمْ أُخْرَى، فَلَبِثَ عَنْهُمْ إِبْرَاهِيمُ مَا شَاءَ اللَّهُ ثُمَّ أَتَاهُمْ بَعْدُ، فَلَمْ يَجِدْهُ، فَدَخَلَ عَلَى امْرَأَتِهِ، فَسَأَلَهَا عَنْهُ‏.‏ فَقَالَتْ خَرَجَ يَبْتَغِي لَنَا‏.‏ قَالَ كَيْفَ أَنْتُمْ وَسَأَلَهَا عَنْ عَيْشِهِمْ، وَهَيْئَتِهِمْ‏.‏ فَقَالَتْ نَحْنُ بِخَيْرٍ وَسَعَةٍ‏.‏ وَأَثْنَتْ عَلَى اللَّهِ‏.‏ فَقَالَ مَا طَعَامُكُمْ قَالَتِ اللَّحْمُ‏.‏ قَالَ فَمَا شَرَابُكُمْ قَالَتِ الْمَاءُ‏.‏ فَقَالَ اللَّهُمَّ بَارِكْ لَهُمْ فِي اللَّحْمِ وَالْمَاءِ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَلَمْ يَكُنْ لَهُمْ يَوْمَئِذٍ حَبٌّ، وَلَوْ كَانَ لَهُمْ دَعَا لَهُمْ فِيهِ ‏"‏‏.‏ قَالَ فَهُمَا لاَ يَخْلُو عَلَيْهِمَا أَحَدٌ بِغَيْرِ مَكَّةَ إِلاَّ لَمْ يُوَافِقَاهُ‏.‏ قَالَ فَإِذَا جَاءَ زَوْجُكِ فَاقْرَئِي عَلَيْهِ السَّلاَمَ، وَمُرِيهِ يُثْبِتُ عَتَبَةَ بَابِهِ، فَلَمَّا جَاءَ إِسْمَاعِيلُ قَالَ هَلْ أَتَاكُمْ مِنْ أَحَدٍ قَالَتْ نَعَمْ أَتَانَا شَيْخٌ حَسَنُ الْهَيْئَةِ، وَأَثْنَتْ عَلَيْهِ، فَسَأَلَنِي عَنْكَ فَأَخْبَرْتُهُ، فَسَأَلَنِي كَيْفَ عَيْشُنَا فَأَخْبَرْتُهُ أَنَّا بِخَيْرٍ‏.‏ قَالَ فَأَوْصَاكِ بِشَىْءٍ قَالَتْ نَعَمْ، هُوَ يَقْرَأُ عَلَيْكَ السَّلاَمَ، وَيَأْمُرُكَ أَنْ تُثْبِتَ عَتَبَةَ بَابِكَ‏.‏ قَالَ ذَاكِ أَبِي، وَأَنْتِ الْعَتَبَةُ، أَمَرَنِي أَنْ أُمْسِكَكِ‏.‏ ثُمَّ لَبِثَ عَنْهُمْ مَا شَاءَ اللَّهُ، ثُمَّ جَاءَ بَعْدَ ذَلِكَ، وَإِسْمَاعِيلُ يَبْرِي نَبْلاً لَهُ تَحْتَ دَوْحَةٍ قَرِيبًا مِنْ زَمْزَمَ، فَلَمَّا رَآهُ قَامَ إِلَيْهِ، فَصَنَعَا كَمَا يَصْنَعُ الْوَالِدُ بِالْوَلَدِ وَالْوَلَدُ بِالْوَالِدِ، ثُمَّ قَالَ يَا إِسْمَاعِيلُ، إِنَّ اللَّهَ أَمَرَنِي بِأَمْرٍ‏.‏ قَالَ فَاصْنَعْ مَا أَمَرَكَ رَبُّكَ‏.‏ قَالَ وَتُعِينُنِي قَالَ وَأُعِينُكَ‏.‏ قَالَ فَإِنَّ اللَّهَ أَمَرَنِي أَنْ أَبْنِيَ هَا هُنَا بَيْتًا‏.‏ وَأَشَارَ إِلَى أَكَمَةٍ مُرْتَفِعَةٍ عَلَى مَا حَوْلَهَا‏.‏ قَالَ فَعِنْدَ ذَلِكَ رَفَعَا الْقَوَاعِدَ مِنَ الْبَيْتِ، فَجَعَلَ إِسْمَاعِيلُ يَأْتِي بِالْحِجَارَةِ، وَإِبْرَاهِيمُ يَبْنِي، حَتَّى إِذَا ارْتَفَعَ الْبِنَاءُ جَاءَ بِهَذَا الْحَجَرِ فَوَضَعَهُ لَهُ، فَقَامَ عَلَيْهِ وَهْوَ يَبْنِي، وَإِسْمَاعِيلُ يُنَاوِلُهُ الْحِجَارَةَ، وَهُمَا يَقُولاَنِ ‏\{‏رَبَّنَا تَقَبَّلْ مِنَّا إِنَّكَ أَنْتَ السَّمِيعُ الْعَلِيمُ‏\}‏‏.‏ قَالَ فَجَعَلاَ يَبْنِيَانِ حَتَّى يَدُورَا حَوْلَ الْبَيْتِ، وَهُمَا يَقُولاَنِ ‏\{‏رَبَّنَا تَقَبَّلْ مِنَّا إِنَّكَ أَنْتَ السَّمِيعُ الْعَلِيمُ ‏\}‏‏.‏\hadithno{3364}\hadithtrans{Narrated Ibn `Abbas:The first lady to use a girdle was the mother of Ishmael. She used a girdle so that she might hide her tracks from Sarah. Abraham brought her and her son Ishmael while she was suckling him, to a place near the Ka`ba under a tree on the spot of Zamzam, at the highest place in the mosque. During those days there was nobody in Mecca, nor was there any water So he made them sit over there and placed near them a leather bag containing some dates, and a small water-skin containing some water, and set out homeward. Ishmael's mother followed him saying, "O Abraham! Where are you going, leaving us in this valley where there is no person whose company we may enjoy, nor is there anything (to enjoy)?" She repeated that to him many times, but he did not look back at her Then she asked him, "Has Allah ordered you to do so?" He said, "Yes." She said, "Then He will not neglect us," and returned while Abraham proceeded onwards, and on reaching the Thaniya where they could not see him, he faced the Ka`ba, and raising both hands, invoked Allah saying the following prayers: 'O our Lord! I have made some of my offspring dwell in a valley without cultivation, by Your Sacred House (Ka`ba at Mecca) in order, O our Lord, that they may offer prayer perfectly. So fill some hearts among men with love towards them, and (O Allah) provide them with fruits, so that they may give thanks.' (14.37) Ishmael's mother went on suckling Ishmael and drinking from the water (she had). When the water in the water-skin had all been used up, she became thirsty and her child also became thirsty. She started looking at him (i.e. Ishmael) tossing in agony; She left him, for she could not endure looking at him, and found that the mountain of Safa was the nearest mountain to her on that land. She stood on it and started looking at the valley keenly so that she might see somebody, but she could not see anybody. Then she descended from Safa and when she reached the valley, she tucked up her robe and ran in the valley like a person in distress and trouble, till she crossed the valley and reached the Marwa mountain where she stood and started looking, expecting to see somebody, but she could not see anybody. She repeated that (running between Safa and Marwa) seven times." The Prophet (ﷺ) said, "This is the source of the tradition of the walking of people between them (i.e. Safa and Marwa). When she reached the Marwa (for the last time) she heard a voice and she asked herself to be quiet and listened attentively. She heard the voice again and said, 'O, (whoever you may be)! You have made me hear your voice; have you got something to help me?" And behold! She saw an angel at the place of Zamzam, digging the earth with his heel (or his wing), till water flowed from that place. She started to make something like a basin around it, using her hand in this way, and started filling her water-skin with water with her hands, and the water was flowing out after she had scooped some of it." The Prophet (ﷺ) added, "May Allah bestow Mercy on Ishmael's mother! Had she let the Zamzam (flow without trying to control it) (or had she not scooped from that water) (to fill her water-skin), Zamzam would have been a stream flowing on the surface of the earth." The Prophet (ﷺ) further added, "Then she drank (water) and suckled her child. The angel said to her, 'Don't be afraid of being neglected, for this is the House of Allah which will be built by this boy and his father, and Allah never neglects His people.' The House (i.e. Ka`ba) at that time was on a high place resembling a hillock, and when torrents came, they flowed to its right and left. She lived in that way till some people from the tribe of Jurhum or a family from Jurhum passed by her and her child, as they (i.e. the Jurhum people) were coming through the way of Kada'. They landed in the lower part of Mecca where they saw a bird that had the habit of flying around water and not leaving it. They said, 'This bird must be flying around water, though we know that there is no water in this valley.' They sent one or two messengers who discovered the source of water, and returned to inform them of the water. So, they all came (towards the water)." The Prophet (ﷺ) added, "Ishmael's mother was sitting near the water. They asked her, 'Do you allow us to stay with you?" She replied, 'Yes, but you will have no right to possess the water.' They agreed to that." The Prophet (ﷺ) further said, "Ishmael's mother was pleased with the whole situation as she used to love to enjoy the company of the people. So, they settled there, and later on they sent for their families who came and settled with them so that some families became permanent residents there. The child (i.e. Ishmael) grew up and learnt Arabic from them and (his virtues) caused them to love and admire him as he grew up, and when he reached the age of puberty they made him marry a woman from amongst them. After Ishmael's mother had died, Abraham came after Ishmael's marriage in order to see his family that he had left before, but he did not find Ishmael there. When he asked Ishmael's wife about him, she replied, 'He has gone in search of our livelihood.' Then he asked her about their way of living and their condition, and she replied, 'We are living in misery; we are living in hardship and destitution,' complaining to him. He said, 'When your husband returns, convey my salutation to him and tell him to change the threshold of the gate (of his house).' When Ishmael came, he seemed to have felt something unusual, so he asked his wife, 'Has anyone visited you?' She replied, 'Yes, an old man of so-and-so description came and asked me about you and I informed him, and he asked about our state of living, and I told him that we were living in hardship and poverty.' On that Ishmael said, 'Did he advise you anything?' She replied, 'Yes, he told me to convey his salutation to you and to tell you to change the threshold of your gate.' Ishmael said, 'It was my father, and he has ordered me to divorce you. Go back to your family.' So, Ishmael divorced her and married another woman from amongst them (i.e. Jurhum). Then Abraham stayed away from them for a period as long as Allah wished and called on them again but did not find Ishmael. So he came to Ishmael's wife and asked her about Ishmael. She said, 'He has gone in search of our livelihood.' Abraham asked her, 'How are you getting on?' asking her about their sustenance and living. She replied, 'We are prosperous and well-off (i.e. we have everything in abundance).' Then she thanked Allah' Abraham said, 'What kind of food do you eat?' She said, 'Meat.' He said, 'What do you drink?' She said, 'Water." He said, "O Allah! Bless their meat and water." The Prophet added, "At that time they did not have grain, and if they had grain, he would have also invoked Allah to bless it." The Prophet (ﷺ) added, "If somebody has only these two things as his sustenance, his health and disposition will be badly affected, unless he lives in Mecca." The Prophet (ﷺ) added," Then Abraham said to Ishmael's wife, "When your husband comes, give my regards to him and tell him that he should keep firm the threshold of his gate.' When Ishmael came back, he asked his wife, 'Did anyone call on you?' She replied, 'Yes, a good-looking old man came to me,' so she praised him and added, 'He asked about you, and I informed him, and he asked about our livelihood and I told him that we were in a good condition.' Ishmael asked her, 'Did he give you any piece of advice?' She said, 'Yes, he told me to give his regards to you and ordered that you should keep firm the threshold of your gate.' On that Ishmael said, 'It was my father, and you are the threshold (of the gate). He has ordered me to keep you with me.' Then Abraham stayed away from them for a period as long as Allah wished, and called on them afterwards. He saw Ishmael under a tree near Zamzam, sharpening his arrows. When he saw Abraham, he rose up to welcome him (and they greeted each other as a father does with his son or a son does with his father). Abraham said, 'O Ishmael! Allah has given me an order.' Ishmael said, 'Do what your Lord has ordered you to do.' Abraham asked, 'Will you help me?' Ishmael said, 'I will help you.' Abraham said, Allah has ordered me to build a house here,' pointing to a hillock higher than the land surrounding it." The Prophet (ﷺ) added, "Then they raised the foundations of the House (i.e. the Ka`ba). Ishmael brought the stones and Abraham was building, and when the walls became high, Ishmael brought this stone and put it for Abraham who stood over it and carried on building, while Ishmael was handing him the stones, and both of them were saying, 'O our Lord! Accept (this service) from us, Verily, You are the All-Hearing, the All-Knowing.' The Prophet (ﷺ) added, "Then both of them went on building and going round the Ka`ba saying: O our Lord ! Accept (this service) from us, Verily, You are the All-Hearing, the All-Knowing}}
\hadithdefcmd{bukhari}{3365}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنْ كَثِيرِ بْنِ كَثِيرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا كَانَ بَيْنَ إِبْرَاهِيمَ وَبَيْنَ أَهْلِهِ مَا كَانَ، خَرَجَ بِإِسْمَاعِيلَ وَأُمِّ إِسْمَاعِيلَ، وَمَعَهُمْ شَنَّةٌ فِيهَا مَاءٌ، فَجَعَلَتْ أُمُّ إِسْمَاعِيلَ تَشْرَبُ مِنَ الشَّنَّةِ فَيَدِرُّ لَبَنُهَا عَلَى صَبِيِّهَا حَتَّى قَدِمَ مَكَّةَ، فَوَضَعَهَا تَحْتَ دَوْحَةٍ، ثُمَّ رَجَعَ إِبْرَاهِيمُ إِلَى أَهْلِهِ، فَاتَّبَعَتْهُ أُمُّ إِسْمَاعِيلَ، حَتَّى لَمَّا بَلَغُوا كَدَاءً نَادَتْهُ مِنْ وَرَائِهِ يَا إِبْرَاهِيمُ إِلَى مَنْ تَتْرُكُنَا قَالَ إِلَى اللَّهِ‏.‏ قَالَتْ رَضِيتُ بِاللَّهِ‏.‏ قَالَ فَرَجَعَتْ فَجَعَلَتْ تَشْرَبُ مِنَ الشَّنَّةِ وَيَدِرُّ لَبَنُهَا عَلَى صَبِيِّهَا، حَتَّى لَمَّا فَنِيَ الْمَاءُ قَالَتْ لَوْ ذَهَبْتُ فَنَظَرْتُ لَعَلِّي أُحِسُّ أَحَدًا‏.‏ قَالَ فَذَهَبَتْ فَصَعِدَتِ الصَّفَا فَنَظَرَتْ وَنَظَرَتْ هَلْ تُحِسُّ أَحَدًا فَلَمْ تُحِسَّ أَحَدًا، فَلَمَّا بَلَغَتِ الْوَادِيَ سَعَتْ وَأَتَتِ الْمَرْوَةَ فَفَعَلَتْ ذَلِكَ أَشْوَاطًا، ثُمَّ قَالَتْ لَوْ ذَهَبْتُ فَنَظَرْتُ مَا فَعَلَ ـ تَعْنِي الصَّبِيَّ ـ فَذَهَبَتْ فَنَظَرَتْ، فَإِذَا هُوَ عَلَى حَالِهِ كَأَنَّهُ يَنْشَغُ لِلْمَوْتِ، فَلَمْ تُقِرَّهَا نَفْسُهَا، فَقَالَتْ لَوْ ذَهَبْتُ فَنَظَرْتُ لَعَلِّي أُحِسُّ أَحَدًا، فَذَهَبَتْ فَصَعِدَتِ الصَّفَا فَنَظَرَتْ وَنَظَرَتْ فَلَمْ تُحِسَّ أَحَدًا، حَتَّى أَتَمَّتْ سَبْعًا، ثُمَّ قَالَتْ لَوْ ذَهَبْتُ فَنَظَرْتُ مَا فَعَلَ، فَإِذَا هِيَ بِصَوْتٍ فَقَالَتْ أَغِثْ إِنْ كَانَ عِنْدَكَ خَيْرٌ‏.‏ فَإِذَا جِبْرِيلُ، قَالَ فَقَالَ بِعَقِبِهِ هَكَذَا، وَغَمَزَ عَقِبَهُ عَلَى الأَرْضِ، قَالَ فَانْبَثَقَ الْمَاءُ، فَدَهَشَتْ أُمُّ إِسْمَاعِيلَ فَجَعَلَتْ تَحْفِزُ‏.‏ قَالَ فَقَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ كَانَ الْمَاءُ ظَاهِرًا ‏"‏‏.‏ قَالَ فَجَعَلَتْ تَشْرَبُ مِنَ الْمَاءِ، وَيَدِرُّ لَبَنُهَا عَلَى صَبِيِّهَا ـ قَالَ ـ فَمَرَّ نَاسٌ مِنْ جُرْهُمَ بِبَطْنِ الْوَادِي، فَإِذَا هُمْ بِطَيْرٍ، كَأَنَّهُمْ أَنْكَرُوا ذَاكَ، وَقَالُوا مَا يَكُونُ الطَّيْرُ إِلاَّ عَلَى مَاءٍ‏.‏ فَبَعَثُوا رَسُولَهُمْ، فَنَظَرَ فَإِذَا هُمْ بِالْمَاءِ، فَأَتَاهُمْ فَأَخْبَرَهُمْ فَأَتَوْا إِلَيْهَا، فَقَالُوا يَا أُمَّ إِسْمَاعِيلَ، أَتَأْذَنِينَ لَنَا أَنْ نَكُونَ مَعَكِ أَوْ نَسْكُنَ مَعَكِ فَبَلَغَ ابْنُهَا فَنَكَحَ فِيهِمُ امْرَأَةً، قَالَ ثُمَّ إِنَّهُ بَدَا لإِبْرَاهِيمَ فَقَالَ لأَهْلِهِ إِنِّي مُطَّلِعٌ تَرِكَتِي‏.‏ قَالَ فَجَاءَ فَسَلَّمَ فَقَالَ أَيْنَ إِسْمَاعِيلُ فَقَالَتِ امْرَأَتُهُ ذَهَبَ يَصِيدُ‏.‏ قَالَ قُولِي لَهُ إِذَا جَاءَ غَيِّرْ عَتَبَةَ بَابِكَ‏.‏ فَلَمَّا جَاءَ أَخْبَرَتْهُ قَالَ أَنْتِ ذَاكِ فَاذْهَبِي إِلَى أَهْلِكِ‏.‏ قَالَ ثُمَّ إِنَّهُ بَدَا لإِبْرَاهِيمَ فَقَالَ لأَهْلِهِ إِنِّي مُطَّلِعٌ تَرِكَتِي‏.‏ قَالَ فَجَاءَ فَقَالَ أَيْنَ إِسْمَاعِيلُ فَقَالَتِ امْرَأَتُهُ ذَهَبَ يَصِيدُ، فَقَالَتْ أَلاَ تَنْزِلُ فَتَطْعَمَ وَتَشْرَبَ فَقَالَ وَمَا طَعَامُكُمْ وَمَا شَرَابُكُمْ قَالَتْ طَعَامُنَا اللَّحْمُ، وَشَرَابُنَا الْمَاءُ‏.‏ قَالَ اللَّهُمَّ بَارِكْ لَهُمْ فِي طَعَامِهِمْ وَشَرَابِهِمْ‏.‏ قَالَ فَقَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏"‏ بَرَكَةٌ بِدَعْوَةِ إِبْرَاهِيمَ ‏"‏‏.‏ قَالَ ثُمَّ إِنَّهُ بَدَا لإِبْرَاهِيمَ فَقَالَ لأَهْلِهِ إِنِّي مُطَّلِعٌ تَرِكَتِي‏.‏ فَجَاءَ فَوَافَقَ إِسْمَاعِيلَ مِنْ وَرَاءِ زَمْزَمَ، يُصْلِحُ نَبْلاً لَهُ، فَقَالَ يَا إِسْمَاعِيلُ، إِنَّ رَبَّكَ أَمَرَنِي أَنْ أَبْنِيَ لَهُ بَيْتًا‏.‏ قَالَ أَطِعْ رَبَّكَ‏.‏ قَالَ إِنَّهُ قَدْ أَمَرَنِي أَنْ تُعِينَنِي عَلَيْهِ‏.‏ قَالَ إِذًا أَفْعَلَ‏.‏ أَوْ كَمَا قَالَ‏.‏ قَالَ فَقَامَا فَجَعَلَ إِبْرَاهِيمُ يَبْنِي، وَإِسْمَاعِيلُ يُنَاوِلُهُ الْحِجَارَةَ، وَيَقُولاَنِ ‏\{‏رَبَّنَا تَقَبَّلْ مِنَّا إِنَّكَ أَنْتَ السَّمِيعُ الْعَلِيمُ‏\}‏ قَالَ حَتَّى ارْتَفَعَ الْبِنَاءُ وَضَعُفَ الشَّيْخُ عَلَى نَقْلِ الْحِجَارَةِ، فَقَامَ عَلَى حَجَرِ الْمَقَامِ، فَجَعَلَ يُنَاوِلُهُ الْحِجَارَةَ، وَيَقُولاَنِ ‏\{‏رَبَّنَا تَقَبَّلْ مِنَّا إِنَّكَ أَنْتَ السَّمِيعُ الْعَلِيمُ ‏\}‏‏.‏\hadithno{3365}\hadithtrans{(Narrated Ibn `Abbas:When Abraham had differences with his wife), (because of her jealousy of Hajar, Ishmael's mother), he took Ishmael and his mother and went away. They had a water-skin with them containing some water, Ishmael's mother used to drink water from the water-skin so that her milk would increase for her child. When Abraham reached Mecca, he made her sit under a tree and afterwards returned home. Ishmael's mother followed him, and when they reached Kada', she called him from behind, 'O Abraham! To whom are you leaving us?' He replied, '(I am leaving you) to Allah's (Care).' She said, 'I am satisfied to be with Allah.' She returned to her place and started drinking water from the water-skin, and her milk increased for her child. When the water had all been used up, she said to herself, 'I'd better go and look so that I may see somebody.' She ascended the Safa mountain and looked, hoping to see somebody, but in vain. When she came down to the valley, she ran till she reached the Marwa mountain. She ran to and fro (between the two mountains) many times. Then she said to herself, 'I'd better go and see the state of the child,' she went and found it in a state of one on the point of dying. She could not endure to watch it dying and said (to herself), 'If I go and look, I may find somebody.' She went and ascended the Safa mountain and looked for a long while but could not find anybody. Thus she completed seven rounds (of running) between Safa and Marwa. Again she said (to herself), 'I'd better go back and see the state of the child.' But suddenly she heard a voice, and she said to that strange voice, 'Help us if you can offer any help.' Lo! It was Gabriel (who had made the voice). Gabriel hit the earth with his heel like this (Ibn `Abbas hit the earth with his heel to Illustrate it), and so the water gushed out. Ishmael's mother was astonished and started digging. (Abu Al-Qasim) (i.e. the Prophet) said, "If she had left the water, (flow naturally without her intervention), it would have been flowing on the surface of the earth.") Ishmael's mother started drinking from the water and her milk increased for her child . Afterwards some people of the tribe of Jurhum, while passing through the bottom of the valley, saw some birds, and that astonished them, and they said, 'Birds can only be found at a place where there is water.' They sent a messenger who searched the place and found the water, and returned to inform them about it. Then they all went to her and said, 'O Ishmael's mother! Will you allow us to be with you (or dwell with you)?' (And thus they stayed there.) Later on her boy reached the age of puberty and married a lady from them. Then an idea occurred to Abraham which he disclosed to his wife (Sarah), 'I want to call on my dependents I left (at Mecca).' When he went there, he greeted (Ishmael's wife) and said, 'Where is Ishmael?' She replied, 'He has gone out hunting.' Abraham said (to her), 'When he comes, tell him to change the threshold of his gate.' When he came, she told him the same whereupon Ishmael said to her, 'You are the threshold, so go to your family (i.e. you are divorced).' Again Abraham thought of visiting his dependents whom he had left (at Mecca), and he told his wife (Sarah) of his intentions. Abraham came to Ishmael's house and asked, "Where is Ishmael?" Ishmael's wife replied, "He has gone out hunting," and added, "Will you stay (for some time) and have something to eat and drink?' Abraham asked, 'What is your food and what is your drink?' She replied, 'Our food is meat and our drink is water.' He said, 'O Allah! Bless their meals and their drink." Abu Al-Qa-sim (i.e. Prophet) said, "Because of Abraham's invocation there are blessings (in Mecca)." Once more Abraham thought of visiting his family he had left (at Mecca), so he told his wife (Sarah) of his decision. He went and found Ishmael behind the Zamzam well, mending his arrows. He said, "O Ishmael, Your Lord has ordered me to build a house for Him." Ishmael said, "Obey (the order of) your Lord." Abraham said, "Allah has also ordered me that you should help me therein." Ishmael said, "Then I will do." So, both of them rose and Abraham started building (the Ka`ba) while Ishmael went on handing him the stones, and both of them were saying, "O our Lord ! Accept (this service) from us, Verily, You are the All-Hearing, the All-Knowing." (2.127). When the building became high and the old man (i.e. Abraham) could no longer lift the stones (to such a high position), he stood over the stone of Al- Maqam and Ishmael carried on handing him the stones, and both of them were saying, 'O our Lord! Accept (this service) from us, Verily You are All-Hearing, All-Knowing}}
\hadithdefcmd{bukhari}{3366}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا إِبْرَاهِيمُ التَّيْمِيُّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبَا ذَرٍّ ـ رضى الله عنه ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ، أَىُّ مَسْجِدٍ وُضِعَ فِي الأَرْضِ أَوَّلُ قَالَ ‏"‏ الْمَسْجِدُ الْحَرَامُ ‏"‏‏.‏ قَالَ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ الْمَسْجِدُ الأَقْصَى ‏"‏‏.‏ قُلْتُ كَمْ كَانَ بَيْنَهُمَا قَالَ ‏"‏ أَرْبَعُونَ سَنَةً، ثُمَّ أَيْنَمَا أَدْرَكَتْكَ الصَّلاَةُ بَعْدُ فَصَلِّهْ، فَإِنَّ الْفَضْلَ فِيهِ ‏"‏‏.‏\hadithno{3366}\hadithtrans{Narrated Abu Dhar:I said, "O Allah's Messenger (ﷺ)! Which mosque was first built on the surface of the earth?" He said, "Al-Masjid-ul-Haram (in Mecca)." I said, "Which was built next?" He replied, "The mosque of Al-Aqsa (in Jerusalem) ." I said, "What was the period of construction between the two?" He said, "Forty years." He added, "Wherever (you may be, and) the prayer time becomes due, perform the prayer there, for the best thing is to do so (i.e. to offer the prayers in time)}}
\hadithdefcmd{bukhari}{3367}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَلَعَ لَهُ أُحُدٌ فَقَالَ ‏ "‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ، اللَّهُمَّ إِنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ، وَإِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا ‏"‏‏.‏ رَوَاهُ عَبْدُ اللَّهِ بْنُ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3367}\hadithtrans{Narrated Anas bin Malik:When the mountain of Uhud came in the sight of Allah's Messenger (ﷺ) he said. "This is a mountain that loves us and is loved by us. O Allah! Abraham made Mecca a sanctuary, and I make (the area) in between these two mountains (of Medina) a sanctuary}}
\hadithdefcmd{bukhari}{3368}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ ابْنَ أَبِي بَكْرٍ، أَخْبَرَ عَبْدَ اللَّهِ بْنَ عُمَرَ، عَنْ عَائِشَةَ ـ رضى الله عنهم ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلَمْ تَرَىْ أَنَّ قَوْمَكِ بَنَوُا الْكَعْبَةَ اقْتَصَرُوا عَنْ قَوَاعِدِ إِبْرَاهِيمَ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ، أَلاَ تَرُدُّهَا عَلَى قَوَاعِدِ إِبْرَاهِيمَ‏.‏ فَقَالَ ‏"‏ لَوْلاَ حِدْثَانُ قَوْمِكِ بِالْكُفْرِ ‏"‏‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لَئِنْ كَانَتْ عَائِشَةُ سَمِعَتْ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أُرَى أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَرَكَ اسْتِلاَمَ الرُّكْنَيْنِ اللَّذَيْنِ يَلِيَانِ الْحِجْرَ إِلاَّ أَنَّ الْبَيْتَ لَمْ يُتَمَّمْ عَلَى قَوَاعِدِ إِبْرَاهِيمَ‏.‏ وَقَالَ إِسْمَاعِيلُ عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَبِي بَكْرٍ‏.‏\hadithno{3368}\hadithtrans{Narrated `Aisha:(The wife of the Prophet) Allah's Messenger (ﷺ) said (to her). "Don't you see that when your folk built the Ka`ba, they did not build it on all the foundations built by Abraham?" I said, "O Allah's Messenger (ﷺ)! Why don't we rebuild it on the foundations of Abraham?" He said. "But for the fact that your folk have recently given up infidelity (I would have done so). Narrated Ibn `Umar: Aisha must have heard this from Allah's Messenger (ﷺ) for I see that Allah's Messenger (ﷺ) used not to touch the two corners facing Al-Hijr only because the House had not been built on the foundations of Abraham}}
\hadithdefcmd{bukhari}{3369}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، أَخْبَرَنِي أَبُو حُمَيْدٍ السَّاعِدِيُّ ـ رضى الله عنه ـ أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ نُصَلِّي عَلَيْكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ، كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ، وَبَارِكْ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ، كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏‏.‏\hadithno{3369}\hadithtrans{Narrated Abu Humaid As-Sa`idi:The people asked, "O Allah's Messenger (ﷺ)! How shall we (ask Allah to) send blessings on you?" Allah's Apostle replied, "Say: O Allah! Send Your Mercy on Muhammad and on his wives and on his offspring, as You sent Your Mercy on Abraham's family; and send Your Blessings on Muhammad and on his offspring, as You sent Your Blessings on Abraham's family, for You are the Most Praiseworthy, the Most Glorious}}
\hadithdefcmd{bukhari}{3370}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا أَبُو قُرَّةَ، مُسْلِمُ بْنُ سَالِمٍ الْهَمْدَانِيُّ قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عِيسَى، سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، قَالَ لَقِيَنِي كَعْبُ بْنُ عُجْرَةَ فَقَالَ أَلاَ أُهْدِي لَكَ هَدِيَّةً سَمِعْتُهَا مِنَ النَّبِيِّ، صلى الله عليه وسلم فَقُلْتُ بَلَى، فَأَهْدِهَا لِي‏.‏ فَقَالَ سَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْنَا يَا رَسُولَ اللَّهِ كَيْفَ الصَّلاَةُ عَلَيْكُمْ أَهْلَ الْبَيْتِ فَإِنَّ اللَّهَ قَدْ عَلَّمَنَا كَيْفَ نُسَلِّمُ‏.‏ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ، وَعَلَى آلِ مُحَمَّدٍ، كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ وَعَلَى آلِ إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ، اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ، وَعَلَى آلِ مُحَمَّدٍ، كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ، وَعَلَى آلِ إِبْرَاهِيمَ، إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏‏.‏\hadithno{3370}\hadithtrans{Narrated `Abdur-Rahman bin Abi Laila:Ka`b bin Ujrah met me and said, "Shall I not give you a present I got from the Prophet?" `Abdur- Rahman said, "Yes, give it to me." I said, "We asked Allah's Messenger (ﷺ) saying, 'O Allah's Messenger (ﷺ)! How should one (ask Allah to) send blessings on you, the members of the family, for Allah has taught us how to salute you (in the prayer)?' He said, 'Say: O Allah! Send Your Mercy on Muhammad and on the family of Muhammad, as You sent Your Mercy on Abraham and on the family of Abraham, for You are the Most Praise-worthy, the Most Glorious. O Allah! Send Your Blessings on Muhammad and the family of Muhammad, as You sent your Blessings on Abraham and on the family of Abraham, for You are the Most Praise-worthy, the Most Glorious}}
\hadithdefcmd{bukhari}{3371}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْمِنْهَالِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعَوِّذُ الْحَسَنَ وَالْحُسَيْنَ وَيَقُولُ ‏ "‏ إِنَّ أَبَاكُمَا كَانَ يُعَوِّذُ بِهَا إِسْمَاعِيلَ وَإِسْحَاقَ، أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ كُلِّ شَيْطَانٍ وَهَامَّةٍ، وَمِنْ كُلِّ عَيْنٍ لاَمَّةٍ ‏"‏‏.‏\hadithno{3371}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) used to seek Refuge with Allah for Al-Hasan and Al-Husain and say: "Your forefather (i.e. Abraham) used to seek Refuge with Allah for Ishmael and Isaac by reciting the following: 'O Allah! I seek Refuge with Your Perfect Words from every devil and from poisonous pests and from every evil, harmful, envious eye}}
\hadithdefcmd{bukhari}{3372}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نَحْنُ أَحَقُّ مِنْ إِبْرَاهِيمَ إِذْ قَالَ ‏\{‏رَبِّ أَرِنِي كَيْفَ تُحْيِي الْمَوْتَى قَالَ أَوَلَمْ تُؤْمِنْ قَالَ بَلَى وَلَكِنْ لِيَطْمَئِنَّ قَلْبِي‏\}‏ وَيَرْحَمُ اللَّهُ لُوطًا، لَقَدْ كَانَ يَأْوِي إِلَى رُكْنٍ شَدِيدٍ وَلَوْ لَبِثْتُ فِي السِّجْنِ طُولَ مَا لَبِثَ يُوسُفُ لأَجَبْتُ الدَّاعِيَ ‏"‏‏.‏\hadithno{3372}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "We are more liable to be in doubt than Abraham when he said, 'My Lord! Show me how You give life to the dead." . He (i.e. Allah) said: 'Don't you believe then?' He (i.e. Abraham) said: "Yes, but (I ask) in order to be stronger in Faith." (2.260) And may Allah send His Mercy on Lot! He wished to have a powerful support. If I were to stay in prison for such a long time as Joseph did I would have accepted the offer (of freedom without insisting on having my guiltlessness declared)}}
\hadithdefcmd{bukhari}{3373}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ ـ رضى الله عنه ـ قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم عَلَى نَفَرٍ مِنْ أَسْلَمَ يَنْتَضِلُونَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ارْمُوا بَنِي إِسْمَاعِيلَ، فَإِنَّ أَبَاكُمْ كَانَ رَامِيًا، وَأَنَا مَعَ بَنِي فُلاَنٍ ‏"‏‏.‏ قَالَ فَأَمْسَكَ أَحَدُ الْفَرِيقَيْنِ بِأَيْدِيهِمْ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَكُمْ لاَ تَرْمُونَ ‏"‏‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ، نَرْمِي وَأَنْتَ مَعَهُمْ قَالَ ‏"‏ ارْمُوا وَأَنَا مَعَكُمْ كُلِّكُمْ ‏"‏‏.‏\hadithno{3373}\hadithtrans{Narrated Salama bin Al-Akwa`:The Prophet (ﷺ) passed by some persons of the tribe of Aslam practicing archery (i.e. the throwing of arrows) Allah's Messenger (ﷺ) said, "O offspring of Ishmael! Practice archery (i.e. arrow throwing) as your father was a great archer (i.e. arrow-thrower). I am with (on the side of) the son of so-and-so-." Hearing that, one of the two teams stopped throwing. Allah's Messenger (ﷺ) asked them, ' Why are you not throwing?" They replied, "O Allah's Messenger (ﷺ)! How shall we throw when you are with the opposite team?" He said, "Throw, for I am with you all}}
\hadithdefcmd{bukhari}{3374}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، سَمِعَ الْمُعْتَمِرَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم مَنْ أَكْرَمُ النَّاسِ قَالَ ‏"‏ أَكْرَمُهُمْ أَتْقَاهُمْ ‏"‏‏.‏ قَالُوا يَا نَبِيَّ اللَّهِ، لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَأَكْرَمُ النَّاسِ يُوسُفُ نَبِيُّ اللَّهِ ابْنُ نَبِيِّ اللَّهِ ابْنِ نَبِيِّ اللَّهِ ابْنِ خَلِيلِ اللَّهِ ‏"‏‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَعَنْ مَعَادِنِ الْعَرَبِ تَسْأَلُونِي ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ‏"‏ فَخِيَارُكُمْ فِي الْجَاهِلِيَّةِ خِيَارُكُمْ فِي الإِسْلاَمِ إِذَا فَقِهُوا ‏"‏‏.‏\hadithno{3374}\hadithtrans{Narrated Abu Huraira:Some people asked the Prophet: "Who is the most honorable amongst the people?" He replied, "The most honorable among them is the one who is the most Allah-fearing." They said, "O Allah's Prophet! We do not ask about this." He said, "Then the most honorable person is Joseph, Allah's Prophet, the son of Allah's Prophet, the son of Allah's Prophet, the son of Allah's Khalil." They said, "We do not ask about this." He said, "Then you want to ask me about the Arabs' descent?" They said, "Yes." He said, "Those who were best in the pre-Islamic period, are the best in Islam, if they comprehend (the religious knowledge)}}
\hadithdefcmd{bukhari}{3375}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏\{‏يَغْفِرُ اللَّهُ لِلُوطٍ إِنْ كَانَ لَيَأْوِي إِلَى رُكْنٍ شَدِيدٍ‏\}‏‏.‏\hadithno{3375}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "May Allah forgive Lot: He wanted to have a powerful support}}
\hadithdefcmd{bukhari}{3376}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَرَأَ النَّبِيُّ صلى الله عليه وسلم ‏\{‏فَهَلْ مِنْ مُدَّكِر ‏\}‏‏.‏\hadithno{3376}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) recited:-- 'Hal-min-Muddakir' (54.15) (Is there any that will remember) (and avoid evil)}}
\hadithdefcmd{bukhari}{3377}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنَ زَمْعَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏ وَذَكَرَ الَّذِي عَقَرَ النَّاقَةَ قَالَ ‏ "‏ انْتَدَبَ لَهَا رَجُلٌ ذُو عِزٍّ وَمَنَعَةٍ فِي قُوَّةٍ كَأَبِي زَمْعَةَ ‏"‏‏.‏\hadithno{3377}\hadithtrans{Narrated `Abdullah bin Zam`a:I heard the Prophet (ﷺ) while referring to the person who had cut the legs of the she-camel (of the Prophet Salih (ﷺ)), saying, "The man who was appointed for doing this job, was a man of honor and power in his nation like Abu Zam`a}}
\hadithdefcmd{bukhari}{3378}{حَدَّثَنَا مُحَمَّدُ بْنُ مِسْكِينٍ أَبُو الْحَسَنِ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ بْنِ حَيَّانَ أَبُو زَكَرِيَّاءَ، حَدَّثَنَا سُلَيْمَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا نَزَلَ الْحِجْرَ فِي غَزْوَةِ تَبُوكَ أَمَرَهُمْ أَنْ لاَ يَشْرَبُوا مِنْ بِئْرِهَا، وَلاَ يَسْتَقُوا مِنْهَا فَقَالُوا قَدْ عَجَنَّا مِنْهَا، وَاسْتَقَيْنَا‏.‏ فَأَمَرَهُمْ أَنْ يَطْرَحُوا ذَلِكَ الْعَجِينَ وَيُهَرِيقُوا ذَلِكَ الْمَاءَ‏.‏ وَيُرْوَى عَنْ سَبْرَةَ بْنِ مَعْبَدٍ وَأَبِي الشُّمُوسِ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِإِلْقَاءِ الطَّعَامِ‏.‏ وَقَالَ أَبُو ذَرٍّ عَنِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ مَنِ اعْتَجَنَ بِمَائِهِ ‏"‏‏.‏\hadithno{3378}\hadithtrans{Narrated Ibn `Umar:When Allah's Messenger (ﷺ) landed at Al-Hijr during the Ghazwa of Tabuk, he ordered his companions not to drink water from its well or reserve water from it. They said, "We have already kneaded the dough with its water. and also filled our bags with its water.'' On that, the Prophet (ﷺ) ordered them to throw away the dough and pour out the water}}
\hadithdefcmd{bukhari}{3379}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ النَّاسَ نَزَلُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْضَ ثَمُودَ الْحِجْرَ، فَاسْتَقَوْا مِنْ بِئْرِهَا، وَاعْتَجَنُوا بِهِ، فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُهَرِيقُوا مَا اسْتَقَوْا مِنْ بِئْرِهَا، وَأَنْ يَعْلِفُوا الإِبِلَ الْعَجِينَ، وَأَمَرَهُمْ أَنْ يَسْتَقُوا مِنَ الْبِئْرِ الَّتِي كَانَ تَرِدُهَا النَّاقَةُ‏.‏ تَابَعَهُ أُسَامَةُ عَنْ نَافِعٍ‏.‏\hadithno{3379}\hadithtrans{Narrated `Abdullah bin `Umar:The people landed at the land of Thamud called Al-Hijr along with Allah's Messenger (ﷺ) and they took water from its well for drinking and kneading the dough with it as well. (When Allah's Messenger (ﷺ) heard about it) he ordered them to pour out the water they had taken from its wells and feed the camels with the dough, and ordered them to take water from the well whence the she-camel (of Prophet Salih) used to drink}}
\hadithdefcmd{bukhari}{3380}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ ـ رضى الله عنهم أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا مَرَّ بِالْحِجْرِ قَالَ ‏ "‏ لاَ تَدْخُلُوا مَسَاكِنَ الَّذِينَ ظَلَمُوا إِلاَّ أَنْ تَكُونُوا بَاكِينَ، أَنْ يُصِيبَكُمْ مَا أَصَابَهُمْ ‏"‏‏.‏ ثُمَّ تَقَنَّعَ بِرِدَائِهِ، وَهْوَ عَلَى الرَّحْلِ‏.‏\hadithno{3380}\hadithtrans{Narrated `Abdullah bin `Umar:When the Prophet (ﷺ) passed by (a place called) Al Hijr, he said, "Do not enter the houses of those who were unjust to themselves, unless (you enter) weeping, lest you should suffer the same punishment as was inflicted upon them." After that he covered his face with his sheet cloth while he was on the camel-saddle}}
\hadithdefcmd{bukhari}{3381}{حَدَّثَنِي عَبْدُ اللَّهِ، حَدَّثَنَا وَهْبٌ، حَدَّثَنَا أَبِي، سَمِعْتُ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، أَنَّ ابْنَ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَدْخُلُوا مَسَاكِنَ الَّذِينَ ظَلَمُوا أَنْفُسَهُمْ إِلاَّ أَنْ تَكُونُوا بَاكِينَ، أَنْ يُصِيبَكُمْ مِثْلُ مَا أَصَابَهُمْ ‏"‏‏.‏\hadithno{3381}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Do not enter the ruined dwellings of those who were unjust to themselves unless (you enter) weeping, lest you should suffer the same punishment as was inflicted upon them}}
\hadithdefcmd{bukhari}{3382}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْكَرِيمُ ابْنُ الْكَرِيمِ ابْنِ الْكَرِيمِ ابْنِ الْكَرِيمِ يُوسُفُ ابْنُ يَعْقُوبَ بْنِ إِسْحَاقَ بْنِ إِبْرَاهِيمَ ـ عَلَيْهِمُ السَّلاَمُ ‏"‏‏.‏\hadithno{3382}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The honorable is the son of the honorable, the son the honorable, the son the honorable, i.e. Joseph, the son of Jacob, the son of Isaac, the son of Abraham}}
\hadithdefcmd{bukhari}{3383}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ أَكْرَمُ النَّاسِ قَالَ ‏"‏ أَتْقَاهُمْ لِلَّهِ ‏"‏‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَأَكْرَمُ النَّاسِ يُوسُفُ نَبِيُّ اللَّهِ ابْنُ نَبِيِّ اللَّهِ ابْنِ نَبِيِّ اللَّهِ ابْنِ خَلِيلِ اللَّهِ ‏"‏‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَعَنْ مَعَادِنِ الْعَرَبِ تَسْأَلُونِي، النَّاسُ مَعَادِنُ خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقِهُوا ‏"‏‏.‏ حَدَّثَنِي مُحَمَّدُ بْنُ سَلَامٍ أَخْبَرَنَا عَبْدَةُ عَنْ عُبَيْدِ اللَّهِ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ رَضِيَ اللَّهُ عَنْهُ عَنْ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ بِهَذَا\hadithno{3383}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) was asked, "Who is the most honorable amongst the people?" He replied, "The most Allah fearing." The people said, "We do not want to ask you about this." He said, "The most honorable person is Joseph, Allah's Prophet, the son of Allah's Prophet, the son of Allah's Prophet, the son of Allah's Khalil" The people said, 'We do not want to ask you about this." He said," Then you want to ask me about the origins of the Arabs? People are of various origins. The best in the pre-Islamic period are the best in Islam, provided they comprehend (the religious knowledge)}}
\hadithdefcmd{bukhari}{3384}{حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، أَخْبَرَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏"‏ مُرِي أَبَا بَكْرٍ يُصَلِّي بِالنَّاسِ ‏"‏‏.‏ قَالَتْ إِنَّهُ رَجُلٌ أَسِيفٌ، مَتَى يَقُمْ مَقَامَكَ رَقَّ‏.‏ فَعَادَ فَعَادَتْ، قَالَ شُعْبَةُ فَقَالَ فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏"‏ إِنَّكُنَّ صَوَاحِبُ يُوسُفَ، مُرُوا أَبَا بَكْرٍ ‏"‏‏.‏\hadithno{3384}\hadithtrans{Narrated `Aisha:That the Prophet (ﷺ) said (to her). "Order Abu Bakr to lead the people in prayer." She replied," Abu Bakr is a soft-hearted person and when he stands at your place, he will weep (so he will not be able to lead the prayer)." The Prophet (ﷺ) repeated the same order and she gave the same reply. The narrator, Shuba said that the Prophet (ﷺ) said on the third or fourth time. "You are (like) the female companions of Joseph. Order Abu Bakr to lead the prayer}}
\hadithdefcmd{bukhari}{3385}{حَدَّثَنَا الرَّبِيعُ بْنُ يَحْيَى الْبَصْرِيُّ، حَدَّثَنَا زَائِدَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، قَالَ مَرِضَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏‏.‏ فَقَالَتْ إِنَّ أَبَا بَكْرٍ رَجُلٌ‏.‏ فَقَالَ مِثْلَهُ فَقَالَتْ مِثْلَهُ‏.‏ فَقَالَ ‏"‏ مُرُوهُ فَإِنَّكُنَّ صَوَاحِبُ يُوسُفَ ‏"‏‏.‏ فَأَمَّ أَبُو بَكْرٍ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ حُسَيْنٌ عَنْ زَائِدَةَ رَجُلٌ رَقِيقٌ‏.‏\hadithno{3385}\hadithtrans{Narrated Abu Musa:When the Prophet (ﷺ) fell ill, he said, "Order Abu Bakr to lead the people in prayer." `Aisha said, "Abu Bakr is a soft-hearted person. The Prophet (ﷺ) gave the same order again and she again gave the same reply. He again said, "Order Abu Bakr (to lead the prayer)! You are (like) the female companions of Joseph." Consequently Abu Bakr led the people in prayer in the life-time of the Prophet}}
\hadithdefcmd{bukhari}{3386}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ أَنْجِ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ، اللَّهُمَّ أَنْجِ سَلَمَةَ بْنَ هِشَامٍ، اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ اللَّهُمَّ أَنْجِ الْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ، اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ، اللَّهُمَّ اجْعَلْهَا سِنِينَ كَسِنِي يُوسُفَ ‏"‏‏.‏\hadithno{3386}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "O Allah! Save `Aiyyash bin Abi Rabi`a (from the unjust treatment of the infidels). O Allah! Save Salama bin Hisham. O Allah! Send your Punishment on (the tribe of) Mudar. O Allah! Let them suffer from years (of drought) similar to that inflicted during the life-time of Joseph}}
\hadithdefcmd{bukhari}{3387}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ ابْنِ أَخِي جُوَيْرِيَةَ حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَأَبَا، عُبَيْدٍ أَخْبَرَاهُ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَرْحَمُ اللَّهُ لُوطًا، لَقَدْ كَانَ يَأْوِي إِلَى رُكْنٍ شَدِيدٍ، وَلَوْ لَبِثْتُ فِي السِّجْنِ مَا لَبِثَ يُوسُفُ ثُمَّ أَتَانِي الدَّاعِي لأَجَبْتُهُ ‏"‏‏.‏\hadithno{3387}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "May Allah bestow His Mercy on Lot. He wanted to have a powerful support. If I were to stay in prison (for a period equal to) the stay of Joseph (in prison) and then the offer of freedom came to me, then I would have accepted it." (See Hadith No)}}
\hadithdefcmd{bukhari}{3388}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا حُصَيْنٌ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، قَالَ سَأَلْتُ أُمَّ رُومَانَ، وَهْىَ أُمُّ عَائِشَةَ، عَمَّا قِيلَ فِيهَا مَا قِيلَ قَالَتْ بَيْنَمَا أَنَا مَعَ عَائِشَةَ جَالِسَتَانِ، إِذْ وَلَجَتْ عَلَيْنَا امْرَأَةٌ مِنَ الأَنْصَارِ، وَهْىَ تَقُولُ فَعَلَ اللَّهُ بِفُلاَنٍ وَفَعَلَ‏.‏ قَالَتْ فَقُلْتُ لِمَ قَالَتْ إِنَّهُ نَمَا ذِكْرَ الْحَدِيثِ‏.‏ فَقَالَتْ عَائِشَةُ أَىُّ حَدِيثٍ فَأَخْبَرَتْهَا‏.‏ قَالَتْ فَسَمِعَهُ أَبُو بَكْرٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ نَعَمْ‏.‏ فَخَرَّتْ مَغْشِيًّا عَلَيْهَا، فَمَا أَفَاقَتْ إِلاَّ وَعَلَيْهَا حُمَّى بِنَافِضٍ، فَجَاءَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَا لِهَذِهِ ‏"‏‏.‏ قُلْتُ حُمَّى أَخَذَتْهَا مِنْ أَجْلِ حَدِيثٍ تُحُدِّثَ بِهِ، فَقَعَدَتْ فَقَالَتْ وَاللَّهِ لَئِنْ حَلَفْتُ لاَ تُصَدِّقُونِي، وَلَئِنِ اعْتَذَرْتُ لاَ تَعْذِرُونِي، فَمَثَلِي وَمَثَلُكُمْ كَمَثَلِ يَعْقُوبَ وَبَنِيهِ، فَاللَّهُ الْمُسْتَعَانُ عَلَى مَا تَصِفُونَ‏.‏ فَانْصَرَفَ النَّبِيُّ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ مَا أَنْزَلَ، فَأَخْبَرَهَا فَقَالَتْ بِحَمْدِ اللَّهِ لاَ بِحَمْدِ أَحَدٍ‏.‏\hadithno{3388}\hadithtrans{Narrated Masruq:I asked Um Ruman, `Aisha's mother about the accusation forged against `Aisha. She said, "While I was sitting with `Aisha, an Ansari woman came to us and said, 'Let Allah condemn such-and-such person.' I asked her, 'Why do you say so?' She replied, 'For he has spread the (slanderous) story.' `Aisha said, 'What story?' The woman then told her the story. `Aisha asked, 'Have Abu Bakr and Allah's Messenger (ﷺ) heard about it ?' She said, 'Yes.' `Aisha fell down senseless (on hearing that), and when she came to her senses, she got fever and shaking of the body. The Prophet (ﷺ) came and asked, 'What is wrong with her?' I said, 'She has got fever because of a story which has been rumored.' `Aisha got up and said, 'By Allah! Even if I took an oath, you would not believe me, and if I put forward an excuse, You would not excuse me. My example and your example is just like that example of Jacob and his sons. Against that which you assert, it is Allah (Alone) Whose Help can be sought.' (12.18) The Prophet (ﷺ) left and then Allah revealed the Verses (concerning the matter), and on that `Aisha said, 'Thanks to Allah (only) and not to anybody else}}
\hadithdefcmd{bukhari}{3389}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّهُ سَأَلَ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَرَأَيْتِ قَوْلَهُ ‏\{‏حَتَّى إِذَا اسْتَيْأَسَ الرُّسُلُ وَظَنُّوا أَنَّهُمْ قَدْ كُذِّبُوا‏\}‏ أَوْ كُذِبُوا‏.‏ قَالَتْ بَلْ كَذَّبَهُمْ قَوْمُهُمْ‏.‏ فَقُلْتُ وَاللَّهِ لَقَدِ اسْتَيْقَنُوا أَنَّ قَوْمَهُمْ كَذَّبُوهُمْ وَمَا هُوَ بِالظَّنِّ‏.‏ فَقَالَتْ يَا عُرَيَّةُ، لَقَدِ اسْتَيْقَنُوا بِذَلِكَ‏.‏ قُلْتُ فَلَعَلَّهَا أَوْ كُذِبُوا‏.‏ قَالَتْ مَعَاذَ اللَّهِ، لَمْ تَكُنِ الرُّسُلُ تَظُنُّ ذَلِكَ بِرَبِّهَا وَأَمَّا هَذِهِ الآيَةُ قَالَتْ هُمْ أَتْبَاعُ الرُّسُلِ الَّذِينَ آمَنُوا بِرَبِّهِمْ وَصَدَّقُوهُمْ، وَطَالَ عَلَيْهِمُ الْبَلاَءُ، وَاسْتَأْخَرَ عَنْهُمُ النَّصْرُ حَتَّى إِذَا اسْتَيْأَسَتْ مِمَّنْ كَذَّبَهُمْ مِنْ قَوْمِهِمْ، وَظَنُّوا أَنَّ أَتْبَاعَهُمْ كَذَّبُوهُمْ جَاءَهُمْ نَصْرُ اللَّهِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ ‏\{‏اسْتَيْأَسُوا‏\}‏ افْتَعَلُوا مِنْ يَئِسْتُ‏.‏ ‏\{‏مِنْهُ‏\}‏ مِنْ يُوسُفَ‏.‏ ‏\{‏لاَ تَيْأَسُوا مِنْ رَوْحِ اللَّهِ‏\}‏ مَعْنَاهُ الرَّجَاءُ‏.‏\hadithno{3389}\hadithtrans{Narrated `Urwa:I asked `Aisha the wife of the Prophet (ﷺ) about the meaning of the following Verse: -- "(Respite will be granted) 'Until when the apostles give up hope (of their people) and thought that they were denied (by their people)..............."(12.110) `Aisha replied, "Really, their nations did not believe them." I said, "By Allah! They were definite that their nations treated them as liars and it was not a matter of suspecting." `Aisha said, "O 'Uraiya (i.e. `Urwa)! No doubt, they were quite sure about it." I said, "May the Verse be read in such a way as to mean that the apostles thought that Allah did not help them?" Aisha said, "Allah forbid! (Impossible) The Apostles did not suspect their Lord of such a thing. But this Verse is concerned with the Apostles' followers who had faith in their Lord and believed in their apostles and their period of trials was long and Allah's Help was delayed till the apostles gave up hope for the conversion of the disbelievers amongst their nation and suspected that even their followers were shaken in their belief, Allah's Help then came to them}}
\hadithdefcmd{bukhari}{3390}{أَخْبَرَنِي عَبْدَةُ، حَدَّثَنَا عَبْدُ الصَّمَدِ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْكَرِيمُ ابْنُ الْكَرِيمِ ابْنِ الْكَرِيمِ ابْنِ الْكَرِيمِ يُوسُفُ بْنُ يَعْقُوبَ بْنِ إِسْحَاقَ بْنِ إِبْرَاهِيمَ عَلَيْهِمِ السَّلاَمُ ‏"‏‏.‏\hadithno{3390}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The honorable, the son of the honorable, the son of the honorable, the son of the honorable, (was) Joseph, the son of Jacob, the son of Isaac, the son of Abraham}}
\hadithdefcmd{bukhari}{3391}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْجُعْفِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا أَيُّوبُ يَغْتَسِلُ عُرْيَانًا خَرَّ عَلَيْهِ رِجْلُ جَرَادٍ مِنْ ذَهَبٍ، فَجَعَلَ يَحْثِي فِي ثَوْبِهِ، فَنَادَى رَبُّهُ يَا أَيُّوبُ، أَلَمْ أَكُنْ أَغْنَيْتُكَ عَمَّا تَرَى قَالَ بَلَى يَا رَبِّ، وَلَكِنْ لاَ غِنَى لِي عَنْ بَرَكَتِكَ ‏"‏‏.‏\hadithno{3391}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "While Job was naked, taking a bath, a swarm of gold locusts fell on him and he started collecting them in his garment. His Lord called him, 'O Job! Have I not made you rich enough to need what you see? He said, 'Yes, O Lord! But I cannot dispense with your Blessing}}
\hadithdefcmd{bukhari}{3392}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، سَمِعْتُ عُرْوَةَ، قَالَ قَالَتْ عَائِشَةُ ـ رضى الله عنها فَرَجَعَ النَّبِيُّ صلى الله عليه وسلم إِلَى خَدِيجَةَ يَرْجُفُ فُؤَادُهُ، فَانْطَلَقَتْ بِهِ إِلَى وَرَقَةَ بْنِ نَوْفَلٍ، وَكَانَ رَجُلاً تَنَصَّرَ يَقْرَأُ الإِنْجِيلَ بِالْعَرَبِيَّةِ‏.‏ فَقَالَ وَرَقَةُ مَاذَا تَرَى فَأَخْبَرَهُ‏.‏ فَقَالَ وَرَقَةُ هَذَا النَّامُوسُ الَّذِي أَنْزَلَ اللَّهُ عَلَى مُوسَى، وَإِنْ أَدْرَكَنِي يَوْمُكَ أَنْصُرْكَ نَصْرًا مُؤَزَّرًا‏.‏ النَّامُوسُ صَاحِبُ السِّرِّ الَّذِي يُطْلِعُهُ بِمَا يَسْتُرُهُ عَنْ غَيْرِهِ‏.‏\hadithno{3392}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) returned to Khadija while his heart was beating rapidly. She took him to Waraqa bin Naufal who was a Christian convert and used to read the Gospels in Arabic Waraqa asked (the Prophet), "What do you see?" When he told him, Waraqa said, "That is the same angel whom Allah sent to the Prophet) Moses. Should I live till you receive the Divine Message, I will support you strongly}}
\hadithdefcmd{bukhari}{3393}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ مَالِكِ بْنِ صَعْصَعَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَدَّثَهُمْ عَنْ لَيْلَةِ أُسْرِيَ بِهِ حَتَّى أَتَى السَّمَاءَ الْخَامِسَةَ، فَإِذَا هَارُونُ قَالَ هَذَا هَارُونُ فَسَلِّمْ عَلَيْهِ‏.‏ فَسَلَّمْتُ عَلَيْهِ، فَرَدَّ ثُمَّ قَالَ مَرْحَبًا بِالأَخِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ‏.‏ تَابَعَهُ ثَابِتٌ وَعَبَّادُ بْنُ أَبِي عَلِيٍّ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3393}\hadithtrans{Narrated Malik bin Sasaa:Allah's Messenger (ﷺ) talked to his companions about his Night Journey to the Heavens. When he reached the fifth Heaven, he met Aaron. (Gabriel said to the Prophet), "This is Aaron." The Prophet (ﷺ) said, "Gabriel greeted and so did I, and he returned the greeting saying, 'Welcome, O Pious Brother and Pious Prophet}}
\hadithdefcmd{bukhari}{3394}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ ‏ "‏ رَأَيْتُ مُوسَى وَإِذَا رَجُلٌ ضَرْبٌ رَجِلٌ، كَأَنَّهُ مِنْ رِجَالِ شَنُوءَةَ، وَرَأَيْتُ عِيسَى، فَإِذَا هُوَ رَجُلٌ رَبْعَةٌ أَحْمَرُ كَأَنَّمَا خَرَجَ مِنْ دِيمَاسٍ، وَأَنَا أَشْبَهُ وَلَدِ إِبْرَاهِيمَ صلى الله عليه وسلم بِهِ، ثُمَّ أُتِيتُ بِإِنَاءَيْنِ، فِي أَحَدِهِمَا لَبَنٌ، وَفِي الآخَرِ خَمْرٌ فَقَالَ اشْرَبْ أَيَّهُمَا شِئْتَ‏.‏ فَأَخَذْتُ اللَّبَنَ فَشَرِبْتُهُ فَقِيلَ أَخَذْتَ الْفِطْرَةَ، أَمَا إِنَّكَ لَوْ أَخَذْتَ الْخَمْرَ غَوَتْ أُمَّتُكَ ‏"‏‏.‏\hadithno{3394}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "On the night of my Ascension to Heaven, I saw (the prophet) Moses who was a thin person with lank hair, looking like one of the men of the tribe of Shanua; and I saw Jesus who was of average height with red face as if he had just come out of a bathroom. And I resemble prophet Abraham more than any of his offspring does. Then I was given two cups, one containing milk and the other wine. Gabriel said, 'Drink whichever you like.' I took the milk and drank it. Gabriel said, 'You have accepted what is natural, (True Religion i.e. Islam) and if you had taken the wine, your followers would have gone astray}}
\hadithdefcmd{bukhari}{3396}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا الْعَالِيَةِ، حَدَّثَنَا ابْنُ عَمِّ، نَبِيِّكُمْ ـ يَعْنِي ابْنَ عَبَّاسٍ ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏ وَنَسَبَهُ إِلَى أَبِيهِ‏.‏ وَذَكَرَ النَّبِيُّ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ فَقَالَ ‏"‏ مُوسَى آدَمُ طُوَالٌ كَأَنَّهُ مِنْ رِجَالِ شَنُوءَةَ ‏"‏‏.‏ وَقَالَ ‏"‏ عِيسَى جَعْدٌ مَرْبُوعٌ ‏"‏‏.‏ وَذَكَرَ مَالِكًا خَازِنَ النَّارِ، وَذَكَرَ الدَّجَّالَ‏.‏\hadithno{3396}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "One should not say that I am better than Jonah (i.e. Yunus) bin Matta." So, he mentioned his father Matta. The Prophet (ﷺ) mentioned the night of his Ascension and said, "The prophet Moses was brown, a tall person as if from the people of the tribe of Shanu'a. Jesus was a curly-haired man of moderate height." He also mentioned Malik, the gate-keeper of the (Hell) Fire, and Ad-Dajjal}}
\hadithdefcmd{bukhari}{3397}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَيُّوبُ السَّخْتِيَانِيُّ، عَنِ ابْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا قَدِمَ الْمَدِينَةَ وَجَدَهُمْ يَصُومُونَ يَوْمًا، يَعْنِي عَاشُورَاءَ، فَقَالُوا هَذَا يَوْمٌ عَظِيمٌ، وَهْوَ يَوْمٌ نَجَّى اللَّهُ فِيهِ مُوسَى، وَأَغْرَقَ آلَ فِرْعَوْنَ، فَصَامَ مُوسَى شُكْرًا لِلَّهِ‏.‏ فَقَالَ ‏ "‏ أَنَا أَوْلَى بِمُوسَى مِنْهُمْ ‏"‏‏.‏ فَصَامَهُ وَأَمَرَ بِصِيَامِهِ‏.‏\hadithno{3397}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) came to Medina, he found (the Jews) fasting on the day of 'Ashura' (i.e. 10th of Muharram). They used to say: "This is a great day on which Allah saved Moses and drowned the folk of Pharaoh. Moses observed the fast on this day, as a sign of gratitude to Allah." The Prophet (ﷺ) said, "I am closer to Moses than they." So, he observed the fast (on that day) and ordered the Muslims to fast on it}}
\hadithdefcmd{bukhari}{3398}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ النَّاسُ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ، فَأَكُونُ أَوَّلَ مَنْ يُفِيقُ، فَإِذَا أَنَا بِمُوسَى آخِذٌ بِقَائِمَةٍ مِنْ قَوَائِمِ الْعَرْشِ، فَلاَ أَدْرِي أَفَاقَ قَبْلِي، أَمْ جُوزِيَ بِصَعْقَةِ الطُّورِ ‏"‏‏.‏\hadithno{3398}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) said, 'People will be struck unconscious on the Day of Resurrection and I will be the first to regain consciousness, and behold! There I will see Moses holding one of the pillars of Allah's Throne. I will wonder whether he has become conscious before me, or if he has been exempted because of his unconsciousness at the Tur (mountain) which he received (on the earth)}}
\hadithdefcmd{bukhari}{3399}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْجُعْفِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْلاَ بَنُو إِسْرَائِيلَ لَمْ يَخْنَزِ اللَّحْمُ، وَلَوْلاَ حَوَّاءُ لَمْ تَخُنْ أُنْثَى زَوْجَهَا الدَّهْرَ ‏"‏‏.‏\hadithno{3399}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Were it not for Bani Israel, meat would not decay; and were it not for Eve, no woman would ever betray her husband}}
\hadithdefcmd{bukhari}{3400}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ تَمَارَى هُوَ وَالْحُرُّ بْنُ قَيْسٍ الْفَزَارِيُّ فِي صَاحِبِ مُوسَى، قَالَ ابْنُ عَبَّاسٍ هُوَ خَضِرٌ، فَمَرَّ بِهِمَا أُبَىُّ بْنُ كَعْبٍ، فَدَعَاهُ ابْنُ عَبَّاسٍ، فَقَالَ إِنِّي تَمَارَيْتُ أَنَا وَصَاحِبِي، هَذَا فِي صَاحِبِ مُوسَى الَّذِي سَأَلَ السَّبِيلَ إِلَى لُقِيِّهِ، هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ شَأْنَهُ قَالَ نَعَمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بَيْنَمَا مُوسَى فِي مَلإٍ مِنْ بَنِي إِسْرَائِيلَ جَاءَهُ رَجُلٌ، فَقَالَ هَلْ تَعْلَمُ أَحَدًا أَعْلَمَ مِنْكَ قَالَ لاَ‏.‏ فَأَوْحَى اللَّهُ إِلَى مُوسَى بَلَى عَبْدُنَا خَضِرٌ‏.‏ فَسَأَلَ مُوسَى السَّبِيلَ إِلَيْهِ، فَجُعِلَ لَهُ الْحُوتُ آيَةً، وَقِيلَ لَهُ إِذَا فَقَدْتَ الْحُوتَ فَارْجِعْ، فَإِنَّكَ سَتَلْقَاهُ‏.‏ فَكَانَ يَتْبَعُ الْحُوتَ فِي الْبَحْرِ، فَقَالَ لِمُوسَى فَتَاهُ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ، فَإِنِّي نَسِيتُ الْحُوتَ، وَمَا أَنْسَانِيهِ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ‏.‏ فَقَالَ مُوسَى ذَلِكَ مَا كُنَّا نَبْغِ‏.‏ فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا فَوَجَدَا خَضِرًا، فَكَانَ مِنْ شَأْنِهِمَا الَّذِي قَصَّ اللَّهُ فِي كِتَابِهِ ‏"‏‏.‏\hadithno{3400}\hadithtrans{Narrated Ibn `Abbas:That he differed with Al-Hur bin Qais Al-Fazari regarding the companion of Moses. Ibn `Abbas said that he was Al-Khadir. Meanwhile Ubai bin Ka`b passed by them and Ibn `Abbas called him saying, "My friend and I have differed regarding Moses' companion whom Moses asked the way to meet. Have you heard Allah's Messenger (ﷺ) mentioning something about him?" He said, "Yes, I heard Allah's Apostle saying, 'While Moses was sitting in the company of some Israelites, a man came and asked (him), 'Do you know anyone who is more learned than you?' Moses replied, 'No.' So, Allah sent the Divine Inspiration to Moses: 'Yes, Our slave, Khadir (is more learned than you).' Moses asked how to meet him (i.e. Khadir). So, the fish, was made, as a sign for him, and he was told that when the fish was lost, he should return and there he would meet him. So, Moses went on looking for the sign of the fish in the sea. The servant boy of Moses said to him, 'Do you know that when we were sitting by the side of the rock, I forgot the fish, and it was only Satan who made me forget to tell (you) about it.' Moses said, That was what we were seeking after,' and both of them returned, following their footmarks and found Khadir; and what happened further to them, is mentioned in Allah's Book}}
\hadithdefcmd{bukhari}{3401}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ إِنَّ نَوْفًا الْبَكَالِيَّ يَزْعُمُ أَنَّ مُوسَى صَاحِبَ الْخَضِرِ لَيْسَ هُوَ مُوسَى بَنِي إِسْرَائِيلَ، إِنَّمَا هُوَ مُوسَى آخَرُ‏.‏ فَقَالَ كَذَبَ عَدُوُّ اللَّهِ حَدَّثَنَا أُبَىُّ بْنُ كَعْبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ أَنَّ مُوسَى قَامَ خَطِيبًا فِي بَنِي إِسْرَائِيلَ، فَسُئِلَ أَىُّ النَّاسِ أَعْلَمُ فَقَالَ أَنَا‏.‏ فَعَتَبَ اللَّهُ عَلَيْهِ إِذْ لَمْ يَرُدَّ الْعِلْمَ إِلَيْهِ‏.‏ فَقَالَ لَهُ بَلَى، لِي عَبْدٌ بِمَجْمَعِ الْبَحْرَيْنِ هُوَ أَعْلَمُ مِنْكَ‏.‏ قَالَ أَىْ رَبِّ وَمَنْ لِي بِهِ ـ وَرُبَّمَا قَالَ سُفْيَانُ أَىْ رَبِّ وَكَيْفَ لِي بِهِ ـ قَالَ تَأْخُذُ حُوتًا، فَتَجْعَلُهُ فِي مِكْتَلٍ، حَيْثُمَا فَقَدْتَ الْحُوتَ فَهْوَ ثَمَّ ـ وَرُبَّمَا قَالَ فَهْوَ ثَمَّهْ ـ وَأَخَذَ حُوتًا، فَجَعَلَهُ فِي مِكْتَلٍ، ثُمَّ انْطَلَقَ هُوَ وَفَتَاهُ يُوشَعُ بْنُ نُونٍ، حَتَّى أَتَيَا الصَّخْرَةَ، وَضَعَا رُءُوسَهُمَا فَرَقَدَ مُوسَى، وَاضْطَرَبَ الْحُوتُ فَخَرَجَ فَسَقَطَ فِي الْبَحْرِ، فَاتَّخَذَ سَبِيلَهُ فِي الْبَحْرِ سَرَبًا، فَأَمْسَكَ اللَّهُ عَنِ الْحُوتِ جِرْيَةَ الْمَاءِ، فَصَارَ مِثْلَ الطَّاقِ، فَقَالَ هَكَذَا مِثْلُ الطَّاقِ‏.‏ فَانْطَلَقَا يَمْشِيَانِ بَقِيَّةَ لَيْلَتِهِمَا وَيَوْمَهُمَا، حَتَّى إِذَا كَانَ مِنَ الْغَدِ قَالَ لِفَتَاهُ آتِنَا غَدَاءَنَا لَقَدْ لَقِينَا مِنْ سَفَرِنَا هَذَا نَصَبًا‏.‏ وَلَمْ يَجِدْ مُوسَى النَّصَبَ حَتَّى جَاوَزَ حَيْثُ أَمَرَهُ اللَّهُ‏.‏ قَالَ لَهُ فَتَاهُ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ، وَمَا أَنْسَانِيهِ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ، وَاتَّخَذَ سَبِيلَهُ فِي الْبَحْرِ عَجَبًا، فَكَانَ لِلْحُوتِ سَرَبًا وَلَهُمَا عَجَبًا‏.‏ قَالَ لَهُ مُوسَى ذَلِكَ مَا كُنَّا نَبْغِي، فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا، رَجَعَا يَقُصَّانِ آثَارَهُمَا حَتَّى انْتَهَيَا إِلَى الصَّخْرَةِ، فَإِذَا رَجُلٌ مُسَجًّى بِثَوْبٍ، فَسَلَّمَ مُوسَى، فَرَدَّ عَلَيْهِ‏.‏ فَقَالَ وَأَنَّى بِأَرْضِكَ السَّلاَمُ‏.‏ قَالَ أَنَا مُوسَى‏.‏ قَالَ مُوسَى بَنِي إِسْرَائِيلَ قَالَ نَعَمْ، أَتَيْتُكَ لِتُعَلِّمَنِي مِمَّا عُلِّمْتَ رَشَدًا‏.‏ قَالَ يَا مُوسَى إِنِّي عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ، عَلَّمَنِيهِ اللَّهُ لاَ تَعْلَمُهُ وَأَنْتَ عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ عَلَّمَكَهُ اللَّهُ لاَ أَعْلَمُهُ‏.‏ قَالَ هَلْ أَتَّبِعُكَ قَالَ ‏\{‏إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا * وَكَيْفَ تَصْبِرُ عَلَى مَا لَمْ تُحِطْ بِهِ خُبْرًا‏\}‏ إِلَى قَوْلِهِ ‏\{‏إِمْرًا‏\}‏ فَانْطَلَقَا يَمْشِيَانِ عَلَى سَاحِلِ الْبَحْرِ، فَمَرَّتْ بِهِمَا سَفِينَةٌ، كَلَّمُوهُمْ أَنْ يَحْمِلُوهُمْ، فَعَرَفُوا الْخَضِرَ، فَحَمَلُوهُ بِغَيْرِ نَوْلٍ، فَلَمَّا رَكِبَا فِي السَّفِينَةِ جَاءَ عُصْفُورٌ، فَوَقَعَ عَلَى حَرْفِ السَّفِينَةِ، فَنَقَرَ فِي الْبَحْرِ نَقْرَةً أَوْ نَقْرَتَيْنِ، قَالَ لَهُ الْخَضِرُ يَا مُوسَى، مَا نَقَصَ عِلْمِي وَعِلْمُكَ مِنْ عِلْمِ اللَّهِ إِلاَّ مِثْلَ مَا نَقَصَ هَذَا الْعُصْفُورُ بِمِنْقَارِهِ مِنَ الْبَحْرِ‏.‏ إِذْ أَخَذَ الْفَأْسَ فَنَزَعَ لَوْحًا، قَالَ فَلَمْ يَفْجَأْ مُوسَى إِلاَّ وَقَدْ قَلَعَ لَوْحًا بِالْقَدُّومِ‏.‏ فَقَالَ لَهُ مُوسَى مَا صَنَعْتَ قَوْمٌ حَمَلُونَا بِغَيْرِ نَوْلٍ، عَمَدْتَ إِلَى سَفِينَتِهِمْ فَخَرَقْتَهَا لِتُغْرِقَ أَهْلَهَا، لَقَدْ جِئْتَ شَيْئًا إِمْرًا‏.‏ قَالَ أَلَمْ أَقُلْ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا‏.‏ قَالَ لاَ تُؤَاخِذْنِي بِمَا نَسِيتُ وَلاَ تُرْهِقْنِي مِنْ أَمْرِي عُسْرًا، فَكَانَتِ الأُولَى مِنْ مُوسَى نِسْيَانًا‏.‏ فَلَمَّا خَرَجَا مِنَ الْبَحْرِ مَرُّوا بِغُلاَمٍ يَلْعَبُ مَعَ الصِّبْيَانِ، فَأَخَذَ الْخَضِرُ بِرَأْسِهِ فَقَلَعَهُ بِيَدِهِ هَكَذَا ـ وَأَوْمَأَ سُفْيَانُ بِأَطْرَافِ أَصَابِعِهِ كَأَنَّهُ يَقْطِفُ شَيْئًا ـ فَقَالَ لَهُ مُوسَى أَقَتَلْتَ نَفْسًا زَكِيَّةً بِغَيْرِ نَفْسٍ لَقَدْ جِئْتَ شَيْئًا نُكْرًا‏.‏ قَالَ أَلَمْ أَقُلْ لَكَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا‏.‏ قَالَ إِنْ سَأَلْتُكَ عَنْ شَىْءٍ بَعْدَهَا فَلاَ تُصَاحِبْنِي، قَدْ بَلَغْتَ مِنْ لَدُنِّي عُذْرًا‏.‏ فَانْطَلَقَا حَتَّى إِذَا أَتَيَا أَهْلَ قَرْيَةٍ اسْتَطْعَمَا أَهْلَهَا فَأَبَوْا أَنْ يُضَيِّفُوهُمَا فَوَجَدَا فِيهَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ مَائِلاً ـ أَوْمَأَ بِيَدِهِ هَكَذَا وَأَشَارَ سُفْيَانُ كَأَنَّهُ يَمْسَحُ شَيْئًا إِلَى فَوْقُ، فَلَمْ أَسْمَعْ سُفْيَانَ يَذْكُرُ مَائِلاً إِلاَّ مَرَّةً ـ قَالَ قَوْمٌ أَتَيْنَاهُمْ فَلَمْ يُطْعِمُونَا وَلَمْ يُضَيِّفُونَا عَمَدْتَ إِلَى حَائِطِهِمْ لَوْ شِئْتَ لاَتَّخَذْتَ عَلَيْهِ أَجْرًا‏.‏ قَالَ هَذَا فِرَاقُ بَيْنِي وَبَيْنِكَ، سَأُنَبِّئُكَ بِتَأْوِيلِ مَا لَمْ تَسْتَطِعْ عَلَيْهِ صَبْرًا‏"‏‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَدِدْنَا أَنَّ مُوسَى كَانَ صَبَرَ، فَقَصَّ اللَّهُ عَلَيْنَا مِنْ خَبَرِهِمَا ‏"‏‏.‏ قَالَ سُفْيَانُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَرْحَمُ اللَّهُ مُوسَى، لَوْ كَانَ صَبَرَ يُقَصُّ عَلَيْنَا مِنْ أَمْرِهِمَا ‏"‏‏.‏ وَقَرَأَ ابْنُ عَبَّاسٍ أَمَامَهُمْ مَلِكٌ يَأْخُذُ كُلَّ سَفِينَةٍ صَالِحَةٍ غَصْبًا، وَأَمَّا الْغُلاَمُ فَكَانَ كَافِرًا وَكَانَ أَبَوَاهُ مُؤْمِنَيْنِ‏.‏ ثُمَّ قَالَ لِي سُفْيَانُ سَمِعْتُهُ مِنْهُ مَرَّتَيْنِ وَحَفِظْتُهُ مِنْهُ‏.‏ قِيلَ لِسُفْيَانَ حَفِظْتَهُ قَبْلَ أَنْ تَسْمَعَهُ مِنْ عَمْرٍو، أَوْ تَحَفَّظْتَهُ مِنْ إِنْسَانٍ فَقَالَ مِمَّنْ أَتَحَفَّظُهُ وَرَوَاهُ أَحَدٌ عَنْ عَمْرٍو غَيْرِي سَمِعْتُهُ مِنْهُ مَرَّتَيْنِ أَوْ ثَلاَثًا وَحَفِظْتُهُ مِنْهُ‏.‏\hadithno{3401}\hadithtrans{Narrated Sa`id bin Jubair:I said to Ibn `Abbas, "Nauf Al-Bakali claims that Moses, the companion of Al-Khadir was not Moses (the prophet) of the children of Israel, but some other Moses." Ibn `Abbas said, "Allah's enemy (i.e. Nauf) has told a lie. Ubai bin Ka`b told us that the Prophet (ﷺ) said, 'Once Moses stood up and addressed Bani Israel. He was asked who was the most learned man amongst the people. He said, 'I.' Allah admonished him as he did not attribute absolute knowledge to Him (Allah). So, Allah said to him, 'Yes, at the junction of the two seas there is a Slave of Mine who is more learned than you.' Moses said, 'O my Lord! How can I meet him?' Allah said, 'Take a fish and put it in a large basket and you will find him at the place where you will lose the fish.' Moses took a fish and put it in a basket and proceeded along with his (servant) boy, Yusha` bin Noon, till they reached the rock where they laid their heads (i.e. lay down). Moses slept, and the fish, moving out of the basket, fell into the sea. It took its way into the sea (straight) as in a tunnel. Allah stopped the flow of water over the fish and it became like an arch (the Prophet (ﷺ) pointed out this arch with his hands). They travelled the rest of the night, and the next day Moses said to his boy (servant), 'Give us our food, for indeed, we have suffered much fatigue in this journey of ours.' Moses did not feel tired till he crossed that place which Allah had ordered him to seek after. His boy (servant) said to him, 'Do you know that when we were sitting near that rock, I forgot the fish, and none but Satan caused me to forget to tell (you) about it, and it took its course into the sea in an amazing way?.' So there was a path for the fish and that astonished them. Moses said, 'That was what we were seeking after.' So, both of them retraced their footsteps till they reached the rock. There they saw a man Lying covered with a garment. Moses greeted him and he replied saying, 'How do people greet each other in your land?' Moses said, 'I am Moses.' The man asked, 'Moses of Bani Israel?' Moses said, 'Yes, I have come to you so that you may teach me from those things which Allah has taught you.' He said, 'O Moses! I have some of the Knowledge of Allah which Allah has taught me, and which you do not know, while you have some of the Knowledge of Allah which Allah has taught you and which I do not know.' Moses asked, 'May I follow you?' He said, 'But you will not be able to remain patient with me for how can you be patient about things which you will not be able to understand?' (Moses said, 'You will find me, if Allah so will, truly patient, and I will not disobey you in aught.') So, both of them set out walking along the sea-shore, a boat passed by them and they asked the crew of the boat to take them on board. The crew recognized Al-Khadir and so they took them on board without fare. When they were on board the boat, a sparrow came and stood on the edge of the boat and dipped its beak once or twice into the sea. Al-Khadir said to Moses, 'O Moses! My knowledge and your knowledge have not decreased Allah's Knowledge except as much as this sparrow has decreased the water of the sea with its beak.' Then suddenly Al-Khadir took an adze and plucked a plank, and Moses did not notice it till he had plucked a plank with the adze. Moses said to him, 'What have you done? They took us on board charging us nothing; yet you have intentionally made a hole in their boat so as to drown its passengers. Verily, you have done a dreadful thing.' Al-Khadir replied, 'Did I not tell you that you would not be able to remain patient with me?' Moses replied, 'Do not blame me for what I have forgotten, and do not be hard upon me for my fault.' So the first excuse of Moses was that he had forgotten. When they had left the sea, they passed by a boy playing with other boys. Al-Khadir took hold of the boys head and plucked it with his hand like this. (Sufyan, the sub narrator pointed with his fingertips as if he was plucking some fruit.) Moses said to him, "Have you killed an innocent person who has not killed any person? You have really done a horrible thing." Al-Khadir said, "Did I not tell you that you could not remain patient with me?' Moses said "If I ask you about anything after this, don't accompany me. You have received an excuse from me.' Then both of them went on till they came to some people of a village, and they asked its inhabitants for food but they refused to entertain them as guests. Then they saw therein a wall which was just going to collapse (and Al Khadir repaired it just by touching it with his hands). (Sufyan, the sub-narrator, pointed with his hands, illustrating how Al-Khadir passed his hands over the wall upwards.) Moses said, "These are the people whom we have called on, but they neither gave us food, nor entertained us as guests, yet you have repaired their wall. If you had wished, you could have taken wages for it." Al-Khadir said, "This is the parting between you and me, and I shall tell you the explanation of those things on which you could not remain patient." The Prophet (ﷺ) added, "We wished that Moses could have remained patient by virtue of which Allah might have told us more about their story. (Sufyan the sub-narrator said that the Prophet (ﷺ) said, "May Allah bestow His Mercy on Moses! If he had remained patient, we would have been told further about their case}}
\hadithdefcmd{bukhari}{3402}{حَدَّثَنَا مُحَمَّدُ بْنُ سَعِيدٍ الأَصْبَهَانِيُّ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا سُمِّيَ الْخَضِرُ أَنَّهُ جَلَسَ عَلَى فَرْوَةٍ بَيْضَاءَ فَإِذَا هِيَ تَهْتَزُّ مِنْ خَلْفِهِ خَضْرَاءَ ‏"‏‏.‏\hadithno{3402}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Al-Khadir was named so because he sat over a barren white land, it turned green with plantation after (his sitting over it)}}
\hadithdefcmd{bukhari}{3403}{حَدَّثَنِي إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قِيلَ لِبَنِي إِسْرَائِيلَ ادْخُلُوا الْبَابَ سُجَّدًا وَقُولُوا حِطَّةٌ‏.‏ فَبَدَّلُوا فَدَخَلُوا يَزْحَفُونَ عَلَى أَسْتَاهِهِمْ، وَقَالُوا حَبَّةٌ فِي شَعْرَةٍ ‏"‏‏.‏\hadithno{3403}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "It was said to Bani Israel, Enter the gate (of the town) with humility (prostrating yourselves) and saying: "Repentance", but they changed the word and entered the town crawling on their buttocks and saying: "A wheat grain in the hair}}
\hadithdefcmd{bukhari}{3404}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا عَوْفٌ، عَنِ الْحَسَنِ، وَمُحَمَّدٍ، وَخِلاَسٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مُوسَى كَانَ رَجُلاً حَيِيًّا سِتِّيرًا، لاَ يُرَى مِنْ جِلْدِهِ شَىْءٌ، اسْتِحْيَاءً مِنْهُ، فَآذَاهُ مَنْ آذَاهُ مِنْ بَنِي إِسْرَائِيلَ، فَقَالُوا مَا يَسْتَتِرُ هَذَا التَّسَتُّرَ إِلاَّ مِنْ عَيْبٍ بِجِلْدِهِ، إِمَّا بَرَصٌ وَإِمَّا أُدْرَةٌ وَإِمَّا آفَةٌ‏.‏ وَإِنَّ اللَّهَ أَرَادَ أَنْ يُبَرِّئَهُ مِمَّا قَالُوا لِمُوسَى فَخَلاَ يَوْمًا وَحْدَهُ فَوَضَعَ ثِيَابَهُ عَلَى الْحَجَرِ ثُمَّ اغْتَسَلَ، فَلَمَّا فَرَغَ أَقْبَلَ إِلَى ثِيَابِهِ لِيَأْخُذَهَا، وَإِنَّ الْحَجَرَ عَدَا بِثَوْبِهِ، فَأَخَذَ مُوسَى عَصَاهُ وَطَلَبَ الْحَجَرَ، فَجَعَلَ يَقُولُ ثَوْبِي حَجَرُ، ثَوْبِي حَجَرُ، حَتَّى انْتَهَى إِلَى مَلإٍ مِنْ بَنِي إِسْرَائِيلَ، فَرَأَوْهُ عُرْيَانًا أَحْسَنَ مَا خَلَقَ اللَّهُ، وَأَبْرَأَهُ مِمَّا يَقُولُونَ، وَقَامَ الْحَجَرُ فَأَخَذَ ثَوْبَهُ فَلَبِسَهُ، وَطَفِقَ بِالْحَجَرِ ضَرْبًا بِعَصَاهُ، فَوَاللَّهِ إِنَّ بِالْحَجَرِ لَنَدَبًا مِنْ أَثَرِ ضَرْبِهِ ثَلاَثًا أَوْ أَرْبَعًا أَوْ خَمْسًا، فَذَلِكَ قَوْلُهُ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَكُونُوا كَالَّذِينَ آذَوْا مُوسَى فَبَرَّأَهُ اللَّهُ مِمَّا قَالُوا وَكَانَ عِنْدَ اللَّهِ وَجِيهًا‏\}‏‏.‏‏"‏\hadithno{3404}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "(The Prophet) Moses was a shy person and used to cover his body completely because of his extensive shyness. One of the children of Israel hurt him by saying, 'He covers his body in this way only because of some defect in his skin, either leprosy or scrotal hernia, or he has some other defect.' Allah wished to clear Moses of what they said about him, so one day while Moses was in seclusion, he took off his clothes and put them on a stone and started taking a bath. When he had finished the bath, he moved towards his clothes so as to take them, but the stone took his clothes and fled; Moses picked up his stick and ran after the stone saying, 'O stone! Give me my garment!' Till he reached a group of Bani Israel who saw him naked then, and found him the best of what Allah had created, and Allah cleared him of what they had accused him of. The stone stopped there and Moses took and put his garment on and started hitting the stone with his stick. By Allah, the stone still has some traces of the hitting, three, four or five marks. This was what Allah refers to in His Saying:-- "O you who believe! Be you not like those Who annoyed Moses, But Allah proved his innocence of that which they alleged, And he was honorable In Allah's Sight}}
\hadithdefcmd{bukhari}{3405}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ ـ رضى الله عنه ـ قَالَ قَسَمَ النَّبِيُّ صلى الله عليه وسلم قَسْمًا، فَقَالَ رَجُلٌ إِنَّ هَذِهِ لَقِسْمَةٌ مَا أُرِيدَ بِهَا وَجْهُ اللَّهِ‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرْتُهُ، فَغَضِبَ حَتَّى رَأَيْتُ الْغَضَبَ فِي وَجْهِهِ، ثُمَّ قَالَ ‏ "‏ يَرْحَمُ اللَّهُ مُوسَى قَدْ أُوذِيَ بِأَكْثَرَ مِنْ هَذَا فَصَبَرَ ‏"‏‏.‏\hadithno{3405}\hadithtrans{Narrated `Abdullah:Once the Prophet (ﷺ) distributed something (among his followers. A man said, "This distribution has not been done (with justice) seeking Allah's Countenance." I went to the Prophet (ﷺ) and told him (of that). He became so angry that I saw the signs of anger on his face. Then he said, "May Allah bestow His Mercy on Moses, for he was harmed more (in a worse manner) than this; yet he endured patiently}}
\hadithdefcmd{bukhari}{3406}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَجْنِي الْكَبَاثَ، وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ عَلَيْكُمْ بِالأَسْوَدِ مِنْهُ، فَإِنَّهُ أَطْيَبُهُ ‏"‏‏.‏ قَالُوا أَكُنْتَ تَرْعَى الْغَنَمَ قَالَ ‏"‏ وَهَلْ مِنْ نَبِيٍّ إِلاَّ وَقَدْ رَعَاهَا ‏"‏‏.‏\hadithno{3406}\hadithtrans{Narrated Jabir bin `Abdullah:We were with Allah's Messenger (ﷺ) picking the fruits of the 'Arak trees, and Allah's Messenger (ﷺ) said, "Pick the black fruit, for it is the best." The companions asked, "Were you a shepherd?" He replied, "There was no prophet who was not a shepherd}}
\hadithdefcmd{bukhari}{3407}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أُرْسِلَ مَلَكُ الْمَوْتِ إِلَى مُوسَى ـ عَلَيْهِمَا السَّلاَمُ ـ فَلَمَّا جَاءَهُ صَكَّهُ، فَرَجَعَ إِلَى رَبِّهِ، فَقَالَ أَرْسَلْتَنِي إِلَى عَبْدٍ لاَ يُرِيدُ الْمَوْتَ‏.‏ قَالَ ارْجِعْ إِلَيْهِ، فَقُلْ لَهُ يَضَعُ يَدَهُ عَلَى مَتْنِ ثَوْرٍ، فَلَهُ بِمَا غَطَّتْ يَدُهُ بِكُلِّ شَعَرَةٍ سَنَةٌ‏.‏ قَالَ أَىْ رَبِّ، ثُمَّ مَاذَا قَالَ ثُمَّ الْمَوْتُ‏.‏ قَالَ فَالآنَ‏.‏ قَالَ فَسَأَلَ اللَّهَ أَنْ يُدْنِيَهُ مِنَ الأَرْضِ الْمُقَدَّسَةِ رَمْيَةً بِحَجَرٍ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ ثَمَّ لأَرَيْتُكُمْ قَبْرَهُ إِلَى جَانِبِ الطَّرِيقِ تَحْتَ الْكَثِيبِ الأَحْمَرِ ‏"‏‏.‏ قَالَ وَأَخْبَرَنَا مَعْمَرٌ عَنْ هَمَّامٍ حَدَّثَنَا أَبُو هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ‏.‏\hadithno{3407}\hadithtrans{Narrated Abu Huraira:The Angel of Death was sent to Moses when he came to Moses, Moses slapped him on the eye. The angel returned to his Lord and said, "You have sent me to a Slave who does not want to die." Allah said, "Return to him and tell him to put his hand on the back of an ox and for every hair that will come under it, he will be granted one year of life." Moses said, "O Lord! What will happen after that?" Allah replied, "Then death." Moses said, "Let it come now." Moses then requested Allah to let him die close to the Sacred Land so much so that he would be at a distance of a stone's throw from it." Abu Huraira added, "Allah's Messenger (ﷺ) said, 'If I were there, I would show you his grave below the red sand hill on the side of the road}}
\hadithdefcmd{bukhari}{3408}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ اسْتَبَّ رَجُلٌ مِنَ الْمُسْلِمِينَ وَرَجُلٌ مِنَ الْيَهُودِ‏.‏ فَقَالَ الْمُسْلِمُ وَالَّذِي اصْطَفَى مُحَمَّدًا صلى الله عليه وسلم عَلَى الْعَالَمِينَ‏.‏ فِي قَسَمٍ يُقْسِمُ بِهِ‏.‏ فَقَالَ الْيَهُودِيُّ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْعَالَمِينَ‏.‏ فَرَفَعَ الْمُسْلِمُ عِنْدَ ذَلِكَ يَدَهُ، فَلَطَمَ الْيَهُودِيَّ، فَذَهَبَ الْيَهُودِيُّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ الَّذِي كَانَ مِنْ أَمْرِهِ وَأَمْرِ الْمُسْلِمِ فَقَالَ ‏ "‏ لاَ تُخَيِّرُونِي عَلَى مُوسَى، فَإِنَّ النَّاسَ يَصْعَقُونَ فَأَكُونُ أَوَّلَ مَنْ يُفِيقُ، فَإِذَا مُوسَى بَاطِشٌ بِجَانِبِ الْعَرْشِ، فَلاَ أَدْرِي أَكَانَ فِيمَنْ صَعِقَ فَأَفَاقَ قَبْلِي أَوْ كَانَ مِمَّنِ اسْتَثْنَى اللَّهُ ‏"‏‏.‏\hadithno{3408}\hadithtrans{Narrated Abu Huraira:A Muslim and a Jew quarreled. The Muslim taking an oath, said, "By Him Who has preferred Muhammad over all people...!" The Jew said, "By Him Who has preferred Moses, over all people." The Muslim raised his hand and slapped the Jew who came to the Prophet (ﷺ) to tell him what had happened between him and the Muslim. The Prophet (ﷺ) said, "Don't give me superiority over Moses, for the people will become unconscious (on the Day of Resurrection) and I will be the first to gain consciousness to see Moses standing and holding a side of Allah's Throne. I will not know if he has been among those people who have become unconscious; and that he has gained consciousness before me, or he has been amongst those whom Allah has exempted}}
\hadithdefcmd{bukhari}{3409}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْتَجَّ آدَمُ وَمُوسَى فَقَالَ لَهُ مُوسَى أَنْتَ آدَمُ الَّذِي أَخْرَجَتْكَ خَطِيئَتُكَ مِنَ الْجَنَّةِ‏.‏ فَقَالَ لَهُ آدَمُ أَنْتَ مُوسَى الَّذِي اصْطَفَاكَ اللَّهُ بِرِسَالاَتِهِ وَبِكَلاَمِهِ، ثُمَّ تَلُومُنِي عَلَى أَمْرٍ قُدِّرَ عَلَىَّ قَبْلَ أَنْ أُخْلَقَ ‏"‏‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَحَجَّ آدَمُ مُوسَى ‏"‏ مَرَّتَيْنِ‏.‏\hadithno{3409}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Adam and Moses argued with each other. Moses said to Adam. 'You are Adam whose mistake expelled you from Paradise.' Adam said to him, 'You are Moses whom Allah selected as His Messenger and as the one to whom He spoke directly; yet you blame me for a thing which had already been written in my fate before my creation?"' Allah's Messenger (ﷺ) said twice, "So, Adam overpowered Moses}}
\hadithdefcmd{bukhari}{3410}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حُصَيْنُ بْنُ نُمَيْرٍ، عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَرَجَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم يَوْمًا قَالَ ‏ "‏ عُرِضَتْ عَلَىَّ الأُمَمُ، وَرَأَيْتُ سَوَادًا كَثِيرًا سَدَّ الأُفُقَ فَقِيلَ هَذَا مُوسَى فِي قَوْمِهِ ‏"‏‏.‏\hadithno{3410}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) once came to us and said, "All the nations were displayed in front of me, and I saw a large multitude of people covering the horizon. Somebody said, 'This is Moses and his followers}}
\hadithdefcmd{bukhari}{3411}{حَدَّثَنَا يَحْيَى بْنُ جَعْفَرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ مُرَّةَ الْهَمْدَانِيِّ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَمَلَ مِنَ الرِّجَالِ كَثِيرٌ، وَلَمْ يَكْمُلْ مِنَ النِّسَاءِ إِلاَّ آسِيَةُ امْرَأَةُ فِرْعَوْنَ، وَمَرْيَمُ بِنْتُ عِمْرَانَ، وَإِنَّ فَضْلَ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏‏.‏\hadithno{3411}\hadithtrans{Narrated Abu Musa:Allah's Messenger (ﷺ) said, "Many amongst men reached (the level of) perfection but none amongst the women reached this level except Asia, Pharaoh's wife, and Mary, the daughter of `Imran. And no doubt, the superiority of `Aisha to other women is like the superiority of Tharid (i.e. a meat and bread dish) to other meals}}
\hadithdefcmd{bukhari}{3412}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي الأَعْمَشُ،‏.‏ حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَقُولَنَّ أَحَدُكُمْ إِنِّي خَيْرٌ مِنْ يُونُسَ ‏"‏‏.‏ زَادَ مُسَدَّدٌ ‏"‏ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏\hadithno{3412}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "None of you should say that I am better than Yunus (i.e. Jonah)." Musadded added, "Jonah bin Matta}}
\hadithdefcmd{bukhari}{3413}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ إِنِّي خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏ وَنَسَبَهُ إِلَى أَبِيهِ‏.‏\hadithno{3413}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "No slave (of Allah) should say that I am better than Yunus bin Matta." So the Prophet mentioned his father's name with his name}}
\hadithdefcmd{bukhari}{3415}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، عَنِ اللَّيْثِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَمَا يَهُودِيٌّ يَعْرِضُ سِلْعَتَهُ أُعْطِيَ بِهَا شَيْئًا كَرِهَهُ‏.‏ فَقَالَ لاَ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْبَشَرِ، فَسَمِعَهُ رَجُلٌ مِنَ الأَنْصَارِ فَقَامَ، فَلَطَمَ وَجْهَهُ، وَقَالَ تَقُولُ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْبَشَرِ، وَالنَّبِيُّ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا فَذَهَبَ إِلَيْهِ، فَقَالَ أَبَا الْقَاسِمِ، إِنَّ لِي ذِمَّةً وَعَهْدًا، فَمَا بَالُ فُلاَنٍ لَطَمَ وَجْهِي‏.‏ فَقَالَ ‏"‏ لِمَ لَطَمْتَ وَجْهَهُ ‏"‏‏.‏ فَذَكَرَهُ، فَغَضِبَ النَّبِيُّ صلى الله عليه وسلم حَتَّى رُئِيَ فِي وَجْهِهِ، ثُمَّ قَالَ ‏"‏ لاَ تُفَضِّلُوا بَيْنَ أَنْبِيَاءِ اللَّهِ، فَإِنَّهُ يُنْفَخُ فِي الصُّورِ، فَيَصْعَقُ مَنْ فِي السَّمَوَاتِ وَمَنْ فِي الأَرْضِ، إِلاَّ مَنْ شَاءَ اللَّهُ، ثُمَّ يُنْفَخُ فِيهِ أُخْرَى، فَأَكُونُ أَوَّلَ مَنْ بُعِثَ فَإِذَا مُوسَى آخِذٌ بِالْعَرْشِ، فَلاَ أَدْرِي أَحُوسِبَ بِصَعْقَتِهِ يَوْمَ الطُّورِ أَمْ بُعِثَ قَبْلِي -‏ وَلَا أَقُولُ إِنَّ أَحَدًا أَفْضَلُ مِنْ يُونُسَ بْنِ مَتَّى"‏‏.‏\hadithno{3415}\hadithtrans{Narrated Abu Huraira:Once while a Jew was selling something, he was offered a price that he was not pleased with. So, he said, "No, by Him Who gave Moses superiority over all human beings!" Hearing him, an Ansari man got up and slapped him on the face and said, "You say: By Him Who Gave Moses superiority over all human beings although the Prophet (Muhammad) is present amongst us!" The Jew went to the Prophet and said, "O Abu-l-Qasim! I am under the assurance and contract of security, so what right does so-and-so have to slap me?" The Prophet (ﷺ) asked the other, "Why have you slapped". He told him the whole story. The Prophet (ﷺ) became angry, till anger appeared on his face, and said, "Don't give superiority to any prophet amongst Allah's Prophets, for when the trumpet will be blown, everyone on the earth and in the heavens will become unconscious except those whom Allah will exempt. The trumpet will be blown for the second time and I will be the first to be resurrected to see Moses holding Allah's Throne. I will not know whether the unconsciousness which Moses received on the Day of Tur has been sufficient for him, or has he got up before me. And I do not say that there is anybody who is better than Yunus bin Matta}}
\hadithdefcmd{bukhari}{3416}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، سَمِعْتُ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏\hadithno{3416}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "None should say that I am better than Yunus bin Matta}}
\hadithdefcmd{bukhari}{3417}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خُفِّفَ عَلَى دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ الْقُرْآنُ، فَكَانَ يَأْمُرُ بِدَوَابِّهِ فَتُسْرَجُ، فَيَقْرَأُ الْقُرْآنَ قَبْلَ أَنْ تُسْرَجَ دَوَابُّهُ، وَلاَ يَأْكُلُ إِلاَّ مِنْ عَمَلِ يَدِهِ ‏"‏‏.‏ رَوَاهُ مُوسَى بْنُ عُقْبَةَ عَنْ صَفْوَانَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3417}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The reciting of the Zabur (i.e. Psalms) was made easy for David. He used to order that his riding animals be saddled, and would finish reciting the Zabur before they were saddled. And he would never eat except from the earnings of his manual work}}
\hadithdefcmd{bukhari}{3418}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، أَخْبَرَهُ وَأَبَا، سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو ـ رضى الله عنهما ـ قَالَ أُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنِّي أَقُولُ وَاللَّهِ لأَصُومَنَّ النَّهَارَ وَلأَقُومَنَّ اللَّيْلَ مَا عِشْتُ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنْتَ الَّذِي تَقُولُ وَاللَّهِ لأَصُومَنَّ النَّهَارَ وَلأَقُومَنَّ اللَّيْلَ مَا عِشْتُ ‏"‏ قُلْتُ قَدْ قُلْتُهُ‏.‏ قَالَ ‏"‏ إِنَّكَ لاَ تَسْتَطِيعُ ذَلِكَ، فَصُمْ وَأَفْطِرْ، وَقُمْ وَنَمْ، وَصُمْ مِنَ الشَّهْرِ ثَلاَثَةَ أَيَّامٍ، فَإِنَّ الْحَسَنَةَ بِعَشْرِ أَمْثَالِهَا، وَذَلِكَ مِثْلُ صِيَامِ الدَّهْرِ ‏"‏‏.‏ فَقُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَصُمْ يَوْمًا وَأَفْطِرْ يَوْمَيْنِ ‏"‏‏.‏ قَالَ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ‏.‏ قَالَ ‏"‏ فَصُمْ يَوْمًا وَأَفْطِرْ يَوْمًا، وَذَلِكَ صِيَامُ دَاوُدَ، وَهْوَ عَدْلُ الصِّيَامِ ‏"‏‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْهُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ لاَ أَفْضَلَ مِنْ ذَلِكَ ‏"‏‏.‏\hadithno{3418}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) was informed that I have said: "By Allah, I will fast all the days and pray all the nights as long as I live." On that, Allah's Messenger (ﷺ) asked me, "Are you the one who says: 'I will fast all the days and pray all the nights as long as I live?' " I said, "Yes, I have said it." He said, "You cannot do that. So fast (sometimes) and do not fast (sometimes). Pray and sleep. Fast for three days a month, for the reward of a good deed is multiplied by ten times, and so the fasting of three days a month equals the fasting of a year." I said, "O Allah's Messenger (ﷺ)! I can do (fast) more than this." He said, "Fast on every third day. I said: I can do (fast) more than that, He said: "Fast on alternate days and this was the fasting of David which is the most moderate sort of fasting." I said, "O Allah's Messenger (ﷺ)! I can do (fast) more than that." He said, "There is nothing better than that}}
\hadithdefcmd{bukhari}{3419}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا مِسْعَرٌ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَمْ أُنَبَّأْ أَنَّكَ تَقُومُ اللَّيْلَ وَتَصُومُ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَقَالَ ‏"‏ فَإِنَّكَ إِذَا فَعَلْتَ ذَلِكَ هَجَمَتِ الْعَيْنُ وَنَفِهَتِ النَّفْسُ، صُمْ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ، فَذَلِكَ صَوْمُ الدَّهْرِ ـ أَوْ كَصَوْمِ الدَّهْرِ ‏"‏‏.‏ قُلْتُ إِنِّي أَجِدُ بِي ـ قَالَ مِسْعَرٌ يَعْنِي ـ قُوَّةً‏.‏ قَالَ ‏"‏ فَصُمْ صَوْمَ دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ وَكَانَ يَصُومُ يَوْمًا، وَيُفْطِرُ يَوْمًا، وَلاَ يَفِرُّ إِذَا لاَقَى ‏"‏‏.‏\hadithno{3419}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-As:The Prophet (ﷺ) said to me, "I have been informed that you pray all the nights and observe fast all the days; is this true?" I replied, "Yes." He said, "If you do so, your eyes will become weak and you will get bored. So fast three days a month, for this will be the fasting of a whole year, or equal to the fasting of a whole year." I said, "I find myself able to fast more." He said, "Then fast like the fasting of (the Prophet) David who used to fast on alternate days and would not flee on facing the enemy}}
\hadithdefcmd{bukhari}{3420}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ أَوْسٍ الثَّقَفِيِّ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحَبُّ الصِّيَامِ إِلَى اللَّهِ صِيَامُ دَاوُدَ، كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا، وَأَحَبُّ الصَّلاَةِ إِلَى اللَّهِ صَلاَةُ دَاوُدَ، كَانَ يَنَامُ نِصْفَ اللَّيْلِ وَيَقُومُ ثُلُثَهُ وَيَنَامُ سُدُسَهُ ‏"‏‏.‏\hadithno{3420}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) said to me, "The most beloved fasting to Allah was the fasting of (the Prophet) David who used to fast on alternate days. And the most beloved prayer to Allah was the prayer of David who used to sleep for (the first) half of the night and pray for 1/3 of it and (again) sleep for a sixth of it}}
\hadithdefcmd{bukhari}{3421}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا سَهْلُ بْنُ يُوسُفَ، قَالَ سَمِعْتُ الْعَوَّامَ، عَنْ مُجَاهِدٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ أَسْجُدُ فِي ‏\{‏ص‏\}‏ فَقَرَأَ ‏\{‏وَمِنْ ذُرِّيَّتِهِ دَاوُدَ وَسُلَيْمَانَ‏\}‏ حَتَّى أَتَى ‏\{‏فَبِهُدَاهُمُ اقْتَدِهْ‏\}‏ فَقَالَ نَبِيُّكُمْ صلى الله عليه وسلم مِمَّنْ أُمِرَ أَنْ يَقْتَدِيَ بِهِمْ‏.‏\hadithno{3421}\hadithtrans{Narrated Mujahid:I asked Ibn `Abbas, "Should we perform a prostration on reciting Surat-Sa`d?" He recited (the Sura) including: 'And among his progeny, David, Solomon..(up to)...so follow their guidance (6.84-91) And then he said, "Your Prophet is amongst those people who have been ordered to follow them (i.e. the preceding apostles)}}
\hadithdefcmd{bukhari}{3422}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَيْسَ ‏\{‏ص‏\}‏ مِنْ عَزَائِمِ السُّجُودِ، وَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْجُدُ فِيهَا‏.‏\hadithno{3422}\hadithtrans{Narrated Ibn `Abbas:The prostration in Sura-Sa`d is not amongst the compulsory prostrations, though I saw the Prophet (ﷺ) prostrating on reciting it}}
\hadithdefcmd{bukhari}{3423}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ إِنَّ عِفْرِيتًا مِنَ الْجِنِّ تَفَلَّتَ الْبَارِحَةَ لِيَقْطَعَ عَلَىَّ صَلاَتِي، فَأَمْكَنَنِي اللَّهُ مِنْهُ، فَأَخَذْتُهُ، فَأَرَدْتُ أَنْ أَرْبُطَهُ عَلَى سَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ حَتَّى تَنْظُرُوا إِلَيْهِ كُلُّكُمْ فَذَكَرْتُ دَعْوَةَ أَخِي سُلَيْمَانَ رَبِّ هَبْ لِي مُلْكًا لاَ يَنْبَغِي لأَحَدٍ مِنْ بَعْدِي‏.‏ فَرَدَدْتُهُ خَاسِئًا ‏"‏‏.‏ عِفْرِيتٌ مُتَمَرِّدٌ مِنْ إِنْسٍ أَوْ جَانٍّ، مِثْلُ زِبْنِيَةٍ جَمَاعَتُهَا الزَّبَانِيَةُ‏.‏\hadithno{3423}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A strong demon from the Jinns came to me yesterday suddenly, so as to spoil my prayer, but Allah enabled me to overpower him, and so I caught him and intended to tie him to one of the pillars of the Mosque so that all of you might see him, but I remembered the invocation of my brother Solomon: 'And grant me a kingdom such as shall not belong to any other after me.' (38.35) so I let him go cursed}}
\hadithdefcmd{bukhari}{3424}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا مُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ لأَطُوفَنَّ اللَّيْلَةَ عَلَى سَبْعِينَ امْرَأَةً تَحْمِلُ كُلُّ امْرَأَةٍ فَارِسًا يُجَاهِدُ فِي سَبِيلِ اللَّهِ، فَقَالَ لَهُ صَاحِبُهُ إِنْ شَاءَ اللَّهُ‏.‏ فَلَمْ يَقُلْ، وَلَمْ تَحْمِلْ شَيْئًا إِلاَّ وَاحِدًا سَاقِطًا إِحْدَى شِقَّيْهِ ‏"‏‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ قَالَهَا لَجَاهَدُوا فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ قَالَ شُعَيْبٌ وَابْنُ أَبِي الزِّنَادِ ‏"‏ تِسْعِينَ ‏"‏‏.‏ وَهْوَ أَصَحُّ‏.‏\hadithno{3424}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Solomon (the son of) David said, 'Tonight I will sleep with seventy ladies each of whom will conceive a child who will be a knight fighting for "Allah's Cause.' His companion said, 'If Allah will.' But Solomon did not say so; therefore none of those women got pregnant except one who gave birth to a half child." The Prophet (ﷺ) further said, "If the Prophet Solomon (ﷺ) had said it (i.e. 'If Allah will') he would have begotten children who would have fought in Allah's Cause." Shuaib and Ibn Abi Az-Zinad said, "Ninety (women) is more correct (than seventy)}}
\hadithdefcmd{bukhari}{3425}{حَدَّثَنِي عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا إِبْرَاهِيمُ التَّيْمِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ أَىُّ مَسْجِدٍ وُضِعَ أَوَّلُ قَالَ ‏"‏ الْمَسْجِدُ الْحَرَامُ ‏"‏‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ ثُمَّ الْمَسْجِدُ الأَقْصَى ‏"‏‏.‏ قُلْتُ كَمْ كَانَ بَيْنَهُمَا قَالَ ‏"‏ أَرْبَعُونَ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ حَيْثُمَا أَدْرَكَتْكَ الصَّلاَةُ فَصَلِّ، وَالأَرْضُ لَكَ مَسْجِدٌ ‏"‏‏.‏\hadithno{3425}\hadithtrans{Narrated Abu Dharr:I said, "O Allah's Messenger (ﷺ)! Which mosque was built first?" He replied, "Al-Masjid-ul-Haram." I asked, "Which (was built) next?" He replied, "Al-Masjid-ul-Aqsa (i.e. Jerusalem)." I asked, "What was the period in between them?" He replied, "Forty (years)." He then added, "Wherever the time for the prayer comes upon you, perform the prayer, for all the earth is a place of worshipping for you}}
\hadithdefcmd{bukhari}{3427}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَثَلِي وَمَثَلُ النَّاسِ كَمَثَلِ رَجُلٍ اسْتَوْقَدَ نَارًا، فَجَعَلَ الْفَرَاشُ وَهَذِهِ الدَّوَابُّ تَقَعُ فِي النَّارِ ‏"‏‏.‏ وَقَالَ ‏"‏ كَانَتِ امْرَأَتَانِ مَعَهُمَا ابْنَاهُمَا جَاءَ الذِّئْبُ فَذَهَبَ بِابْنِ إِحْدَاهُمَا، فَقَالَتْ صَاحِبَتُهَا إِنَّمَا ذَهَبَ بِابْنِكِ‏.‏ وَقَالَتِ الأُخْرَى إِنَّمَا ذَهَبَ بِابْنِكِ‏.‏ فَتَحَاكَمَتَا إِلَى دَاوُدَ، فَقَضَى بِهِ لِلْكُبْرَى فَخَرَجَتَا عَلَى سُلَيْمَانَ بْنِ دَاوُدَ فَأَخْبَرَتَاهُ‏.‏ فَقَالَ ائْتُونِي بِالسِّكِّينِ أَشُقُّهُ بَيْنَهُمَا‏.‏ فَقَالَتِ الصُّغْرَى لاَ تَفْعَلْ يَرْحَمُكَ اللَّهُ، هُوَ ابْنُهَا‏.‏ فَقَضَى بِهِ لِلصُّغْرَى ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ وَاللَّهِ إِنْ سَمِعْتُ بِالسِّكِّينِ إِلاَّ يَوْمَئِذٍ، وَمَا كُنَّا نَقُولُ إِلاَّ الْمُدْيَةُ‏.‏\hadithno{3427}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "My example and the example of the people is like that of a person who lit a fire and let the moths, butterflies and these insects fall in it." He also said, "There were two women, each of whom had a child with her. A wolf came and took away the child of one of them, whereupon the other said, 'It has taken your child.' The first said, 'But it has taken your child.' So they both carried the case before David who judged that the living child be given to the elder lady. So both of them went to Solomon bin David and informed him (of the case). He said, 'Bring me a knife so as to cut the child into two pieces and distribute it between them.' The younger lady said, 'May Allah be merciful to you! Don't do that, for it is her (i.e. the other lady's) child.' So he gave the child to the younger lady}}
\hadithdefcmd{bukhari}{3428}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَمَّا نَزَلَتِ ‏\{‏الَّذِينَ آمَنُوا وَلَمْ يَلْبِسُوا إِيمَانَهُمْ بِظُلْمٍ‏\}‏ قَالَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم أَيُّنَا لَمْ يَلْبِسْ إِيمَانَهُ بِظُلْمٍ فَنَزَلَتْ ‏\{‏لاَ تُشْرِكْ بِاللَّهِ إِنَّ الشِّرْكَ لَظُلْمٌ عَظِيمٌ ‏\}‏\hadithno{3428}\hadithtrans{Narrated `Abdullah:When the Verse:-- 'Those who believe and mix not their belief with wrong." was revealed, the companions of the Prophet (ﷺ) said, "Who amongst us has not mixed his belief with wrong?" Then Allah revealed: "Join none in worship with Allah, Verily joining others in worship with Allah is a great wrong indeed}}
\hadithdefcmd{bukhari}{3429}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتِ ‏\{‏الَّذِينَ آمَنُوا وَلَمْ يَلْبِسُوا إِيمَانَهُمْ بِظُلْمٍ‏\}‏ شَقَّ ذَلِكَ عَلَى الْمُسْلِمِينَ، فَقَالُوا يَا رَسُولَ اللَّهِ، أَيُّنَا لاَ يَظْلِمُ نَفْسَهُ قَالَ ‏"‏ لَيْسَ ذَلِكَ، إِنَّمَا هُوَ الشِّرْكُ، أَلَمْ تَسْمَعُوا مَا قَالَ لُقْمَانُ لاِبْنِهِ وَهْوَ يَعِظُهُ ‏\{‏يَا بُنَىَّ لاَ تُشْرِكْ بِاللَّهِ إِنَّ الشِّرْكَ لَظُلْمٌ عَظِيمٌ ‏\}‏‏"‏‏.‏\hadithno{3429}\hadithtrans{Narrated `Abdullah:When the Verse:-- 'Those who believe and mix not their belief with wrong.' was revealed, the Muslims felt it very hard on them and said, "O Allah's Messenger (ﷺ)! Who amongst us does not do wrong to himself?" He replied, "The Verse does not mean this. But that (wrong) means to associate others in worship to Allah: Don't you listen to what Luqman said to his son when he was advising him," O my son! Join not others in worship with Allah. Verily joining others in worship with Allah is a great wrong indeed}}
\hadithdefcmd{bukhari}{3430}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ مَالِكِ بْنِ صَعْصَعَةَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم حَدَّثَهُمْ عَنْ لَيْلَةَ أُسْرِيَ ‏ "‏ ثُمَّ صَعِدَ حَتَّى أَتَى السَّمَاءَ الثَّانِيَةَ فَاسْتَفْتَحَ، قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ وَمَنْ مَعَكَ قَالَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ فَلَمَّا خَلَصْتُ، فَإِذَا يَحْيَى وَعِيسَى وَهُمَا ابْنَا خَالَةٍ‏.‏ قَالَ هَذَا يَحْيَى وَعِيسَى فَسَلِّمْ عَلَيْهِمَا‏.‏ فَسَلَّمْتُ فَرَدَّا ثُمَّ قَالاَ مَرْحَبًا بِالأَخِ الصَّالِحِ وَالنَّبِيِّ الصَّالِحِ ‏"‏‏.‏\hadithno{3430}\hadithtrans{Narrated Malik bin Sasaa:That the Prophet (ﷺ) talked to them about the night of his Ascension to the Heavens. He said, "(Then Gabriel took me) and ascended up till he reached the second heaven where he asked for the gate to be opened, but it was asked, 'Who is it?' Gabriel replied, 'I am Gabriel.' It was asked, 'Who is accompanying you?' He replied, 'Muhammad.' It was asked, 'Has he been called?' He said, 'Yes.' When we reached over the second heaven, I saw Yahya (i.e. John) and Jesus who were cousins. Gabriel said, 'These are John (Yahya) and Jesus, so greet them.' I greeted them and they returned the greeting saying, 'Welcome, O Pious Brother and Pious Prophet!;}}
\hadithdefcmd{bukhari}{3431}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، قَالَ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ بَنِي آدَمَ مَوْلُودٌ إِلاَّ يَمَسُّهُ الشَّيْطَانُ حِينَ يُولَدُ، فَيَسْتَهِلُّ صَارِخًا مِنْ مَسِّ الشَّيْطَانِ، غَيْرَ مَرْيَمَ وَابْنِهَا ‏"‏‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ ‏\{‏وَإِنِّي أُعِيذُهَا بِكَ وَذُرِّيَّتَهَا مِنَ الشَّيْطَانِ الرَّجِيمِ ‏\}‏‏.‏\hadithno{3431}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:Abu Huraira said, "I heard Allah's Messenger (ﷺ) saying, 'There is none born among the off-spring of Adam, but Satan touches it. A child therefore, cries loudly at the time of birth because of the touch of Satan, except Mary and her child." Then Abu Huraira recited: "And I seek refuge with You for her and for her offspring from the outcast Satan}}
\hadithdefcmd{bukhari}{3432}{حَدَّثَنِي أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا النَّضْرُ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي قَالَ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ جَعْفَرٍ، قَالَ سَمِعْتُ عَلِيًّا ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ نِسَائِهَا مَرْيَمُ ابْنَةُ عِمْرَانَ، وَخَيْرُ نِسَائِهَا خَدِيجَةُ ‏"‏‏.‏\hadithno{3432}\hadithtrans{Narrated `Ali:I heard the Prophet (ﷺ) saying, "Mary, the daughter of `Imran, was the best among the women (of the world of her time) and Khadija is the best amongst the women. (of this nation)}}
\hadithdefcmd{bukhari}{3433}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ مُرَّةَ الْهَمْدَانِيَّ، يُحَدِّثُ عَنْ أَبِي مُوسَى الأَشْعَرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ فَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ، كَمَلَ مِنَ الرِّجَالِ كَثِيرٌ، وَلَمْ يَكْمُلْ مِنَ النِّسَاءِ إِلاَّ مَرْيَمُ بِنْتُ عِمْرَانَ وَآسِيَةُ امْرَأَةُ فِرْعَوْنَ ‏"‏‏.‏\hadithno{3433}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) said, "The superiority of `Aisha to other ladies is like the superiority of Tharid (i.e. meat and bread dish) to other meals. Many men reached the level of perfection, but no woman reached such a level except Mary, the daughter of `Imran and Asia, the wife of Pharaoh}}
\hadithdefcmd{bukhari}{3434}{وَقَالَ ابْنُ وَهْبٍ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نِسَاءُ قُرَيْشٍ خَيْرُ نِسَاءٍ رَكِبْنَ الإِبِلَ، أَحْنَاهُ عَلَى طِفْلٍ، وَأَرْعَاهُ عَلَى زَوْجٍ فِي ذَاتِ يَدِهِ ‏"‏‏.‏ يَقُولُ أَبُو هُرَيْرَةَ عَلَى إِثْرِ ذَلِكَ وَلَمْ تَرْكَبْ مَرْيَمُ بِنْتُ عِمْرَانَ بَعِيرًا قَطُّ‏.‏ تَابَعَهُ ابْنُ أَخِي الزُّهْرِيِّ وَإِسْحَاقُ الْكَلْبِيُّ عَنِ الزُّهْرِيِّ‏.‏\hadithno{3434}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "Amongst all those women who ride camels (i.e. Arabs), the ladies of Quraish are the best. They are merciful and kind to their off-spring and the best guardians of their husbands' properties.' Abu Huraira added, "Mary the daughter of `Imran never rode a camel}}
\hadithdefcmd{bukhari}{3435}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي عُمَيْرُ بْنُ هَانِئٍ، قَالَ حَدَّثَنِي جُنَادَةُ بْنُ أَبِي أُمَيَّةَ، عَنْ عُبَادَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ شَهِدَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ، وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ، وَأَنَّ عِيسَى عَبْدُ اللَّهِ وَرَسُولُهُ وَكَلِمَتُهُ، أَلْقَاهَا إِلَى مَرْيَمَ، وَرُوحٌ مِنْهُ، وَالْجَنَّةُ حَقٌّ وَالنَّارُ حَقٌّ، أَدْخَلَهُ اللَّهُ الْجَنَّةَ عَلَى مَا كَانَ مِنَ الْعَمَلِ ‏"‏‏.‏ قَالَ الْوَلِيدُ حَدَّثَنِي ابْنُ جَابِرٍ عَنْ عُمَيْرٍ عَنْ جُنَادَةَ وَزَادَ ‏"‏ مِنْ أَبْوَابِ الْجَنَّةِ الثَّمَانِيَةِ، أَيَّهَا شَاءَ ‏"‏‏.‏\hadithno{3435}\hadithtrans{Narrated 'Ubada:The Prophet (ﷺ) said, "If anyone testifies that None has the right to be worshipped but Allah Alone Who has no partners, and that Muhammad is His Slave and His Apostle, and that Jesus is Allah's Slave and His Apostle and His Word which He bestowed on Mary and a Spirit created by Him, and that Paradise is true, and Hell is true, Allah will admit him into Paradise with the deeds which he had done even if those deeds were few." (Junada, the sub-narrator said, " 'Ubada added, 'Such a person can enter Paradise through any of its eight gates he likes)}}
\hadithdefcmd{bukhari}{3436}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَمْ يَتَكَلَّمْ فِي الْمَهْدِ إِلاَّ ثَلاَثَةٌ عِيسَى، وَكَانَ فِي بَنِي إِسْرَائِيلَ رَجُلٌ يُقَالُ لَهُ جُرَيْجٌ، كَانَ يُصَلِّي، فَجَاءَتْهُ أُمُّهُ فَدَعَتْهُ، فَقَالَ أُجِيبُهَا أَوْ أُصَلِّي‏.‏ فَقَالَتِ اللَّهُمَّ لاَ تُمِتْهُ حَتَّى تُرِيَهُ وُجُوهَ الْمُومِسَاتِ‏.‏ وَكَانَ جُرَيْجٌ فِي صَوْمَعَتِهِ، فَتَعَرَّضَتْ لَهُ امْرَأَةٌ وَكَلَّمَتْهُ فَأَبَى، فَأَتَتْ رَاعِيًا، فَأَمْكَنَتْهُ مِنْ نَفْسِهَا فَوَلَدَتْ غُلاَمًا، فَقَالَتْ مِنْ جُرَيْجٍ‏.‏ فَأَتَوْهُ فَكَسَرُوا صَوْمَعَتَهُ، وَأَنْزَلُوهُ وَسَبُّوهُ، فَتَوَضَّأَ وَصَلَّى ثُمَّ أَتَى الْغُلاَمَ فَقَالَ مَنْ أَبُوكَ يَا غُلاَمُ قَالَ الرَّاعِي‏.‏ قَالُوا نَبْنِي صَوْمَعَتَكَ مِنْ ذَهَبٍ‏.‏ قَالَ لاَ إِلاَّ مِنْ طِينٍ‏.‏ وَكَانَتِ امْرَأَةٌ تُرْضِعُ ابْنًا لَهَا مِنْ بَنِي إِسْرَائِيلَ، فَمَرَّ بِهَا رَجُلٌ رَاكِبٌ ذُو شَارَةٍ، فَقَالَتِ اللَّهُمَّ اجْعَلِ ابْنِي مِثْلَهُ‏.‏ فَتَرَكَ ثَدْيَهَا، وَأَقْبَلَ عَلَى الرَّاكِبِ فَقَالَ اللَّهُمَّ لاَ تَجْعَلْنِي مِثْلَهُ‏.‏ ثُمَّ أَقْبَلَ عَلَى ثَدْيِهَا يَمَصُّهُ ـ قَالَ أَبُو هُرَيْرَةَ كَأَنِّي أَنْظُرُ إِلَى النَّبِيِّ صلى الله عليه وسلم يَمَصُّ إِصْبَعَهُ ـ ثُمَّ مُرَّ بِأَمَةٍ فَقَالَتِ اللَّهُمَّ لاَ تَجْعَلِ ابْنِي مِثْلَ هَذِهِ‏.‏ فَتَرَكَ ثَدْيَهَا فَقَالَ اللَّهُمَّ اجْعَلْنِي مِثْلَهَا‏.‏ فَقَالَتْ لِمَ ذَاكَ فَقَالَ الرَّاكِبُ جَبَّارٌ مِنَ الْجَبَابِرَةِ، وَهَذِهِ الأَمَةُ يَقُولُونَ سَرَقْتِ زَنَيْتِ‏.‏ وَلَمْ تَفْعَلْ ‏"‏‏.‏\hadithno{3436}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "None spoke in cradle but three: (The first was) Jesus, (the second was), there was a man from Bani Israel called Juraij. While he was offering his prayers, his mother came and called him. He said (to himself), 'Shall I answer her or keep on praying?" (He went on praying) and did not answer her. His mother said, "O Allah! Do not let him die till he sees the faces of prostitutes." So while he was in his hermitage, a lady came and sought to seduce him, but he refused. So she went to a shepherd and presented herself to him to commit illegal sexual intercourse with her and then later she gave birth to a child and claimed that it belonged to Juraij. The people, therefore, came to him and dismantled his hermitage and expelled him out of it and abused him. Juraij performed the ablution and offered prayer, and then came to the child and said, 'O child! Who is your father?' The child replied, 'The shepherd.' (After hearing this) the people said, 'We shall rebuild your hermitage of gold,' but he said, 'No, of nothing but mud.'(The third was the hero of the following story) A lady from Bani Israel was nursing her child at her breast when a handsome rider passed by her. She said, 'O Allah ! Make my child like him.' On that the child left her breast, and facing the rider said, 'O Allah! Do not make me like him.' The child then started to suck her breast again. (Abu Huraira further said, "As if I were now looking at the Prophet (ﷺ) sucking his finger (in way of demonstration.") After a while the people passed by, with a lady slave and she (i.e. the child's mother) said, 'O Allah! Do not make my child like this (slave girl)!, On that the child left her breast and said, 'O Allah! Make me like her.' When she asked why, the child replied, 'The rider is one of the tyrants while this slave girl is falsely accused of theft and illegal sexual intercourse}}
\hadithdefcmd{bukhari}{3437}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ،‏.‏ حَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْلَةَ أُسْرِيَ بِهِ لَقِيتُ مُوسَى ـ قَالَ فَنَعَتَهُ ـ فَإِذَا رَجُلٌ ـ حَسِبْتُهُ قَالَ ـ مُضْطَرِبٌ رَجِلُ الرَّأْسِ، كَأَنَّهُ مِنْ رِجَالِ شَنُوءَةَ ـ قَالَ ـ وَلَقِيتُ عِيسَى ـ فَنَعَتَهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ـ رَبْعَةٌ أَحْمَرُ كَأَنَّمَا خَرَجَ مِنْ دِيمَاسٍ ـ يَعْنِي الْحَمَّامَ ـ وَرَأَيْتُ إِبْرَاهِيمَ، وَأَنَا أَشْبَهُ وَلَدِهِ بِهِ ـ قَالَ ـ وَأُتِيتُ بِإِنَاءَيْنِ أَحَدُهُمَا لَبَنٌ وَالآخَرُ فِيهِ خَمْرٌ، فَقِيلَ لِي خُذْ أَيَّهُمَا شِئْتَ‏.‏ فَأَخَذْتُ اللَّبَنَ فَشَرِبْتُهُ، فَقِيلَ لِي هُدِيتَ الْفِطْرَةَ، أَوْ أَصَبْتَ الْفِطْرَةَ، أَمَا إِنَّكَ لَوْ أَخَذْتَ الْخَمْرَ غَوَتْ أُمَّتُكَ ‏"‏‏.‏\hadithno{3437}\hadithtrans{Narrated Hisham:From Ma`mar as below. Narrated Abu Huraira: The Prophet (ﷺ) said, "I met Moses on the night of my Ascension to heaven." The Prophet (ﷺ) then described him saying, as I think, "He was a tall person with lank hair as if he belonged to the people of the tribe of Shanuah.' The Prophet (ﷺ) further said, "I met Jesus." The Prophet (ﷺ) described him saying, "He was one of moderate height and was red-faced as if he had just come out of a bathroom. I saw Abraham whom I resembled more than any of his children did." The Prophet (ﷺ) further said, "(That night) I was given two cups; one full of milk and the other full of wine. I was asked to take either of them which I liked, and I took the milk and drank it. On that it was said to me, 'You have taken the right path (religion). If you had taken the wine, your (Muslim) nation would have gone astray}}
\hadithdefcmd{bukhari}{3438}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا إِسْرَائِيلُ، أَخْبَرَنَا عُثْمَانُ بْنُ الْمُغِيرَةِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ عِيسَى وَمُوسَى وَإِبْرَاهِيمَ، فَأَمَّا عِيسَى فَأَحْمَرُ جَعْدٌ عَرِيضُ الصَّدْرِ، وَأَمَّا مُوسَى فَآدَمُ جَسِيمٌ سَبْطٌ كَأَنَّهُ مِنْ رِجَالِ الزُّطِّ ‏"‏‏.‏\hadithno{3438}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "I saw Moses, Jesus and Abraham (on the night of my Ascension to the heavens). Jesus was of red complexion, curly hair and a broad chest. Moses was of brown complexion, straight hair and tall stature as if he was from the people of Az-Zutt}}
\hadithdefcmd{bukhari}{3440}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى، عَنْ نَافِعٍ، قَالَ عَبْدُ اللَّهِ ذَكَرَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا بَيْنَ ظَهْرَىِ النَّاسِ الْمَسِيحَ الدَّجَّالَ، فَقَالَ ‏"‏ إِنَّ اللَّهَ لَيْسَ بِأَعْوَرَ، أَلاَ إِنَّ الْمَسِيحَ الدَّجَّالَ أَعْوَرُ الْعَيْنِ الْيُمْنَى، كَأَنَّ عَيْنَهُ عِنَبَةٌ طَافِيَةٌ ‏"‏‏.‏ ‏"‏ وَأَرَانِي اللَّيْلَةَ عِنْدَ الْكَعْبَةِ فِي الْمَنَامِ، فَإِذَا رَجُلٌ آدَمُ كَأَحْسَنِ مَا يُرَى مِنْ أُدْمِ الرِّجَالِ، تَضْرِبُ لِمَّتُهُ بَيْنَ مَنْكِبَيْهِ، رَجِلُ الشَّعَرِ، يَقْطُرُ رَأْسُهُ مَاءً، وَاضِعًا يَدَيْهِ عَلَى مَنْكِبَىْ رَجُلَيْنِ وَهْوَ يَطُوفُ بِالْبَيْتِ‏.‏ فَقُلْتُ مَنْ هَذَا فَقَالُوا هَذَا الْمَسِيحُ ابْنُ مَرْيَمَ‏.‏ ثُمَّ رَأَيْتُ رَجُلاً وَرَاءَهُ جَعْدًا قَطَطًا أَعْوَرَ عَيْنِ الْيُمْنَى كَأَشْبَهِ مَنْ رَأَيْتُ بِابْنِ قَطَنٍ، وَاضِعًا يَدَيْهِ عَلَى مَنْكِبَىْ رَجُلٍ، يَطُوفُ بِالْبَيْتِ، فَقُلْتُ مَنْ هَذَا قَالُوا الْمَسِيحُ الدَّجَّالُ ‏"‏‏.‏ تَابَعَهُ عُبَيْدُ اللَّهِ عَنْ نَافِعٍ‏.‏\hadithno{3440}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) mentioned the Masih Ad-Dajjal in front of the people saying, Allah is not one-eyed while Masih Ad-Dajjal is blind in the right eye and his eye looks like a bulging out grape. While sleeping near the Ka`ba last night, I saw in my dream a man of brown color the best one can see amongst brown color and his hair was long that it fell between his shoulders. His hair was lank and water was dribbling from his head and he was placing his hands on the shoulders of two men while circumambulating the Ka`ba. I asked, 'Who is this?' They replied, 'This is Jesus, son of Mary.' Behind him I saw a man who had very curly hair and was blind in the right eye, resembling Ibn Qatan (i.e. an infidel) in appearance. He was placing his hands on the shoulders of a person while performing Tawaf around the Ka`ba. I asked, 'Who is this? 'They replied, 'The Masih, Ad-Dajjal}}
\hadithdefcmd{bukhari}{3441}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَكِّيُّ، قَالَ سَمِعْتُ إِبْرَاهِيمَ بْنَ سَعْدٍ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ،، قَالَ لاَ وَاللَّهِ مَا قَالَ النَّبِيُّ صلى الله عليه وسلم لِعِيسَى أَحْمَرُ، وَلَكِنْ قَالَ ‏ "‏ بَيْنَمَا أَنَا نَائِمٌ أَطُوفُ بِالْكَعْبَةِ، فَإِذَا رَجُلٌ آدَمُ سَبْطُ الشَّعَرِ، يُهَادَى بَيْنَ رَجُلَيْنِ، يَنْطِفُ رَأْسُهُ مَاءً أَوْ يُهَرَاقُ رَأْسُهُ مَاءً فَقُلْتُ مَنْ هَذَا قَالُوا ابْنُ مَرْيَمَ، فَذَهَبْتُ أَلْتَفِتُ، فَإِذَا رَجُلٌ أَحْمَرُ جَسِيمٌ، جَعْدُ الرَّأْسِ، أَعْوَرُ عَيْنِهِ الْيُمْنَى، كَأَنَّ عَيْنَهُ عِنَبَةٌ طَافِيَةٌ‏.‏ قُلْتُ مَنْ هَذَا قَالُوا هَذَا الدَّجَّالُ‏.‏ وَأَقْرَبُ النَّاسِ بِهِ شَبَهًا ابْنُ قَطَنٍ ‏"‏‏.‏ قَالَ الزُّهْرِيُّ رَجُلٌ مِنْ خُزَاعَةَ هَلَكَ فِي الْجَاهِلِيَّةِ‏.‏\hadithno{3441}\hadithtrans{Narrated Salim from his father:No, By Allah, the Prophet (ﷺ) did not tell that Jesus was of red complexion but said, "While I was asleep circumambulating the Ka`ba (in my dream), suddenly I saw a man of brown complexion and lank hair walking between two men, and water was dropping from his head. I asked, 'Who is this?' The people said, 'He is the son of Mary.' Then I looked behind and I saw a red-complexioned, fat, curly-haired man, blind in the right eye which looked like a bulging out grape. I asked, 'Who is this?' They replied, 'He is Ad-Dajjal.' The one who resembled to him among the people was Ibn Qatan." (Az-Zuhri said, "He (i.e. Ibn Qatan) was a man from the tribe Khuza`a who died in the pre-Islamic period}}
\hadithdefcmd{bukhari}{3442}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عَنْهُ ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا أَوْلَى النَّاسِ بِابْنِ مَرْيَمَ، وَالأَنْبِيَاءُ أَوْلاَدُ عَلاَّتٍ، لَيْسَ بَيْنِي وَبَيْنَهُ نَبِيٌّ ‏"‏‏.‏\hadithno{3442}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "I am the nearest of all the people to the son of Mary, and all the prophets are paternal brothers, and there has been no prophet between me and him (i.e. Jesus)}}
\hadithdefcmd{bukhari}{3443}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هِلاَلُ بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا أَوْلَى النَّاسِ بِعِيسَى ابْنِ مَرْيَمَ فِي الدُّنْيَا وَالآخِرَةِ، وَالأَنْبِيَاءُ إِخْوَةٌ لِعَلاَّتٍ، أُمَّهَاتُهُمْ شَتَّى، وَدِينُهُمْ وَاحِدٌ ‏"‏‏.‏ وَقَالَ إِبْرَاهِيمُ بْنُ طَهْمَانَ عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3443}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Both in this world and in the Hereafter, I am the nearest of all the people to Jesus, the son of Mary. The prophets are paternal brothers; their mothers are different, but their religion is one}}
\hadithdefcmd{bukhari}{3444}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رَأَى عِيسَى ابْنُ مَرْيَمَ رَجُلاً يَسْرِقُ، فَقَالَ لَهُ أَسَرَقْتَ قَالَ كَلاَّ وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ‏.‏ فَقَالَ عِيسَى آمَنْتُ بِاللَّهِ وَكَذَّبْتُ عَيْنِي ‏"‏‏.‏\hadithno{3444}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Jesus, seeing a man stealing, asked him, 'Did you steal?, He said, 'No, by Allah, besides Whom there is none who has the right to be worshipped' Jesus said, 'I believe in Allah and suspect my eyes}}
\hadithdefcmd{bukhari}{3445}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، يَقُولُ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، سَمِعَ عُمَرَ ـ رضى الله عنه ـ يَقُولُ عَلَى الْمِنْبَرِ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُطْرُونِي كَمَا أَطْرَتِ النَّصَارَى ابْنَ مَرْيَمَ، فَإِنَّمَا أَنَا عَبْدُهُ، فَقُولُوا عَبْدُ اللَّهِ وَرَسُولُهُ ‏"‏‏.‏\hadithno{3445}\hadithtrans{Narrated `Umar:I heard the Prophet (ﷺ) saying, "Do not exaggerate in praising me as the Christians praised the son of Mary, for I am only a Slave. So, call me the Slave of Allah and His Apostle}}
\hadithdefcmd{bukhari}{3446}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا صَالِحُ بْنُ حَىٍّ، أَنَّ رَجُلاً، مِنْ أَهْلِ خُرَاسَانَ قَالَ لِلشَّعْبِيِّ‏.‏ فَقَالَ الشَّعْبِيُّ أَخْبَرَنِي أَبُو بُرْدَةَ عَنْ أَبِي مُوسَى الأَشْعَرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَدَّبَ الرَّجُلُ أَمَتَهُ فَأَحْسَنَ تَأْدِيبَهَا، وَعَلَّمَهَا فَأَحْسَنَ تَعْلِيمَهَا ثُمَّ أَعْتَقَهَا فَتَزَوَّجَهَا، كَانَ لَهُ أَجْرَانِ، وَإِذَا آمَنَ بِعِيسَى ثُمَّ آمَنَ بِي، فَلَهُ أَجْرَانِ، وَالْعَبْدُ إِذَا اتَّقَى رَبَّهُ وَأَطَاعَ مَوَالِيَهُ، فَلَهُ أَجْرَانِ ‏"‏‏.‏\hadithno{3446}\hadithtrans{Narrated Abu Musa Al-Ash`ari:Allah's Messenger (ﷺ) said, "If a person teaches his slave girl good manners properly, educates her properly, and then manumits and marries her, he will get a double reward. And if a man believes in Jesus and then believes in me, he will get a double reward. And if a slave fears his Lord (i.e. Allah) and obeys his masters, he too will get a double reward}}
\hadithdefcmd{bukhari}{3447}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تُحْشَرُونَ حُفَاةً عُرَاةً غُرْلاً، ثُمَّ قَرَأَ ‏\{‏كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ وَعْدًا عَلَيْنَا إِنَّا كُنَّا فَاعِلِينَ‏\}‏ فَأَوَّلُ مَنْ يُكْسَى إِبْرَاهِيمُ، ثُمَّ يُؤْخَذُ بِرِجَالٍ مِنْ أَصْحَابِي ذَاتَ الْيَمِينِ وَذَاتَ الشِّمَالِ فَأَقُولُ أَصْحَابِي فَيُقَالُ إِنَّهُمْ لَمْ يَزَالُوا مُرْتَدِّينَ عَلَى أَعْقَابِهِمْ مُنْذُ فَارَقْتَهُمْ، فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُ عِيسَى ابْنُ مَرْيَمَ ‏\{‏وَكُنْتُ عَلَيْهِمْ شَهِيدًا مَا دُمْتُ فِيهِمْ فَلَمَّا تَوَفَّيْتَنِي كُنْتَ أَنْتَ الرَّقِيبَ عَلَيْهِمْ وَأَنْتَ عَلَى كُلِّ شَىْءٍ شَهِيدٌ‏\}‏ إِلَى قَوْلِهِ ‏\{‏الْعَزِيزُ الْحَكِيمُ‏\}‏‏"‏‏.‏ قَالَ مُحَمَّدُ بْنُ يُوسُفَ ذُكِرَ عَنْ أَبِي عَبْدِ اللَّهِ عَنْ قَبِيصَةَ قَالَ هُمُ الْمُرْتَدُّونَ الَّذِينَ ارْتَدُّوا عَلَى عَهْدِ أَبِي بَكْرٍ، فَقَاتَلَهُمْ أَبُو بَكْرٍ ـ رضى الله عنه‏.‏\hadithno{3447}\hadithtrans{Narrted Ibn `Abbas:Allah's Messenger (ﷺ) said, "You will be resurrected (and assembled) bare-footed, naked and uncircumcised." The Prophet (ﷺ) then recited the Divine Verse:-- "As We began the first creation, We shall repeat it: A promise We have undertaken. Truly We shall do it." (21.104) He added, "The first to be dressed will be Abraham. Then some of my companions will take to the right and to the left. I will say: 'My companions! 'It will be said, 'They had been renegades since you left them.' I will then say what the Pious Slave Jesus, the son of Mary said: 'And I was a witness over them while I dwelt amongst them; when You did take me up, You were the Watcher over them, and You are a Witness to all things. If You punish them, they are Your slaves, and if You forgive them, You, only You are the All-Mighty the All-Wise.' " (5.117-118) Narrated Qabisah, "Those were the apostates who renegade from Islam during the Caliphate of Abu Bakr who fought them}}
\hadithdefcmd{bukhari}{3448}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ، لَيُوشِكَنَّ أَنْ يَنْزِلَ فِيكُمُ ابْنُ مَرْيَمَ حَكَمًا عَدْلاً، فَيَكْسِرَ الصَّلِيبَ، وَيَقْتُلَ الْخِنْزِيرَ، وَيَضَعَ الْجِزْيَةَ، وَيَفِيضَ الْمَالُ حَتَّى لاَ يَقْبَلَهُ أَحَدٌ، حَتَّى تَكُونَ السَّجْدَةُ الْوَاحِدَةُ خَيْرًا مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏وَإِنْ مِنْ أَهْلِ الْكِتَابِ إِلاَّ لَيُؤْمِنَنَّ بِهِ قَبْلَ مَوْتِهِ وَيَوْمَ الْقِيَامَةِ يَكُونُ عَلَيْهِمْ شَهِيدًا‏\}‏‏.‏\hadithno{3448}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "By Him in Whose Hands my soul is, surely (Jesus,) the son of Mary will soon descend amongst you and will judge mankind justly (as a Just Ruler); he will break the Cross and kill the pigs and there will be no Jizya (i.e. taxation taken from non Muslims). Money will be in abundance so that nobody will accept it, and a single prostration to Allah (in prayer) will be better than the whole world and whatever is in it." Abu Huraira added "If you wish, you can recite (this verse of the Holy Book): -- 'And there is none Of the people of the Scriptures (Jews and Christians) But must believe in him (i.e Jesus as an Apostle of Allah and a human being) Before his death. And on the Day of Judgment He will be a witness Against them." (4.159) (See Fath-ul-Bari, Page 302 Vol)}}
\hadithdefcmd{bukhari}{3449}{حَدَّثَنَا ابْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ الأَنْصَارِيِّ أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَيْفَ أَنْتُمْ إِذَا نَزَلَ ابْنُ مَرْيَمَ فِيكُمْ وَإِمَامُكُمْ مِنْكُمْ ‏"‏‏.‏ تَابَعَهُ عُقَيْلٌ وَالأَوْزَاعِيُّ‏.‏\hadithno{3449}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said "How will you be when the son of Mary (i.e. Jesus) descends amongst you and your imam is among you}}
\hadithdefcmd{bukhari}{3452}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، قَالَ قَالَ عُقْبَةُ بْنُ عَمْرٍو لِحُذَيْفَةَ أَلاَ تُحَدِّثُنَا مَا سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ إِنِّي سَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ مَعَ الدَّجَّالِ إِذَا خَرَجَ مَاءً وَنَارًا، فَأَمَّا الَّذِي يَرَى النَّاسُ أَنَّهَا النَّارُ فَمَاءٌ بَارِدٌ، وَأَمَّا الَّذِي يَرَى النَّاسُ أَنَّهُ مَاءٌ بَارِدٌ فَنَارٌ تُحْرِقُ، فَمَنْ أَدْرَكَ مِنْكُمْ فَلْيَقَعْ فِي الَّذِي يَرَى أَنَّهَا نَارٌ، فَإِنَّهُ عَذْبٌ بَارِدٌ ‏"‏‏.‏ قَالَ حُذَيْفَةُ وَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ رَجُلاً كَانَ فِيمَنْ كَانَ قَبْلَكُمْ أَتَاهُ الْمَلَكُ لِيَقْبِضَ رُوحَهُ فَقِيلَ لَهُ هَلْ عَمِلْتَ مِنْ خَيْرٍ قَالَ مَا أَعْلَمُ، قِيلَ لَهُ انْظُرْ‏.‏ قَالَ مَا أَعْلَمُ شَيْئًا غَيْرَ أَنِّي كُنْتُ أُبَايِعُ النَّاسَ فِي الدُّنْيَا وَأُجَازِيهِمْ، فَأُنْظِرُ الْمُوسِرَ، وَأَتَجَاوَزُ عَنِ الْمُعْسِرِ‏.‏ فَأَدْخَلَهُ اللَّهُ الْجَنَّةَ ‏"‏‏.‏ فَقَالَ وَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ رَجُلاً حَضَرَهُ الْمَوْتُ، فَلَمَّا يَئِسَ مِنَ الْحَيَاةِ أَوْصَى أَهْلَهُ إِذَا أَنَا مُتُّ فَاجْمَعُوا لِي حَطَبًا كَثِيرًا وَأَوْقِدُوا فِيهِ نَارًا حَتَّى إِذَا أَكَلَتْ لَحْمِي، وَخَلَصَتْ إِلَى عَظْمِي، فَامْتَحَشْتُ، فَخُذُوهَا فَاطْحَنُوهَا، ثُمَّ انْظُرُوا يَوْمًا رَاحًا فَاذْرُوهُ فِي الْيَمِّ‏.‏ فَفَعَلُوا، فَجَمَعَهُ فَقَالَ لَهُ لِمَ فَعَلْتَ ذَلِكَ قَالَ مِنْ خَشْيَتِكَ‏.‏ فَغَفَرَ اللَّهُ لَهُ ‏"‏‏.‏ قَالَ عُقْبَةُ بْنُ عَمْرٍو، وَأَنَا سَمِعْتُهُ يَقُولُ ذَاكَ، وَكَانَ نَبَّاشًا‏.‏\hadithno{3452}\hadithtrans{Narrated Rabi bin Hirash:`Uqba bin `Amr said to Hudhaifa, "Won't you relate to us of what you have heard from Allah's Apostle ?" He said, "I heard him saying, "When Al-Dajjal appears, he will have fire and water along with him. What the people will consider as cold water, will be fire that will burn (things). So, if anyone of you comes across this, he should fall in the thing which will appear to him as fire, for in reality, it will be fresh cold water." Hudhaifa added, "I also heard him saying, 'From among the people preceding your generation, there was a man whom the angel of death visited to capture his soul. (So his soul was captured) and he was asked if he had done any good deed.' He replied, 'I don't remember any good deed.' He was asked to think it over. He said, 'I do not remember, except that I used to trade with the people in the world and I used to give a respite to the rich and forgive the poor (among my debtors). So Allah made him enter Paradise." Hudhaifa further said, "I also heard him saying, 'Once there was a man on his death-bed, who, losing every hope of surviving said to his family: When I die, gather for me a large heap of wood and make a fire (to burn me). When the fire eats my meat and reaches my bones, and when the bones burn, take and crush them into powder and wait for a windy day to throw it (i.e. the powder) over the sea. They did so, but Allah collected his particles and asked him: Why did you do so? He replied: For fear of You. So Allah forgave him." `Uqba bin `Amr said, "I heard him saying that the Israeli used to dig the grave of the dead (to steal their shrouds)}}
\hadithdefcmd{bukhari}{3454}{حَدَّثَنِي بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنِي مَعْمَرٌ، وَيُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ عَائِشَةَ، وَابْنَ، عَبَّاسٍ رضى الله عنهم قَالاَ لَمَّا نَزَلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم طَفِقَ يَطْرَحُ خَمِيصَةً عَلَى وَجْهِهِ، فَإِذَا اغْتَمَّ كَشَفَهَا عَنْ وَجْهِهِ، فَقَالَ وَهْوَ كَذَلِكَ ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الْيَهُودِ وَالنَّصَارَى، اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏‏.‏ يُحَذِّرُ مَا صَنَعُوا‏.‏\hadithno{3454}\hadithtrans{Narrated `Aisha and Ibn `Abbas:On his death-bed Allah's Messenger (ﷺ) put a sheet over his-face and when he felt hot, he would remove it from his face. When in that state (of putting and removing the sheet) he said, "May Allah's Curse be on the Jews and the Christians for they build places of worship at the graves of their prophets." (By that) he intended to warn (the Muslim) from what they (i.e. Jews and Christians) had done}}
\hadithdefcmd{bukhari}{3455}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ فُرَاتٍ الْقَزَّازِ، قَالَ سَمِعْتُ أَبَا حَازِمٍ، قَالَ قَاعَدْتُ أَبَا هُرَيْرَةَ خَمْسَ سِنِينَ، فَسَمِعْتُهُ يُحَدِّثُ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَتْ بَنُو إِسْرَائِيلَ تَسُوسُهُمُ الأَنْبِيَاءُ، كُلَّمَا هَلَكَ نَبِيٌّ خَلَفَهُ نَبِيٌّ، وَإِنَّهُ لاَ نَبِيَّ بَعْدِي، وَسَيَكُونُ خُلَفَاءُ فَيَكْثُرُونَ‏.‏ قَالُوا فَمَا تَأْمُرُنَا قَالَ فُوا بِبَيْعَةِ الأَوَّلِ فَالأَوَّلِ، أَعْطُوهُمْ حَقَّهُمْ، فَإِنَّ اللَّهَ سَائِلُهُمْ عَمَّا اسْتَرْعَاهُمْ ‏"‏‏.‏\hadithno{3455}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Israelis used to be ruled and guided by prophets: Whenever a prophet died, another would take over his place. There will be no prophet after me, but there will be Caliphs who will increase in number." The people asked, "O Allah's Messenger (ﷺ)! What do you order us (to do)?" He said, "Obey the one who will be given the pledge of allegiance first. Fulfil their (i.e. the Caliphs) rights, for Allah will ask them about (any shortcoming) in ruling those Allah has put under their guardianship}}
\hadithdefcmd{bukhari}{3456}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لَتَتَّبِعُنَّ سَنَنَ مَنْ قَبْلَكُمْ شِبْرًا بِشِبْرٍ، وَذِرَاعًا بِذِرَاعٍ، حَتَّى لَوْ سَلَكُوا جُحْرَ ضَبٍّ لَسَلَكْتُمُوهُ ‏"‏‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ، الْيَهُودَ وَالنَّصَارَى قَالَ ‏"‏ فَمَنْ ‏"‏‏.‏\hadithno{3456}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) said, "You will follow the wrong ways, of your predecessors so completely and literally that if they should go into the hole of a mastigure, you too will go there." We said, "O Allah's Messenger (ﷺ)! Do you mean the Jews and the Christians?" He replied, "Whom else?" (Meaning, of course, the Jews and the Christians)}}
\hadithdefcmd{bukhari}{3457}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ ذَكَرُوا النَّارَ وَالنَّاقُوسَ، فَذَكَرُوا الْيَهُودَ وَالنَّصَارَى، فَأُمِرَ بِلاَلٌ أَنْ يَشْفَعَ الأَذَانَ وَأَنْ يُوتِرَ الإِقَامَةَ‏.‏\hadithno{3457}\hadithtrans{Narrated Anas:The people mentioned the fire and the bell (as means proposed for announcing the time of prayer) and by such a suggestion they referred to the Jews and the Christians. But Bilal was ordered, "Pronounce the words of the Adhan (i.e. call for the prayer) twice and the Iqama once only}}
\hadithdefcmd{bukhari}{3458}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها كَانَتْ تَكْرَهُ أَنْ يَجْعَلَ ‏\{‏الْمُصَلِّي‏\}‏ يَدَهُ فِي خَاصِرَتِهِ وَتَقُولُ إِنَّ الْيَهُودَ تَفْعَلُهُ‏.‏ تَابَعَهُ شُعْبَةُ عَنِ الأَعْمَشِ‏.‏\hadithno{3458}\hadithtrans{Narrated `Aisha:That she used to hate that one should keep his hands on his flanks while praying. She said that the Jews used to do so}}
\hadithdefcmd{bukhari}{3459}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا أَجَلُكُمْ فِي أَجَلِ مَنْ خَلاَ مِنَ الأُمَمِ مَا بَيْنَ صَلاَةِ الْعَصْرِ إِلَى مَغْرِبِ الشَّمْسِ، وَإِنَّمَا مَثَلُكُمْ وَمَثَلُ الْيَهُودِ وَالنَّصَارَى كَرَجُلٍ اسْتَعْمَلَ عُمَّالاً فَقَالَ مَنْ يَعْمَلُ لِي إِلَى نِصْفِ النَّهَارِ عَلَى قِيرَاطٍ قِيرَاطٍ فَعَمِلَتِ الْيَهُودُ إِلَى نِصْفِ النَّهَارِ عَلَى قِيرَاطٍ قِيرَاطٍ، ثُمَّ قَالَ مَنْ يَعْمَلُ لِي مِنْ نِصْفِ النَّهَارِ إِلَى صَلاَةِ الْعَصْرِ عَلَى قِيرَاطٍ قِيرَاطٍ فَعَمِلَتِ النَّصَارَى مِنْ نِصْفِ النَّهَارِ إِلَى صَلاَةِ الْعَصْرِ، عَلَى قِيرَاطٍ قِيرَاطٍ، ثُمَّ قَالَ مَنْ يَعْمَلُ لِي مِنْ صَلاَةِ الْعَصْرِ إِلَى مَغْرِبِ الشَّمْسِ عَلَى قِيرَاطَيْنِ قِيرَاطَيْنِ أَلاَ فَأَنْتُمُ الَّذِينَ يَعْمَلُونَ مِنْ صَلاَةِ الْعَصْرِ إِلَى مَغْرِبِ الشَّمْسِ عَلَى قِيرَاطَيْنِ قِيرَاطَيْنِ، أَلاَ لَكُمُ الأَجْرُ مَرَّتَيْنِ، فَغَضِبَتِ الْيَهُودُ وَالنَّصَارَى، فَقَالُوا نَحْنُ أَكْثَرُ عَمَلاً وَأَقَلُّ عَطَاءً، قَالَ اللَّهُ هَلْ ظَلَمْتُكُمْ مِنْ حَقِّكُمْ شَيْئًا قَالُوا لاَ‏.‏ قَالَ فَإِنَّهُ فَضْلِي أُعْطِيهِ مَنْ شِئْتُ ‏"‏‏.‏\hadithno{3459}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Your period (i.e. the Muslims' period) in comparison to the periods of the previous nations, is like the period between the `Asr prayer and sunset. And your example in comparison to the Jews and the Christians is like the example of a person who employed some laborers and asked them, 'Who will work for me till midday for one Qirat each?' The Jews worked for half a day for one Qirat each. The person asked, 'Who will do the work for me from midday to the time of the `Asr (prayer) for one Qirat each?' The Christians worked from midday till the `Asr prayer for one Qirat. Then the person asked, 'Who will do the work for me from the `Asr till sunset for two Qirats each?' " The Prophet (ﷺ) added, "It is you (i.e. Muslims) who are doing the work from the `Asr till sunset, so you will have a double reward. The Jews and the Christians got angry and said, 'We have done more work but got less wages.' Allah said, 'Have I been unjust to you as regards your rights?' They said, 'No.' So Allah said, 'Then it is My Blessing which I bestow on whomever I like}}
\hadithdefcmd{bukhari}{3460}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ عُمَرَ ـ رضى الله عنه ـ يَقُولُ قَاتَلَ اللَّهُ فُلاَنًا، أَلَمْ يَعْلَمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْيَهُودَ، حُرِّمَتْ عَلَيْهِمُ الشُّحُومُ، فَجَمَّلُوهَا فَبَاعُوهَا ‏"‏‏.‏ تَابَعَهُ جَابِرٌ وَأَبُو هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3460}\hadithtrans{Narrated Ibn `Abbas:I heard `Umar saying, "May Allah Curse so-and-so! Doesn't he know that the Prophet (ﷺ) said, 'May Allah curse the Jews for, though they were forbidden (to eat) fat, they liquefied it and sold it}}
\hadithdefcmd{bukhari}{3461}{حَدَّثَنَا أَبُو عَاصِمٍ الضَّحَّاكُ بْنُ مَخْلَدٍ، أَخْبَرَنَا الأَوْزَاعِيُّ، حَدَّثَنَا حَسَّانُ بْنُ عَطِيَّةَ، عَنْ أَبِي كَبْشَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ بَلِّغُوا عَنِّي وَلَوْ آيَةً، وَحَدِّثُوا عَنْ بَنِي إِسْرَائِيلَ وَلاَ حَرَجَ، وَمَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏‏.‏\hadithno{3461}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) said, "Convey (my teachings) to the people even if it were a single sentence, and tell others the stories of Bani Israel (which have been taught to you), for it is not sinful to do so. And whoever tells a lie on me intentionally, will surely take his place in the (Hell) Fire}}
\hadithdefcmd{bukhari}{3462}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ إِنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْيَهُودَ وَالنَّصَارَى لاَ يَصْبُغُونَ، فَخَالِفُوهُمْ ‏"‏‏.‏\hadithno{3462}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Jews and the Christians do not dye (their grey hair), so you shall do the opposite of what they do (i.e. dye your grey hair and beards)}}
\hadithdefcmd{bukhari}{3463}{حَدَّثَنِي مُحَمَّدٌ، قَالَ حَدَّثَنِي حَجَّاجٌ، حَدَّثَنَا جَرِيرٌ، عَنِ الْحَسَنِ، حَدَّثَنَا جُنْدُبُ بْنُ عَبْدِ اللَّهِ، فِي هَذَا الْمَسْجِدِ، وَمَا نَسِينَا مُنْذُ حَدَّثَنَا، وَمَا نَخْشَى أَنْ يَكُونَ جُنْدُبٌ كَذَبَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَانَ فِيمَنْ كَانَ قَبْلَكُمْ رَجُلٌ بِهِ جُرْحٌ، فَجَزِعَ فَأَخَذَ سِكِّينًا فَحَزَّ بِهَا يَدَهُ، فَمَا رَقَأَ الدَّمُ حَتَّى مَاتَ، قَالَ اللَّهُ تَعَالَى بَادَرَنِي عَبْدِي بِنَفْسِهِ، حَرَّمْتُ عَلَيْهِ الْجَنَّةَ ‏"‏‏.‏\hadithno{3463}\hadithtrans{Narrated Jundub:Allah's Messenger (ﷺ) said, "Amongst the nations before you there was a man who got a wound, and growing impatient (with its pain), he took a knife and cut his hand with it and the blood did not stop till he died. Allah said, 'My Slave hurried to bring death upon himself so I have forbidden him (to enter) Paradise}}
\hadithdefcmd{bukhari}{3464}{حَدَّثَنِي أَحْمَدُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُ أَنَّهُ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم ح وَحَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، أَخْبَرَنَا هَمَّامٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ حَدَّثَهُ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ ثَلاَثَةً فِي بَنِي إِسْرَائِيلَ أَبْرَصَ وَأَقْرَعَ وَأَعْمَى بَدَا لِلَّهِ أَنْ يَبْتَلِيَهُمْ، فَبَعَثَ إِلَيْهِمْ مَلَكًا، فَأَتَى الأَبْرَصَ‏.‏ فَقَالَ أَىُّ شَىْءٍ أَحَبُّ إِلَيْكَ قَالَ لَوْنٌ حَسَنٌ وَجِلْدٌ حَسَنٌ، قَدْ قَذِرَنِي النَّاسُ‏.‏ قَالَ فَمَسَحَهُ، فَذَهَبَ عَنْهُ، فَأُعْطِيَ لَوْنًا حَسَنًا وَجِلْدًا حَسَنًا‏.‏ فَقَالَ أَىُّ الْمَالِ أَحَبُّ إِلَيْكَ قَالَ الإِبِلُ ـ أَوْ قَالَ الْبَقَرُ هُوَ شَكَّ فِي ذَلِكَ، إِنَّ الأَبْرَصَ وَالأَقْرَعَ، قَالَ أَحَدُهُمَا الإِبِلُ، وَقَالَ الآخَرُ الْبَقَرُ ـ فَأُعْطِيَ نَاقَةً عُشَرَاءَ‏.‏ فَقَالَ يُبَارَكُ لَكَ فِيهَا‏.‏ وَأَتَى الأَقْرَعَ فَقَالَ أَىُّ شَىْءٍ أَحَبُّ إِلَيْكَ قَالَ شَعَرٌ حَسَنٌ، وَيَذْهَبُ عَنِّي هَذَا، قَدْ قَذِرَنِي النَّاسُ‏.‏ قَالَ فَمَسَحَهُ فَذَهَبَ، وَأُعْطِيَ شَعَرًا حَسَنًا‏.‏ قَالَ فَأَىُّ الْمَالِ أَحَبُّ إِلَيْكَ قَالَ الْبَقَرُ‏.‏ قَالَ فَأَعْطَاهُ بَقَرَةً حَامِلاً، وَقَالَ يُبَارَكُ لَكَ فِيهَا‏.‏ وَأَتَى الأَعْمَى فَقَالَ أَىُّ شَىْءٍ أَحَبُّ إِلَيْكَ قَالَ يَرُدُّ اللَّهُ إِلَىَّ بَصَرِي، فَأُبْصِرُ بِهِ النَّاسَ‏.‏ قَالَ فَمَسَحَهُ، فَرَدَّ اللَّهُ إِلَيْهِ بَصَرَهُ‏.‏ قَالَ فَأَىُّ الْمَالِ أَحَبُّ إِلَيْكَ قَالَ الْغَنَمُ‏.‏ فَأَعْطَاهُ شَاةً وَالِدًا، فَأُنْتِجَ هَذَانِ، وَوَلَّدَ هَذَا، فَكَانَ لِهَذَا وَادٍ مِنْ إِبِلٍ، وَلِهَذَا وَادٍ مِنْ بَقَرٍ، وَلِهَذَا وَادٍ مِنَ الْغَنَمِ‏.‏ ثُمَّ إِنَّهُ أَتَى الأَبْرَصَ فِي صُورَتِهِ وَهَيْئَتِهِ فَقَالَ رَجُلٌ مِسْكِينٌ، تَقَطَّعَتْ بِيَ الْحِبَالُ فِي سَفَرِي، فَلاَ بَلاَغَ الْيَوْمَ إِلاَّ بِاللَّهِ ثُمَّ بِكَ، أَسْأَلُكَ بِالَّذِي أَعْطَاكَ اللَّوْنَ الْحَسَنَ وَالْجِلْدَ الْحَسَنَ وَالْمَالَ بَعِيرًا أَتَبَلَّغُ عَلَيْهِ فِي سَفَرِي‏.‏ فَقَالَ لَهُ إِنَّ الْحُقُوقَ كَثِيرَةٌ‏.‏ فَقَالَ لَهُ كَأَنِّي أَعْرِفُكَ، أَلَمْ تَكُنْ أَبْرَصَ يَقْذَرُكَ النَّاسُ فَقِيرًا فَأَعْطَاكَ اللَّهُ فَقَالَ لَقَدْ وَرِثْتُ لِكَابِرٍ عَنْ كَابِرٍ‏.‏ فَقَالَ إِنْ كُنْتَ كَاذِبًا فَصَيَّرَكَ اللَّهُ إِلَى مَا كُنْتَ، وَأَتَى الأَقْرَعَ فِي صُورَتِهِ وَهَيْئَتِهِ، فَقَالَ لَهُ مِثْلَ مَا قَالَ لِهَذَا، فَرَدَّ عَلَيْهِ مِثْلَ مَا رَدَّ عَلَيْهِ هَذَا فَقَالَ إِنْ كُنْتَ كَاذِبًا فَصَيَّرَكَ اللَّهُ إِلَى مَا كُنْتَ‏.‏ وَأَتَى الأَعْمَى فِي صُورَتِهِ فَقَالَ رَجُلٌ مِسْكِينٌ وَابْنُ سَبِيلٍ وَتَقَطَّعَتْ بِيَ الْحِبَالُ فِي سَفَرِي، فَلاَ بَلاَغَ الْيَوْمَ إِلاَّ بِاللَّهِ، ثُمَّ بِكَ أَسْأَلُكَ بِالَّذِي رَدَّ عَلَيْكَ بَصَرَكَ شَاةً أَتَبَلَّغُ بِهَا فِي سَفَرِي‏.‏ فَقَالَ قَدْ كُنْتُ أَعْمَى فَرَدَّ اللَّهُ بَصَرِي، وَفَقِيرًا فَقَدْ أَغْنَانِي، فَخُذْ مَا شِئْتَ، فَوَاللَّهِ لاَ أَجْهَدُكَ الْيَوْمَ بِشَىْءٍ أَخَذْتَهُ لِلَّهِ‏.‏ فَقَالَ أَمْسِكْ مَالَكَ، فَإِنَّمَا ابْتُلِيتُمْ، فَقَدْ رَضِيَ اللَّهُ عَنْكَ وَسَخِطَ عَلَى صَاحِبَيْكَ ‏"‏‏.‏\hadithno{3464}\hadithtrans{Narrated Abu Huraira:that he heard Allah's Messenger (ﷺ) saying, "Allah willed to test three Israelis who were a Leper, a blind man and a bald-headed man. So, he sent them an angel who came to the leper and said, 'What thing do you like most?' He replied, 'Good color and good skin, for the people have a strong aversion to me.' The angel touched him and his illness was cured, and he was given a good color and beautiful skin. The angel asked him, 'What kind of property do you like best?' He replied, 'Camels (or cows).' (The narrator is in doubt, for either the leper or the bald-headed man demanded camels and the other demanded cows). So he (i.e. the leper) was given a pregnant she-camel, and the angel said (to him), 'May Allah bless you in it.' The angel then went to the bald-headed man and said, 'What thing do you like most?' He said, 'I like good hair and wish to be cured of this disease, for the people feel repulsion for me.' The angel touched him and his illness was cured, and he was given good hair. The angel asked (him), 'What kind of property do you like best?' He replied, 'Cows,' The angel gave him a pregnant cow and said, 'May Allah bless you in it.' The angel went to the blind man and asked, 'What thing do you like best?' He said, '(I like) that Allah may restore my eye-sight to me so that I may see the people.' The angel touched his eyes and Allah gave him back his eye-sight. The angel asked him, 'What kind of property do you like best?' He replied, 'Sheep.' The angel gave him a pregnant sheep. Afterwards, all the three pregnant animals gave birth to young ones, and multiplied and brought forth so much that one of the (three) men had a herd of camels filling a valley, and one had a herd of cows filling a valley, and one had a flock of sheep filling a valley. Then the angel, disguised in the shape and appearance of a leper, went to the leper and said, I am a poor man, who has lost all means of livelihood while on a journey. So none will satisfy my need except Allah and then you. In the Name of Him Who has given you such nice color and beautiful skin, and so much property, I ask you to give me a camel so that I may reach my destination. The man replied, 'I have many obligations (so I cannot give you).' The angel said, 'I think I know you; were you not a leper to whom the people had a strong aversion? Weren't you a poor man, and then Allah gave you (all this property).' He replied, '(This is all wrong), I got this property through inheritance from my fore-fathers.' The angel said, 'If you are telling a lie, then let Allah make you as you were before. ' Then the angel, disguised in the shape and appearance of a bald man, went to the bald man and said to him the same as he told the first one, and he too answered the same as the first one did. The angel said, 'If you are telling a lie, then let Allah make you as you were before.' The angel, disguised in the shape of a blind man, went to the blind man and said, 'I am a poor man and a traveler, whose means of livelihood have been exhausted while on a journey. I have nobody to help me except Allah, and after Him, you yourself. I ask you in the Name of Him Who has given you back your eye-sight to give me a sheep, so that with its help, I may complete my journey.' The man said, 'No doubt, I was blind and Allah gave me back my eye-sight; I was poor and Allah made me rich; so take anything you wish from my property. By Allah, I will not stop you for taking anything (you need) of my property which you may take for Allah's sake.' The angel replied, 'Keep your property with you. You (i.e the three men) have been tested, and Allah is pleased with you and is angry with your two companions}}
\hadithdefcmd{bukhari}{3465}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ خَلِيلٍ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا ثَلاَثَةُ نَفَرٍ مِمَّنْ كَانَ قَبْلَكُمْ يَمْشُونَ إِذْ أَصَابَهُمْ مَطَرٌ، فَأَوَوْا إِلَى غَارٍ، فَانْطَبَقَ عَلَيْهِمْ، فَقَالَ بَعْضُهُمْ لِبَعْضٍ إِنَّهُ وَاللَّهِ يَا هَؤُلاَءِ لاَ يُنْجِيكُمْ إِلاَّ الصِّدْقُ، فَلْيَدْعُ كُلُّ رَجُلٍ مِنْكُمْ بِمَا يَعْلَمُ أَنَّهُ قَدْ صَدَقَ فِيهِ‏.‏ فَقَالَ وَاحِدٌ مِنْهُمُ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنَّهُ كَانَ لِي أَجِيرٌ عَمِلَ لِي عَلَى فَرَقٍ مِنْ أَرُزٍّ، فَذَهَبَ وَتَرَكَهُ، وَأَنِّي عَمَدْتُ إِلَى ذَلِكَ الْفَرَقِ فَزَرَعْتُهُ، فَصَارَ مِنْ أَمْرِهِ أَنِّي اشْتَرَيْتُ مِنْهُ بَقَرًا، وَأَنَّهُ أَتَانِي يَطْلُبُ أَجْرَهُ فَقُلْتُ اعْمِدْ إِلَى تِلْكَ الْبَقَرِ‏.‏ فَسُقْهَا، فَقَالَ لِي إِنَّمَا لِي عِنْدَكَ فَرَقٌ مِنْ أَرُزٍّ‏.‏ فَقُلْتُ لَهُ اعْمِدْ إِلَى تِلْكَ الْبَقَرِ فَإِنَّهَا مِنْ ذَلِكَ الْفَرَقِ، فَسَاقَهَا، فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ مِنْ خَشْيَتِكَ، فَفَرِّجْ عَنَّا‏.‏ فَانْسَاحَتْ عَنْهُمُ الصَّخْرَةُ‏.‏ فَقَالَ الآخَرُ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنَّهُ كَانَ لِي أَبَوَانِ شَيْخَانِ كَبِيرَانِ، فَكُنْتُ آتِيهِمَا كُلَّ لَيْلَةٍ بِلَبَنِ غَنَمٍ لِي، فَأَبْطَأْتُ عَلَيْهِمَا لَيْلَةً فَجِئْتُ وَقَدْ رَقَدَا وَأَهْلِي وَعِيَالِي يَتَضَاغَوْنَ مِنَ الْجُوعِ، فَكُنْتُ لاَ أَسْقِيهِمْ حَتَّى يَشْرَبَ أَبَوَاىَ، فَكَرِهْتُ أَنْ أُوقِظَهُمَا، وَكَرِهْتُ أَنْ أَدَعَهُمَا، فَيَسْتَكِنَّا لِشَرْبَتِهِمَا، فَلَمْ أَزَلْ أَنْتَظِرُ حَتَّى طَلَعَ الْفَجْرُ، فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ مِنْ خَشْيَتِكَ، فَفَرِّجْ عَنَّا‏.‏ فَانْسَاحَتْ عَنْهُمُ الصَّخْرَةُ، حَتَّى نَظَرُوا إِلَى السَّمَاءِ‏.‏ فَقَالَ الآخَرُ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنَّهُ كَانَ لِي ابْنَةُ عَمٍّ مِنْ أَحَبِّ النَّاسِ إِلَىَّ، وَأَنِّي رَاوَدْتُهَا عَنْ نَفْسِهَا فَأَبَتْ إِلاَّ أَنْ آتِيَهَا بِمِائَةِ دِينَارٍ، فَطَلَبْتُهَا حَتَّى قَدَرْتُ، فَأَتَيْتُهَا بِهَا فَدَفَعْتُهَا إِلَيْهَا، فَأَمْكَنَتْنِي مِنْ نَفْسِهَا، فَلَمَّا قَعَدْتُ بَيْنَ رِجْلَيْهَا، فَقَالَتِ اتَّقِ اللَّهَ وَلاَ تَفُضَّ الْخَاتَمَ إِلاَّ بِحَقِّهِ‏.‏ فَقُمْتُ وَتَرَكْتُ الْمِائَةَ دِينَارٍ، فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ مِنْ خَشْيَتِكَ فَفَرِّجْ عَنَّا‏.‏ فَفَرَّجَ اللَّهُ عَنْهُمْ فَخَرَجُوا ‏"‏‏.‏\hadithno{3465}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Once three persons (from the previous nations) were traveling, and suddenly it started raining and they took shelter in a cave. The entrance of the cave got closed while they were inside. They said to each other, 'O you! Nothing can save you except the truth, so each of you should ask Allah's Help by referring to such a deed as he thinks he did sincerely (i.e. just for gaining Allah's Pleasure).' So one of them said, 'O Allah! You know that I had a laborer who worked for me for one Faraq (i.e. three Sas) of rice, but he departed, leaving it (i.e. his wages). I sowed that Faraq of rice and with its yield I bought cows (for him). Later on when he came to me asking for his wages, I said (to him), 'Go to those cows and drive them away.' He said to me, 'But you have to pay me only a Faraq of rice,' I said to him, 'Go to those cows and take them, for they are the product of that Faraq (of rice).' So he drove them. O Allah! If you consider that I did that for fear of You, then please remove the rock.' The rock shifted a bit from the mouth of the cave. The second one said, 'O Allah, You know that I had old parents whom I used to provide with the milk of my sheep every night. One night I was delayed and when I came, they had slept, while my wife and children were crying with hunger. I used not to let them (i.e. my family) drink unless my parents had drunk first. So I disliked to wake them up and also disliked that they should sleep without drinking it, I kept on waiting (for them to wake) till it dawned. O Allah! If You consider that I did that for fear of You, then please remove the rock.' So the rock shifted and they could see the sky through it. The (third) one said, 'O Allah! You know that I had a cousin (i.e. my paternal uncle's daughter) who was most beloved to me and I sought to seduce her, but she refused, unless I paid her one-hundred Dinars (i.e. gold pieces). So I collected the amount and brought it to her, and she allowed me to sleep with her. But when I sat between her legs, she said, 'Be afraid of Allah, and do not deflower me but legally. 'I got up and left the hundred Dinars (for her). O Allah! If You consider that I did that for fear of You then please remove the rock. So Allah saved them and they came out (of the cave)}}
\hadithdefcmd{bukhari}{3466}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بَيْنَمَا امْرَأَةٌ تُرْضِعُ ابْنَهَا إِذْ مَرَّ بِهَا رَاكِبٌ وَهْىَ تُرْضِعُهُ، فَقَالَتِ اللَّهُمَّ لاَ تُمِتِ ابْنِي حَتَّى يَكُونَ مِثْلَ هَذَا‏.‏ فَقَالَ اللَّهُمَّ لاَ تَجْعَلْنِي مِثْلَهُ‏.‏ ثُمَّ رَجَعَ فِي الثَّدْىِ، وَمُرَّ بِامْرَأَةٍ تُجَرَّرُ وَيُلْعَبُ بِهَا فَقَالَتِ اللَّهُمَّ لاَ تَجْعَلِ ابْنِي مِثْلَهَا‏.‏ فَقَالَ اللَّهُمَّ اجْعَلْنِي مِثْلَهَا‏.‏ فَقَالَ أَمَّا الرَّاكِبُ فَإِنَّهُ كَافِرٌ، وَأَمَّا الْمَرْأَةُ فَإِنَّهُمْ يَقُولُونَ لَهَا تَزْنِي‏.‏ وَتَقُولُ حَسْبِي اللَّهُ‏.‏ وَيَقُولُونَ تَسْرِقُ‏.‏ وَتَقُولُ حَسْبِي اللَّهُ ‏"‏‏.‏\hadithno{3466}\hadithtrans{Narrated Abu Huraira:That he heard Allah's Messenger (ﷺ) saying, "While a lady was nursing her child, a rider passed by and she said, 'O Allah! Don't let my child die till he becomes like this (rider).' The child said, 'O Allah! Don't make me like him,' and then returned to her breast (sucking it). (After a while) they passed by a lady who was being pulled and teased (by the people). The child's mother said, 'O Allah! Do not make my child like her.' The child said, 'O Allah! Make me like her.' Then he said, 'As for the rider, he is an infidel, while the lady is accused of illegal sexual intercourse (falsely) and she says: Allah is sufficient for me (He knows the truth)}}
\hadithdefcmd{bukhari}{3467}{حَدَّثَنَا سَعِيدُ بْنُ تَلِيدٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بَيْنَمَا كَلْبٌ يُطِيفُ بِرَكِيَّةٍ كَادَ يَقْتُلُهُ الْعَطَشُ، إِذْ رَأَتْهُ بَغِيٌّ مِنْ بَغَايَا بَنِي إِسْرَائِيلَ، فَنَزَعَتْ مُوقَهَا فَسَقَتْهُ، فَغُفِرَ لَهَا بِهِ ‏"‏‏.‏\hadithno{3467}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "While a dog was going round a well and was about to die of thirst, an Israeli prostitute saw it and took off her shoe and watered it. So Allah forgave her because of that good deed}}
\hadithdefcmd{bukhari}{3468}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ،، عَامَ حَجَّ عَلَى الْمِنْبَرِ، فَتَنَاوَلَ قُصَّةً مِنْ شَعَرٍ وَكَانَتْ فِي يَدَىْ حَرَسِيٍّ فَقَالَ يَا أَهْلَ الْمَدِينَةِ، أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَنْهَى عَنْ مِثْلِ هَذِهِ، وَيَقُولُ ‏ "‏ إِنَّمَا هَلَكَتْ بَنُو إِسْرَائِيلَ حِينَ اتَّخَذَهَا نِسَاؤُهُمْ ‏"‏‏.‏\hadithno{3468}\hadithtrans{Narrated Humaid bin `Abdur-Rahman:That he heard Muawiya bin Abi Sufyan (talking) on the pulpit in the year when he performed the Hajj. He took a tuft of hair that was in the hand of an orderly and said, "O people of Medina! Where are your learned men? I heard the Prophet (ﷺ) forbidding such a thing as this (i.e. false hair) and he used to say, 'The Israelis were destroyed when their ladies practiced this habit (of using false hair to lengthen their locks)}}
\hadithdefcmd{bukhari}{3469}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهُ قَدْ كَانَ فِيمَا مَضَى قَبْلَكُمْ مِنَ الأُمَمِ مُحَدَّثُونَ، وَإِنَّهُ إِنْ كَانَ فِي أُمَّتِي هَذِهِ مِنْهُمْ، فَإِنَّهُ عُمَرُ بْنُ الْخَطَّابِ ‏"‏‏.‏\hadithno{3469}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Amongst the people preceding you there used to be 'Muhaddithun' (i.e. persons who can guess things that come true later on, as if those persons have been inspired by a divine power), and if there are any such persons amongst my followers, it is `Umar bin Al-Khattab}}
\hadithdefcmd{bukhari}{3470}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ فِي بَنِي إِسْرَائِيلَ رَجُلٌ قَتَلَ تِسْعَةً وَتِسْعِينَ إِنْسَانًا ثُمَّ خَرَجَ يَسْأَلُ، فَأَتَى رَاهِبًا فَسَأَلَهُ، فَقَالَ لَهُ هَلْ مِنْ تَوْبَةٍ قَالَ لاَ‏.‏ فَقَتَلَهُ، فَجَعَلَ يَسْأَلُ، فَقَالَ لَهُ رَجُلٌ ائْتِ قَرْيَةَ كَذَا وَكَذَا‏.‏ فَأَدْرَكَهُ الْمَوْتُ فَنَاءَ بِصَدْرِهِ نَحْوَهَا، فَاخْتَصَمَتْ فِيهِ مَلاَئِكَةُ الرَّحْمَةِ وَمَلاَئِكَةُ الْعَذَابِ، فَأَوْحَى اللَّهُ إِلَى هَذِهِ أَنْ تَقَرَّبِي‏.‏ وَأَوْحَى اللَّهُ إِلَى هَذِهِ أَنْ تَبَاعَدِي‏.‏ وَقَالَ قِيسُوا مَا بَيْنَهُمَا‏.‏ فَوُجِدَ إِلَى هَذِهِ أَقْرَبُ بِشِبْرٍ، فَغُفِرَ لَهُ ‏"‏‏.‏\hadithno{3470}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Amongst the men of Bani Israel there was a man who had murdered ninety-nine persons. Then he set out asking (whether his repentance could be accepted or not). He came upon a monk and asked him if his repentance could be accepted. The monk replied in the negative and so the man killed him. He kept on asking till a man advised to go to such and such village. (So he left for it) but death overtook him on the way. While dying, he turned his chest towards that village (where he had hoped his repentance would be accepted), and so the angels of mercy and the angels of punishment quarrelled amongst themselves regarding him. Allah ordered the village (towards which he was going) to come closer to him, and ordered the village (whence he had come), to go far away, and then He ordered the angels to measure the distances between his body and the two villages. So he was found to be one span closer to the village (he was going to). So he was forgiven}}
\hadithdefcmd{bukhari}{3471}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الصُّبْحِ، ثُمَّ أَقْبَلَ عَلَى النَّاسِ، فَقَالَ ‏"‏ بَيْنَا رَجُلٌ يَسُوقُ بَقَرَةً إِذْ رَكِبَهَا فَضَرَبَهَا فَقَالَتْ إِنَّا لَمْ نُخْلَقْ لِهَذَا، إِنَّمَا خُلِقْنَا لِلْحَرْثِ ‏"‏‏.‏ فَقَالَ النَّاسُ سُبْحَانَ اللَّهِ بَقَرَةٌ تَكَلَّمُ‏.‏ فَقَالَ ‏"‏ فَإِنِّي أُومِنُ بِهَذَا أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ـ وَمَا هُمَا ثَمَّ ـ وَبَيْنَمَا رَجُلٌ فِي غَنَمِهِ إِذْ عَدَا الذِّئْبُ فَذَهَبَ مِنْهَا بِشَاةٍ، فَطَلَبَ حَتَّى كَأَنَّهُ اسْتَنْقَذَهَا مِنْهُ، فَقَالَ لَهُ الذِّئْبُ هَذَا اسْتَنْقَذْتَهَا مِنِّي فَمَنْ لَهَا يَوْمَ السَّبُعِ، يَوْمَ لاَ رَاعِيَ لَهَا غَيْرِي ‏"‏‏.‏ فَقَالَ النَّاسُ سُبْحَانَ اللَّهِ ذِئْبٌ يَتَكَلَّمُ‏.‏ قَالَ ‏"‏ فَإِنِّي أُومِنُ بِهَذَا أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏‏.‏ وَمَا هُمَا ثَمَّ‏.‏ وَحَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، عَنْ مِسْعَرٍ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ‏.‏\hadithno{3471}\hadithtrans{Narrated Abu Huraira:Once Allah's Messenger (ﷺ); offered the morning prayer and then faced the people and said, "While a man was driving a cow, he suddenly rode over it and beat it. The cow said, "We have not been created for this, but we have been created for ploughing." On that the people said astonishingly, "Glorified be Allah! A cow speaks!" The Prophet (ﷺ) said, "I believe this, and Abu Bakr and `Umar too, believe it, although neither of them was present there. While a person was amongst his sheep, a wolf attacked and took one of the sheep. The man chased the wolf till he saved it from the wolf, where upon the wolf said, 'You have saved it from me; but who will guard it on the day of the wild beasts when there will be no shepherd to guard them except me (because of riots and afflictions)? ' " The people said surprisingly, "Glorified be Allah! A wolf speaks!" The Prophet (ﷺ) said, "But I believe this, and Abu Bakr and `Umar too, believe this, although neither of them was present there." (See the Foot-note of page No. 10 Vol)}}
\hadithdefcmd{bukhari}{3472}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اشْتَرَى رَجُلٌ مِنْ رَجُلٍ عَقَارًا لَهُ، فَوَجَدَ الرَّجُلُ الَّذِي اشْتَرَى الْعَقَارَ فِي عَقَارِهِ جَرَّةً فِيهَا ذَهَبٌ، فَقَالَ لَهُ الَّذِي اشْتَرَى الْعَقَارَ خُذْ ذَهَبَكَ مِنِّي، إِنَّمَا اشْتَرَيْتُ مِنْكَ الأَرْضَ، وَلَمْ أَبْتَعْ مِنْكَ الذَّهَبَ‏.‏ وَقَالَ الَّذِي لَهُ الأَرْضُ إِنَّمَا بِعْتُكَ الأَرْضَ وَمَا فِيهَا، فَتَحَاكَمَا إِلَى رَجُلٍ، فَقَالَ الَّذِي تَحَاكَمَا إِلَيْهِ أَلَكُمَا وَلَدٌ قَالَ أَحَدُهُمَا لِي غُلاَمٌ‏.‏ وَقَالَ الآخَرُ لِي جَارِيَةٌ‏.‏ قَالَ أَنْكِحُوا الْغُلاَمَ الْجَارِيَةَ، وَأَنْفِقُوا عَلَى أَنْفُسِهِمَا مِنْهُ، وَتَصَدَّقَا ‏"‏‏.‏\hadithno{3472}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A man bought a piece of land from another man, and the buyer found an earthenware jar filled with gold in the land. The buyer said to the seller. 'Take your gold, as I have bought only the land from you, but I have not bought the gold from you.' The (former) owner of the land said, "I have sold you the land with everything in it.' So both of them took their case before a man who asked, 'Do you have children?' One of them said, "I have a boy.' The other said, "I have a girl.' The man said, 'Marry the girl to the boy and spend the money on both of them and give the rest of it in charity}}
\hadithdefcmd{bukhari}{3473}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَعَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَهُ يَسْأَلُ، أُسَامَةَ بْنَ زَيْدٍ مَاذَا سَمِعْتَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الطَّاعُونِ فَقَالَ أُسَامَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الطَّاعُونُ رِجْسٌ أُرْسِلَ عَلَى طَائِفَةٍ مِنْ بَنِي إِسْرَائِيلَ أَوْ عَلَى مَنْ كَانَ قَبْلَكُمْ، فَإِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ، وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏‏.‏ قَالَ أَبُو النَّضْرِ ‏"‏ لاَ يُخْرِجُكُمْ إِلاَّ فِرَارًا مِنْهُ ‏"‏‏.‏\hadithno{3473}\hadithtrans{Narrated Usama bin Zaid:Allah's Messenger (ﷺ) said, "Plague was a means of torture sent on a group of Israelis (or on some people before you). So if you hear of its spread in a land, don't approach it, and if a plague should appear in a land where you are present, then don't leave that land in order to run away from it (i.e. plague)}}
\hadithdefcmd{bukhari}{3474}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي الْفُرَاتِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الطَّاعُونِ، فَأَخْبَرَنِي ‏ "‏ أَنَّهُ عَذَابٌ يَبْعَثُهُ اللَّهُ عَلَى مَنْ يَشَاءُ، وَأَنَّ اللَّهَ جَعَلَهُ رَحْمَةً لِلْمُؤْمِنِينَ، لَيْسَ مِنْ أَحَدٍ يَقَعُ الطَّاعُونُ فَيَمْكُثُ فِي بَلَدِهِ صَابِرًا مُحْتَسِبًا، يَعْلَمُ أَنَّهُ لاَ يُصِيبُهُ إِلاَّ مَا كَتَبَ اللَّهُ لَهُ، إِلاَّ كَانَ لَهُ مِثْلُ أَجْرِ شَهِيدٍ ‏"‏‏.‏\hadithno{3474}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) I asked Allah's Messenger (ﷺ) about the plague. He told me that it was a Punishment sent by Allah on whom He wished, and Allah made it a source of mercy for the believers, for if one in the time of an epidemic plague stays in his country patiently hoping for Allah's Reward and believing that nothing will befall him except what Allah has written for him, he will get the reward of a martyr}}
\hadithdefcmd{bukhari}{3475}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ قُرَيْشًا، أَهَمَّهُمْ شَأْنُ الْمَرْأَةِ الْمَخْزُومِيَّةِ الَّتِي سَرَقَتْ، فَقَالَ وَمَنْ يُكَلِّمُ فِيهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالُوا وَمَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ بْنُ زَيْدٍ، حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَكَلَّمَهُ أُسَامَةُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏‏.‏ ثُمَّ قَامَ فَاخْتَطَبَ، ثُمَّ قَالَ ‏"‏ إِنَّمَا أَهْلَكَ الَّذِينَ قَبْلَكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ، وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ، وَايْمُ اللَّهِ، لَوْ أَنَّ فَاطِمَةَ ابْنَةَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏‏.‏\hadithno{3475}\hadithtrans{Narrated `Aisha:The people of Quraish worried about the lady from Bani Makhzum who had committed theft. They asked, "Who will intercede for her with Allah's Messenger (ﷺ)?" Some said, "No one dare to do so except Usama bin Zaid the beloved one to Allah's Messenger (ﷺ) ." When Usama spoke about that to Allah's Apostle Allah's Messenger (ﷺ) said, (to him), "Do you try to intercede for somebody in a case connected with Allah's Prescribed Punishments?" Then he got up and delivered a sermon saying, "What destroyed the nations preceding you, was that if a noble amongst them stole, they would forgive him, and if a poor person amongst them stole, they would inflict Allah's Legal punishment on him. By Allah, if Fatima, the daughter of Muhammad stole, I would cut off her hand}}
\hadithdefcmd{bukhari}{3476}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مَيْسَرَةَ، قَالَ سَمِعْتُ النَّزَّالَ بْنَ سَبْرَةَ الْهِلاَلِيَّ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَجُلاً، قَرَأَ، وَسَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ خِلاَفَهَا فَجِئْتُ بِهِ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَعَرَفْتُ فِي وَجْهِهِ الْكَرَاهِيَةَ وَقَالَ ‏ "‏ كِلاَكُمَا مُحْسِنٌ، وَلاَ تَخْتَلِفُوا، فَإِنَّ مَنْ كَانَ قَبْلَكُمُ اخْتَلَفُوا فَهَلَكُوا ‏"‏‏.‏\hadithno{3476}\hadithtrans{Narrated Ibn Mas`ud:I heard a person reciting a (Qur'anic) Verse in a certain way, and I had heard the Prophet (ﷺ) reciting the same Verse in a different way. So I took him to the Prophet (ﷺ) and informed him of that but I noticed the sign of disapproval on his face, and then he said, "Both of you are correct, so don't differ, for the nations before you differed, so they were destroyed}}
\hadithdefcmd{bukhari}{3477}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي شَقِيقٌ، قَالَ عَبْدُ اللَّهِ كَأَنِّي أَنْظُرُ إِلَى النَّبِيِّ صلى الله عليه وسلم يَحْكِي نَبِيًّا مِنَ الأَنْبِيَاءِ ضَرَبَهُ قَوْمُهُ فَأَدْمَوْهُ، وَهْوَ يَمْسَحُ الدَّمَ عَنْ وَجْهِهِ، وَيَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِقَوْمِي فَإِنَّهُمْ لاَ يَعْلَمُونَ ‏"‏‏.‏\hadithno{3477}\hadithtrans{Narrated `Abdullah:As if I saw the Prophet (ﷺ) talking about one of the prophets whose nation had beaten him and caused him to bleed, while he was cleaning the blood off his face and saying, "O Allah! Forgive my nation, for they have no knowledge}}
\hadithdefcmd{bukhari}{3478}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ عُقْبَةَ بْنِ عَبْدِ الْغَافِرِ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ رَجُلاً كَانَ قَبْلَكُمْ رَغَسَهُ اللَّهُ مَالاً فَقَالَ لِبَنِيهِ لَمَّا حُضِرَ أَىَّ أَبٍ كُنْتُ لَكُمْ قَالُوا خَيْرَ أَبٍ‏.‏ قَالَ فَإِنِّي لَمْ أَعْمَلْ خَيْرًا قَطُّ، فَإِذَا مُتُّ فَأَحْرِقُونِي ثُمَّ اسْحَقُونِي ثُمَّ ذَرُّونِي فِي يَوْمٍ عَاصِفٍ‏.‏ فَفَعَلُوا، فَجَمَعَهُ اللَّهُ عَزَّ وَجَلَّ، فَقَالَ مَا حَمَلَكَ قَالَ مَخَافَتُكَ‏.‏ فَتَلَقَّاهُ بِرَحْمَتِهِ ‏"‏‏.‏ وَقَالَ مُعَاذٌ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعْتُ عُقْبَةَ بْنَ عَبْدِ الْغَافِرِ، سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3478}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) said, "Amongst the people preceding your age, there was a man whom Allah had given a lot of money. While he was in his death-bed, he called his sons and said, 'What type of father have I been to you? They replied, 'You have been a good father.' He said, 'I have never done a single good deed; so when I die, burn me, crush my body, and scatter the resulting ashes on a windy day.' His sons did accordingly, but Allah gathered his particles and asked (him), 'What made you do so?' He replied, 'Fear of You.' So Allah bestowed His Mercy upon him (forgave him)}}
\hadithdefcmd{bukhari}{3479}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، قَالَ قَالَ عُقْبَةُ لِحُذَيْفَةَ أَلاَ تُحَدِّثُنَا مَا سَمِعْتَ مِنَ النَّبِيِّ صلى الله عليه وسلم‏.‏ قَالَ سَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ رَجُلاً حَضَرَهُ الْمَوْتُ، لَمَّا أَيِسَ مِنَ الْحَيَاةِ، أَوْصَى أَهْلَهُ إِذَا مُتُّ فَاجْمَعُوا لِي حَطَبًا كَثِيرًا، ثُمَّ أَوْرُوا نَارًا حَتَّى إِذَا أَكَلَتْ لَحْمِي، وَخَلَصَتْ إِلَى عَظْمِي، فَخُذُوهَا فَاطْحَنُوهَا، فَذَرُّونِي فِي الْيَمِّ فِي يَوْمٍ حَارٍّ أَوْ رَاحٍ‏.‏ فَجَمَعَهُ اللَّهُ، فَقَالَ لِمَ فَعَلْتَ قَالَ خَشْيَتَكَ‏.‏ فَغَفَرَ لَهُ ‏"‏‏.‏ قَالَ عُقْبَةُ وَأَنَا سَمِعْتُهُ يَقُولُ‏.‏ حَدَّثَنَا مُوسَى حَدَّثَنَا أَبُو عَوَانَةَ حَدَّثَنَا عَبْدُ الْمَلِكِ وَقَالَ ‏"‏ فِي يَوْمٍ رَاحٍ ‏"‏‏.‏\hadithno{3479}\hadithtrans{Narrated Rabi` bin Hirash:`Uqba said to Hudhaifa, "Won't you narrate to us what you heard from Allah's Messenger (ﷺ) ?" Hudhaifa said, "I heard him saying, 'Death approached a man and when he had no hope of surviving, he said to his family, 'When I die, gather for me much wood and build a fire (to burn me),. When the fire has eaten my flesh and reached my bones, take the bones and grind them and scatter the resulting powder in the sea on a hot (or windy) day.' (That was done.) But Allah collected his particles and asked (him), 'Why did you do so?' He replied, 'For fear of You.' So Allah forgave him." Narrated `Abdul Malik: As above, saying, "On a windy day}}
\hadithdefcmd{bukhari}{3480}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ الرَّجُلُ يُدَايِنُ النَّاسَ، فَكَانَ يَقُولُ لِفَتَاهُ إِذَا أَتَيْتَ مُعْسِرًا فَتَجَاوَزْ عَنْهُ، لَعَلَّ اللَّهُ أَنْ يَتَجَاوَزَ عَنَّا‏.‏ قَالَ فَلَقِيَ اللَّهَ فَتَجَاوَزَ عَنْهُ ‏"‏‏.‏\hadithno{3480}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A man used to give loans to the people and used to say to his servant, 'If the debtor is poor, forgive him, so that Allah may forgive us.' So when he met Allah (after his death), Allah forgave him}}
\hadithdefcmd{bukhari}{3481}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ كَانَ رَجُلٌ يُسْرِفُ عَلَى نَفْسِهِ، فَلَمَّا حَضَرَهُ الْمَوْتُ قَالَ لِبَنِيهِ إِذَا أَنَا مُتُّ فَأَحْرِقُونِي ثُمَّ اطْحَنُونِي ثُمَّ ذَرُّونِي فِي الرِّيحِ، فَوَاللَّهِ لَئِنْ قَدَرَ عَلَىَّ رَبِّي لَيُعَذِّبَنِّي عَذَابًا مَا عَذَّبَهُ أَحَدًا‏.‏ فَلَمَّا مَاتَ فُعِلَ بِهِ ذَلِكَ، فَأَمَرَ اللَّهُ الأَرْضَ، فَقَالَ اجْمَعِي مَا فِيكِ مِنْهُ‏.‏ فَفَعَلَتْ فَإِذَا هُوَ قَائِمٌ، فَقَالَ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ قَالَ يَا رَبِّ، خَشْيَتُكَ‏.‏ فَغَفَرَ لَهُ ‏"‏‏.‏ وَقَالَ غَيْرُهُ ‏"‏ مَخَافَتُكَ يَا رَبِّ ‏"‏‏.‏\hadithno{3481}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A man used to do sinful deeds, and when death came to him, he said to his sons, 'After my death, burn me and then crush me, and scatter the powder in the air, for by Allah, if Allah has control over me, He will give me such a punishment as He has never given to anyone else.' When he died, his sons did accordingly. Allah ordered the earth saying, 'Collect what you hold of his particles.' It did so, and behold! There he was (the man) standing. Allah asked (him), 'What made you do what you did?' He replied, 'O my Lord! I was afraid of You.' So Allah forgave him. " Another narrator said "The man said, Fear of You, O Lord}}
\hadithdefcmd{bukhari}{3482}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عُذِّبَتِ امْرَأَةٌ فِي هِرَّةٍ سَجَنَتْهَا حَتَّى مَاتَتْ، فَدَخَلَتْ فِيهَا النَّارَ، لاَ هِيَ أَطْعَمَتْهَا وَلاَ سَقَتْهَا إِذْ حَبَسَتْهَا، وَلاَ هِيَ تَرَكَتْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ ‏"‏‏.‏\hadithno{3482}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "A lady was punished because of a cat which she had imprisoned till it died. She entered the (Hell) Fire because of it, for she neither gave it food nor water as she had imprisoned it, nor set it free to eat from the vermin of the earth}}
\hadithdefcmd{bukhari}{3483}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، عَنْ زُهَيْرٍ، حَدَّثَنَا مَنْصُورٌ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، حَدَّثَنَا أَبُو مَسْعُودٍ، عُقْبَةُ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ مِمَّا أَدْرَكَ النَّاسُ مِنْ كَلاَمِ النُّبُوَّةِ، إِذَا لَمْ تَسْتَحِي فَافْعَلْ مَا شِئْتَ ‏"‏‏.‏\hadithno{3483}\hadithtrans{Narrated Abu Masud: `Uqba said:The Prophet (ﷺ) said, "One of the sayings of the prophets which the people have got is, 'If you do not feel ashamed, then do whatever you like}}
\hadithdefcmd{bukhari}{3484}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ سَمِعْتُ رِبْعِيَّ بْنَ حِرَاشٍ، يُحَدِّثُ عَنْ أَبِي مَسْعُودٍ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ مِمَّا أَدْرَكَ النَّاسُ مِنْ كَلاَمِ النُّبُوَّةِ إِذَا لَمْ تَسْتَحِي فَاصْنَعْ مَا شِئْتَ ‏"‏‏.‏\hadithno{3484}\hadithtrans{Narrated Abu Mas'ud:The Prophet (ﷺ) said, "One of the sayings of the prophets which the people have got is, 'If you do not feel ashamed, then do whatever you like}}
\hadithdefcmd{bukhari}{3485}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمٌ، أَنَّ ابْنَ عُمَرَ، حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا رَجُلٌ يَجُرُّ إِزَارَهُ مِنَ الْخُيَلاَءِ خُسِفَ بِهِ، فَهْوَ يَتَجَلْجَلُ فِي الأَرْضِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏ تَابَعَهُ عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ عَنِ الزُّهْرِيِّ‏.‏\hadithno{3485}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "While a man was walking, dragging his dress with pride, he was caused to be swallowed by the earth and will go on sinking in it till the Day of Resurrection}}
\hadithdefcmd{bukhari}{3487}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنِي ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ، بَيْدَ كُلُّ أُمَّةٍ أُوتُوا الْكِتَابَ مِنْ قَبْلِنَا وَأُوتِينَا مِنْ بَعْدِهِمْ، فَهَذَا الْيَوْمُ الَّذِي اخْتَلَفُوا، فَغَدًا لِلْيَهُودِ وَبَعْدَ غَدٍ لِلنَّصَارَى ‏"‏‏.‏ ‏"‏عَلَى كُلِّ مُسْلِمٍ فِى كُلِّ سَبْعَةِ أَيَّامٍ يَوْمٌ يَغْسِلُ رَأْسَهُ وَجَسَدَهُ‏"‏\hadithno{3487}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "We are the last (to come) but we will be the foremost on the Day of Resurrection, nations were given the Book (i.e. Scripture) before us, and we were given the Holy Book after them. This (i.e. Friday) is the day about which they differed. So the next day (i.e. Saturday) was prescribed for the Jews and the day after it (i.e. Sunday) for the Christians. It is incumbent on every Muslim to wash his head and body on a Day (i.e. Friday) (at least) in every seven days}}
\hadithdefcmd{bukhari}{3488}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ قَدِمَ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ الْمَدِينَةَ آخِرَ قَدْمَةٍ قَدِمَهَا، فَخَطَبَنَا فَأَخْرَجَ كُبَّةً مِنْ شَعَرٍ فَقَالَ مَا كُنْتُ أُرَى أَنَّ أَحَدًا يَفْعَلُ هَذَا غَيْرَ الْيَهُودِ، وَإِنَّ النَّبِيَّ صلى الله عليه وسلم سَمَّاهُ الزُّورَ ـ يَعْنِي الْوِصَالَ فِي الشَّعَرِ‏.‏ تَابَعَهُ غُنْدَرٌ عَنْ شُعْبَةَ‏.‏\hadithno{3488}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:When Muawiya bin Abu Sufyan came to Medina for the last time, he delivered a sermon before us. He took out a tuft of hair and said, "I never thought that someone other than the Jews would do such a thing (i.e. use false hair). The Prophet (ﷺ) named such a practice, 'Az-Zur' (i.e. falsehood)," meaning the use of false hair}}
