% Auto-generated chapter 1 for ibnmajah
% Hadiths in this chapter: 400

\hadithdefcmd{ibnmajah}{267}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَبِي رَيْحَانَةَ، عَنْ سَفِينَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَتَوَضَّأُ بِالْمُدِّ وَيَغْتَسِلُ بِالصَّاعِ ‏.‏\hadithno{267}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Safinah said:"The Messenger of Allah used to perform ablution with a Mudd (of water) and bath with a Sa}}
\hadithdefcmd{ibnmajah}{268}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ هَمَّامٍ، عَنْ قَتَادَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَتَوَضَّأُ بِالْمُدِّ وَيَغْتَسِلُ بِالصَّاعِ ‏.‏\hadithno{268}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to perform ablution with a Mudd (of water) and bath with a Sa}}
\hadithdefcmd{ibnmajah}{269}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الرَّبِيعُ بْنُ بَدْرٍ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَتَوَضَّأُ بِالْمُدِّ وَيَغْتَسِلُ بِالصَّاعِ ‏.‏\hadithno{269}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that:The Messenger of Allah used to perform ablution with a Mudd (of water) and bath with a Sa}}
\hadithdefcmd{ibnmajah}{270}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُؤَمَّلِ بْنِ الصَّبَّاحِ، وَعَبَّادُ بْنُ الْوَلِيدِ، قَالاَ حَدَّثَنَا بَكْرُ بْنُ يَحْيَى بْنِ زَبَّانَ، حَدَّثَنَا حِبَّانُ بْنُ عَلِيٍّ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلِ بْنِ أَبِي طَالِبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُجْزِئُ مِنَ الْوُضُوءِ مُدٌّ وَمِنَ الْغُسْلِ صَاعٌ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ لاَ يُجْزِئُنَا ‏.‏ فَقَالَ قَدْ كَانَ يُجْزِئُ مَنْ هُوَ خَيْرٌ مِنْكَ وَأَكْثَرُ شَعَرًا ‏.‏ يَعْنِي النَّبِيَّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{270}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Muhammed bin 'Aqil bin Abu Talib narrated from his father that his grandfather said:"The Messenger of Allah said: 'A Mudd is sufficient for the ablution and a Sa' is sufficient for the bath.' A man said: 'It is not sufficient for us.'" He (the narrator) said: "It was sufficient for one who is better than you and had more hair" meaning the Prophet}}
\hadithdefcmd{ibnmajah}{271}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، خَتَنُ الْمُقْرِئِ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالُوا حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ بْنِ أُسَامَةَ، عَنْ أَبِيهِ، أُسَامَةَ بْنِ عُمَيْرٍ الْهُذَلِيِّ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَقْبَلُ اللَّهُ صَلاَةً إِلاَّ بِطُهُورٍ وَلاَ يَقْبَلُ صَدَقَةً مِنْ غُلُولٍ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ بْنُ سَعِيدٍ، وَشَبَابَةُ بْنُ سَوَّارٍ، عَنْ شُعْبَةَ، نَحْوَهُ ‏.‏\hadithno{271}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Usamah bin 'Umair Al-Hudhali said:"The Messenger of Allah said: 'Allah does not accept any prayer without purification and He does not accept any charity from Ghulul.'" (Sahih) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{272}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ سِمَاكٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَقْبَلُ اللَّهُ صَلاَةً إِلاَّ بِطُهُورٍ وَلاَ صَدَقَةً مِنْ غُلُولٍ ‏"‏ ‏.‏\hadithno{272}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'Allah does not accept any prayer without purification, and He does not accept any charity from ghulul}}
\hadithdefcmd{ibnmajah}{273}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا أَبُو زُهَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سِنَانِ بْنِ سَعْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ يَقْبَلُ اللَّهُ صَلاَةً بِغَيْرِ طُهُورٍ وَلاَ يَقْبَلُ صَدَقَةً مِنْ غُلُولٍ ‏"‏ ‏.‏\hadithno{273}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"I heard the Messenger of Allah say: 'Allah does not accept any prayer without purification, and He does not accept any charity from Ghulul}}
\hadithdefcmd{ibnmajah}{274}{حَدَّثَنَا مُحَمَّدُ بْنُ عَقِيلٍ، حَدَّثَنَا الْخَلِيلُ بْنُ زَكَرِيَّا، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَقْبَلُ اللَّهُ صَلاَةً بِغَيْرِ طُهُورٍ وَلاَ صَدَقَةً مِنْ غُلُولٍ ‏"‏ ‏.‏\hadithno{274}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Bakrah said:"The Messenger of Allah said: 'Allah does not accept any Salat (prayer) without purification, and He does not accept any charity from Ghulul}}
\hadithdefcmd{ibnmajah}{275}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ مُحَمَّدٍ ابْنِ الْحَنَفِيَّةِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مِفْتَاحُ الصَّلاَةِ الطُّهُورُ وَتَحْرِيمُهَا التَّكْبِيرُ وَتَحْلِيلُهَا التَّسْلِيمُ ‏"‏ ‏.‏\hadithno{275}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muhammed bin Al-Hanafiyyah that his father said:"The Messenger of Allah said: 'The key to prayer is purification, its opening is to say 'Allahu Akbar' and its closing is to say As-salamu 'alaikum}}
\hadithdefcmd{ibnmajah}{276}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ أَبِي سُفْيَانَ، طَرِيفٍ السَّعْدِيِّ ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ أَبِي سُفْيَانَ السَّعْدِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مِفْتَاحُ الصَّلاَةِ الطُّهُورُ وَتَحْرِيمُهَا التَّكْبِيرُ وَتَحْلِيلُهَا التَّسْلِيمُ ‏"‏ ‏.‏\hadithno{276}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:The Messenger of Allah said: "The key to prayer is purification, its opening is to say Allahu Akbar and its closing is to say As-salamu 'alaikum}}
\hadithdefcmd{ibnmajah}{277}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اسْتَقِيمُوا وَلَنْ تُحْصُوا وَاعْلَمُوا أَنَّ خَيْرَ أَعْمَالِكُمُ الصَّلاَةُ وَلاَ يُحَافِظُ عَلَى الْوُضُوءِ إِلاَّ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{277}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Thawban said:"The Messenger of Allah said: 'Adhere to righteousness even though you will not be able to do all acts of virtue. Know that the best of your deeds is Salat (prayer) and that no one maintains his ablution except a believer}}
\hadithdefcmd{ibnmajah}{278}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ لَيْثٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اسْتَقِيمُوا وَلَنْ تُحْصُوا وَاعْلَمُوا أَنَّ مِنْ أَفْضَلِ أَعْمَالِكُمُ الصَّلاَةَ وَلاَ يُحَافِظُ عَلَى الْوُضُوءِ إِلاَّ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{278}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah said: 'Adhere to righteousness even though you will not be able to do all acts of virtue. Know that among the best of your deeds is prayer and that no one maintains his ablution except a believer}}
\hadithdefcmd{ibnmajah}{279}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنِي إِسْحَاقُ بْنُ أَسِيدٍ، عَنْ أَبِي حَفْصٍ الدِّمَشْقِيِّ، عَنْ أَبِي أُمَامَةَ، يَرْفَعُ الْحَدِيثَ قَالَ ‏ "‏ اسْتَقِيمُوا وَنِعِمَّا أَنْ تَسْتَقِيمُوا وَخَيْرُ أَعْمَالِكُمُ الصَّلاَةُ وَلاَ يُحَافِظُ عَلَى الْوُضُوءِ إِلاَّ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{279}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah said, in a marfu' Hadith:"Adhere to righteousness and it is a blessing if you are able to do so. Know that the best of your deeds is prayer and that no one maintains his ablution except a believer}}
\hadithdefcmd{ibnmajah}{280}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبِ بْنِ شَابُورٍ، أَخْبَرَنِي مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ أَخِيهِ، أَنَّهُ أَخْبَرَهُ عَنْ جَدِّهِ أَبِي سَلاَّمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ أَبِي مَالِكٍ الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِسْبَاغُ الْوُضُوءِ شَطْرُ الإِيمَانِ وَالْحَمْدُ لِلَّهِ تَمْلأُ الْمِيزَانَ وَالتَّسْبِيحُ وَالتَّكْبِيرُ مِلْءُ السَّمَوَاتِ وَالأَرْضِ وَالصَّلاَةُ نُورٌ وَالزَّكَاةُ بُرْهَانٌ وَالصَّبْرُ ضِيَاءٌ وَالْقُرْآنُ حُجَّةٌ لَكَ أَوْ عَلَيْكَ كُلُّ النَّاسِ يَغْدُو فَبَائِعٌ نَفْسَهُ فَمُعْتِقُهَا أَوْ مُوبِقُهَا ‏"‏ ‏.‏\hadithno{280}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Malik Ash'ari that:The Messenger of Allah said: "Performing ablution properly is half of faith, saying Al-Hamdu Lillah fills the Scale (of good deeds), saying Subhan-Allah and Allahu Akbar fills the heavens and the earth, prayer is light, Zakat is proof, patience is brightness and the Qur'an is proof for you or against you. Every person goes out in the morning to sell his soul, so he either frees it or destroys it}}
\hadithdefcmd{ibnmajah}{281}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ أَتَى الْمَسْجِدَ لاَ يَنْهَزُهُ إِلاَّ الصَّلاَةُ لَمْ يَخْطُ خَطْوَةً إِلاَّ رَفَعَهُ اللَّهُ عَزَّ وَجَلَّ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً حَتَّى يَدْخُلَ الْمَسْجِدَ ‏"‏ ‏.‏\hadithno{281}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'When anyone of you performs ablution and does it well, then he comes to the mosque for no other purpose than prayer, he does not take one step but Allah will raise him one degree (in status) thereby, and remove one sin from him thereby, until he enters the mosque}}
\hadithdefcmd{ibnmajah}{282}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنِي حَفْصُ بْنُ مَيْسَرَةَ، حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ الصُّنَابِحِيِّ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ تَوَضَّأَ فَمَضْمَضَ وَاسْتَنْشَقَ خَرَجَتْ خَطَايَاهُ مِنْ فَمِهِ وَأَنْفِهِ فَإِذَا غَسَلَ وَجْهَهُ خَرَجَتْ خَطَايَاهُ مِنْ وَجْهِهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَشْفَارِ عَيْنَيْهِ فَإِذَا غَسَلَ يَدَيْهِ خَرَجَتْ خَطَايَاهُ مِنْ يَدَيْهِ فَإِذَا مَسَحَ رَأْسَهُ خَرَجَتْ خَطَايَاهُ مِنْ رَأْسِهِ حَتَّى تَخْرُجَ مِنْ أُذُنَيْهِ فَإِذَا غَسَلَ رِجْلَيْهِ خَرَجَتْ خَطَايَاهُ مِنْ رِجْلَيْهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَظْفَارِ رِجْلَيْهِ وَكَانَتْ صَلاَتُهُ وَمَشْيُهُ إِلَى الْمَسْجِدِ نَافِلَةً ‏"‏ ‏.‏\hadithno{282}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah As-Sunabihi that:The Messenger of Allah said: "Whoever performs ablution and rinses his mouth and nose, his sins will exit through his mouth and nose. When he washes his face, his sins will exit from his face, even from beneath his eyelids. When he washes his hands, his sins will exit from his hands. When he wipes his head, his sins will exit from his head, and even from his ears. When he washes his feet, his sins will exit from his feet, even from beneath his toenails. Then his prayer and walking towards the mosque will earn extra merit for him}}
\hadithdefcmd{ibnmajah}{283}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا غُنْدَرٌ، مُحَمَّدُ بْنُ جَعْفَرٍ عَنْ شُعْبَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ يَزِيدَ بْنِ طَلْقٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ عَمْرِو بْنِ عَبَسَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ الْعَبْدَ إِذَا تَوَضَّأَ فَغَسَلَ يَدَيْهِ خَرَّتْ خَطَايَاهُ مِنْ يَدَيْهِ فَإِذَا غَسَلَ وَجْهَهُ خَرَّتْ خَطَايَاهُ مِنْ وَجْهِهِ فَإِذَا غَسَلَ ذِرَاعَيْهِ وَمَسَحَ بِرَأْسِهِ خَرَّتْ خَطَايَاهُ مِنْ ذِرَاعَيْهِ وَرَأْسِهِ فَإِذَا غَسَلَ رِجْلَيْهِ خَرَّتْ خَطَايَاهُ مِنْ رِجْلَيْهِ ‏"‏ ‏.‏\hadithno{283}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin 'Abasah said:"The Messenger of Allah said: 'When a person performs ablution and washes his hands, his sins exit through his hands. When he washes his face, his sins exit through his face. When he washes his forearms and wipes his head, his sins exit though his forearms and head. When he washes his feet, his sins exit through his feet}}
\hadithdefcmd{ibnmajah}{284}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ حَدَّثَنَا حَمَّادٌ، عَنْ عَاصِمٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ كَيْفَ تَعْرِفُ مَنْ لَمْ تَرَ مِنْ أُمَّتِكَ قَالَ ‏ "‏ غُرٌّ مُحَجَّلُونَ بُلْقٌ مِنْ آثَارِ الطُّهُورِ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ الْقَطَّانُ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا أَبُو الْوَلِيدِ، فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{284}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Mas'ud said:"It was said: 'O Messenger of Allah, how will you recognize those whom you have not seen of your Ummah?' He said: 'From the blazes of their foreheads and feet, like horses with black and white traces (which make them distinct from others) which are the traces of ablution.'" (Hasan) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{285}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي شَقِيقُ بْنُ سَلَمَةَ، حَدَّثَنِي حُمْرَانُ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ قَالَ رَأَيْتُ عُثْمَانَ بْنَ عَفَّانَ قَاعِدًا فِي الْمَقَاعِدِ فَدَعَا بِوَضُوءٍ فَتَوَضَّأَ ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي مَقْعَدِي هَذَا تَوَضَّأَ مِثْلَ وُضُوئِي هَذَا ثُمَّ قَالَ ‏"‏ مَنْ تَوَضَّأَ مِثْلَ وُضُوئِي هَذَا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ وَلاَ تَغْتَرُّوا ‏"‏ ‏.‏ حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى، حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي عِيسَى بْنُ طَلْحَةَ، حَدَّثَنِي حُمْرَانُ، عَنْ عُثْمَانَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{285}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Humran the freed slave of 'Uthman bin 'Affan said:"I saw 'Uthman bin 'Affan sitting in Maqa'id. He called for water and he performed ablution, the he said: 'I saw the Messenger of Allah sitting in this place where I am sitting, performing ablution as I have done. Then he said: "Whoever performs ablution as I have done, his previous sins will be forgiven." And the Messenger of Allah said: "And do not be conceited (due to this great virtue)." (Sahih) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{286}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَأَبِي، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، وَحُصَيْنٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا قَامَ مِنَ اللَّيْلِ يَتَهَجَّدُ يَشُوصُ فَاهُ بِالسِّوَاكِ ‏.‏\hadithno{286}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Hudhaifah said:"Whenever the Messenger of Allah got up for prayer at night to pray Tahajjud (night optional prayer), he would clean his mouth with the tooth stick}}
\hadithdefcmd{ibnmajah}{287}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِالسِّوَاكِ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏\hadithno{287}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Were it not that it would be too difficult for my Ummah (nation), I would have commanded them to use the tooth stick at every time of prayer}}
\hadithdefcmd{ibnmajah}{288}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَثَّامُ بْنُ عَلِيٍّ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي بِاللَّيْلِ رَكْعَتَيْنِ رَكْعَتَيْنِ ثُمَّ يَنْصَرِفُ فَيَسْتَاكُ ‏.‏\hadithno{288}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah used to pray in the night (Qiyamul-Lail) two Rak'ah by two, then when he finished he would use the tooth stick}}
\hadithdefcmd{ibnmajah}{289}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، حَدَّثَنَا عُثْمَانُ بْنُ أَبِي الْعَاتِكَةِ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ تَسَوَّكُوا فَإِنَّ السِّوَاكَ مَطْهَرَةٌ لِلْفَمِ مَرْضَاةٌ لِلرَّبِّ وَمَا جَاءَنِي جِبْرِيلُ إِلاَّ أَوْصَانِي بِالسِّوَاكِ حَتَّى لَقَدْ خَشِيتُ أَنْ يُفْرَضَ عَلَىَّ وَعَلَى أُمَّتِي وَلَوْلاَ أَنِّي أَخَافُ أَنْ أَشُقَّ عَلَى أُمَّتِي لَفَرَضْتُهُ لَهُمْ وَإِنِّي لأَسْتَاكُ حَتَّى لَقَدْ خَشِيتُ أَنْ أُحْفِيَ مَقَادِمَ فَمِي ‏"‏ ‏.‏\hadithno{289}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that:The Messenger of Allah said: "Use the tooth stick, for the tooth stick purifies the mouth and is pleasing to the Lord. Jibril never came to me but he advised me to use the tooth stick, until I feared that it would be made obligatory for me and my Ummah. Were it not that I fear that it would be too difficult for my Ummah, I would have enjoined it upon them. And I use the tooth stick until I fear that I may make the front of my mouth sore.' (i.e. my gums) (or cause my teeth to fall out due to brushing them so often)}}
\hadithdefcmd{ibnmajah}{290}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحِ بْنِ هَانِئٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَ قُلْتُ أَخْبِرِينِي بِأَىِّ، شَىْءٍ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَبْدَأُ إِذَا دَخَلَ عَلَيْكِ قَالَتْ كَانَ إِذَا دَخَلَ يَبْدَأُ بِالسِّوَاكِ ‏.‏\hadithno{290}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Miqdam bin Shuraih bin Hani' that his father said:"I said to 'Aishah: 'Tell me, what was the first thing that the Messenger of Allah did when he entered upon you?' She said: 'The first thing he would do would be to use the tooth stick}}
\hadithdefcmd{ibnmajah}{291}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا بَحْرُ بْنُ كَنِيزٍ، عَنْ عُثْمَانَ بْنِ سَاجٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ إِنَّ أَفْوَاهَكُمْ طُرُقٌ لِلْقُرْآنِ فَطَيِّبُوهَا بِالسِّوَاكِ ‏.‏\hadithno{291}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali bin Abu Talib said:"Your mouths are the paths of the Qur'an, so perfume them with the tooth stick}}
\hadithdefcmd{ibnmajah}{292}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْفِطْرَةُ خَمْسٌ - أَوْ خَمْسٌ مِنَ الْفِطْرَةِ - الْخِتَانُ وَالاِسْتِحْدَادُ وَتَقْلِيمُ الأَظْفَارِ وَنَتْفُ الإِبِطِ وَقَصُّ الشَّارِبِ ‏"‏ ‏.‏\hadithno{292}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The deeds connected to the Fitrah are five (or five things are connected to the Fitrah): circumcision, shaving the pubic hairs, clipping the nails, plucking the armpit hairs and trimming the mustache}}
\hadithdefcmd{ibnmajah}{293}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا زَكَرِيَّا بْنُ أَبِي زَائِدَةَ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ طَلْقِ بْنِ حَبِيبٍ، عَنِ ابْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عَشْرٌ مِنَ الْفِطْرَةِ قَصُّ الشَّارِبِ وَإِعْفَاءُ اللِّحْيَةِ وَالسِّوَاكُ وَالاِسْتِنْشَاقُ بِالْمَاءِ وَقَصُّ الأَظْفَارِ وَغَسْلُ الْبَرَاجِمِ وَنَتْفُ الإِبِطِ وَحَلْقُ الْعَانَةِ وَانْتِقَاصُ الْمَاءِ ‏"‏ ‏.‏ يَعْنِي الاِسْتِنْجَاءَ ‏.‏ قَالَ زَكَرِيَّا قَالَ مُصْعَبٌ وَنَسِيتُ الْعَاشِرَةَ إِلاَّ أَنْ تَكُونَ الْمَضْمَضَةَ ‏.‏\hadithno{293}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'Ten things are connected to the Fitrah: trimming the mustache, letting the beard grow, using the tooth stick, rinsing out the nostrils with water, clipping the nails, washing the joints, plucking the armpit hairs, shaving the pubic hairs, washing the private parts with water.'"(One of the narrators) Zakariyya said: "Mus'ab said: 'I have forgotten the tenth thing, but it may have been rinsing out the mouth}}
\hadithdefcmd{ibnmajah}{294}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا حَمَّادٌ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَلَمَةَ بْنِ مُحَمَّدِ بْنِ عَمَّارِ بْنِ يَاسِرٍ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مِنَ الْفِطْرَةِ الْمَضْمَضَةُ وَالاِسْتِنْشَاقُ وَالسِّوَاكُ وَقَصُّ الشَّارِبِ وَتَقْلِيمُ الأَظْفَارِ وَنَتْفُ الإِبِطِ وَالاِسْتِحْدَادُ وَغَسْلُ الْبَرَاجِمِ وَالاِنْتِضَاحُ وَالاِخْتِتَانُ ‏"‏ ‏.‏ حَدَّثَنَا جَعْفَرُ بْنُ أَحْمَدَ بْنِ عُمَرَ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، مِثْلَهُ ‏.‏\hadithno{294}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ammar bin Yasir that:The Messenger of Allah said: "Part of the Fitrah is rinsing out the mouth, rinsing out the nostrils, using the tooth stick, trimming the mustache, clipping the nails, plucking the armpit hairs, shaving the pubic hairs, washing the joints, washing the private parts and circumcision.'" (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{295}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ وُقِّتَ لَنَا فِي قَصِّ الشَّارِبِ وَحَلْقِ الْعَانَةِ وَنَتْفِ الإِبْطِ وَتَقْلِيمِ الأَظْفَارِ أَنْ لاَ نَتْرُكَ أَكْثَرَ مِنْ أَرْبَعِينَ لَيْلَةً ‏.‏\hadithno{295}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:"We were given a time limit with regard to trimming the mustache, shaving the pubic hairs, plucking the armpit hairs and clipping the nails. We were not to leave that for more than forty days}}
\hadithdefcmd{ibnmajah}{296}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ هَذِهِ الْحُشُوشَ مُحْتَضَرَةٌ فَإِذَا دَخَلَ أَحَدُكُمْ فَلْيَقُلِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْخُبُثِ وَالْخَبَائِثِ ‏"‏ ‏.‏ حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ الْعَتَكِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، ح وَحَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَبْدَةُ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْقَاسِمِ بْنِ عَوْفٍ الشَّيْبَانِيِّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ قَالَ فَذَكَرَ الْحَدِيثَ ‏.‏\hadithno{296}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Zaid bin Arqam said:"The Messenger of Allah said: 'These Hushush (waste areas) are visited (by devils), so when anyone of you enters, let him say: 'Allahumma inni a`udhu bika minal-khubthi wal-khaba'ith (O Allah, I seek refuge with You from male and female devils).'" (Sahih) Other chains with similar wording}}
\hadithdefcmd{ibnmajah}{297}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، حَدَّثَنَا الْحَكَمُ بْنُ بَشِيرِ بْنِ سَلْمَانَ، حَدَّثَنَا خَلاَّدٌ الصَّفَّارُ، عَنِ الْحَكَمِ النَّصْرِيِّ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي جُحَيْفَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سِتْرُ مَا بَيْنَ الْجِنِّ وَعَوْرَاتِ بَنِي آدَمَ إِذَا دَخَلَ الْكَنِيفَ أَنْ يَقُولَ بِسْمِ اللَّهِ ‏"‏ ‏.‏\hadithno{297}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah said: 'The screen between the Jinn and the nakedness of the sons of Adam is that when a person enters the Kanif, he should say: Bismillah (in the name of Allah)}}
\hadithdefcmd{ibnmajah}{298}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا دَخَلَ الْخَلاَءَ قَالَ ‏ "‏ أَعُوذُ بِاللَّهِ مِنَ الْخُبُثِ وَالْخَبَائِثِ ‏"‏ ‏.‏\hadithno{298}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:"Whenever the Messenger of Allah entered the toilet, he would say: 'A'udhu Billahi minal-khubthi wa'l-khaba'ith (I seek refuge with Allah from male and female devils)}}
\hadithdefcmd{ibnmajah}{299}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَعْجِزْ أَحَدُكُمْ إِذَا دَخَلَ مِرْفَقَهُ أَنْ يَقُولَ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الرِّجْسِ النَّجَسِ الْخَبِيثِ الْمُخْبِثِ الشَّيْطَانِ الرَّجِيمِ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ وَحَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، فَذَكَرَ نَحْوَهُ وَلَمْ يَقُلْ فِي حَدِيثِهِ مِنَ الرِّجْسِ النَّجَسِ إِنَّمَا قَالَ مِنَ الْخَبِيثِ الْمُخْبِثِ الشَّيْطَانِ الرَّجِيمِ ‏.‏\hadithno{299}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that:The Messenger of Allah said: "None of you should fail to say, when he enters his toilet: 'Allahumma inni a`udhu bika minar-rijsin-najis, al-khabithil-mukhbith, ash-Shaitanir-rajim (O Allah, I seek refuge with You from the filthy and impure, the evil one with evil companions, the accursed Shaitan).'" (Da'if) Another chain with a slightly different wording from Ibn Abi Maryam who mentioned similar, but he did not say in his narration: "Minar-rijsin-najis (From the filthy and the impure)" he only said: "Minal-khabithil-mukhbith, ash-Shaitanir-rajim (From the evil one with evil companions, the accursed Shaitan)}}
\hadithdefcmd{ibnmajah}{300}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا إِسْرَائِيلُ، حَدَّثَنَا يُوسُفُ بْنُ أَبِي بُرْدَةَ، سَمِعْتُ أَبِي يَقُولُ، دَخَلْتُ عَلَى عَائِشَةَ فَسَمِعْتُهَا تَقُولُ، كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا خَرَجَ مِنَ الْغَائِطِ قَالَ ‏ "‏ غُفْرَانَكَ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ وَأَخْبَرَنَا أَبُو حَاتِمٍ، حَدَّثَنَا أَبُو غَسَّانَ النَّهْدِيُّ، حَدَّثَنَا إِسْرَائِيلُ، نَحْوَهُ ‏.‏\hadithno{300}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Yusuf bin Abi Burdah narrated:"I heard my father say: 'I entered upon 'Aishah, and I heard her say: "When the Messenger of Allah exited the toilet, he would say: Ghufranaka (I seek Your forgiveness).'" (Sahih) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{301}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنِ الْحَسَنِ، وَقَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا خَرَجَ مِنَ الْخَلاَءِ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَذْهَبَ عَنِّي الأَذَى وَعَافَانِي ‏"‏ ‏.‏\hadithno{301}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"Whenever the Prophet exited the toilet, he would say: 'Al-hamdu lillahilladhi adhhaba 'annial-adha wa 'afani (Praise is to Allah Who has relieved me of impurity and given me good health)}}
\hadithdefcmd{ibnmajah}{302}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ خَالِدِ بْنِ سَلَمَةَ، عَنْ عَبْدِ اللَّهِ الْبَهِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَذْكُرُ اللَّهَ عَلَى كُلِّ أَحْيَانِهِ ‏.‏\hadithno{302}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Urwah narrated from 'Aishah that:The Messenger of Allah used to remember Allah in all circumstances}}
\hadithdefcmd{ibnmajah}{303}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا دَخَلَ الْخَلاَءَ وَضَعَ خَاتَمَهُ ‏.‏\hadithno{303}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that:When the Prophet entered the toilet, he would take off his ring}}
\hadithdefcmd{ibnmajah}{304}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ أَشْعَثَ بْنِ عَبْدِ اللَّهِ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي مُسْتَحَمِّهِ فَإِنَّ عَامَّةَ الْوَسْوَاسِ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ بْنُ مَاجَهْ سَمِعْتُ عَلِيَّ بْنَ مُحَمَّدٍ الطَّنَافِسِيَّ يَقُولُ إِنَّمَا هَذَا فِي الْحَفِيرَةِ فَأَمَّا الْيَوْمَ فَلاَ ‏.‏ فَمُغْتَسَلاَتُهُمُ الْجَصُّ وَالصَّارُوجُ وَالْقِيرُ فَإِذَا بَالَ فَأَرْسَلَ عَلَيْهِ الْمَاءَ لاَ بَأْسَ بِهِ ‏.‏\hadithno{304}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mughaffal said:"The Messenger of Allah said: 'None of you should urinate in his wash area for most of the insinuating thoughts come from that.'" (Da'if) Abu 'Abdullah bin Majah said: ("Abul-Hasan said: 'I heard Muhammed bin Yazid saying:) ''Ali bin Muhammed At-Tanafisi said: 'This (prohibition) applies to cases where the ground (in the place used for washing) was soft. But nowadays this does not apply, because the baths you use now are built of plaster, Saruj and tar; so if a person urinates there then pours water over it, that clears it away, and that is fine}}
\hadithdefcmd{ibnmajah}{305}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، وَهُشَيْمٌ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَتَى سُبَاطَةَ قَوْمٍ فَبَالَ عَلَيْهَا قَائِمًا ‏.‏\hadithno{305}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Hudhaifah that:The Messenger of Allah came to the garbage dump of some people and he urinated on it standing up}}
\hadithdefcmd{ibnmajah}{306}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَتَى سُبَاطَةَ قَوْمٍ فَبَالَ قَائِمًا ‏.‏ قَالَ شُعْبَةُ قَالَ عَاصِمٌ يَوْمَئِذٍ وَهَذَا الأَعْمَشُ يَرْوِيهِ عَنْ أَبِي وَائِلٍ عَنْ حُذَيْفَةَ وَمَا حَفِظَهُ ‏.‏ فَسَأَلْتُ عَنْهُ مَنْصُورًا فَحَدَّثَنِيهِ عَنْ أَبِي وَائِلٍ عَنْ حُذَيْفَةَ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَتَى سُبَاطَةَ قَوْمٍ فَبَالَ قَائِمًا ‏.‏\hadithno{306}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shu'bah narrated from 'Asim from Abu Wa'il from Mughirah bin Shu'bah that:The Messenger of Allah came to the garbage dump of some people and urinated while standing up. (Hasan) Shu'bah said: "That day, 'Asim said: 'Amash reported this from Abu Wa'il, from Hudhaifah, but he did not remember it (correctly). So I asked Mansur about it, and he narrated it to me from Abu Wa'il, from Hudhaifah, that the Prophet came to a dump of some people and urinated while standing}}
\hadithdefcmd{ibnmajah}{307}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَإِسْمَاعِيلُ بْنُ مُوسَى السُّدِّيُّ، قَالُوا حَدَّثَنَا شَرِيكٌ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحِ بْنِ هَانِئٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَنْ حَدَّثَكَ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بَالَ قَائِمًا فَلاَ تُصَدِّقْهُ أَنَا رَأَيْتُهُ يَبُولُ قَاعِدًا ‏.‏\hadithno{307}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"If anyone tells you that the Messenger of Allah urinated while standing, do not believe him, for I (always) saw him urinating while sitting down}}
\hadithdefcmd{ibnmajah}{308}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ الْكَرِيمِ بْنِ أَبِي أُمَيَّةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ رَآنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَنَا أَبُولُ قَائِمًا فَقَالَ ‏ "‏ يَا عُمَرُ لاَ تَبُلْ قَائِمًا ‏"‏ ‏.‏ فَمَا بُلْتُ قَائِمًا بَعْدُ ‏.‏\hadithno{308}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Umar said:"The Messenger of Allah saw me urinating while standing, and he said: 'O 'Umar, do not urinate standing up.' So I never urinated whilst standing after that}}
\hadithdefcmd{ibnmajah}{309}{حَدَّثَنَا يَحْيَى بْنُ الْفَضْلِ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا عَدِيُّ بْنُ الْفَضْلِ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، عَنْ أَبِي نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَبُولَ قَائِمًا ‏.‏ سَمِعْتُ مُحَمَّدَ بْنَ يَزِيدَ أَبَا عَبْدِ اللَّهِ يَقُولُ سَمِعْتُ أَحْمَدَ بْنَ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيَّ يَقُولُ قَالَ سُفْيَانُ الثَّوْرِيُّ - فِي حَدِيثِ عَائِشَةَ أَنَا رَأَيْتُهُ يَبُولُ قَاعِدًا - قَالَ الرَّجُلُ أَعْلَمُ بِهَذَا مِنْهَا ‏.‏ قَالَ أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ كَانَ مِنْ شَأْنِ الْعَرَبِ الْبَوْلُ قَائِمًا أَلاَ تَرَاهُ فِي حَدِيثِ عَبْدِ الرَّحْمَنِ ابْنِ حَسَنَةَ يَقُولُ قَعَدَ يَبُولُ كَمَا تَبُولُ الْمَرْأَةُ ‏.‏\hadithno{309}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah forbade us to urinate while standing." (Da'if) I heard Muhammed bin Yazid, Abu 'Abdullah, say: "I heard Ahmad bin 'Abdur-Rahman Al-Makhzumi say: 'Sufyan Ath-Thawri said concerning the Hadith of 'Aisha- 'I (always) saw him urinating whilst sitting down' - a man knows more about that (about such matters) than she.' Ahmad bin 'Abdur-Rahman said: 'It was the custom of the Arabs to urinate standing up. Do you not see that in the Hadith of 'Abdur-Rahman bin Hasanah it was said: 'He sits down to urinate as a woman does}}
\hadithdefcmd{ibnmajah}{310}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبِ بْنِ أَبِي الْعِشْرِينَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، أَخْبَرَنِي أَبِي أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا بَالَ أَحَدُكُمْ فَلاَ يَمَسَّ ذَكَرَهُ بِيَمِينِهِ وَلاَ يَسْتَنْجِ بِيَمِينِهِ ‏"‏ ‏.‏ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، بِإِسْنَادِهِ نَحْوَهُ ‏.‏\hadithno{310}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abdullah bin Abu Qatadah said:"My father told me that he heard the Messenger of Allah say: 'When anyone of you urinates, let him not touch his penis with his right hand nor clean himself with his right hand.'" Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{311}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الصَّلْتُ بْنُ دِينَارٍ، عَنْ عُقْبَةَ بْنِ صُهْبَانَ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ، يَقُولُ مَا تَغَنَّيْتُ وَلاَ تَمَنَّيْتُ وَلاَ مَسِسْتُ ذَكَرِي بِيَمِينِي مُنْذُ بَايَعْتُ بِهَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{311}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Uqbah bin Suhban said:"I heard 'Uthman bin 'Affan say: 'I never sang a song or told a lie or touched my penis with my right hand after I swore on oath of allegiance to the Messenger of Allah to that effect}}
\hadithdefcmd{ibnmajah}{312}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، وَعَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا اسْتَطَابَ أَحَدُكُمْ فَلاَ يَسْتَطِبْ بِيَمِينِهِ لِيَسْتَنْجِ بِشِمَالِهِ ‏"‏ ‏.‏\hadithno{312}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'When anyone of you cleans himself, he should not clean himself with his right hand. Let him clean himself with his left hand}}
\hadithdefcmd{ibnmajah}{313}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّمَا أَنَا لَكُمْ مِثْلُ الْوَالِدِ لِوَلَدِهِ أُعَلِّمُكُمْ إِذَا أَتَيْتُمُ الْغَائِطَ فَلاَ تَسْتَقْبِلُوا الْقِبْلَةَ وَلاَ تَسْتَدْبِرُوهَا ‏"‏ ‏.‏ وَأَمَرَ بِثَلاَثَةِ أَحْجَارٍ وَنَهَى عَنِ الرَّوْثِ وَالرِّمَّةِ وَنَهَى أَنْ يَسْتَطِيبَ الرَّجُلُ بِيَمِينِهِ ‏.‏\hadithno{313}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'I am to you like a father to his son, and I teach you. So when you go to relieve yourselves, do not face the Qiblah or turn your backs towards it.' He ordered us to use three pebbles, and he forbade us to use dung and bones, and he forbade cleaning oneself with the right hand}}
\hadithdefcmd{ibnmajah}{314}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ زُهَيْرٍ، عَنْ أَبِي إِسْحَاقَ، - قَالَ لَيْسَ أَبُو عُبَيْدَةَ ذَكَرَهُ وَلَكِنْ عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ - عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَتَى الْخَلاَءَ فَقَالَ ‏"‏ ائْتِنِي بِثَلاَثَةِ أَحْجَارٍ ‏"‏ ‏.‏ فَأَتَيْتُهُ بِحَجَرَيْنِ وَرَوْثَةٍ فَأَخَذَ الْحَجَرَيْنِ وَأَلْقَى الرَّوْثَةَ وَقَالَ ‏"‏ هِيَ رِجْسٌ ‏"‏ ‏.‏\hadithno{314}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah bin Mas'ud:"The Messenger of Allah went to the toilet and said: 'Bring me three stones.' So I brought him two stones and a piece of dung. He took the two stones and threw the dung away, saying: 'It is impure}}
\hadithdefcmd{ibnmajah}{315}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِي خُزَيْمَةَ، عَنْ عُمَارَةَ بْنِ خُزَيْمَةَ، عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ فِي الاِسْتِنْجَاءِ ثَلاَثَةُ أَحْجَارٍ لَيْسَ فِيهَا رَجِيعٌ ‏"‏ ‏.‏\hadithno{315}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Khuzaimah bin Thabit said:"The Messenger of Allah said: 'For cleaning yourself you need three stones, no one of them being dung}}
\hadithdefcmd{ibnmajah}{316}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ سَلْمَانَ، قَالَ قَالَ لَهُ بَعْضُ الْمُشْرِكِينَ وَهُمْ يَسْتَهْزِئُونَ بِهِ إِنِّي أَرَى صَاحِبَكُمْ يُعَلِّمُكُمْ كُلَّ شَىْءٍ حَتَّى الْخِرَاءَةِ ‏.‏ قَالَ أَجَلْ أَمَرَنَا أَنْ لاَ نَسْتَقْبِلَ الْقِبْلَةَ وَأَنْ لاَ نَسْتَنْجِيَ بِأَيْمَانِنَا وَلاَ نَكْتَفِيَ بِدُونِ ثَلاَثَةِ أَحْجَارٍ لَيْسَ فِيهَا رَجِيعٌ وَلاَ عَظْمٌ ‏.‏\hadithno{316}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Salman said that one of the idolaters said to him, while they were making fun of him:"I see that your companion (the Prophet) is teaching you everything, even how to relieve yourselves?" He said: "Yes indeed. He has ordered us not to face the Qiblah (prayer direction) nor to clean ourselves with our right hands, and not to be content with anything less than three stones, which are not to include any excrement or bones}}
\hadithdefcmd{ibnmajah}{317}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ الْحَارِثِ بْنِ جَزْءٍ الزُّبَيْدِيَّ، يَقُولُ أَنَا أَوَّلُ، مَنْ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ مُسْتَقْبِلَ الْقِبْلَةِ ‏"‏ ‏.‏ وَأَنَا أَوَّلُ مَنْ حَدَّثَ النَّاسَ بِذَلِكَ ‏.‏\hadithno{317}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Harith bin Jaz' Az-Zubaidi said:"I am the first one who heard the Prophet say: 'No one among you should urinate facing towards the Qiblah,' and I am the first one who told the people of that}}
\hadithdefcmd{ibnmajah}{318}{حَدَّثَنَا أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، أَنَّهُ سَمِعَ أَبَا أَيُّوبَ الأَنْصَارِيَّ، يَقُولُ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَسْتَقْبِلَ الَّذِي يَذْهَبُ إِلَى الْغَائِطِ الْقِبْلَةَ وَقَالَ ‏ "‏ شَرِّقُوا أَوْ غَرِّبُوا ‏"‏ ‏.‏\hadithno{318}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Ayyub Ansari said:"The Messenger of Allah forbade the person who went to the Gha'it to face the Qiblah. He said: 'face towards the east or the west}}
\hadithdefcmd{ibnmajah}{319}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، حَدَّثَنِي عَمْرُو بْنُ يَحْيَى الْمَازِنِيُّ، عَنْ أَبِي زَيْدٍ، مَوْلَى الثَّعْلَبِيِّينَ عَنْ مَعْقِلِ بْنِ أَبِي مَعْقِلٍ الأَسَدِيِّ، وَقَدْ صَحِبَ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَسْتَقْبِلَ الْقِبْلَتَيْنِ بِغَائِطٍ أَوْ بِبَوْلٍ ‏.‏\hadithno{319}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ma'qil bin Abu Ma'qil Al-Asadi, who was a Companion of the Prophet, said:"The Messenger of Allah forbade us from facing either of the two Qiblah when defecating or urinating}}
\hadithdefcmd{ibnmajah}{320}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ، أَنَّهُ شَهِدَ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ نَهَى أَنْ نَسْتَقْبِلَ الْقِبْلَةَ بِغَائِطٍ أَوْ بِبَوْلٍ ‏.‏\hadithno{320}\hadithgrade{Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah:"Abu Sa'eed Al-Khudri narrated to me, that he bears witness that the Messenger of Allah forbade facing the Qiblah when defecating or urinating}}
\hadithdefcmd{ibnmajah}{321}{قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ وَحَدَّثَنَاهُ أَبُو سَعْدٍ، عُمَيْرُ بْنُ مِرْدَاسٍ الدَّوْنَقِيُّ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ أَبُو يَحْيَى الْبَصْرِيُّ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَانِي أَنْ أَشْرَبَ قَائِمًا وَأَنْ أَبُولَ مُسْتَقْبِلَ الْقِبْلَةِ ‏.‏\hadithno{321}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir heard Abu Sa'eed Al-Khudri say:"The Messenger of Allah forbade me from drinking while standing and from urinating while facing the Qiblah}}
\hadithdefcmd{ibnmajah}{322}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، أَنَّ مُحَمَّدَ بْنَ يَحْيَى بْنِ حَبَّانَ، أَخْبَرَهُ أَنَّ عَمَّهُ وَاسِعَ بْنَ حَبَّانَ أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ يَقُولُ أُنَاسٌ إِذَا قَعَدْتَ لِلْغَائِطِ فَلاَ تَسْتَقْبِلِ الْقِبْلَةَ وَلَقَدْ ظَهَرْتُ ذَاتَ يَوْمٍ مِنَ الأَيَّامِ عَلَى ظَهْرِ بَيْتِنَا فَرَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَاعِدًا عَلَى لَبِنَتَيْنِ مُسْتَقْبِلَ بَيْتِ الْمَقْدِسِ ‏.‏ هَذَا حَدِيثُ يَزِيدَ بْنِ هَارُونَ ‏.‏\hadithno{322}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdullah bin 'Umar said:"People say: 'When you sit to relieve yourself, do not face the Qiblah.' But one day I climbed up onto the roof of our house, and I saw the Messenger of Allah sitting on two bricks (to relieve himself), facing the direction of Baitul-Maqdis (Jerusalem)." This is a Hadith narrated by Yazid bin Harun}}
\hadithdefcmd{ibnmajah}{323}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ عِيسَى الْحَنَّاطِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي كَنِيفِهِ مُسْتَقْبِلَ الْقِبْلَةِ ‏. ‏ قَالَ عِيسَى فَقُلْتُ ذَلِكَ لِلشَّعْبِيِّ فَقَالَ صَدَقَ ابْنُ عُمَرَ وَصَدَقَ أَبُو هُرَيْرَةَ أَمَّا قَوْلُ أَبِي هُرَيْرَةَ فَقَالَ فِي الصَّحْرَاءِ لاَ يَسْتَقْبِلِ الْقِبْلَةَ وَلاَ يَسْتَدْبِرْهَا وَأَمَّا قَوْلُ ابْنِ عُمَرَ فَإِنَّ الْكَنِيفَ لَيْسَ فِيهِ قِبْلَةٌ اسْتَقْبِلْ فِيهِ حَيْثُ شِئْتَ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ وَحَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{323}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"I saw the Messenger of Allah in his (constructed) toilet, facing towards the Qiblah." (Da'if) (One of the narrators) 'Eisa said: "I told that to Sha'bi, and he said: 'Ibn 'Umar spoke the truth. As for the words of Abu Hurairah, he said: "In the desert do not face the Qiblah nor turn one's back towards it." As for the words of Ibn 'Umar, he said: "In the (constructed) toilet there is no Qiblah so turn in whatever direction you want." Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{324}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ خَالِدِ بْنِ أَبِي الصَّلْتِ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عَائِشَةَ، قَالَتْ ذُكِرَ عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَوْمٌ يَكْرَهُونَ أَنْ يَسْتَقْبِلُوا بِفُرُوجِهِمُ الْقِبْلَةَ فَقَالَ ‏ "‏ أُرَاهُمْ قَدْ فَعَلُوهَا اسْتَقْبِلُوا بِمَقْعَدَتِي الْقِبْلَةَ ‏"‏ ‏. ‏ قَالَ أَبُو الْحَسَنِ الْقَطَّانُ حَدَّثَنَا يَحْيَى بْنُ عُبَيْدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُغِيرَةِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ خَالِدِ بْنِ أَبِي الصَّلْتِ، مِثْلَهُ ‏.‏\hadithno{324}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"Mention was made in the presence of the Messenger of Allah of some people who did not like to face towards the Qiblah with their private parts. He said: 'I think that they do that. Turn my seat (in the toilet) to face the Qiblah.'" (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{325}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ مُحَمَّدَ بْنَ إِسْحَاقَ، عَنْ أَبَانَ بْنِ صَالِحٍ، عَنْ مُجَاهِدٍ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَسْتَقْبِلَ الْقِبْلَةَ بِبَوْلٍ فَرَأَيْتُهُ قَبْلَ أَنْ يُقْبَضَ بِعَامٍ يَسْتَقْبِلُهَا ‏.‏\hadithno{325}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah forbade facing the Qiblah when urinating. But I saw him, one year before he died, facing the Qiblah (while urinating)}}
\hadithdefcmd{ibnmajah}{326}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا زَمْعَةُ بْنُ صَالِحٍ، عَنْ عِيسَى بْنِ يَزْدَادَ الْيَمَانِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا بَالَ أَحَدُكُمْ فَلْيَنْتُرْ ذَكَرَهُ ثَلاَثَ مَرَّاتٍ ‏"‏ ‏. ‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَمْعَةُ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{326}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Eisa bin Yazdad Al-Yamani that his father said:"The Messenger of Allah said: 'When anyone of you urinates, let him squeeze his penis three times (to remove the remaining urine drops)." (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{327}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَحْيَى التَّوْأَمِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتِ انْطَلَقَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَبُولُ فَاتَّبَعَهُ عُمَرُ بِمَاءٍ فَقَالَ ‏"‏ مَا هَذَا يَا عُمَرُ ‏"‏ ‏.‏ قَالَ مَاءٌ ‏.‏ قَالَ ‏"‏ مَا أُمِرْتُ كُلَّمَا بُلْتُ أَنْ أَتَوَضَّأَ وَلَوْ فَعَلْتُ لَكَانَتْ سُنَّةً ‏"‏ ‏.‏\hadithno{327}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Prophet went out to urinate, and 'Umar followed him with water. He said: 'What is this, O 'Umar?' He said: 'Water.' He said: 'I have not been commanded to perform ablution every time I urinate. If I did that it would have become a Sunnah}}
\hadithdefcmd{ibnmajah}{328}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي نَافِعُ بْنُ يَزِيدَ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، أَنَّ أَبَا سَعِيدٍ الْحِمْيَرِيَّ، حَدَّثَهُ قَالَ كَانَ مُعَاذُ بْنُ جَبَلٍ يَتَحَدَّثُ بِمَا لَمْ يَسْمَعْ أَصْحَابُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَيَسْكُتُ عَمَّا سَمِعُوا فَبَلَغَ عَبْدَ اللَّهِ بْنَ عَمْرٍو مَا يَتَحَدَّثُ بِهِ فَقَالَ وَاللَّهِ مَا سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ هَذَا وَأَوْشَكَ مُعَاذٌ أَنْ يَفْتِنَكُمْ فِي الْخَلاَءِ ‏.‏ فَبَلَغَ ذَلِكَ مُعَاذًا فَلَقِيَهُ فَقَالَ مُعَاذٌ يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو إِنَّ التَّكْذِيبَ بِحَدِيثٍ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ نِفَاقٌ وَإِنَّمَا إِثْمُهُ عَلَى مَنْ قَالَهُ لَقَدْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ اتَّقُوا الْمَلاَعِنَ الثَّلاَثَ الْبَرَازَ فِي الْمَوَارِدِ وَالظِّلِّ وَقَارِعَةِ الطَّرِيقِ ‏"‏ ‏.‏\hadithno{328}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Himyari narrated that :Mu'adh bin Jabal used to narrate something that the Companions of the Messenger of Allah had not heard, and he used to keep quiet about what they had heard. News of this report reached 'Abdullah bin 'Amr, and he said: "By Allah, I never heard the Messenger of Allah say this, and Mu'adh will put you into difficulty with regard to relieving yourself." News of that reached Mu'adh, so he met with him ('Abdullah). Mu'adh said: "O 'Abdullah! Denying a Hadith from the Messenger of Allah is hypocrisy, and its sn is upon the one who said it (if it is not true). I did indeed hear the Messenger of Allah say: 'Beware of the three things which provoke curses: Relieving oneself in watering places, in places of shade and in the middle of the street}}
\hadithdefcmd{ibnmajah}{329}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، عَنْ زُهَيْرٍ، قَالَ قَالَ سَالِمٌ سَمِعْتُ الْحَسَنَ، يَقُولُ حَدَّثَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِيَّاكُمْ وَالتَّعْرِيسَ عَلَى جَوَادِّ الطَّرِيقِ وَالصَّلاَةَ عَلَيْهَا فَإِنَّهَا مَأْوَى الْحَيَّاتِ وَالسِّبَاعِ وَقَضَاءَ الْحَاجَةِ عَلَيْهَا فَإِنَّهَا مِنَ الْمَلاَعِنِ ‏"‏ ‏.‏\hadithno{329}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah said: 'Beware of stopping to rest and praying in the middle of the road, for it is the refuge of snakes and carnivorous animals, and beware of relieving yourselves in the middle of the road, for this is an act that provokes curses}}
\hadithdefcmd{ibnmajah}{330}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ قُرَّةَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُصَلَّى عَلَى قَارِعَةِ الطَّرِيقِ أَوْ يُضْرَبَ الْخَلاَءُ عَلَيْهَا أَوْ يُبَالَ فِيهَا ‏.‏\hadithno{330}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Salim narrated from his father that:The Prophet forbade praying in the middle of the road, or defecating there, or urinating}}
\hadithdefcmd{ibnmajah}{331}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا ذَهَبَ الْمَذْهَبَ أَبْعَدَ ‏.‏\hadithno{331}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Mugirah bin Shu'bah said:"Whenever the Prophet went to relieve himself, he would go far away}}
\hadithdefcmd{ibnmajah}{332}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ، عَنْ عُمَرَ بْنِ الْمُثَنَّى، عَنْ عَطَاءٍ الْخُرَاسَانِيِّ، عَنْ أَنَسٍ، قَالَ كُنْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ فَتَنَحَّى لِحَاجَتِهِ ثُمَّ جَاءَ فَدَعَا بِوَضُوءٍ فَتَوَضَّأَ ‏.‏\hadithno{332}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:"I was with the Prophet on a journey. He went away to relieve himself, then he came and called for water and performed ablution}}
\hadithdefcmd{ibnmajah}{333}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنِ ابْنِ خُثَيْمٍ، عَنْ يُونُسَ بْنِ خَبَّابٍ، عَنْ يَعْلَى بْنِ مُرَّةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا ذَهَبَ إِلَى الْغَائِطِ أَبْعَدَ ‏.‏\hadithno{333}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ya'la bin Murrah that:When the Prophet went to relieve himself, he would go far away}}
\hadithdefcmd{ibnmajah}{334}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ أَبِي جَعْفَرٍ الْخَطْمِيِّ، - قَالَ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَاسْمُهُ عُمَيْرُ بْنُ يَزِيدَ - عَنْ عُمَارَةَ بْنِ خُزَيْمَةَ، وَالْحَارِثِ بْنِ فُضَيْلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي قُرَادٍ، قَالَ حَجَجْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَذَهَبَ لِحَاجَتِهِ فَأَبْعَدَ ‏.‏\hadithno{334}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdur-Rahman bin Abu Qurad said:"I went for Hajj with the Prophet and he went far away to relieve himself}}
\hadithdefcmd{ibnmajah}{335}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا إِسْمَاعِيلُ بْنُ عَبْدِ الْمَلِكِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لاَ يَأْتِي الْبَرَازَ حَتَّى يَتَغَيَّبَ فَلاَ يُرَى ‏.‏\hadithno{335}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"We went out on a journey with the Messenger of Allah, and the Messenger of Allah would not relieve himself until he had disappeared and could not be seen by anyone}}
\hadithdefcmd{ibnmajah}{336}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ كَثِيرِ بْنِ جَعْفَرٍ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ بِلاَلِ بْنِ الْحَارِثِ الْمُزَنِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أَرَادَ الْحَاجَةَ أَبْعَدَ ‏.‏\hadithno{336}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Bilal bin Al-Harith Al-Muzani that:When the Messenger of Allah wanted to relieve himself, he would go far away}}
\hadithdefcmd{ibnmajah}{337}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الصَّبَّاحِ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، عَنْ حُصَيْنٍ الْحِمْيَرِيِّ، عَنْ أَبِي سَعِيدِ الْخَيْرِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنِ اسْتَجْمَرَ فَلْيُوتِرْ مَنْ فَعَلَ ذَلِكَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ وَمَنْ تَخَلَّلَ فَلْيَلْفِظْ وَمَنْ لاَكَ فَلْيَبْتَلِعْ مَنْ فَعَلَ ذَلِكَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ وَمَنْ أَتَى الْخَلاَءَ فَلْيَسْتَتِرْ فَإِنْ لَمْ يَجِدْ إِلاَّ كَثِيبًا مِنْ رَمْلٍ فَلْيَمْدُدْهُ عَلَيْهِ فَإِنَّ الشَّيْطَانَ يَلْعَبُ بِمَقَاعِدِ ابْنِ آدَمَ مَنْ فَعَلَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{337}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "Whoever uses stones to clean himself, let him use an odd number of stones. Whoever does that has done well, and whoever does not, there is no harm in it. Whoever uses a tooth stick should spit out (whatever he removes) and whoever removes (the particle of food) by dislodging it with his tongue should swallow it. Whoever does that has done well, and whoever does not, tere is no harm in it. Whoever goes to the toilet should conceal himself, and if he cannot find anything except a pile of sand (behind which to conceal himself), then he should use that, for the Shaitan plays with the backside of the son of Adam. Whoever does that has done well, and whoever does not, there is no harm in it}}
\hadithdefcmd{ibnmajah}{338}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الصَّبَّاحِ، بِإِسْنَادِهِ نَحْوَهُ وَزَادَ فِيهِ ‏ "‏ وَمَنِ اكْتَحَلَ فَلْيُوتِرْ مَنْ فَعَلَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ وَمَنْ لاَكَ فَلْيَبْتَلِعْ ‏"‏ ‏.‏\hadithno{338}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar report was narrated by 'Abdul-Malik bin As-Sabbah with a similar chain, with the additional words:"Whoever applies kohl to his eyes, let him add it an odd number of times. Whoever does that has done well, and whoever does not, there is no harm in it. And whoever dislodges (a particle of food from between the teeth) by dislodging it with his tongue, let him swallow it}}
\hadithdefcmd{ibnmajah}{339}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ يَعْلَى بْنِ مُرَّةَ، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ فَأَرَادَ أَنْ يَقْضِيَ حَاجَتَهُ فَقَالَ لِي ‏"‏ ائْتِ تِلْكَ الأَشَاءَتَيْنِ ‏"‏ ‏.‏ - قَالَ وَكِيعٌ يَعْنِي النَّخْلَ الصِّغَارَ ‏.‏ قَالَ أَبُو بَكْرٍ الْقِصَارَ - ‏"‏ فَقُلْ لَهُمَا إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْمُرُكُمَا أَنْ تَجْتَمِعَا ‏"‏ ‏.‏ فَاجْتَمَعَتَا فَاسْتَتَرَ بِهِمَا فَقَضَى حَاجَتَهُ ثُمَّ قَالَ لِي ‏"‏ ائْتِهِمَا فَقُلْ لَهُمَا لِتَرْجِعْ كُلُّ وَاحِدَةٍ مِنْكُمَا إِلَى مَكَانِهَا ‏"‏ ‏.‏ فَقُلْتُ لَهُمَا فَرَجَعَتَا ‏.‏\hadithno{339}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ya'la bin Murrah that his father said:"I was with the Prophet on a journey, and he wanted to relieve himself. He said to me: 'Go to those two small date-palm trees and tell them: "The Messenger of Allah orders you to come together.'" So they came together and he concealed himself behind them, and relieved himself. Then he said to me: 'Go to them and tell them: "Go back, each one of you, to your places.'" So I said that to them and they went back}}
\hadithdefcmd{ibnmajah}{340}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي يَعْقُوبَ، عَنِ الْحَسَنِ بْنِ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ كَانَ أَحَبَّ مَا اسْتَتَرَ بِهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ لِحَاجَتِهِ هَدَفٌ أَوْ حَائِشُ نَخْلٍ ‏.‏\hadithno{340}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Ja'far said:"The thing that the Prophet most liked to conceal himself behind when relieving himself was a hillock or a stand of date-palm trees}}
\hadithdefcmd{ibnmajah}{341}{حَدَّثَنَا مُحَمَّدُ بْنُ عَقِيلِ بْنِ خُوَيْلِدٍ، حَدَّثَنِي حَفْصُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ مُحَمَّدِ بْنِ ذَكْوَانَ، عَنْ يَعْلَى بْنِ حَكِيمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ عَدَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى الشِّعْبِ فَبَالَ حَتَّى أَنِّي آوِي لَهُ مِنْ فَكِّ وَرِكَيْهِ حِينَ بَالَ ‏.‏\hadithno{341}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah turned towards a mountain pass and urinated, until I took pity on him because of the way he parted his legs when he urinated}}
\hadithdefcmd{ibnmajah}{342}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، أَنْبَأَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ عِيَاضٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَتَنَاجَى اثْنَانِ عَلَى غَائِطِهِمَا يَنْظُرُ كُلُّ وَاحِدٍ مِنْهُمَا إِلَى عَوْرَةِ صَاحِبِهِ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ يَمْقُتُ عَلَى ذَلِكَ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سَلْمُ بْنُ إِبْرَاهِيمَ الْوَرَّاقُ، حَدَّثَنَا عِكْرِمَةُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِيَاضِ بْنِ هِلاَلٍ، ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى هُوَ الصَّوَابُ ‏. ‏ حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَلِيُّ بْنُ أَبِي بَكْرٍ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، نَحْوَهُ ‏.‏\hadithno{342}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa`eed al-Khudri that:The Messenger of Allah said: "No two people should converse while relieving themselves, each of them looking at the private parts of the other, for Allah, the Mighty and Sublime, hates that." (Da'if) Other chains with similar wording}}
\hadithdefcmd{ibnmajah}{343}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ نَهَى عَنْ أَنْ يُبَالَ فِي الْمَاءِ الرَّاكِدِ ‏.‏\hadithno{343}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:The Messenger of Allah forbade urinating into standing water}}
\hadithdefcmd{ibnmajah}{344}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الرَّاكِدِ ‏"‏ ‏.‏\hadithno{344}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'No one among you should urinate into standing water}}
\hadithdefcmd{ibnmajah}{345}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا ابْنُ أَبِي فَرْوَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ النَّاقِعِ ‏"‏ ‏.‏\hadithno{345}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'No one among you should urinate into standing water}}
\hadithdefcmd{ibnmajah}{346}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ ابْنِ حَسَنَةَ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَفِي يَدِهِ الدَّرَقَةُ فَوَضَعَهَا ثُمَّ جَلَسَ فَبَالَ إِلَيْهَا فَقَالَ بَعْضُهُمُ انْظُرُوا إِلَيْهِ يَبُولُ كَمَا تَبُولُ الْمَرْأَةُ ‏.‏ فَسَمِعَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ وَيْحَكَ أَمَا عَلِمْتَ مَا أَصَابَ صَاحِبَ بَنِي إِسْرَائِيلَ كَانُوا إِذَا أَصَابَهُمُ الْبَوْلُ قَرَضُوهُ بِالْمَقَارِيضِ فَنَهَاهُمْ عَنْ ذَلِكَ فَعُذِّبَ فِي قَبْرِهِ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا الأَعْمَشُ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{346}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that `Abdur-Rahman bin Hasanah said:"The Messenger of Allah came out to us holding a small shield in his hand. He put it down, then he sat down and urinated towards it. Some of the people said: 'Look at him, he urinates like a woman!' The Prophet heard that and said: 'Woe to you! Do you not know what happened to one of the children of Israel? If any urine touched any part of their clothes, they would cut that out with scissors. He told them not to do that, so he was tormented in his grave.'" (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{347}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِقَبْرَيْنِ جَدِيدَيْنِ فَقَالَ ‏ "‏ إِنَّهُمَا لَيُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا أَحَدُهُمَا فَكَانَ لاَ يَسْتَنْزِهُ مِنْ بَوْلِهِ وَأَمَّا الآخَرُ فَكَانَ يَمْشِي بِالنَّمِيمَةِ ‏"‏ ‏.‏\hadithno{347}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah passed by two new graves, and he said: 'They are being punished, but they are not being punished for anything major. One of them was heedless about preventing urine from getting on his clothes, and the other used to walk about spreading malicious gossip}}
\hadithdefcmd{ibnmajah}{348}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَكْثَرُ عَذَابِ الْقَبْرِ مِنَ الْبَوْلِ ‏"‏ ‏.‏\hadithno{348}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Most of the torment of the grave is because of urine}}
\hadithdefcmd{ibnmajah}{349}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَسْوَدُ بْنُ شَيْبَانَ، حَدَّثَنِي بَحْرُ بْنُ مَرَّارٍ، عَنْ جَدِّهِ أَبِي بَكْرَةَ، قَالَ مَرَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِقَبْرَيْنِ فَقَالَ ‏ "‏ إِنَّهُمَا لَيُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا أَحَدُهُمَا فَيُعَذَّبُ فِي الْبَوْلِ وَأَمَّا الآخَرُ فَيُعَذَّبُ فِي الْغِيبَةِ ‏"‏ ‏.‏\hadithno{349}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Bahr bin Marrar narrated that his grandfather Abu Bakrah said:"The Messenger of Allah passed by two graves, and he said: 'They are being punished but they are not being punished for anything major. One of them is being punished because of urine, and the other is being punished because of backbiting}}
\hadithdefcmd{ibnmajah}{350}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُحَمَّدٍ الطَّلْحِيُّ، وَأَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، قَالاَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ حُضَيْنِ بْنِ الْمُنْذِرِ بْنِ الْحَارِثِ بْنِ وَعْلَةَ أَبِي سَاسَانَ الرَّقَاشِيِّ، عَنِ الْمُهَاجِرِ بْنِ قُنْفُذِ بْنِ عُمَيْرِ بْنِ جُدْعَانَ، قَالَ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَهُوَ يَتَوَضَّأُ فَسَلَّمْتُ عَلَيْهِ فَلَمْ يَرُدَّ عَلَىَّ السَّلاَمَ فَلَمَّا فَرَغَ مِنْ وُضُوئِهِ قَالَ ‏ "‏ إِنَّهُ لَمْ يَمْنَعْنِي مِنْ أَنْ أَرُدَّ عَلَيْكَ إِلاَّ أَنِّي كُنْتُ عَلَى غَيْرِ وُضُوءٍ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا الأَنْصَارِيُّ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{350}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Muhajir bin Qunfudh bin (Umair) bin Jud'an said:"I came to the Prophet when he was performing ablution and greeted him with the Salam, but he did not return (the greeting). When he had finished his ablution he said: 'Nothing prevented me from returning your greeting but the fact that I need to have ablution.'" (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{351}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَسْلَمَةُ بْنُ عُلَىٍّ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَرَّ رَجُلٌ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَهُوَ يَبُولُ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْهِ فَلَمَّا فَرَغَ ضَرَبَ بِكَفَّيْهِ الأَرْضَ فَتَيَمَّمَ ثُمَّ رَدَّ عَلَيْهِ السَّلاَمَ ‏.‏\hadithno{351}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"A man passed by the Prophet while he was urinating, and greeted him with the Salam, but he did not return the greeting. While he finished, he struck the ground with his palms and did dry ablution (Tayammum), then he returned the greeting}}
\hadithdefcmd{ibnmajah}{352}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ هَاشِمِ بْنِ الْبَرِيدِ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مَرَّ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَهُوَ يَبُولُ فَسَلَّمَ عَلَيْهِ فَقَالَ لَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا رَأَيْتَنِي عَلَى مِثْلِ هَذِهِ الْحَالَةِ فَلاَ تُسَلِّمْ عَلَىَّ فَإِنَّكَ إِنْ فَعَلْتَ ذَلِكَ لَمْ أَرُدَّ عَلَيْكَ ‏"‏ ‏.‏\hadithno{352}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin `Abdullah that:"A man passed by the Prophet while he was urinating, and greeted him by the Salam. The Messenger of Allah said to him: "If you see me in this situation, do not greet me with the Salam, for if you do that I will not respond to you}}
\hadithdefcmd{ibnmajah}{353}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، وَالْحُسَيْنُ بْنُ أَبِي السَّرِيِّ الْعَسْقَلاَنِيُّ، قَالاَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ سُفْيَانَ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَرَّ رَجُلٌ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَهُوَ يَبُولُ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْهِ ‏.‏\hadithno{353}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"A man passed by the Prophet while he was urinating and greeted him with the Salam, and he did not return the greeting}}
\hadithdefcmd{ibnmajah}{354}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ خَرَجَ مِنْ غَائِطٍ قَطُّ إِلاَّ مَسَّ مَاءً ‏.‏\hadithno{354}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"I never saw the Messenger of Allah come out of the toilet without first (cleansing himself) with water}}
\hadithdefcmd{ibnmajah}{355}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا عُتْبَةُ بْنُ أَبِي حَكِيمٍ، حَدَّثَنِي طَلْحَةُ بْنُ نَافِعٍ أَبُو سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو أَيُّوبَ الأَنْصَارِيُّ، وَجَابِرُ بْنُ عَبْدِ اللَّهِ، وَأَنَسُ بْنُ مَالِكٍ، أَنَّ هَذِهِ الآيَةَ، نَزَلَتْ ‏\{فِيهِ رِجَالٌ يُحِبُّونَ أَنْ يَتَطَهَّرُوا وَاللَّهُ يُحِبُّ الْمُطَّهِّرِينَ\}‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ يَا مَعْشَرَ الأَنْصَارِ إِنَّ اللَّهَ قَدْ أَثْنَى عَلَيْكُمْ فِي الطُّهُورِ فَمَا طُهُورُكُمْ ‏"‏ ‏.‏ قَالُوا نَتَوَضَّأُ لِلصَّلاَةِ وَنَغْتَسِلُ مِنَ الْجَنَابَةِ وَنَسْتَنْجِي بِالْمَاءِ ‏.‏ قَالَ ‏"‏ هُوَ ذَلِكَ فَعَلَيْكُمُوهُ ‏"‏ ‏.‏\hadithno{355}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sufyan said:"Abu Ayyub Al-Ansari, Jabir bin 'Abdullah, and Anas bin Malik told me that when this Verse: "In it (the mosque) are men who love to clean and to purify themselves. And Allah loves those who make themselves clean and pure." was revealed, the Messenger of Allah said: 'O Ansar! Allah has praised you for your cleanliness. What is the nature of your cleanliness?' They said: 'We perform ablution for prayer and we take bath to cleanse ourselves of impurity due to sexual activity, and we clean ourselves with water (after urinating). He said: 'This is what it is. So adhere to it}}
\hadithdefcmd{ibnmajah}{356}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ جَابِرٍ، عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَغْسِلُ مَقْعَدَتَهُ ثَلاَثًا ‏.‏ قَالَ ابْنُ عُمَرَ فَعَلْنَاهُ فَوَجَدْنَاهُ دَوَاءً وَطُهُورًا ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، وَإِبْرَاهِيمُ بْنُ سُلَيْمَانَ الْوَاسِطِيُّ، قَالاَ حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَرِيكٌ، نَحْوَهُ ‏.‏\hadithno{356}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:The Prophet used to wash his private parts three times. Ibn 'Umar said: "We did that and we found it to be healing and a means of purification}}
\hadithdefcmd{ibnmajah}{357}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ يُونُسَ بْنِ الْحَارِثِ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ نَزَلَتْ فِي أَهْلِ قُبَاءٍ ‏\{فِيهِ رِجَالٌ يُحِبُّونَ أَنْ يَتَطَهَّرُوا وَاللَّهُ يُحِبُّ الْمُطَّهِّرِينَ\}‏ قَالَ كَانُوا يَسْتَنْجُونَ بِالْمَاءِ فَنَزَلَتْ فِيهِمْ هَذِهِ الآيَةُ ‏"‏ ‏.‏\hadithno{357}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The (following) was revealed about the people of Quba': 'In it (the mosque) are men who love to clean and purify themselves. And Allah loves those who make themselves clean and pure.'" He said: 'They used to clean themselves with water (after urinating), and this Verse was revealed concerning them}}
\hadithdefcmd{ibnmajah}{358}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ إِبْرَاهِيمَ بْنِ جَرِيرٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَضَى حَاجَتَهُ ثُمَّ اسْتَنْجَى مِنْ تَوْرٍ ثُمَّ دَلَكَ يَدَهُ بِالأَرْضِ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ الْوَاسِطِيُّ، عَنْ شَرِيكٍ، نَحْوَهُ ‏.‏\hadithno{358}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet relieved himself, then he cleaned himself (with water) from a pot made of brass, then he wiped his hand on the ground. Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{359}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا أَبَانُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ جَرِيرٍ، عَنْ أَبِيهِ، أَنَّ نَبِيَّ اللَّهِ ـ صلى الله عليه وسلم ـ دَخَلَ الْغَيْضَةَ فَقَضَى حَاجَتَهُ فَأَتَاهُ جَرِيرٌ بِإِدَاوَةٍ مِنْ مَاءٍ فَاسْتَنْجَى مِنْهَا وَمَسَحَ يَدَهُ بِالتُّرَابِ ‏.‏\hadithno{359}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Ibrahim bin Jarir narrated from his father that :The Prophet of Allah entered a thicket and relieved himself, then Jarir brought him a small water skin from which he cleansed himself, then he wiped his hand in the dirt}}
\hadithdefcmd{ibnmajah}{360}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَعْلَى بْنُ عُبَيْدٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَمَرَنَا النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ نُوكِيَ أَسْقِيَتَنَا وَنُغَطِّيَ آنِيَتَنَا ‏.‏\hadithno{360}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Prophet commanded (us) to tie up our water skins and cover our vessels}}
\hadithdefcmd{ibnmajah}{361}{حَدَّثَنَا عِصْمَةُ بْنُ الْفَضْلِ، وَيَحْيَى بْنُ حَكِيمٍ، قَالاَ حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ بْنِ أَبِي حَفْصَةَ، حَدَّثَنَا حَرِيشُ بْنُ الْخِرِّيتِ، أَنْبَأَنَا ابْنُ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَضَعُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثَلاَثَةَ آنِيَةٍ مِنَ اللَّيْلِ مُخَمَّرَةً إِنَاءً لِطَهُورِهِ وَإِنَاءً لِسِوَاكِهِ وَإِنَاءً لِشَرَابِهِ ‏.‏\hadithno{361}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"I used to cover three vessels for the Messenger of Allah at night: A vessel (of water) for his ablution, a vessel for his tooth stick and a vessel for his drink}}
\hadithdefcmd{ibnmajah}{362}{حَدَّثَنَا أَبُو بَدْرٍ، عَبَّادُ بْنُ الْوَلِيدِ حَدَّثَنَا مُطَهَّرُ بْنُ الْهَيْثَمِ، حَدَّثَنَا عَلْقَمَةُ بْنُ أَبِي جَمْرَةَ الضُّبَعِيُّ، عَنْ أَبِيهِ أَبِي جَمْرَةَ الضُّبَعِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لاَ يَكِلُ طُهُورَهُ إِلَى أَحَدٍ وَلاَ صَدَقَتَهُ الَّتِي يَتَصَدَّقُ بِهَا يَكُونُ هُوَ الَّذِي يَتَوَلاَّهَا بِنَفْسِهِ ‏.‏\hadithno{362}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah never entrusted his purification to anyone nor his charity that he had given to anyone; he would be the one to take care of these matters himself}}
\hadithdefcmd{ibnmajah}{363}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي رَزِينٍ، قَالَ رَأَيْتُ أَبَا هُرَيْرَةَ يَضْرِبُ جَبْهَتَهُ بِيَدِهِ وَيَقُولُ يَا أَهْلَ الْعِرَاقِ أَنْتُمْ تَزْعُمُونَ أَنِّي أَكْذِبُ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لِيَكُونَ لَكُمُ الْمَهْنَأُ وَعَلَىَّ الإِثْمُ أَشْهَدُ لَسَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{363}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Razin said:'I saw Abu Hurairah hitting his forehead with his hand and saying: "O people of Iraq! Do you claim that I would tell a lie against the Messenger of Allah so that it may be more convenient for you and a sin upon me?' I bear witness that I heard the Messenger of Allah say: 'If a dog licks the vessel of anyone of you, let him wash it seven times}}
\hadithdefcmd{ibnmajah}{364}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا شَرِبَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{364}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "If a dog licks the vessel of anyome of you, let him wash it seven times}}
\hadithdefcmd{ibnmajah}{365}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ مُطَرِّفًا، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ الْمُغَفَّلِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي الإِنَاءِ فَاغْسِلُوهُ سَبْعَ مَرَّاتٍ وَعَفِّرُوهُ الثَّامِنَةَ بِالتُّرَابِ ‏"‏ ‏.‏\hadithno{365}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin Mughaffal that:The Messenger of Allah said: 'If a dog licks a vessel, wash it seven times and rub it with dust the eight times}}
\hadithdefcmd{ibnmajah}{366}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{366}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'If a dog licks the vessel of anyone of you, let him wash it seven times}}
\hadithdefcmd{ibnmajah}{367}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، أَنْبَأَنَا مَالِكُ بْنُ أَنَسٍ، أَخْبَرَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ الأَنْصَارِيُّ، عَنْ حُمَيْدَةَ بِنْتِ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ كَبْشَةَ بِنْتِ كَعْبٍ، وَكَانَتْ، تَحْتَ بَعْضِ وَلَدِ أَبِي قَتَادَةَ أَنَّهَا صَبَّتْ لأَبِي قَتَادَةَ مَاءً يَتَوَضَّأُ بِهِ فَجَاءَتْ هِرَّةٌ تَشْرَبُ فَأَصْغَى لَهَا الإِنَاءَ فَجَعَلْتُ أَنْظُرُ إِلَيْهِ فَقَالَ يَا ابْنَةَ أَخِي أَتَعْجَبِينَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّهَا لَيْسَتْ بِنَجَسٍ هِيَ مِنَ الطَّوَّافِينَ أَوِ الطَّوَّافَاتِ ‏"‏ ‏.‏\hadithno{367}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Kabshah bint Ka'b, who was married to one of the sons of Ab Qatadah, that:She poured water for Abu Qatadah to perform ablution. A cat came and drank the water, and he tilted the vessel for it. She started looking at it (in surprise) and he said: "O daughter of my brother, do you find it strange? The Messenger of Allah said: 'They (cats) are not impure, they are of those who go around among you}}
\hadithdefcmd{ibnmajah}{368}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، وَإِسْمَاعِيلُ بْنُ تَوْبَةَ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ حَارِثَةَ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَتَوَضَّأُ أَنَا وَرَسُولُ اللَّهِ، ـ صلى الله عليه وسلم ـ مِنْ إِنَاءٍ وَاحِدٍ قَدْ أَصَابَتْ مِنْهُ الْهِرَّةُ قَبْلَ ذَلِكَ ‏.‏\hadithno{368}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah and I used to perform ablution from a single vessel, when the cat had drunk from it beforehand}}
\hadithdefcmd{ibnmajah}{369}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْهِرَّةُ لاَ تَقْطَعُ الصَّلاَةَ لأَنَّهَا مِنْ مَتَاعِ الْبَيْتِ ‏"‏ ‏.‏\hadithno{369}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "Cats do not invalidate the prayer, because they are one of the things that are useful in the house}}
\hadithdefcmd{ibnmajah}{370}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ اغْتَسَلَ بَعْضُ أَزْوَاجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي جَفْنَةٍ فَجَاءَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لِيَغْتَسِلَ أَوْ يَتَوَضَّأَ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ جُنُبًا ‏.‏ فَقَالَ ‏ "‏ الْمَاءُ لاَ يُجْنِبُ ‏"‏ ‏.‏\hadithno{370}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"One of the wives of the Prophet took a bath from a large vessel, then the Prophet came and had a bath or ablution, and she said: 'O Messenger of Allah, I was sexually impure.' He said: 'Water does not become impure}}
\hadithdefcmd{ibnmajah}{371}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، مِنْ أَزْوَاجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ اغْتَسَلَتْ مِنْ جَنَابَةٍ فَتَوَضَّأَ أَوِ اغْتَسَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ مِنْ فَضْلِ وَضُوئِهَا ‏.‏\hadithno{371}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that:One of the wives of the Prophet took a bath to cleanse herself from sexual impurity, then the Prophet performed ablution and had a bath with the water left over from her ablution}}
\hadithdefcmd{ibnmajah}{372}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالُوا حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شَرِيكٌ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ تَوَضَّأَ بِفَضْلِ غُسْلِهَا مِنَ الْجَنَابَةِ ‏.‏\hadithno{372}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas, from Maimunah the wife of the Prophet, that :the Prophet performed ablution with the water left over after she had taken a bath to cleanse herself from sexual impurity}}
\hadithdefcmd{ibnmajah}{373}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي حَاجِبٍ، عَنِ الْحَكَمِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يَتَوَضَّأَ الرَّجُلُ بِفَضْلِ وَضُوءِ الْمَرْأَةِ ‏.‏\hadithno{373}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Hakam bin 'Amr that:The Messenger of Allah forbade men to perform ablution with the left over water by a woman}}
\hadithdefcmd{ibnmajah}{374}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْمُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَغْتَسِلَ الرَّجُلُ بِفَضْلِ وَضُوءِ الْمَرْأَةِ وَالْمَرْأَةُ بِفَضْلِ الرَّجُلِ وَلَكِنْ يَشْرَعَانِ جَمِيعًا ‏. ‏ قَالَ أَبُو عَبْدِ اللَّهِ بْنُ مَاجَهْ الصَّحِيحُ هُوَ الأَوَّلُ وَالثَّانِي وَهَمٌ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، وَأَبُو عُثْمَانَ الْبُخَارِيُّ قَالاَ حَدَّثَنَا الْمُعَلَّى بْنُ أَسَدٍ، نَحْوَهُ ‏.‏\hadithno{374}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that `Abdullah bin Sarjis said:"The Messenger of Allah forbade men to perform ablution with the water left over by a woman, and women to perform ablution with water left over by a man, however both (spouses) may start to perform their ablutions at the same time." Abu `Abdullah Ibn Majah said: "The first (narration) is correct, and the second (narration) is Wahm (an error)." Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{375}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَهْلُهُ يَغْتَسِلُونَ مِنْ إِنَاءٍ وَاحِدٍ وَلاَ يَغْتَسِلُ أَحَدُهُمَا بِفَضْلِ صَاحِبِهِ ‏.‏\hadithno{375}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Prophet and his wife would take a bath from one vessel, but neither of them would have a bath with the leftover water of the other." (Daif)}}
\hadithdefcmd{ibnmajah}{376}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، ـ صلى الله عليه وسلم ـ مِنْ إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{376}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah and I would take a bath from a single vessel}}
\hadithdefcmd{ibnmajah}{377}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ خَالَتِهِ، مَيْمُونَةَ قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، ـ صلى الله عليه وسلم ـ مِنْ إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{377}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that his maternal aunt Maimunah said:"The Messager of Allah and I used to take bath from a single vessel}}
\hadithdefcmd{ibnmajah}{378}{حَدَّثَنَا أَبُو عَامِرٍ الأَشْعَرِيُّ عَبْدُ اللَّهِ بْنُ عَامِرٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ أُمِّ هَانِئٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ اغْتَسَلَ وَمَيْمُونَةُ مِنْ إِنَاءٍ وَاحِدٍ فِي قَصْعَةٍ فِيهَا أَثَرُ الْعَجِينِ ‏.‏\hadithno{378}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Hani that :The Prophet and Maimunah took a bath from a single vessel, a large bowl in which they were some traces of dough}}
\hadithdefcmd{ibnmajah}{379}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ الْحَسَنِ الأَسَدِيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَزْوَاجُهُ يَغْتَسِلُونَ مِنْ إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{379}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah and his wives used to take a bath from a single vessel}}
\hadithdefcmd{ibnmajah}{380}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّهَا كَانَتْ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَغْتَسِلاَنِ مِنْ إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{380}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Zainab the daughter of Umm Salamah narrated from Umm Salamah that:She and the Messenger of Allah used to take a bath from a single vessel}}
\hadithdefcmd{ibnmajah}{381}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ الرِّجَالُ وَالنِّسَاءُ يَتَوَضَّئُونَ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{381}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Umar said:"Men and women used to perform ablution from a single vessel during the time of the Messenger of Allah}}
\hadithdefcmd{ibnmajah}{382}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ سَالِمٍ أَبِي النُّعْمَانِ، - وَهُوَ ابْنُ سَرْجٍ - عَنْ أُمِّ صُبَيَّةَ الْجُهَنِيَّةِ، قَالَتْ رُبَّمَا اخْتَلَفَتْ يَدِي وَيَدُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْوُضُوءِ مِنْ إِنَاءٍ وَاحِدٍ ‏. ‏ قَالَ أَبُو عَبْدِ اللَّهِ ابْنُ مَاجَهْ سَمِعْتُ مُحَمَّدًا يَقُولُ أُمُّ صُبَيَّةَ هِيَ خَوْلَةُ بِنْتُ قَيْسٍ ‏.‏ فَذَكَرْتُ لأَبِي زُرْعَةَ فَقَالَ صَدَقَ ‏.‏\hadithno{382}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Umm Subyah Al-Juhaniyyah said:"Often my hand would touch the hand of the Messenger of Allah while performing ablution from a single vessel." (Hasan) Abu `Abdullah bin Majah said: "I heard Muhammad say: 'Umm Subyah was Khawlah bint Qais. I mentioned that to Abu Zur`ah and he said: "It is true}}
\hadithdefcmd{ibnmajah}{383}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا دَاوُدُ بْنُ شَبِيبٍ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي حَبِيبٍ، عَنْ عَمْرِو بْنِ هَرَمٍ، عَنْ عِكْرِمَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُمَا كَانَا يَتَوَضَّآنِ جَمِيعًا لِلصَّلاَةِ ‏.‏\hadithno{383}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that:The Prophet and she used to perform ablution together for prayer}}
\hadithdefcmd{ibnmajah}{384}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ أَبِيهِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ سُفْيَانَ، عَنْ أَبِي فَزَارَةَ الْعَبْسِيِّ، عَنْ أَبِي زَيْدٍ، مَوْلَى عَمْرِو بْنِ حُرَيْثٍ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لَهُ لَيْلَةَ الْجِنِّ ‏"‏ عِنْدَكَ طَهُورٌ ‏"‏ ‏.‏ قَالَ لاَ إِلاَّ شَىْءٌ مِنْ نَبِيذٍ فِي إِدَاوَةٍ ‏.‏ قَالَ ‏"‏ تَمْرَةٌ طَيِّبَةٌ وَمَاءٌ طَهُورٌ ‏"‏ ‏.‏ فَتَوَضَّأَ ‏.‏ هَذَا حَدِيثُ وَكِيعٍ ‏.‏\hadithno{384}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Mas'ud that :On the night of the jinn, the Messenger of Allah said to him: "Do you have water for ablution?" He said: "No, I have nothing, but some Nabidh in a vessel." He said: "Good dates and pure water (i.e. there is no harm from the mixing of the two)." So he performed ablution with it. This is the narration of Waki}}
\hadithdefcmd{ibnmajah}{385}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، حَدَّثَنَا قَيْسُ بْنُ الْحَجَّاجِ، عَنْ حَنَشٍ الصَّنْعَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لاِبْنِ مَسْعُودٍ لَيْلَةَ الْجِنِّ ‏"‏ مَعَكَ مَاءٌ ‏"‏ ‏.‏ قَالَ لاَ إِلاَّ نَبِيذًا فِي سَطِيحَةٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ تَمْرَةٌ طَيِّبَةٌ وَمَاءٌ طَهُورٌ صُبَّ عَلَىَّ ‏"‏ ‏.‏ قَالَ فَصَبَبْتُ عَلَيْهِ فَتَوَضَّأَ بِهِ ‏.‏\hadithno{385}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that :On the night of the Jinn the Messenger of Allah said to Ibn Mas'ud: "Do you have water?" He said: "No, only some Nabidh in a large water skin." The Messenger of Allah said: "Good dates and pure water." (i.e. there is no harm from the mixing of the two.) Pour it for me." He said: "So I performed ablution with it}}
\hadithdefcmd{ibnmajah}{386}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنِي صَفْوَانُ بْنُ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ سَلَمَةَ، - هُوَ مِنْ آلِ ابْنِ الأَزْرَقِ - أَنَّ الْمُغِيرَةَ بْنَ أَبِي بُرْدَةَ، - وَهُوَ مِنْ بَنِي عَبْدِ الدَّارِ - حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نَرْكَبُ الْبَحْرَ وَنَحْمِلُ مَعَنَا الْقَلِيلَ مِنَ الْمَاءِ فَإِنْ تَوَضَّأْنَا بِهِ عَطِشْنَا أَفَنَتَوَضَّأُ مِنْ مَاءِ الْبَحْرِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏\hadithno{386}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Mughirah bin Abu Burdah, who was from the tribe of Banu 'Abdud-Dar, said that:He heard Abu Hurairah say: "A man came to the Messenger of Allah and said: "O Messenger of Allah, we travel by sea and carry a small amount of water with us. If we use it for ablution, we will become thirsty. Can we perform ablution with seawater?' The Messenger of Allah said: 'Its water is a means of purification, ad its dead meat is permissible. (i.e. the fish found dead in the sea)}}
\hadithdefcmd{ibnmajah}{387}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنِي اللَّيْثُ بْنُ سَعْدٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ مُسْلِمِ بْنِ مَخْشِيٍّ، عَنِ ابْنِ الْفِرَاسِيِّ، قَالَ كُنْتُ أَصِيدُ وَكَانَتْ لِي قِرْبَةٌ أَجْعَلُ فِيهَا مَاءً وَإِنِّي تَوَضَّأْتُ بِمَاءِ الْبَحْرِ فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏\hadithno{387}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Firasi said:"I was fishing and I had a vessel with me in which I kept water, and I used seawater for ablution. I mentioned that to the Messenger of Allah and he said: 'Its water is a means of purification, and its dead meat is permissible}}
\hadithdefcmd{ibnmajah}{388}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو الْقَاسِمِ بْنُ أَبِي الزِّنَادِ، قَالَ حَدَّثَنِي إِسْحَاقُ بْنُ حَازِمٍ، عَنْ عُبَيْدِ اللَّهِ، - هُوَ ابْنُ مِقْسَمٍ - عَنْ جَابِرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ سُئِلَ عَنْ مَاءِ الْبَحْرِ فَقَالَ ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ الْهِسِنْجَانِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو الْقَاسِمِ بْنُ أَبِي الزِّنَادِ، حَدَّثَنِي إِسْحَاقُ بْنُ حَازِمٍ، عَنْ عُبَيْدِ اللَّهِ، - هُوَ ابْنُ مِقْسَمٍ - عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{388}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir that:The Prophet was asked about seawater, and he said: "Its water is a means of purification, and its dead meat is permissible." (Hasan) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{389}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، عَنْ مَسْرُوقٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ خَرَجَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لِبَعْضِ حَاجَتِهِ فَلَمَّا رَجَعَ تَلَقَّيْتُهُ بِالإِدَاوَةِ فَصَبَبْتُ عَلَيْهِ فَغَسَلَ يَدَيْهِ ثُمَّ غَسَلَ وَجْهَهُ ثُمَّ ذَهَبَ يَغْسِلُ ذِرَاعَيْهِ فَضَاقَتِ الْجُبَّةُ فَأَخْرَجَهُمَا مِنْ تَحْتِ الْجُبَّةِ فَغَسَلَهُمَا وَمَسَحَ عَلَى خُفَّيْهِ ثُمَّ صَلَّى بِنَا ‏.‏\hadithno{389}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Mughirah bin Shu'bah said:"The Prophet went out to relieve himself and when he came back, I met him with a water skin and poured water for him. He washed his hands and his face, then he went to wash his forearms but his garment was too tight, so he brought his arms out from underneath his garment and washed them, then he wiped over his leather socks, then he led us in prayer}}
\hadithdefcmd{ibnmajah}{390}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْهَيْثَمُ بْنُ جَمِيلٍ، حَدَّثَنَا شَرِيكٌ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذٍ، قَالَتْ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ بِمِيضَأَةٍ فَقَالَ ‏ "‏ اسْكُبِي ‏"‏ ‏.‏ فَسَكَبْتُ فَغَسَلَ وَجْهَهُ وَذِرَاعَيْهِ وَأَخَذَ مَاءً جَدِيدًا فَمَسَحَ بِهِ رَأْسَهُ مُقَدَّمَهُ وَمُؤَخَّرَهُ وَغَسَلَ قَدَمَيْهِ ثَلاَثًا ثَلاَثًا ‏.‏\hadithno{390}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Rubai' bint Mu'awwidh said:"I brought a basin of water to the Prophet and he said: 'Pour it,' so I poured it and he washed his face and forearms, then he took fresh water and wiped his head, front and back, and then he washed his feet. He washed each part three times}}
\hadithdefcmd{ibnmajah}{391}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنِي الْوَلِيدُ بْنُ عُقْبَةَ، حَدَّثَنِي حُذَيْفَةُ بْنُ أَبِي حُذَيْفَةَ الأَزْدِيُّ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ صَبَبْتُ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ الْمَاءَ فِي السَّفَرِ وَالْحَضَرِ فِي الْوُضُوءِ ‏.‏\hadithno{391}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Safwan bin 'Assal said:"I poured water for the Prophet on journeys and as a resident, when he performed ablution}}
\hadithdefcmd{ibnmajah}{392}{حَدَّثَنَا كُرْدُوسُ بْنُ أَبِي عَبْدِ اللَّهِ الْوَاسِطِيُّ، حَدَّثَنَا عَبْدُ الْكَرِيمِ بْنُ رَوْحٍ، حَدَّثَنَا أَبِي رَوْحُ بْنُ عَنْبَسَةَ بْنِ سَعِيدِ بْنِ أَبِي عَيَّاشٍ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ عَنْ أَبِيهِ، عَنْبَسَةَ بْنِ سَعِيدٍ عَنْ جَدَّتِهِ أُمِّ أَبِيهِ أُمِّ عَيَّاشٍ، وَكَانَتْ، أَمَةً لِرُقَيَّةَ بِنْتِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَتْ كُنْتُ أُوَضِّئُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَا قَائِمَةٌ وَهُوَ قَاعِدٌ ‏.‏\hadithno{392}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umm 'Ayyash, the slave woman of Ruqayyah, the daughter of the Messenger of Allah, said:"I used to help the Messenger of Allah perform ablution, when I was standing and he was sitting}}
\hadithdefcmd{ibnmajah}{393}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّهُمَا حَدَّثَاهُ أَنَّ أَبَا هُرَيْرَةَ كَانَ يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنَ اللَّيْلِ فَلاَ يُدْخِلْ يَدَهُ فِي الإِنَاءِ حَتَّى يُفْرِغَ عَلَيْهَا مَرَّتَيْنِ أَوْ ثَلاَثًا فَإِنَّ أَحَدَكُمْ لاَ يَدْرِي فِيمَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏\hadithno{393}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sa'eed bin Musayyab and Abu Salamah bin 'Abdur-Rahman narrated that :Abu Hurairah used to say: "The Messenger of Allah said: 'When anyone of you wakes up from sleep, he should not put his hand into the vessel until he has poured water on it two or three times, for none of you knows where his hand spent the night}}
\hadithdefcmd{ibnmajah}{394}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، وَجَابِرُ بْنُ إِسْمَاعِيلَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ نَوْمِهِ فَلاَ يُدْخِلْ يَدَهُ فِي الإِنَاءِ حَتَّى يَغْسِلَهَا ‏"‏ ‏.‏\hadithno{394}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim from his father that:The Messenger of Allah said: "When anyone of you wakes up from sleep, he should not put his hand into the vessel until he has washed it}}
\hadithdefcmd{ibnmajah}{395}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ تَوْبَةَ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ الْبَكَّائِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا قَامَ أَحَدُكُمْ مِنَ النَّوْمِ فَأَرَادَ أَنْ يَتَوَضَّأَ فَلاَ يُدْخِلْ يَدَهُ فِي وَضُوئِهِ حَتَّى يَغْسِلَهَا فَإِنَّهُ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ وَلاَ عَلَى مَا وَضَعَهَا ‏"‏ ‏.‏\hadithno{395}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah said: 'When anyone of oyu gets up from sleep and wants to perform ablution, he should not put his hand into the vessel he used for ablution until he has washed it, because he does not know where his hand spent the night or where he put it.'" [(One of the narrators) Abu Ishaq said: "What is correct is that it is narrated from Jabir, from Abu Hurairah}}
\hadithdefcmd{ibnmajah}{396}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، قَالَ دَعَا عَلِيٌّ بِمَاءٍ فَغَسَلَ يَدَيْهِ قَبْلَ أَنْ يُدْخِلَهُمَا الإِنَاءَ ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَنَعَ ‏.‏\hadithno{396}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Harith said:"'Ali called for water, and he washed his hands before putting them in the vessel, then he said: 'This is what I saw the Messenger of Allah doing}}
\hadithdefcmd{ibnmajah}{397}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، قَالُوا حَدَّثَنَا كَثِيرُ بْنُ زَيْدٍ، عَنْ رُبَيْحِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ وُضُوءَ لِمَنْ لَمْ يَذْكُرِ اسْمَ اللَّهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{397}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed that:The Messenger of Allah said: "There is no ablution for one who does not mention the Name of Allah (before doing it)}}
\hadithdefcmd{ibnmajah}{398}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا يَزِيدُ بْنُ عِيَاضٍ، حَدَّثَنَا أَبُو ثِفَالٍ، عَنْ رَبَاحِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سُفْيَانَ، أَنَّهُ سَمِعَ جَدَّتَهُ بِنْتَ سَعِيدِ بْنِ زَيْدٍ، تَذْكُرُ أَنَّهَا سَمِعَتْ أَبَاهَا، سَعِيدَ بْنَ زَيْدٍ يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ صَلاَةَ لِمَنْ لاَ وُضُوءَ لَهُ وَلاَ وُضُوءَ لِمَنْ لَمْ يَذْكُرِ اسْمَ اللَّهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{398}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed bin Zaid said:"The Messenger of Allah said: 'There is no prayer for one who does not have ablution, and there is no ablution for one who does not mention the Name of Allah (before it)}}
\hadithdefcmd{ibnmajah}{399}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَعَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى بْنِ أَبِي عَبْدِ اللَّهِ، عَنْ يَعْقُوبَ بْنِ سَلَمَةَ اللَّيْثِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ صَلاَةَ لِمَنْ لاَ وُضُوءَ لَهُ وَلاَ وُضُوءَ لِمَنْ لَمْ يَذْكُرِ اسْمَ اللَّهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{399}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'There is no prayer for one who does not have ablution, and there is no ablution for one who does not mention the Name of Allah (before it)}}
\hadithdefcmd{ibnmajah}{400}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ الْمُهَيْمِنِ بْنِ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ صَلاَةَ لِمَنْ لاَ وُضُوءَ لَهُ وَلاَ وُضُوءَ لِمَنْ لَمْ يَذْكُرِ اسْمَ اللَّهِ عَلَيْهِ وَلاَ صَلاَةَ لِمَنْ لاَ يُصَلِّي عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَلاَ صَلاَةَ لِمَنْ لاَ يُحِبُّ الأَنْصَارَ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا عُبَيْسُ بْنُ مَرْحُومٍ الْعَطَّارُ، حَدَّثَنَا عَبْدُ الْمُهَيْمِنِ بْنُ عَبَّاسٍ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{400}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated by 'Abdul-Muhaimin bin 'Abbas bin Sahl bin Sa'd As-Sa'idi, from his father, from his grandfather, that:The Prophet said: "There is no prayer for one who does not have ablution, and there is no ablution for one who does not mention the Name of Allah (before it). There is no prayer for one who does not send blessing, (Salat) upon the Prophet, and there is no prayer for one who does not love the Ansar." (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{401}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، ح وَحَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُحِبُّ التَّيَمُّنَ فِي الطُّهُورِ إِذَا تَطَهَّرَ وَفِي تَرَجُّلِهِ إِذَا تَرَجَّلَ وَفِي انْتِعَالِهِ إِذَا انْتَعَلَ ‏.‏\hadithno{401}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah liked to start on the right when purifying himself, when combing his hair and when putting on his footwear}}
\hadithdefcmd{ibnmajah}{402}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو جَعْفَرٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا تَوَضَّأْتُمْ فَابْدَءُوا بِمَيَامِنِكُمْ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، وَابْنُ، نُفَيْلٍ وَغَيْرُهُمَا قَالُوا حَدَّثَنَا زُهَيْرٌ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{402}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'When you perform ablution, start on the right.'" (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{403}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَضْمَضَ وَاسْتَنْشَقَ مِنْ غَرْفَةٍ وَاحِدَةٍ ‏.‏\hadithno{403}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that:The Messenger of Allah rinsed his mouth and sniffed water up into his nostrils from one scoop of water}}
\hadithdefcmd{ibnmajah}{404}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ خَالِدِ بْنِ عَلْقَمَةَ، عَنْ عَبْدِ خَيْرٍ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَمَضْمَضَ ثَلاَثًا وَاسْتَنْشَقَ ثَلاَثًا مِنْ كَفٍّ وَاحِدٍ ‏.‏\hadithno{404}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ali that:The Messenger of Allah performed ablution and he rinsed his mouth three times, and sniffed water up into his nose three times from one handful}}
\hadithdefcmd{ibnmajah}{405}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو الْحُسَيْنِ الْعُكْلِيُّ، عَنْ خَالِدِ بْنِ عَبْدِ اللَّهِ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ الأَنْصَارِيِّ، قَالَ أَتَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَسَأَلَنَا وَضُوءًا فَأَتَيْتُهُ بِمَاءٍ فَمَضْمَضَ وَاسْتَنْشَقَ مِنْ كَفٍّ وَاحِدٍ ‏.‏\hadithno{405}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Abdullah bin Zaid Al-Ansari said:"The Messenger of Allah came to us and asked us for water for ablution. I brought water to him and he rinsed his mouth and sniffed water up into his nostrils from one handful}}
\hadithdefcmd{ibnmajah}{406}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مَنْصُورٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ سَلَمَةَ بْنِ قَيْسٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا تَوَضَّأْتَ فَانْثُرْ وَإِذَا اسْتَجْمَرْتَ فَأَوْتِرْ ‏"‏ ‏.‏\hadithno{406}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Salamah bin Qais said to me:The Messenger of Allah said to me: 'When you perform ablution, clean your nose, and when you use pebbles to clean yourself after defecating, use an odd number}}
\hadithdefcmd{ibnmajah}{407}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْ��َةَ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، عَنْ إِسْمَاعِيلَ بْنِ كَثِيرٍ، عَنْ عَاصِمِ بْنِ لَقِيطِ بْنِ صَبِرَةَ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَخْبِرْنِي عَنِ الْوُضُوءِ، ‏.‏ قَالَ ‏ "‏ أَسْبِغِ الْوُضُوءَ وَبَالِغْ فِي الاِسْتِنْشَاقِ إِلاَّ أَنْ تَكُونَ صَائِمًا ‏"‏ ‏.‏\hadithno{407}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Asim bin Laqit bin Sabrah that his father said:"I said: 'O Messenger of Allah! Tell me about ablution.' He said: 'Perform ablution properly and sniff water up into your nostrils, thoroughly, unless you are fasting}}
\hadithdefcmd{ibnmajah}{408}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ قَارِظِ بْنِ شَيْبَةَ، عَنْ أَبِي غَطَفَانَ الْمُرِّيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اسْتَنْثِرُوا مَرَّتَيْنِ بَالِغَتَيْنِ أَوْ ثَلاَثًا ‏"‏ ‏.‏\hadithno{408}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:'Sniff up water into the nostrils thoroughly, two or three times}}
\hadithdefcmd{ibnmajah}{409}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، وَدَاوُدُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَوَضَّأَ فَلْيَسْتَنْثِرْ وَمَنِ اسْتَجْمَرَ فَلْيُوتِرْ ‏"‏ ‏.‏\hadithno{409}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever performs ablution, let him clean his nose, and whoever uses pebbles to clean himself after defecating, let him use an odd number}}
\hadithdefcmd{ibnmajah}{410}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ النَّخَعِيُّ، عَنْ ثَابِتِ بْنِ أَبِي صَفِيَّةَ الثُّمَالِيِّ، قَالَ سَأَلْتُ أَبَا جَعْفَرٍ قُلْتُ لَهُ حُدِّثْتَ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ تَوَضَّأَ مَرَّةً مَرَّةً قَالَ نَعَمْ ‏.‏ قُلْتُ وَمَرَّتَيْنِ مَرَّتَيْنِ وَثَلاَثًا ثَلاَثًا قَالَ نَعَمْ ‏.‏\hadithno{410}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Thabit bin Abi Safiyyah Ath-Thumali said:"I asked Abu Ja'far: Was it narrated to you from Jabir bin 'Abdullah that the Prophet performed ablution washing each part once?' He said: 'Yes.' I said: 'And each part twice, and each part thrice?' He said: 'Yes}}
\hadithdefcmd{ibnmajah}{411}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ سُفْيَانَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ غُرْفَةً غُرْفَةً ‏.‏\hadithno{411}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Abbas said:"I saw the Messenger of Allah performing ablution, taking one handful (of water) at a time}}
\hadithdefcmd{ibnmajah}{412}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، أَنْبَأَنَا الضَّحَّاكُ بْنُ شُرَحْبِيلَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي غَزْوَةِ تَبُوكَ تَوَضَّأَ وَاحِدَةً وَاحِدَةً ‏.‏\hadithno{412}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Umar said:"I saw the Messenger of Allah during the campaign of Tabuk performing ablution, washing each part once}}
\hadithdefcmd{ibnmajah}{413}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ الدِّمَشْقِيُّ، عَنِ ابْنِ ثَوْبَانَ، عَنْ عَبْدَةَ بْنِ أَبِي لُبَابَةَ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، قَالَ رَأَيْتُ عُثْمَانَ وَعَلِيًّا يَتَوَضَّآنِ ثَلاَثًا ثَلاَثًا وَيَقُولاَنِ هَكَذَا كَانَ وُضُوءُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَاهُ أَبُو حَاتِمٍ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ ثَابِتِ بْنِ ثَوْبَانَ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{413}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Shaqiq bin Salamah said:"I saw `Uthman and `Ali performing ablution, washing each part three times, and they said: 'This is how the Messenger of Allah used to perform ablution.'" (Hasan) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{414}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ تَوَضَّأَ ثَلاَثًا ثَلاَثًا وَرَفَعَ ذَلِكَ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{414}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar:Performed ablution washing each part three times, and he attributed that to the Prophet}}
\hadithdefcmd{ibnmajah}{415}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا خَالِدُ بْنُ حَيَّانَ، عَنْ سَالِمٍ أَبِي الْمُهَاجِرِ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ عَائِشَةَ، وَأَبِي، هُرَيْرَةَ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ تَوَضَّأَ ثَلاَثًا ثَلاَثًا ‏.‏\hadithno{415}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Aishah and Abu Hurairah that:The Prophet did ablution washing each part three times}}
\hadithdefcmd{ibnmajah}{416}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ فَائِدٍ أَبِي الْوَرْقَاءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ ثَلاَثًا ثَلاَثًا وَمَسَحَ رَأْسَهُ مَرَّةً ‏.‏\hadithno{416}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Awfa said:"I saw the Messenger of Allah performing ablution, washing each part three times, and wiping his head once}}
\hadithdefcmd{ibnmajah}{417}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ سُفْيَانَ، عَنْ لَيْثٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي مَالِكٍ الأَشْعَرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَتَوَضَّأُ ثَلاَثًا ثَلاَثًا ‏.‏\hadithno{417}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Malik Ash'ari said:"The Messenger of Allah used to perform ablution washing each part three times}}
\hadithdefcmd{ibnmajah}{418}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ بْنِ عَفْرَاءَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ ثَلاَثًا ثَلاَثًا ‏.‏\hadithno{418}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Rabi' bint Mu'awwidh bin 'Afra' that:The Messenger of Allah performed ablution washing each part three times}}
\hadithdefcmd{ibnmajah}{419}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنِي مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ الْعَطَّارُ، حَدَّثَنِي عَبْدُ الرَّحِيمِ بْنُ زَيْدٍ الْعَمِّيُّ، عَنْ أَبِيهِ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنِ ابْنِ عُمَرَ، قَالَ تَوَضَّأَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَاحِدَةً وَاحِدَةً فَقَالَ ‏"‏ هَذَا وُضُوءُ مَنْ لاَ يَقْبَلُ اللَّهُ مِنْهُ صَلاَةً إِلاَّ بِهِ ‏"‏ ‏.‏ ثُمَّ تَوَضَّأَ ثِنْتَيْنِ ثِنْتَيْنِ فَقَالَ ‏"‏ هَذَا وُضُوءُ الْقَدْرِ مِنَ الْوُضُوءِ ‏"‏ ‏.‏ وَتَوَضَّأَ ثَلاَثًا ثَلاَثًا وَقَالَ ‏"‏ هَذَا أَسْبَغُ الْوُضُوءِ وَهُوَ وُضُوئِي وَوُضُوءُ خَلِيلِ اللَّهِ إِبْرَاهِيمَ وَمَنْ تَوَضَّأَ هَكَذَا ثُمَّ قَالَ عِنْدَ فَرَاغِهِ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ فُتِحَ لَهُ ثَمَانِيَةُ أَبْوَابِ الْجَنَّةِ يَدْخُلُ مِنْ أَيِّهَا شَاءَ ‏"‏ ‏.‏\hadithno{419}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah performed ablution washing each part once. He said: 'This is the ablution of the person from whom Allah will not accept his prayer without it.' Then he performed ablution washing each part twice, and he said: 'This is the ablution that Allah appreciates.' Then he performed ablution washing each part three times, and said: 'This is how ablution is performed properly, and this is my ablution and the ablution of the Close Friend of Allah, Ibrahim. Whoever performs ablution like this, then on completing it says: 'Ashhadu an la ilaha illallah, wa ashhadu anna Muhammadan 'abduhu wa rasuluhu' (I bear witness that none has the right to be worshipped but Allah, and I bear witness that Muhammed is His servant and His Messenger), eight gates of Paradise will be opened to him and he may enter through whichever one he wants}}
\hadithdefcmd{ibnmajah}{420}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ قَعْنَبٍ أَبُو بِشْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَرَادَةَ الشَّيْبَانِيُّ، عَنْ زَيْدِ بْنِ الْحَوَارِيِّ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ دَعَا بِمَاءٍ فَتَوَضَّأَ مَرَّةً مَرَّةً فَقَالَ ‏"‏ هَذَا وَظِيفَةُ الْوُضُوءِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ وُضُوءٌ مَنْ لَمْ يَتَوَضَّأْهُ لَمْ يَقْبَلِ اللَّهُ لَهُ صَلاَةً ‏"‏ ‏.‏ ثُمَّ تَوَضَّأَ مَرَّتَيْنِ مَرَّتَيْنِ ثُمَّ قَالَ ‏"‏ هَذَا وُضُوءٌ مَنْ تَوَضَّأَهُ أَعْطَاهُ اللَّهُ كِفْلَيْنِ مِنَ الأَجْرِ ‏"‏ ‏.‏ ثُمَّ تَوَضَّأَ ثَلاَثًا ثَلاَثًا فَقَالَ ‏"‏ هَذَا وُضُوئِي وَوُضُوءُ الْمُرْسَلِينَ مِنْ قَبْلِي ‏"‏ ‏.‏\hadithno{420}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ubayy bin Ka'b that:The Messenger of Allah called for water and performed ablution once. He said: "This is the minimum requirement of ablution' or he said: 'The ablution of one who, if he does not perform this ablution, Allah will not accept his prayer." Then he performed ablution washing each part twice, and he said: 'This is the ablution of one who, if he performs it, Allah will give him two shares of reward." Then he performed ablution washing each part three times, and said: 'This is my ablution and the ablution of the Messengers who were sent before me}}
\hadithdefcmd{ibnmajah}{421}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا خَارِجَةُ بْنُ مُصْعَبٍ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنْ عُتَىِّ بْنِ ضَمْرَةَ السَّعْدِيِّ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لِلْوُضُوءِ شَيْطَانًا يُقَالُ لَهُ وَلَهَانُ فَاتَّقُوا وَسْوَاسَ الْمَاءِ ‏"‏ ‏.‏\hadithno{421}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ubayy bin Ka'b said:"The Messenger of Allah said: 'There is a devil for ablution who is called Walahan, so be on guard against the insinuating thoughts (Waswas) about water}}
\hadithdefcmd{ibnmajah}{422}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا خَالِي، يَعْلَى عَنْ سُفْيَانَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَسَأَلَهُ عَنِ الْوُضُوءِ فَأَرَاهُ ثَلاَثًا ثَلاَثًا ثُمَّ قَالَ ‏ "‏ هَذَا الْوُضُوءُ فَمَنْ زَادَ عَلَى هَذَا فَقَدْ أَسَاءَ وَتَعَدَّى أَوْ ظَلَمَ ‏"‏ ‏.‏\hadithno{422}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib from his father, from his grandfather, that:A Bedouin came to the Prophet and asked him about ablution. He showed him how to perform it washing each part of the body three times. Then he said: 'This is the ablution, and whoever does more than this, has done evil, transgressed the limits and wronged himself}}
\hadithdefcmd{ibnmajah}{423}{حَدَّثَنَا أَبُو إِسْحَاقَ الشَّافِعِيُّ، إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ الْعَبَّاسِ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ كُرَيْبًا، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ فَقَامَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَتَوَضَّأَ مِنْ شَنَّةٍ وُضُوءًا يُقَلِّلُهُ فَقُمْتُ فَصَنَعْتُ كَمَا صَنَعَ ‏.‏\hadithno{423}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Amr heard Kuraib saying:"I heard Ibn 'Abbas say: 'I stayed overnight with my maternal aunt Maimunah, and the Prophet got up and performed ablution from an old water skin, and he did a brief ablution. Then I got up and did the same as he had done}}
\hadithdefcmd{ibnmajah}{424}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ مُحَمَّدِ بْنِ الْفَضْلِ، عَنْ أَبِيهِ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ رَجُلاً يَتَوَضَّأُ فَقَالَ ‏ "‏ لاَ تُسْرِفْ لاَ تُسْرِفْ ‏"‏ ‏.‏\hadithno{424}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It is narrated that Ibn 'Umar said:"The Messenger of Allah saw a man performing ablution, and he said: 'Do not be extravagant, do not be extravagant (in using water).'" (Maudu)}}
\hadithdefcmd{ibnmajah}{425}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ حُيَىِّ بْنِ عَبْدِ اللَّهِ الْمَعَافِرِيِّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّ بِسَعْدٍ وَهُوَ يَتَوَضَّأُ فَقَالَ ‏"‏ مَا هَذَا السَّرَفُ ‏"‏ ‏.‏ فَقَالَ أَفِي الْوُضُوءِ إِسْرَافٌ قَالَ ‏"‏ نَعَمْ وَإِنْ كُنْتَ عَلَى نَهَرٍ جَارٍ ‏"‏ ‏.‏\hadithno{425}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that:The Messenger of Allah passed by Sa'd when he was performing ablution, and he said: 'What is this extravagance?' He said: 'Can there be any extravagance in ablution?' He said: 'Yes, even if you are on the bank of a flowing river}}
\hadithdefcmd{ibnmajah}{426}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا مُوسَى بْنُ سَالِمٍ أَبُو جَهْضَمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِإِسْبَاغِ الْوُضُوءِ ‏.‏\hadithno{426}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah commanded us to perform ablution properly}}
\hadithdefcmd{ibnmajah}{427}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ أَلاَ أَدُلُّكُمْ عَلَى مَا يُكَفِّرُ اللَّهُ بِهِ الْخَطَايَا وَيَزِيدُ بِهِ فِي الْحَسَنَاتِ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِسْبَاغُ الْوُضُوءِ عَلَى الْمَكَارِهِ وَكَثْرَةُ الْخُطَا إِلَى الْمَسَاجِدِ وَانْتِظَارُ الصَّلاَةِ بَعْدَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{427}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Khudri that he heard :The Messenger of Allah say: "Shall I not tell you of something by means of which Allah expiates for sins and increases good deeds?" They said: "Yes, O Messenger of Allah." He said: "Perform ablution properly despite difficulties, increasing the number of steps one takes towards the mosque and waiting for the next prayer after prayer}}
\hadithdefcmd{ibnmajah}{428}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا سُفْيَانُ بْنُ حَمْزَةَ، عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنِ الْوَلِيدِ بْنِ رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كَفَّارَاتُ الْخَطَايَا إِسْبَاغُ الْوُضُوءِ عَلَى الْمَكَارِهِ وَإِعْمَالُ الأَقْدَامِ إِلَى الْمَسَاجِدِ وَانْتِظَارُ الصَّلاَةِ بَعْدَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{428}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "Sins are expiated by well-performed ablution despite difficulties, increasing the number of steps one takes towards the mosque, (and waiting for the next prayer after prayer)}}
\hadithdefcmd{ibnmajah}{429}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْكَرِيمِ أَبِي أُمَيَّةَ، عَنْ حَسَّانِ بْنِ بِلاَلٍ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ حَسَّانِ بْنِ بِلاَلٍ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُخَلِّلُ لِحْيَتَهُ ‏.‏\hadithno{429}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ammar bin Yasir said:"I saw the Messenger of Allah running his fingers through his beard}}
\hadithdefcmd{ibnmajah}{430}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي خَالِدٍ الْقَزْوِينِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ إِسْرَائِيلَ، عَنْ عَامِرِ بْنِ شَقِيقٍ الأَسَدِيِّ، عَنْ أَبِي وَائِلٍ، عَنْ عُثْمَانَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَخَلَّلَ لِحْيَتَهُ ‏.‏\hadithno{430}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Uthman that:The Messenger of Allah performed ablution and ran his fingers through his beard}}
\hadithdefcmd{ibnmajah}{431}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَفْصِ بْنِ هِشَامِ بْنِ زَيْدِ بْنِ أَنَسِ بْنِ مَالِكٍ، حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ أَبُو النَّضْرِ، صَاحِبُ الْبَصْرِيِّ عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا تَوَضَّأَ خَلَّلَ لِحْيَتَهُ وَفَرَّجَ أَصَابِعَهُ مَرَّتَيْنِ ‏.‏\hadithno{431}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"When the Messenger of Allah performed ablution, he ran his fingers through his beard and separated his fingers (to let water run through them) twice}}
\hadithdefcmd{ibnmajah}{432}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ قَيْسٍ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا تَوَضَّأَ عَرَكَ عَارِضَيْهِ بَعْضَ الْعَرْكِ ثُمَّ شَبَكَ لِحْيَتَهُ بِأَصَابِعِهِ مِنْ تَحْتِهَا ‏.‏\hadithno{432}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"Whenever the Messenger of Allah performed ablution, he rubbed the sides of his face then run his fingers through his beard from beneath}}
\hadithdefcmd{ibnmajah}{433}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ الْكِلاَبِيُّ، حَدَّثَنَا وَاصِلُ بْنُ السَّائِبِ الرَّقَاشِيُّ، عَنْ أَبِي سَوْرَةَ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَخَلَّلَ لِحْيَتَهُ ‏.‏\hadithno{433}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Ayyub Al-Ansari said:"I saw the Messenger of Allah performing ablution and he ran his fingers through his beard}}
\hadithdefcmd{ibnmajah}{434}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا مُحَمَّدُ بْنُ إِدْرِيسَ الشَّافِعِيُّ، قَالَ أَنْبَأَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ زَيْدٍ - وَهُوَ جَدُّ عَمْرِو بْنِ يَحْيَى - هَلْ تَسْتَطِيعُ أَنْ تُرِيَنِي، كَيْفَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَتَوَضَّأُ فَقَالَ عَبْدُ اللَّهِ بْنُ زَيْدٍ نَعَمْ ‏.‏ فَدَعَا بِوَضُوءٍ فَأَفْرَغَ عَلَى يَدَيْهِ فَغَسَلَ يَدَيْهِ مَرَّتَيْنِ ثُمَّ تَمَضْمَضَ وَاسْتَنْثَرَ ثَلاَثًا ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ غَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ إِلَى الْمِرْفَقَيْنِ ثُمَّ مَسَحَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ بَدَأَ بِمُقَدَّمِ رَأْسِهِ ثُمَّ ذَهَبَ بِهِمَا إِلَى قَفَاهُ ثُمَّ رَدَّهُمَا حَتَّى رَجَعَ إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ ثُمَّ غَسَلَ رِجْلَيْهِ ‏.‏\hadithno{434}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Amr bin Yahya narrated that his father said to 'Abdullah bin Zaid who was the grandfather of 'Amr bin Yahya:"Can you show me how the Messenger of Allah used to perform ablution?" 'Abdullah bin Zaid said: "Yes," So he called for water, poured it over his hands and washed his hands twice. Then he raised his mouth and sniffed water up into his nostrils three times. Then he washed his face three times and his arms up to his elbows twice. Then he wiped his head with his hands, from front to back. He started at the front of his head, then went with them to the nape of his neck, then he brought them back, returning them to the place he started, then he washed his feet}}
\hadithdefcmd{ibnmajah}{435}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ حَجَّاجٍ، عَنْ عَطَاءٍ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَمَسَحَ رَأْسَهُ مَرَّةً ‏.‏\hadithno{435}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Uthman bin 'Affan said:"I saw the Messenger of Allah performing ablution and he wiped his head once}}
\hadithdefcmd{ibnmajah}{436}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَسَحَ رَأْسَهُ مَرَّةً ‏.‏\hadithno{436}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ali that:The Messenger of Allah wiped his head once}}
\hadithdefcmd{ibnmajah}{437}{حَدَّثَنَا مُحَمَّدُ بْنُ الْحَارِثِ الْمِصْرِيُّ، حَدَّثَنَا يَحْيَى بْنُ رَاشِدٍ الْبَصْرِيُّ، عَنْ يَزِيدَ، مَوْلَى سَلَمَةَ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَمَسَحَ رَأْسَهُ مَرَّةً ‏.‏\hadithno{437}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Salamah bin Akwa' said:"I saw the Messenger of Allah performing ablution, and he wiped his head once}}
\hadithdefcmd{ibnmajah}{438}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ ابْنِ عَفْرَاءَ، قَالَتْ تَوَضَّأَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَمَسَحَ رَأْسَهُ مَرَّتَيْنِ ‏.‏\hadithno{438}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ar-Rubai' bint Mu'awwidh bin 'Afra' said:"The Messenger of Allah performed ablution and wiped his head twice}}
\hadithdefcmd{ibnmajah}{439}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَسَحَ أُذُنَيْهِ دَاخِلَهُمَا بِالسَّبَّابَتَيْنِ وَخَالَفَ إِبْهَامَيْهِ إِلَى ظَاهِرِ أُذُنَيْهِ فَمَسَحَ ظَاهِرَهُمَا وَبَاطِنَهُمَا ‏.‏\hadithno{439}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that:The Messenger of Allah wiped his ears, putting his forefingers in his ears and wiping the back of them with his thumbs, so he wiped them inside and out}}
\hadithdefcmd{ibnmajah}{440}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَمَسَحَ ظَاهِرَ أُذُنَيْهِ وَبَاطِنَهُمَا ‏.‏\hadithno{440}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Rubai' that:The prophet performed ablution and wiped his ears inside and out}}
\hadithdefcmd{ibnmajah}{441}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ ابْنِ عَفْرَاءَ، قَالَتْ تَوَضَّأَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَأَدْخَلَ إِصْبَعَيْهِ فِي جُحْرَىْ أُذُنَيْهِ ‏.‏\hadithno{441}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Rubai' bint Mu'awwidh bin 'Afra' said:"The Prophet performed ablution, and he put his fingers in the (holes) inside of his ears}}
\hadithdefcmd{ibnmajah}{442}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا حَرِيزُ بْنُ عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَيْسَرَةَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَمَسَحَ بِرَأْسِهِ وَأُذُنَيْهِ ظَاهِرَهُمَا وَبَاطِنَهُمَا ‏.‏\hadithno{442}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Miqdam bin Ma'dikarib that:The Messenger of Allah performed ablution and he wiped his head and his ears, inside and out}}
\hadithdefcmd{ibnmajah}{443}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ شُعْبَةَ، عَنْ حَبِيبِ بْنِ زَيْدٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الأُذُنَانِ مِنَ الرَّأْسِ ‏"‏ ‏.‏\hadithno{443}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Zaid said:"The Messenger of Allah said: 'The ears are part of the head}}
\hadithdefcmd{ibnmajah}{444}{حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ سِنَانِ بْنِ رَبِيعَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الأُذُنَانِ مِنَ الرَّأْسِ ‏"‏ ‏.‏ وَكَانَ يَمْسَحُ رَأْسَهُ مَرَّةً وَكَانَ يَمْسَحُ الْمَأْقَيْنِ ‏.‏\hadithno{444}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Umamah that:The Messenger of Allah said: "The ears are part of the head." He used to wipe his head once, and he used to wipe over the inner corners of the eyes (that are close to the nose)}}
\hadithdefcmd{ibnmajah}{445}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَمْرُو بْنُ الْحُصَيْنِ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عُلاَثَةَ، عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الأُذُنَانِ مِنَ الرَّأْسِ ‏"‏ ‏.‏\hadithno{445}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The ears are part of the head}}
\hadithdefcmd{ibnmajah}{446}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حِمْيَرَ، عَنِ ابْنِ لَهِيعَةَ، حَدَّثَنِي يَزِيدُ بْنُ عَمْرٍو الْمَعَافِرِيُّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنِ الْمُسْتَوْرِدِ بْنِ شَدَّادٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَخَلَّلَ أَصَابِعَ رِجْلَيْهِ بِخِنْصِرِهِ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا خَازِمُ بْنُ يَحْيَى الْحُلْوَانِيُّ، حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{446}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mustawarid bin Shaddad said:"I saw the Messenger of Allah performing ablution, and he ran his little finger between his toes." (Sahih) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{447}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا سَعْدُ بْنُ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنِ ابْنِ أَبِي الزِّنَادِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ صَالِحٍ، مَوْلَى التَّوْأَمَةِ عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَأَسْبِغِ الْوُضُوءَ وَاجْعَلِ الْمَاءَ بَيْنَ أَصَابِعِ يَدَيْكَ وَرِجْلَيْكَ ‏"‏ ‏.‏\hadithno{447}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:'The Messenger of Allah said: 'When you get up for prayer, perform ablution properly and make the water run between your toes and your fingers}}
\hadithdefcmd{ibnmajah}{448}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، عَنْ إِسْمَاعِيلَ بْنِ كَثِيرٍ، عَنْ عَاصِمِ بْنِ لَقِيطِ بْنِ صَبِرَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَسْبِغِ الْوُضُوءَ وَخَلِّلْ بَيْنَ الأَصَابِعِ ‏"‏ ‏.‏\hadithno{448}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Asim bin Laqit bin Saabirah narrated that his father said:"The Messenger of Allah said: perform ablution properly and let the water run between your fingers}}
\hadithdefcmd{ibnmajah}{449}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مُحَمَّدٍ الرَّقَاشِيُّ، حَدَّثَنَا مَعْمَرُ بْنُ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، حَدَّثَنِي أَبِي، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا تَوَضَّأَ حَرَّكَ خَاتَمَهُ ‏.‏\hadithno{449}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Ubaidullah bin Abu Rafi' narrated from his father that:Whenever the Messenger of Allah performed ablution, he moved his ring}}
\hadithdefcmd{ibnmajah}{450}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ أَبِي يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ رَأَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَوْمًا يَتَوَضَّئُونَ وَأَعْقَابُهُمْ تَلُوحُ فَقَالَ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ أَسْبِغُوا الْوُضُوءَ ‏"‏ ‏.‏\hadithno{450}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin 'Amr said:"The Messenger of Allah saw some people performing ablution, and their heels were dry. He said: 'Woe to the heels because of Hell-fire, perform ablution properly}}
\hadithdefcmd{ibnmajah}{451}{قَالَ الْقَطَّانُ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا عَبْدُ الْمُؤْمِنِ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{451}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:The Messenger of Allah said: 'Woe to the heels because of Hell-fire}}
\hadithdefcmd{ibnmajah}{452}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنِ ابْنِ عَجْلاَنَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَأَبُو خَالِدٍ الأَحْمَرُ عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، قَالَ رَأَتْ عَائِشَةُ عَبْدَ الرَّحْمَنِ وَهُوَ يَتَوَضَّأُ فَقَالَتْ أَسْبِغِ الْوُضُوءَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ وَيْلٌ لِلْعَرَاقِيبِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{452}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Salamah said:"Aishah saw 'Abdur-Rahman performing abluti0on, and she said: Perform ablution properly, for I heard the Messenger of Allah say: 'Woe to the Achilles' tendon because of Hell-fire}}
\hadithdefcmd{ibnmajah}{453}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{453}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that :The Prophet said: "Woe to the heels because of Hell-fire}}
\hadithdefcmd{ibnmajah}{454}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي كَرِبٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ وَيْلٌ لِلْعَرَاقِيبِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{454}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"I heard the Messenger of Allah say: 'Woe to the Achilles' tendon because of Hell-fire}}
\hadithdefcmd{ibnmajah}{455}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ، وَعُثْمَانُ بْنُ إِسْمَاعِيلَ الدِّمَشْقِيَّانِ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا شَيْبَةُ بْنُ الأَحْنَفِ، عَنْ أَبِي سَلاَّمٍ الأَسْوَدِ، عَنْ أَبِي صَالِحٍ الأَشْعَرِيِّ، حَدَّثَنِي أَبُو عَبْدِ اللَّهِ الأَشْعَرِيُّ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، وَيَزِيدَ بْنِ أَبِي سُفْيَانَ، وَشُرَحْبِيلَ ابْنِ حَسَنَةَ، وَعَمْرِو بْنِ الْعَاصِ، كُلُّ هَؤُلاَءِ سَمِعُوا مِنْ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَتِمُّوا الْوُضُوءَ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{455}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Khalid bin Walid, Yazid bin Abu Sufyan, Shurahbil bin Hasanah and 'Amr bin 'As that:They all heard the Messenger of Allah say: 'Complete the ablution. Woe to the heels because of Hell-fire}}
\hadithdefcmd{ibnmajah}{456}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ، قَالَ رَأَيْتُ عَلِيًّا تَوَضَّأَ فَغَسَلَ قَدَمَيْهِ إِلَى الْكَعْبَيْنِ ثُمَّ قَالَ أَرَدْتُ أَنْ أُرِيَكُمْ طُهُورَ نَبِيِّكُمْ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{456}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Haiyah said:"I saw 'Ali performing ablution and he washed his feet up to the ankles, then he said: 'I wanted to show you how your Prophet purified himself}}
\hadithdefcmd{ibnmajah}{457}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَرِيزُ بْنُ عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَيْسَرَةَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَغَسَلَ رِجْلَيْهِ ثَلاَثًا ثَلاَثًا ‏.‏\hadithno{457}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Miqdam bin Ma'dikarib that:The Messenger of Allah performed ablution; so he washed his feet three times}}
\hadithdefcmd{ibnmajah}{458}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ رَوْحِ بْنِ الْقَاسِمِ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الرُّبَيِّعِ، قَالَتْ أَتَانِي ابْنُ عَبَّاسٍ فَسَأَلَنِي عَنْ هَذَا الْحَدِيثِ، - تَعْنِي حَدِيثَهَا الَّذِي ذَكَرَتْ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ وَغَسَلَ رِجْلَيْهِ - فَقَالَ ابْنُ عَبَّاسٍ إِنَّ النَّاسَ أَبَوْا إِلاَّ الْغَسْلَ وَلاَ أَجِدُ فِي كِتَابِ اللَّهِ إِلاَّ الْمَسْحَ ‏.‏\hadithno{458}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Rubai' said:"Ibn 'Abbas came to me and asked me about this Hadith" meaning the Hadith, that she had narrated, saying that the Messenger of Allah performed ablution and washed his feet. "Ibn 'Abbas said: 'The people are insisting on washing their feet, but I do not find anything in the Qur'an except (the injunction to) wipe them}}
\hadithdefcmd{ibnmajah}{459}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ جَامِعِ بْنِ شَدَّادٍ أَبِي صَخْرَةَ، قَالَ سَمِعْتُ حُمْرَانَ، يُحَدِّثُ أَبَا بُرْدَةَ فِي الْمَسْجِدِ أَنَّهُ سَمِعَ عُثْمَانَ بْنَ عَفَّانَ، يُحَدِّثُ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَتَمَّ الْوُضُوءَ كَمَا أَمَرَهُ اللَّهُ فَالصَّلَوَاتُ الْمَكْتُوبَاتُ كَفَّارَاتٌ لِمَا بَيْنَهُنَّ ‏"‏ ‏.‏\hadithno{459}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jami' bin Shaddad - AbuSakhrah - said:"I heard Humran telling Abu Burdah in the mosque that he had heard 'Uthman bin 'Affan narrating that the Prophet had said" 'Whoever performs ablution perfectly as Allah has enjoined, then his prescribed prayer will serve as expiation for what is between them}}
\hadithdefcmd{ibnmajah}{460}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، حَدَّثَنِي عَلِيُّ بْنُ يَحْيَى بْنِ خَلاَّدٍ، عَنْ أَبِيهِ، عَنْ عَمِّهِ، رِفَاعَةَ بْنِ رَافِعٍ أَنَّهُ كَانَ جَالِسًا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ إِنَّهَا لاَ تَتِمُّ صَلاَةٌ لأَحَدٍ حَتَّى يُسْبِغَ الْوُضُوءَ كَمَا أَمَرَهُ اللَّهُ تَعَالَى يَغْسِلُ وَجْهَهُ وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ وَيَمْسَحُ بِرَأْسِهِ وَرِجْلَيْهِ إِلَى الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{460}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ali bin Yahya bin Khallad narrated, from his father, from his paternal uncle Rifa'ah bin Rafi' that:He was sitting with the Prophet who said: 'No person's prayer is complete until he performs ablution properly as Allah has commanded him, washing his face, his arms up to the elbows, wiping his head and his feet up to the ankles}}
\hadithdefcmd{ibnmajah}{461}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا زَكَرِيَّا بْنُ أَبِي زَائِدَةَ، قَالَ قَالَ مَنْصُورٌ حَدَّثَنَا مُجَاهِدٌ، عَنِ الْحَكَمِ بْنِ سُفْيَانَ الثَّقَفِيِّ، أَنَّهُ رَأَى رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ ثُمَّ أَخَذَ كَفًّا مِنْ مَاءٍ فَنَضَحَ بِهِ فَرْجَهُ ‏.‏\hadithno{461}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hakam bin Sufyan Ath-Thawri that:He saw the Messenger of Allah perform ablution then take a handful of water and sprinkle it over his private area to remove any doubts about urine drippings}}
\hadithdefcmd{ibnmajah}{462}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ الْفِرْيَابِيُّ، حَدَّثَنَا حَسَّانُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ أَبِيهِ، زَيْدِ بْنِ حَارِثَةَ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عَلَّمَنِي جِبْرَائِيلُ الْوُضُوءَ وَأَمَرَنِي أَنْ أَنْضَحَ تَحْتَ ثَوْبِي لِمَا يَخْرُجُ مِنَ الْبَوْلِ بَعْدَ الْوُضُوءِ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ التَّنِّيسِيُّ، حَدَّثَنَا ابْنُ لَهِيعَةَ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{462}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Usamah bin Zaid narrated that his father Zaid bin Harithah said:"The Messenger of Allah said: 'Jibril taught me (how to perform) the ablution, and he ordered me to sprinkle water underneath my garment, lest a drop of urine leak out after the ablution.'" (Da'if) Other chains with similar wording}}
\hadithdefcmd{ibnmajah}{463}{حَدَّثَنَا الْحُسَيْنُ بْنُ سَلَمَةَ الْيَحْمَدِيُّ، حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْهَاشِمِيُّ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا تَوَضَّأْتَ فَانْتَضِحْ ‏"‏ ‏.‏\hadithno{463}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'When you perform ablution, sprinkle water}}
\hadithdefcmd{ibnmajah}{464}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا قَيْسٌ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ تَوَضَّأَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَنَضَحَ فَرْجَهُ ‏.‏\hadithno{464}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah performed ablution and sprinkled his private part}}
\hadithdefcmd{ibnmajah}{465}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، أَنَّ أَبَا مُرَّةَ، مَوْلَى عَقِيلٍ حَدَّثَهُ أَنَّ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ حَدَّثَتْهُ أَنَّهُ، لَمَّا كَانَ عَامُ الْفَتْحِ قَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى غُسْلِهِ فَسَتَرَتْ عَلَيْهِ فَاطِمَةُ ثُمَّ أَخَذَ ثَوْبَهُ فَالْتَحَفَ بِهِ ‏.‏\hadithno{465}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Umm Hani' bint Abu Talib narrated that :When it was the year of the Conquest (of Makkah), the Messenger of Allah got up to perform a bath and Fatimah screened him. Then he took his garment and wrapped himself in it (such that it became like the towel used to dry oneself)}}
\hadithdefcmd{ibnmajah}{466}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا ابْنُ أَبِي لَيْلَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَعْدِ بْنِ زُرَارَةَ، عَنْ مُحَمَّدِ بْنِ شُرَحْبِيلَ، عَنْ قَيْسِ بْنِ سَعْدٍ، قَالَ أَتَانَا النَّبِيُّ ـ صلى الله عليه وسلم ـ فَوَضَعْنَا لَهُ مَاءً فَاغْتَسَلَ ثُمَّ أَتَيْنَاهُ بِمِلْحَفَةٍ وَرْسِيَّةٍ فَاشْتَمَلَ بِهَا فَكَأَنِّي أَنْظُرُ إِلَى أَثَرِ الْوَرْسِ عَلَى عُكَنِهِ ‏.‏\hadithno{466}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qais bin Sa'd said:"The Prophet came to us and we gave him water to perform a bath." Then we brought him a Warshiyyah cloth, and he wrapped himself in it. It is as if I can see the marks of the Wars on the folds of his stomach}}
\hadithdefcmd{ibnmajah}{467}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، حَدَّثَنَا ابْنُ عَبَّاسٍ، عَنْ خَالَتِهِ، مَيْمُونَةَ قَالَتْ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بِثَوْبٍ حِينَ اغْتَسَلَ مِنَ الْجَنَابَةِ فَرَدَّهُ وَجَعَلَ يَنْفُضُ الْمَاءَ ‏.‏\hadithno{467}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn 'Abbas narrated that his maternal aunt Maimunah said:"I brought a piece of cloth (for drying) to the Messenger of Allahwhen he performed a bath to cleanse himself from sexual impurity. He refused it and began to shake off water}}
\hadithdefcmd{ibnmajah}{468}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ، وَأَحْمَدُ بْنُ الأَزْهَرِ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَزِيدُ بْنُ السِّمْطِ، حَدَّثَنَا الْوَضِينُ بْنُ عَطَاءٍ، عَنْ مَحْفُوظِ بْنِ عَلْقَمَةَ، عَنْ سَلْمَانَ الْفَارِسِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَقَلَبَ جُبَّةَ صُوفٍ كَانَتْ عَلَيْهِ فَمَسَحَ بِهَا وَجْهَهُ ‏.‏\hadithno{468}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from salman Al-Farisi that :The Messenger of Allah performed ablution, then he turned inside out the woolen garment that he was wearing and wiped his face with it}}
\hadithdefcmd{ibnmajah}{469}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، وَزَيْدُ بْنُ الْحُبَابِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو نُعَيْمٍ، قَالُوا حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ بْنِ وَهْبٍ أَبُو سُلَيْمَانَ النَّخَعِيُّ، قَالَ حَدَّثَنِي زَيْدٌ الْعَمِّيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ قَالَ ثَلاَثَ مَرَّاتٍ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ فُتِحَ لَهُ ثَمَانِيَةُ أَبْوَابِ الْجَنَّةِ مِنْ أَيِّهَا شَاءَ دَخَلَ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ الْقَطَّانُ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَصْرٍ، حَدَّثَنَا أَبُو نُعَيْمٍ، بِنَحْوِهِ ‏.‏\hadithno{469}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that :The Prophet said: "Whoever performs ablution and does it well, then says three times: 'Ashhadu an la ilaha illallah wahdahu la sharika lahu, wa ashhadu anna Muhammadan `abduhu wa rasuluhu (I bear witness that none has the right to be worshipped but Allah alone, with no partner, and I bear witness that Muhammad is His slave and His Messenger),' eight gates of Paradise will be opened for him; whichever one he wants he may enter." (Da'if) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{470}{حَدَّثَنَا عَلْقَمَةُ بْنُ عَمْرٍو الدَّارِمِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ الْبَجَلِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ مُسْلِمٍ يَتَوَضَّأُ فَيُحْسِنُ الْوُضُوءَ ثُمَّ يَقُولُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ إِلاَّ فُتِحَتْ لَهُ ثَمَانِيَةُ أَبْوَابِ الْجَنَّةِ يَدْخُلُ مِنْ أَيِّهَا شَاءَ ‏"‏ ‏.‏\hadithno{470}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Umar bin Khattab said:"The Messenger of Allah said: 'There is no Muslim who performs ablution and does it well, then says: Ashhadu an la ilaha illallah, wa ashhadu anna Muhammadan `abduhu wa rasuluhu (I bear witness that none has the right to be worshipped but Allah, and I bear witness that Muhammad is His slave and Messenger),' (except that) eight gates of Paradise will be opened for him, and he will enter through whichever one he wants}}
\hadithdefcmd{ibnmajah}{471}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ الْمَاجِشُونِ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، صَاحِبِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ أَتَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَخْرَجْنَا لَهُ مَاءً فِي تَوْرٍ مِنْ صُفْرٍ فَتَوَضَّأَ بِهِ ‏.‏\hadithno{471}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Abdullah bin Zaid, the Companion of the Prophet, said:"The Messenger of Allah came to us, and we brought water out to him in a vessel of brass, and he performed ablution with it}}
\hadithdefcmd{ibnmajah}{472}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ جَحْشٍ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ جَحْشٍ، أَنَّهُ كَانَ لَهَا مِخْضَبٌ مِنْ صُفْرٍ قَالَتْ فَكُنْتُ أُرَجِّلُ رَأْسَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِيهِ ‏.‏\hadithno{472}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab bint Jahsh that :She had a tub of brass. She said: "I used to comb the hair of the Messenger of Allah in it}}
\hadithdefcmd{ibnmajah}{473}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ إِبْرَاهِيمَ بْنِ جَرِيرٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فِي تَوْرٍ ‏.‏\hadithno{473}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet performed ablution using (the water in) a vessel made of brass}}
\hadithdefcmd{ibnmajah}{474}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَنَامُ حَتَّى يَنْفُخَ ثُمَّ يَقُومُ فَيُصَلِّي وَلاَ يَتَوَضَّأُ ‏.‏ قَالَ الطَّنَافِسِيُّ قَالَ وَكِيعٌ تَعْنِي وَهُوَ سَاجِدٌ ‏.‏\hadithno{474}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that `A'ishah said:"The Messenger of Allah would fall asleep until he was breathing deeply, then he would get up and offer the prayer, and he did not perform ablution." (Hasan) Tanafisi said: "Waki` said: 'She meant while he was prostrating (he would sleep)}}
\hadithdefcmd{ibnmajah}{475}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ حَجَّاجٍ، عَنْ فُضَيْلِ بْنِ عَمْرٍو، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَامَ حَتَّى نَفَخَ ثُمَّ قَامَ فَصَلَّى ‏.‏\hadithno{475}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah that:The Messenger of Allah slept until he was breathing deeply, then he got up and prayed}}
\hadithdefcmd{ibnmajah}{476}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، عَنِ ابْنِ أَبِي زَائِدَةَ، عَنْ حُرَيْثِ بْنِ أَبِي مَطَرٍ، عَنْ يَحْيَى بْنِ عَبَّادٍ أَبِي هُبَيْرَةَ الأَنْصَارِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ نَوْمُهُ ذَلِكَ وَهُوَ جَالِسٌ ‏.‏ يَعْنِي النَّبِيَّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{476}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"He would sleep like that while he was sitting up}}
\hadithdefcmd{ibnmajah}{477}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنِ الْوَضِينِ بْنِ عَطَاءٍ، عَنْ مَحْفُوظِ بْنِ عَلْقَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَائِذٍ الأَزْدِيِّ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْعَيْنُ وِكَاءُ السَّهِ فَمَنْ نَامَ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{477}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ali bin Abu Talib that:The Messenger of Allah said: "The eye is the leather strap (that ties up) the anus, so whoever falls asleep, let him perform ablution}}
\hadithdefcmd{ibnmajah}{478}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْمُرُنَا أَنْ لاَ نَنْزِعَ خِفَافَنَا ثَلاَثَةَ أَيَّامٍ إِلاَّ مِنْ جَنَابَةٍ لَكِنْ مِنْ غَائِطٍ وَبَوْلٍ وَنَوْمٍ ‏.‏\hadithno{478}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Safwan bin 'Assal said:"The Messenger of Allah used to command us not to take off our leather socks for three days except in the case of sexual impurity, but not in the case of defecation, urine or sleep (i.e. during travel)}}
\hadithdefcmd{ibnmajah}{479}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ مَرْوَانَ بْنِ الْحَكَمِ، عَنْ بُسْرَةَ بِنْتِ صَفْوَانَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا مَسَّ أَحَدُكُمْ ذَكَرَهُ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{479}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Busrah bint Safwan said:"The Messenger of Allah said: 'If anyone of you touches his penis, let him perform ablution}}
\hadithdefcmd{ibnmajah}{480}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، جَمِيعًا عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ عُقْبَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا مَسَّ أَحَدُكُمْ ذَكَرَهُ فَعَلَيْهِ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{480}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah said: 'If anyone of you touches his penis, then he has to perform ablution}}
\hadithdefcmd{ibnmajah}{481}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْمُعَلَّى بْنُ مَنْصُورٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ بَشِيرِ بْنِ ذَكْوَانَ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، حَدَّثَنَا الْعَلاَءُ بْنُ الْحَارِثِ، عَنْ مَكْحُولٍ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّ حَبِيبَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ مَسَّ فَرْجَهُ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{481}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Habibah said:"I heard the Messenger of Allah say: 'Whoever touches his sexual organ then let him perform ablution}}
\hadithdefcmd{ibnmajah}{482}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ إِسْحَاقَ بْنِ أَبِي فَرْوَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدٍ الْقَارِيِّ، عَنْ أَبِي أَيُّوبَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ مَسَّ فَرْجَهُ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{482}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Ayyub said:"I heard the Messenger of Allah say: 'Whoever touches his sexual organ, let him perform ablution}}
\hadithdefcmd{ibnmajah}{483}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مُحَمَّدُ بْنُ جَابِرٍ، قَالَ سَمِعْتُ قَيْسَ بْنَ طَلْقٍ الْحَنَفِيَّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سُئِلَ عَنْ مَسِّ الذَّكَرِ فَقَالَ ‏ "‏ لَيْسَ فِيهِ وُضُوءٌ إِنَّمَا هُوَ مِنْكَ ‏"‏ ‏.‏\hadithno{483}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qais bin Talq Al-Hanafi narrated that his father said:"I heard the Messenger of Allah being asked about touching the penis. He said: 'That does not require ablution, because it is a part of you (your body)}}
\hadithdefcmd{ibnmajah}{484}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، قَالَ سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ مَسِّ الذَّكَرِ فَقَالَ ‏ "‏ إِنَّمَا هُوَ حذية مِنْكَ ‏"‏ ‏.‏\hadithno{484}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah said:"The Messenger of Allah was asked about touching the penis and he said: 'Rather it is a piece of you (your body)}}
\hadithdefcmd{ibnmajah}{485}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَلْقَمَةَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ تَوَضَّئُوا مِمَّا غَيَّرَتِ النَّارُ ‏"‏ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ أَتَوَضَّأُ مِنَ الْحَمِيمِ فَقَالَ لَهُ يَا ابْنَ أَخِي إِذَا سَمِعْتَ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَدِيثًا فَلاَ تَضْرِبْ لَهُ الأَمْثَالَ ‏.‏\hadithno{485}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "Perform ablution after (eating) that which has been changed by fir." Ibn 'Abbas said: "Should I do ablution after (touching) hot water?" Abu Hurairah said: "O son of my brother, when I narrate a Hadith of the Messenger of Allah to you, then do not try to make examples for it}}
\hadithdefcmd{ibnmajah}{486}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{486}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'Perform ablution after (eating) that which has been changed by fire}}
\hadithdefcmd{ibnmajah}{487}{حَدَّثَنَا هِشَامُ بْنُ خَالِدٍ الأَزْرَقُ، حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ بْنِ أَبِي مَالِكٍ، عَنْ أَبِيهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ يَضَعُ يَدَيْهِ عَلَى أُذُنَيْهِ وَيَقُولُ صُمَّتَا إِنْ لَمْ أَكُنْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{487}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik would place his hands over his ears and say:"May my ears be made deaf, if I did not hear the messenger of Allah saying: 'Perform ablution after (eating) that which has been changed by fire}}
\hadithdefcmd{ibnmajah}{488}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَكَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ كَتِفًا ثُمَّ مَسَحَ يَدَيْهِ بِمِسْحٍ كَانَ تَحْتَهُ ثُمَّ قَامَ إِلَى الصَّلاَةِ فَصَلَّى ‏.‏\hadithno{488}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah ate a shoulder, then he wiped his hands on a Mish that was underneath him, then he got up for prayer, and performed the prayer}}
\hadithdefcmd{ibnmajah}{489}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَعَمْرِو بْنِ دِينَارٍ، وَعَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَكَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَبُو بَكْرٍ وَعُمَرُ خُبْزًا وَلَحْمًا وَلَمْ يَتَوَضَّئُوا ‏.‏\hadithno{489}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Prophet, Abu Bakr and 'Umar ate some bread and meat, and they did not perform ablution (after that)}}
\hadithdefcmd{ibnmajah}{490}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا الزُّهْرِيُّ، قَالَ حَضَرْتُ عَشَاءَ الْوَلِيدِ - أَوْ عَبْدِ الْمَلِكِ - فَلَمَّا حَضَرَتِ الصَّلاَةُ قُمْتُ لأَتَوَضَّأَ فَقَالَ جَعْفَرُ بْنُ عَمْرِو بْنِ أُمَيَّةَ أَشْهَدُ عَلَى أَبِي أَنَّهُ شَهِدَ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ أَكَلَ طَعَامًا مِمَّا غَيَّرَتِ النَّارُ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏ وَقَالَ عَلِيُّ بْنُ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ وَأَنَا أَشْهَدُ، عَلَى أَبِي بِمِثْلِ ذَلِكَ ‏.‏\hadithno{490}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Zuhri said:"I had dinner with Walid or Abdul-Malik. When the time for prayer came, I got up to perform ablution. Ja'far bin 'Amr bin Umayyah said: 'I bear witness that my father bore witness, that the Messenger of Allah ate food that had been changed by fire, then he performed prayer, and he did not perform ablution.' (Sahih) And 'Ali bin 'Abdullah bin 'Abbas said: 'And I bear witness to similar from my father}}
\hadithdefcmd{ibnmajah}{491}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ أُتِيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِكَتِفِ شَاةٍ فَأَكَلَ مِنْهُ وَصَلَّى وَلَمْ يَمَسَّ مَاءً ‏.‏\hadithno{491}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Umm Salamah said:"Some meat from the shoulder of a sheep was brought to the Messenger of Allah and he ate some of it, then he performed prayer without touching water (for ablution)}}
\hadithdefcmd{ibnmajah}{492}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، أَنْبَأَنَا سُوَيْدُ بْنُ النُّعْمَانِ الأَنْصَارِيُّ، أَنَّهُمْ خَرَجُوا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى خَيْبَرَ حَتَّى إِذَا كَانُوا بِالصَّهْبَاءِ صَلَّى الْعَصْرَ ثُمَّ دَعَا بِأَطْعِمَةٍ فَلَمْ يُؤْتَ إِلاَّ بِسَوِيقٍ فَأَكَلُوا وَشَرِبُوا ثُمَّ دَعَا بِمَاءٍ فَمَضْمَضَ فَاهُ ثُمَّ قَامَ فَصَلَّى بِنَا الْمَغْرِبَ ‏.‏\hadithno{492}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Suwaid bin Nu'man Ansari narrated that :They went out with the Messenger of Allah to Khaibar. When they reached As-Sahba' (a place near Khaibar), he performed 'Asr (Afternoon prayer), then he called for food, but no food was brought except for Sawiq. So they ate that and drank, and then he called for water and rinsed his mouth, then he stood up and led us for Maghrib (Sunset) prayer}}
\hadithdefcmd{ibnmajah}{493}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَكَلَ كَتِفَ شَاةٍ فَمَضْمَضَ وَغَسَلَ يَدَيْهِ وَصَلَّى ‏.‏\hadithno{493}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah ate meat from the shoulder of a sheep, then he rinsed his mouth and washed his hands, then he prayed}}
\hadithdefcmd{ibnmajah}{494}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَأَبُو مُعَاوِيَةَ قَالاَ حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْوُضُوءِ مِنْ لُحُومِ الإِبِلِ فَقَالَ ‏ "‏ تَوَضَّئُوا مِنْهَا ‏"‏ ‏.‏\hadithno{494}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Bara'bin 'Azib said:"The Messenger of Allah was asked about performing ablution after eating camel meat. He said: 'Perform ablution after eating it}}
\hadithdefcmd{ibnmajah}{495}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا زَائِدَةُ، وَإِسْرَائِيلُ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ جَعْفَرِ بْنِ أَبِي ثَوْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَتَوَضَّأَ مِنْ لُحُومِ الإِبِلِ وَلاَ نَتَوَضَّأَ مِنْ لُحُومِ الْغَنَمِ ‏.‏\hadithno{495}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"The Messenger of Allah commanded us to perform ablution after eating camel meat but not to perform ablution after eating the mutton}}
\hadithdefcmd{ibnmajah}{496}{حَدَّثَنَا أَبُو إِسْحَاقَ الْهَرَوِيُّ، إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حَاتِمٍ حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ حَجَّاجٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، مَوْلَى بَنِي هَاشِمٍ - وَكَانَ ثِقَةً وَكَانَ الْحَكَمُ يَأْخُذُ عَنْهُ - حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى عَنْ أُسَيْدِ بْنِ حُضَيْرٍ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَوَضَّئُوا مِنْ أَلْبَانِ الْغَنَمِ وَتَوَضَّئُوا مِنْ أَلْبَانِ الإِبِلِ ‏"‏ ‏.‏\hadithno{496}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Usaid bin Hudair said:"The Messenger of Allah said: 'Do not perform ablution after (drinking) sheep's milk, but perform ablution after (drinking) camel's milk}}
\hadithdefcmd{ibnmajah}{497}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ رَبِّهِ، حَدَّثَنَا بَقِيَّةُ، عَنْ خَالِدِ بْنِ يَزِيدَ بْنِ عُمَرَ بْنِ هُبَيْرَةَ الْفَزَارِيِّ، عَنْ عَطَاءِ بْنِ السَّائِبِ، قَالَ سَمِعْتُ مُحَارِبَ بْنَ دِثَارٍ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ تَوَضَّئُوا مِنْ لُحُومِ الإِبِلِ وَلاَ تَوَضَّئُوا مِنْ لُحُومِ الْغَنَمِ وَتَوَضَّئُوا مِنْ أَلْبَانِ الإِبِلِ وَلاَ تَوَضَّئُوا مِنْ أَلْبَانِ الْغَنَمِ وَصَلُّوا فِي مَرَابِضِ الْغَنَمِ وَلاَ تُصَلُّوا فِي مَعَاطِنِ الإِبِلِ ‏"‏ ‏.‏\hadithno{497}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin 'Amr said:"I heard the Messenger of Allah say: 'Perform ablution after (eating) camel meat, but do not perform ablution after (eating) mutton. Perform ablution after (drinking) camel's milk, but do not perform ablution after (drinking) sheep's milk. Perform prayer in the sheep pens but not do in the camels' Ma'atin}}
\hadithdefcmd{ibnmajah}{498}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَضْمِضُوا مِنَ اللَّبَنِ فَإِنَّ لَهُ دَسَمًا ‏"‏ ‏.‏\hadithno{498}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that:The Prophet said: 'Rinse your mouths after drinking milk for there is some greasiness in it}}
\hadithdefcmd{ibnmajah}{499}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ مُوسَى بْنِ يَعْقُوبَ، حَدَّثَنِي أَبُو عُبَيْدَةَ بْنُ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا شَرِبْتُمُ اللَّبَنَ فَمَضْمِضُوا فَإِنَّ لَهُ دَسَمًا ‏"‏ ‏.‏\hadithno{499}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Umm Salamah, the wife of the Prophet, said:"The Messenger of Allah said: 'If you drink milk, then rinse your mouths, for there is some greasiness in it}}
\hadithdefcmd{ibnmajah}{500}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا عَبْدُ الْمُهَيْمِنِ بْنُ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَضْمِضُوا مِنَ اللَّبَنِ فَإِنَّ لَهُ دَسَمًا ‏"‏ ‏.‏\hadithno{500}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdul-Muhaimin bin 'Abbas bin Sahl bin Sa'd As-Sa'di narraed from his father, from his grandfather, that:The Messenger of Allah said: "Rinse your mouths after drinking milk, for it has some greasiness in it}}
\hadithdefcmd{ibnmajah}{501}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ السَّوَّاقُ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا زَمْعَةُ بْنُ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ حَلَبَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ شَاةً وَشَرِبَ مِنْ لَبَنِهَا ثُمَّ دَعَا بِمَاءٍ فَمَضْمَضَ فَاهُ وَقَالَ ‏ "‏ إِنَّ لَهُ دَسَمًا ‏"‏ ‏.‏\hadithno{501}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah milked a sheep and drank some of its milk, then he called for water and rinsed his mouth and said: 'It has some greasiness in it}}
\hadithdefcmd{ibnmajah}{502}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَبَّلَ بَعْضَ نِسَائِهِ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ وَلَمْ يَتَوَضَّأْ ‏.‏ قُلْتُ مَا هِيَ إِلاَّ أَنْتِ ‏.‏ فَضَحِكَتْ ‏.‏\hadithno{502}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Urwah bin Az-Subair narrated from 'Aishah, that:The Messenger of Allah kissed one of his women (i.e., wives), then he went to perform the prayer, and he did not perform ablution. I ('Urwah bin Zubair) said: "That was not anyone but you,' and she smiled}}
\hadithdefcmd{ibnmajah}{503}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حَجَّاجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ زَيْنَبَ السَّهْمِيَّةِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَتَوَضَّأُ ثُمَّ يُقَبِّلُ وَيُصَلِّي وَلاَ يَتَوَضَّأُ وَرُبَّمَا فَعَلَهُ بِي ‏.‏\hadithno{503}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah:"The Messenger of Allah would perform ablution, then he would kiss, then he would perform prayer without performing ablution again. And sometimes he did that with me}}
\hadithdefcmd{ibnmajah}{504}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، قَالَ سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْمَذْىِ فَقَالَ ‏ "‏ فِيهِ الْوُضُوءُ وَفِي الْمَنِيِّ الْغُسْلُ ‏"‏ ‏.‏\hadithno{504}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah was asked about prostatic fluid and he said: 'For that ablution (is necessary), and for semen, bath is necessary}}
\hadithdefcmd{ibnmajah}{505}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ، أَنَّهُ سَأَلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ عَنِ الرَّجُلِ يَدْنُو مِنِ امْرَأَتِهِ فَلاَ يُنْزِلُ قَالَ ‏ "‏ إِذَا وَجَدَ أَحَدُكُمْ ذَلِكَ فَلْيَنْضِحْ فَرْجَهُ - يَعْنِي لِيَغْسِلْهُ - وَيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{505}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Miqdad bin Aswad that:He asked the Prophet about a man who approached his wife, but did not ejaculate. He said: "If anyone of you finds that, he should sprinkle water over his private part (meaning he must wash it) and perform ablution}}
\hadithdefcmd{ibnmajah}{506}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، وَعَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدِ بْنِ السَّبَّاقِ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ حُنَيْفٍ، قَالَ كُنْتُ أَلْقَى مِنَ الْمَذْىِ شِدَّةً فَأُكْثِرُ مِنْهُ الاِغْتِسَالَ فَسَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ إِنَّمَا يُجْزِيكَ مِنْ ذَلِكَ الْوُضُوءُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ بِمَا يُصِيبُ ثَوْبِي قَالَ ‏"‏ إِنَّمَا يَكْفِيكَ كَفٌّ مِنْ مَاءٍ تَنْضِحُ بِهِ مِنْ ثَوْبِكَ حَيْثُ تَرَى أَنَّهُ أَصَابَ ‏"‏ ‏.‏\hadithno{506}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Sahl bin Hunaif said:"I used to suffer from a great deal of prostatic fluid, and I took many baths because of that. I asked the messenger of Allah about that, and he said: 'Ablution is sufficient for you in this case.' I said: 'O Messenger of Allah! What about the prostatic fluid that gets onto my clothes?' he said: 'it is sufficient for you to pour a handful of water on the part of your clothes wherever you see it has reached}}
\hadithdefcmd{ibnmajah}{507}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مِسْعَرٌ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ أَبِي حَبِيبِ بْنِ يَعْلَى بْنِ مُنْيَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ أَتَى أُبَىَّ بْنَ كَعْبٍ وَمَعَهُ عُمَرُ فَخَرَجَ عَلَيْهِمَا فَقَالَ إِنِّي وَجَدْتُ مَذْيًا فَغَسَلْتُ ذَكَرِي وَتَوَضَّأْتُ ‏.‏ فَقَالَ عُمَرُ أَوَ يُجْزِئُ ذَلِكَ قَالَ نَعَمْ ‏.‏ قَالَ أَسَمِعْتَهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ نَعَمْ ‏.‏\hadithno{507}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that:He came to Ubayy bin Ka'b accompanied by 'Umar. Ubayy came out to them and said: "I noticed some prostatic fluid, so I washed my penis and performed ablution. 'Umar said: "Is that sufficient?" He said: "Yes." He ('Umar) asked: "Did you hear that from the messenger of Allah?" He said: "Yes}}
\hadithdefcmd{ibnmajah}{508}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، سَمِعْتُ سُفْيَانَ، يَقُولُ لِزَائِدَةَ بْنِ قُدَامَةَ يَا أَبَا الصَّلْتِ هَلْ سَمِعْتَ فِي، هَذَا شَيْئًا فَقَالَ حَدَّثَنَا سَلَمَةُ بْنُ كُهَيْلٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَامَ مِنَ اللَّيْلِ فَدَخَلَ الْخَلاَءَ فَقَضَى حَاجَتَهُ ثُمَّ غَسَلَ وَجْهَهُ وَكَفَّيْهِ ثُمَّ نَامَ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا شُعْبَةُ، أَنْبَأَنَا سَلَمَةُ بْنُ كُهَيْلٍ، أَنْبَأَنَا بُكَيْرٌ، عَنْ كُرَيْبٍ، قَالَ فَلَقِيتُ كُرَيْبًا فَحَدَّثَنِي عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{508}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that:The Prophet got up during the night and went to the toilet and relieved himself, then he washed his face and hands, and went back to sleep. (Sahih) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{509}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا شَرِيكٌ، عَنْ عَمْرِو بْنِ عَامِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَتَوَضَّأُ لِكُلِّ صَلاَةٍ وَكُنَّا نَحْنُ نُصَلِّي الصَّلَوَاتِ كُلَّهَا بِوُضُوءٍ وَاحِدٍ ‏.‏\hadithno{509}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah used to perform ablution for every prayer, and we used to perform all of the prayers with one ablution}}
\hadithdefcmd{ibnmajah}{510}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَتَوَضَّأُ لِكُلِّ صَلاَةٍ فَلَمَّا كَانَ يَوْمُ فَتْحِ مَكَّةَ صَلَّى الصَّلَوَاتِ كُلَّهَا بِوُضُوءٍ وَاحِدٍ ‏.‏\hadithno{510}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sulaiman bin Buraidah narrated from his father that:The Prophet used to perform ablution for every prayer, but on the day of the conquest of Makkah, he performed all of the prayers with one ablution}}
\hadithdefcmd{ibnmajah}{511}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ تَوْبَةَ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْفَضْلُ بْنُ مُبَشِّرٍ، قَالَ رَأَيْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ يُصَلِّي الصَّلَوَاتِ بِوُضُوءٍ وَاحِدٍ ‏.‏ فَقُلْتُ مَا هَذَا فَقَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَصْنَعُ هَذَا فَأَنَا أَصْنَعُ كَمَا صَنَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{511}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Fadl bin Mubashshir said:"I saw Jabir bin 'Abdullah performing every prayer with one ablution, and I said: 'What is this?' He said: 'I saw the Messenger of Allah doing this, and I am doing as the Messenger of Allah did}}
\hadithdefcmd{ibnmajah}{512}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زِيَادٍ، عَنْ أَبِي غُطَيْفٍ الْهُذَلِيِّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ بْنِ الْخَطَّابِ، فِي مَجْلِسِهِ فِي الْمَسْجِدِ فَلَمَّا حَضَرَتِ الصَّلاَةُ قَامَ فَتَوَضَّأَ وَصَلَّى ثُمَّ عَادَ إِلَى مَجْلِسِهِ فَلَمَّا حَضَرَتِ الْعَصْرُ قَامَ فَتَوَضَّأَ وَصَلَّى ثُمَّ عَادَ إِلَى مَجْلِسِهِ فَلَمَّا حَضَرَتِ الْمَغْرِبُ قَامَ فَتَوَضَّأَ وَصَلَّى ثُمَّ عَادَ إِلَى مَجْلِسِهِ فَقُلْتُ أَصْلَحَكَ اللَّهُ أَفَرِيضَةٌ أَمْ سُنَّةٌ الْوُضُوءُ عِنْدَ كُلِّ صَلاَةٍ قَالَ أَوَ فَطِنْتَ إِلَىَّ وَإِلَى هَذَا مِنِّي فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ لاَ لَوْ تَوَضَّأْتُ لِصَلاَةِ الصُّبْحِ لَصَلَّيْتُ بِهِ الصَّلَوَاتِ كُلَّهَا مَا لَمْ أُحْدِثْ وَلَكِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ تَوَضَّأَ عَلَى كُلِّ طُهْرٍ فَلَهُ عَشْرُ حَسَنَاتٍ ‏"‏ ‏.‏ وَإِنَّمَا رَغِبْتُ فِي الْحَسَنَاتِ ‏.‏\hadithno{512}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Ghutaif Al-Hudhali said:"I was listening to 'Abdullah bin 'Umar bin Khattab in the mosque, and when the time for prayer came, he got up, performed ablution, and offered prayer, then he went back to where he had been sitting. When the time for 'Asr (Afternnon prayer) came, he got up, performed ablution, and offered prayer, then he went back to where he had been sitting. When the time for Maghrib (Sunset prayer) came, he got up, performed ablution, and offered prayer, then he went back to where he had been sitting. I said: 'May Allah improve you (i.e., your condition) Is it obligatory or Sunnah to perform ablution for every prayer?' He said: 'Did you notice that?' I said: 'Yes.' He said: 'No (it is not obligatory). If I perform ablution for Morning prayer I can perform all of the prayers with this ablution, so as long as I do not get impure. But I heard the Messenger of Allah say: "Whoever performs ablution while he is pure, he will have ten merits." So I wanted to earn the merits}}
\hadithdefcmd{ibnmajah}{513}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، قَالَ أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَعَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ شُكِيَ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ الرَّجُلُ يَجِدُ الشَّىْءَ فِي الصَّلاَةِ فَقَالَ ‏ "‏ لاَ حَتَّى يَجِدَ رِيحًا أَوْ يَسْمَعَ صَوْتًا ‏"‏ ‏.‏\hadithno{513}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abbad bin Tamim narrated that his paternal uncle said:"A complaint was made to the Prophet about a man who sensed something (some doubt about his ablution) during prayer. He said: 'No (he does not have to perform ablution) unless he notices a smell or hears a sound}}
\hadithdefcmd{ibnmajah}{514}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ مَعْمَرِ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، أَنْبَأَنَا سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سُئِلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَنِ التَّشَبُّهِ فِي الصَّلاَةِ فَقَالَ ‏ "‏ لاَ يَنْصَرِفْ حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏ ‏.‏\hadithno{514}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Prophet was asked about doubts (concerning ablution) during prayer. He said: 'he should not leave until he hears a sound or detects an odor}}
\hadithdefcmd{ibnmajah}{515}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ، قَالُوا حَدَّثَنَا شُعْبَةُ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ وُضُوءَ إِلاَّ مِنْ صَوْتٍ أَوْ رِيحٍ ‏"‏ ‏.‏\hadithno{515}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'No ablution (is needed) unless there is an odor or a sound}}
\hadithdefcmd{ibnmajah}{516}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُبَيْدِ اللَّهِ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، قَالَ رَأَيْتُ السَّائِبَ بْنَ يَزِيدَ يَشَمُّ ثَوْبَهُ فَقُلْتُ مِمَّ ذَلِكَ قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ وُضُوءَ إِلاَّ مِنْ رِيحٍ أَوْ سَمَاعٍ ‏"‏ ‏.‏\hadithno{516}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Amr bin 'Ata' said:"I saw Sa'ib bin Yazid sniffing his garment, and I said: 'Why (are you doing) that?' He said: 'I heard the Messenger of Allah say: "No ablution (is needed) unless there is an odor or a sound}}
\hadithdefcmd{ibnmajah}{517}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سُئِلَ عَنِ الْمَاءِ يَكُونُ بِالْفَلاَةِ مِنَ الأَرْضِ وَمَا يَنُوبُهُ مِنَ الدَّوَابِّ وَالسِّبَاعِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا بَلَغَ الْمَاءُ قُلَّتَيْنِ لَمْ يُنَجِّسْهُ شَىْءٌ ‏"‏ ‏.‏ حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{517}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah bin 'Umar that his father said:"I heard the Messenger of Allah being asked about water in the wilderness that is frequented by beasts and predators. The Messenger of Allah said: "If the water reaches the amount of two Qullah, nothing can make it impure (Najis).'" (Sahih) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{518}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَاصِمِ بْنِ الْمُنْذِرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا كَانَ الْمَاءُ قُلَّتَيْنِ أَوْ ثَلاَثًا لَمْ يُنَجِّسْهُ شَىْءٌ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا أَبُو الْوَلِيدِ، وَأَبُو سَلَمَةَ وَابْنُ عَائِشَةَ الْقُرَشِيُّ قَالُوا حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{518}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah bin 'Umar that his father said:"The Messenger of Allah said: 'If the water is the amount of two or three Qullah, nothing can make it impure (Najis).'" (Sahih) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{519}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدَنِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ سُئِلَ عَنِ الْحِيَاضِ الَّتِي بَيْنَ مَكَّةَ وَالْمَدِينَةِ تَرِدُهَا السِّبَاعُ وَالْكِلاَبُ وَالْحُمُرُ وَعَنِ الطَّهَارَةِ مِنْهَا فَقَالَ ‏ "‏ لَهَا مَا حَمَلَتْ فِي بُطُونِهَا وَلَنَا مَا غَبَرَ طَهُورٌ ‏"‏ ‏.‏\hadithno{519}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:The Prophet was asked about the water basins located between Makkah and Al-Madinah, which were visited by wild animals, dogs and donkeys, and about using them for means of purification. He said: "Whatever they (the animals) have carried in their bellies is for them, and whatever is left over is for us, and is pure}}
\hadithdefcmd{ibnmajah}{520}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا شَرِيكٌ، عَنْ طَرِيفِ بْنِ شِهَابٍ، قَالَ سَمِعْتُ أَبَا نَضْرَةَ، يُحَدِّثُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ انْتَهَيْنَا إِلَى غَدِيرٍ فَإِذَا فِيهِ جِيفَةُ حِمَارٍ ‏.‏ قَالَ فَكَفَفْنَا عَنْهُ حَتَّى انْتَهَى إِلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ إِنَّ الْمَاءَ لاَ يُنَجِّسُهُ شَىْءٌ ‏"‏ ‏.‏ فَاسْتَقَيْنَا وَأَرْوَيْنَا وَحَمَلْنَا ‏.‏\hadithno{520}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"We came to a pond in which there was the carcass of a donkey, so we refrained from using the water until the Messenger of Allah came to us and said: 'Water is not made impure by anything.' Then we drank from it and gave it to our animals to drink, and we carried some with us}}
\hadithdefcmd{ibnmajah}{521}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، وَالْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيَّانِ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا رِشْدِينُ، أَنْبَأَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ الْمَاءَ لاَ يُنَجِّسُهُ شَىْءٌ إِلاَّ مَا غَلَبَ عَلَى رِيحِهِ وَطَعْمِهِ وَلَوْنِهِ ‏"‏ ‏.‏\hadithno{521}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah Al-Bahili said:"The Messenger of Allah said: 'Water is not made impure by anything except that which changes its smell, taste and color}}
\hadithdefcmd{ibnmajah}{522}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ قَابُوسَ بْنِ أَبِي الْمُخَارِقِ، عَنْ لُبَابَةَ بِنْتِ الْحَارِثِ، قَالَتْ بَالَ الْحُسَيْنُ بْنُ عَلِيٍّ فِي حِجْرِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ أَعْطِنِي ثَوْبَكَ وَالْبَسْ ثَوْبًا غَيْرَهُ فَقَالَ ‏ "‏ إِنَّمَا يُنْضَحُ مِنْ بَوْلِ الذَّكَرِ وَيُغْسَلُ مِنْ بَوْلِ الأُنْثَى ‏"‏ ‏.‏\hadithno{522}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Lubabah bint Harith said:"Husain bin 'Ali urinated in the lap of the Prophet and I said: 'O Messenger of Allah, give me your garment and put on another garment.' He said: 'Water should be sprinkled on the urine of a baby boy, and the urine of a baby girl should be washed away}}
\hadithdefcmd{ibnmajah}{523}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أُتِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِصَبِيٍّ فَبَالَ عَلَيْهِ فَأَتْبَعَهُ الْمَاءَ وَلَمْ يَغْسِلْهُ ‏.‏\hadithno{523}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"A baby boy was brought to the Prophet who then urinated on him. He sprinkled over it with water and did not wash it}}
\hadithdefcmd{ibnmajah}{524}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، قَالَتْ دَخَلْتُ بِابْنٍ لِي عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لَمْ يَأْكُلِ الطَّعَامَ فَبَالَ عَلَيْهِ فَدَعَا بِمَاءٍ فَرَشَّ عَلَيْهِ ‏.‏\hadithno{524}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Umm Qais bint Mihsan said:"I came to the Messenger of Allah with a son of mine who was not yet eating solid food, and he (the baby) urinated on him. He called for water and sprinkled it over (the urine)}}
\hadithdefcmd{ibnmajah}{525}{حَدَّثَنَا حَوْثَرَةُ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ سَعِيدِ بْنِ يَزِيدَ بْنِ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، أَنْبَأَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي حَرْبِ بْنِ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ فِي بَوْلِ الرَّضِيعِ ‏"‏ يُنْضَحُ بَوْلُ الْغُلاَمِ وَيُغْسَلُ بَوْلُ الْجَارِيَةِ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَا أَحْمَدُ بْنُ مُوسَى بْنِ مَعْقِلٍ، حَدَّثَنَا أَبُو الْيَمَانِ الْمِصْرِيُّ، قَالَ سَأَلْتُ الشَّافِعِيَّ عَنْ حَدِيثِ النَّبِيِّ، ـ صلى الله عليه وسلم ـ ‏"‏ يُرَشُّ مِنْ بَوْلِ الْغُلاَمِ وَيُغْسَلُ مِنْ بَوْلِ الْجَارِيَةِ ‏"‏ ‏.‏ وَالْمَاءَانِ جَمِيعًا وَاحِدٌ قَالَ لأَنَّ بَوْلَ الْغُلاَمِ مِنَ الْمَاءِ وَالطِّينِ وَبَوْلَ الْجَارِيَةِ مِنَ اللَّحْمِ وَالدَّمِ ‏.‏ ثُمَّ قَالَ لِي فَهِمْتَ أَوْ قَالَ لَقِنْتَ قَالَ قُلْتُ لاَ ‏.‏ قَالَ إِنَّ اللَّهَ تَعَالَى لَمَّا خَلَقَ آدَمَ خُلِقَتْ حَوَّاءُ مِنْ ضِلَعِهِ الْقَصِيرِ فَصَارَ بَوْلُ الْغُلاَمِ مِنَ الْمَاءِ وَالطِّينِ وَصَارَ بَوْلُ الْجَارِيَةِ مِنَ اللَّحْمِ وَالدَّمِ ‏.‏ قَالَ قَالَ لِي فَهِمْتَ قُلْتُ نَعَمْ ‏.‏ قَالَ لِي نَفَعَكَ اللَّهُ بِهِ ‏.‏\hadithno{525}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ali that :The Prophet said concerning the urine of a nursing infant: "Water should be sprinkled over the urine of a boy, and the urine of a girl should be washed." Abul-Hasan bin Salamah said: "Ahmad bin Musa bin Ma'qil narrated to us that Abul-Yaman Al-Misri said: 'I asked Shafi'i about the Hadith of the Prophet, "Water should be sprinkled over the urine of a baby boy, and the urine of a baby girl should be washed," when the two types of water (urine) are the same. He said, "This is because the urine of the boy is of water and clay, but the urine of the girl is of flesh and blood." Then he said to me: "Did you understand?" I said: "No." He said: "When Allah the Most High created Adam, He created Eve (Hawwa') from his short rib, so the boy's urine is from water and clay, and the girl's urine is from flesh and blood." Then he said to me: "Did you understand?" I said: "Yes." He said: "May Allah cause you benefit from this}}
\hadithdefcmd{ibnmajah}{526}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُجَاهِدُ بْنُ مُوسَى، وَالْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، قَالُوا حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا يَحْيَى بْنُ الْوَلِيدِ، حَدَّثَنَا مُحِلُّ بْنُ خَلِيفَةَ، أَخْبَرَنَا أَبُو السَّمْحِ، قَالَ كُنْتُ خَادِمَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَجِيءَ بِالْحَسَنِ أَوِ الْحُسَيْنِ فَبَالَ عَلَى صَدْرِهِ فَأَرَادُوا أَنْ يَغْسِلُوهُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ رُشَّهُ فَإِنَّهُ يُغْسَلُ بَوْلُ الْجَارِيَةِ وَيُرَشُّ عَلَى بَوْلِ الْغُلاَمِ ‏"‏ ‏.‏\hadithno{526}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Samh said:"I was a servant of the Prophet, and Hasan and Husain was brought to him and (the infant) urinated on his chest. They wanted to wash it, but the Messenger of Allah said: 'Sprinkle water on it, for the urine of a girl should be washed, but the urine of a boy should be sprinkled over with water}}
\hadithdefcmd{ibnmajah}{527}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أُمِّ كُرْزٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ بَوْلُ الْغُلاَمِ يُنْضَحُ وَبَوْلُ الْجَارِيَةِ يُغْسَلُ ‏"‏ ‏.‏\hadithno{527}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Umm Kurz that:The Messenger of Allah said: "The urine of a boy should be sprinkled over and the urine of a girl should be washed}}
\hadithdefcmd{ibnmajah}{528}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ أَعْرَابِيًّا، بَالَ فِي الْمَسْجِدِ فَوَثَبَ إِلَيْهِ بَعْضُ الْقَوْمِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُزْرِمُوهُ ‏"‏ ‏.‏ ثُمَّ دَعَا بِدَلْوٍ مِنْ مَاءٍ فَصَبَّ عَلَيْهِ ‏.‏\hadithno{528}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Anas bin Malik that:A Bedouin urinated in the mosque, and some of the people rushed at him. The Messenger of Allah said: "Do not interrupt him." Then he called for a bucket of water and poured it over (the urine)}}
\hadithdefcmd{ibnmajah}{529}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ دَخَلَ أَعْرَابِيٌّ الْمَسْجِدَ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ جَالِسٌ فَقَالَ اللَّهُمَّ اغْفِرْ لِي وَلِمُحَمَّدٍ وَلاَ تَغْفِرْ لأَحَدٍ مَعَنَا ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَالَ ‏"‏ لَقَدِ احْتَظَرْتَ وَاسِعًا ‏"‏ ‏.‏ ثُمَّ وَلَّى حَتَّى إِذَا كَانَ فِي نَاحِيَةِ الْمَسْجِدِ فَشَجَ يَبُولُ ‏.‏ فَقَالَ الأَعْرَابِيُّ بَعْدَ أَنْ فَقِهَ فَقَامَ إِلَىَّ بِأَبِي وَأُمِّي ‏.‏ فَلَمْ يُؤَنِّبْ وَلَمْ يَسُبَّ ‏.‏ فَقَالَ ‏"‏ إِنَّ هَذَا الْمَسْجِدَ لاَ يُبَالُ فِيهِ وَإِنَّمَا بُنِيَ لِذِكْرِ اللَّهِ وَلِلصَّلاَةِ ‏"‏ ‏.‏ ثُمَّ أَمَرَ بِسَجْلٍ مِنَ مَاءٍ فَأُفْرِغَ عَلَى بَوْلِهِ ‏.‏\hadithno{529}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"A Bedouin entered the mosque when the Messenger of Allah was sitting there, and (the man) said: 'O Allah, forgive me and Muhammed, and do not forgive anyone else with us.' The Messenger of Allah smiled and said: 'You have placed restrictions on something that is vast.' Then the Bedouin turned away, went to a corner of the mosque, spread his legs and began to urinate. After he had a better understanding, the Bedouin said: 'He got up and came to me, and may my father and mother be ransomed for him, he did not rebuke me nor revile me. He said: "This mosque is not for urinating in. Rather it is built for the remembrance of Allah and prayer.'" Then he called for a large vessel of water and poured it over the place where he had urinated}}
\hadithdefcmd{ibnmajah}{530}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ الْهُذَلِيِّ، - قَالَ مُحَمَّدُ بْنُ يَحْيَى وَهُوَ عِنْدَنَا ابْنُ أَبِي حُمَيْدٍ - أَنْبَأَنَا أَبُو الْمَلِيحِ الْهُذَلِيُّ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ اللَّهُمَّ ارْحَمْنِي وَمُحَمَّدًا وَلاَ تُشْرِكْ فِي رَحْمَتِكَ إِيَّانَا أَحَدًا ‏.‏ فَقَالَ ‏"‏ لَقَدْ حَظَرْتَ وَاسِعًا وَيْحَكَ - أَوْ وَيْلَكَ - ‏"‏ ‏.‏ قَالَ فَشَجَ يَبُولُ فَقَالَ أَصْحَابُ النَّبِيِّ ـ صلى الله عليه وسلم ـ مَهْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ دَعُوهُ ‏"‏ ‏.‏ ثُمَّ دَعَا بِسَجْلٍ مِنْ مَاءٍ فَصَبَّ عَلَيْهِ ‏.‏\hadithno{530}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Wathilah bin Asqa' said:"A Bedouin came to the Prophet and said: 'O Allah, have mercy on me and Muhammed, and do not allow anyone else to share in your Mercy.' The Prophet said: 'You have placed restrictions on something that is vast, woe to you!' Then he (the Bedouin) spread his legs and urinated, and the Companions of the Prophet told him to stop, but the Messenger of Allah said: 'Let him be,' then he called for a vessel of water and poured it over (the urine)}}
\hadithdefcmd{ibnmajah}{531}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُمَارَةَ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ أُمِّ وَلَدٍ، لإِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهَا سَأَلَتْ أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ إِنِّي امْرَأَةٌ أُطِيلُ ذَيْلِي فَأَمْشِي فِي الْمَكَانِ الْقَذِرِ فَقَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُطَهِّرُهُ مَا بَعْدَهُ ‏"‏ ‏.‏\hadithno{531}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Salamah, the wife of the Prophet, said:"I am a woman whose hem is lengthy, and I may walk through a dirty place. The Messenger of Allah said: 'That which comes after it purifies it}}
\hadithdefcmd{ibnmajah}{532}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ الْيَشْكُرِيُّ، عَنِ ابْنِ أَبِي حَبِيبَةَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي سُفْيَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ إِنَّا نُرِيدُ الْمَسْجِدَ فَنَطَأُ الطَّرِيقَ النَّجِسَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الأَرْضُ يُطَهِّرُ بَعْضُهَا بَعْضًا ‏"‏ ‏.‏\hadithno{532}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:It was said: "O Messenger of Allah, we want to come to the mosque, but the path that we walk upon is impure." The Messenger of Allah said: "Some parts of the earth purify others}}
\hadithdefcmd{ibnmajah}{533}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ مُوسَى بْنِ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنِ امْرَأَةٍ، مِنْ بَنِي عَبْدِ الأَشْهَلِ قَالَتْ سَأَلْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ إِنَّ بَيْنِي وَبَيْنَ الْمَسْجِدِ طَرِيقًا قَذِرَةً ‏.‏ قَالَ ‏"‏ فَبَعْدَهَا طَرِيقٌ أَنْظَفُ مِنْهَا ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَهَذِهِ بِهَذِهِ ‏"‏ ‏.‏\hadithno{533}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that a woman from (the tribe of) Banu 'Abdul-Ashhal said:"I said to the prophet: 'Between the mosque and I there is a filthy path.' He said: 'After that is there a cleaner path?' I said: 'Yes.' He said: 'This is (a remedy) for that}}
\hadithdefcmd{ibnmajah}{534}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ حُمَيْدٍ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ لَقِيَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ فِي طَرِيقٍ مِنْ طُرُقِ الْمَدِينَةِ وَهُوَ جُنُبٌ فَانْسَلَّ فَفَقَدَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَلَمَّا جَاءَ قَالَ ‏"‏ أَيْنَ كُنْتَ يَا أَبَا هُرَيْرَةَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ لَقِيتَنِي وَأَنَا جُنُبٌ فَكَرِهْتُ أَنْ أُجَالِسَكَ حَتَّى أَغْتَسِلَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ الْمُؤْمِنُ لاَ يَنْجُسُ ‏"‏ ‏.‏\hadithno{534}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Rafi' that :Abu Hurairah was met by the Prophet in one of the streets of Al-Madinah when he was in a state of sexual impurity, so he slipped away. The Prophet missed him, so when he came (later on), he said: 'Where were you O Abu Hurairah?' He said: 'O Messenger of Allah, you met me when I was in a state of sexual impurity, and I did not want to sit with you until I had a bath. The Messenger of Allah said: 'The believer does not become impure}}
\hadithdefcmd{ibnmajah}{535}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، جَمِيعًا عَنْ مِسْعَرٍ، عَنْ وَاصِلٍ الأَحْدَبِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ خَرَجَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَلَقِيَنِي وَأَنَا جُنُبٌ فَحِدْتُ عَنْهُ فَاغْتَسَلْتُ ثُمَّ جِئْتُ فَقَالَ ‏"‏ مَا لَكَ ‏"‏ ‏.‏ قُلْتُ كُنْتُ جُنُبًا ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ الْمُسْلِمَ لاَ يَنْجُسُ ‏"‏ ‏.‏\hadithno{535}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Hudhaifah said:"The Prophet came out and met me when I was sexually impure, so I kept away from him. Then I had a bath and came to him. He said: 'What is the matter with you?' I said: 'I was sexually impure.' The Messenger of Allah said: 'The Muslim does not become impure}}
\hadithdefcmd{ibnmajah}{536}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ سَأَلْتُ سُلَيْمَانَ بْنَ يَسَارٍ عَنِ الثَّوْبِ، يُصِيبُهُ الْمَنِيُّ أَنَغْسِلُهُ أَوْ نَغْسِلُ الثَّوْبَ كُلَّهُ قَالَ سُلَيْمَانُ قَالَتْ عَائِشَةُ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصِيبُ ثَوْبَهُ فَيَغْسِلُهُ مِنْ ثَوْبِهِ ثُمَّ يَخْرُجُ فِي ثَوْبِهِ إِلَى الصَّلاَةِ وَأَنَا أَرَى أَثَرَ الْغُسْلِ فِيهِ ‏.‏\hadithno{536}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Amr bin Maimun said:"I asked Sulaiman bin Yasar about a garment which gets semen on it. 'Should I wash it off or wash the entire garment?' Sulaiman said: 'Aishah said: "Semen used to get on the garment of the Messenger of Allah and he would wash it off his garment, then he would go out to pray wearing that garment, and I could see the marks left on it by washing}}
\hadithdefcmd{ibnmajah}{537}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، جَمِيعًا عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، عَنْ عَائِشَةَ، قَالَتْ رُبَّمَا فَرَكْتُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِيَدِي ‏.‏\hadithno{537}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I often scraped it (semen) from the garment of the Messenger of Allah with my hand}}
\hadithdefcmd{ibnmajah}{538}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، قَالَ نَزَلَ بِعَائِشَةَ ضَيْفٌ فَأَمَرَتْ لَهُ بِمِلْحَفَةٍ لَهَا صَفْرَاءَ فَاحْتَلَمَ فِيهَا فَاسْتَحْيَى أَنْ يُرْسِلَ بِهَا وَفِيهَا أَثَرُ الاِحْتِلاَمِ فَغَمَسَهَا فِي الْمَاءِ ثُمَّ أَرْسَلَ بِهَا فَقَالَتْ عَائِشَةُ لِمَ أَفْسَدْتَ عَلَيْنَا ثَوْبَنَا إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَفْرُكَهُ بِإِصْبَعِكَ رُبَّمَا فَرَكْتُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِإِصْبَعِي ‏.‏\hadithno{538}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hammam bin Harith narrated:"A guest came and stayed with 'Aishah, and she ordered that he be given a yellow blanket of hers. He had a nocturnal emission on it, and he felt too shy to send it back to send it back to her when it had the traces of that emission on it, so he dipped it in water and then sent it to her. 'Aishah said: 'Why did he spoil our garment? It would have been sufficient for him to scrape it off with his finger. I often scraped it (semen) from the garment of the Messenger of Allah with my finger}}
\hadithdefcmd{ibnmajah}{539}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي أَجِدُهُ فِي ثَوْبِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَحُتُّهُ عَنْهُ ‏.‏\hadithno{539}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I remember when I found it (semen) on the garment of the Messenger of Allah and I scratched it off}}
\hadithdefcmd{ibnmajah}{540}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، عَنْ مُعَاوِيَةَ بْنِ حُدَيْجٍ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، أَنَّهُ سَأَلَ أُخْتَهُ أُمَّ حَبِيبَةَ زَوْجَ النَّبِيِّ ـ صلى الله عليه وسلم ـ هَلْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي فِي الثَّوْبِ الَّذِي يُجَامِعُ فِيهِ قَالَتْ نَعَمْ إِذَا لَمْ يَكُنْ فِيهِ أَذًى ‏.‏\hadithno{540}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Mu'awiyah bin Abu Sufyan that:He asked his sister Umm Habibah, the wife of the Prophet: "Did the Messenger of Allah ever offered prayer in a garment in which he had sexual intercourse?" She said: "Yes, if there was nothing noxious on it}}
\hadithdefcmd{ibnmajah}{541}{حَدَّثَنَا هِشَامُ بْنُ خَالِدٍ الأَزْرَقُ، حَدَّثَنَا الْحَسَنُ بْنُ يَحْيَى الْخُشَنِيُّ، حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَرَأْسُهُ يَقْطُرُ مَاءً فَصَلَّى بِنَا فِي ثَوْبٍ وَاحِدٍ مُتَوَشِّحًا بِهِ قَدْ خَالَفَ بَيْنَ طَرَفَيْهِ فَلَمَّا انْصَرَفَ قَالَ عُمَرُ بْنُ الْخَطَّابِ يَا رَسُولَ اللَّهِ تُصَلِّي بِنَا فِي ثَوْبٍ وَاحِدٍ قَالَ ‏ "‏ نَعَمْ أُصَلِّي فِيهِ وَفِيهِ ‏"‏ ‏.‏ أَىْ قَدْ جَامَعْتُ فِيهِ ‏.‏\hadithno{541}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Darda' said:"The Messenger of Allah came out to us with water dripping from his head, and he led us in prayer wearing a single garment, placing its one end on the right shoulder, and the other end on the other shoulder. When he finished praying, 'Umar bin Khattab said to him: 'O Messenger of Allah, did you lead us in prayer wearing a single garment? He said: 'Yes, I perform prayer in it, and in it I (i.e. I had sexual intercourse in it)}}
\hadithdefcmd{ibnmajah}{542}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَحْيَى بْنُ يُوسُفَ الزِّمِّيُّ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ عُبَيْدِ اللَّهِ الرَّقِّيُّ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ سَأَلَ رَجُلٌ النَّبِيَّ ـ صلى الله عليه وسلم ـ يُصَلِّي فِي الثَّوْبِ الَّذِي يَأْتِي فِيهِ أَهْلَهُ قَالَ ‏ "‏ نَعَمْ إِلاَّ أَنْ يَرَى فِيهِ شَيْئًا فَيَغْسِلَهُ ‏"‏ ‏.‏\hadithno{542}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin Samurah said:"A man asked the Prophet whether he could perform prayer in a garment in which he had intercourse with his wife. He said: 'Yes, unless he sees something on it, in which case he should wash it}}
\hadithdefcmd{ibnmajah}{543}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، قَالَ بَالَ جَرِيرُ بْنُ عَبْدِ اللَّهِ ثُمَّ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ فَقِيلَ لَهُ أَتَفْعَلُ هَذَا قَالَ وَمَا يَمْنَعُنِي وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَفْعَلُهُ ‏.‏ قَالَ إِبْرَاهِيمُ كَانَ يُعْجِبُهُمْ حَدِيثُ جَرِيرٍ لأَنَّ إِسْلاَمَهُ كَانَ بَعْدَ نُزُولِ الْمَائِدَةِ ‏.‏\hadithno{543}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Hammam bin Harith said:"Jarir bin 'Abdullah urinated, then he performed ablution and wiped over his leather socks. Someone asked him: 'Do you do this?' He said: 'Why shouldn't I? I saw the Messenger of Allah doing this.'" Ibrahim (who narrated it from Hammam) said: "They were pleased by the Hadith of Jarir because he accepted Islam after the revelation of Ma'idah}}
\hadithdefcmd{ibnmajah}{544}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو هَمَّامٍ الْوَلِيدُ بْنُ شُجَاعِ بْنِ الْوَلِيدِ، حَدَّثَنَا أَبِي وَابْنُ، عُيَيْنَةَ وَابْنُ أَبِي زَائِدَةَ جَمِيعًا عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ ‏.‏\hadithno{544}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hudhaifah that:The Messenger of Allah performed ablution and wiped over his leather socks}}
\hadithdefcmd{ibnmajah}{545}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أَبِيهِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ خَرَجَ لِحَاجَتِهِ فَاتَّبَعَهُ الْمُغِيرَةُ بِإِدَاوَةٍ فِيهَا مَاءٌ حَتَّى فَرَغَ مِنْ حَاجَتِهِ فَتَوَضَّأَ وَمَسَحَ عَلَى الْخُفَّيْنِ ‏.‏\hadithno{545}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Urwah bin Mughirah bin Shu'bah from his father Mughirah bin Shu'bah, that:The Messenger of Allah went out to relieve himself, and Mughirah followed him with a vessel of water. When he finished relieving himself, he performed ablution and wiped over his leather socks}}
\hadithdefcmd{ibnmajah}{546}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ رَأَى سَعْدَ بْنَ مَالِكٍ وَهُوَ يَمْسَحُ عَلَى الْخُفَّيْنِ فَقَالَ إِنَّكُمْ لَتَفْعَلُونَ ذَلِكَ فَاجْتَمَعْنَا عِنْدَ عُمَرَ فَقَالَ سَعْدٌ لِعُمَرَ أَفْتِ ابْنَ أَخِي فِي الْمَسْحِ عَلَى الْخُفَّيْنِ ‏.‏ فَقَالَ عُمَرُ كُنَّا وَنَحْنُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ نَمْسَحُ عَلَى خِفَافِنَا لَمْ نَرَ بِذَلِكَ بَأْسًا ‏.‏ فَقَالَ ابْنُ عُمَرَ وَإِنْ جَاءَ مِنَ الْغَائِطِ قَالَ نَعَمْ ‏.‏\hadithno{546}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:He saw Sa'd bin Malik wiping over his leather socks and said: "Is it you doing this?" They both went to 'Umar and Sa'd said to 'Umar: "Give my brother's son a verdict regarding wiping over leather socks." 'Umar said: "We used to wipe over our leather socks when we were with the Messenger of Allah and we do not see anything wrong with that." Ibn 'Umar said: "Even if that is after one has defecated?" He said: "Yes}}
\hadithdefcmd{ibnmajah}{547}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدَنِيُّ، حَدَّثَنَا عَبْدُ الْمُهَيْمِنِ بْنُ الْعَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَسَحَ عَلَى الْخُفَّيْنِ وَأَمَرَنَا بِالْمَسْحِ عَلَى الْخُفَّيْنِ ‏.‏\hadithno{547}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdul-Muhaimin bin 'Abbas bin Sahl As-Sa'idi narrated from his father, from his grandfather:"The Messenger of Allah wiped over his leather socks and he ordered us to wipe over the leather socks}}
\hadithdefcmd{ibnmajah}{548}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، حَدَّثَنَا عُمَرُ بْنُ الْمُثَنَّى، عَنْ عَطَاءٍ الْخُرَاسَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ فَقَالَ ‏ "‏ هَلْ مِنْ مَاءٍ ‏"‏ ‏.‏ فَتَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ ثُمَّ لَحِقَ بِالْجَيْشِ فَأَمَّهُمْ ‏.‏\hadithno{548}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"I was with the Messenger of Allah on a journey, and he said: 'Is there any water?' He performed ablution and wiped over his leather socks, then he joined the army and led them (in prayer)}}
\hadithdefcmd{ibnmajah}{549}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا دَلْهَمُ بْنُ صَالِحٍ الْكِنْدِيُّ، عَنْ حُجَيْرِ بْنِ عَبْدِ اللَّهِ الْكِنْدِيِّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّجَاشِيَّ، أَهْدَى لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ خُفَّيْنِ أَسْوَدَيْنِ سَاذَجَيْنِ فَلَبِسَهُمَا ثُمَّ تَوَضَّأَ وَمَسَحَ عَلَيْهِمَا ‏.‏\hadithno{549}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Buraidah from his father that:An-Najashi gave the Prophet a gift of a pair of plain black leather socks. He put them on, then he (performed ablution and) wiped over them}}
\hadithdefcmd{ibnmajah}{550}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، عَنْ رَجَاءِ بْنِ حَيْوَةَ، عَنْ وَرَّادٍ، كَاتِبِ الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَسَحَ أَعْلَى الْخُفِّ وَأَسْفَلَهُ ‏.‏\hadithno{550}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mughirah bin Shu'bah that:The Messenger of Allah wiped over the top and the bottom of the leather socks}}
\hadithdefcmd{ibnmajah}{551}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ جَرِيرِ بْنِ يَزِيدَ، قَالَ حَدَّثَنِي مُنْذِرٌ، حَدَّثَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ مَرَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِرَجُلٍ يَتَوَضَّأُ وَيَغْسِلُ خُفَّيْهِ فَقَالَ بِيَدِهِ كَأَنَّهُ دَفَعَهُ ‏ "‏ إِنَّمَا أُمِرْتَ بِالْمَسْحِ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِيَدِهِ هَكَذَا مِنْ أَطْرَافِ الأَصَابِعِ إِلَى أَصْلِ السَّاقِ وَخَطَّطَ بِالأَصَابِعِ ‏.‏\hadithno{551}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah passed by a man who was performing ablution and washing his leather socks. He gestures with his hand, (and said): 'Rather I have been commanded to wipe them.' The Messenger of Allah gestured with his hand like this, from the tips of the toes to the base of the shin, tracing lines with his fingers}}
\hadithdefcmd{ibnmajah}{552}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ الْقَاسِمَ بْنَ مُخَيْمِرَةَ، عَنْ شُرَيْحِ بْنِ هَانِئٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنِ الْمَسْحِ، عَلَى الْخُفَّيْنِ فَقَالَتِ ائْتِ عَلِيًّا فَسَلْهُ فَإِنَّهُ أَعْلَمُ بِذَلِكَ مِنِّي ‏.‏ فَأَتَيْتُ عَلِيًّا فَسَأَلْتُهُ عَنِ الْمَسْحِ فَقَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْمُرُنَا أَنْ نَمْسَحَ لِلْمُقِيمِ يَوْمًا وَلَيْلَةً وَلِلْمُسَافِرِ ثَلاَثَةَ أَيَّامٍ ‏.‏\hadithno{552}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Shuraih bin Hani' said:"I asked 'Aishah about wiping over the leather socks and she said: 'Go to 'Ali and ask him, for he knows more about that than I do.' So I went to 'Ali and asked him about wiping. He said: 'The Messenger of Allah used to tell us that the resident could wipe for one day and one night, and the traveler could do so for three days}}
\hadithdefcmd{ibnmajah}{553}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِيهِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ، قَالَ جَعَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِلْمُسَافِرِ ثَلاَثًا وَلَوْ مَضَى السَّائِلُ عَلَى مَسْأَلَتِهِ لَجَعَلَهَا خَمْسًا ‏.‏\hadithno{553}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Khuzaimah bin Thabit said:"The Messenger of Allah set a time limit for the traveler of three days, and if the questioner had persisted in asking, he would have made it five (days)}}
\hadithdefcmd{ibnmajah}{554}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ سَمِعْتُ إِبْرَاهِيمَ التَّيْمِيَّ، يُحَدِّثُ عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ خُزَيْمَةَ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ ثَلاَثَةُ أَيَّامٍ - أَحْسِبُهُ قَالَ - وَلَيَالِيهِنَّ لِلْمُسَافِرِ فِي الْمَسْحِ عَلَى الْخُفَّيْنِ ‏"‏ ‏.‏\hadithno{554}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Khuzaimah bin Thabit that:The Prophet said: "Three days." I think he said, "And three nights during which the traveler may wipe over his leather socks}}
\hadithdefcmd{ibnmajah}{555}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنَا عُمَرُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي خَثْعَمٍ الثُّمَالِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ مَا الطُّهُورُ عَلَى الْخُفَّيْنِ قَالَ ‏ "‏ لِلْمُسَافِرِ ثَلاَثَةُ أَيَّامٍ وَلَيَالِيهِنَّ وَلِلْمُقِيمِ يَوْمٌ وَلَيْلَةٌ ‏"‏ ‏.‏\hadithno{555}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"They said: 'O Messenger of Allah! What about the purification of the leather socks?' He said: 'For the traveler it is three days and nights, and for the resident it is one day and one night}}
\hadithdefcmd{ibnmajah}{556}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَبِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، قَالَ حَدَّثَنَا الْمُهَاجِرُ أَبُو مَخْلَدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ رَخَّصَ لِلْمُسَافِرِ إِذَا تَوَضَّأَ وَلَبِسَ خُفَّيْهِ ثُمَّ أَحْدَثَ وُضُوءًا أَنْ يَمْسَحَ ثَلاَثَةَ أَيَّامٍ وَلَيَالِيَهُنَّ وَلِلْمُقِيمِ يَوْمًا وَلَيْلَةً ‏"‏ ‏.‏\hadithno{556}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman bin Abu Bakrah, from his father, that:The Prophet granted a concession to travelers: "If a traveler performed ablution and put on leather socks, then he performed a fresh ablution, he could wipe over the leather socks for three days and nights; the resident could do so for one day and one night}}
\hadithdefcmd{ibnmajah}{557}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، وَعَمْرُو بْنُ سَوَّادٍ الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَزِينٍ، عَنْ مُحَمَّدِ بْنِ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ أَيُّوبَ بْنِ قَطَنٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ أُبَىِّ بْنِ عِمَارَةَ، - وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَدْ صَلَّى فِي بَيْتِهِ الْقِبْلَتَيْنِ كِلْتَيْهِمَا - أَنَّهُ قَالَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَمْسَحُ عَلَى الْخُفَّيْنِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ يَوْمًا قَالَ ‏"‏ وَيَوْمَيْنِ ‏"‏ ‏.‏ قَالَ وَثَلاَثًا حَتَّى بَلَغَ سَبْعًا قَالَ لَهُ ‏"‏ وَمَا بَدَا لَكَ ‏"‏ ‏.‏\hadithno{557}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ubayy bin 'Imarah, in whose house the Messenger of Allah performed prayer facing both prayer direction, that :He said to the Messenger of Allah: "Can I wipe over my leather socks?" He said: "Yes." He said: "For one day?" He said: "For two days?" He said: "For three?" And so on, until the number reached seven. He (the Prophet) said: "For as long as you see fit}}
\hadithdefcmd{ibnmajah}{558}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنِ الْحَكَمِ بْنِ عَبْدِ اللَّهِ الْبَلَوِيِّ، عَنْ عَلِيِّ بْنِ رَبَاحٍ اللَّخْمِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، أَنَّهُ قَدِمَ عَلَى عُمَرَ بْنِ الْخَطَّابِ مِنْ مِصْرَ فَقَالَ مُنْذُ كَمْ لَمْ تَنْزِعْ خُفَّيْكَ قَالَ مِنَ الْجُمُعَةِ إِلَى الْجُمُعَةِ ‏.‏ قَالَ أَصَبْتَ السُّنَّةَ ‏.‏\hadithno{558}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Uqbah bin 'Amir Al-Juhani that:He came to 'Umar bin Khattab from Egypt. 'Umar said: "How long has it been since you have taken off your leather socks?" He said: "From one Friday to the next." He said: "You have acted in accordance with the Sunnah}}
\hadithdefcmd{ibnmajah}{559}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي قَيْسٍ الأَوْدِيِّ، عَنِ الْهُزَيْلِ بْنِ شُرَحْبِيلَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ وَمَسَحَ عَلَى الْجَوْرَبَيْنِ وَالنَّعْلَيْنِ ‏.‏\hadithno{559}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mughirah bin Shu'bah that:The Messenger of Allah performed ablution and wiped over his socks and his sandals}}
\hadithdefcmd{ibnmajah}{560}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، وَبِشْرُ بْنُ آدَمَ، قَالاَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عِيسَى بْنِ سِنَانٍ، عَنِ الضَّحَّاكِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَرْزَبٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ وَمَسَحَ عَلَى الْجَوْرَبَيْنِ وَالنَّعْلَيْنِ ‏.‏ قَالَ الْمُعَلَّى فِي حَدِيثِهِ لاَ أَعْلَمُهُ إِلاَّ قَالَ وَالنَّعْلَيْنِ ‏.‏\hadithno{560}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Musa Al-Ash'ari that:The Messenger of Allah performed ablution and wiped over his socks and his sandals}}
\hadithdefcmd{ibnmajah}{561}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنْ بِلاَلٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَسَحَ عَلَى الْخُفَّيْنِ وَالْخِمَارِ ‏.‏\hadithno{561}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Bilal that:The Messenger of Allah wiped over his leather socks and his head cover (i.e., over the Imamah)}}
\hadithdefcmd{ibnmajah}{562}{حَدَّثَنَا دُحَيْمٌ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ جَعْفَرِ بْنِ عَمْرٍو، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَمْسَحُ عَلَى الْخُفَّيْنِ وَالْعِمَامَةِ ‏.‏\hadithno{562}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ja'far bin 'Amr that his father said:"I saw the Messenger of Allah wiping over his leather socks and turban}}
\hadithdefcmd{ibnmajah}{563}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، عَنْ دَاوُدَ بْنِ أَبِي الْفُرَاتِ، عَنْ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ أَبِي شُرَيْحٍ، عَنْ أَبِي مُسْلِمٍ، مَوْلَى زَيْدِ بْنِ صُوحَانَ قَالَ كُنْتُ مَعَ سَلْمَانَ فَرَأَى رَجُلاً يَنْزِعُ خُفَّيْهِ لِلْوُضُوءِ فَقَالَ لَهُ سَلْمَانُ امْسَحْ عَلَى خُفَّيْكَ وَعَلَى خِمَارِكَ وَبِنَاصِيَتِكَ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَمْسَحُ عَلَى الْخُفَّيْنِ وَالْخِمَارِ ‏.‏\hadithno{563}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Muslim, the freed slave of Zaid bin Suhan, said:"I was with Salman, and he saw a man removing his leather socks for ablution. Salman said to him" 'Wipe over your leather socks and your head cover, and your forehead, for I saw the Messenger of Allah wiping over his leather socks and head cover}}
\hadithdefcmd{ibnmajah}{564}{حَدَّثَنَا أَبُو طَاهِرٍ، أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ مُسْلِمٍ، عَنْ أَبِي مَعْقِلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ وَعَلَيْهِ عِمَامَةٌ قِطْرِيَّةٌ فَأَدْخَلَ يَدَهُ مِنْ تَحْتِ الْعِمَامَةِ فَمَسَحَ مُقَدَّمَ رَأْسِهِ وَلَمْ يَنْقُضِ الْعِمَامَةَ ‏.‏\hadithno{564}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"I saw the Messenger of Allah performing ablution, wearing a Qatari turban. He put his hand beneath the turban and wiped the front part of his head, and he did not take the turban off}}
\hadithdefcmd{ibnmajah}{565}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّهُ قَالَ سَقَطَ عِقْدُ عَائِشَةَ فَتَخَلَّفَتْ لاِلْتِمَاسِهِ فَانْطَلَقَ أَبُو بَكْرٍ إِلَى عَائِشَةَ فَتَغَيَّظَ عَلَيْهَا فِي حَبْسِهَا النَّاسَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ الرُّخْصَةَ فِي التَّيَمُّمِ ‏.‏ قَالَ فَمَسَحْنَا يَوْمَئِذٍ إِلَى الْمَنَاكِبِ ‏.‏ قَالَ فَانْطَلَقَ أَبُو بَكْرٍ إِلَى عَائِشَةَ فَقَالَ مَا عَلِمْتُ إِنَّكِ لَمُبَارَكَةٌ ‏.‏\hadithno{565}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ammar bin Yasir said:"Aishah dropped a necklace and stayed behind to look for it. Abu Bakr went to 'Aishah and got angry with her for keeping the people waiting. Then Allah revealed the concession allowing dry ablution, so we wiped our arms up to the shoulders. Abu Bakr went to 'Aishah and said: 'I did not know that you are blessed}}
\hadithdefcmd{ibnmajah}{566}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، قَالَ تَيَمَّمْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى الْمَنَاكِبِ ‏.‏\hadithno{566}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ammar [bin Yasir] said:"We did dry ablution with the Messenger of Allah, (wiping our arms) up to our shoulders}}
\hadithdefcmd{ibnmajah}{567}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، ح وَحَدَّثَنَا أَبُو إِسْحَاقَ الْهَرَوِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، جَمِيعًا عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ جُعِلَتْ لِيَ الأَرْضُ مَسْجِدًا وَطَهُورًا ‏"‏ ‏.‏\hadithno{567}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "the earth has been made for me a place of worship and a means of purification}}
\hadithdefcmd{ibnmajah}{568}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا اسْتَعَارَتْ مِنْ أَسْمَاءَ قِلاَدَةً فَهَلَكَتْ فَأَرْسَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ أُنَاسًا فِي طَلَبِهَا فَأَدْرَكَتْهُمُ الصَّلاَةُ فَصَلَّوْا بِغَيْرِ وُضُوءٍ فَلَمَّا أَتَوُا النَّبِيَّ ـ صلى الله عليه وسلم ـ شَكَوْا ذَلِكَ إِلَيْهِ فَنَزَلَتْ آيَةُ التَّيَمُّمِ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ جَزَاكِ اللَّهُ خَيْرًا فَوَاللَّهِ مَا نَزَلَ بِكِ أَمْرٌ قَطُّ إِلاَّ جَعَلَ اللَّهُ لَكِ مِنْهُ مَخْرَجًا وَجَعَلَ لِلْمُسْلِمِينَ فِيهِ بَرَكَةً ‏.‏\hadithno{568}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Aishah that:She borrowed a necklace from Asma', and she lost it. The Prophet sent some people to look for it, and the time for prayer came so they prayed without ablution. When they came to the Prophet they complained to him about that, then the Verse of dry ablution was revealed. Usaid bin Hudair said: "May Allah reward you with good, for by Allah, nothing ever happens to you but Allah grants you a way out and blesses the Muslims thereby}}
\hadithdefcmd{ibnmajah}{569}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ ذَرٍّ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى عُمَرَ بْنَ الْخَطَّابِ فَقَالَ إِنِّي أَجْنَبْتُ فَلَمْ أَجِدِ الْمَاءَ ‏.‏ فَقَالَ عُمَرُ لاَ تُصَلِّ ‏.‏ فَقَالَ عَمَّارُ بْنُ يَاسِرٍ أَمَا تَذْكُرُ يَا أَمِيرَ الْمُؤْمِنِينَ إِذْ أَنَا وَأَنْتَ فِي سَرِيَّةٍ فَأَجْنَبْنَا فَلَمْ نَجِدِ الْمَاءَ فَأَمَّا أَنْتَ فَلَمْ تُصَلِّ وَأَمَّا أَنَا فَتَمَعَّكْتُ فِي التُّرَابِ فَصَلَّيْتُ فَلَمَّا أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَذَكَرْتُ ذَلِكَ لَهُ ‏.‏ فَقَالَ ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ ‏"‏ ‏.‏ وَضَرَبَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِيَدَيْهِ إِلَى الأَرْضِ ثُمَّ نَفَخَ فِيهِمَا وَمَسَحَ بِهِمَا وَجْهَهُ وَكَفَّيْهِ ‏.‏\hadithno{569}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Sa'eed bin 'Abdur-Rahman bin Abza from his father, that:A man came to 'Umar bin khattab and said: "I became impure following sexual emission and cannot find any water." 'Umar said to him: "Do not pray." But 'Ammar bin Yasir said: "Do you not remember, O Commander of the Believers, when you and I were on a military expedition and we became sexually impure and could not find water? As for you, you did not pray, but I rolled in the dust and then prayed. When I came to the Prophet and told him what had happened, he said: 'It would have been enough for you (to do this).' (Then demonstrating) the Prophet struck the ground with his hands, then blew on hem, and wiped his face and palms with them}}
\hadithdefcmd{ibnmajah}{570}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْحَكَمِ، وَسَلَمَةَ بْنِ كُهَيْلٍ، أَنَّهُمَا سَأَلاَ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى عَنِ التَّيَمُّمِ، فَقَالَ أَمَرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَمَّارًا أَنْ يَفْعَلَ هَكَذَا وَضَرَبَ بِيَدَيْهِ إِلَى الأَرْضِ ثُمَّ نَفَضَهُمَا وَمَسَحَ عَلَى وَجْهِهِ ‏.‏ قَالَ الْحَكَمُ وَيَدَيْهِ ‏.‏ وَقَالَ سَلَمَةُ وَمِرْفَقَيْهِ ‏.‏\hadithno{570}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hakam and Salamah in Kuhail that:They asked 'Abdullah bin Abi Awfa about dry ablution. He said: "The Prophet commanded 'Ammar to do like this;' and he struck the ground with his palms, shook the dust off and wiped his face. (Da'if)Hakam said, "and his hands," Salamah said, "and his elbows}}
\hadithdefcmd{ibnmajah}{571}{حَدَّثَنَا أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، حِينَ تَيَمَّمُوا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَمَرَ الْمُسْلِمِينَ فَضَرَبُوا بِأَكُفِّهِمُ التُّرَابَ وَلَمْ يَقْبِضُوا مِنَ التُّرَابِ شَيْئًا فَمَسَحُوا بِوُجُوهِهِمْ مَسْحَةً وَاحِدَةً ثُمَّ عَادُوا فَضَرَبُوا بِأَكُفِّهِمُ الصَّعِيدَ مَرَّةً أُخْرَى فَمَسَحُوا بِأَيْدِيهِمْ ‏.‏\hadithno{571}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ammar bin Yasir that:When they did dry ablution with the Messenger of Allah, he commanded the Muslims to strike the dust with the palms of their hands, and they did not pick up any dust. Then they wiped their faces once, then they struck the dust with their palms once again and wiped their hands}}
\hadithdefcmd{ibnmajah}{572}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبِ بْنِ أَبِي الْعِشْرِينَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يُخْبِرُ أَنَّ رَجُلاً، أَصَابَهُ جُرْحٌ فِي رَأْسِهِ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ أَصَابَهُ احْتِلاَمٌ فَأُمِرَ بِالاِغْتِسَالِ فَاغْتَسَلَ فَكُزَّ فَمَاتَ فَبَلَغَ ذَلِكَ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ قَتَلُوهُ قَتَلَهُمُ اللَّهُ أَفَلَمْ يَكُنْ شِفَاءَ الْعِيِّ السُّؤَالُ ‏"‏ ‏.‏ قَالَ عَطَاءٌ وَبَلَغَنَا أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ لَوْ غَسَلَ جَسَدَهُ وَتَرَكَ رَأْسَهُ حَيْثُ أَصَابَهُ الْجِرَاحُ ‏"‏ ‏.‏\hadithno{572}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ata' bin Abu Rabah said:"I heard Ibn 'Abbas saying that a man was injured in the head at the time of the Messenger of Allah, then he had a wet dream. He was told to have a bath, so he took the bath, became rigid and stiff, and died. News of that reached the Messenger of Allah and he said: 'They have killed him, may Allah kill them! Is not the cure for a lack of knowledge to ask questions?'"'Ata' said: "We heard that the Messenger of Allah said: 'If only he had washed his body and left his head alone where the wound was}}
\hadithdefcmd{ibnmajah}{573}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ حَدَّثَنَا ابْنُ عَبَّاسٍ، عَنْ خَالَتِهِ، مَيْمُونَةَ قَالَتْ وَضَعْتُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ غُسْلاً فَاغْتَسَلَ مِنَ الْجَنَابَةِ فَأَكْفَأَ الإِنَاءَ بِشِمَالِهِ عَلَى يَمِينِهِ فَغَسَلَ كَفَّيْهِ ثَلاَثًا ثُمَّ أَفَاضَ عَلَى فَرْجِهِ ثُمَّ دَلَكَ يَدَهُ فِي الأَرْضِ ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ وَغَسَلَ وَجْهَهُ ثَلاَثًا وَذِرَاعَيْهِ ثَلاَثًا ثُمَّ أَفَاضَ الْمَاءَ عَلَى سَائِرِ جَسَدِهِ ثُمَّ تَنَحَّى فَغَسَلَ رِجْلَيْهِ ‏.‏\hadithno{573}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Abbas narrated that his maternal aunt Maimunah said:"I put out some water for the Prophet to take a bath, and he bathe to cleanse himself from impurity following sexual activity. He tilted the vessel with his left hand, pouring water into his right, and washed his hands three times. Then he pourd water over his private parts, then he rubbed his hands on the ground. Then he rinsed his mouth and nose, and washed his face three times, and his forearms three times. Then he poured water over the rest of his body, then he moved aside and washed his feet}}
\hadithdefcmd{ibnmajah}{574}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا صَدَقَةُ بْنُ سَعِيدٍ الْحَنَفِيُّ، حَدَّثَنَا جُمَيْعُ بْنُ عُمَيْرٍ التَّيْمِيُّ، قَالَ انْطَلَقْتُ مَعَ عَمَّتِي وَخَالَتِي فَدَخَلْنَا عَلَى عَائِشَةَ فَسَأَلْنَاهَا كَيْفَ كَانَ يَصْنَعُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عِنْدَ غُسْلِهِ مِنَ الْجَنَابَةِ قَالَتْ كَانَ يُفِيضُ عَلَى كَفَّيْهِ ثَلاَثَ مَرَّاتٍ ثُمَّ يُدْخِلُهَا فِي الإِنَاءِ ثُمَّ يَغْسِلُ رَأْسَهُ ثَلاَثَ مَرَّاتٍ ثُمَّ يُفِيضُ عَلَى جَسَدِهِ ثُمَّ يَقُومُ إِلَى الصَّلاَةِ وَأَمَّا نَحْنُ فَإِنَّا نَغْسِلُ رُءُوسَنَا خَمْسَ مِرَارٍ مِنْ أَجْلِ الضَّفْرِ ‏.‏\hadithno{574}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jumai' bin 'Umair At-Taimi said:"I went out with my paternal aunt and maternal aunt and we entered upon 'Aishah. We asked her: 'What did the Messenger of Allah do when he had the bath to cleanse himself from sexual impurity?' She said: 'He used to pour water on his hand three times, then he would put them in the vessel and wash his face three times, then he would pour water over his body, then he would get up and perform prayer. As for us, we would wash our heads five times because of our braided hair}}
\hadithdefcmd{ibnmajah}{575}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ صُرَدٍ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ تَمَارَوْا فِي الْغُسْلِ مِنَ الْجَنَابَةِ عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَمَّا أَنَا فَأُفِيضُ عَلَى رَأْسِي ثَلاَثَ أَكُفٍّ ‏"‏ ‏.‏\hadithno{575}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Jubair bin Mut'im said:"(The Companions) disputed in the presence of the Messenger of Allah about having a bath to cleanse oneself from sexual impurity. The Messenger of Allah said: 'As for me, I pour three handfuls of water on my head}}
\hadithdefcmd{ibnmajah}{576}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ فُضَيْلٍ، جَمِيعًا عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَجُلاً، سَأَلَهُ عَنِ الْغُسْلِ، مِنَ الْجَنَابَةِ فَقَالَ ثَلاَثًا ‏.‏ فَقَالَ الرَّجُلُ إِنَّ شَعْرِي كَثِيرٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ أَكْثَرَ شَعْرًا مِنْكَ وَأَطْيَبَ ‏.‏\hadithno{576}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa'eed that:A man asked him about having a bath to cleanse oneself from sexual impurity. He said to pour water three times. The man said: "But I have a lot of hair." He said: "The Messenger of Allah had more hair than you and he was cleaner}}
\hadithdefcmd{ibnmajah}{577}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَنَا فِي، أَرْضٍ بَارِدَةٍ فَكَيْفَ الْغُسْلُ مِنَ الْجَنَابَةِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَمَّا أَنَا فَأَحْثُو عَلَى رَأْسِي ثَلاَثًا ‏"‏ ‏.‏\hadithno{577}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"I said: 'O Messenger of Allah! I live in a cold land, so how should I have a bath to cleanse myself from sexual impurity?' He said: 'As for me, I pour three handfuls of water over my head}}
\hadithdefcmd{ibnmajah}{578}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، سَأَلَهُ رَجُلٌ كَمْ أُفِيضُ عَلَى رَأْسِي وَأَنَا جُنُبٌ قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَحْثُو عَلَى رَأْسِهِ ثَلاَثَ حَثَيَاتٍ ‏.‏ قَالَ الرَّجُلُ إِنَّ شَعْرِي طَوِيلٌ ‏.‏ قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَكْثَرَ شَعَرًا مِنْكَ وَأَطْيَبَ ‏.‏\hadithno{578}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that :A man asked him: "How much water should I pour over my head when I m sexually impure?" He said: "the messenger of Allah used to pour three handfuls of water over his head." The man said: "My hair is long." He said: "The Messenger of Allah had more hair than you and he was cleaner}}
\hadithdefcmd{ibnmajah}{579}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، وَإِسْمَاعِيلُ بْنُ مُوسَى السُّدِّيُّ، قَالُوا حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لاَ يَتَوَضَّأُ بَعْدَ الْغُسْلِ مِنَ الْجَنَابَةِ ‏.‏\hadithno{579}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah would not perform ablution after the bath to cleanse himself from sexual impurity}}
\hadithdefcmd{ibnmajah}{580}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ حُرَيْثٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَغْتَسِلُ مِنَ الْجَنَابَةِ ثُمَّ يَسْتَدْفِئُ بِي قَبْلَ أَنْ أَغْتَسِلَ ‏.‏\hadithno{580}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to have a bath to cleanse himself from sexual impurity, then he would warm himself with me before I had the bath}}
\hadithdefcmd{ibnmajah}{581}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُجْنِبُ ثُمَّ يَنَامُ وَلاَ يَمَسُّ مَاءً حَتَّى يَقُومَ بَعْدَ ذَلِكَ فَيَغْتَسِلَ ‏.‏\hadithno{581}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah would become sexually impure and then sleep without water until he got up later on and taken a bath}}
\hadithdefcmd{ibnmajah}{582}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ إِنْ كَانَتْ لَهُ إِلَى أَهْلِهِ حَاجَةٌ قَضَاهَا ثُمَّ يَنَامُ كَهَيْئَتِهِ لاَ يَمَسُّ مَاءً ‏.‏\hadithno{582}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah, if he needed any of his wives, would satisfy his needs then he would sleep as he was, without touching water}}
\hadithdefcmd{ibnmajah}{583}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُجْنِبُ ثُمَّ يَنَامُ كَهَيْئَتِهِ لاَ يَمَسُّ مَاءً ‏.‏ قَالَ سُفْيَانُ فَذَكَرْتُ الْحَدِيثَ يَوْمًا فَقَالَ لِي إِسْمَاعِيلُ يَا فَتًى يُشَدُّ هَذَا الْحَدِيثُ بِشَىْءٍ ‏.‏\hadithno{583}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah would become sexually impure then sleep as he was, without touching water. (Da'if)Sufyan said: "I mentioned this Hadith one day, and Isma'il said to me: 'O young man, you should support this Hadith with something else}}
\hadithdefcmd{ibnmajah}{584}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا أَرَادَ أَنْ يَنَامَ وَهُوَ جُنُبٌ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ‏.‏\hadithno{584}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"When the Messenger of Allah wanted to sleep and he was sexually impure, he would perform ablution as for prayer}}
\hadithdefcmd{ibnmajah}{585}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَيَرْقُدُ أَحَدُنَا وَهُوَ جُنُبٌ قَالَ ‏ "‏ نَعَمْ إِذَا تَوَضَّأَ ‏"‏ ‏.‏\hadithno{585}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that :'Umar bin Khattab said to the Messenger of Allah: "can anyone of us sleep if he is sexually impure?" He said: "Yes, if he performs ablution}}
\hadithdefcmd{ibnmajah}{586}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، مُحَمَّدُ بْنُ عُثْمَانَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ كَانَ تُصِيبُهُ الْجَنَابَةُ بِاللَّيْلِ فَيُرِيدُ أَنْ يَنَامَ فَأَمَرَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَتَوَضَّأَ ثُمَّ يَنَامَ ‏.‏\hadithno{586}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Sa'eed Khudri that:He used to become sexually impure at night, then he would want to sleep. The Messenger of Allah told him to perform ablution and then go to sleep}}
\hadithdefcmd{ibnmajah}{587}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَتَى أَحَدُكُمْ أَهْلَهُ ثُمَّ أَرَادَ أَنْ يَعُودَ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{587}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah said: 'If anyone of you has intercourse with his wife, then he wants to do it again, let him perform ablution}}
\hadithdefcmd{ibnmajah}{588}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى أَبُو مُوسَى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَأَبُو أَحْمَدَ عَنْ سُفْيَانَ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَطُوفُ عَلَى نِسَائِهِ فِي غُسْلٍ وَاحِدٍ ‏.‏\hadithno{588}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:The Prophet used to go round to all his wives with one bath}}
\hadithdefcmd{ibnmajah}{589}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ صَالِحِ بْنِ أَبِي الأَخْضَرِ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ وَضَعْتُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ غُسْلاً فَاغْتَسَلَ مِنْ جَمِيعِ نِسَائِهِ فِي لَيْلَةٍ ‏.‏\hadithno{589}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:"I put out water for the Messenger of Allah for a bath, and he had a bath after going to all of his wives in one night}}
\hadithdefcmd{ibnmajah}{590}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي رَافِعٍ، عَنْ عَمَّتِهِ، سَلْمَى عَنْ أَبِي رَافِعٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ طَافَ عَلَى نِسَائِهِ فِي لَيْلَةٍ وَكَانَ يَغْتَسِلُ عِنْدَ كُلِّ وَاحِدَةٍ مِنْهُنَّ فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ أَلاَ تَجْعَلُهُ غُسْلاً وَاحِدًا فَقَالَ ‏ "‏ هُوَ أَزْكَى وَأَطْيَبُ وَأَطْهَرُ ‏"‏ ‏.‏\hadithno{590}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Rafi' that:The Prophet went around to all of his wives in one night, and he had a bath after each one of them. It was said to him: "O Messenger of Allah, why not make it one bath?" He said: "This is purer, better and cleaner}}
\hadithdefcmd{ibnmajah}{591}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، وَغُنْدَرٌ، وَوَكِيعٌ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا أَرَادَ أَنْ يَأْكُلَ وَهُوَ جُنُبٌ تَوَضَّأَ ‏.‏\hadithno{591}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"If the Messenger of Allah wanted to eat when he was sexually impure, he would perform ablution}}
\hadithdefcmd{ibnmajah}{592}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ هَيَّاجٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ صُبَيْحٍ، حَدَّثَنَا أَبُو أُوَيْسٍ، عَنْ شُرَحْبِيلَ بْنِ سَعْدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سُئِلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَنِ الْجُنُبِ هَلْ يَنَامُ أَوْ يَأْكُلُ أَوْ يَشْرَبُ قَالَ ‏ "‏ نَعَمْ إِذَا تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{592}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Prophet was asked about whether a person who is sexually impure can sleep, or eat, or drink. He said: 'yes, if he does ablution as for the prayer}}
\hadithdefcmd{ibnmajah}{593}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أَرَادَ أَنْ يَأْكُلَ وَهُوَ جُنُبٌ غَسَلَ يَدَيْهِ ‏.‏\hadithno{593}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that:If the Prophet wanted to eat when he was sexually impure, he would wash his hands}}
\hadithdefcmd{ibnmajah}{594}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، قَالَ دَخَلْتُ عَلَى عَلِيِّ بْنِ أَبِي طَالِبٍ فَقَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْتِي الْخَلاَءَ فَيَقْضِي الْحَاجَةَ ثُمَّ يَخْرُجُ فَيَأْكُلُ مَعَنَا الْخُبْزَ وَاللَّحْمَ وَيَقْرَأُ الْقُرْآنَ وَلاَ يَحْجُبُهُ - وَرُبَّمَا قَالَ وَلاَ يَحْجُزُهُ - عَنِ الْقُرْآنِ شَىْءٌ إِلاَّ الْجَنَابَةُ ‏.‏\hadithno{594}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin Salamah said:"I entered upon 'Ali bin Abu Talib and he said: 'The Messenger of Allah used to go to the lavatory and relieve himself, then come out, and he would eat bread and meat with us and recite Qur'an, nothing stopped him' or perhaps he said: 'prevented him from doing so except sexual impurity}}
\hadithdefcmd{ibnmajah}{595}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَقْرَأُ الْقُرْآنَ الْجُنُبُ وَلاَ الْحَائِضُ ‏"‏ ‏.‏\hadithno{595}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'No one who is sexually impure and no woman who is menstruating should recite Qur'an}}
\hadithdefcmd{ibnmajah}{596}{قَالَ أَبُو الْحَسَنِ وَحَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَقْرَأُ الْجُنُبُ وَالْحَائِضُ شَيْئًا مِنَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{596}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'No one who is sexually impure and no woman who is menstruating should recite anything of the Qur'an}}
\hadithdefcmd{ibnmajah}{597}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا الْحَارِثُ بْنُ وَجِيهٍ، حَدَّثَنَا مَالِكُ بْنُ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ تَحْتَ كُلِّ شَعَرَةٍ جَنَابَةً فَاغْسِلُوا الشَّعَرَ وَأَنْقُوا الْبَشَرَةَ ‏"‏ ‏.‏\hadithno{597}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Under every hair there is the state of sexual impurity, so wash the hair and cleanse the skin}}
\hadithdefcmd{ibnmajah}{598}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي عُتْبَةُ بْنُ أَبِي حَكِيمٍ، حَدَّثَنِي طَلْحَةُ بْنُ نَافِعٍ، حَدَّثَنِي أَبُو أَيُّوبَ الأَنْصَارِيُّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ الصَّلَوَاتُ الْخَمْسُ وَالْجُمُعَةُ إِلَى الْجُمُعَةِ وَأَدَاءُ الأَمَانَةِ كَفَّارَةٌ لِمَا بَيْنَهَا ‏"‏ ‏.‏ قُلْتُ وَمَا أَدَاءُ الأَمَانَةِ قَالَ ‏"‏ غُسْلُ الْجَنَابَةِ فَإِنَّ تَحْتَ كُلِّ شَعَرَةٍ جَنَابَةً ‏"‏ ‏.‏\hadithno{598}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Ayyub Al-Ansari narrated that:The Prophet said: "The five daily prayers, from one Friday to the next, and fulfilling the trust are all expiation for whatever (sins) come between them." I said: "What is fulfilling the trust?" He said: Having a bath to cleanse oneself from sexual impurity, for under every hair there is the state of sexual impurity}}
\hadithdefcmd{ibnmajah}{599}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ زَاذَانَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ تَرَكَ مَوْضِعَ شَعَرَةٍ مِنْ جَسَدِهِ مِنْ جَنَابَةٍ لَمْ يَغْسِلْهَا فُعِلَ بِهِ كَذَا وَكَذَا مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ عَلِيٌّ فَمِنْ ثَمَّ عَادَيْتُ شَعَرِي ‏.‏ وَكَانَ يَجُزُّهُ ‏.‏\hadithno{599}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Ali bin Abu Talib that:The Prophet said: "Whoever leaves an area the size of a hair on his body and does not cleanse it from sexual impurity, such and such will be done to him in the Fire." 'Ali said: "Because of that I am hostile towards my hair," and he used to shave his head}}
\hadithdefcmd{ibnmajah}{600}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّهَا أُمِّ سَلَمَةَ، قَالَتْ جَاءَتْ أُمُّ سُلَيْمٍ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَسَأَلَتْهُ عَنِ الْمَرْأَةِ تَرَى فِي مَنَامِهَا مَا يَرَى الرَّجُلُ قَالَ ‏"‏ نَعَمْ إِذَا رَأَتِ الْمَاءَ فَلْتَغْتَسِلْ ‏"‏ ‏.‏ فَقُلْتُ فَضَحْتِ النِّسَاءَ وَهَلْ تَحْتَلِمُ الْمَرْأَةُ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ تَرِبَتْ يَمِينُكِ فَبِمَ يُشْبِهُهَا وَلَدُهَا إِذًا ‏"‏ ‏.‏\hadithno{600}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Zainab, the daughter of Umm Salamah, that :Her mother Umm Salamah said: "Umm Sulaim came to the Prophet and asked him about a woman who sees in her dream something like a man sees. He said: 'Yes, if she sees water (discharge), let her take a bath.' I said: 'You have embarrassed the women. Do women experience wet dreams?' The Prophet said: 'May your hands be rubbed with dust, how else does her child resemble her?}}
\hadithdefcmd{ibnmajah}{601}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَعَبْدُ الأَعْلَى، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ أُمَّ سُلَيْمٍ، سَأَلَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْمَرْأَةِ تَرَى فِي مَنَامِهَا مَا يَرَى الرَّجُلُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِذَا رَأَتْ ذَلِكَ فَأَنْزَلَتْ فَعَلَيْهَا الْغُسْلُ ‏"‏ ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ أَيَكُونُ هَذَا قَالَ ‏"‏ نَعَمْ مَاءُ الرَّجُلِ غَلِيظٌ أَبْيَضُ وَمَاءُ الْمَرْأَةِ رَقِيقٌ أَصْفَرُ فَأَيُّهُمَا سَبَقَ أَوْ عَلاَ أَشْبَهَهُ الْوَلَدُ ‏"‏ ‏.‏\hadithno{601}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that:Umm Sulaim asked the Messenger of Allah about a woman who sees in her dream something like that which a man sees. The Messenger of Allah said: "If she sees that and has a discharge, then let her perform a bath." Umm Salamah said: "O Messenger of Allah, does that really happen?" He said: "Yes, the water of the man is thick and white and the water of a woman is thin and yellow. Whichever of them comes first or predominates, the child will resemble (that parent)}}
\hadithdefcmd{ibnmajah}{602}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ خَوْلَةَ بِنْتِ حَكِيمٍ، أَنَّهَا سَأَلَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْمَرْأَةِ تَرَى فِي مَنَامِهَا مَا يَرَى الرَّجُلُ فَقَالَ ‏ "‏ لَيْسَ عَلَيْهَا غُسْلٌ حَتَّى تُنْزِلَ كَمَا أَنَّهُ لَيْسَ عَلَى الرَّجُلِ غُسْلٌ حَتَّى يُنْزِلَ ‏"‏ ‏.‏\hadithno{602}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Khawlah bint Hakim that:She asked the Messenger of Allah about a woman who sees in her dream that which a man sees. He said: "She does not have to take a bath unless she has an orgasm, just as man does not have to take a bath unless he has an orgasm}}
\hadithdefcmd{ibnmajah}{603}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أَشُدُّ ضَفْرَ رَأْسِي أَفَأَنْقُضُهُ لِغُسْلِ الْجَنَابَةِ فَقَالَ ‏"‏ إِنَّمَا يَكْفِيكِ أَنْ تَحْثِي عَلَيْهِ ثَلاَثَ حَثَيَاتٍ مِنْ مَاءٍ ثُمَّ تُفِيضِي عَلَيْكِ مِنَ الْمَاءِ فَتَطْهُرِينَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فَإِذَا أَنْتِ قَدْ طَهُرْتِ ‏"‏ ‏.‏\hadithno{603}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Umm Salamah said:"I said, O Messenger of Allah! I am a woman with tight braids. Should I undo them when I take a bath to cleanse myself from the state of sexual impurity?" He said: "Rather it is sufficient for you to pour three handfuls of water over yourself, and you will be purified," or he said: "In that case you would have become purified}}
\hadithdefcmd{ibnmajah}{604}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، قَالَ بَلَغَ عَائِشَةَ أَنَّ عَبْدَ، اللَّهِ بْنَ عَمْرٍو يَأْمُرُ نِسَاءَهُ إِذَا اغْتَسَلْنَ أَنْ يَنْقُضْنَ رُءُوسَهُنَّ فَقَالَتْ يَا عَجَبًا لاِبْنِ عَمْرٍو هَذَا أَفَلاَ يَأْمُرُهُنَّ أَنَّ يَحْلِقْنَ رُءُوسَهُنَّ لَقَدْ كُنْتُ أَنَا وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ نَغْتَسِلُ مِنْ إِنَاءٍ وَاحِدٍ فَلاَ أَزِيدُ عَلَى أَنْ أُفْرِغَ عَلَى رَأْسِي ثَلاَثَ إِفْرَاغَاتٍ ‏.‏\hadithno{604}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ubaid bin 'Umair said:"Aishah heard that 'Abdullah bin 'Amr was telling his wives to undo their braids (when they bathed). She said: 'How odd that Ibn 'Amr would do that! Why does he not tell them to shave their heads? The Messenger of Allah and I used to bathe from a single vessel, and I never did more than pour three handfuls of water over my head}}
\hadithdefcmd{ibnmajah}{605}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى، وَحَرْمَلَةُ بْنُ يَحْيَى الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، أَنَّ أَبَا السَّائِبِ، مَوْلَى هِشَامِ بْنِ زُهْرَةَ حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَغْتَسِلْ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ وَهُوَ جُنُبٌ ‏"‏ ‏.‏ فَقَالَ كَيْفَ يَفْعَلُ يَا أَبَا هُرَيْرَةَ فَقَالَ يَتَنَاوَلُهُ تَنَاوُلاً ‏.‏\hadithno{605}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Bukair bin 'Abdullah bin Ashajj that:Abu Sa'ib, the freed slave of Hisham bin Zuhrah, told him that he heard Abu Hurairah say: "The Messenger of Allah said: 'No one of you should bathe in standing water when he is sexually impure.'" He (Abu Sa'ib) said: "What should he do, O Abu Hurairah?" He said: "Let him take some out (and pour it over himself)}}
\hadithdefcmd{ibnmajah}{606}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا غُنْدَرٌ، مُحَمَّدُ بْنُ جَعْفَرٍ عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ ذَكْوَانَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّ عَلَى رَجُلٍ مِنَ الأَنْصَارِ فَأَرْسَلَ إِلَيْهِ فَخَرَجَ رَأْسُهُ يَقْطُرُ فَقَالَ ‏"‏ لَعَلَّنَا أَعْجَلْنَاكَ ‏"‏ ‏.‏ قَالَ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِذَا أُعْجِلْتَ أَوْ أُقْحِطْتَ فَلاَ غُسْلَ عَلَيْكَ وَعَلَيْكَ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{606}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:The Messenger of Allah passed by (the house of) one of the Ansar and sent word for him to come out. He came out with his head dripping and (the Prophet) said: "Perhaps we made you hurry?"He said: "O Messenger of Allah." He said, "If you are hurried (by someone) or obstructed (from orgasm) and do not ejaculate, then you do not have to take a bath, but you should perform ablution}}
\hadithdefcmd{ibnmajah}{607}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ السَّائِبِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سُعَادٍ، عَنْ أَبِي أَيُّوبَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمَاءُ مِنَ الْمَاءِ ‏"‏ ‏.‏\hadithno{607}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Ayyub said:"The Messenger of Allah said: 'Water (of bath) is for water (of seminal discharge)}}
\hadithdefcmd{ibnmajah}{608}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ الطَّنَافِسِيُّ، وَعَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، أَخْبَرَنَا الْقَاسِمُ بْنُ مُحَمَّدٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ إِذَا الْتَقَى الْخِتَانَانِ فَقَدْ وَجَبَ الْغُسْلُ فَعَلْتُهُ أَنَا وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَاغْتَسَلْنَا ‏.‏\hadithno{608}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah the wife of the Prophet said:"When the two circumcised parts meet, then bath is obligatory. The Messenger of Allah and I did that, and we bathed}}
\hadithdefcmd{ibnmajah}{609}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَنْبَأَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ قَالَ سَهْلُ بْنُ سَعْدٍ السَّاعِدِيُّ أَنْبَأَنَا أُبَىُّ بْنُ كَعْبٍ، قَالَ إِنَّمَا كَانَتْ رُخْصَةً فِي أَوَّلِ الإِسْلاَمِ ثُمَّ أُمِرْنَا بِالْغُسْلِ بَعْدُ ‏.‏\hadithno{609}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ubayy bin Ka'b said:"That was a concession that was granted in the early days of Islam, then we were commanded to have a bathe after that}}
\hadithdefcmd{ibnmajah}{610}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا جَلَسَ الرَّجُلُ بَيْنَ شُعَبِهَا الأَرْبَعِ ثُمَّ جَهَدَهَا فَقَدْ وَجَبَ الْغُسْلُ ‏"‏ ‏.‏\hadithno{610}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "When a man sits between the four parts (arms and legs of his wife) and has intercourse, then bath is obligatory}}
\hadithdefcmd{ibnmajah}{611}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ حَجَّاجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا الْتَقَى الْخِتَانَانِ وَتَوَارَتِ الْحَشَفَةُ فَقَدْ وَجَبَ الْغُسْلُ ‏"‏ ‏.‏\hadithno{611}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib from his father, that his grandfather said:"The Messenger of Allah said: 'When the two circumcised parts meet, and (the tip of the penis) disappears, then bath is obligatory}}
\hadithdefcmd{ibnmajah}{612}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ، عَنِ الْعُمَرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ نَوْمِهِ فَرَأَى بَلَلاً وَلَمْ يَرَ أَنَّهُ احْتَلَمَ اغْتَسَلَ وَإِذَا رَأَى أَنَّهُ قَدِ احْتَلَمَ وَلَمْ يَرَ بَلَلاً فَلاَ غُسْلَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{612}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:The Prophet said: "If anyone of wakes up and sees some wetness, but he does not think that he had an erotic dream, let him have a bath. But if he thinks that he had an erotic dream but he does not see any wetness, then he does not have to take a bath}}
\hadithdefcmd{ibnmajah}{613}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، وَأَبُو حَفْصٍ عَمْرُو بْنُ عَلِيٍّ الْفَلاَّسُ وَمُجَاهِدُ بْنُ مُوسَى قَالُوا حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا يَحْيَى بْنُ الْوَلِيدِ، أَخْبَرَنِي مُحِلُّ بْنُ خَلِيفَةَ، حَدَّثَنِي أَبُو السَّمْحِ، قَالَ كُنْتُ أَخْدُمُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَكَانَ إِذَا أَرَادَ أَنْ يَغْتَسِلَ قَالَ ‏ "‏ وَلِّنِي ‏"‏ ‏.‏ فَأُوَلِّيهِ قَفَاىَ وَأَنْشُرُ الثَّوْبَ فَأَسْتُرُهُ بِهِ ‏.‏\hadithno{613}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Samh said:"I used to serve the Prophet, and when he wanted to take a bath he would say: 'Turn your back to me.' So I would turn my back and hung up a cloth, and concealed him with it}}
\hadithdefcmd{ibnmajah}{614}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ نَوْفَلٍ، أَنَّهُ قَالَ سَأَلْتُ فَلَمْ أَجِدْ أَحَدًا يُخْبِرُنِي أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سَبَّحَ فِي سَفَرٍ حَتَّى أَخْبَرَتْنِي أُمُّ هَانِئٍ بِنْتُ أَبِي طَالِبٍ أَنَّهُ قَدِمَ عَامَ الْفَتْحِ فَأَمَرَ بِسِتْرٍ فَسُتِرَ عَلَيْهِ فَاغْتَسَلَ ثُمَّ سَبَّحَ ثَمَانِيَ رَكَعَاتٍ ‏.‏\hadithno{614}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah bin Harith bin Nawfal said:"I asked whether the Messenger of Allah prayed voluntary prayer when traveling, but I could not find anyone to tell me until Umm Hani' bint Abu Talib told me that he had come during the year of the Conquest (of Makkah). He ordered that a screen be held up, and that was done, and he took a bath; then he prayed eight Rak'ah (units) of voluntary prayer}}
\hadithdefcmd{ibnmajah}{615}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ ثَعْلَبَةَ الْحِمَّانِيُّ، حَدَّثَنَا عَبْدُ الْحَمِيدِ أَبُو يَحْيَى الْحِمَّانِيُّ، حَدَّثَنَا الْحَسَنُ بْنُ عُمَارَةَ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَغْتَسِلَنَّ أَحَدُكُمْ بِأَرْضِ فَلاَةٍ وَلاَ فَوْقَ سَطْحٍ لاَ يُوَارِيهِ فَإِنْ لَمْ يَكُنْ يَرَى فَإِنَّهُ يُرَى ‏"‏ ‏.‏\hadithno{615}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"The Messenger of Allah said: 'No one of you should bathe in open land or on a roof where he is not concealed; even if he does not see anyone, he can still be seen}}
\hadithdefcmd{ibnmajah}{616}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ أَرْقَمَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَرَادَ أَحَدُكُمُ الْغَائِطَ وَأُقِيمَتِ الصَّلاَةُ فَلْيَبْدَأْ بِهِ ‏"‏ ‏.‏\hadithno{616}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Arqam said:"The Messenger of Allah said: 'If anyone of you needs to defecate and the immediate call to prayer (Iqamah) is given, let him start with (relieving himself)}}
\hadithdefcmd{ibnmajah}{617}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنِ السَّفْرِ بْنِ نُسَيْرٍ، عَنْ يَزِيدَ بْنِ شُرَيْحٍ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُصَلِّيَ الرَّجُلُ وَهُوَ حَاقِنٌ ‏.‏\hadithno{617}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Umamah that:The Messenger of Allah forbade a man to perform prayer when he was suppressing (the urge to urinate or defecate)}}
\hadithdefcmd{ibnmajah}{618}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ إِدْرِيسَ الأَوْدِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَقُومُ أَحَدُكُمْ إِلَى الصَّلاَةِ وَبِهِ أَذًى ‏"‏ ‏.‏\hadithno{618}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said, 'No one of you should stand to pray when he feels some discomfort (because of needing to urinate or defecate)}}
\hadithdefcmd{ibnmajah}{619}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ حَبِيبِ بْنِ صَالِحٍ، عَنْ أَبِي حَىٍّ الْمُؤَذِّنِ، عَنْ ثَوْبَانَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ لاَ يَقُومُ أَحَدٌ مِنَ الْمُسْلِمِينَ وَهُوَ حَاقِنٌ حَتَّى يَتَخَفَّفَ ‏"‏ ‏.‏\hadithno{619}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Thawban that:The Messenger of Allah said: "No one among the Muslims should stand to pray when he is suppressing (the need to urinate or defecate), until he has to relieve himself}}
\hadithdefcmd{ibnmajah}{620}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنِ الْمُنْذِرِ بْنِ الْمُغِيرَةِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، حَدَّثَتْهُ أَنَّهَا، أَتَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَشَكَتْ إِلَيْهِ الدَّمَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّمَا ذَلِكَ عِرْقٌ فَانْظُرِي إِذَا أَتَى قَرْؤُكِ فَلاَ تُصَلِّي فَإِذَا مَرَّ الْقَرْءُ فَتَطَهَّرِي ثُمَّ صَلِّي مَا بَيْنَ الْقَرْءِ إِلَى الْقَرْءِ ‏"‏ ‏.‏\hadithno{620}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Urwah bin Zubair that Fatimah bint Abi Hubaish narrated to him that:She went to the Messenger of Allah and complained to him about bleeding. The Messenger of Allah said: "Rather that is a vein, so look and see when your period comes, then do not perform the prayer. When the period is over, then purify yourself and perform the prayer between one period to the next}}
\hadithdefcmd{ibnmajah}{621}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ ‏ "‏ لاَ إِنَّمَا ذَلِكَ عِرْقٌ وَلَيْسَ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏ هَذَا حَدِيثُ وَكِيعٍ ‏.‏\hadithno{621}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"Fatimah bint Abi Hubaish came to the Messenger of Allah and said: 'O Messenger of Allah! I am a woman who bleeds continuously and never becomes pure, should I give up the prayer?' He said: 'No, rather that is a vein and it is not menstruation. When the time of your period comes, leave off the prayer, and when it is over, take a bath and wash the blood from yourself and perform the prayer." This is the Hadith of Waki}}
\hadithdefcmd{ibnmajah}{622}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - إِمْلاَءً عَلَىَّ مِنْ كِتَابِهِ وَكَانَ السَّائِلُ غَيْرِي - أَنْبَأَنَا ابْنُ جُرَيْجٍ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ عَنْ عُمَرَ بْنِ طَلْحَةَ عَنْ أُمِّ حَبِيبَةَ بِنْتِ جَحْشٍ قَالَتْ كُنْتُ أُسْتَحَاضُ حَيْضَةً كَثِيرَةً طَوِيلَةً ‏.‏ قَالَتْ فَجِئْتُ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ أَسْتَفْتِيهِ وَأُخْبِرُهُ ‏.‏ قَالَتْ فَوَجَدْتُهُ عِنْدَ أُخْتِي زَيْنَبَ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لِي إِلَيْكَ حَاجَةً ‏.‏ قَالَ ‏"‏ وَمَا هِيَ أَىْ هَنْتَاهْ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُسْتَحَاضُ حَيْضَةً طَوِيلَةً كَبِيرَةً وَقَدْ مَنَعَتْنِي الصَّلاَةَ وَالصَّوْمَ فَمَا تَأْمُرُنِي فِيهَا قَالَ ‏"‏ أَنْعَتُ لَكِ الْكُرْسُفَ فَإِنَّهُ يُذْهِبُ الدَّمَ ‏"‏ ‏.‏ قُلْتُ هُوَ أَكْثَرُ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ شَرِيكٍ ‏.‏\hadithno{622}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Habibah bint Jahsh said:"I used to bleed continuously and heavily. I went to the Prophet asking him for advice and telling him (about my situation). I found him with my sister Zainab and said: 'o Messenger of Allah! I need to ask you something.' He said: 'What is it?' I said: 'I bleed continuously and heavily, and that is keeping me from prayer and fasting. What do you command me to do about it?' He said: 'I advise you to use a piece of cotton, for that will take away the blood.' I said: 'It is more than that.'" And he mentioned something like the Hadith of Sharik (below)}}
\hadithdefcmd{ibnmajah}{623}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ سَأَلَتِ امْرَأَةٌ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَتْ إِنِّي أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ ‏"‏ لاَ وَلَكِنْ دَعِي قَدْرَ الأَيَّامِ وَاللَّيَالِي الَّتِي كُنْتِ تَحِيضِينَ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ فِي حَدِيثِهِ ‏"‏ وَقَدْرَهُنَّ مِنَ الشَّهْرِ ثُمَّ اغْتَسِلِي وَاسْتَثْفِرِي بِثَوْبٍ وَصَلِّي ‏"‏ ‏.‏\hadithno{623}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Salamah said:"A woman asked the Prophet: 'I bleed continuously and I do not become pure. Should I give up the prayer?' He said: 'No, but leave off praying for the number of days and nights that used to menstruate.'" (One of the narrators) Abu Bakr (Ibn Abu Shaibah) said in this Hadith: "Estimate the number of days in the month, then take a bath and cover your private part with a cloth and perform prayer}}
\hadithdefcmd{ibnmajah}{624}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ ‏ "‏ لاَ إِنَّمَا ذَلِكَ عِرْقٌ وَلَيْسَ بِالْحَيْضَةِ اجْتَنِبِي الصَّلاَةَ أَيَّامَ مَحِيضِكِ ثُمَّ اغْتَسِلِي وَتَوَضَّئِي لِكُلِّ صَلاَةٍ وَإِنْ قَطَرَ الدَّمُ عَلَى الْحَصِيرِ ‏"‏ ‏.‏\hadithno{624}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"Fatimah bint Abi Hubaish came to the Prophet: 'O Messenger of Allah! I am a woman who bleeds continuously and never becomes pure. Should I give up prayer?' he said: 'No, that is just a vein and is not menstruation. Do not perform prayer during the days of your period, then take a bath, and perform ablution for each prayer, even if drops of blood fall on the mat}}
\hadithdefcmd{ibnmajah}{625}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْمَاعِيلُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي الْيَقْظَانِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْمُسْتَحَاضَةُ تَدَعُ الصَّلاَةَ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلُ وَتَتَوَضَّأُ لِكُلِّ صَلاَةٍ وَتَصُومُ وَتُصَلِّي ‏"‏ ‏.‏\hadithno{625}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Adiyy bin Thabit, from his father, from his grandfather, that:The Prophet said: "The woman who experiences irregular non-menstrual bleeding should leave prayer during the days of her period, then she should take a bath, and perform ablution for each prayer, and she should fast and perform the prayer}}
\hadithdefcmd{ibnmajah}{626}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتِ اسْتُحِيضَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ وَهِيَ تَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ سَبْعَ سِنِينَ فَشَكَتْ ذَلِكَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ هَذِهِ لَيْسَتْ بِالْحَيْضَةِ وَإِنَّمَا هُوَ عِرْقٌ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْتَسِلِي وَصَلِّي ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ ثُمَّ تُصَلِّي وَكَانَتْ تَقْعُدُ فِي مِرْكَنٍ لأُخْتِهَا زَيْنَبَ بِنْتِ جَحْشٍ حَتَّى إِنَّ حُمْرَةَ الدَّمِ لَتَعْلُو الْمَاءَ ‏.‏\hadithno{626}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Urwah bin Zubair and 'Amrah bint 'Abdur-Rahman that :'Aishah the wife of the Prophet said: "Umm Habibah Jahsh experienced prolonged non-menstrual bleeding for seven years when she was married to 'Abdur-Rahman bin 'Awf. She complained about that to the Prophet and the Prophet said: 'That is not menstruation, rather it is a vein, so when the time of your period comes, leave the prayer, and when it is over, take a bath and perform prayer.'" 'Aishah said: "She used to bathe for every prayer and then perform the prayer. She used to sit in a washtub belonging to her sister Zainab bint Jahsh and the blood would turn the water red}}
\hadithdefcmd{ibnmajah}{627}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا شَرِيكٌ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ، عَنْ عَمِّهِ، عِمْرَانَ بْنِ طَلْحَةَ عَنْ أُمِّهِ، حَمْنَةَ بِنْتِ جَحْشٍ أَنَّهَا اسْتُحِيضَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَتَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ إِنِّي اسْتُحِضْتُ حَيْضَةً مُنْكَرَةً شَدِيدَةً ‏.‏ قَالَ لَهَا ‏"‏ احْتَشِي كُرْسُفًا ‏"‏ ‏.‏ قَالَتْ لَهُ إِنَّهُ أَشَدُّ مِنْ ذَلِكَ إِنِّي أَثُجُّ ثَجًّا ‏.‏ قَالَ ‏"‏ تَلَجَّمِي وَتَحَيَّضِي فِي كُلِّ شَهْرٍ فِي عِلْمِ اللَّهِ سِتَّةَ أَيَّامٍ أَوْ سَبْعَةَ أَيَّامٍ ثُمَّ اغْتَسِلِي غُسْلاً فَصَلِّي وَصُومِي ثَلاَثَةً وَعِشْرِينَ أَوْ أَرْبَعَةً وَعِشْرِينَ وَأَخِّرِي الظُّهْرَ وَقَدِّمِي الْعَصْرَ وَاغْتَسِلِي لَهُمَا غُسْلاً وَأَخِّرِي الْمَغْرِبَ وَعَجِّلِي الْعِشَاءَ وَاغْتَسِلِي لَهُمَا غُسْلاً وَهَذَا أَحَبُّ الأَمْرَيْنِ إِلَىَّ ‏"‏ ‏.‏\hadithno{627}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hamnah bint Jahsh that:She experienced prolonged non-menstrual bleeding during the time of the Messenger of Allah. She came to the Messenger of Allah and said: "I am suffering prolonged and painful bleeding." He said: "Fill it with a pad of cloth." She said: "It is worse than that, it is flowing copiously." He said: "Then bind yourself with a cloth and observe your menses for six or seven days, in the knowledge of Allah, then have a bath and perform prayer and fast for twenty-three or twenty-four days. Delay Zuhr and bring 'Asr forward, and take (one) bath for both, and delay Maghrib and bring 'Isha' forward, and have (one) bath for both. That is what I prefer of the two matters}}
\hadithdefcmd{ibnmajah}{628}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ ثَابِتِ بْنِ هُرْمُزَ أَبِي الْمِقْدَامِ، عَنْ عَدِيِّ بْنِ دِينَارٍ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ دَمِ الْحَيْضِ يُصِيبُ الثَّوْبَ قَالَ ‏ "‏ اغْسِلِيهِ بِالْمَاءِ وَالسِّدْرِ وَحُكِّيهِ وَلَوْ بِضِلَعٍ ‏"‏ ‏.‏\hadithno{628}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Umm Qais bint Mihsan said:"I asked the Messenger of Allah about menstrual blood that gets on clothing. He said, 'Wash it with water and lote leaves, and rub it, even with a piece of stick}}
\hadithdefcmd{ibnmajah}{629}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ الصِّدِّيقِ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ دَمِ الْحَيْضِ يَكُونُ فِي الثَّوْبِ قَالَ ‏ "‏ اقْرُصِيهِ وَاغْسِلِيهِ وَصَلِّي فِيهِ ‏"‏ ‏.‏\hadithno{629}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Asma' bint Abi Bakr said:"The Messenger of Allah was asked about menstrual blood that gets on clothing. He said: 'Rub it off, wash it and perform prayer in (the garment)}}
\hadithdefcmd{ibnmajah}{630}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهَا قَالَتْ إِنْ كَانَتْ إِحْدَانَا لَتَحِيضُ ثُمَّ تَقْتَنِصُ الدَّمَ مِنْ ثَوْبِهَا عِنْدَ طُهْرِهَا فَتَغْسِلُهُ وَتَنْضِحُ عَلَى سَائِرِهِ ثُمَّ تُصَلِّي فِيهِ ‏.‏\hadithno{630}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aisha the wife of the Prophet said:"One of us used to menstruate, then rub the blood off her garment when she became pure again, and wash it, and sprinkle water over the rest of the garment, then perform prayer in it}}
\hadithdefcmd{ibnmajah}{631}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ مُعَاذَةَ الْعَدَوِيَّةِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، سَأَلَتْهَا أَتَقْضِي الْحَائِضُ الصَّلاَةَ قَالَتْ لَهَا عَائِشَةُ أَحَرُورِيَّةٌ أَنْتِ قَدْ كُنَّا نَحِيضُ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ ثُمَّ نَطْهُرُ وَلَمْ يَأْمُرْنَا بِقَضَاءِ الصَّلاَةِ ‏.‏\hadithno{631}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from 'Aishah that:A woman asked her: "Does a woman who menstruates have to make up for the prayers she misses?" 'Aisha said to her: "Are you a Haruriyyah? We used to menstruate with the Prophet and then become pure, and he did not tell us to make up for the prayers we missed}}
\hadithdefcmd{ibnmajah}{632}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَهِيِّ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ نَاوِلِينِي الْخُمْرَةَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي حَائِضٌ ‏.‏ فَقَالَ ‏"‏ لَيْسَتْ حَيْضَتُكِ فِي يَدِكِ ‏"‏ ‏.‏\hadithno{632}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said to me: 'Get me a mat from the mosque.' I said: 'I am menstruating.' He said: 'Your menstruation is not in your hand}}
\hadithdefcmd{ibnmajah}{633}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُدْنِي رَأْسَهُ إِلَىَّ وَأَنَا حَائِضٌ وَهُوَ مُجَاوِرٌ - تَعْنِي مُعْتَكِفًا - فَأَغْسِلُهُ وَأُرَجِّلُهُ ‏.‏\hadithno{633}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Prophet used to bring his head close to me when I was menstruaring and he was in I'tikaf (seclusion in a mosques for the purpose of worship), and I would wash it and comb his hair}}
\hadithdefcmd{ibnmajah}{634}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا سُفْيَانُ، عَنْ مَنْصُورِ ابْنِ صَفِيَّةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَضَعُ رَأْسَهُ فِي حِجْرِي وَأَنَا حَائِضٌ وَيَقْرَأُ الْقُرْآنَ ‏.‏\hadithno{634}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to put his head in my lap when I was menstruating and recite Qur'an}}
\hadithdefcmd{ibnmajah}{635}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَبْدِ الْكَرِيمِ، ح وَحَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، جَمِيعًا عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ إِحْدَانَا إِذَا كَانَتْ حَائِضًا أَمَرَهَا النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ تَأْتَزِرَ فِي فَوْرِ حَيْضَتِهَا ثُمَّ يُبَاشِرُهَا وَأَيُّكُمْ يَمْلِكُ إِرْبَهُ كَمَا كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَمْلِكُ إِرْبَهُ\hadithno{635}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Aishah said:"If one of us was menstruating, the Messenger of Allah would tell her to tie her waist-wrapper around herself if the bleeding was heavy, then he would embrace her. And who among you can control his desire as the Messenger of Allah used to control his desire?}}
\hadithdefcmd{ibnmajah}{636}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ إِحْدَانَا إِذَا حَاضَتْ أَمَرَهَا النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ تَأْتَزِرَ بِإِزَارٍ ثُمَّ يُبَاشِرُهَا ‏.‏\hadithno{636}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Aishah said:"If one of us was menstruating, the Messenger of Allah would tell her to tie her waist-wrapper around herself, then he would embrace her}}
\hadithdefcmd{ibnmajah}{637}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كُنْتُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي لِحَافِهِ فَوَجَدْتُ مَا تَجِدُ النِّسَاءُ مِنَ الْحَيْضَةِ فَانْسَلَلْتُ مِنَ اللِّحَافِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَنَفِسْتِ ‏"‏ ‏.‏ قُلْتُ وَجَدْتُ مَا تَجِدُ النِّسَاءُ مِنَ الْحَيْضَةِ ‏.‏ قَالَ ‏"‏ ذَلِكَ مَا كَتَبَ اللَّهُ عَلَى بَنَاتِ آدَمَ ‏"‏ ‏.‏ قَالَتْ فَانْسَلَلْتُ فَأَصْلَحْتُ مِنْ شَأْنِي ثُمَّ رَجَعْتُ فَقَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ تَعَالَىْ فَادْخُلِي مَعِي فِي اللِّحَافِ ‏"‏ ‏.‏ قَالَتْ فَدَخَلْتُ مَعَهُ ‏.‏\hadithno{637}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Umm Salamah said:"I was with the Messenger of Allah under his blanket, then I felt that I was menstruating as women do, so I slipped out from under the cover. The Messenger of Allah said: 'Are you menstruating?' I said: 'I feel that I am menstruating as women do.' He said: 'That is what Allah has decreed for the daughters of Adam.' So I slipped out and sorted myself out, then I came back, and the Messenger of Allah said to me: 'Come under the cover with me,' so I went in with him}}
\hadithdefcmd{ibnmajah}{638}{حَدَّثَنَا الْخَلِيلُ بْنُ عَمْرٍو، حَدَّثَنَا ابْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، عَنْ مُعَاوِيَةَ بْنِ حُدَيْجٍ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّ حَبِيبَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ سَأَلْتُهَا كَيْفَ كُنْتِ تَصْنَعِينَ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْحَيْضَةِ قَالَتْ كَانَتْ إِحْدَانَا فِي فَوْرِهَا أَوَّلَ مَا تَحِيضُ تَشُدُّ عَلَيْهَا إِزَارًا إِلَى أَنْصَافِ فَخِذَيْهَا ثُمَّ تَضْطَجِعُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{638}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mu'awiyah bin Abu Sufyan that :He asked Umm Habibah, the wife of the Prophet: "What did you used to do with the Messenger of Allah when you were menstruating?" She said: "If it was at the beginning of the period when the bleeding is heavy, we would tie the waist-wrapper tightly around our thighs, then lie down with the Messenger of Allah}}
\hadithdefcmd{ibnmajah}{639}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حَكِيمٍ الأَثْرَمِ، عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَتَى حَائِضًا أَوِ امْرَأَةً فِي دُبُرِهَا أَوْ كَاهِنًا فَصَدَّقَهُ بِمَا يَقُولُ فَقَدْ كَفَرَ بِمَا أُنْزِلَ عَلَى مُحَمَّدٍ ‏"‏ ‏.‏\hadithno{639}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Whoever has intercourse with a menstruating woman, or with a woman in her rear, or who goes to a fortuneteller and believes what he says, he has disbelieved in that which was revealed to Muhammad}}
\hadithdefcmd{ibnmajah}{640}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، وَابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الْحَمِيدِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي الَّذِي يَأْتِي امْرَأَتَهُ وَهِيَ حَائِضٌ قَالَ ‏ "‏ يَتَصَدَّقُ بِدِينَارٍ أَوْ بِنِصْفِ دِينَارٍ ‏"‏ ‏.‏\hadithno{640}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that:The Prophet said concerning one who has intercourse with a woman when she is menstruating: "Let him give a Dinar or half a Dinar in charity}}
\hadithdefcmd{ibnmajah}{641}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ لَهَا وَكَانَتْ حَائِضًا ‏"‏ انْقُضِي شَعْرَكِ وَاغْتَسِلِي ‏"‏ ‏.‏ قَالَ عَلِيٌّ فِي حَدِيثِهِ ‏"‏ انَقُضِي رَأْسَكِ ‏"‏ ‏.‏\hadithno{641}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:The Prophet said to her, when she was menstruating: "Undo your braids and bathe." (Sahih)(A narrator) 'Ali said in his narration: "Undo your head}}
\hadithdefcmd{ibnmajah}{642}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، قَالَ سَمِعْتُ صَفِيَّةَ، تُحَدِّثُ عَنْ عَائِشَةَ، أَنَّ أَسْمَاءَ، سَأَلَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْغُسْلِ مِنَ الْمَحِيضِ فَقَالَ ‏"‏ تَأْخُذُ إِحْدَاكُنَّ مَاءَهَا وَسِدْرَهَا فَتَطْهُرُ فَتُحْسِنُ الطُّهُورَ أَوْ تَبْلُغُ فِي الطُّهُورِ ثُمَّ تَصُبُّ عَلَى رَأْسِهَا فَتَدْلُكُهُ دَلْكًا شَدِيدًا حَتَّى تَبْلُغَ شُئُونَ رَأْسِهَا ثُمَّ تَصُبُّ عَلَيْهَا الْمَاءَ ثُمَّ تَأْخُذُ فِرْصَةً مُمَسَّكَةً فَتَطْهُرُ بِهَا ‏"‏ ‏.‏ قَالَتْ أَسْمَاءُ كَيْفَ أَتَطَهَّرُ بِهَا قَالَ ‏"‏ سُبْحَانَ اللَّهِ تَطَهَّرِي بِهَا ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ - كَأَنَّهَا تُخْفِي ذَلِكَ - تَتَبَّعِي بِهَا أَثَرَ الدَّمِ ‏.‏ قَالَتْ وَسَأَلَتْهُ عَنِ الْغُسْلِ مِنَ الْجَنَابَةِ ‏.‏ فَقَالَ ‏"‏ تَأْخُذُ إِحْدَاكُنَّ مَاءَهَا فَتَطْهُرُ فَتُحْسِنُ الطُّهُورَ أَوْ تَبْلُغُ فِي الطُّهُورِ حَتَّى تَصُبَّ الْمَاءَ عَلَى رَأْسِهَا فَتَدْلُكُهُ حَتَّى تَبْلُغَ شُئُونَ رَأْسِهَا ثُمَّ تُفِيضُ الْمَاءَ عَلَى جَسَدِهَا ‏.‏ فَقَالَتْ عَائِشَةُ نِعْمَ النِّسَاءُ نِسَاءُ الأَنْصَارِ لَمْ يَمْنَعْهُنَّ الْحَيَاءُ أَنْ يَتَفَقَّهْنَ فِي الدِّينِ ‏.‏\hadithno{642}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that:Asma asked the Messenger of Allah about bathing after ones's period. He said: "One of you should take her water and lote leaves, and purify herself well, or thoroughly. Then she should pour water over her head and rub it vigorously so that the water reaches the roots of her hair. Then she should take a piece of cotton perfumed with musk and purify herself with it." Asma said: "How should I purify myself with it?" He said: "Subhan Allah! Purify yourself with it!" 'Aishah said, as if whispering to her: "Wipe away the traces of blood with it." Then she (Asma) asked him about bathing to cleanse oneself from sexual impurity. He said: "One of you should take her water, and purify herself, and purify herself well, or thoroughly. She should pour water over her head and rub it so that the water reaches the roots of her hair, then she should pour water over her body." 'Aishah said: "How good were the women of the Ansar! For they did not let shyness keep them from understanding their religion properly}}
\hadithdefcmd{ibnmajah}{643}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحِ بْنِ هَانِئٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَتَعَرَّقُ الْعَظْمَ وَأَنَا حَائِضٌ، فَيَأْخُذُهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَيَضَعُ فَمَهُ حَيْثُ كَانَ فَمِي وَأَشْرَبُ مِنَ الإِنَاءِ فَيَأْخُذُهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَيَضَعُ فَمَهُ حَيْثُ كَانَ فَمِي وَأَنَا حَائِضٌ ‏.‏\hadithno{643}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I used to eat the meat from a bone when I was menstruating, then the Messenger of Allah would take it and put his mouth where my mouth had been. And I would drink from a vessel, and the Messenger of Allah would take it and put his mouth where my mouth had been, and I was menstruating}}
\hadithdefcmd{ibnmajah}{644}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ الْيَهُودَ، كَانُوا لاَ يَجْلِسُونَ مَعَ الْحَائِضِ فِي بَيْتٍ وَلاَ يَأْكُلُونَ وَلاَ يَشْرَبُونَ ‏.‏ قَالَ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَنْزَلَ اللَّهُ ‏\{وَيَسْأَلُونَكَ عَنِ الْمَحِيضِ قُلْ هُوَ أَذًى فَاعْتَزِلُوا النِّسَاءَ فِي الْمَحِيضِ\}‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اصْنَعُوا كُلَّ شَىْءٍ إِلاَّ الْجِمَاعَ ‏"‏ ‏.‏\hadithno{644}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that:The Jews would not sit with a menstruating woman in a house, nor eat with her, nor drink with her. That was mentioned to the Messenger of Allah, then Allah revealed the words: "They ask you concerning menstruation. Say: that is a harmful thing, therefore keep away from women during menses." The Messenger of Allah said: "Do everything except sexual intercourse}}
\hadithdefcmd{ibnmajah}{645}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا ابْنُ أَبِي غَنِيَّةَ، عَنْ أَبِي الْخَطَّابِ الْهَجَرِيِّ، عَنْ مَحْدُوجٍ الذُّهْلِيِّ، عَنْ جَسْرَةَ، قَالَتْ أَخْبَرَتْنِي أُمُّ سَلَمَةَ، قَالَتْ دَخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَرْحَةَ هَذَا الْمَسْجِدِ فَنَادَى بِأَعْلَى صَوْتِهِ ‏ "‏ إِنَّ الْمَسْجِدَ لاَ يَحِلُّ لِجُنُبٍ وَلاَ لِحَائِضٍ ‏"‏ ‏.‏\hadithno{645}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jasrah said:"Umm Salamah told me: 'The Messenger of Allah entered the courtyard of this mosque and called out at the top of his voice: 'The mosque is not permissible for anyone who is sexually impure or any woman who is menstruating}}
\hadithdefcmd{ibnmajah}{646}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ النَّحْوِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ بَكْرٍ، أَنَّهَا أَخْبَرَتْ أَنَّ عَائِشَةَ قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْمَرْأَةِ تَرَى مَا يَرِيبُهَا بَعْدَ الطُّهْرِ قَالَ ‏ "‏ إِنَّمَا هِيَ عِرْقٌ أَوْ عُرُوقٌ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى يُرِيدُ بَعْدَ الطُّهْرِ بَعْدَ الْغُسْلِ ‏.‏\hadithno{646}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Bakr that:She was told that 'Aishah said: "The Messenger of Allah said concerning a woman who sees that which causes her doubt (i.e. some bleeding) after she becomes pure: 'That is a vein or veins.'" (Da'if)"What was meant by 'after becomes pure' is after having a bath (following the end of her period)}}
\hadithdefcmd{ibnmajah}{647}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ لَمْ نَكُنْ نَرَى الصُّفْرَةَ وَالْكُدْرَةَ شَيْئًا ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرَّقَاشِيُّ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ كُنَّا لاَ نَعُدُّ الصُّفْرَةَ وَالْكُدْرَةَ شَيْئًا ‏. ‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى وُهَيْبٌ أَوْلاَهُمَا عِنْدَنَا بِهَذَا ‏.‏\hadithno{647}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Umm 'Atiyyah said:"We did not think anything of the yellowish or brownish discharge." (Sahih) (Another chain) It was narrated that Umm 'Atiyyah said: "We did not think that the yellowish or brownish discharge counted for anything." Muhammad bin Yahya said: "Wuhaib (who narrated the second version) is the better of them with this according to us}}
\hadithdefcmd{ibnmajah}{648}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا شُجَاعُ بْنُ الْوَلِيدِ، عَنْ عَلِيِّ بْنِ عَبْدِ الأَعْلَى، عَنْ أَبِي سَهْلٍ، عَنْ مُسَّةَ الأَزْدِيَّةِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَتِ النُّفَسَاءُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ تَجْلِسُ أَرْبَعِينَ يَوْمًا وَكُنَّا نَطْلِي وُجُوهَنَا بِالْوَرْسِ مِنَ الْكَلَفِ ‏.‏\hadithno{648}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Salamah said:"At the time of the Messenger of Allah, women in postnatal bleeding (after childbirth) used to wait for forty days, and we used to put Wars on our faces because of freckles}}
\hadithdefcmd{ibnmajah}{649}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ سَلاَّمِ بْنِ سُلَيْمٍ، - أَوْ سَلْمٍ شَكَّ أَبُو الْحَسَنِ وَأَظُنُّهُ هُوَ أَبُو الأَحْوَصِ - عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَّتَ لِلنُّفَسَاءِ أَرْبَعِينَ يَوْمًا إِلاَّ أَنْ تَرَى الطُّهْرَ قَبْلَ ذَلِكَ ‏.‏\hadithno{649}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah set the time for postnatal bleeding at forty days, except for one who becomes pure before that}}
\hadithdefcmd{ibnmajah}{650}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ الرَّجُلُ إِذَا وَقَعَ عَلَى امْرَأَتِهِ وَهِيَ حَائِضٌ أَمَرَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ يَتَصَدَّقَ بِنِصْفِ دِينَارٍ ‏.‏\hadithno{650}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"If a man had intercourse with his wife while she was menstruating, the Prophet commanded him to give half a Dinar in charity}}
\hadithdefcmd{ibnmajah}{651}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ حَرَامِ بْنِ حَكِيمٍ، عَنْ عَمِّهِ عَبْدِ اللَّهِ بْنِ سَعْدٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ مُوَاكَلَةِ الْحَائِضِ فَقَالَ ‏ "‏ وَاكِلْهَا ‏"‏ ‏.‏\hadithno{651}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin Sa'd said:"I asked the Messenger of Allah about eating with a menstruating woman and he said: 'Eat with her}}
\hadithdefcmd{ibnmajah}{652}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَلِّي وَأَنَا إِلَى جَنْبِهِ وَأَنَا حَائِضٌ وَعَلَىَّ مِرْطٌ لِي وَعَلَيْهِ بَعْضُهُ ‏.‏\hadithno{652}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah was performing prayer, and I was by his side. I was menstruating, and I was wearing a wool cloak, and part of it was over him}}
\hadithdefcmd{ibnmajah}{653}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا الشَّيْبَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ مَيْمُونَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى وَعَلَيْهِ مِرْطٌ عَلَيْهِ بَعْضُهُ وَعَلَيْهَا بَعْضُهُ وَهِيَ حَائِضٌ ‏.‏\hadithno{653}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Maimunah that:The Messenger of Allah performed prayer wearing a wool cloak. Part of it was over him and part was over her, and she was menstruating}}
\hadithdefcmd{ibnmajah}{654}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ دَخَلَ عَلَيْهَا فَاخْتَبَأَتْ مَوْلاَةٌ لَهَا فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ حَاضَتْ ‏"‏ ‏.‏ فَقَالَتْ نَعَمْ ‏.‏ فَشَقَّ لَهَا مِنْ عِمَامَتِهِ فَقَالَ ‏"‏ اخْتَمِرِي بِهَذَا ‏"‏ ‏.‏\hadithno{654}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:The Prophet entered upon her, and a freed slave girl of hers concealed herself. The Prophet asked: "Have her periods begun?" She said: "Yes." He tore a piece of his turban and said: "Cover your head with this}}
\hadithdefcmd{ibnmajah}{655}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو الْوَلِيدِ، وَأَبُو النُّعْمَانِ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَتَادَةَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ صَفِيَّةَ بِنْتِ الْحَارِثِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَقْبَلُ اللَّهُ صَلاَةَ حَائِضٍ إِلاَّ بِخِمَارٍ ‏"‏ ‏.‏\hadithno{655}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that:The Prophet said: "Allah does not accept the prayer of a woman who menstruates (i.e., an adult woman) except with a head cover}}
\hadithdefcmd{ibnmajah}{656}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا يَزِيدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ مُعَاذَةَ، ‏.‏ أَنَّ امْرَأَةً، سَأَلَتْ عَائِشَةَ قَالَتْ تَخْتَضِبُ الْحَائِضُ فَقَالَتْ قَدْ كُنَّا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَنَحْنُ نَخْتَضِبُ فَلَمْ يَكُنْ يَنْهَانَا عَنْهُ ‏.‏\hadithno{656}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Mu'adh that:A woman asked 'Aishah: "Can a woman who is menstruating, dye her hands?" She said: "We were with the Prophet and we used to dye our hands, and he did not tell us not to do that}}
\hadithdefcmd{ibnmajah}{657}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبَانَ الْبَلْخِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا إِسْرَائِيلُ، عَنْ عَمْرِو بْنِ خَالِدٍ، عَنْ زَيْدِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ انْكَسَرَتْ إِحْدَى زَنْدَىَّ فَسَأَلْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَمَرَنِي أَنْ أَمْسَحَ عَلَى الْجَبَائِرِ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ أَنْبَأَنَا الدَّبَرِيُّ، عَنْ عَبْدِ الرَّزَّاقِ، نَحْوَهُ ‏.‏\hadithno{657}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali bin Abu Talib said:"I broke one of my forearms and I asked the Prophet about that. He told me to wipe over the bandages." (Maudu') Another chain with similar meaning}}
\hadithdefcmd{ibnmajah}{658}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ حَامِلَ الْحُسَيْنِ بْنِ عَلِيٍّ عَلَى عَاتِقِهِ وَلُعَابُهُ يَسِيلُ عَلَيْهِ ‏.‏\hadithno{658}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"I saw the Prophet carrying Hasan bin 'Ali on his shoulder, and his saliva was dripping down on him}}
\hadithdefcmd{ibnmajah}{659}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مِسْعَرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ بْنِ كَرَامَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مِسْعَرٍ، عَنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ أُتِيَ بِدَلْوٍ فَمَضْمَضَ مِنْهُ فَمَجَّ فِيهِ مِسْكًا أَوْ أَطْيَبَ مِنَ الْمِسْكِ وَاسْتَنْثَرَ خَارِجًا مِنَ الدَّلْوِ ‏.‏\hadithno{659}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdul Jabbar bin Wa'il that his father said:"A bucket was brought to the Prophet; he rinsed his mouth and spat into it, and it was like musk or better than musk, and he rinsed his nostrils outside the bucket}}
\hadithdefcmd{ibnmajah}{660}{حَدَّثَنَا أَبُو مَرْوَانَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، وَكَانَ، قَدْ عَقَلَ مَجَّةً مَجَّهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي دَلْوٍ مِنْ بِئْرٍ لَهُمْ ‏.‏\hadithno{660}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Zuhri that:Mahmud bin Rabi' remembered that the Prophet spat into a bucket from a well that belonged to them}}
\hadithdefcmd{ibnmajah}{661}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، حَدَّثَنَا زَيْدُ بْنُ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَنْظُرِ الْمَرْأَةُ إِلَى عَوْرَةِ الْمَرْأَةِ وَلاَ يَنْظُرِ الرَّجُلُ إِلَى عَوْرَةِ الرَّجُلِ ‏"‏ ‏.‏\hadithno{661}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdur-Rahman bin Abu Sa'eed Al-Khudri from his father that:The Messenger of Allah said: "No woman should look at the nakedness of another woman, and no man should look at the nakedness of another man}}
\hadithdefcmd{ibnmajah}{662}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ مُوسَى بْنِ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ مَوْلًى، لِعَائِشَةَ عَنْ عَائِشَةَ، قَالَتْ مَا نَظَرْتُ - أَوْ مَا رَأَيْتُ - فَرْجَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَطُّ ‏.‏ قَالَ أَبُو بَكْرٍ كَانَ أَبُو نُعَيْمٍ يَقُولُ عَنْ مَوْلاَةٍ لِعَائِشَةَ ‏.‏\hadithno{662}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from a freed slave of 'Aishah that:'Aishah said: "I never looked at (or I never saw) the private part of the Messenger of Allah." (Da'if)(One of the narrators) Abu Bakr (Ibn Abu Shaibah) said: "Abu Nu'aim would say: '(From) a freed female slave of 'Aishah}}
\hadithdefcmd{ibnmajah}{663}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا مُسْتَلِمُ بْنُ سَعِيدٍ، عَنْ أَبِي عَلِيٍّ الرَّحَبِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ اغْتَسَلَ مِنْ جَنَابَةٍ فَرَأَى لُمْعَةً لَمْ يُصِبْهَا الْمَاءُ فَقَالَ بِجُمَّتِهِ فَبَلَّهَا عَلَيْهَا ‏.‏ قَالَ إِسْحَاقُ فِي حَدِيثِهِ فَعَصَرَ شَعْرَهُ عَلَيْهَا ‏.‏\hadithno{663}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas:"The Prophet bathed to cleanse himself from sexual impurity, then he saw a spot that the water did not reach." Then he motioned with the hair hanging over his shoulders and squeezed (the water from it) over that spot." (Da'if)In his narration, Ishaq said: "So he wrung his hair over it}}
\hadithdefcmd{ibnmajah}{664}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ، عَنِ الْحَسَنِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ إِنِّي اغْتَسَلْتُ مِنَ الْجَنَابَةِ وَصَلَّيْتُ الْفَجْرَ ثُمَّ أَصْبَحْتُ فَرَأَيْتُ قَدْرَ مَوْضِعِ الظُّفْرِ لَمْ يُصِبْهُ الْمَاءُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْ كُنْتَ مَسَحْتَ عَلَيْهِ بِيَدِكَ أَجْزَأَكَ ‏"‏ ‏.‏\hadithno{664}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"A man came to the Prophet and said: 'I bathed to cleanse myself from sexual impurity, and I prayed Fajr, then I noticed a spot the size of a fingernail that the water did not reach.' The Messenger of Allah said: 'If you had wiped it that would have been sufficient for you}}
\hadithdefcmd{ibnmajah}{665}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ وَقَدْ تَوَضَّأَ وَتَرَكَ مَوْضِعَ الظُّفْرِ لَمْ يُصِبْهُ الْمَاءُ فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ ارْجِعْ فَأَحْسِنْ وُضُوءَكَ ‏"‏ ‏.‏\hadithno{665}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:A man came to the Prophet; he had performed ablution and has missed a spot the size of a fingernail where water had not reached. The Prophet said to him: 'Go back and perform ablution properly}}
\hadithdefcmd{ibnmajah}{666}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، ح وَحَدَّثَنَا ابْنُ حُمَيْدٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالاَ حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ رَأَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ رَجُلاً تَوَضَّأَ فَتَرَكَ مَوْضِعَ الظُّفْرِ عَلَى قَدَمِهِ فَأَمَرَهُ أَنْ يُعِيدَ الْوُضُوءَ وَالصَّلاَةَ ‏.‏ قَالَ فَرَجَعَ ‏.‏\hadithno{666}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Umar bin Khattab said:"The Messenger of Allah saw a man performing ablution and he missed a spot the size of a fingernail on his foot. He commanded him to repeat the ablution and his prayer, so he did}}
