% Auto-generated chapter 5 for muslim
% Hadiths in this chapter: 396

\hadithdefcmd{muslim}{1161}{حَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ مَسْجِدٍ وُضِعَ فِي الأَرْضِ أَوَّلُ قَالَ ‏"‏ الْمَسْجِدُ الْحَرَامُ ‏"‏ ‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ الْمَسْجِدُ الأَقْصَى ‏"‏ ‏.‏ قُلْتُ كَمْ بَيْنَهُمَا قَالَ ‏"‏ أَرْبَعُونَ سَنَةً وَأَيْنَمَا أَدْرَكَتْكَ الصَّلاَةُ فَصَلِّ فَهُوَ مَسْجِدٌ ‏"‏ ‏.‏ وَفِي حَدِيثِ أَبِي كَامِلٍ ‏"‏ ثُمَّ حَيْثُمَا أَدْرَكَتْكَ الصَّلاَةُ فَصَلِّهْ فَإِنَّهُ مَسْجِدٌ ‏"‏ ‏.‏\hadithno{1161}\hadithtrans{Abu Dharr reported:I said: Messenger of Allah, which mosque was set up first on the earth? He said: Al-Masjid al-Haram (the sacred). I (again) said: Then which next? He said: It was the Masjid Aqsa. I (again) said: How long the space of time (between their setting up)? He (the Holy Prophet) said: It was forty years. And whenever the time comes for prayer, pray there, for that is a mosque; and in the hadith transmitted by Abu Kamil (the words are):" Whenever time comes for prayer, pray, for that is a mosque (for you)}}
\hadithdefcmd{muslim}{1162}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ بْنِ يَزِيدَ التَّيْمِيِّ، قَالَ كُنْتُ أَقْرَأُ عَلَى أَبِي الْقُرْآنَ فِي السُّدَّةِ فَإِذَا قَرَأْتُ السَّجْدَةَ سَجَدَ فَقُلْتُ لَهُ يَا أَبَتِ أَتَسْجُدُ فِي الطَّرِيقِ قَالَ إِنِّي سَمِعْتُ أَبَا ذَرٍّ يَقُولُ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ أَوَّلِ مَسْجِدٍ وُضِعَ فِي الأَرْضِ قَالَ ‏"‏ الْمَسْجِدُ الْحَرَامُ ‏"‏ ‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ الْمَسْجِدُ الأَقْصَى ‏"‏ ‏.‏ قُلْتُ كَمْ بَيْنَهُمَا قَالَ ‏"‏ أَرْبَعُونَ عَامًا ثُمَّ الأَرْضُ لَكَ مَسْجِدٌ فَحَيْثُمَا أَدْرَكَتْكَ الصَّلاَةُ فَصَلِّ ‏"‏ ‏.‏\hadithno{1162}\hadithtrans{Ibrahim b. Yazid al-Tayml reported:I used to read the Qur'an with my father in the vestibule (before the door of the mosque). When I recited the ayat (verses) concerning prostration, he prostrated himself. I said to him: Father, do you prostrate yourself in the path? He said: I heard Abu Dharr saying: I asked the Messenger of Allah (ﷺ) about the mosque that was first set up on the earth. He said: Masjid Harim. I said: Then which next? He said: The Masjid al-Aqsa. I said: How long is the space of time between the two? He said: Forty years. He (then) further said: The earth is a mosque for you, so wherever you are at the time of prayer, pray there}}
\hadithdefcmd{muslim}{1163}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ سَيَّارٍ، عَنْ يَزِيدَ الْفَقِيرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُعْطِيتُ خَمْسًا لَمْ يُعْطَهُنَّ أَحَدٌ قَبْلِي كَانَ كُلُّ نَبِيٍّ يُبْعَثُ إِلَى قَوْمِهِ خَاصَّةً وَبُعِثْتُ إِلَى كُلِّ أَحْمَرَ وَأَسْوَدَ وَأُحِلَّتْ لِيَ الْغَنَائِمُ وَلَمْ تُحَلَّ لأَحَدٍ قَبْلِي وَجُعِلَتْ لِيَ الأَرْضُ طَيِّبَةً طَهُورًا وَمَسْجِدًا فَأَيُّمَا رَجُلٍ أَدْرَكَتْهُ الصَّلاَةُ صَلَّى حَيْثُ كَانَ وَنُصِرْتُ بِالرُّعْبِ بَيْنَ يَدَىْ مَسِيرَةِ شَهْرٍ وَأُعْطِيتُ الشَّفَاعَةَ ‏"‏ ‏.‏\hadithno{1163}\hadithtrans{Jabir b. 'Abdullah al-Ansari reported:The Prophet (ﷺ) said: I have been conferred upon five (things) which were not granted to anyone before me (and these are): Every apostle wassent particularly to his own people, whereas I have been sent to all the red and the black the spoils of war have been made lawful for me, and these were never made lawful to anyone before me, and the earth has been made sacred and pure and mosque for me, so whenever the time of prayer comes for any one of you he should pray whenever he is, and I have been supported by awe (by which the enemy is overwhelmed) from the distance (which one takes) one month to cover and I have been granted intercession}}
\hadithdefcmd{muslim}{1164}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا سَيَّارٌ، حَدَّثَنَا يَزِيدُ الْفَقِيرُ، أَخْبَرَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{1164}\hadithtrans{Jabir b. 'Abdullah related that the Messenger of Allah (ﷺ) said, and he related like this}}
\hadithdefcmd{muslim}{1165}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فُضِّلْنَا عَلَى النَّاسِ بِثَلاَثٍ جُعِلَتْ صُفُوفُنَا كَصُفُوفِ الْمَلاَئِكَةِ وَجُعِلَتْ لَنَا الأَرْضُ كُلُّهَا مَسْجِدًا وَجُعِلَتْ تُرْبَتُهَا لَنَا طَهُورًا إِذَا لَمْ نَجِدِ الْمَاءَ ‏"‏ ‏.‏ وَذَكَرَ خَصْلَةً أُخْرَى ‏.‏\hadithno{1165}\hadithtrans{Hudhaifa reported:The Messenger of Allah (may peace be npon him) said: We have been made to excel (other) people in three (things): Our rows have been made like the rows of the angels and the whole earth has been made a mosque for us, and its dust has been made a purifier for us in case water is not available. And he mentioned another characteristic too}}
\hadithdefcmd{muslim}{1166}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ سَعْدِ بْنِ طَارِقٍ، حَدَّثَنِي رِبْعِيُّ بْنُ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1166}\hadithtrans{Hudhaifa reported:The Messenger of Allah (ﷺ) said like this}}
\hadithdefcmd{muslim}{1167}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فُضِّلْتُ عَلَى الأَنْبِيَاءِ بِسِتٍّ أُعْطِيتُ جَوَامِعَ الْكَلِمِ وَنُصِرْتُ بِالرُّعْبِ وَأُحِلَّتْ لِيَ الْغَنَائِمُ وَجُعِلَتْ لِيَ الأَرْضُ طَهُورًا وَمَسْجِدًا وَأُرْسِلْتُ إِلَى الْخَلْقِ كَافَّةً وَخُتِمَ بِيَ النَّبِيُّونَ ‏"‏ ‏.‏\hadithno{1167}\hadithtrans{Abu Huraira reported that the Messenger of Allah (may peace be upon hlmg) said:I have been given superiority over the other prophets in six respects: I have been given words which are concise but comprehensive in meaning; I have been helped by terror (in the hearts of enemies): spoils have been made lawful to me: the earth has been made for me clean and a place of worship; I have been sent to all mankind and the line of prophets is closed with me}}
\hadithdefcmd{muslim}{1168}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بُعِثْتُ بِجَوَامِعِ الْكَلِمِ وَنُصِرْتُ بِالرُّعْبِ وَبَيْنَا أَنَا نَائِمٌ أُتِيتُ بِمَفَاتِيحِ خَزَائِنِ الأَرْضِ فَوُضِعَتْ فِي يَدَىَّ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْتُمْ تَنْتَثِلُونَهَا ‏.‏\hadithno{1168}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: I have been commissioned with words which are concise but comprehensive in meaning; I have been helped by terror (in the hearts of enemies): and while I was asleep I was brought the keys of the treasures of the earth which were placed in my hand. And Abfi Huraira added: The Messenger of Allah (ﷺ) has left (for his heavenly home) and you are now busy in getting them}}
\hadithdefcmd{muslim}{1169}{وَحَدَّثَنَا حَاجِبُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ مِثْلَ حَدِيثِ يُونُسَ ‏.‏\hadithno{1169}\hadithtrans{Abu Huraira reported:I heard the Messenger of Allah (ﷺ) saying a hadith like that of Yunus}}
\hadithdefcmd{muslim}{1170}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1170}\hadithtrans{This hadith has been narratted by Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{1171}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ أَبِي يُونُسَ، مَوْلَى أَبِي هُرَيْرَةَ أَنَّهُ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ نُصِرْتُ بِالرُّعْبِ عَلَى الْعَدُوِّ وَأُوتِيتُ جَوَامِعَ الْكَلِمِ وَبَيْنَمَا أَنَا نَائِمٌ أُتِيتُ بِمَفَاتِيحِ خَزَائِنِ الأَرْضِ فَوُضِعَتْ فِي يَدَىَّ ‏"‏ ‏.‏\hadithno{1171}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: I have been helped by terror (in the heart of the enemy) ; I have been given words which are concise but comprehensive in meaning; and while I was asleep I was brought the keys of the treasures of the earth which were placed in my hand}}
\hadithdefcmd{muslim}{1172}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نُصِرْتُ بِالرُّعْبِ وَأُوتِيتُ جَوَامِعَ الْكَلِمِ ‏"‏ ‏.‏\hadithno{1172}\hadithtrans{Hammam b. Munabbih reported:That is what Abu Huraira reported to us from the Messenger of Allah (ﷺ) and he narrated (some) ahadith one of which is that the Messenger of Allah (ﷺ) said: I have been helped by terror (in the hearts of enemies) and I have been given words which are concise but comprehensive in meaning}}
\hadithdefcmd{muslim}{1173}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَشَيْبَانُ بْنُ فَرُّوخَ، كِلاَهُمَا عَنْ عَبْدِ الْوَارِثِ، - قَالَ يَحْيَى أَخْبَرَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ أَبِي التَّيَّاحِ الضُّبَعِيِّ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدِمَ الْمَدِينَةَ فَنَزَلَ فِي عُلْوِ الْمَدِينَةِ فِي حَىٍّ يُقَالُ لَهُمْ بَنُو عَمْرِو بْنِ عَوْفٍ ‏.‏ فَأَقَامَ فِيهِمْ أَرْبَعَ عَشْرَةَ لَيْلَةً ثُمَّ إِنَّهُ أَرْسَلَ إِلَى مَلإِ بَنِي النَّجَّارِ فَجَاءُوا مُتَقَلِّدِينَ بِسُيُوفِهِمْ - قَالَ - فَكَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى رَاحِلَتِهِ وَأَبُو بَكْرٍ رِدْفُهُ وَمَلأُ بَنِي النَّجَّارِ حَوْلَهُ حَتَّى أَلْقَى بِفِنَاءِ أَبِي أَيُّوبَ - قَالَ - فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي حَيْثُ أَدْرَكَتْهُ الصَّلاَةُ وَيُصَلِّي فِي مَرَابِضِ الْغَنَمِ ثُمَّ إِنَّهُ أَمَرَ بِالْمَسْجِدِ قَالَ فَأَرْسَلَ إِلَى مَلإِ بَنِي النَّجَّارِ فَجَاءُوا فَقَالَ ‏ "‏ يَا بَنِي النَّجَّارِ ثَامِنُونِي بِحَائِطِكُمْ هَذَا ‏"‏ ‏.‏ قَالُوا لاَ وَاللَّهِ لاَ نَطْلُبُ ثَمَنَهُ إِلاَّ إِلَى اللَّهِ ‏.‏ قَالَ أَنَسٌ فَكَانَ فِيهِ مَا أَقُولُ كَانَ فِيهِ نَخْلٌ وَقُبُورُ الْمُشْرِكِينَ وَخِرَبٌ ‏.‏ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّخْلِ فَقُطِعَ وَبِقُبُورِ الْمُشْرِكِينَ فَنُبِشَتْ وَبِالْخِرَبِ فُسُوِّيَتْ - قَالَ - فَصَفُّوا النَّخْلَ قِبْلَةً وَجَعَلُوا عِضَادَتَيْهِ حِجَارَةً - قَالَ - فَكَانُوا يَرْتَجِزُونَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مَعَهُمْ وَهُمْ يَقُولُونَ اللَّهُمَّ إِنَّهُ لاَ خَيْرَ إِلاَّ خَيْرُ الآخِرَهْ فَانْصُرِ الأَنْصَارَ وَالْمُهَاجِرَهْ\hadithno{1173}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) came to Medina and stayed in the upper part of Medina for fourteen nights with a tribe called Banu 'Amr b 'Auf. He then sent for the chiefs of Banu al-Najir, and they came with swords around their inecks. He (the narrator) said: I perceive as if I am seeing the Messenger of Allah (ﷺ) on his ride with Abu Bakr behind him and the chiefs of Banu al-Najjar around him till he alighted in the courtyard of Abu Ayyub. He (the narrator) said: The Messenger of Allah (ﷺ) said prayer when the time came for prayer, and he prayed in the fold of goats and sheep. He then ordered mosques to be built and sent for the chiefs of Banu al-Najjar, and they came (to him). He (the Holy Prophet) said to them: O Banu al-Najjar, sell these lands of yours to me. They said: No, by Allah. we would not demand their price, but (reward) from the Lord. Anas said: There (in these lands) were trees and graves of the polytheists, and ruins. The Messenger of Allah (may peace he upon him) ordered that the trees should be cut, and the graves should be dug out, and the ruins should be levelled. The trees (were thus) placed in rows towards the qibla and the stones were set on both sides of the door, and (while building the mosque) they (the Companions) sang rajaz verses along with the Messenger of Allah (ﷺ): O Allah: there is no good but the good of the next world, So help the Ansar and the Muhajirin}}
\hadithdefcmd{muslim}{1174}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي أَبُو التَّيَّاحِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي فِي مَرَابِضِ الْغَنَمِ قَبْلَ أَنْ يُبْنَى الْمَسْجِدُ ‏.‏\hadithno{1174}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) used to pray in the folds of the sheep and goats before the mosque was built}}
\hadithdefcmd{muslim}{1175}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1175}\hadithtrans{Abu al-Tiyyah reported:I heard from Anas a narration like this from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1176}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم إِلَى بَيْتِ الْمَقْدِسِ سِتَّةَ عَشَرَ شَهْرًا حَتَّى نَزَلَتِ الآيَةُ الَّتِي فِي الْبَقَرَةِ ‏\{‏ وَحَيْثُمَا كُنْتُمْ فَوَلُّوا وُجُوهَكُمْ شَطْرَهُ‏\}‏ فَنَزَلَتْ بَعْدَ مَا صَلَّى النَّبِيُّ صلى الله عليه وسلم فَانْطَلَقَ رَجُلٌ مِنَ الْقَوْمِ فَمَرَّ بِنَاسٍ مِنَ الأَنْصَارِ وَهُمْ يُصَلُّونَ فَحَدَّثَهُمْ فَوَلَّوْا وُجُوهَهُمْ قِبَلَ الْبَيْتِ ‏.‏\hadithno{1176}\hadithtrans{Al-Bara' b. 'Azib reported:I said prayer with the Apostle (ﷺ) turning towards Bait-ul-Maqdis for sixteen months till this verse of Surah Baqara wis revealed:" And wherever you are turn your faces towards it" (ii. 144). This verse was revealed when the Apostle (ﷺ) had said prayer. A person amongst his people passed by the people of Ansar as they were engaged in prayer. He narrated to them (this command of Allah) and they turned their faces towards the Ka'ba}}
\hadithdefcmd{muslim}{1177}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ جَمِيعًا عَنْ يَحْيَى، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، - عَنْ سُفْيَانَ، حَدَّثَنِي أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ صَلَّيْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَحْوَ بَيْتِ الْمَقْدِسِ سِتَّةَ عَشَرَ شَهْرًا أَوْ سَبْعَةَ عَشَرَ شَهْرًا ثُمَّ صُرِفْنَا نَحْوَ الْكَعْبَةِ ‏.‏\hadithno{1177}\hadithtrans{Abu Ishaq reported:I heard al-Bara' saying: We prayed with the Messenger of Allah (ﷺ) (with our faces) towards Bait-ul-Maqdis for sixteen months or seventeen months. Then we were made to change (our direction) towards the Ka'ba}}
\hadithdefcmd{muslim}{1178}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لَهُ - عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَيْنَمَا النَّاسُ فِي صَلاَةِ الصُّبْحِ بِقُبَاءٍ إِذْ جَاءَهُمْ آتٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أُنْزِلَ عَلَيْهِ اللَّيْلَةَ ‏.‏ وَقَدْ أُمِرَ أَنْ يَسْتَقْبِلَ الْكَعْبَةَ فَاسْتَقْبِلُوهَا ‏.‏ وَكَانَتْ وُجُوهُهُمْ إِلَى الشَّامِ فَاسْتَدَارُوا إِلَى الْكَعْبَةِ ‏.‏\hadithno{1178}\hadithtrans{Ibn 'Umar reported:As the people were praying at Quba' a man came to them and said: It has been revealed to file Messenger of Allah (ﷺ) during the night and he has been directed to turn towards the Ka'ba. So turn towards it. Their faces were towards Syria and they turned round towards Ka'ba}}
\hadithdefcmd{muslim}{1179}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، وَعَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَيْنَمَا النَّاسُ فِي صَلاَةِ الْغَدَاةِ إِذْ جَاءَهُمْ رَجُلٌ ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ ‏.‏\hadithno{1179}\hadithtrans{Ibn 'Umar reported:As the people were engaged in the morning prayer a man came to them. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{1180}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي نَحْوَ بَيْتِ الْمَقْدِسِ فَنَزَلَتْ ‏\{‏ قَدْ نَرَى تَقَلُّبَ وَجْهِكَ فِي السَّمَاءِ فَلَنُوَلِّيَنَّكَ قِبْلَةً تَرْضَاهَا فَوَلِّ وَجْهَكَ شَطْرَ الْمَسْجِدِ الْحَرَامِ‏\}‏ فَمَرَّ رَجُلٌ مِنْ بَنِي سَلِمَةَ وَهُمْ رُكُوعٌ فِي صَلاَةِ الْفَجْرِ وَقَدْ صَلَّوْا رَكْعَةً فَنَادَى أَلاَ إِنَّ الْقِبْلَةَ قَدْ حُوِّلَتْ ‏.‏ فَمَالُوا كَمَا هُمْ نَحْوَ الْقِبْلَةِ ‏.‏\hadithno{1180}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) used to pray towards Bait-ul-Maqdis, that it was revealed (to him):" Indeed We see the turning of the face to heaven, wherefore We shall assuredly cause thee to turn towards Qibla which shall please thee. So turn thy face towards the sacred Mosque (Ka'ba)" (ii. 144). A person from Banu Salama was going; (he found the people) in ruk'u (while) praying the dawn prayer and they had said one rak'ah. He said in a loud voice: Listen! the Qibla has been changed and they turned towards (the new) Qibla (Ka'ba) in that very state}}
\hadithdefcmd{muslim}{1181}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّ أُمَّ حَبِيبَةَ، وَأُمَّ سَلَمَةَ ذَكَرَتَا كَنِيسَةً رَأَيْنَهَا بِالْحَبَشَةِ - فِيهَا تَصَاوِيرُ - لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أُولَئِكِ إِذَا كَانَ فِيهِمُ الرَّجُلُ الصَّالِحُ فَمَاتَ بَنَوْا عَلَى قَبْرِهِ مَسْجِدًا وَصَوَّرُوا فِيهِ تِلْكَ الصُّوَرَ أُولَئِكِ شِرَارُ الْخَلْقِ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1181}\hadithtrans{A'isha reported:Umm Habiba and Umm Salama made a mention before the Messenger of Allah (ﷺ) of a church which they had seen in Abyssinia and which had pictures in it. The Messenger of Allah (ﷺ) said: When a pious person amongst them (among the religious groups) dies they build a place of worship on his grave, and then decorate it with such pictures. They would be the worst of creatures on the Day of judgment in the sight of Allah}}
\hadithdefcmd{muslim}{1182}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهُمْ تَذَاكَرُوا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ فَذَكَرَتْ أُمُّ سَلَمَةَ وَأُمُّ حَبِيبَةَ كَنِيسَةً ‏.‏ ثُمَّ ذَكَرَ نَحْوَهُ ‏.‏\hadithno{1182}\hadithtrans{A'isha reported:They (some Companions of the Holy Prophet) were conversing with one another in the presence of the Messenger of Allah (ﷺ) (during his last) illness. Umm Salama and Umm Habiba made a mention of the church and then (the hadith was) narrated}}
\hadithdefcmd{muslim}{1183}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ ذَكَرْنَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم كَنِيسَةً رَأَيْنَهَا بِأَرْضِ الْحَبَشَةِ يُقَالُ لَهَا مَارِيَةُ ‏.‏ بِمِثْلِ حَدِيثِهِمْ ‏.‏\hadithno{1183}\hadithtrans{A'isha reported:The wives of the Messenger of Allah (may peace be Upon him) made a mention of the church which they had seen in Abyssinia which was called Marya, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1184}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا شَيْبَانُ، عَنْ هِلاَلِ بْنِ أَبِي حُمَيْدٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ الَّذِي لَمْ يَقُمْ مِنْهُ ‏ "‏ لَعَنَ اللَّهُ الْيَهُودَ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏ قَالَتْ فَلَوْلاَ ذَاكَ أُبْرِزَ قَبْرُهُ غَيْرَ أَنَّهُ خُشِيَ أَنْ يُتَّخَذَ مَسْجِدًا ‏.‏ وَفِي رِوَايَةِ ابْنِ أَبِي شَيْبَةَ وَلَوْلاَ ذَاكَ لَمْ يَذْكُرْ قَالَتْ ‏.‏\hadithno{1184}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) said during his illness from which he never recovered: Allah cursed the Jews and the Christians that they took the graves of their prophets as mosques. She ('A'isha) reported: Had it not been so, his (Prophet's) grave would have been in an open place, but it could not be due to the fear that it may not be taken as a mosque}}
\hadithdefcmd{muslim}{1185}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، وَمَالِكٌ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏\hadithno{1185}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Let Allah destroy the Jews for they have taken the graves of their apostles as places of worship}}
\hadithdefcmd{muslim}{1186}{وَحَدَّثَنِي قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْفَزَارِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَصَمِّ، حَدَّثَنَا يَزِيدُ بْنُ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْيَهُودَ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏\hadithno{1186}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Let there be curse of Allah upon the Jews and the Christians for they have taken the graves of their apostles as places of worship}}
\hadithdefcmd{muslim}{1187}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالَ حَرْمَلَةُ أَخْبَرَنَا وَقَالَ، هَارُونُ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ عَائِشَةَ، وَعَبْدَ اللَّهِ بْنَ عَبَّاسٍ، قَالاَ لَمَّا نَزَلَتْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم طَفِقَ يَطْرَحُ خَمِيصَةً لَهُ عَلَى وَجْهِهِ فَإِذَا اغْتَمَّ كَشَفَهَا عَنْ وَجْهِهِ فَقَالَ وَهُوَ كَذَلِكَ ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الْيَهُودِ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏ يُحَذِّرُ مِثْلَ مَا صَنَعُوا ‏.‏\hadithno{1187}\hadithtrans{A'isha and Abdullah reported:As the Messenger of Allah (ﷺ) was about to breathe his last, he drew his sheet upon his face and when he felt uneasy, he uncovered his face and said in that very state: Let there be curse upon the Jews and the Christians that they have taken the graves of their apostles as places of worship. He in fact warned (his men) against what they (the Jews and the Christians) did}}
\hadithdefcmd{muslim}{1188}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ أَبُو بَكْرٍ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ النَّجْرَانِيِّ، قَالَ حَدَّثَنِي جُنْدَبٌ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم قَبْلَ أَنْ يَمُوتَ بِخَمْسٍ وَهُوَ يَقُولُ ‏ "‏ إِنِّي أَبْرَأُ إِلَى اللَّهِ أَنْ يَكُونَ لِي مِنْكُمْ خَلِيلٌ فَإِنَّ اللَّهَ تَعَالَى قَدِ اتَّخَذَنِي خَلِيلاً كَمَا اتَّخَذَ إِبْرَاهِيمَ خَلِيلاً وَلَوْ كُنْتُ مُتَّخِذًا مِنْ أُمَّتِي خَلِيلاً لاَتَّخَذْتُ أَبَا بَكْرٍ خَلِيلاً أَلاَ وَإِنَّ مَنْ كَانَ قَبْلَكُمْ كَانُوا يَتَّخِذُونَ قُبُورَ أَنْبِيَائِهِمْ وَصَالِحِيهِمْ مَسَاجِدَ أَلاَ فَلاَ تَتَّخِذُوا الْقُبُورَ مَسَاجِدَ إِنِّي أَنْهَاكُمْ عَنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{1188}\hadithtrans{Jundub reported:I heard from the Messenger of Allah (ﷺ) five days before his death and he said: I stand acquitted before Allah that I took any one of you as friend, for Allah has taken me as His friend, as he took Ibrahim as His friend. Had I taken any one of my Ummah as a friend, I would have taken Abu Bakr as a friend. Beware of those who preceded you and used to take the graves of their prophets and righteous men as places of worship, but you must not take graves as mosques; I forbid you to do that}}
\hadithdefcmd{muslim}{1189}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ بُكَيْرًا، حَدَّثَهُ أَنَّ عَاصِمَ بْنَ عُمَرَ بْنِ قَتَادَةَ حَدَّثَهُ أَنَّهُ، سَمِعَ عُبَيْدَ اللَّهِ الْخَوْلاَنِيَّ، يَذْكُرُ أَنَّهُ سَمِعَ عُثْمَانَ بْنَ عَفَّانَ، عِنْدَ قَوْلِ النَّاسِ فِيهِ حِينَ بَنَى مَسْجِدَ الرَّسُولِ صلى الله عليه وسلم ‏.‏ إِنَّكُمْ قَدْ أَكْثَرْتُمْ وَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ بَنَى مَسْجِدًا لِلَّهِ تَعَالَى - قَالَ بُكَيْرٌ حَسِبْتُ أَنَّهُ قَالَ - يَبْتَغِي بِهِ وَجْهَ اللَّهِ - بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏ وَقَالَ ابْنُ عِيسَى فِي رِوَايَتِهِ ‏"‏ مِثْلَهُ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1189}\hadithtrans{Ubaidullah al-Khaulini reported:'Uthman b. 'Affan listened to the opinion of the people (which was not favourable) when he rebuilt the mosque of the Messenger of Allah (ﷺ). Thereupon he said: You have not been fair to me for I have heard from the Messenger of Allah (ﷺ) saying: He who built a mosque for Allah, the Exalted, Allah would build for him a house in Paradise. Bukair said: I think he (the Holy Prophet) said: While he seeks the pleasure of Allah (by building the mosque). And in the narration of Ibn 'Isa (the words are):" (a house) like that (mosque) in Paradise}}
\hadithdefcmd{muslim}{1190}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنِي أَبِي، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، أَرَادَ بِنَاءَ الْمَسْجِدِ فَكَرِهَ النَّاسُ ذَلِكَ فَأَحَبُّوا أَنْ يَدَعَهُ عَلَى هَيْئَتِهِ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ بَنَى مَسْجِدًا لِلَّهِ بَنَى اللَّهُ لَهُ فِي الْجَنَّةِ مِثْلَهُ ‏"‏ ‏.‏\hadithno{1190}\hadithtrans{Mahmud b. Labid reported:When 'Uthman b. 'Affan intended to build the mosque (of the Prophet) the people did not approve of it. They liked that it should be kept in the same state. Thereupon he said: I heard the Messenger of Allah (ﷺ) say: He who built a mosque for Allah, Allah would build a house for him like it in Paradise}}
\hadithdefcmd{muslim}{1191}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، وَعَلْقَمَةَ، قَالاَ أَتَيْنَا عَبْدَ اللَّهِ بْنَ مَسْعُودٍ فِي دَارِهِ فَقَالَ أَصَلَّى هَؤُلاَءِ خَلْفَكُمْ فَقُلْنَا لاَ ‏.‏ قَالَ فَقُومُوا فَصَلُّوا ‏.‏ فَلَمْ يَأْمُرْنَا بِأَذَانٍ وَلاَ إِقَامَةٍ - قَالَ - وَذَهَبْنَا لِنَقُومَ خَلْفَهُ فَأَخَذَ بِأَيْدِينَا فَجَعَلَ أَحَدَنَا عَنْ يَمِينِهِ وَالآخَرَ عَنْ شِمَالِهِ - قَالَ - فَلَمَّا رَكَعَ وَضَعْنَا أَيْدِيَنَا عَلَى رُكَبِنَا - قَالَ - فَضَرَبَ أَيْدِيَنَا وَطَبَّقَ بَيْنَ كَفَّيْهِ ثُمَّ أَدْخَلَهُمَا بَيْنَ فَخِذَيْهِ - قَالَ - فَلَمَّا صَلَّى قَالَ إِنَّهُ سَتَكُونُ عَلَيْكُمْ أُمَرَاءُ يُؤَخِّرُونَ الصَّلاَةَ عَنْ مِيقَاتِهَا وَيَخْنُقُونَهَا إِلَى شَرَقِ الْمَوْتَى فَإِذَا رَأَيْتُمُوهُمْ قَدْ فَعَلُوا ذَلِكَ فَصَلُّوا الصَّلاَةَ لِمِيقَاتِهَا وَاجْعَلُوا صَلاَتَكُمْ مَعَهُمْ سُبْحَةً وَإِذَا كُنْتُمْ ثَلاَثَةً فَصَلُّوا جَمِيعًا وَإِذَا كُنْتُمْ أَكْثَرَ مِنْ ذَلِكَ فَلْيَؤُمَّكُمْ أَحَدُكُمْ وَإِذَا رَكَعَ أَحَدُكُمْ فَلْيَفْرِشْ ذِرَاعَيْهِ عَلَى فَخِذَيْهِ وَلْيَجْنَأْ وَلْيُطَبِّقْ بَيْنَ كَفَّيْهِ فَلَكَأَنِّي أَنْظُرُ إِلَى اخْتِلاَفِ أَصَابِعِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَرَاهُمْ ‏.‏\hadithno{1191}\hadithtrans{Al-Aswad and 'Alqama reported:We came to the house of 'Abdullah b. Mas'ud. He said: Have these people said prayer behind you? We said: No. He said: Then stand up and say prayer. He neither ordered us to say Adhan nor Iqama. We went to stand behind him. He caught hold of our hands and mode one of us stand on his right hand and the other on his left side. When we bowed, we placed our hands on our knees. He struck our hands and put his hands together, palm to palm, then put them between his thighs. When he completed the prayer he said. There would soon come your Amirs, who would defer prayers from their appointed time and would make such delay that a little time is left before sunset. So when you see them doing so, say prayer at its appointed time and then say prayer along with them as (Nafl), and when you are three, pray together (standing in one row), and when you are more than three, appoint one amongst you as your Imam. And when any one of you bows he must place his hands upon hie thighs and kneel down. and putting his palms together place (them within his thighs). I perceive as if I am seeing the gap between the fingers of the Messenger of Allah (may peace he upon him)}}
\hadithdefcmd{muslim}{1192}{وَحَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، أَخْبَرَنَا ابْنُ مُسْهِرٍ، ح قَالَ وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح قَالَ وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا مُفَضَّلٌ، كُلُّهُمْ عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، أَنَّهُمَا دَخَلاَ عَلَى عَبْدِ اللَّهِ ‏.‏ بِمَعْنَى حَدِيثِ أَبِي مُعَاوِيَةَ ‏.‏ وَفِي حَدِيثِ ابْنِ مُسْهِرٍ وَجَرِيرٍ فَلَكَأَنِّي أَنْظُرُ إِلَى اخْتِلاَفِ أَصَابِعِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ رَاكِعٌ ‏.‏\hadithno{1192}\hadithtrans{This hadith is narrated on the authority of Alqama and Aswad by another chain of transmitters and in the hadith transmitted by Ibn Mus-hir and Jabir the words are:" I perceive as if I am seeing the gap between the fingers of the Messenger of Allah (ﷺ) as he was bowing}}
\hadithdefcmd{muslim}{1193}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، أَنَّهُمَا دَخَلاَ عَلَى عَبْدِ اللَّهِ فَقَالَ أَصَلَّى مَنْ خَلْفَكُمْ قَالاَ نَعَمْ ‏.‏ فَقَامَ بَيْنَهُمَا وَجَعَلَ أَحَدَهُمَا عَنْ يَمِينِهِ وَالآخَرَ عَنْ شِمَالِهِ ثُمَّ رَكَعْنَا فَوَضَعْنَا أَيْدِيَنَا عَلَى رُكَبِنَا فَضَرَبَ أَيْدِيَنَا ثُمَّ طَبَّقَ بَيْنَ يَدَيْهِ ثُمَّ جَعَلَهُمَا بَيْنَ فَخِذَيْهِ فَلَمَّا صَلَّى قَالَ هَكَذَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1193}\hadithtrans{Alqama and Aswad reported that they went to 'Abdullah. He said:Have (people) behind you said prayer? They said: Yes. He stood between them ('Alqama and Aswad). One was on his right aide and the other was on his left. We then bowed and placed our hands on our knees. He struck our hands and then putting his hands together, palm to palm, placed them between his thighs. When he completed the prayer he said: This is how the Messenger of Allah (ﷺ) used to do}}
\hadithdefcmd{muslim}{1194}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ - وَاللَّفْظُ لِقُتَيْبَةَ - قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي يَعْفُورٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، قَالَ صَلَّيْتُ إِلَى جَنْبِ أَبِي قَالَ وَجَعَلْتُ يَدَىَّ بَيْنَ رُكْبَتَىَّ فَقَالَ لِي أَبِي اضْرِبْ بِكَفَّيْكَ عَلَى رُكْبَتَيْكَ ‏.‏ قَالَ ثُمَّ فَعَلْتُ ذَلِكَ مَرَّةً أُخْرَى فَضَرَبَ يَدَىَّ وَقَالَ إِنَّا نُهِينَا عَنْ هَذَا وَأُمِرْنَا أَنْ نَضْرِبَ بِالأَكُفِّ عَلَى الرُّكَبِ ‏.‏\hadithno{1194}\hadithtrans{Mus'ab b. Sa'd reported:I said prayer by the side of my father and placed my hands between my knees. My father said to me: Place your hands on your knees. I repeated that (the previous act) for the second time, and he struck at my hands and said: We have been forbidden to do so and have been commanded to place our palms on the knees}}
\hadithdefcmd{muslim}{1195}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، ح قَالَ وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ أَبِي يَعْفُورٍ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ فَنُهِينَا عَنْهُ ‏.‏ وَلَمْ يَذْكُرَا مَا بَعْدَهُ ‏.‏\hadithno{1195}\hadithtrans{This hadith has been narrated by Abu Ya'fur with the same chain of transmitters up to these words:We have been forbidden from it and no mention of that has been made what follows it}}
\hadithdefcmd{muslim}{1196}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، قَالَ رَكَعْتُ فَقُلْتُ بِيَدَىَّ هَكَذَا - يَعْنِي طَبَّقَ بِهِمَا وَوَضَعَهُمَا بَيْنَ فَخِذَيْهِ - فَقَالَ أَبِي قَدْ كُنَّا نَفْعَلُ هَذَا ثُمَّ أُمِرْنَا بِالرُّكَبِ ‏.‏\hadithno{1196}\hadithtrans{Ibn Sa'd reported:I bowed and my hands were in this state, i. e. they were put together, palm to palm, and were placed between his thighs. My father said: We used to do like this but were later on commanded to place them on the knees}}
\hadithdefcmd{muslim}{1197}{حَدَّثَنِي الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنِ مُصْعَبِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ صَلَّيْتُ إِلَى جَنْبِ أَبِي فَلَمَّا رَكَعْتُ شَبَّكْتُ أَصَابِعِي وَجَعَلْتُهُمَا بَيْنَ رُكْبَتَىَّ فَضَرَبَ يَدَىَّ فَلَمَّا صَلَّى قَالَ قَدْ كُنَّا نَفْعَلُ هَذَا ثُمَّ أُمِرْنَا أَنْ نَرْفَعَ إِلَى الرُّكَبِ ‏.‏\hadithno{1197}\hadithtrans{Mus'ab b. Sa'd b. Abu Waqqas reported:I said prayer by the side of my father. When I bowed I intertwined my fingers and placed them between my knees. He struck my hands. When he completed the prayer he said: We used to do that but then were commanded to lift (our palms) to the knees}}
\hadithdefcmd{muslim}{1198}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، ح قَالَ وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ جَمِيعًا أَخْبَرَنَا ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ أَنَّهُ سَمِعَ طَاوُسًا يَقُولُ قُلْنَا لاِبْنِ عَبَّاسٍ فِي الإِقْعَاءِ عَلَى الْقَدَمَيْنِ فَقَالَ هِيَ السُّنَّةُ ‏.‏ فَقُلْنَا لَهُ إِنَّا لَنَرَاهُ جَفَاءً بِالرَّجُلِ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ بَلْ هِيَ سُنَّةُ نَبِيِّكَ صلى الله عليه وسلم ‏.‏\hadithno{1198}\hadithtrans{Tawus reported:We asked Ibn Abbas about sitting on one's buttocks (in prayer). (ala alqad mein) He said: It is sunnah. We said to him: We find it a sort of cruelty to the foot. Ibn 'Abbas said: It is the sunnah of your Apostle (ﷺ)}}
\hadithdefcmd{muslim}{1199}{حَدَّثَنَا أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الصَّبَّاحِ وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَتَقَارَبَا فِي لَفْظِ الْحَدِيثِ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ حَجَّاجٍ الصَّوَّافِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ مُعَاوِيَةَ بْنِ الْحَكَمِ السُّلَمِيِّ، قَالَ بَيْنَا أَنَا أُصَلِّي، مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ عَطَسَ رَجُلٌ مِنَ الْقَوْمِ فَقُلْتُ يَرْحَمُكَ اللَّهُ ‏.‏ فَرَمَانِي الْقَوْمُ بِأَبْصَارِهِمْ فَقُلْتُ وَاثُكْلَ أُمِّيَاهْ مَا شَأْنُكُمْ تَنْظُرُونَ إِلَىَّ ‏.‏ فَجَعَلُوا يَضْرِبُونَ بِأَيْدِيهِمْ عَلَى أَفْخَاذِهِمْ فَلَمَّا رَأَيْتُهُمْ يُصَمِّتُونَنِي لَكِنِّي سَكَتُّ فَلَمَّا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَبِأَبِي هُوَ وَأُمِّي مَا رَأَيْتُ مُعَلِّمًا قَبْلَهُ وَلاَ بَعْدَهُ أَحْسَنَ تَعْلِيمًا مِنْهُ فَوَاللَّهِ مَا كَهَرَنِي وَلاَ ضَرَبَنِي وَلاَ شَتَمَنِي قَالَ ‏"‏ إِنَّ هَذِهِ الصَّلاَةَ لاَ يَصْلُحُ فِيهَا شَىْءٌ مِنْ كَلاَمِ النَّاسِ إِنَّمَا هُوَ التَّسْبِيحُ وَالتَّكْبِيرُ وَقِرَاءَةُ الْقُرْآنِ ‏"‏ ‏.‏ أَوْ كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي حَدِيثُ عَهْدٍ بِجَاهِلِيَّةٍ وَقَدْ جَاءَ اللَّهُ بِالإِسْلاَمِ وَإِنَّ مِنَّا رِجَالاً يَأْتُونَ الْكُهَّانَ ‏.‏ قَالَ ‏"‏ فَلاَ تَأْتِهِمْ ‏"‏ ‏.‏ قَالَ وَمِنَّا رِجَالٌ يَتَطَيَّرُونَ ‏.‏ قَالَ ‏"‏ ذَاكَ شَىْءٌ يَجِدُونَهُ فِي صُدُورِهِمْ فَلاَ يَصُدَّنَّهُمْ ‏"‏ ‏.‏ قَالَ ابْنُ الصَّبَّاحِ ‏"‏ فَلاَ يَصُدَّنَّكُمْ ‏"‏ ‏.‏ قَالَ قُلْتُ وَمِنَّا رِجَالٌ يَخُطُّونَ ‏.‏ قَالَ ‏"‏ كَانَ نَبِيٌّ مِنَ الأَنْبِيَاءِ يَخُطُّ فَمَنْ وَافَقَ خَطَّهُ فَذَاكَ ‏"‏ ‏.‏ قَالَ وَكَانَتْ لِي جَارِيَةٌ تَرْعَى غَنَمًا لِي قِبَلَ أُحُدٍ وَالْجَوَّانِيَّةِ فَاطَّلَعْتُ ذَاتَ يَوْمٍ فَإِذَا الذِّيبُ قَدْ ذَهَبَ بِشَاةٍ مِنْ غَنَمِهَا وَأَنَا رَجُلٌ مِنْ بَنِي آدَمَ آسَفُ كَمَا يَأْسَفُونَ لَكِنِّي صَكَكْتُهَا صَكَّةً فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَظَّمَ ذَلِكَ عَلَىَّ قُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ أُعْتِقُهَا قَالَ ‏"‏ ائْتِنِي بِهَا ‏"‏ ‏.‏ فَأَتَيْتُهُ بِهَا فَقَالَ لَهَا ‏"‏ أَيْنَ اللَّهُ ‏"‏ ‏.‏ قَالَتْ فِي السَّمَاءِ ‏.‏ قَالَ ‏"‏ مَنْ أَنَا ‏"‏ ‏.‏ قَالَتْ أَنْتَ رَسُولُ اللَّهِ ‏.‏ قَالَ ‏"‏ أَعْتِقْهَا فَإِنَّهَا مُؤْمِنَةٌ ‏"‏ ‏.‏\hadithno{1199}\hadithtrans{Mu'awiya b. al-Hakam said:While I was praying with the Messenger of Allah (ﷺ), a man in the company sneezed. I said: Allah have mercy on you! The people stared at me with disapproving looks, so I said: Woe be upon me, why is it that you stare at me? They began to strike their hands on their thighs, and when I saw them urging me to observe silence (I became angry) but I said nothing. When the Messenger of Allah (ﷺ) had said the prayer (and I declare that neither before him nor after him have I seen a leader who gave better instruction than he for whom I would give my father and mother as ransom). I swear that he did not scold, beat or revile me but said: Talking to persons is not fitting during the prayer, for it consists of glorifying Allah, declaring his Greatness. and recitation of the Qur'an or words to that effect. I said: Messenger of Allah. I was till recently a pagan, but Allah has brought Islam to us; among us there are men who have recourse to Kahins. He said, Do not have recourse to them. I said. There are men who take omens. That is something which they find in their breasts, but let it not turn their way (from freedom of action). I said: Among us there are men who draw lines. He said: There was a prophet who drew lines, so if they do it as they did, that is allowable. I had a maid-servant who tended goats by the side of Uhud and Jawwaniya. One day I happened to pass that way and found that a wolf had carried a goat from her flock. I am after all a man from the posterity of Adam. I felt sorry as they (human beings) feel sorry. So I slapped her. I came to the Messenger of Allah (ﷺ) and felt (this act of mine) as something grievous I said: Messenger of Allah, should I not grant her freedom? He (the Holy Prophet) said: Bring her to me. So I brought her to him. He said to her: Where is Allah? She said: He is in the heaven. He said: Who am I? She said: Thou art the Messenger of Allah. He said: Grant her freedom, she is a believing woman}}
\hadithdefcmd{muslim}{1200}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{1200}\hadithtrans{This hadith has been narrated by Yahya b. Abu Kathir with the same chain of transmitters}}
\hadithdefcmd{muslim}{1201}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ وَأَبُو سَعِيدٍ الأَشَجُّ - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالُوا حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا نُسَلِّمُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي الصَّلاَةِ فَيَرُدُّ عَلَيْنَا فَلَمَّا رَجَعْنَا مِنْ عِنْدِ النَّجَاشِي سَلَّمْنَا عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْنَا فَقُلْنَا يَا رَسُولَ اللَّهِ كُنَّا نُسَلِّمُ عَلَيْكَ فِي الصَّلاَةِ فَتَرُدُّ عَلَيْنَا ‏.‏ فَقَالَ ‏ "‏ إِنَّ فِي الصَّلاَةِ شُغُلاً ‏"‏ ‏.‏\hadithno{1201}\hadithtrans{Abdullah (b. Masu'd) reported:We used to greet the Messenger of Allah (ﷺ) while he was engaged in prayer and he would respond to our greeting. But when we returned from the Negus we greeted him and he did not respond to us; so we said: Messenger of Allah. we used to greet you when you were engaged in prayer and you would respond to us. He replied: Prayer demands whole attention}}
\hadithdefcmd{muslim}{1202}{حَدَّثَنِي ابْنُ نُمَيْرٍ، حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ السَّلُولِيُّ، حَدَّثَنَا هُرَيْمُ بْنُ سُفْيَانَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏\hadithno{1202}\hadithtrans{This hadith has been reported by A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{1203}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ الْحَارِثِ بْنِ شُبَيْلٍ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ كُنَّا نَتَكَلَّمُ فِي الصَّلاَةِ يُكَلِّمُ الرَّجُلُ صَاحِبَهُ وَهُوَ إِلَى جَنْبِهِ فِي الصَّلاَةِ حَتَّى نَزَلَتْ ‏\{‏ وَقُومُوا لِلَّهِ قَانِتِينَ‏\}‏ فَأُمِرْنَا بِالسُّكُوتِ وَنُهِينَا عَنِ الْكَلاَمِ ‏.‏\hadithno{1203}\hadithtrans{Zaid b. Arqam reported:We used to talk while engaged in prayer and a person talked with a companion on his side in prayer till (this verse) was revealed:" And stand before Allah in devout obedience" (ii, 238) and we were commanded to observe silence (in prayer) and were forbidden to speak}}
\hadithdefcmd{muslim}{1204}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَوَكِيعٌ، ح قَالَ وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{1204}\hadithtrans{A hadith like this has been transmitted by Isma'il b. Abu Khalid}}
\hadithdefcmd{muslim}{1205}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَنِي لِحَاجَةٍ ثُمَّ أَدْرَكْتُهُ وَهُوَ يَسِيرُ - قَالَ قُتَيْبَةُ يُصَلِّي - فَسَلَّمْتُ عَلَيْهِ فَأَشَارَ إِلَىَّ فَلَمَّا فَرَغَ دَعَانِي فَقَالَ ‏ "‏ إِنَّكَ سَلَّمْتَ آنِفًا وَأَنَا أُصَلِّي ‏"‏ ‏.‏ وَهُوَ مُوَجِّهٌ حِينَئِذٍ قِبَلَ الْمَشْرِقِ ‏.‏\hadithno{1205}\hadithtrans{Jabir reported:The Messenger of Allah (ﷺ) sent me on an errand. I (having done the business assigned to me came back and) joined him as he was going (on a ride). Qutaiba said that he was saying prayer while he rode. I greeted him. He gestured to me. When he completed the prayer. he called me and said: You greeted me just now while I was engaged in prayer. (Qutaiba said): His (Prophet's face) was towards the east, as he was praying}}
\hadithdefcmd{muslim}{1206}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَرْسَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ مُنْطَلِقٌ إِلَى بَنِي الْمُصْطَلِقِ فَأَتَيْتُهُ وَهُوَ يُصَلِّي عَلَى بَعِيرِهِ فَكَلَّمْتُهُ فَقَالَ لِي بِيَدِهِ هَكَذَا - وَأَوْمَأَ زُهَيْرٌ بِيَدِهِ - ثُمَّ كَلَّمْتُهُ فَقَالَ لِي هَكَذَا - فَأَوْمَأَ زُهَيْرٌ أَيْضًا بِيَدِهِ نَحْوَ الأَرْضِ - وَأَنَا أَسْمَعُهُ يَقْرَأُ يُومِئُ بِرَأْسِهِ فَلَمَّا فَرَغَ قَالَ ‏ "‏ مَا فَعَلْتَ فِي الَّذِي أَرْسَلْتُكَ لَهُ فَإِنَّهُ لَمْ يَمْنَعْنِي أَنْ أُكَلِّمَكَ إِلاَّ أَنِّي كُنْتُ أُصَلِّي ‏"‏ ‏.‏ قَالَ زُهَيْرٌ وَأَبُو الزُّبَيْرِ جَالِسٌ مُسْتَقْبِلَ الْكَعْبَةِ فَقَالَ بِيَدِهِ أَبُو الزُّبَيْرِ إِلَى بَنِي الْمُصْطَلِقِ فَقَالَ بِيَدِهِ إِلَى غَيْرِ الْكَعْبَةِ ‏.‏\hadithno{1206}\hadithtrans{Jabir reported:The Messenger of Allah (ﷺ) sent me (on an errand) while he was going to Banu Mustaliq. I came to him and he was engaged in prayer on the back of his camel. I talked to him and he gestured to me With his hand, and Zuhair gestured with his hand. I then again talked and he again (gestured to me with his hand). Zuhair pointed with his hand towards the ground. I heard him (the Holy Prophet) reciting the Qur'an and making a sign with his head. When he com- pleted the prayer he sa'id: What have you done (with regard to that business) for which I sent you? I could not talk with you but for the fact that I was engaged in prayer. Zuhair told that Abu Zubair was sitting with his face turned towards Qibla (as he transmitted this hadith). Abu Zuhair pointed towards Banu Mustaliq with his hand and the direction to which he pointed with his hand was not towards the Ka'ba}}
\hadithdefcmd{muslim}{1207}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ كَثِيرٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فَبَعَثَنِي فِي حَاجَةٍ فَرَجَعْتُ وَهُوَ يُصَلِّي عَلَى رَاحِلَتِهِ وَوَجْهُهُ عَلَى غَيْرِ الْقِبْلَةِ فَسَلَّمْتُ عَلَيْهِ فَلَمْ يَرُدَّ عَلَىَّ فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّهُ لَمْ يَمْنَعْنِي أَنْ أَرُدَّ عَلَيْكَ إِلاَّ أَنِّي كُنْتُ أُصَلِّي ‏"‏ ‏.‏\hadithno{1207}\hadithtrans{Jabir reported:We were in the company of the Messenger of Allah (ﷺ), and he sent me on an errand, and when I came back (I saw him) saying prayer on his ride and his face was not turned towards Qibla. I greeted him but he did not respond to me. As he completed the prayer, he said: Nothing prevented me from responding to your greeting but the fact that I was praying}}
\hadithdefcmd{muslim}{1208}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا كَثِيرُ بْنُ شِنْظِيرٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَاجَةٍ ‏.‏ بِمَعْنَى حَدِيثِ حَمَّادٍ ‏.‏\hadithno{1208}\hadithtrans{This hadith that the Messenger of Allah (ﷺ) sent Jabir on an errand has been reported by him through another chain of transmitters}}
\hadithdefcmd{muslim}{1209}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ زِيَادٍ - قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ عِفْرِيتًا مِنَ الْجِنِّ جَعَلَ يَفْتِكُ عَلَىَّ الْبَارِحَةَ لِيَقْطَعَ عَلَىَّ الصَّلاَةَ وَإِنَّ اللَّهَ أَمْكَنَنِي مِنْهُ فَذَعَتُّهُ فَلَقَدْ هَمَمْتُ أَنْ أَرْبِطَهُ إِلَى جَنْبِ سَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ حَتَّى تُصْبِحُوا تَنْظُرُونَ إِلَيْهِ أَجْمَعُونَ - أَوْ كُلُّكُمْ - ثُمَّ ذَكَرْتُ قَوْلَ أَخِي سُلَيْمَانَ رَبِّ اغْفِرْ لِي وَهَبْ لِي مُلْكًا لاَ يَنْبَغِي لأَحَدٍ مِنْ بَعْدِي ‏.‏ فَرَدَّهُ اللَّهُ خَاسِئًا ‏"‏ ‏.‏ وَقَالَ ابْنُ مَنْصُورٍ شُعْبَةُ عَنْ مُحَمَّدِ بْنِ زِيَادٍ ‏.‏\hadithno{1209}\hadithtrans{Abu Huraira reported that he heard the Messenger of Allah (ﷺ) saying:A highly wicked one amongst the Jinn escaped yesternight to interrupt my prayer, but Allah gave me power over him, so I seized him and intended to tie him to one of the pillars of the mosque in order that you, all together or all, might look at him, but I remembered the supplication of my brother Sulaiman:" My Lord, forgive me, give me such a kingdom as will not be possible for anyone after me" (Qur'an, xxxvii)}}
\hadithdefcmd{muslim}{1210}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، هُوَ ابْنُ جَعْفَرٍ ح قَالَ وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، كِلاَهُمَا عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ وَلَيْسَ فِي حَدِيثِ ابْنِ جَعْفَرٍ قَوْلُهُ فَذَعَتُّهُ ‏.‏ وَأَمَّا ابْنُ أَبِي شَيْبَةَ فَقَالَ فِي رِوَايَتِهِ فَدَعَتُّهُ ‏.‏\hadithno{1210}\hadithtrans{This hadith has been transmitted by Ibn Abi Shaiba}}
\hadithdefcmd{muslim}{1211}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، يَقُولُ حَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَمِعْنَاهُ يَقُولُ ‏"‏ أَعُوذُ بِاللَّهِ مِنْكَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلْعَنُكَ بِلَعْنَةِ اللَّهِ ‏"‏ ‏.‏ ثَلاَثًا ‏.‏ وَبَسَطَ يَدَهُ كَأَنَّهُ يَتَنَاوَلُ شَيْئًا فَلَمَّا فَرَغَ مِنَ الصَّلاَةِ قُلْنَا يَا رَسُولَ اللَّهِ قَدْ سَمِعْنَاكَ تَقُولُ فِي الصَّلاَةِ شَيْئًا لَمْ نَسْمَعْكَ تَقُولُهُ قَبْلَ ذَلِكَ وَرَأَيْنَاكَ بَسَطْتَ يَدَكَ ‏.‏ قَالَ ‏"‏ إِنَّ عَدُوَّ اللَّهِ إِبْلِيسَ جَاءَ بِشِهَابٍ مِنْ نَارٍ لِيَجْعَلَهُ فِي وَجْهِي فَقُلْتُ أَعُوذُ بِاللَّهِ مِنْكَ ‏.‏ ثَلاَثَ مَرَّاتٍ ثُمَّ قُلْتُ أَلْعَنُكَ بِلَعْنَةِ اللَّهِ التَّامَّةِ فَلَمْ يَسْتَأْخِرْ ثَلاَثَ مَرَّاتٍ ثُمَّ أَرَدْتُ أَخْذَهُ وَاللَّهِ لَوْلاَ دَعْوَةُ أَخِينَا سُلَيْمَانَ لأَصْبَحَ مُوثَقًا يَلْعَبُ بِهِ وِلْدَانُ أَهْلِ الْمَدِينَةِ ‏"‏ ‏.‏\hadithno{1211}\hadithtrans{Abu Darda' reported:Allah's Messenger (ﷺ) stood up (to pray) and we heard him say:" I seek refuge in Allah from thee." Then said:" curse thee with Allah's curse" three times, then he stretched out his hand as though he was taking hold of something. When he finished the prayer, we said: Messenger of Allah, we heard you say something during the prayer which we have not heard you say before, and we saw you stretch out your hand. He replied: Allah's enemy Iblis came with a flame of fire to put it in my face, so I said three times:" I Seek refuge in Allah from thee." Then I said three times:" I curse thee with Allah's full curse." But he did not retreat (on any one of these) three occasions. Thereafter I meant to seize him. I swear by Allah that had it not been for the supplication of my brother Sulaiman he would have been bound, and made an object of sport for the children of Medina}}
\hadithdefcmd{muslim}{1212}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا مَالِكٌ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قُلْتُ لِمَالِكٍ حَدَّثَكَ عَامِرُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي وَهُوَ حَامِلٌ أُمَامَةَ بِنْتَ زَيْنَبَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلأَبِي الْعَاصِ بْنِ الرَّبِيعِ فَإِذَا قَامَ حَمَلَهَا وَإِذَا سَجَدَ وَضَعَهَا قَالَ يَحْيَى قَالَ مَالِكٌ نَعَمْ ‏.‏\hadithno{1212}\hadithtrans{Abu Qatadi reported:I saw the Messenger of Allah (ﷺ) saying the prayer while he was carrying Umama, daughter of Zainab, daughter of the Messenger of Allah (ﷺ). and Abu'l-'As b. al-Rabi'. When he stood up, he took her up and when he prostrated he put her down, Yahya said: Malik replied in the affirmative}}
\hadithdefcmd{muslim}{1213}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عُثْمَانَ بْنِ أَبِي سُلَيْمَانَ، وَابْنِ، عَجْلاَنَ سَمِعَا عَامِرَ بْنَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، يُحَدِّثُ عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَؤُمُّ النَّاسَ وَأُمَامَةُ بِنْتُ أَبِي الْعَاصِ وَهْىَ ابْنَةُ زَيْنَبَ بِنْتِ النَّبِيِّ صلى الله عليه وسلم عَلَى عَاتِقِهِ فَإِذَا رَكَعَ وَضَعَهَا وَإِذَا رَفَعَ مِنَ السُّجُودِ أَعَادَهَا ‏.‏\hadithno{1213}\hadithtrans{Abu Qatada al-Ansari reported:I saw the Apostle (ﷺ) leading the people in prayer with Umima, daughter of Abu'l-'As and Zainab, daughter of the Messenger of Allah (ﷺ), on his shoulder. When he bowed, he put her down, and when he got up after prostration, he lifted her again}}
\hadithdefcmd{muslim}{1214}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ مَخْرَمَةَ بْنِ بُكَيْرٍ، ح قَالَ وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، قَالَ سَمِعْتُ أَبَا قَتَادَةَ الأَنْصَارِيَّ، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي لِلنَّاسِ وَأُمَامَةُ بِنْتُ أَبِي الْعَاصِ عَلَى عُنُقِهِ فَإِذَا سَجَدَ وَضَعَهَا ‏.‏\hadithno{1214}\hadithtrans{Abu Qatada reported:I saw the Messenger of Allah (ﷺ) leading the people in prayer with Umama daughter of Abu'l-'As on his neck; and when he prostrated he put her down}}
\hadithdefcmd{muslim}{1215}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، جَمِيعًا عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، سَمِعَ أَبَا قَتَادَةَ، يَقُولُ بَيْنَا نَحْنُ فِي الْمَسْجِدِ جُلُوسٌ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِنَحْوِ حَدِيثِهِمْ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ أَنَّهُ أَمَّ النَّاسَ فِي تِلْكَ الصَّلاَةِ ‏.‏\hadithno{1215}\hadithtrans{Abu Qatada reported:As we were sitting in the mosque, the Messenger of Allah (ﷺ) came to us, and the rest of the hadith is the same except that he made no mention that he led people in this prayer}}
\hadithdefcmd{muslim}{1216}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ عَبْدِ الْعَزِيزِ، قَالَ يَحْيَى أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، أَنَّ نَفَرًا، جَاءُوا إِلَى سَهْلِ بْنِ سَعْدٍ قَدْ تَمَارَوْا فِي الْمِنْبَرِ مِنْ أَىِّ عُودٍ هُوَ فَقَالَ أَمَا وَاللَّهِ إِنِّي لأَعْرِفُ مِنْ أَىِّ عُودٍ هُوَ وَمَنْ عَمِلَهُ وَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَوَّلَ يَوْمٍ جَلَسَ عَلَيْهِ - قَالَ - فَقُلْتُ لَهُ يَا أَبَا عَبَّاسٍ فَحَدِّثْنَا ‏.‏ قَالَ أَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى امْرَأَةٍ قَالَ أَبُو حَازِمٍ إِنَّهُ لَيُسَمِّيهَا يَوْمَئِذٍ ‏"‏ انْظُرِي غُلاَمَكِ النَّجَّارَ يَعْمَلْ لِي أَعْوَادًا أُكَلِّمُ النَّاسَ عَلَيْهَا ‏"‏ ‏.‏ فَعَمِلَ هَذِهِ الثَّلاَثَ دَرَجَاتٍ ثُمَّ أَمَرَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَوُضِعَتْ هَذَا الْمَوْضِعَ فَهْىَ مِنْ طَرْفَاءِ الْغَابَةِ ‏.‏ وَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ عَلَيْهِ فَكَبَّرَ وَكَبَّرَ النَّاسُ وَرَاءَهُ وَهُوَ عَلَى الْمِنْبَرِ ثُمَّ رَفَعَ فَنَزَلَ الْقَهْقَرَى حَتَّى سَجَدَ فِي أَصْلِ الْمِنْبَرِ ثُمَّ عَادَ حَتَّى فَرَغَ مِنْ آخِرِ صَلاَتِهِ ثُمَّ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ يَا أُيُّهَا النَّاسُ إِنِّي صَنَعْتُ هَذَا لِتَأْتَمُّوا بِي وَلِتَعَلَّمُوا صَلاَتِي ‏"‏ ‏.‏\hadithno{1216}\hadithtrans{Abu Hazim is reported on the authority of his father:Some people came to Sahl b. Sa'd and began to differ about the wood of which the (Prophet's pulpit was made. He (Sahl b. Sa'd) said: By Allah, I know of which wood it is made and who made it, and the day when I saw the Messenger of Allah (ﷺ) seated himself on it on the first day. I said to him: O Abu Abbas (kunyah of Sabl b. Sa'd), narrate to us (all these facts), He said: The Messenger of Allah (ﷺ) sent a person to a woman asking her to allow her slave, a carpenter, to work on woods (to prepare a pulpit) so that I should talk to the people (sitting on it). Abu Hazim said: He (Sahl b. Sa'd) pointed out the name of (that lady) that day. So he (the carpenter) made (a pulpit) with these three steps. Then the Messengerof Allah (ﷺ) commanded it to be placed here (where it is lying now). It was fashioned out of the wood of al-Ghaba. And I saw the Messenger of Allah (may peace he upon him) standing upon it and glorifying Allah and the people also glorified Allah after him, while he was on the pulpit. He then raised (his head from prostration) and stepped back (on his heels) till he prostrated himself at the base of pulpit, and then returned (to the former place and this movement of one or two steps continued) till the prayer was complete. He then turned towards the people and said: O people, I have done it so that you should follow me and learn (my mode of) prayer}}
\hadithdefcmd{muslim}{1217}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدٍ الْقَارِيُّ الْقُرَشِيُّ، حَدَّثَنِي أَبُو حَازِمٍ، أَنَّ رِجَالاً، أَتَوْا سَهْلَ بْنَ سَعْدٍ ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي حَازِمٍ، قَالَ أَتَوْا سَهْلَ بْنَ سَعْدٍ فَسَأَلُوهُ مِنْ أَىِّ شَىْءٍ مِنْبَرُ النَّبِيِّ صلى الله عليه وسلم وَسَاقُوا الْحَدِيثَ نَحْوَ حَدِيثِ ابْنِ أَبِي حَازِمٍ ‏.‏\hadithno{1217}\hadithtrans{Abu Hazim reported:They (the people) came to Sahl b. Sa'd and they asked him of what thing the pulpit of the Messenger of Allah (ﷺ) was made, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1218}{وَحَدَّثَنِي الْحَكَمُ بْنُ مُوسَى الْقَنْطَرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ، وَأَبُو أُسَامَةَ جَمِيعًا عَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ يُصَلِّيَ الرَّجُلُ مُخْتَصِرًا ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1218}\hadithtrans{Abu Huraira reported from the Messenger of Allah (ﷺ) that he forbade keeping one's hand on one's waist while praying, and in the narration of Abu Bakr (the words are):The Messenger of Allah (ﷺ) forbade to do so}}
\hadithdefcmd{muslim}{1219}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ مُعَيْقِيبٍ، قَالَ ذَكَرَ النَّبِيُّ صلى الله عليه وسلم الْمَسْحَ فِي الْمَسْجِدِ - يَعْنِي الْحَصَى - قَالَ ‏ "‏ إِنْ كُنْتَ لاَ بُدَّ فَاعِلاً فَوَاحِدَةً ‏"‏ ‏.‏\hadithno{1219}\hadithtrans{Mu'aiqib quoted the Messenger of Allah (ﷺ) mentioning the removal of pebbles from the ground where he prostrated himself. He (the Prophet) said:It you must do so, do it only once}}
\hadithdefcmd{muslim}{1223}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى بُصَاقًا فِي جِدَارِ الْقِبْلَةِ فَحَكَّهُ ثُمَّ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ يُصَلِّي فَلاَ يَبْصُقْ قِبَلَ وَجْهِهِ فَإِنَّ اللَّهَ قِبَلَ وَجْهِهِ إِذَا صَلَّى ‏"‏ ‏.‏\hadithno{1223}\hadithtrans{Abdullah b. Umar reported:The Messenger of Allah (ﷺ) saw spittle on the wall towards Qibla, and scratched it away and then turning to the people said: When any one of you prays, he must not spit in front of him, for Allah is in front of him when he is engaged in prayer}}
\hadithdefcmd{muslim}{1224}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي جَمِيعًا، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ رُمْحٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ ح وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ رَأَى نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ ‏.‏ إِلاَّ الضَّحَّاكَ فَإِنَّ فِي حَدِيثِهِ نُخَامَةً فِي الْقِبْلَةِ ‏.‏ بِمَعْنَى حَدِيثِ مَالِكٍ ‏.‏\hadithno{1224}\hadithtrans{Ibn Umar reported that the Messenger of Allah (ﷺ) saw sputum sticking to the Qibla wall of the mosque, the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1225}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ جَمِيعًا عَنْ سُفْيَانَ، - قَالَ يَحْيَى أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ فَحَكَّهَا بِحَصَاةٍ ثُمَّ نَهَى أَنْ يَبْزُقَ الرَّجُلُ عَنْ يَمِينِهِ أَوْ أَمَامَهُ وَلَكِنْ يَبْزُقُ عَنْ يَسَارِهِ أَوْ تَحْتَ قَدَمِهِ الْيُسْرَى ‏.‏\hadithno{1225}\hadithtrans{Abu Sa'id al-Khudri reported:The Apostle of Allah (ﷺ) saw sputum sticking to the Qibla of the mosque. He scratched it off with a pebble and then forbade spitting on the right side or in front, but (it is permissible) to spit on the left side or under the left foot}}
\hadithdefcmd{muslim}{1226}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، ح قَالَ وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي كِلاَهُمَا، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، وَأَبَا، سَعِيدٍ أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى نُخَامَةً ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{1226}\hadithtrans{Abu Huraira and Abu Sa'id narrated that the Messenger of Allah (ﷺ) saw sputum, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1227}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى بُصَاقًا فِي جِدَارِ الْقِبْلَةِ أَوْ مُخَاطًا أَوْ نُخَامَةً فَحَكَّهُ ‏.‏\hadithno{1227}\hadithtrans{A'isha reported:The Apostle of Allah (may, peace be upon him) saw spittle or snot or sputum, sticking to the wall towards Qibla and scratched it off}}
\hadithdefcmd{muslim}{1228}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، قَالَ زُهَيْرٌ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنِ الْقَاسِمِ بْنِ مِهْرَانَ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ فَأَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏ "‏ مَا بَالُ أَحَدِكُمْ يَقُومُ مُسْتَقْبِلَ رَبِّهِ فَيَتَنَخَّعُ أَمَامَهُ أَيُحِبُّ أَحَدُكُمْ أَنْ يُسْتَقْبَلَ فَيُتَنَخَّعَ فِي وَجْهِهِ فَإِذَا تَنَخَّعَ أَحَدُكُمْ فَلْيَتَنَخَّعْ عَنْ يَسَارِهِ تَحْتَ قَدَمِهِ فَإِنْ لَمْ يَجِدْ فَلْيَقُلْ هَكَذَا ‏"‏ ‏.‏ وَوَصَفَ الْقَاسِمُ فَتَفَلَ فِي ثَوْبِهِ ثُمَّ مَسَحَ بَعْضَهُ عَلَى بَعْضٍ ‏.‏\hadithno{1228}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) saw some sputum in the direction of the Qibla of the mosque. He turned towards people and said:How Is it that someone amongst you stands before his Lord and then spits out in front of Him? Does any one of you like that he should be made to stand in front of someone and then spit at his face? So when any one of you spits, he must spit on his left side under his foot. But if he does not find (space to spit) he should do like this. Qasim (one of the narrators) spat in his cloth and then folded it and rubbed it}}
\hadithdefcmd{muslim}{1229}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، ح قَالَ وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كُلُّهُمْ عَنِ الْقَاسِمِ بْنِ مِهْرَانَ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَ حَدِيثِ ابْنِ عُلَيَّةَ وَزَادَ فِي حَدِيثِ هُشَيْمٍ قَالَ أَبُو هُرَيْرَةَ كَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَرُدُّ ثَوْبَهُ بَعْضَهُ عَلَى بَعْضٍ ‏.‏\hadithno{1229}\hadithtrans{Abu Huraira reported:I perceive as if I am looking at the Messenger of Allah (ﷺ) folding up a part of his cloth with another one}}
\hadithdefcmd{muslim}{1230}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ أَحَدُكُمْ فِي الصَّلاَةِ فَإِنَّهُ يُنَاجِي رَبَّهُ فَلاَ يَبْزُقَنَّ بَيْنَ يَدَيْهِ وَلاَ عَنْ يَمِينِهِ وَلَكِنْ عَنْ شِمَالِهِ تَحْتَ قَدَمِهِ ‏"‏ ‏.‏\hadithno{1230}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) said: When any one of you is engaged in prayer, he is holding intimate conversation with his Lord, so none of you must spit in front of him, or towards his right side, but towards his left side under his foot}}
\hadithdefcmd{muslim}{1231}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ، قُتَيْبَةُ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبُزَاقُ فِي الْمَسْجِدِ خَطِيئَةٌ وَكَفَّارَتُهَا دَفْنُهَا ‏"‏ ‏.‏\hadithno{1231}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) said: Spitting in a mosque is a sin, and its expiation is that it should be buried}}
\hadithdefcmd{muslim}{1232}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، قَالَ سَأَلْتُ قَتَادَةَ عَنِ التَّفْلِ، فِي الْمَسْجِدِ فَقَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ التَّفْلُ فِي الْمَسْجِدِ خَطِيئَةٌ وَكَفَّارَتُهَا دَفْنُهَا ‏"‏ ‏.‏\hadithno{1232}\hadithtrans{Shu'ba reported:I asked Qatada about spitting, in the mosque. He said: I heard Anas b. Malik say: I heard the Messenger of Allah (ﷺ) say: Spitting in the mosque is a sin, and its expiation is that it should be buried}}
\hadithdefcmd{muslim}{1233}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، وَشَيْبَانُ بْنُ فَرُّوخَ، قَالاَ حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا وَاصِلٌ، مَوْلَى أَبِي عُيَيْنَةَ عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عُرِضَتْ عَلَىَّ أَعْمَالُ أُمَّتِي حَسَنُهَا وَسَيِّئُهَا فَوَجَدْتُ فِي مَحَاسِنِ أَعْمَالِهَا الأَذَى يُمَاطُ عَنِ الطَّرِيقِ وَوَجَدْتُ فِي مَسَاوِي أَعْمَالِهَا النُّخَاعَةَ تَكُونُ فِي الْمَسْجِدِ لاَ تُدْفَنُ ‏"‏ ‏.‏\hadithno{1233}\hadithtrans{Abu Dharr reported:The Apostle of Allah (ﷺ) said: The deeds of my people, good and bad, were presented before me, and I found the removal of something objectionable from the road among their good deeds, and the sputum mucus left unburied in the mosque among their evil deeds}}
\hadithdefcmd{muslim}{1234}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا كَهْمَسٌ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ أَبِيهِ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُهُ تَنَخَّعَ فَدَلَكَهَا بِنَعْلِهِ ‏.‏\hadithno{1234}\hadithtrans{Abdullah b. Shakhkhir reported on the authority of his father that he said:I said prayer with the Messenger of Allah (ﷺ) and saw him spitting and rubbing it off with his shoe}}
\hadithdefcmd{muslim}{1235}{وَحَدَّثَنِي يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الْعَلاَءِ، يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ عَنْ أَبِيهِ، أَنَّهُ صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم قَالَ فَتَنَخَّعَ فَدَلَكَهَا بِنَعْلِهِ الْيُسْرَى ‏.‏\hadithno{1235}\hadithtrans{Abdullah b. Shakhkhir narrated it on the authority of his father that he said prayer with the Messenger of Allah (ﷺ), and he spat and then rubbed it off with his left shoe}}
\hadithdefcmd{muslim}{1236}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ أَبِي مَسْلَمَةَ، سَعِيدِ بْنِ يَزِيدَ قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي النَّعْلَيْنِ قَالَ نَعَمْ ‏.‏\hadithno{1236}\hadithtrans{Sa'd b. Yazid reported:I said to Anas b. Malik: Did the Messenger of Allah (ﷺ) pray while putting on the shoes? He said: Yes}}
\hadithdefcmd{muslim}{1237}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، حَدَّثَنَا سَعِيدُ بْنُ يَزِيدَ أَبُو مَسْلَمَةَ، قَالَ سَأَلْتُ أَنَسًا ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1237}\hadithtrans{Sa'd b. Yazid Abu Mas'ama reported:I said to Anas like (that mentioned above)}}
\hadithdefcmd{muslim}{1238}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، ح قَالَ وَحَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى فِي خَمِيصَةٍ لَهَا أَعْلاَمٌ وَقَالَ ‏ "‏ شَغَلَتْنِي أَعْلاَمُ هَذِهِ فَاذْهَبُوا بِهَا إِلَى أَبِي جَهْمٍ وَائْتُونِي بِأَنْبِجَانِيِّهِ ‏"‏ ‏.‏\hadithno{1238}\hadithtrans{A'isha reported:The Apostle of Allah (ﷺ) prayed in a garment which had designs over it, so he (the Holy Prophet) said: Take it to Abu Jahm and bring me a plain blanket from him, because its designs have distracted me}}
\hadithdefcmd{muslim}{1239}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي خَمِيصَةٍ ذَاتِ أَعْلاَمٍ فَنَظَرَ إِلَى عَلَمِهَا فَلَمَّا قَضَى صَلاَتَهُ قَالَ ‏ "‏ اذْهَبُوا بِهَذِهِ الْخَمِيصَةِ إِلَى أَبِي جَهْمِ بْنِ حُذَيْفَةَ وَائْتُونِي بِأَنْبِجَانِيِّهِ فَإِنَّهَا أَلْهَتْنِي آنِفًا فِي صَلاَتِي ‏"‏ ‏.‏\hadithno{1239}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) stood for prayer with a garment which had designs over it. He looked at these designs and after completing the prayer said: Take this garment to Abu Jahm b. Hudhaifa and bring me a blanket for it has distracted me just now}}
\hadithdefcmd{muslim}{1240}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَتْ لَهُ خَمِيصَةٌ لَهَا عَلَمٌ فَكَانَ يَتَشَاغَلُ بِهَا فِي الصَّلاَةِ فَأَعْطَاهَا أَبَا جَهْمٍ وَأَخَذَ كِسَاءً لَهُ أَنْبِجَانِيًّا ‏.‏\hadithno{1240}\hadithtrans{A'isha reported:The Apostle of Allah (way peace be upon him) had a garment which had designs upon it and this distracted him in prayer. He gave it to Abu Jahm and took a plain garment in its place which is known anbijaniya}}
\hadithdefcmd{muslim}{1241}{أَخْبَرَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا حَضَرَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ ‏"‏ ‏.‏\hadithno{1241}\hadithtrans{Anas b. Malik reported the Messenger of Allah (ﷺ) saying:When the supper is brought and the prayer begins, one, should first take food}}
\hadithdefcmd{muslim}{1242}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قُرِّبَ الْعَشَاءُ وَحَضَرَتِ الصَّلاَةُ فَابْدَءُوا بِهِ قَبْلَ أَنْ تُصَلُّوا صَلاَةَ الْمَغْرِبِ وَلاَ تَعْجَلُوا عَنْ عَشَائِكُمْ ‏"‏ ‏.‏\hadithno{1242}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) said: When the supper is brought before you, and it is also the time to say prayer, first take food before saying evening prayer and do not hasten (to prayer, leaving aside the food)}}
\hadithdefcmd{muslim}{1243}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَحَفْصٌ، وَوَكِيعٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ أَنَسٍ ‏.‏\hadithno{1243}\hadithtrans{This hadith has been narrated on the authority of Anas by another chain of transmitters}}
\hadithdefcmd{muslim}{1244}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبُو أُسَامَةَ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وُضِعَ عَشَاءُ أَحَدِكُمْ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ وَلاَ يَعْجَلَنَّ حَتَّى يَفْرُغَ مِنْهُ ‏"‏ ‏.‏\hadithno{1244}\hadithtrans{Ibn 'Umar reported:The Messenger of Allah (ﷺ) said: When the supper is served to any one of you and the prayer also begins. (in such a case) first take supper, and do not make haste (for prayer) till you have (taken the food)}}
\hadithdefcmd{muslim}{1245}{وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، حَدَّثَنِي أَنَسٌ، - يَعْنِي ابْنَ عِيَاضٍ - عَنْ مُوسَى بْنِ عُقْبَةَ، ح وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنِ ابْنِ جُرَيْجٍ، ح قَالَ وَحَدَّثَنَا الصَّلْتُ بْنُ مَسْعُودٍ، حَدَّثَنَا سُفْيَانُ بْنُ مُوسَى، عَنْ أَيُّوبَ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{1245}\hadithtrans{A hadith like this has been narrated from the Messenger of Allah (ﷺ) on the authority of Ibn 'Umar with another chain of transmitters}}
\hadithdefcmd{muslim}{1246}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا حَاتِمٌ، - هُوَ ابْنُ إِسْمَاعِيلَ - عَنْ يَعْقُوبَ بْنِ مُجَاهِدٍ، عَنِ ابْنِ أَبِي عَتِيقٍ، قَالَ تَحَدَّثْتُ أَنَا وَالْقَاسِمُ، عِنْدَ عَائِشَةَ - رضى الله عنها - حَدِيثًا وَكَانَ الْقَاسِمُ رَجُلاً لَحَّانَةً وَكَانَ لأُمِّ وَلَدٍ فَقَالَتْ لَهُ عَائِشَةُ مَا لَكَ لاَ تَحَدَّثُ كَمَا يَتَحَدَّثُ ابْنُ أَخِي هَذَا أَمَا إِنِّي قَدْ عَلِمْتُ مِنْ أَيْنَ أُتِيتَ ‏.‏ هَذَا أَدَّبَتْهُ أُمُّهُ وَأَنْتَ أَدَّبَتْكَ أُمُّكَ - قَالَ - فَغَضِبَ الْقَاسِمُ وَأَضَبَّ عَلَيْهَا فَلَمَّا رَأَى مَائِدَةَ عَائِشَةَ قَدْ أُتِيَ بِهَا قَامَ ‏.‏ قَالَتْ أَيْنَ قَالَ أُصَلِّي ‏.‏ قَالَتِ اجْلِسْ ‏.‏ قَالَ إِنِّي أُصَلِّي ‏.‏ قَالَتِ اجْلِسْ غُدَرُ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ صَلاَةَ بِحَضْرَةِ الطَّعَامِ وَلاَ وَهُوَ يُدَافِعُهُ الأَخْبَثَانِ ‏"‏ ‏.‏\hadithno{1246}\hadithtrans{Ibn Atiq reported:Al-Qasim was in the presence of 'A'isha (Allah be pleased with her) that I narrated a hadith and Qasim was a man who committed errors in (pronouncing words) and his mother was a freed slave-girl. 'A'isha said to him: What is the matter with you that you do not narrate as this son of my brother narrated (the ahaditb)? Well I know from where you picked it up. This is how his mother brought him up and how your mother brought you up. Qasim felt angry (on this remark of Hadrat 'A'isha) and showed bitterness towards her. When he saw that the table had been spread for 'A'isha, he stood up, 'A'isha, said: Where are you going? He said: (I am going) to say prayer. She said: Sit down (to take the food). He said: I must say prayer. She said: Sit down, ) faithless, for I have heard the Messenger of Allah (ﷺ) say: No prayer can be (rightly said) when the food is there (before the worshipper), or when he is prompted by the call of nature}}
\hadithdefcmd{muslim}{1247}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - أَخْبَرَنِي أَبُو حَزْرَةَ الْقَاصُّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي عَتِيقٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ وَلَمْ يَذْكُرْ فِي الْحَدِيثِ قِصَّةَ الْقَاسِمِ ‏.‏\hadithno{1247}\hadithtrans{Abdullah b. 'Atiq narrated from the Apostle (ﷺ) on the authority of 'A'isha, but he made no mention of the account of Qasim}}
\hadithdefcmd{muslim}{1248}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي غَزْوَةِ خَيْبَرَ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ - يَعْنِي الثُّومَ - فَلاَ يَأْتِيَنَّ الْمَسَاجِدَ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ فِي غَزْوَةٍ ‏.‏ وَلَمْ يَذْكُرْ خَيْبَرَ ‏.‏\hadithno{1248}\hadithtrans{Ibn 'Umar reported:The Messenger of Allah (ﷺ) said during the battle of Khaybar: He who ate of this plant, i. e. garlic, should not come to the mosques. In the narration of Zubair, there is only a mention of" battle" and not of Khaybar}}
\hadithdefcmd{muslim}{1249}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الْبَقْلَةِ فَلاَ يَقْرَبَنَّ مَسَاجِدَنَا حَتَّى يَذْهَبَ رِيحُهَا ‏"‏ ‏.‏ يَعْنِي الثُّومَ ‏.‏\hadithno{1249}\hadithtrans{Ibn 'Umar reported:The Messenger of Allah (ﷺ) said: He who eats of this (offensive) plant must not approach our mosque, till its odor dies: (plant signifies) garlic}}
\hadithdefcmd{muslim}{1250}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ، - وَهُوَ ابْنُ صُهَيْبٍ - قَالَ سُئِلَ أَنَسٌ عَنِ الثُّومِ، فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ فَلاَ يَقْرَبَنَّا وَلاَ يُصَلِّي مَعَنَا ‏"‏ ‏.‏\hadithno{1250}\hadithtrans{Ibn Suhaib reported:Anas was asked about the garlic; he stated that the Messenger of Allah (ﷺ) had said: He who eats of this plant (garlic) should not approach us and pray along with us}}
\hadithdefcmd{muslim}{1252}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ فَلاَ يَقْرَبَنَّ مَسْجِدَنَا وَلاَ يُؤْذِيَنَّا بِرِيحِ الثُّومِ ‏"‏ ‏.‏\hadithno{1252}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: He who eats of this plant (garlic) should not approach our mosque and should not harm us with the odour of garlic}}
\hadithdefcmd{muslim}{1253}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ الْبَصَلِ وَالْكُرَّاثِ ‏.‏ فَغَلَبَتْنَا الْحَاجَةُ فَأَكَلْنَا مِنْهَا فَقَالَ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ الْمُنْتِنَةِ فَلاَ يَقْرَبَنَّ مَسْجِدَنَا فَإِنَّ الْمَلاَئِكَةَ تَأَذَّى مِمَّا يَتَأَذَّى مِنْهُ الإِنْسُ ‏"‏ ‏.‏\hadithno{1253}\hadithtrans{Jabir reported:The Messenger of Allah (ﷺ) forbade eating of onions and leek. When we were overpowered by a desire (to eat) we ate them. Upon this he (the Holy Prophet) said: He who eats of this offensive plant must not approach our mosque, for the angels are harmed by the same things as men}}
\hadithdefcmd{muslim}{1254}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ - وَفِي رِوَايَةِ حَرْمَلَةَ وَزَعَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَكَلَ ثُومًا أَوْ بَصَلاً فَلْيَعْتَزِلْنَا أَوْ لِيَعْتَزِلْ مَسْجِدَنَا وَلْيَقْعُدْ فِي بَيْتِهِ ‏"‏ ‏.‏ وَأَنَّهُ أُتِيَ بِقِدْرٍ فِيهِ خَضِرَاتٌ مِنْ بُقُولٍ فَوَجَدَ لَهَا رِيحًا فَسَأَلَ فَأُخْبِرَ بِمَا فِيهَا مِنَ الْبُقُولِ فَقَالَ ‏"‏ قَرِّبُوهَا ‏"‏ ‏.‏ إِلَى بَعْضِ أَصْحَابِهِ فَلَمَّا رَآهُ كَرِهَ أَكْلَهَا قَالَ ‏"‏ كُلْ فَإِنِّي أُنَاجِي مَنْ لاَ تُنَاجِي ‏"‏ ‏.‏\hadithno{1254}\hadithtrans{Jabir reported:The Messenger of Allah (ﷺ) said: He who eats garlic or onion should remain away from us or from our mosque and stay in his house. A kettle was brought to him which had (cooked) vegetables in it, He smelt (offensive) odour in it. On asking he was informed of the vegetables (cooked in it). He said: Take it to such and such Companion. When he saw it, he also disliked eating it. (Upon this). he (the Holy Prophet) said: You may eat it, for I converse wkh one with whom you do not converse}}
\hadithdefcmd{muslim}{1255}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، ح قَالَ وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالاَ جَمِيعًا أَخْبَرَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ - يُرِيدُ الثُّومَ - فَلاَ يَغْشَنَا فِي مَسْجِدِنَا ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الْبَصَلَ وَالْكُرَّاثَ ‏.‏\hadithno{1255}\hadithtrans{Ibn Juraij has narrated it with the same chain of transmitters:He who eats of this plant, i. e. garlic, should not come to us in our mosque, and he made no mention of onions or leek}}
\hadithdefcmd{muslim}{1256}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ لَمْ نَعْدُ أَنْ فُتِحَتْ، خَيْبَرُ فَوَقَعْنَا أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي تِلْكَ الْبَقْلَةِ الثُّومِ وَالنَّاسُ جِيَاعٌ فَأَكَلْنَا مِنْهَا أَكْلاً شَدِيدًا ثُمَّ رُحْنَا إِلَى الْمَسْجِدِ فَوَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم الرِّيحَ فَقَالَ ‏"‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ الْخَبِيثَةِ شَيْئًا فَلاَ يَقْرَبَنَّا فِي الْمَسْجِدِ ‏"‏ ‏.‏ فَقَالَ النَّاسُ حُرِّمَتْ حُرِّمَتْ ‏.‏ فَبَلَغَ ذَاكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَيُّهَا النَّاسُ إِنَّهُ لَيْسَ بِي تَحْرِيمُ مَا أَحَلَّ اللَّهُ لِي وَلَكِنَّهَا شَجَرَةٌ أَكْرَهُ رِيحَهَا ‏"‏ ‏.‏\hadithno{1256}\hadithtrans{Abu Sa'id reported:We made no transgression but Khaybar was conquered. We, the Companions of the Messenger of Allah (ﷺ), fell upon this plant. i e. garlic. because the people were hungry. We ate it to our heart's content and then made our way towards the mosque. The Messenger of Allah (ﷺ) sensed its odour and he said: He who takes anything of this offensive plant must not approach us in the mosque. The people said: Its (use) has been forbidden; its (use) bu been forbidden. This reached the Messenger of Allah (ﷺ) and he said: O people, I cannot forbid (the use of a thing) which Allah has made lawful, but (this garlic) is a plant the odour of which is repugnant to me}}
\hadithdefcmd{muslim}{1257}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنِ ابْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ عَلَى زَرَّاعَةِ بَصَلٍ هُوَ وَأَصْحَابُهُ فَنَزَلَ نَاسٌ مِنْهُمْ فَأَكَلُوا مِنْهُ وَلَمْ يَأْكُلْ آخَرُونَ فَرُحْنَا إِلَيْهِ فَدَعَا الَّذِينَ لَمْ يَأْكُلُوا الْبَصَلَ وَأَخَّرَ الآخَرِينَ حَتَّى ذَهَبَ رِيحُهَا ‏.‏\hadithno{1257}\hadithtrans{Abu Sa'id al-Khudri reported:The Messenger of Allah (ﷺ) along with his Companions happened to pass by a field in which onions were sown. The people stopped there and ate out of that, but some of them did not eat. Then they (Propbet's Companions) went to him. He (first) called those who had not eaten the onions and kept the others (who had taken onions) waiting till its odour vanished}}
\hadithdefcmd{muslim}{1258}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، خَطَبَ يَوْمَ الْجُمُعَةِ فَذَكَرَ نَبِيَّ اللَّهِ صلى الله عليه وسلم وَذَكَرَ أَبَا بَكْرٍ قَالَ إِنِّي رَأَيْتُ كَأَنَّ دِيكًا نَقَرَنِي ثَلاَثَ نَقَرَاتٍ وَإِنِّي لاَ أُرَاهُ إِلاَّ حُضُورَ أَجَلِي وَإِنَّ أَقْوَامًا يَأْمُرُونَنِي أَنْ أَسْتَخْلِفَ وَإِنَّ اللَّهَ لَمْ يَكُنْ لِيُضَيِّعَ دِينَهُ وَلاَ خِلاَفَتَهُ وَلاَ الَّذِي بَعَثَ بِهِ نَبِيَّهُ صلى الله عليه وسلم فَإِنْ عَجِلَ بِي أَمْرٌ فَالْخِلاَفَةُ شُورَى بَيْنَ هَؤُلاَءِ السِّتَّةِ الَّذِينَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَنْهُمْ رَاضٍ وَإِنِّي قَدْ عَلِمْتُ أَنَّ أَقْوَامًا يَطْعَنُونَ فِي هَذَا الأَمْرِ أَنَا ضَرَبْتُهُمْ بِيَدِي هَذِهِ عَلَى الإِسْلاَمِ فَإِنْ فَعَلُوا ذَلِكَ فَأُولَئِكَ أَعْدَاءُ اللَّهِ الْكَفَرَةُ الضُّلاَّلُ ثُمَّ إِنِّي لاَ أَدَعُ بَعْدِي شَيْئًا أَهَمَّ عِنْدِي مِنَ الْكَلاَلَةِ مَا رَاجَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي شَىْءٍ مَا رَاجَعْتُهُ فِي الْكَلاَلَةِ وَمَا أَغْلَظَ لِي فِي شَىْءٍ مَا أَغْلَظَ لِي فِيهِ حَتَّى طَعَنَ بِإِصْبَعِهِ فِي صَدْرِي فَقَالَ ‏ "‏ يَا عُمَرُ أَلاَ تَكْفِيكَ آيَةُ الصَّيْفِ الَّتِي فِي آخِرِ سُورَةِ النِّسَاءِ ‏"‏ ‏.‏ وَإِنِّي إِنْ أَعِشْ أَقْضِ فِيهَا بِقَضِيَّةٍ يَقْضِي بِهَا مَنْ يَقْرَأُ الْقُرْآنَ وَمَنْ لاَ يَقْرَأُ الْقُرْآنَ ثُمَّ قَالَ اللَّهُمَّ إِنِّي أُشْهِدُكَ عَلَى أُمَرَاءِ الأَمْصَارِ وَإِنِّي إِنَّمَا بَعَثْتُهُمْ عَلَيْهِمْ لِيَعْدِلُوا عَلَيْهِمْ وَلِيُعَلِّمُوا النَّاسَ دِينَهُمْ وَسُنَّةَ نَبِيِّهِمْ صلى الله عليه وسلم وَيَقْسِمُوا فِيهِمْ فَيْئَهُمْ وَيَرْفَعُوا إِلَىَّ مَا أَشْكَلَ عَلَيْهِمْ مِنْ أَمْرِهِمْ ثُمَّ إِنَّكُمْ أَيُّهَا النَّاسُ تَأْكُلُونَ شَجَرَتَيْنِ لاَ أَرَاهُمَا إِلاَّ خَبِيثَتَيْنِ هَذَا الْبَصَلَ وَالثُّومَ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا وَجَدَ رِيحَهُمَا مِنَ الرَّجُلِ فِي الْمَسْجِدِ أَمَرَ بِهِ فَأُخْرِجَ إِلَى الْبَقِيعِ فَمَنْ أَكَلَهُمَا فَلْيُمِتْهُمَا طَبْخًا ‏.‏\hadithno{1258}\hadithtrans{Ma'dan b. Talha reported:'Umar b. Khattab, delivered the Friday sermon and he made a mention of the Messenger of Allah (ﷺ) and Abu Bakr. He (further) said: I saw in a dream that a cock pecked me twice, and I perceive that my death is near. Some people have suggested me to appoint my successor. And Allah would not destroy His religion. His caliphate and that with which He sent His Apostle (ﷺ) If death approaches me soon, the (issue) of Caliphate (would be decided) by the consent of these six men with whom the Messenger of Allah (ﷺ) remained well pleased till his death. And I know fully well that some people would blame me that I killed with these very hands of mine some persons who apparently professed (Islam). And if they do this (blame me) they are the enemies of Allah, and are non-believers and have gone astray. And I leave not after me anything which to my mind seems more important than Kalala. And I never turned towards the Messenger of Allah (ﷺ) (for guidance) more often than this Kalala, and he (the Holy Prophet) was not annoyed with me on any other (issue) than this: (And he was so perturbed) that he struck his fingers on my chest and said: Does this verse. that is at the end of Surat al-Nisa'. which was revealed in the hot season not suffice you? And if I live longer I would decide this (problem so clearly) that one who reads the Qur'an, or one who does not read it, would be able to take (correct), decisions (under its light). He ('Umar) further said: Allah! I call You witness on these governors of lands, that I sent them to (the peoples of these lands) so that they should administer justice amongst them, teach them their religion and the Sunnah of the Messenger of Allah (ﷺ), and distribute amongst them the spoils of war and refer to me that which they find difficult to perform. O people. you eat 'these two plants and these are onions and garlic. and I find them nothing but repugnant for I saw that when the Messenger of Allah (ﷺ) sensed the odour of these two from a person in a mosque, he was made to go to al-Baqi'. So he who eats it should (make its odour) die by cooking it well}}
\hadithdefcmd{muslim}{1259}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، ح قَالَ وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ شَبَابَةَ بْنِ سَوَّارٍ، قَالَ حَدَّثَنَا شُعْبَةُ، جَمِيعًا عَنْ قَتَادَةَ، فِي هَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1259}\hadithtrans{This hadith has been narrated by Qatada with the same chain of transmitters}}
\hadithdefcmd{muslim}{1260}{حَدَّثَنَا أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرٍو حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ حَيْوَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي عَبْدِ اللَّهِ، مَوْلَى شَدَّادِ بْنِ الْهَادِ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَمِعَ رَجُلاً يَنْشُدُ ضَالَّةً فِي الْمَسْجِدِ فَلْيَقُلْ لاَ رَدَّهَا اللَّهُ عَلَيْكَ فَإِنَّ الْمَسَاجِدَ لَمْ تُبْنَ لِهَذَا ‏"‏ ‏.‏\hadithno{1260}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: If anyone hears a man crying out in the mosque about something he has lost, he should say: May Allah not restore it to you, for the mosques were not built for this}}
\hadithdefcmd{muslim}{1261}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ، قَالَ سَمِعْتُ أَبَا الأَسْوَدِ، يَقُولُ حَدَّثَنِي أَبُو عَبْدِ اللَّهِ، مَوْلَى شَدَّادٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1261}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) saying like this}}
\hadithdefcmd{muslim}{1262}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا الثَّوْرِيُّ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، نَشَدَ فِي الْمَسْجِدِ فَقَالَ مَنْ دَعَا إِلَى الْجَمَلِ الأَحْمَرِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ وَجَدْتَ ‏.‏ إِنَّمَا بُنِيَتِ الْمَسَاجِدُ لِمَا بُنِيَتْ لَهُ ‏"‏ ‏.‏\hadithno{1262}\hadithtrans{Sulaiman b. Buraida narrated it on the authority of his father that a man cried out in the mosque saying:Who had called out for the red camel? Upon this the Messenger of Allah (ﷺ) said: May it not be restored to you! The mosques are built for what they are meant}}
\hadithdefcmd{muslim}{1263}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي سِنَانٍ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا صَلَّى قَامَ رَجُلٌ فَقَالَ مَنْ دَعَا إِلَى الْجَمَلِ الأَحْمَرِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ وَجَدْتَ إِنَّمَا بُنِيَتِ الْمَسَاجِدُ لِمَا بُنِيَتْ لَهُ ‏"‏ ‏.‏\hadithno{1263}\hadithtrans{Sulaiman b. Buraida reported on the authority of his father that when the Messenger of Allah (ﷺ) had said prayer a man stood up and said:Who called for a red camel? (Upon this) the Messenger of Allah (ﷺ) said: May it not be restored to you! The mosques are built for what they are meant}}
\hadithdefcmd{muslim}{1264}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُحَمَّدِ بْنِ شَيْبَةَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ جَاءَ أَعْرَابِيٌّ بَعْدَ مَا صَلَّى النَّبِيُّ صلى الله عليه وسلم صَلاَةَ الْفَجْرِ ‏.‏ فَأَدْخَلَ رَأْسَهُ مِنْ بَابِ الْمَسْجِدِ فَذَكَرَ ‏.‏ بِمِثْلِ حَدِيثِهِمَا ‏.‏ قَالَ مُسْلِمٌ هُوَ شَيْبَةُ بْنُ نَعَامَةَ أَبُو نَعَامَةَ رَوَى عَنْهُ مِسْعَرٌ وَهُشَيْمٌ وَجَرِيرٌ وَغَيْرُهُمْ مِنَ الْكُوفِيِّينَ ‏.‏\hadithno{1264}\hadithtrans{Ibn Buraida narrated it on the authority of his father that a Bedouin came when the Messenger of Allah (ﷺ) had completed the morning prayer. He thrust his head in the door of the mosque, and then the hadith (as narrated above) was narrated. This hadith has been reported by another chain of transmitters}}
\hadithdefcmd{muslim}{1265}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا قَامَ يُصَلِّي جَاءَهُ الشَّيْطَانُ فَلَبَسَ عَلَيْهِ حَتَّى لاَ يَدْرِي كَمْ صَلَّى فَإِذَا وَجَدَ ذَلِكَ أَحَدُكُمْ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏\hadithno{1265}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When any one of you stands up to pray, the devil comes to him and confuses him to that he does not know how much he has prayed. If any one of you has such an experience he should perform two prostrations while sitting down (in qa'da)}}
\hadithdefcmd{muslim}{1266}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، - وَهُوَ ابْنُ عُيَيْنَةَ - ح قَالَ وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{1266}\hadithtrans{This hadith has been narrated by al-Zubri with the same chain of transmitters}}
\hadithdefcmd{muslim}{1267}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نُودِيَ بِالأَذَانِ أَدْبَرَ الشَّيْطَانُ لَهُ ضُرَاطٌ حَتَّى لاَ يَسْمَعَ الأَذَانَ فَإِذَا قُضِيَ الأَذَانُ أَقْبَلَ فَإِذَا ثُوِّبَ بِهَا أَدْبَرَ فَإِذَا قُضِيَ التَّثْوِيبُ أَقْبَلَ يَخْطُرُ بَيْنَ الْمَرْءِ وَنَفْسِهِ يَقُولُ اذْكُرْ كَذَا اذْكُرْ كَذَا ‏.‏ لِمَا لَمْ يَكُنْ يَذْكُرُ حَتَّى يَظَلَّ الرَّجُلُ إِنْ يَدْرِي كَمْ صَلَّى فَإِذَا لَمْ يَدْرِ أَحَدُكُمْ كَمْ صَلَّى فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏\hadithno{1267}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When there is a call to prayer the devil runs back breaking the wind so that he may not hear the call, and when the call is complete he comes back. And when the takbir is pronounced he again runs back, and when takbir is over he comes back and distracts a man saying: Remember such and such, remember such and such, referring to something the man did not have in his mind. with the result that he does not know how much he has prayed; so when any one of you is not sure how much he has prayed. he should perform two prostrations while sitting (qa'da)}}
\hadithdefcmd{muslim}{1268}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الشَّيْطَانَ إِذَا ثُوِّبَ بِالصَّلاَةِ وَلَّى وَلَهُ ضُرَاطٌ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَهُ وَزَادَ ‏"‏ فَهَنَّاهُ وَمَنَّاهُ وَذَكَّرَهُ مِنْ حَاجَاتِهِ مَا لَمْ يَكُنْ يَذْكُرُ ‏"‏ ‏.‏\hadithno{1268}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: The devil takes to his heels breaking wind when the prayer begins. and the rest is the same but with this addition:" He (the devil) makes him think of pleasant things (or things productive of enjoyment) and of the things wished for, and reminds him of such needs which he had forgotten}}
\hadithdefcmd{muslim}{1269}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ، قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ مِنْ بَعْضِ الصَّلَوَاتِ ثُمَّ قَامَ فَلَمْ يَجْلِسْ فَقَامَ النَّاسُ مَعَهُ فَلَمَّا قَضَى صَلاَتَهُ وَنَظَرْنَا تَسْلِيمَهُ كَبَّرَ فَسَجَدَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ قَبْلَ التَّسْلِيمِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1269}\hadithtrans{Abdullah b. Buhaina reported:The Messenger of Allah (ﷺ) led us two rak'ahs of prayer in one of the (obligatory) prayers and then got up and did not sit. and the people stood up along with him. When he finished the prayer and we expected him to pronounce salutation. he said:" Allah is Most Great" while sitting and made two prostrations before salutation and then pronounced (the, final) salutation}}
\hadithdefcmd{muslim}{1270}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح قَالَ وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ الأَسْدِيِّ، حَلِيفِ بَنِي عَبْدِ الْمُطَّلِبِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فِي صَلاَةِ الظُّهْرِ وَعَلَيْهِ جُلُوسٌ فَلَمَّا أَتَمَّ صَلاَتَهُ سَجَدَ سَجْدَتَيْنِ يُكَبِّرُ فِي كُلِّ سَجْدَةٍ وَهُوَ جَالِسٌ قَبْلَ أَنْ يُسَلِّمَ وَسَجَدَهُمَا النَّاسُ مَعَهُ مَكَانَ مَا نَسِيَ مِنَ الْجُلُوسِ ‏.‏\hadithno{1270}\hadithtrans{Abdullah b. Buhaina al-Asadi, the ally of Abual-Muttalib, reported:The Messenger of Allah (ﷺ) stood up in the noon prayer (though) he hadith sit (after the two rak'ahs). When he completed the prayer he performed two prostrations and said," Allah is the Most Great" in each prostration, while he was sitting before pronouncing salutation, and the people performed prostration along with him. That was a compensation for he had forgotten to observe jalsa (after two rak'ahs)}}
\hadithdefcmd{muslim}{1271}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ ابْنِ بُحَيْنَةَ الأَزْدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فِي الشَّفْعِ الَّذِي يُرِيدُ أَنْ يَجْلِسَ فِي صَلاَتِهِ فَمَضَى فِي صَلاَتِهِ فَلَمَّا كَانَ فِي آخِرِ الصَّلاَةِ سَجَدَ قَبْلَ أَنْ يُسَلِّمَ ثُمَّ سَلَّمَ ‏.‏\hadithno{1271}\hadithtrans{Abdullah b. Malik ibn Buhaina al-Asadi reported:The Messenger of Allah (ﷺ) stood up (at the end of two rak'ahs) when he had to sit and proceeded on with the prayer. But when he was at the end of the prayer, he performed a prostration before the salutation and then pronounced the salutation}}
\hadithdefcmd{muslim}{1272}{وَحَدَّثَنِي مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا مُوسَى بْنُ دَاوُدَ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَكَّ أَحَدُكُمْ فِي صَلاَتِهِ فَلَمْ يَدْرِ كَمْ صَلَّى ثَلاَثًا أَمْ أَرْبَعًا فَلْيَطْرَحِ الشَّكَّ وَلْيَبْنِ عَلَى مَا اسْتَيْقَنَ ثُمَّ يَسْجُدُ سَجْدَتَيْنِ قَبْلَ أَنْ يُسَلِّمَ فَإِنْ كَانَ صَلَّى خَمْسًا شَفَعْنَ لَهُ صَلاَتَهُ وَإِنْ كَانَ صَلَّى إِتْمَامًا لأَرْبَعٍ كَانَتَا تَرْغِيمًا لِلشَّيْطَانِ ‏"‏ ‏.‏\hadithno{1272}\hadithtrans{Abu Sa'id al-Khudri reported:The Messenger of Allah (ﷺ) said: When any one of you is in doubt about his prayer and he does Dot know how much he has prayed, three or four (rak'ahs). he should cast aside his doubt and base his prayer on what he is sure of. then perform two prostrations before giving salutations. If he has prayed five rak'ahs, they will make his prayer an even number for him, and if he has prayed exactly four, they will be humiliation for the devil}}
\hadithdefcmd{muslim}{1273}{حَدَّثَنِي أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ وَهْبٍ، حَدَّثَنِي عَمِّي عَبْدُ اللَّهِ، حَدَّثَنِي دَاوُدُ بْنُ قَيْسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، بِهَذَا الإِسْنَادِ وَفِي مَعْنَاهُ قَالَ ‏ "‏ يَسْجُدُ سَجْدَتَيْنِ قَبْلَ السَّلاَمِ ‏"‏ ‏.‏ كَمَا قَالَ سُلَيْمَانُ بْنُ بِلاَلٍ ‏.‏\hadithno{1273}\hadithtrans{This hadith has been narrated by Zaid b. Aslam with the same chain of transmitters and he said:He should perform two prostrations before the salutation, as it was mentioned by Sulaiman b. Bilal}}
\hadithdefcmd{muslim}{1274}{وَحَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ جَمِيعًا عَنْ جَرِيرٍ، - قَالَ عُثْمَانُ حَدَّثَنَا جَرِيرٌ، - عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ قَالَ عَبْدُ اللَّهِ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ إِبْرَاهِيمُ زَادَ أَوْ نَقَصَ - فَلَمَّا سَلَّمَ قِيلَ لَهُ يَا رَسُولَ اللَّهِ أَحَدَثَ فِي الصَّلاَةِ شَىْءٌ قَالَ ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالُوا صَلَّيْتَ كَذَا وَكَذَا - قَالَ - فَثَنَى رِجْلَيْهِ وَاسْتَقْبَلَ الْقِبْلَةَ فَسَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏"‏ إِنَّهُ لَوْ حَدَثَ فِي الصَّلاَةِ شَىْءٌ أَنْبَأْتُكُمْ بِهِ وَلَكِنْ إِنَّمَا أَنَا بَشَرٌ أَنْسَى كَمَا تَنْسَوْنَ فَإِذَا نَسِيتُ فَذَكِّرُونِي وَإِذَا شَكَّ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيَتَحَرَّ الصَّوَابَ فَلْيُتِمَّ عَلَيْهِ ثُمَّ لْيَسْجُدْ سَجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{1274}\hadithtrans{Alqama narrated It on the authority of 'Abdullah (b. Mas'ud) who said:The Messenger of Allah (ﷺ) said the prayer; (the narrator added): He made some act of omission or commission when he pronounced salutation; it was said to him: Messenger of Allah, is there something new about the prayer? He (the Holy Prophet) said: What is it? They said: You said prayer in such and such away. He (the narrator) said: He (the Holy Prophet) turned his feet and faced the Qibla and performed two prostrations and then pronounced salutations, and then turned his face towards us and said: If there is anything new about prayer (new command from the Lord) I informed you of that. But I am a human being and I forget as you for. get, so when I forget, remind me, and when any one of you is in doubt about his prayer. he should aim at what Is correct. and complete his prayer in that respect and then make two prostrations}}
\hadithdefcmd{muslim}{1275}{حَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ بِشْرٍ، ح قَالَ وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا وَكِيعٌ، كِلاَهُمَا عَنْ مِسْعَرٍ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي رِوَايَةِ ابْنِ بِشْرٍ ‏"‏ فَلْيَنْظُرْ أَحْرَى ذَلِكَ لِلصَّوَابِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ وَكِيعٍ ‏"‏ فَلْيَتَحَرَّ الصَّوَابَ ‏"‏ ‏.‏\hadithno{1275}\hadithtrans{This hadith has been narrated by Mansur with the same chain of transmitters, with a slight modification of words}}
\hadithdefcmd{muslim}{1276}{وَحَدَّثَنَاهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، حَدَّثَنَا مَنْصُورٌ، بِهَذَا الإِسْنَادِ وَقَالَ مَنْصُورٌ ‏ "‏ فَلْيَنْظُرْ أَحْرَى ذَلِكَ لِلصَّوَابِ ‏"‏ ‏.‏\hadithno{1276}\hadithtrans{This hadith is reported by Mansur with the same chain of transmitters, but with these words:" He should aim at correct (prayer) and it is advisable}}
\hadithdefcmd{muslim}{1277}{حَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عُبَيْدُ بْنُ سَعِيدٍ الأُمَوِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ فَلْيَتَحَرَّ الصَّوَابَ ‏"‏ ‏.‏\hadithno{1277}\hadithtrans{This hadith has been narrated by Mansur with the same chain of transmitters with the words:He should aim at what is correct and complete}}
\hadithdefcmd{muslim}{1278}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ فَلْيَتَحَرَّ أَقْرَبَ ذَلِكَ إِلَى الصَّوَابِ ‏"‏ ‏.‏\hadithno{1278}\hadithtrans{This hadith has been narrated by Mansur with the same chain of transmitters and said:" He should aim at correctness and that is right}}
\hadithdefcmd{muslim}{1279}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا فُضَيْلُ بْنُ عِيَاضٍ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ فَلْيَتَحَرَّ الَّذِي يُرَى أَنَّهُ الصَّوَابُ ‏"‏ ‏.‏\hadithno{1279}\hadithtrans{This hadith has been reported by Mansur with the same chain of transwitters and he said:" He should aim at what is according to him correct}}
\hadithdefcmd{muslim}{1280}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، عَنْ مَنْصُورٍ، بِإِسْنَادِ هَؤُلاَءِ وَقَالَ ‏ "‏ فَلْيَتَحَرَّ الصَّوَابَ ‏"‏ ‏.‏\hadithno{1280}\hadithtrans{This hadith has been narrated by Mansur and he said:" He should aim at correctness}}
\hadithdefcmd{muslim}{1281}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ خَمْسًا فَلَمَّا سَلَّمَ قِيلَ لَهُ أَزِيدَ فِي الصَّلاَةِ قَالَ ‏ "‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالُوا صَلَّيْتَ خَمْسًا ‏.‏ فَسَجَدَ سَجْدَتَيْنِ ‏.‏\hadithno{1281}\hadithtrans{Abdullah (b. Mas'ud) reported:The Apostle of Allah (ﷺ) said five rak'ahs of the noon prayer and when he completed the prayer, It was said to him: Has there been (commanded) an addition In prayer? He said: What is it? They said: You have said five rak'ahs, so he performed two prostrations}}
\hadithdefcmd{muslim}{1282}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، أَنَّهُ صَلَّى بِهِمْ خَمْسًا ‏.‏\hadithno{1282}\hadithtrans{Alqama reported:He (the Holy Prophet) had led them five rak'ahs in prayer}}
\hadithdefcmd{muslim}{1283}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا جَرِيرٌ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ سُوَيْدٍ، قَالَ صَلَّى بِنَا عَلْقَمَةُ الظُّهْرَ خَمْسًا فَلَمَّا سَلَّمَ قَالَ الْقَوْمُ يَا أَبَا شِبْلٍ قَدْ صَلَّيْتَ خَمْسًا ‏.‏ قَالَ كَلاَّ مَا فَعَلْتُ ‏.‏ قَالُوا بَلَى - قَالَ - وَكُنْتُ فِي نَاحِيَةِ الْقَوْمِ وَأَنَا غُلاَمٌ فَقُلْتُ بَلَى قَدْ صَلَّيْتَ خَمْسًا ‏.‏ قَالَ لِي وَأَنْتَ أَيْضًا يَا أَعْوَرُ تَقُولُ ذَاكَ قَالَ قُلْتُ نَعَمْ ‏.‏ قَالَ فَانْفَتَلَ فَسَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ قَالَ قَالَ عَبْدُ اللَّهِ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم خَمْسًا فَلَمَّا انْفَتَلَ تَوَشْوَشَ الْقَوْمُ بَيْنَهُمْ فَقَالَ ‏"‏ مَا شَأْنُكُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ هَلْ زِيدَ فِي الصَّلاَةِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالُوا فَإِنَّكَ قَدْ صَلَّيْتَ خَمْسًا ‏.‏ فَانْفَتَلَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ قَالَ ‏"‏ إِنَّمَا أَنَا بَشَرٌ مِثْلُكُمْ أَنْسَى كَمَا تَنْسَوْنَ ‏"‏ ‏.‏ وَزَادَ ابْنُ نُمَيْرٍ فِي حَدِيثِهِ ‏"‏ فَإِذَا نَسِيَ أَحَدُكُمْ فَلْيَسْجُدْ سَجْدَتَيْنِ ‏"‏ ‏.‏\hadithno{1283}\hadithtrans{Ibrahim b. Suwaid-reported:'Alqama led us in the noon prayer and be offered five rak'ahs; when the prayer was complete, the people said to him: Abu Shibl, you have offered five rak'ahs. He said: No, I have not done that. They said: Yes (you said five rak'ahs). He (the narrator) said: And I was sitting in a corner among people and I was just a boy. I (also) said: Yes, you have offered five (rak'ahs). He said to me: O, one-eyed, do you say the same thing? I said: Yes. Upon this he turned (his face) and performed two prostrations and then gave salutations, and then reported 'Abdullah as saying: The Messenger of Allah (ﷺ) led us in prayer and offered five rak'ahs. And as he turned away the people began to whisper amongst themselves. He (the Holy Prophet) said: What is the matter with you? They said: Has the prayer been extended? He said: No. They said: You have in fact said five rak'ahs. He (the Holy Prophet) then turned his back (and faced the Qibla) and performed two prostrations and then gave salutations and further said: Verily I am a human being like you, I forget just as you forget. Ibn Numair made this addition:" When any one of you forgets, he must perform two prostrations}}
\hadithdefcmd{muslim}{1284}{وَحَدَّثَنَاهُ عَوْنُ بْنُ سَلاَّمٍ الْكُوفِيُّ، أَخْبَرَنَا أَبُو بَكْرٍ النَّهْشَلِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم خَمْسًا فَقُلْنَا يَا رَسُولَ اللَّهِ أَزِيدَ فِي الصَّلاَةِ قَالَ ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالُوا صَلَّيْتَ خَمْسًا ‏.‏ قَالَ ‏"‏ إِنَّمَا أَنَا بَشَرٌ مِثْلُكُمْ أَذْكُرُ كَمَا تَذْكُرُونَ وَأَنْسَى كَمَا تَنْسَوْنَ ‏"‏ ‏.‏ ثُمَّ سَجَدَ سَجْدَتَىِ السَّهْوِ ‏.‏\hadithno{1284}\hadithtrans{Abdullah (b. Mas'ud) reported:The Messenger of Allah (ﷺ) led us five (rak'ahs in prayer). We said: Messenger of Allah, has the prayer been extended? He said: What is the matter? They said: You have said five (rak'ahs). He (the Holy Prophet) said: Verily I am a human being like you. I remember as you remember and I forget just as you forget. He then performed two prostrations as (compensation of) forgetfulness}}
\hadithdefcmd{muslim}{1285}{وَحَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، أَخْبَرَنَا ابْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَزَادَ أَوْ نَقَصَ - قَالَ إِبْرَاهِيمُ وَالْوَهْمُ مِنِّي - فَقِيلَ يَا رَسُولَ اللَّهِ أَزِيدَ فِي الصَّلاَةِ شَىْءٌ فَقَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ مِثْلُكُمْ أَنْسَى كَمَا تَنْسَوْنَ فَإِذَا نَسِيَ أَحَدُكُمْ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏ ثُمَّ تَحَوَّلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَجَدَ سَجْدَتَيْنِ ‏.‏\hadithno{1285}\hadithtrans{Abdullah (b. Mas'ud) reported:The Messenger of Allah (ﷺ) said prayer and he omitted or committed (something). Ibrahim (one of the narrators of this hadith) said: It is my doubt, and it was said: Messenger of Allah, has there been any addition to the prayer? He (the Holy Prophet) said: Verily I am a human being like you. I forget just as you forget so when any one of you forgets, he must perform two prostrations, and he (the Holy Prophet) was sitting and then the Messenger of Allah (ﷺ) turned (his face towards the Qibla) and performed two prostrations}}
\hadithdefcmd{muslim}{1286}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح قَالَ وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا حَفْصٌ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَجَدَ سَجْدَتَىِ السَّهْوِ بَعْدَ السَّلاَمِ وَالْكَلاَمِ ‏.‏\hadithno{1286}\hadithtrans{Abdullah b. Mas'ud reported:The Apostle of Allah (ﷺ) performed two prostrations for forgetfulness after salutation and talking}}
\hadithdefcmd{muslim}{1287}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّيْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِمَّا زَادَ أَوْ نَقَصَ - قَالَ إِبْرَاهِيمُ وَايْمُ اللَّهِ مَا جَاءَ ذَاكَ إِلاَّ مِنْ قِبَلِي - قَالَ فَقُلْنَا يَا رَسُولَ اللَّهِ أَحَدَثَ فِي الصَّلاَةِ شَىْءٌ فَقَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ فَقُلْنَا لَهُ الَّذِي صَنَعَ فَقَالَ ‏"‏ إِذَا زَادَ الرَّجُلُ أَوْ نَقَصَ فَلْيَسْجُدْ سَجْدَتَيْنِ ‏"‏ ‏.‏ قَالَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ‏.‏\hadithno{1287}\hadithtrans{Abdullah reported:We prayed along with the Messenger of Allah (may peace he upon him) and he committed or omitted (something). Ibrahim said: By Allah, this is a misgiving of mine only. We said: Messenger of Allah, is there something new about the prayer? He (the Holy Prophet) said: No. We told him about what he had done. He (the Holy Prophet) said: When a man commits or omits (something in prayer), he should perform two prostrations, and he then himself performed two prostrations}}
\hadithdefcmd{muslim}{1288}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - حَدَّثَنَا أَيُّوبُ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ سِيرِينَ، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم إِحْدَى صَلاَتَىِ الْعَشِيِّ إِمَّا الظُّهْرَ وَإِمَّا الْعَصْرَ فَسَلَّمَ فِي رَكْعَتَيْنِ ثُمَّ أَتَى جِذْعًا فِي قِبْلَةِ الْمَسْجِدِ فَاسْتَنَدَ إِلَيْهَا مُغْضَبًا وَفِي الْقَوْمِ أَبُو بَكْرٍ وَعُمَرُ فَهَابَا أَنْ يَتَكَلَّمَا وَخَرَجَ سَرَعَانُ النَّاسِ قُصِرَتِ الصَّلاَةُ فَقَامَ ذُو الْيَدَيْنِ فَقَالَ يَا رَسُولَ اللَّهِ أَقُصِرَتِ الصَّلاَةُ أَمْ نَسِيتَ فَنَظَرَ النَّبِيُّ صلى الله عليه وسلم يَمِينًا وَشِمَالاً فَقَالَ ‏ "‏ مَا يَقُولُ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ قَالُوا صَدَقَ لَمْ تُصَلِّ إِلاَّ رَكْعَتَيْنِ ‏.‏ فَصَلَّى رَكْعَتَيْنِ وَسَلَّمَ ثُمَّ كَبَّرَ ثُمَّ سَجَدَ ثُمَّ كَبَّرَ فَرَفَعَ ثُمَّ كَبَّرَ وَسَجَدَ ثُمَّ كَبَّرَ وَرَفَعَ ‏.‏ قَالَ وَأُخْبِرْتُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ أَنَّهُ قَالَ وَسَلَّمَ ‏.‏\hadithno{1288}\hadithtrans{Ibn Sirin reported Abu Huraira as saying:The Messenger of Allah (ﷺ) led us in one of the two evening prayers, Zuhr or `Asr, and gave salutations after two rak`ahs and going towards a piece of wood which was placed to the direction of the Qibla in the mosque, leaned on it looking as if he were angry. Abu Bakr and `Umar were among the people and they were too afraid to speak to him and the people came out in haste (saying): The prayer has been shortened. But among them was a man called Dhul-Yadain who said: Messenger of Allah, has the prayer been shortened or have you forgotten? The Apostle of Allah (ﷺ) looked to the right and left and said: What was Dhul-Yadain saying? They said: He is right. You (the Holy Prophet) offered but two rak`ahs. He offered two (more) rak`ahs and gave salutation, then said takbir and prostrated and lifted (his head) and then said takbir and prostrated, then said takbir and lifted (his head). He (the narrator) says: It has been reported to me by `Imran b. Husain that he said: He (then) gave salutation}}
\hadithdefcmd{muslim}{1289}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم إِحْدَى صَلاَتَىِ الْعَشِيِّ ‏.‏ بِمَعْنَى حَدِيثِ سُفْيَانَ ‏.‏\hadithno{1289}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) led us in one of the evening prayers. And this hadith was narrated like one transmitted by Sufyan}}
\hadithdefcmd{muslim}{1290}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي سُفْيَانَ، مَوْلَى ابْنِ أَبِي أَحْمَدَ أَنَّهُ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْعَصْرِ فَسَلَّمَ فِي رَكْعَتَيْنِ فَقَامَ ذُو الْيَدَيْنِ فَقَالَ أَقُصِرَتِ الصَّلاَةُ يَا رَسُولَ اللَّهِ أَمْ نَسِيتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ ذَلِكَ لَمْ يَكُنْ ‏"‏ ‏.‏ فَقَالَ قَدْ كَانَ بَعْضُ ذَلِكَ يَا رَسُولَ اللَّهِ ‏.‏ فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النَّاسِ فَقَالَ ‏"‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالُوا نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ فَأَتَمَّ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا بَقِيَ مِنَ الصَّلاَةِ ثُمَّ سَجَدَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ بَعْدَ التَّسْلِيمِ ‏.‏\hadithno{1290}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) led us in the 'Asr prayer and gave salutation after two rak'ahs. Dhu'l-Yadain (the possessor of long arms) stood up and said: Messenger of Allah, has the prayer been shortened or have you forgotten? The Messenger of Allah (ﷺ) said: Nothing like this has happened (neither the prayer has been shortened nor have I forgotten). He (Dhu'l-Yadain) said: Messenger of Allah, something has definitely happened. The Messenger of Allah (ﷺ) turned towards people and said: Is Dhu'l-Yadain true (in his assertion)? They said: Messenger of Allah, he is true. Then the Messenger of Allah (ﷺ) completed the rest of the prayer. and then performed two prostrations while he was sitting after salutation}}
\hadithdefcmd{muslim}{1291}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا هَارُونُ بْنُ إِسْمَاعِيلَ الْخَزَّازُ، حَدَّثَنَا عَلِيٌّ، - وَهُوَ ابْنُ الْمُبَارَكِ - حَدَّثَنَا يَحْيَى، حَدَّثَنَا أَبُو سَلَمَةَ، حَدَّثَنَا أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى رَكْعَتَيْنِ مِنْ صَلاَةِ الظُّهْرِ ثُمَّ سَلَّمَ فَأَتَاهُ رَجُلٌ مِنْ بَنِي سُلَيْمٍ فَقَالَ يَا رَسُولَ اللَّهِ أَقُصِرَتِ الصَّلاَةُ أَمْ نَسِيتَ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{1291}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said two rak'ahs of the noon prayer and then gave salutation when a man from Band Sulaim came to him and said: Messenger of Allah. has the prayer been shortened, or have you forgotten? -and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1292}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَا أَنَا أُصَلِّي، مَعَ النَّبِيِّ صلى الله عليه وسلم صَلاَةَ الظُّهْرِ سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الرَّكْعَتَيْنِ فَقَامَ رَجُلٌ مِنْ بَنِي سُلَيْمٍ ‏.‏ وَاقْتَصَّ الْحَدِيثَ ‏.‏\hadithno{1292}\hadithtrans{Abu Huraira reported:I offered with the Messenger of Allah (ﷺ) the noon prayer and the Messenger of Allah (ﷺ) gave salutation after two rak'ahs. A person from Bani Sulaim stood up, and the rest of the hadith was narrated as mentioned above}}
\hadithdefcmd{muslim}{1293}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، - قَالَ زُهَيْرٌ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، - عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الْعَصْرَ فَسَلَّمَ فِي ثَلاَثِ رَكَعَاتٍ ثُمَّ دَخَلَ مَنْزِلَهُ فَقَامَ إِلَيْهِ رَجُلٌ يُقَالُ لَهُ الْخِرْبَاقُ وَكَانَ فِي يَدَيْهِ طُولٌ فَقَالَ يَا رَسُولَ اللَّهِ ‏.‏ فَذَكَرَ لَهُ صَنِيعَهُ ‏.‏ وَخَرَجَ غَضْبَانَ يَجُرُّ رِدَاءَهُ حَتَّى انْتَهَى إِلَى النَّاسِ فَقَالَ ‏ "‏ أَصَدَقَ هَذَا ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَصَلَّى رَكْعَةً ثُمَّ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1293}\hadithtrans{Imran b. Husain reported:The Messenger of Allah (ﷺ) said the afternoon prayer and gave the salutation. at the end of three rak'ahs and then went into his house. A man called al-Khirbaq, who bad long aims, got up and went to him, and addressed him as Messenger of Allah and mentioned to him what he had done. He came out angrily trailing his mantle, and when he came to the people he said: Is this man telling the truth? They said: Yes. He then said one rak'ah and then gave salutation and then performed two prostrations and then gave salutation}}
\hadithdefcmd{muslim}{1294}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا خَالِدٌ، - وَهُوَ الْحَذَّاءُ - عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، قَالَ سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَلاَثِ رَكَعَاتٍ مِنَ الْعَصْرِ ثُمَّ قَامَ فَدَخَلَ الْحُجْرَةَ فَقَامَ رَجُلٌ بَسِيطُ الْيَدَيْنِ فَقَالَ أَقُصِرَتِ الصَّلاَةُ يَا رَسُولَ اللَّهِ ‏.‏ فَخَرَجَ مُغْضَبًا فَصَلَّى الرَّكْعَةَ الَّتِي كَانَ تَرَكَ ثُمَّ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَىِ السَّهْوِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1294}\hadithtrans{Imran b. Husain reported:The Messenger of Allah (ﷺ) said three rak'ahs of the 'Asr prayer and then got up and went to his apartment. A man possessing large arms stood up and said: Messenger of Allah, bias the player been shortened? He came out angrily, and said the rak'ah which he had omitted and then gave salutation. then performed two prostrations of forgetfulness and then gave salutation}}
\hadithdefcmd{muslim}{1295}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، كُلُّهُمْ عَنْ يَحْيَى الْقَطَّانِ، - قَالَ زُهَيْرٌ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، - عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ الْقُرْآنَ فَيَقْرَأُ سُورَةً فِيهَا سَجْدَةٌ فَيَسْجُدُ وَنَسْجُدُ مَعَهُ حَتَّى مَا يَجِدُ بَعْضُنَا مَوْضِعًا لِمَكَانِ جَبْهَتِهِ ‏.‏\hadithno{1295}\hadithtrans{Ibn 'Umar reported:The Messenger of Allah (ﷺ) while reciting the Qur'an recited its surah containing sajda, and he performed prostration and we also prostrated along with him (but we were so overcrowded) that some of us could not find a place for our forehead (when prostrating ourselves)}}
\hadithdefcmd{muslim}{1296}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ رُبَّمَا قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْقُرْآنَ فَيَمُرُّ بِالسَّجْدَةِ فَيَسْجُدُ بِنَا حَتَّى ازْدَحَمْنَا عِنْدَهُ حَتَّى مَا يَجِدُ أَحَدُنَا مَكَانًا لِيَسْجُدَ فِيهِ فِي غَيْرِ صَلاَةٍ ‏.‏\hadithno{1296}\hadithtrans{Ibn 'Umar reported:Sometimes the Messenger of Allah (ﷺ) recited the Qur'an, and would pass by (recite) the verse of sajda and performed prostration and he did this along with us, but we were so crowded in his company that none of us could find a place for performing prostration. (and it was done on occasions) other than prayer}}
\hadithdefcmd{muslim}{1297}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الأَسْوَدَ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَ ‏\{‏ وَالنَّجْمِ‏\}‏ فَسَجَدَ فِيهَا وَسَجَدَ مَنْ كَانَ مَعَهُ غَيْرَ أَنَّ شَيْخًا أَخَذَ كَفًّا مِنْ حَصًى أَوْ تُرَابٍ فَرَفَعَهُ إِلَى جَبْهَتِهِ وَقَالَ يَكْفِينِي هَذَا ‏.‏ قَالَ عَبْدُ اللَّهِ لَقَدْ رَأَيْتُهُ بَعْدُ قُتِلَ كَافِرًا ‏.‏\hadithno{1297}\hadithtrans{Abdullah (b. 'Umar) reported:The Apostle of Allah (ﷺ) recited (Surat) al Najm and performed prostration during its recital and all those who were along with him also prostrated themselves except one old man who took a handful of pebbles or dust in his palm and lifted it to his forehead and said: This is sufficient for me. 'Abdullah said: I saw that he was later killed in a state of unbelief}}
\hadithdefcmd{muslim}{1298}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، وَهُوَ ابْنُ جَعْفَرٍ عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنِ ابْنِ قُسَيْطٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، سَأَلَ زَيْدَ بْنَ ثَابِتٍ عَنِ الْقِرَاءَةِ، مَعَ الإِمَامِ فَقَالَ لاَ قِرَاءَةَ مَعَ الإِمَامِ فِي شَىْءٍ ‏.‏ وَزَعَمَ أَنَّهُ قَرَأَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏\{‏ وَالنَّجْمِ إِذَا هَوَى‏\}‏ فَلَمْ يَسْجُدْ ‏.‏\hadithno{1298}\hadithtrans{ta' b. Yasar reported that he had asked Zaid b. Thabit about recital along with the Imam, to which he said:There should be no recital along with the Imam in anything, and alleged that he recited:" By the star when it sets" (Surah Najm) before the Messenger of Allah (ﷺ) and he did not prostrate himself}}
\hadithdefcmd{muslim}{1299}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَرَأَ لَهُمْ ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ فَسَجَدَ فِيهَا فَلَمَّا انْصَرَفَ أَخْبَرَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَجَدَ فِيهَا ‏.‏\hadithno{1299}\hadithtrans{Abu Salama b. 'Abual-Rahman reported:Abu Huraira recited before them:" hen the heaven burst asunder" (al-Qur'an, lxxxiv. 1) and performed prostration. After completing (the prayer) he informed them that the Messenger of Allah (ﷺ) has prostrated himself at it (this verse)}}
\hadithdefcmd{muslim}{1300}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، عَنِ الأَوْزَاعِيِّ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، كِلاَهُمَا عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1300}\hadithtrans{A hadith like this has been narrated by AbuSalama on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{1301}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَطَاءِ بْنِ مِينَاءَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ وَ ‏\{‏ اقْرَأْ بِاسْمِ رَبِّكَ‏\}‏\hadithno{1301}\hadithtrans{Abu Huraira reported:We performed prostration along with the Messenger of Allah (ﷺ) (as he recited these verses: )" When the heaven burst asunder" and" Read in the name of Thy Lord" (al-Qur'an, xcvi)}}
\hadithdefcmd{muslim}{1302}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، مَوْلَى بَنِي مَخْزُومٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ سَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ وَ ‏\{‏ اقْرَأْ بِاسْمِ رَبِّكَ‏\}‏\hadithno{1302}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) prostrated himself (while reciting these verses)." When the heaven burst asunder" ;" Read in the name of Thy Lord}}
\hadithdefcmd{muslim}{1303}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1303}\hadithtrans{A hadith like this has been transmitted by Abual-Rahman al-Araj on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{1304}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، عَنْ بَكْرٍ، عَنْ أَبِي رَافِعٍ، قَالَ صَلَّيْتُ مَعَ أَبِي هُرَيْرَةَ صَلاَةَ الْعَتَمَةِ فَقَرَأَ ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ فَسَجَدَ فِيهَا ‏.‏ فَقُلْتُ لَهُ مَا هَذِهِ السَّجْدَةُ فَقَالَ سَجَدْتُ بِهَا خَلْفَ أَبِي الْقَاسِمِ صلى الله عليه وسلم فَلاَ أَزَالُ أَسْجُدُ بِهَا حَتَّى أَلْقَاهُ ‏.‏ وَقَالَ ابْنُ عَبْدِ الأَعْلَى فَلاَ أَزَالُ أَسْجُدُهَا ‏.‏\hadithno{1304}\hadithtrans{Abu Rafi' reported:I said the night prayer along with Abu Huraira and -as he recited:" When the heaven burst asunder," he performed prostration. Isaid to him: What prostration is this? He said: I prostrated myself (on this occasion of recital) behind Abu'I-Qasim (Muhammad. may peace be upon him), and Iwould go on doing this till I meet him (in the next world). Ibn 'Abu al-A'la said: (Abu Huraira uttered this: ) I would not abandon performing prostration}}
\hadithdefcmd{muslim}{1305}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، ح قَالَ وَحَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - ح قَالَ وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا سُلَيْمُ بْنُ أَخْضَرَ، كُلُّهُمْ عَنِ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ غَيْرَ أَنَّهُمْ لَمْ يَقُولُوا خَلْفَ أَبِي الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{1305}\hadithtrans{This hadith has been narrated by Tamimi with the same chain of transmitters except for this that they made no mention of:" Behind Abu'l-Qasim" (ﷺ)}}
\hadithdefcmd{muslim}{1306}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَبِي رَافِعٍ، قَالَ رَأَيْتُ أَبَا هُرَيْرَةَ يَسْجُدُ فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ فَقُلْتُ تَسْجُدُ فِيهَا فَقَالَ نَعَمْ رَأَيْتُ خَلِيلِي صلى الله عليه وسلم يَسْجُدُ فِيهَا فَلاَ أَزَالُ أَسْجُدُ فِيهَا حَتَّى أَلْقَاهُ ‏.‏ قَالَ شُعْبَةُ قُلْتُ النَّبِيَّ صلى الله عليه وسلم ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{1306}\hadithtrans{Abu Rafi' reported:I saw Abu Huraira performing prostration (while reciting this verse: )" When the heaven burst asunder." I said to him: Do you prostrate yourself (while reciting) i? He said: Yes, I saw my best Friend (ﷺ) prostrating himself on (the recital of this verse) and I shall continue prostrating till I meet him. Shu'ba asked: Do you mean (by Friend) the Messenger of Allah (ﷺ)? He said: Yes}}
\hadithdefcmd{muslim}{1307}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرِ بْنِ رِبْعِيٍّ الْقَيْسِيُّ، حَدَّثَنَا أَبُو هِشَامٍ الْمَخْزُومِيُّ، عَنْ عَبْدِ الْوَاحِدِ، - وَهُوَ ابْنُ زِيَادٍ - حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، حَدَّثَنِي عَامِرُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَعَدَ فِي الصَّلاَةِ جَعَلَ قَدَمَهُ الْيُسْرَى بَيْنَ فَخِذِهِ وَسَاقِهِ وَفَرَشَ قَدَمَهُ الْيُمْنَى وَوَضَعَ يَدَهُ الْيُسْرَى عَلَى رُكْبَتِهِ الْيُسْرَى وَوَضَعَ يَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَأَشَارَ بِإِصْبَعِهِ ‏.‏\hadithno{1307}\hadithtrans{Abdullah b. Zubair narrated on the authority of his father:When the Messenger of Allah (ﷺ) sat in prayer. he placed the left foot between his thigh and shank and stretched the right foot and placed his left hand on his left knee and placed his right hand on his right thigh, and raised his finger}}
\hadithdefcmd{muslim}{1308}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ عَجْلاَنَ، ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَعَدَ يَدْعُو وَضَعَ يَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَيَدَهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى وَأَشَارَ بِإِصْبَعِهِ السَّبَّابَةِ وَوَضَعَ إِبْهَامَهُ عَلَى إِصْبَعِهِ الْوُسْطَى وَيُلْقِمُ كَفَّهُ الْيُسْرَى رُكْبَتَهُ ‏.‏\hadithno{1308}\hadithtrans{Abdullah b. Zubair narrated on the authority of his father that when the Messenger of Allah (ﷺ) sat for supplication, i. e. tashahhud (blessing and supplication), he placed his right hand on his right thigh and his left hand on his left thigh, and pointed with his forefinger, and placed his thumb on his (milddle) finger, and covered his knee with the palm of his left hand}}
\hadithdefcmd{muslim}{1309}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا جَلَسَ فِي الصَّلاَةِ وَضَعَ يَدَيْهِ عَلَى رُكْبَتَيْهِ وَرَفَعَ إِصْبَعَهُ الْيُمْنَى الَّتِي تَلِي الإِبْهَامَ فَدَعَا بِهَا وَيَدَهُ الْيُسْرَى عَلَى رُكْبَتِهِ الْيُسْرَى بَاسِطُهَا عَلَيْهَا ‏.‏\hadithno{1309}\hadithtrans{Ibn 'Umar reported that when the Messenger of Allah (ﷺ) sat for tashahhud he placed his left hand on his left knee. and his right hand on his right knee. and he raised his right finger, which is next to the thumb, making supplication in this way, and he stretched his left hand on his left knee}}
\hadithdefcmd{muslim}{1310}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَعَدَ فِي التَّشَهُّدِ وَضَعَ يَدَهُ الْيُسْرَى عَلَى رُكْبَتِهِ الْيُسْرَى وَوَضَعَ يَدَهُ الْيُمْنَى عَلَى رُكْبَتِهِ الْيُمْنَى وَعَقَدَ ثَلاَثَةً وَخَمْسِينَ وَأَشَارَ بِالسَّبَّابَةِ ‏.‏\hadithno{1310}\hadithtrans{Another version on the authority of Ibn Umar says:When the Messenger of Allah (ﷺ) sat for tashahhud, he placed his left hand on his left knee and placed his right hand on his right knee, and he formed a ring like (fifty-three) and pointed with his finger of attestation}}
\hadithdefcmd{muslim}{1311}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ عَلِيِّ بْنِ عَبْدِ الرَّحْمَنِ الْمُعَاوِيِّ، أَنَّهُ قَالَ رَآنِي عَبْدُ اللَّهِ بْنُ عُمَرَ وَأَنَا أَعْبَثُ بِالْحَصَى فِي الصَّلاَةِ فَلَمَّا انْصَرَفَ نَهَانِي فَقَالَ اصْنَعْ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏ فَقُلْتُ وَكَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ قَالَ كَانَ إِذَا جَلَسَ فِي الصَّلاَةِ وَضَعَ كَفَّهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَقَبَضَ أَصَابِعَهُ كُلَّهَا وَأَشَارَ بِإِصْبَعِهِ الَّتِي تَلِي الإِبْهَامَ وَوَضَعَ كَفَّهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى ‏.‏\hadithno{1311}\hadithtrans{Ali b. 'Abual-Rahman al-Mu'awi reported:'Abdullah b. Umar saw me playing with pebbles during prayer. After finishing the prayer he forbade me (to do it) and said: Do as the Messenger of Allah (ﷺ) used to do. I said: How did Allah's Messenger (ﷺ) do? He said that he (the Messenger of Allah) sat at tashahhud, placed his right palm on the right thigh and closed all his fingers and pointed with the help of finger next to the thumb, and placed his left palm on his left thigh}}
\hadithdefcmd{muslim}{1312}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ عَلِيِّ بْنِ عَبْدِ الرَّحْمَنِ الْمُعَاوِيِّ، قَالَ صَلَّيْتُ إِلَى جَنْبِ ابْنِ عُمَرَ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ مَالِكٍ وَزَادَ قَالَ سُفْيَانُ فَكَانَ يَحْيَى بْنُ سَعِيدٍ حَدَّثَنَا بِهِ عَنْ مُسْلِمٍ ثُمَّ حَدَّثَنِيهِ مُسْلِمٌ ‏.‏\hadithno{1312}\hadithtrans{This hadith has been narrated by another chain of transmitters}}
\hadithdefcmd{muslim}{1313}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، وَمَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، أَنَّ أَمِيرًا، كَانَ بِمَكَّةَ يُسَلِّمُ تَسْلِيمَتَيْنِ فَقَالَ عَبْدُ اللَّهِ أَنَّى عَلِقَهَا قَالَ الْحَكَمُ فِي حَدِيثِهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُهُ ‏.‏\hadithno{1313}\hadithtrans{Abu Ma'mar reported:There was an Amir in Mecca who pronounced taslim twice. Abdullah said: Where did he get this sunnah? Al-Hakam said: There is a hadith to the effect that the Messenger of Allah (ﷺ) did like It}}
\hadithdefcmd{muslim}{1314}{وَحَدَّثَنِي أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، - قَالَ شُعْبَةُ - رَفَعَهُ مَرَّةً - أَنَّ أَمِيرًا أَوْ رَجُلاً سَلَّمَ تَسْلِيمَتَيْنِ فَقَالَ عَبْدُ اللَّهِ أَنَّى عَلِقَهَا\hadithno{1314}\hadithtrans{Abdullah reported:An Amir or a person pronounced taslim twice. 'Abdullah said: Where did he get this sunnah?}}
\hadithdefcmd{muslim}{1315}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ كُنْتُ أَرَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ حَتَّى أَرَى بَيَاضَ خَدِّهِ ‏.‏\hadithno{1315}\hadithtrans{Amir b. Sa'd reported:I saw the Messenger of Allah (may peace be open him) pronouncing taslim on his right and on his left till I saw the whiteness of his cheek}}
\hadithdefcmd{muslim}{1316}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، قَالَ أَخْبَرَنِي بِذَا أَبُو مَعْبَدٍ، - ثُمَّ أَنْكَرَهُ بَعْدُ - عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنَّا نَعْرِفُ انْقِضَاءَ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالتَّكْبِيرِ ‏.‏\hadithno{1316}\hadithtrans{Ibn 'Abbas said:We used to know that Allah's Messenger (ﷺ) had finished his prayer when we heard the takbir (Allah-O-Akbar)}}
\hadithdefcmd{muslim}{1317}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّهُ سَمِعَهُ يُخْبِرُ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَا كُنَّا نَعْرِفُ انْقِضَاءَ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ بِالتَّكْبِيرِ ‏.‏ قَالَ عَمْرٌو فَذَكَرْتُ ذَلِكَ لأَبِي مَعْبَدٍ فَأَنْكَرَهُ وَقَالَ لَمْ أُحَدِّثْكَ بِهَذَا ‏.‏ قَالَ عَمْرٌو وَقَدْ أَخْبَرَنِيهِ قَبْلَ ذَلِكَ ‏.‏\hadithno{1317}\hadithtrans{Ibn 'Abbas reported:We knew the finishing of the prayer of the Messenger of Allah (ﷺ) through takbir. 'Amr (b. Dinar) said: I made a mention of it to Abu Mas'ud. hue he rejected it and said: I never narrated it to you. 'Amr said: He did narrate it before this}}
\hadithdefcmd{muslim}{1318}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح قَالَ وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّ أَبَا مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ أَخْبَرَهُ أَنَّ ابْنَ عَبَّاسٍ أَخْبَرَهُ أَنَّ رَفْعَ الصَّوْتِ بِالذِّكْرِ حِينَ يَنْصَرِفُ النَّاسُ مِنَ الْمَكْتُوبَةِ كَانَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَنَّهُ قَالَ قَالَ ابْنُ عَبَّاسٍ كُنْتُ أَعْلَمُ إِذَا انْصَرَفُوا بِذَلِكَ إِذَا سَمِعْتُهُ ‏.‏\hadithno{1318}\hadithtrans{Ibn 'Abbas reported:Dhikr (mentioning the name of Allah) in a loud voice after obligatory prayers was (a common practice) during the lifetime of the Messenger of Allah (ﷺ) ; and when I heard that I came to knew that they (the people) had finished the prayer}}
\hadithdefcmd{muslim}{1319}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالَ هَارُونُ حَدَّثَنَا وَقَالَ، حَرْمَلَةُ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي امْرَأَةٌ مِنَ الْيَهُودِ وَهْىَ تَقُولُ هَلْ شَعَرْتِ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ قَالَتْ فَارْتَاعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ إِنَّمَا تُفْتَنُ يَهُودُ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَلَبِثْنَا لَيَالِيَ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ شَعَرْتِ أَنَّهُ أُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدُ يَسْتَعِيذُ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{1319}\hadithtrans{A'isha reported:The Prophet (ﷺ) entered my house when a Jewess was with me and she was saying: Do you know that you would be put to trial in the grave? The Messenger of Allah (ﷺ) trembled (on hearing this) and said: It is the Jews only who would-be put to trial. 'A'isha said: We passed some nights and then the Messenger of Allah (ﷺ) said: Do you know that it has been revealed to me:" You would be put to trial in the grave"? 'A'isha said: 1 heard the Messenger of Allah (ﷺ) seeking refuge from the torment of the grave after this}}
\hadithdefcmd{muslim}{1320}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ، وَحَرْمَلَةُ بْنُ يَحْيَى، وَعَمْرُو بْنُ سَوَّادٍ، قَالَ حَرْمَلَةُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ يَسْتَعِيذُ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{1320}\hadithtrans{Abu Huraira reported. I heard the Messenger of Allah (ﷺ) seeking refuge from the torment of the grave after this (after the revelation)}}
\hadithdefcmd{muslim}{1321}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ جَرِيرٍ، قَالَ زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَتْ عَلَىَّ عَجُوزَانِ مِنْ عُجُزِ يَهُودِ الْمَدِينَةِ فَقَالَتَا إِنَّ أَهْلَ الْقُبُورِ يُعَذَّبُونَ فِي قُبُورِهِمْ ‏.‏ قَالَتْ فَكَذَّبْتُهُمَا وَلَمْ أُنْعِمْ أَنْ أُصَدِّقَهُمَا فَخَرَجَتَا وَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ يَا رَسُولَ اللَّهِ إِنَّ عَجُوزَيْنِ مِنْ عُجُزِ يَهُودِ الْمَدِينَةِ دَخَلَتَا عَلَىَّ فَزَعَمَتَا أَنَّ أَهْلَ الْقُبُورِ يُعَذَّبُونَ فِي قُبُورِهِمْ فَقَالَ ‏ "‏ صَدَقَتَا إِنَّهُمْ يُعَذَّبُونَ عَذَابًا تَسْمَعُهُ الْبَهَائِمُ ‏"‏ ‏.‏ قَالَتْ فَمَا رَأَيْتُهُ بَعْدُ فِي صَلاَةٍ إِلاَّ يَتَعَوَّذُ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{1321}\hadithtrans{A'isha reported:There came to me two old women from the old Jewesses of Medina and said: The people of the grave are tormented in their graves. I contradicted them and I did not deem it proper to testify them. They went away and the Messenger of Allah (ﷺ) came to me and I said to him: Messenger of Allah I there came to me two old women from the old Jewesses of Medina and asserted that the people of the graves would be tormented therein. He (the Prophet) said: They told the truth; they would be tormented (so much) that the animals would listen to it. She ('A'isha) said: Never did I see him (the Holy Prophet) afterwards but seeking refuge from the torment of the grave in prayer}}
\hadithdefcmd{muslim}{1322}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، بِهَذَا الْحَدِيثِ وَفِيهِ قَالَتْ وَمَا صَلَّى صَلاَةً بَعْدَ ذَلِكَ إِلاَّ سَمِعْتُهُ يَتَعَوَّذُ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{1322}\hadithtrans{Masruq reported this hadith on the authority of 'A'isha who said:Never did he (the Holy Prophet) say prayer after this in which I did not hear him seeking refuge from the torment of the grave}}
\hadithdefcmd{muslim}{1323}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَعِيذُ فِي صَلاَتِهِ مِنْ فِتْنَةِ الدَّجَّالِ ‏.‏\hadithno{1323}\hadithtrans{A'isha reported:1 heard the Messenger of Allah (ﷺ) seeking refuge from the trial of Dajjal (Antichrist) in prayer}}
\hadithdefcmd{muslim}{1324}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَابْنُ، نُمَيْرٍ وَأَبُو كُرَيْبٍ وَزُهَيْرُ بْنُ حَرْبٍ جَمِيعًا عَنْ وَكِيعٍ، - قَالَ أَبُو كُرَيْبٍ حَدَّثَنَا وَكِيعٌ، - حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ مُحَمَّدِ بْنِ أَبِي عَائِشَةَ، عَنْ أَبِي هُرَيْرَةَ، وَعَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَشَهَّدَ أَحَدُكُمْ فَلْيَسْتَعِذْ بِاللَّهِ مِنْ أَرْبَعٍ يَقُولُ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَمِنْ عَذَابِ الْقَبْرِ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَمِنْ شَرِّ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{1324}\hadithtrans{Abu Huraira reported:The Messenger of Allah (way peace be upon him) said: When any one of you utters tashahhud (in prayer) he must seek refuge with Allah from four (trials) and should thus say:" O Allah! I seek refuge with Thee from the torment of the Hell, from the torment of the grave, from the trial of life and death and from the evil of the trial of Masih al-Dajjal" (Antichrist)}}
\hadithdefcmd{muslim}{1325}{حَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدْعُو فِي الصَّلاَةِ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْمَأْثَمِ وَالْمَغْرَمِ ‏"‏ ‏.‏ قَالَتْ فَقَالَ لَهُ قَائِلٌ مَا أَكْثَرَ مَا تَسْتَعِيذُ مِنَ الْمَغْرَمِ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ إِنَّ الرَّجُلَ إِذَا غَرِمَ حَدَّثَ فَكَذَبَ وَوَعَدَ فَأَخْلَفَ ‏"‏ ‏.‏\hadithno{1325}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ) reported:The Apostle of Allah (ﷺ) used to supplicate in prayer thus:" O Allah! I seek refuge with Thee from the torment of the grave, and I seek refuge with Thee from the trial of the Masih al-Dajjal (Antichrist) and I seek refuge with Thee from the trial of life and death. O Allah! I seek refuge with Thee from sin and debt." She ('A'isha) reported: Someone said to him - (the Holy Prophet): Messenger of Allah! why is it that you so often seek refuge from debt? He said: When a (person) incurs debt, (he is obliged) to tell lies and break promise}}
\hadithdefcmd{muslim}{1326}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنِي الأَوْزَاعِيُّ، حَدَّثَنَا حَسَّانُ بْنُ عَطِيَّةَ، حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي عَائِشَةَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا فَرَغَ أَحَدُكُمْ مِنَ التَّشَهُّدِ الآخِرِ فَلْيَتَعَوَّذْ بِاللَّهِ مِنْ أَرْبَعٍ مِنْ عَذَابِ جَهَنَّمَ وَمِنْ عَذَابِ الْقَبْرِ وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَمِنْ شَرِّ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا هِقْلُ بْنُ زِيَادٍ، ح قَالَ وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - جَمِيعًا عَنِ الأَوْزَاعِيِّ، بِهَذَا الإِسْنَادِ وَقَالَ ‏"‏ إِذَا فَرَغَ أَحَدُكُمْ مِنَ التَّشَهُّدِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ ‏"‏ الآخِرَ ‏"‏ ‏.‏\hadithno{1326}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When any one of you completes the last tashahhud. he should seek refuge with Allah from four (trials). I.e. from the torment of Hell, from the torment of grave, from the trial of life and death, and from the mischief of Masih at-Dajjal (Antichrist). This hadith has been narrated by al-Auza'i with the same chain of transmitters but with these words:" When any one of you completes the tashahhud" and he made no mention of the words" the last}}
\hadithdefcmd{muslim}{1327}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَعَذَابِ النَّارِ وَفِتْنَةِ الْمَحْيَا وَالْمَمَاتِ وَشَرِّ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{1327}\hadithtrans{Abu Huraira reported:The Apostle of Allah (ﷺ) said: O Allah! I seek refuge with Thee from the torment of the grave, and the torment of Hell, and the trial of life and death and the mischief of Masih al-Dajjal}}
\hadithdefcmd{muslim}{1328}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عُوذُوا بِاللَّهِ مِنْ عَذَابِ اللَّهِ عُوذُوا بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ عُوذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ عُوذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{1328}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) as saying:Seek refuge with Allah from the torment of Hell, seek refuge with Allah from the torment of the grave, and seek refuge with Allah from the trial of Masih al-Dajjal and seek refuge with Allah from the trial of life and death}}
\hadithdefcmd{muslim}{1329}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1329}\hadithtrans{A hadith like this has been transmitted by Ibn Tawus from his father on the authority of AbuHuraira}}
\hadithdefcmd{muslim}{1330}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1330}\hadithtrans{A hadith like this has been transmitted by A'raj on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{1331}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ بُدَيْلٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَتَعَوَّذُ مِنْ عَذَابِ الْقَبْرِ وَعَذَابِ جَهَنَّمَ وَفِتْنَةِ الدَّجَّالِ ‏.‏\hadithno{1331}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) used to seek refuge from the torment of the grave, torment of Hell and the trial of Dajjal}}
\hadithdefcmd{muslim}{1333}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، - فِيمَا قُرِئَ عَلَيْهِ - عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعَلِّمُهُمْ هَذَا الدُّعَاءَ كَمَا يُعَلِّمُهُمُ السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ ‏ "‏ قُولُوا اللَّهُمَّ إِنَّا نَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏ قَالَ مُسْلِمُ بْنُ الْحَجَّاجِ بَلَغَنِي أَنَّ طَاوُسًا قَالَ لاِبْنِهِ أَدَعَوْتَ بِهَا فِي صَلاَتِكَ فَقَالَ لاَ ‏.‏ قَالَ أَعِدْ صَلاَتَكَ لأَنَّ طَاوُسًا رَوَاهُ عَنْ ثَلاَثَةٍ أَوْ أَرْبَعَةٍ أَوْ كَمَا قَالَ ‏.‏\hadithno{1333}\hadithtrans{Ibn 'Abbas reported that the Messenger of Allah (ﷺ) used to teach them this supplication (in the same spirit) with which he used to teach them a surah of the Qur'an. He would thus instruct us:"Say, O Allah, we seek refuge with Thee from the torment of Hell. And I seek refuge with Thee from the torment of the grave, and I seek refuge with Thee from the trial of al-Masih ad-Dajjal, and I seek refuge with Thee from the trial of life and death." Muslim b. Hajjaj said: It has reached me that Tawus said to his son: Did you make this supplication in prayer? He said: No. (Upon this) he (Tawus) said: Repeat the prayer. Tawus has narrated this hadith through three or four (transmitters) with words to the same effect}}
\hadithdefcmd{muslim}{1334}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنْ أَبِي عَمَّارٍ، - اسْمُهُ شَدَّادُ بْنُ عَبْدِ اللَّهِ - عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا انْصَرَفَ مِنْ صَلاَتِهِ اسْتَغْفَرَ ثَلاَثًا وَقَالَ ‏ "‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ تَبَارَكْتَ ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏ قَالَ الْوَلِيدُ فَقُلْتُ لِلأَوْزَاعِيِّ كَيْفَ الاِسْتِغْفَارُ قَالَ تَقُولُ أَسْتَغْفِرُ اللَّهَ أَسْتَغْفِرُ اللَّهَ ‏.‏\hadithno{1334}\hadithtrans{Thauban reported:When the Messenger of Allah (ﷺ) finished his prayer. He begged forgiveness three times and said: O Allah! Thou art Peace, and peace comes from Thee; Blessed art Thou, O Possessor of Glory and Honour. Walid reported: I said to Auza'i: How is the seeking of forgiveness? He replied: You should say: I beg forgiveness from Allah, I beg forgiveness from Allah}}
\hadithdefcmd{muslim}{1335}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا سَلَّمَ لَمْ يَقْعُدْ إِلاَّ مِقْدَارَ مَا يَقُولُ ‏"‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ تَبَارَكْتَ ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ نُمَيْرٍ ‏"‏ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{1335}\hadithtrans{A'isha reported:When the Messenger of Allah (ﷺ) pronounced salutation, he salutation longer than it took him to say: O Allah: Thou art Peace, and peace comes from Thee, blessed art Thou, Possessor of Glory and ]Honour; and in the narration of Ibn Numair the words are:" O Possessor of Glory and Honour}}
\hadithdefcmd{muslim}{1336}{وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي الأَحْمَرَ - عَنْ عَاصِمٍ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{1336}\hadithtrans{Ibn Numair narrated it with the same chain of transmitters and said:O Possessor of Glory and Honour}}
\hadithdefcmd{muslim}{1337}{وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، وَخَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، كِلاَهُمَا عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ كَانَ يَقُولُ ‏ "‏ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{1337}\hadithtrans{A hadith like this has been transmitted by Abdullah b. Harith on the authority of A'isha except for the words that he (the Holy Prophet) used to say:" 0 Possessor of Glory and Honour}}
\hadithdefcmd{muslim}{1338}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ وَرَّادٍ، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ قَالَ كَتَبَ الْمُغِيرَةُ بْنُ شُعْبَةَ إِلَى مُعَاوِيَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا فَرَغَ مِنَ الصَّلاَةِ وَسَلَّمَ قَالَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏\hadithno{1338}\hadithtrans{Mughira b. Shu'ba wrote to Mu'awiya:When the Messenger of Allah (ﷺ) finished the prayer and pronounced salutation he uttered (this supplication):" There is no god but Allah. He is alone, Who has no partner. To Him belongs the sovereignty and to Him praise is due and He is Potent over every. thing. O Allah! no one can withhold what Thou givest, or give what Thou withholdest, and the riches cannot avail a wealthy person with Thee}}
\hadithdefcmd{muslim}{1339}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَأَحْمَدُ بْنُ سِنَانٍ قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ وَرَّادٍ، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ الْمُغِيرَةِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ مِثْلَهُ قَالَ أَبُو بَكْرٍ وَأَبُو كُرَيْبٍ فِي رِوَايَتِهِمَا قَالَ فَأَمْلاَهَا عَلَىَّ الْمُغِيرَةُ وَكَتَبْتُ بِهَا إِلَى مُعَاوِيَةَ ‏.‏\hadithno{1339}\hadithtrans{A hadith like this has been narrated by Mughira b. Shu'ba with another chain of transmitters. Abu Bakr and Abu Kuraib narrated in their narration (that Warrad reported):Mughira gave me dictation of it and 1 wrote it to Mu'awiya}}
\hadithdefcmd{muslim}{1340}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدَةُ بْنُ أَبِي لُبَابَةَ، أَنَّ وَرَّادًا، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ قَالَ كَتَبَ الْمُغِيرَةُ بْنُ شُعْبَةَ إِلَى مُعَاوِيَةَ - كَتَبَ ذَلِكَ الْكِتَابَ لَهُ وَرَّادٌ - إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ حِينَ سَلَّمَ ‏.‏ بِمِثْلِ حَدِيثِهِمَا ‏.‏ إِلاَّ قَوْلَهُ ‏ "‏ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ فَإِنَّهُ لَمْ يَذْكُرْ ‏.‏\hadithno{1340}\hadithtrans{Warrad, the freed slave of Mughira b. Shu'ba, reported:Mughira b. Shu'ba wrote to Mu'awiya (it was Warrad who wrote this letter for him, i. e. Mughira): I heard the Messenger of Allah (ﷺ) saying:" When the salutation is pronounced." and the rest of the hadith is the same except this that he made no mention of:" He is Potent over everything}}
\hadithdefcmd{muslim}{1341}{وَحَدَّثَنَا حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي أَزْهَرُ، جَمِيعًا عَنِ ابْنِ عَوْنٍ، عَنْ أَبِي سَعِيدٍ، عَنْ وَرَّادٍ، كَاتِبِ الْمُغِيرَةِ بْنِ شُعْبَةَ قَالَ كَتَبَ مُعَاوِيَةُ إِلَى الْمُغِيرَةِ ‏.‏ بِمِثْلِ حَدِيثِ مَنْصُورٍ وَالأَعْمَشِ ‏.‏\hadithno{1341}\hadithtrans{Warrad, the scribe of Mughira b. Shu'ba, reported:Mu'awiya wrote to Mughira (the contents) of the hadith as transmitted by Mansur and A'mash}}
\hadithdefcmd{muslim}{1342}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَبْدَةُ بْنُ أَبِي لُبَابَةَ، وَعَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، سَمِعَا وَرَّادًا، كَاتِبَ الْمُغِيرَةِ بْنِ شُعْبَةَ يَقُولُ كَتَبَ مُعَاوِيَةُ إِلَى الْمُغِيرَةِ اكْتُبْ إِلَىَّ بِشَىْءٍ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَكَتَبَ إِلَيْهِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ إِذَا قَضَى الصَّلاَةَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏\hadithno{1342}\hadithtrans{Warrad, the scribe of Mughira b. Shu'ba, reported:Mu'awiya wrote to Mughira: Write to me anything which you heard from the Messenger of Allah (ﷺ). So he (Mughira) wrote to him (Mu'awiya): I heard the Messenger of Allah (ﷺ) uttering (these words) at the completion of prayer:" There is no god but Allah. He is alone and there is no partner with Him. Sovereignty belongs to Him and to Him is praise due and He is Potent over everything. O Allah! no one can withhold what Thou givest, or give what Thou withholdest, and riches cannot avail a wealthy person with Thee}}
\hadithdefcmd{muslim}{1343}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا هِشَامٌ، عَنْ أَبِي الزُّبَيْرِ، قَالَ كَانَ ابْنُ الزُّبَيْرِ يَقُولُ فِي دُبُرِ كُلِّ صَلاَةٍ حِينَ يُسَلِّمُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ لاَ إِلَهَ إِلاَّ اللَّهُ وَلاَ نَعْبُدُ إِلاَّ إِيَّاهُ لَهُ النِّعْمَةُ وَلَهُ الْفَضْلُ وَلَهُ الثَّنَاءُ الْحَسَنُ لاَ إِلَهَ إِلاَّ اللَّهُ مُخْلِصِينَ لَهُ الدِّينَ وَلَوْ كَرِهَ الْكَافِرُونَ ‏"‏ ‏.‏ وَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُهَلِّلُ بِهِنَّ دُبُرَ كُلِّ صَلاَةٍ ‏.‏\hadithno{1343}\hadithtrans{Abu Zubair reported:Ibn Zubair uttered at the end of every prayer after pronouncing salutation (these words):" There is no god but Allah. He is alone. There is no partner with Him. Sovereignty belongs to Him and He is Potent over everything. There is no might or power except with Allah. There is no god but Allah and we do not worship but Him alone. To Him belong all bounties, to Him belongs all Grace, and to Him is worthy praise accorded. There is no god but Allah, to Whom we are sincere in devotion, even though the unbelievers should disapprove it." (The narrator said): He (the Holy Prophet) uttered it at the end of every (obligatory) prayer}}
\hadithdefcmd{muslim}{1344}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِي الزُّبَيْرِ، مَوْلًى لَهُمْ أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، كَانَ يُهَلِّلُ دُبُرَ كُلِّ صَلاَةٍ ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ وَقَالَ فِي آخِرِهِ ثُمَّ يَقُولُ ابْنُ الزُّبَيْرِ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُهَلِّلُ بِهِنَّ دُبُرَ كُلِّ صَلاَةٍ ‏.‏\hadithno{1344}\hadithtrans{Abu Zubair reported:Abdullah b Zubair used to say La ilaha il-Allah at the end of every prayer like the hadith narrated by Ibn Numair and he reported it in the end, and then reported Ibn Zubair saying: The Messenger of Allah (ﷺ) uttered La ilaha il-Allah at the end of every prayer}}
\hadithdefcmd{muslim}{1345}{وَحَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا ابْنُ عُلَيَّةَ، حَدَّثَنَا الْحَجَّاجُ بْنُ أَبِي عُثْمَانَ، حَدَّثَنِي أَبُو الزُّبَيْرِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، يَخْطُبُ عَلَى هَذَا الْمِنْبَرِ وَهُوَ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ إِذَا سَلَّمَ فِي دُبُرِ الصَّلاَةِ أَوِ الصَّلَوَاتِ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ هِشَامِ بْنِ عُرْوَةَ ‏.‏\hadithno{1345}\hadithtrans{Abu Zubair reported:I heard Abdullah b. Zubair addressing (people) on the pulpit and saying: When the Messenger of Allah (ﷺ) pronounced salutation at the end of the prayer or prayers, and then he made a mention of the hadith as transmitted by Hisham b. 'Urwa}}
\hadithdefcmd{muslim}{1346}{وَحَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ سَالِمٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، أَنَّ أَبَا الزُّبَيْرِ الْمَكِّيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، وَهُوَ يَقُولُ فِي إِثْرِ الصَّلاَةِ إِذَا سَلَّمَ ‏.‏ بِمِثْلِ حَدِيثِهِمَا وَقَالَ فِي آخِرِهِ وَكَانَ يَذْكُرُ ذَلِكَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1346}\hadithtrans{Abu Zubair al-Makki reported that he had heard 'Abdullah b. Zubair uttering (the words) like that of the hadith (narrated above) at the end of the prayer after pronouncing salutation. He at the conclusion also said that he was making a mention of that from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1347}{حَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا الْمُعْتَمِرُ، حَدَّثَنَا عُبَيْدُ اللَّهِ، ح قَالَ وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ عَجْلاَنَ، كِلاَهُمَا عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، - وَهَذَا حَدِيثُ قُتَيْبَةَ أَنَّ فُقَرَاءَ، الْمُهَاجِرِينَ أَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالُوا ذَهَبَ أَهْلُ الدُّثُورِ بِالدَّرَجَاتِ الْعُلَى وَالنَّعِيمِ الْمُقِيمِ ‏.‏ فَقَالَ ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالُوا يُصَلُّونَ كَمَا نُصَلِّي وَيَصُومُونَ كَمَا نَصُومُ وَيَتَصَدَّقُونَ وَلاَ نَتَصَدَّقُ وَيُعْتِقُونَ وَلاَ نُعْتِقُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفَلاَ أُعَلِّمُكُمْ شَيْئًا تُدْرِكُونَ بِهِ مَنْ سَبَقَكُمْ وَتَسْبِقُونَ بِهِ مَنْ بَعْدَكُمْ وَلاَ يَكُونُ أَحَدٌ أَفْضَلَ مِنْكُمْ إِلاَّ مَنْ صَنَعَ مِثْلَ مَا صَنَعْتُمْ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ تُسَبِّحُونَ وَتُكَبِّرُونَ وَتَحْمَدُونَ دُبُرَ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ مَرَّةً ‏"‏ ‏.‏ قَالَ أَبُو صَالِحٍ فَرَجَعَ فُقَرَاءُ الْمُهَاجِرِينَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا سَمِعَ إِخْوَانُنَا أَهْلُ الأَمْوَالِ بِمَا فَعَلْنَا فَفَعَلُوا مِثْلَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَلِكَ فَضْلُ اللَّهِ يُؤْتِيهِ مَنْ يَشَاءُ ‏"‏ ‏.‏ وَزَادَ غَيْرُ قُتَيْبَةَ فِي هَذَا الْحَدِيثِ عَنِ اللَّيْثِ عَنِ ابْنِ عَجْلاَنَ قَالَ سُمَىٌّ فَحَدَّثْتُ بَعْضَ أَهْلِي هَذَا الْحَدِيثَ فَقَالَ وَهِمْتَ إِنَّمَا قَالَ ‏"‏ تُسَبِّحُ اللَّهَ ثَلاَثًا وَثَلاَثِينَ وَتَحْمَدُ اللَّهَ ثَلاَثًا وَثَلاَثِينَ وَتُكَبِّرُ اللَّهَ ثَلاَثًا وَثَلاَثِينَ ‏"‏ ‏.‏ فَرَجَعْتُ إِلَى أَبِي صَالِحٍ فَقُلْتُ لَهُ ذَلِكَ فَأَخَذَ بِيَدِي فَقَالَ اللَّهُ أَكْبَرُ وَسُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَاللَّهُ أَكْبَرُ وَسُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ حَتَّى تَبْلُغَ مِنْ جَمِيعِهِنَّ ثَلاَثَةً وَثَلاَثِينَ ‏.‏ قَالَ ابْنُ عَجْلاَنَ فَحَدَّثْتُ بِهَذَا الْحَدِيثِ رَجَاءَ بْنَ حَيْوَةَ فَحَدَّثَنِي بِمِثْلِهِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1347}\hadithtrans{Abu Huraira reported:The poor amongst the emigrants came to the Messenger of Allah (ﷺ) and said: The possessors of great wealth have obtained the highest ranks and the lasting bliss. He (the Holy Prophet) said: How is that? They said: They pray as we pray, and they observe fast as we observe fast, and they give charity but we do not give charity, and they set slaves free but we do not set slaves free. Upon this the Messenger of Allah (ﷺ) said: Shall I not teach you something by which you will catch upon those who have preceded you, and get ahead of those who come after you, only those who do as you do being more excellent than you? They said: Yes, Messenger of Allah. He (the Holy Prophet) said: Extol Allah, declare His Greatness, and Praise Him thirty-three times after every prayer. Abu Salih said: The poor amongst the emigrants returned to the Messenger of Allah (may peace upon him) saying: Our brethren, the possessors, of property have heard what we have done and they did the same. So the Messenger of Allah (ﷺ) said: This is Allah's Grace which He gives to whom He wishes. Sumayy reported: I made a mention of this hadith to some members of my family (and one of them) said: You have forgotten; he (the Holy Prophet) had said (like this): "Extol Allah thirty-three time, praise Allah thirty-three times and declare His Greatness thirty-three times." Ibn `Ajlan said: I made a mention of this hadith to Raja' b. Haiwa and he narrated to me a hadith like this from Abu Salih from the Messenger of Allah (ﷺ) on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{1348}{وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ ذَهَبَ أَهْلُ الدُّثُورِ بِالدَّرَجَاتِ الْعُلَى وَالنَّعِيمِ الْمُقِيمِ ‏.‏ بِمِثْلِ حَدِيثِ قُتَيْبَةَ عَنِ اللَّيْثِ إِلاَّ أَنَّهُ أَدْرَجَ فِي حَدِيثِ أَبِي هُرَيْرَةَ قَوْلَ أَبِي صَالِحٍ ثُمَّ رَجَعَ فُقَرَاءُ الْمُهَاجِرِينَ ‏.‏ إِلَى آخِرِ الْحَدِيثِ وَزَادَ فِي الْحَدِيثِ يَقُولُ سُهَيْلٌ إِحْدَى عَشْرَةَ إِحْدَى عَشْرَةَ فَجَمِيعُ ذَلِكَ كُلِّهُ ثَلاَثَةٌ وَثَلاَثُونَ ‏.‏\hadithno{1348}\hadithtrans{Abu Huraira narrated it from the Messenger of Allah (ﷺ) that they (the poor among the emigrants) said:Messenger of Allah, the possessors of great wealth have obtained the highest ranks and lasting bliss, and the rest of the hadith is the same as transmitted by Qutaiba on the authority of Laith except that he inserted the words of Abu Salih in the narration of Abu Huraira that" the poor of the emigrants came back," to the end of the hadith,, but this addition was made that Suhail said (that every part of the supplication, i. e. Glorification of Allah, His Praise and declaration of His Greatness) should be uttered eleven times making the total as thirty-three}}
\hadithdefcmd{muslim}{1349}{وَحَدَّثَنَا الْحَسَنُ بْنُ عِيسَى، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا مَالِكُ بْنُ مِغْوَلٍ، قَالَ سَمِعْتُ الْحَكَمَ بْنَ عُتَيْبَةَ، يُحَدِّثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مُعَقِّبَاتٌ لاَ يَخِيبُ قَائِلُهُنَّ - أَوْ فَاعِلُهُنَّ - دُبُرَ كُلِّ صَلاَةٍ مَكْتُوبَةٍ ثَلاَثٌ وَثَلاَثُونَ تَسْبِيحَةً وَثَلاَثٌ وَثَلاَثُونَ تَحْمِيدَةً وَأَرْبَعٌ وَثَلاَثُونَ تَكْبِيرَةً ‏"‏ ‏.‏\hadithno{1349}\hadithtrans{Ka'b b. 'Ujra reported Allah's Messenger (ﷺ) as saying:There are certain ejaculations, the repeaters of which or the performers of which after every prescribed prayer will never be caused disappointment:" Glory be to Allah" thirty-three times." Praise be to Allah" thirty-three times, and" Allah is most Great" thirty-four times}}
\hadithdefcmd{muslim}{1352}{حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ سُهَيْلٍ، عَنْ أَبِي عُبَيْدٍ الْمَذْحِجِيِّ، - قَالَ مُسْلِمٌ أَبُو عُبَيْدٍ مَوْلَى سُلَيْمَانَ بْنِ عَبْدِ الْمَلِكِ - عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَبَّحَ اللَّهَ فِي دُبُرِ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَحَمِدَ اللَّهَ ثَلاَثًا وَثَلاَثِينَ وَكَبَّرَ اللَّهَ ثَلاَثًا وَثَلاَثِينَ فَتِلْكَ تِسْعَةٌ وَتِسْعُونَ وَقَالَ تَمَامَ الْمِائَةِ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ غُفِرَتْ خَطَايَاهُ وَإِنْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{1352}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If anyone extols Allah after every prayer thirty-three times, and praises Allah thirty-three times, and declares His Greatness thirty-three times, ninety-nine times in all, and says to complete a hundred:" There is no god but Allah, having no partner with Him, to Him belongs sovereignty and to Him is praise due, and He is Potent over everything," his sins will be forgiven even If these are as abundant as the foam of the sea}}
\hadithdefcmd{muslim}{1353}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنْ سُهَيْلٍ، عَنْ أَبِي عُبَيْدٍ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1353}\hadithtrans{This hadith has been narrated by Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{1356}{قَالَ مُسْلِمٌ وَحُدِّثْتُ عَنْ يَحْيَى بْنِ حَسَّانَ، وَيُونُسَ الْمُؤَدِّبِ، و غَيْرِهِمَا قَالُوا حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، قَالَ حَدَّثَنِي عُمَارَةُ بْنُ الْقَعْقَاعِ، حَدَّثَنَا أَبُو زُرْعَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا نَهَضَ مِنَ الرَّكْعَةِ الثَّانِيَةِ اسْتَفْتَحَ الْقِرَاءَةَ بِـ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ وَلَمْ يَسْكُتْ ‏.‏\hadithno{1356}\hadithtrans{Abu Huraira reported that when the Messenger of Allah (ﷺ) stood up for the second rak'ah he opened it with the recitation of the praise of Allah, the Lord of universe (al-Fatiha), and he did not observe silence (before the recitation of al-Fatiha)}}
\hadithdefcmd{muslim}{1357}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا قَتَادَةُ، وَثَابِتٌ، وَحُمَيْدٌ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، جَاءَ فَدَخَلَ الصَّفَّ وَقَدْ حَفَزَهُ النَّفَسُ فَقَالَ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ ‏.‏ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَتَهُ قَالَ ‏"‏ أَيُّكُمُ الْمُتَكَلِّمُ بِالْكَلِمَاتِ ‏"‏ ‏.‏ فَأَرَمَّ الْقَوْمُ فَقَالَ ‏"‏ أَيُّكُمُ الْمُتَكَلِّمُ بِهَا فَإِنَّهُ لَمْ يَقُلْ بَأْسًا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ جِئْتُ وَقَدْ حَفَزَنِي النَّفَسُ فَقُلْتُهَا ‏.‏ فَقَالَ ‏"‏ لَقَدْ رَأَيْتُ اثْنَىْ عَشَرَ مَلَكًا يَبْتَدِرُونَهَا أَيُّهُمْ يَرْفَعُهَا ‏"‏ ‏.‏\hadithno{1357}\hadithtrans{Anas reported:A man came panting and entered the row of worshippers and said: Praise be to Allah, much praised and blessed. When the Messenger of Allah (ﷺ) finished the prayer he said: Who amongst you uttered these words? The people remained silent. He (the Prophet again said) -: Who amongst you uttered these words? He said nothing wrong. Then a man said: I came and had a difficulty in breathing, so I uttered them. He replied: I saw twelve angels facing one another as to who will take them up (to Allah)}}
\hadithdefcmd{muslim}{1358}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، أَخْبَرَنِي الْحَجَّاجُ بْنُ أَبِي عُثْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عُمَرَ، قَالَ بَيْنَمَا نَحْنُ نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ قَالَ رَجُلٌ مِنَ الْقَوْمِ اللَّهُ أَكْبَرُ كَبِيرًا وَالْحَمْدُ لِلَّهِ كَثِيرًا وَسُبْحَانَ اللَّهِ بُكْرَةً وَأَصِيلاً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ الْقَائِلُ كَلِمَةَ كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَ رَجُلٌ مِنَ الْقَوْمِ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ عَجِبْتُ لَهَا فُتِحَتْ لَهَا أَبْوَابُ السَّمَاءِ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ فَمَا تَرَكْتُهُنَّ مُنْذُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ذَلِكَ ‏\hadithno{1358}\hadithtrans{Ibn 'Umar reported:While we said prayer with the Messenger of Allah (ﷺ), one among the people said: Allah is truly Great, praise be to Allah in abundance. Glory be to Allah in the morning and the evening. The Messenger of Allah (may peace be upon, him) said: Who uttered such and such a word? A person among the people said: It is I, Messenger of Allah (who have recited these words). He (the Holy Prophet) said: It (its utterance) surprised me, for the doors of heaven were opened for It. Ibn 'Umar said: I have not abandoned them (these words) since I heard the Messenger of Allah (ﷺ) saying this}}
\hadithdefcmd{muslim}{1359}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح قَالَ وَحَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ، أَخْبَرَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح قَالَ وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَأْتُوهَا تَسْعَوْنَ وَأْتُوهَا تَمْشُونَ وَعَلَيْكُمُ السَّكِينَةُ فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَأَتِمُّوا ‏"‏ ‏.‏\hadithno{1359}\hadithtrans{Abu Huraira reported:I heard the Messenger of Allah (ﷺ) saying: When the Iqama has been pronounced for prayer, do not go running to it, but go walking in tranquillity and pray what you are in time for, and complete what you have missed}}
\hadithdefcmd{muslim}{1360}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، - أَخْبَرَنِي الْعَلاَءُ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا ثُوِّبَ لِلصَّلاَةِ فَلاَ تَأْتُوهَا وَأَنْتُمْ تَسْعَوْنَ وَأْتُوهَا وَعَلَيْكُمُ السَّكِينَةُ فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَأَتِمُّوا فَإِنَّ أَحَدَكُمْ إِذَا كَانَ يَعْمِدُ إِلَى الصَّلاَةِ فَهُوَ فِي صَلاَةٍ ‏"‏ ‏.‏\hadithno{1360}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) said:When the words of Iqama are pronounced, do not come to (prayer) running, but go with tranquillity, and pray what you are in time for, and complete (what you have missed) for when one of you is preparing for prayer he is in fact engaged in prayer}}
\hadithdefcmd{muslim}{1361}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا نُودِيَ بِالصَّلاَةِ فَأْتُوهَا وَأَنْتُمْ تَمْشُونَ وَعَلَيْكُمُ السَّكِينَةُ فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَأَتِمُّوا ‏"‏ ‏.‏\hadithno{1361}\hadithtrans{Abu Huraira reported ahadith from the Messenger of Allah (ﷺ), and one of them is that the Messenger of Allah (may peace be upon), said:When the call is made for prayer come to it walking with tranquillity, and pray what you are in time for, and complete what you have missed}}
\hadithdefcmd{muslim}{1362}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْفُضَيْلُ، - يَعْنِي ابْنَ عِيَاضٍ - عَنْ هِشَامٍ، ح قَالَ وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا ثُوِّبَ بِالصَّلاَةِ فَلاَ يَسْعَ إِلَيْهَا أَحَدُكُمْ وَلَكِنْ لِيَمْشِ وَعَلَيْهِ السَّكِينَةُ وَالْوَقَارُ صَلِّ مَا أَدْرَكْتَ وَاقْضِ مَا سَبَقَكَ ‏"‏ ‏.‏\hadithno{1362}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When the words of Iqama are pronounced, none of you should run to it (to join the prayer) but walk with tranquillity and dignity, and pray what you are in time for and complete what has gone before (what the Imam has completed)}}
\hadithdefcmd{muslim}{1363}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ الصُّورِيُّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، أَنَّ أَبَاهُ، أَخْبَرَهُ قَالَ بَيْنَمَا نَحْنُ نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَمِعَ جَلَبَةً ‏.‏ فَقَالَ ‏"‏ مَا شَأْنُكُمْ ‏"‏ ‏.‏ قَالُوا اسْتَعْجَلْنَا إِلَى الصَّلاَةِ ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلُوا إِذَا أَتَيْتُمُ الصَّلاَةَ فَعَلَيْكُمُ السَّكِينَةُ فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا سَبَقَكُمْ فَأَتِمُّوا ‏"‏ ‏.‏\hadithno{1363}\hadithtrans{Abdullah b. Abu Qatada reported on the authority of his father:While we said our prayer with the Messenger of Allah (ﷺ) he heard tumult. (At the end of the prayer) he (the Holy Prophet) said: What is the matter with you? They said: We hastened to prayer. He (the Holy Prophet) said: Don't do that; when you come for prayer, there should be tranquillity upon you. Pray (along with the Imam) what you can find and complete what preceded you}}
\hadithdefcmd{muslim}{1364}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا شَيْبَانُ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1364}\hadithtrans{This hadith has been narrated by Shaiban with the same chain of transmitters}}
\hadithdefcmd{muslim}{1367}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ أُقِيمَتِ الصَّلاَةُ فَقُمْنَا فَعَدَّلْنَا الصُّفُوفَ قَبْلَ أَنْ يَخْرُجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا قَامَ فِي مُصَلاَّهُ قَبْلَ أَنْ يُكَبِّرَ ذَكَرَ فَانْصَرَفَ وَقَالَ لَنَا ‏ "‏ مَكَانَكُمْ ‏"‏ ‏.‏ فَلَمْ نَزَلْ قِيَامًا نَنْتَظِرُهُ حَتَّى خَرَجَ إِلَيْنَا وَقَدِ اغْتَسَلَ يَنْطِفُ رَأْسُهُ مَاءً فَكَبَّرَ فَصَلَّى بِنَا ‏.‏\hadithno{1367}\hadithtrans{Abu Salama son of Abd al-Rahman b. Auf reported Abu Huraira as saying:Iqama was pronounced and we stood up and made rows straight till he (the Holy Prophet) stood at his place of worship (the place ahead of the rows where he stood to lead the prayer) before takbir tahrima. He reminded to (himself something) and went back saying that we should stand at our places and not leave them. We waited, till he came back to us and he had taken a bath and water trickled out of his head and then led us in prayer}}
\hadithdefcmd{muslim}{1368}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو عَمْرٍو، - يَعْنِي الأَوْزَاعِيَّ - حَدَّثَنَا الزُّهْرِيُّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُقِيمَتِ الصَّلاَةُ وَصَفَّ النَّاسُ صُفُوفَهُمْ وَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَامَ مَقَامَهُ فَأَوْمَأَ إِلَيْهِمْ بِيَدِهِ أَنْ ‏ "‏ مَكَانَكُمْ ‏"‏ ‏.‏ فَخَرَجَ وَقَدِ اغْتَسَلَ وَرَأْسُهُ يَنْطِفُ الْمَاءَ فَصَلَّى بِهِمْ ‏.‏\hadithno{1368}\hadithtrans{Abu Salama reported Abu Huraira as saying:Iqama was pronounced. ant the people had formed themselves into rows. The Messenger of Allah (ﷺ) came out and stood at his place, and then pointed out with his hand that we should stand at our places. He then went away and took a bath and water trickled from his head and then led them in prayer}}
\hadithdefcmd{muslim}{1369}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ الصَّلاَةَ، كَانَتْ تُقَامُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَيَأْخُذُ النَّاسُ مَصَافَّهُمْ قَبْلَ أَنْ يَقُومَ النَّبِيُّ صلى الله عليه وسلم مَقَامَهُ ‏.‏\hadithno{1369}\hadithtrans{Abu Salama reported on the authority of Abu Huraira that when Iqama was pronounced for the Messenger of Allah (ﷺ), the people occupied their places in the rows before the Messenger of Allah (way peace be upon him) stood up at his place}}
\hadithdefcmd{muslim}{1370}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ بِلاَلٌ يُؤَذِّنُ إِذَا دَحَضَتْ فَلاَ يُقِيمُ حَتَّى يَخْرُجَ النَّبِيُّ صلى الله عليه وسلم فَإِذَا خَرَجَ أَقَامَ الصَّلاَةَ حِينَ يَرَاهُ ‏.‏\hadithno{1370}\hadithtrans{Jabir b. Samura reported:Bilal summoned to prayer as the sun declined but did not pronounce Iqama till the Messenger of Allah (ﷺ) came out and the Iqama was pronounced on seeing him}}
\hadithdefcmd{muslim}{1371}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنَ الصَّلاَةِ فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{1371}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) as saying:He who finds a rak'ah of the prayer, he in fact finds the prayer}}
\hadithdefcmd{muslim}{1372}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنَ الصَّلاَةِ مَعَ الإِمَامِ فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{1372}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) as saying:He who finds one rak'ah of the prayer with the Imam, he in fact finds the prayer}}
\hadithdefcmd{muslim}{1373}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا ابْنُ عُيَيْنَةَ، ح قَالَ وَحَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، وَالأَوْزَاعِيِّ، وَمَالِكِ بْنِ أَنَسٍ، وَيُونُسَ، ح قَالَ وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، قَالَ وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، جَمِيعًا عَنْ عُبَيْدِ اللَّهِ، كُلُّ هَؤُلاَءِ عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ يَحْيَى عَنْ مَالِكٍ وَلَيْسَ فِي حَدِيثِ أَحَدٍ مِنْهُمْ ‏"‏ مَعَ الإِمَامِ ‏"‏ ‏.‏ وَفِي حَدِيثِ عُبَيْدِ اللَّهِ قَالَ ‏"‏ فَقَدْ أَدْرَكَ الصَّلاَةَ كُلَّهَا ‏"‏ ‏.‏\hadithno{1373}\hadithtrans{This hadith has been narrated on the authority of Malik and there is no mention of" along with the Imam" and In the hadith transmitted by Abdullah the words are:" he in fact finds the entire prayer}}
\hadithdefcmd{muslim}{1374}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، وَعَنْ بُسْرِ بْنِ سَعِيدٍ، وَعَنِ الأَعْرَجِ، حَدَّثُوهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنَ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَ الصُّبْحَ وَمَنْ أَدْرَكَ رَكْعَةً مِنَ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَ الْعَصْرَ ‏"‏ ‏\hadithno{1374}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: He who finds one rak'ah at dawn before the rising of the sun, he in fact finds the dawn prayer. and he who finds one rak'ah of the afternoon prayer before sunset, he in fact finds the afternoon prayer}}
\hadithdefcmd{muslim}{1375}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ عَنْ زَيْدِ بْنِ أَسْلَمَ، ‏\hadithno{1375}\hadithtrans{This hadith is narrated by Abu Huraira with another chain of transmitters}}
\hadithdefcmd{muslim}{1376}{وَحَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنَا عُرْوَةُ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ح قَالَ وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، كِلاَهُمَا عَنِ ابْنِ وَهْبٍ، - وَالسِّيَاقُ لِحَرْمَلَةَ - قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَدْرَكَ مِنَ الْعَصْرِ سَجْدَةً قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ أَوْ مِنَ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ فَقَدْ أَدْرَكَهَا ‏"‏ ‏.‏ وَالسَّجْدَةُ إِنَّمَا هِيَ الرَّكْعَةُ ‏.‏\hadithno{1376}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) said: He who finds a prostration before sunset or at dawn (prayer) before the rising (of the sun) he in fact finds that (prayer), and prostration implies a rak'ah}}
\hadithdefcmd{muslim}{1377}{وَحَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَدْرَكَ مِنَ الْعَصْرِ رَكْعَةً قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَ وَمَنْ أَدْرَكَ مِنَ الْفَجْرِ رَكْعَةً قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَ ‏"‏ ‏.‏\hadithno{1377}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: He who finds (gets) a rak'ah of the afternoon (prayer) before the setting of the sun, he in fact gets (the full prayer), and he who gets a rak'ah of the morning (prayer) before the rising of the sun he in fact gets (the full prayer)}}
\hadithdefcmd{muslim}{1378}{وَحَدَّثَنَاهُ عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ مَعْمَرًا، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1378}\hadithtrans{This hadith has been reported by Ma'mar with another chain of transmitters}}
\hadithdefcmd{muslim}{1379}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح قَالَ وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخَّرَ الْعَصْرَ شَيْئًا فَقَالَ لَهُ عُرْوَةُ أَمَا إِنَّ جِبْرِيلَ قَدْ نَزَلَ فَصَلَّى إِمَامَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ لَهُ عُمَرُ اعْلَمْ مَا تَقُولُ يَا عُرْوَةُ ‏.‏ فَقَالَ سَمِعْتُ بَشِيرَ بْنَ أَبِي مَسْعُودٍ يَقُولُ سَمِعْتُ أَبَا مَسْعُودٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نَزَلَ جِبْرِيلُ فَأَمَّنِي فَصَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ‏"‏ ‏.‏ يَحْسُبُ بِأَصَابِعِهِ خَمْسَ صَلَوَاتٍ ‏.‏\hadithno{1379}\hadithtrans{Ibn Shibab reported:'Umar b. 'Abd al-'Aziz deferred the afternoon prayer somewhat and 'Urwa said to him: Gabriel came down and he led the Messenger of Allah (ﷺ) in prayer. 'Umar said to him: O 'Urwa, are you aware of what you are saying? Upon this he ('Urwa) said: I heard Bashir b. Abu Mas'ud say that he heard Abu Mas'ud say that he heard the Messenger of Allah (ﷺ) say: Gabriel came down and acted as my Imam, then I prayed with him, then I prayed with him, then I prayed with him. then I prayed with him. then I prayed with him. reckoning with his fingers five times of prayer}}
\hadithdefcmd{muslim}{1380}{أَخْبَرَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخَّرَ الصَّلاَةَ يَوْمًا فَدَخَلَ عَلَيْهِ عُرْوَةُ بْنُ الزُّبَيْرِ فَأَخْبَرَهُ أَنَّ الْمُغِيرَةَ بْنَ شُعْبَةَ أَخَّرَ الصَّلاَةَ يَوْمًا وَهُوَ بِالْكُوفَةِ فَدَخَلَ عَلَيْهِ أَبُو مَسْعُودٍ الأَنْصَارِيُّ فَقَالَ مَا هَذَا يَا مُغِيرَةُ أَلَيْسَ قَدْ عَلِمْتَ أَنَّ جِبْرِيلَ نَزَلَ فَصَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ بِهَذَا أُمِرْتُ ‏"‏ ‏.‏ فَقَالَ عُمَرُ لِعُرْوَةَ انْظُرْ مَا تُحَدِّثُ يَا عُرْوَةُ أَوَإِنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ هُوَ أَقَامَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَقْتَ الصَّلاَةِ فَقَالَ عُرْوَةُ كَذَلِكَ كَانَ بَشِيرُ بْنُ أَبِي مَسْعُودٍ يُحَدِّثُ عَنْ أَبِيهِ ‏.‏\hadithno{1380}\hadithtrans{Ibn Shihab reported:Umar b. 'Abd al-'Aziz one day deferred the prayer. 'Urwa b. Zubair came to him and informed him that one day as Mughira b. Shu'ba was in Kufa (as its governor), he deferred the prayer, Abu Mas'ud al-Ansari came to him and said: What is this, O Mughira? Did you know that it was Gabriel who came and said prayer and (then) the Messenger of Allah (ﷺ) said the prayer (along with him), then (Gabriel) prayed and the Messenger of Allah (ﷺ) also prayed, then (Gabriel) prayed and the Messenger of Allah (ﷺ) also prayed, then (Gabriel) prayed and the Messenger of Allah (ﷺ) prayed (along with him). then Gabriel prayed and the Messenger of Allah (ﷺ) also prayed (along with him) and then said: This is how I have been ordered to do. 'Umar (b. 'Abd al-'Aziz) said. O 'Urwa be mindful of what you are saying that Gabriel (peace be upon him) taught the Messenger of Allah (ﷺ) the times of prayer. Upon this 'Urwa said: This is how Bashir b. Abu Mas'ud narrated on the authority of his father}}
\hadithdefcmd{muslim}{1381}{قَالَ عُرْوَةُ وَلَقَدْ حَدَّثَتْنِي عَائِشَةُ، زَوْجُ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ وَالشَّمْسُ فِي حُجْرَتِهَا قَبْلَ أَنْ تَظْهَرَ ‏.‏\hadithno{1381}\hadithtrans{Urwah (also) said:'A'isha?, the wife of the Apostle (ﷺ) narrated it to me that the Messenger of Allah (ﷺ) used to say the afternoon prayer, when the light of the sun was there in her apartment before it went out (of it)}}
\hadithdefcmd{muslim}{1382}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الْعَصْرَ وَالشَّمْسُ طَالِعَةٌ فِي حُجْرَتِي لَمْ يَفِئِ الْفَىْءُ بَعْدُ ‏.‏ وَقَالَ أَبُو بَكْرٍ لَمْ يَظْهَرِ الْفَىْءُ بَعْدُ ‏.‏\hadithno{1382}\hadithtrans{A'isha reported:The Apostle of Allah (ﷺ) said the afternoon" prayer as the sun shone in my apartment, and the afternoon shadow did not extend further. Abu Bakr said: The afternoon shadow did not appear to extend further}}
\hadithdefcmd{muslim}{1383}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ وَالشَّمْسُ فِي حُجْرَتِهَا لَمْ يَظْهَرِ الْفَىْءُ فِي حُجْرَتِهَا ‏.‏\hadithno{1383}\hadithtrans{A'isha, the wife of the Apostle (ﷺ), said that the Messenger of Allah (ﷺ) said the afternoon prayer (at the time) when the sun shone in her apartment and its shadow did not extend beyond her apartment}}
\hadithdefcmd{muslim}{1384}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْعَصْرَ وَالشَّمْسُ وَاقِعَةٌ فِي حُجْرَتِي ‏.‏\hadithno{1384}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) said the afternoon prayer (at a time) when the (light) of the sun was there in my apartment}}
\hadithdefcmd{muslim}{1385}{حَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا صَلَّيْتُمُ الْفَجْرَ فَإِنَّهُ وَقْتٌ إِلَى أَنْ يَطْلُعَ قَرْنُ الشَّمْسِ الأَوَّلُ ثُمَّ إِذَا صَلَّيْتُمُ الظُّهْرَ فَإِنَّهُ وَقْتٌ إِلَى أَنْ يَحْضُرَ الْعَصْرُ فَإِذَا صَلَّيْتُمُ الْعَصْرَ فَإِنَّهُ وَقْتٌ إِلَى أَنْ تَصْفَرَّ الشَّمْسُ فَإِذَا صَلَّيْتُمُ الْمَغْرِبَ فَإِنَّهُ وَقْتٌ إِلَى أَنْ يَسْقُطَ الشَّفَقُ فَإِذَا صَلَّيْتُمُ الْعِشَاءَ فَإِنَّهُ وَقْتٌ إِلَى نِصْفِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1385}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that the Prophet (ﷺ) said:"When you pray Fajr, its time is until the first part of the sun appears. When you pray Zuhr, its time is until 'Asr comes. When you pray 'Asr, its time is until the sun turns yellow. When you pray Maghrib, its time is until the twilight has disappeared. When you pray 'Isha, its time is until half of the night has passed}}
\hadithdefcmd{muslim}{1386}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي أَيُّوبَ، - وَاسْمُهُ يَحْيَى بْنُ مَالِكٍ الأَزْدِيُّ وَيُقَالُ الْمَرَاغِيُّ وَالْمَرَاغُ حَىٌّ مِنَ الأَزْدِ - عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَقْتُ الظُّهْرِ مَا لَمْ يَحْضُرِ الْعَصْرُ وَوَقْتُ الْعَصْرِ مَا لَمْ تَصْفَرَّ الشَّمْسُ وَوَقْتُ الْمَغْرِبِ مَا لَمْ يَسْقُطْ ثَوْرُ الشَّفَقِ وَوَقْتُ الْعِشَاءِ إِلَى نِصْفِ اللَّيْلِ وَوَقْتُ الْفَجْرِ مَا لَمْ تَطْلُعِ الشَّمْسُ ‏"‏ ‏.‏\hadithno{1386}\hadithtrans{Abdullah b. 'Amr reported the Apostle (ﷺ) saying:The time of the noon prayer (lasts) as long as it is not afternoon, and the time of the afternoon prayer (lasts) as long as the sun does not turn pale and the time of the evening prayer (lasts) as long as the spreading appearance of the redness above the horizon after sunset does not sink down, and the, time of the night prayer (lasts) by midnight and the time of the morning prayer (lasts) as long as the sun dots not rise}}
\hadithdefcmd{muslim}{1387}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِهِمَا قَالَ شُعْبَةُ رَفَعَهُ مَرَّةً وَلَمْ يَرْفَعْهُ مَرَّتَيْنِ ‏.‏\hadithno{1387}\hadithtrans{Abu Bakr b Abu Shaiban and Yahya b Abu Bukair both of them narrated this hadith with the same chain of transmitters}}
\hadithdefcmd{muslim}{1388}{وَحَدَّثَنِي أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَقْتُ الظُّهْرِ إِذَا زَالَتِ الشَّمْسُ وَكَانَ ظِلُّ الرَّجُلِ كَطُولِهِ مَا لَمْ يَحْضُرِ الْعَصْرُ وَوَقْتُ الْعَصْرِ مَا لَمْ تَصْفَرَّ الشَّمْسُ وَوَقْتُ صَلاَةِ الْمَغْرِبِ مَا لَمْ يَغِبِ الشَّفَقُ وَوَقْتُ صَلاَةِ الْعِشَاءِ إِلَى نِصْفِ اللَّيْلِ الأَوْسَطِ وَوَقْتُ صَلاَةِ الصُّبْحِ مِنْ طُلُوعِ الْفَجْرِ مَا لَمْ تَطْلُعِ الشَّمْسُ فَإِذَا طَلَعَتِ الشَّمْسُ فَأَمْسِكْ عَنِ الصَّلاَةِ فَإِنَّهَا تَطْلُعُ بَيْنَ قَرْنَىْ شَيْطَانٍ ‏"‏ ‏.‏\hadithno{1388}\hadithtrans{Abdullah b. 'Amr reported:The Messenger of Allah (ﷺ) said: The time of the noon prayer is when the sun passes the meridian and a man's shadow is the same (length) as his height, (and it lasts) as long as the time for the afternoon prayer has not come; the time for the afternoon prayer is as long as the sun has not become pale; the time of the evening prayer is as long as the twilight has not ended; the time of the night prayer is up to the middle of the average night and the time of the morning prayer is from the appearance of dawn, as long as the sun has not risen; but when the sun rises, refrain from prayer for it rises between the horns of the devil}}
\hadithdefcmd{muslim}{1389}{وَحَدَّثَنِي أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ اللَّهِ بْنِ رَزِينٍ، حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ طَهْمَانَ - عَنِ الْحَجَّاجِ، - وَهُوَ ابْنُ حَجَّاجٍ - عَنْ قَتَادَةَ، عَنْ أَبِي أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ وَقْتِ الصَّلَوَاتِ فَقَالَ ‏ "‏ وَقْتُ صَلاَةِ الْفَجْرِ مَا لَمْ يَطْلُعْ قَرْنُ الشَّمْسِ الأَوَّلُ وَوَقْتُ صَلاَةِ الظُّهْرِ إِذَا زَالَتِ الشَّمْسُ عَنْ بَطْنِ السَّمَاءِ مَا لَمْ يَحْضُرِ الْعَصْرُ وَوَقْتُ صَلاَةِ الْعَصْرِ مَا لَمْ تَصْفَرَّ الشَّمْسُ وَيَسْقُطْ قَرْنُهَا الأَوَّلُ وَوَقْتُ صَلاَةِ الْمَغْرِبِ إِذَا غَابَتِ الشَّمْسُ مَا لَمْ يَسْقُطِ الشَّفَقُ وَوَقْتُ صَلاَةِ الْعِشَاءِ إِلَى نِصْفِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1389}\hadithtrans{Abdullah b. 'Amr b. al-'As reported:The Messenger of Allah (ﷺ) was asked about the times of prayers. He said: The time for the morning prayer (lasts) as long as the first visible part of the rising sun does not appear and the time of the noon prayer is when the sun declines from the zenith and there is not a time for the afternoon prayer and the time for the afternoon prayer is so long as the sun does not become pale and its first visible part does not set, and the time for the evening prayer is that when the sun disappears and (it lasts) till the twilight is no more and the time for the night prayer is up to the midnight}}
\hadithdefcmd{muslim}{1390}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، لاَ يُسْتَطَاعُ الْعِلْمُ بِرَاحَةِ الْجِسْمِ ‏.‏\hadithno{1390}\hadithtrans{Abdullah narrated it on the authority of his father Yahya:Knowledge cannot be acquired with sloth}}
\hadithdefcmd{muslim}{1391}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، كِلاَهُمَا عَنِ الأَزْرَقِ، - قَالَ زُهَيْرٌ حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، - حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَجُلاً سَأَلَهُ عَنْ وَقْتِ الصَّلاَةِ فَقَالَ لَهُ ‏"‏ صَلِّ مَعَنَا هَذَيْنِ ‏"‏ ‏.‏ يَعْنِي الْيَوْمَيْنِ فَلَمَّا زَالَتِ الشَّمْسُ أَمَرَ بِلاَلاً فَأَذَّنَ ثُمَّ أَمَرَهُ فَأَقَامَ الظُّهْرَ ثُمَّ أَمَرَهُ فَأَقَامَ الْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ بَيْضَاءُ نَقِيَّةٌ ثُمَّ أَمَرَهُ فَأَقَامَ الْمَغْرِبَ حِينَ غَابَتِ الشَّمْسُ ثُمَّ أَمَرَهُ فَأَقَامَ الْعِشَاءَ حِينَ غَابَ الشَّفَقُ ثُمَّ أَمَرَهُ فَأَقَامَ الْفَجْرَ حِينَ طَلَعَ الْفَجْرُ فَلَمَّا أَنْ كَانَ الْيَوْمُ الثَّانِي أَمَرَهُ فَأَبْرَدَ بِالظُّهْرِ فَأَبْرَدَ بِهَا فَأَنْعَمَ أَنْ يُبْرِدَ بِهَا وَصَلَّى الْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ أَخَّرَهَا فَوْقَ الَّذِي كَانَ وَصَلَّى الْمَغْرِبَ قَبْلَ أَنْ يَغِيبَ الشَّفَقُ وَصَلَّى الْعِشَاءَ بَعْدَ مَا ذَهَبَ ثُلُثُ اللَّيْلِ وَصَلَّى الْفَجْرَ فَأَسْفَرَ بِهَا ثُمَّ قَالَ ‏"‏ أَيْنَ السَّائِلُ عَنْ وَقْتِ الصَّلاَةِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَقْتُ صَلاَتِكُمْ بَيْنَ مَا رَأَيْتُمْ ‏"‏ ‏.‏\hadithno{1391}\hadithtrans{Sulaiman b. Buraida narrated it on the authority of his father that a person asked the Messenger of Allah (ﷺ) about the time of prayer. Upon this he said:Pray with us these two, meaning two days. When the sun passed the meridian, he gave command to Bilal who uttered the call to prayer. Then he commanded him and pronounced Iqama for noon prayer (Then at the time of the afternoon prayer) he again commanded and Iqama for the afternoon prayer was pronounced when the sun was high, white and clear. He then commanded and Iqama for the evening prayer was pronounced, when the sun had set. He then commanded him and the Iqama for the night prayer was pronounced when the twilight had disappeared. He then commanded him and the Iqama for the morning prayer was pronounced, when the dawn had appeared. When it was the next day, he commanded him to delay the noon prayer till the extreme heat had passed and he did so, and he allowed it to be delayed till the extreme heat had passed. He observed the afternoon prayer when the sun was high, delaying it beyond the time he had previously observed it. He observed the evening prayer before the twilight had vanished; he observed the night prayer when a third of the night had passed; and he observed the dawn prayer when there was clear daylight. He (the Holy Prophet) then said: Where is the man who inquired about the time of prayer? He (the inquirer) said: Messenger of Allah, here I am. He (the Holy Prophet) said: The time for your prayer is within the limits of what you have seen}}
\hadithdefcmd{muslim}{1392}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ عَرْعَرَةَ السَّامِيُّ، حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ عَنْ مَوَاقِيتِ الصَّلاَةِ فَقَالَ ‏"‏ اشْهَدْ مَعَنَا الصَّلاَةَ ‏"‏ ‏.‏ فَأَمَرَ بِلاَلاً فَأَذَّنَ بِغَلَسٍ فَصَلَّى الصُّبْحَ حِينَ طَلَعَ الْفَجْرُ ثُمَّ أَمَرَهُ بِالظُّهْرِ حِينَ زَالَتِ الشَّمْسُ عَنْ بَطْنِ السَّمَاءِ ثُمَّ أَمَرَهُ بِالْعَصْرِ وَالشَّمْسُ مُرْتَفِعَةٌ ثُمَّ أَمَرَهُ بِالْمَغْرِبِ حِينَ وَجَبَتِ الشَّمْسُ ثُمَّ أَمَرَهُ بِالْعِشَاءِ حِينَ وَقَعَ الشَّفَقُ ثُمَّ أَمَرَهُ الْغَدَ فَنَوَّرَ بِالصُّبْحِ ثُمَّ أَمَرَهُ بِالظُّهْرِ فَأَبْرَدَ ثُمَّ أَمَرَهُ بِالْعَصْرِ وَالشَّمْسُ بَيْضَاءُ نَقِيَّةٌ لَمْ تُخَالِطْهَا صُفْرَةٌ ثُمَّ أَمَرَهُ بِالْمَغْرِبِ قَبْلَ أَنْ يَقَعَ الشَّفَقُ ثُمَّ أَمَرَهُ بِالْعِشَاءِ عِنْدَ ذَهَابِ ثُلُثِ اللَّيْلِ أَوْ بَعْضِهِ - شَكَّ حَرَمِيٌّ - فَلَمَّا أَصْبَحَ قَالَ ‏"‏ أَيْنَ السَّائِلُ مَا بَيْنَ مَا رَأَيْتَ وَقْتٌ ‏"‏ ‏.‏\hadithno{1392}\hadithtrans{Buraida narrated on the authority of his father that a man came to the Prophet (ﷺ) and asked about the times of prayer. He said:You observe with us the prayer. He commanded Bilal, and he uttered the call to prayer in the darkness of night preceding daybreak and he said the morning prayer till dawn had appeared. He then commanded him (Bilal) to call for the noon prayer when the sun had declined from the zenith. He then commanded him (Bilal) to call for the afternoon prayer when the sun was high. He then commanded him for the evening prayer when the sun had set. He then commanded him for the night prayer when the twilight had disappeared. Then on the next day he commanded him (to call for prayer) when there was light in the morning. He then commanded him (to call) for the noon prayer when the extreme heat was no more. He then commanded him for the afternoon prayer when the sun was bright and clear and yellowness did not blend with it. He then commanded him to observe the sunset prayer. He then commanded him for the night prayer when a third part of the night bad passed or a bit less than that. Harami (the narrator of this hadith) was in doubt about that part of the mentioned hadith which concerned the portion of the night. When it was dawn, he (the Holy Prophet) said: Where is the inquirer (who inquired about the times of prayer and added): Between (these two extremes) is the time for prayer}}
\hadithdefcmd{muslim}{1393}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا بَدْرُ بْنُ عُثْمَانَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي مُوسَى، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَتَاهُ سَائِلٌ يَسْأَلُهُ عَنْ مَوَاقِيتِ الصَّلاَةِ فَلَمْ يَرُدَّ عَلَيْهِ شَيْئًا - قَالَ - فَأَقَامَ الْفَجْرَ حِينَ انْشَقَّ الْفَجْرُ وَالنَّاسُ لاَ يَكَادُ يَعْرِفُ بَعْضُهُمْ بَعْضًا ثُمَّ أَمَرَهُ فَأَقَامَ بِالظُّهْرِ حِينَ زَالَتِ الشَّمْسُ وَالْقَائِلُ يَقُولُ قَدِ انْتَصَفَ النَّهَارُ وَهُوَ كَانَ أَعْلَمَ مِنْهُمْ ثُمَّ أَمَرَهُ فَأَقَامَ بِالْعَصْرِ وَالشَّمْسُ مُرْتَفِعَةٌ ثُمَّ أَمَرَهُ فَأَقَامَ بِالْمَغْرِبِ حِينَ وَقَعَتِ الشَّمْسُ ثُمَّ أَمَرَهُ فَأَقَامَ الْعِشَاءَ حِينَ غَابَ الشَّفَقُ ثُمَّ أَخَّرَ الْفَجْرَ مِنَ الْغَدِ حَتَّى انْصَرَفَ مِنْهَا وَالْقَائِلُ يَقُولُ قَدْ طَلَعَتِ الشَّمْسُ أَوْ كَادَتْ ثُمَّ أَخَّرَ الظُّهْرَ حَتَّى كَانَ قَرِيبًا مِنْ وَقْتِ الْعَصْرِ بِالأَمْسِ ثُمَّ أَخَّرَ الْعَصْرَ حَتَّى انْصَرَفَ مِنْهَا وَالْقَائِلُ يَقُولُ قَدِ احْمَرَّتِ الشَّمْسُ ثُمَّ أَخَّرَ الْمَغْرِبَ حَتَّى كَانَ عِنْدَ سُقُوطِ الشَّفَقِ ثُمَّ أَخَّرَ الْعِشَاءَ حَتَّى كَانَ ثُلُثُ اللَّيْلِ الأَوَّلُ ثُمَّ أَصْبَحَ فَدَعَا السَّائِلَ فَقَالَ ‏ "‏ الْوَقْتُ بَيْنَ هَذَيْنِ ‏"‏ ‏.‏\hadithno{1393}\hadithtrans{Abu Musa narrated on the authority of his father that a person came to the Messenger of Allah (ﷺ) for inquiring about the times of prayers. He (the Holy Prophet) gave him no reply (because he wanted to explain to him the times by practically observing these prayers). He then said the morning player when it was daybreak, but the people could hardly recognise one another. He then commanded and the Iqama for the noon prayer was pronounced when the tan had passed the meridian and one would say that it was midday but he (the Holy Prophet) knew batter than them. He then again commanded and the Iqama for the afternoon prayer was pronounced when the sun was high. He then commanded and Iqama for the evening prayer was pronounced when the sun had sunk. He then commanded and Iqama for the night prayer was pronounced when the twilight had disappeared. He then delayed the morning prayer on the next day (so much so) that after returning from it one would say that the sun had risen or it was about to rise. He then delayed the noon prayer till it was near the time of afternoon prayer (as it was observed yesterday). He then delayed the afternoon prayer till one after returning from it would say that the sun had become red. He then delayed the evening prayer till the twilight was about to disappear. He then delayed the night prayer till it was one-third of the night. He then called the inquirer in the morning and said:The time for prayers is between these two (extremes)}}
\hadithdefcmd{muslim}{1394}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ بَدْرِ بْنِ عُثْمَانَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مُوسَى، سَمِعَهُ مِنْهُ، عَنْ أَبِيهِ، أَنَّ سَائِلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ عَنْ مَوَاقِيتِ الصَّلاَةِ ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ غَيْرَ أَنَّهُ قَالَ فَصَلَّى الْمَغْرِبَ قَبْلَ أَنْ يَغِيبَ الشَّفَقُ فِي الْيَوْمِ الثَّانِي ‏.‏\hadithno{1394}\hadithtrans{Abu Musa reported on the authority of his father that an Inquirer came to the Prophet (ﷺ) and asked him about the times of prayers, and the rest of the hadith is the same (as narrated above) but for these words:" On the second day he (the Holy Prophet) observed the evening prayer before the disappearance of the twilight}}
\hadithdefcmd{muslim}{1395}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخ ْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا بِالصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{1395}\hadithtrans{Abu Huraira reported that the Messenger of Allah (may peace he upon him) said:When it is very hot, say (the noon prayer) when the extreme heat passes away, for intensity of heat is from the exhalation of Hell}}
\hadithdefcmd{muslim}{1396}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ سَوَاءً ‏.‏\hadithno{1396}\hadithtrans{Another hadith like this has been transmitted by Abu Huraira}}
\hadithdefcmd{muslim}{1397}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَعَمْرُو بْنُ سَوَّادٍ، وَأَحْمَدُ بْنُ عِيسَى، قَالَ عَمْرٌو أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ بُكَيْرًا، حَدَّثَهُ عَنْ بُسْرِ بْنِ سَعِيدٍ، وَسَلْمَانَ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا كَانَ الْيَوْمُ الْحَارُّ فَأَبْرِدُوا بِالصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏. قَالَ عَمْرٌو وَحَدَّثَنِي أَبُو يُونُسَ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَبْرِدُوا عَنِ الصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏. قَالَ عَمْرٌو وَحَدَّثَنِي ابْنُ شِهَابٍ عَنِ ابْنِ الْمُسَيَّبِ وَأَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِنَحْوِ ذَلِكَ\hadithno{1397}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When it is a hot day, (delay) the prayer till the extreme heat passes away, for the intensity of heat is from the exhalation of Hell. Abu Huraira reported that the Messenger of Allah (ﷺ) said: Refrain from saying (the noon prayer) till the extreme heat passes away, for the Intensity of heat is from the exhalation of Hell. Abu Huraira narrated this hadith from the Messenger of Allah (may peace be up on him) by another chain of transmitters}}
\hadithdefcmd{muslim}{1398}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ هَذَا الْحَرَّ مِنْ فَيْحِ جَهَنَّمَ فَأَبْرِدُوا بِالصَّلاَةِ ‏"‏ ‏.‏\hadithno{1398}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) said:This heat is from the exhalation of Hell-fire, so delay the prayer till it is cool}}
\hadithdefcmd{muslim}{1399}{حَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَبْرِدُوا عَنِ الْحَرِّ فِي الصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{1399}\hadithtrans{Hammam b. Munabbih reported:This is what Abu Huraira narrated to us from the Prophet and he transmitted some ahadith-one of them was that the Messenger of Allah (ﷺ) said: Let the heat become less severe before prayer, for the intensity of heat is from the exhalation of Hell}}
\hadithdefcmd{muslim}{1400}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ مُهَاجِرًا أَبَا الْحَسَنِ، يُحَدِّثُ أَنَّهُ سَمِعَ زَيْدَ بْنَ وَهْبٍ، يُحَدِّثُ عَنْ أَبِي ذَرٍّ، قَالَ أَذَّنَ مُؤَذِّنُ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالظُّهْرِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبْرِدْ أَبْرِدْ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ انْتَظِرِ انْتَظِرْ ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ فَإِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ ‏"‏ ‏.‏ قَالَ أَبُو ذَرٍّ حَتَّى رَأَيْنَا فَىْءَ التُّلُولِ ‏.‏\hadithno{1400}\hadithtrans{Abu Dharr reported:The Mu'adhdbin (the announcer of the hour of prayer) of the Messenger of Allah (ﷺ) called for the noon prayer. Upon this the Messenger of Allah (ﷺ) said: Let it cool down, let it cool down, or he said: Wait, wait for the intensity of heat is from the exhalation of Hell. When the heat is intense, delay the prayer till it becomes cooler. Abu Dharr said: (We waited) till we saw the shadow of the mounds}}
\hadithdefcmd{muslim}{1401}{وَحَدَّثَنِي عَمْرُو بْنُ سَوَّادٍ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لِحَرْمَلَةَ - أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْتَكَتِ النَّارُ إِلَى رَبِّهَا فَقَالَتْ يَا رَبِّ أَكَلَ بَعْضِي بَعْضًا ‏.‏ فَأَذِنَ لَهَا بِنَفَسَيْنِ نَفَسٍ فِي الشِّتَاءِ وَنَفَسٍ فِي الصَّيْفِ فَهُوَ أَشَدُّ مَا تَجِدُونَ مِنَ الْحَرِّ وَأَشَدُّ مَا تَجِدُونَ مِنَ الزَّمْهَرِيرِ ‏"‏ ‏.‏\hadithno{1401}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: The Fire made a complaint before the Lord saying." O Lord, some parts of mine have consumed the others." So it was allowed to take two exhalations, one exhalation in winter and the other exhalation in summer. That is why you find extreme heat (in summer) and extreme cold (in winter)}}
\hadithdefcmd{muslim}{1402}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَمُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا كَانَ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏ وَذَكَرَ ‏"‏ أَنَّ النَّارَ اشْتَكَتْ إِلَى رَبِّهَا فَأَذِنَ لَهَا فِي كُلِّ عَامٍ بِنَفَسَيْنِ نَفَسٍ فِي الشِّتَاءِ وَنَفَسٍ فِي الصَّيْفِ ‏"‏ ‏.‏\hadithno{1402}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When it is hot, make delay (in the noon prayer) till it cools down, for the intensity of beat is from the Exhalation of Hell; and he also mentioned that Hellfire complained to the Lord (about the congested atmosphere) and so it was permitted to take two exhalations during the whole year, one exhalation during the winter and one exhalation during the summer}}
\hadithdefcmd{muslim}{1403}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا حَيْوَةُ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَتِ النَّارُ رَبِّ أَكَلَ بَعْضِي بَعْضًا فَأْذَنْ لِي أَتَنَفَّسْ ‏.‏ فَأَذِنَ لَهَا بِنَفَسَيْنِ نَفَسٍ فِي الشِّتَاءِ وَنَفَسٍ فِي الصَّيْفِ فَمَا وَجَدْتُمْ مِنْ بَرْدٍ أَوْ زَمْهَرِيرٍ فَمِنْ نَفَسِ جَهَنَّمَ وَمَا وَجَدْتُمْ مِنْ حَرٍّ أَوْ حَرُورٍ فَمِنْ نَفَسِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{1403}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) said:The Fire said to the Lord: O Lord! some parts of mine have consumed the others, so allow me to exhale (in order to find some relief from this congestion). It was granted permission to take two exhalations, one exhalation during the winter and the other exhalation during the summer So whatever you perceive in the form of intense cold or hurting cold is from the exhalation of Hell. And whatever you perceive in the form of extreme heat or intense beat is from the exhalation of Hell}}
\hadithdefcmd{muslim}{1404}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، كِلاَهُمَا عَنْ يَحْيَى الْقَطَّانِ، وَابْنِ، مَهْدِيٍّ - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، - عَنْ شُعْبَةَ، قَالَ حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ ابْنُ الْمُثَنَّى وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الظُّهْرَ إِذَا دَحَضَتِ الشَّمْسُ ‏.‏\hadithno{1404}\hadithtrans{Jabir b. Samura reported:The Apostle of Allah (ﷺ) used to offer the noon prayer when the sun declined}}
\hadithdefcmd{muslim}{1405}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، سَلاَّمُ بْنُ سُلَيْمٍ عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ وَهْبٍ، عَنْ خَبَّابٍ، قَالَ شَكَوْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الصَّلاَةَ فِي الرَّمْضَاءِ فَلَمْ يُشْكِنَا ‏.‏\hadithno{1405}\hadithtrans{Khabbab reported:We complained to the Messenger of Allah (ﷺ) (the difficulty of) saying prayer on the intensely heated (ground or sand), but he paid no heed to our complaint}}
\hadithdefcmd{muslim}{1406}{وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، وَعَوْنُ بْنُ سَلاَّمٍ، - قَالَ عَوْنٌ أَخْبَرَنَا وَقَالَ ابْنُ يُونُسَ، وَاللَّفْظُ، لَهُ حَدَّثَنَا زُهَيْرٌ، - قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ سَعِيدِ بْنِ وَهْبٍ، عَنْ خَبَّابٍ، قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَشَكَوْنَا إِلَيْهِ حَرَّ الرَّمْضَاءِ فَلَمْ يُشْكِنَا ‏.‏ قَالَ زُهَيْرٌ قُلْتُ لأَبِي إِسْحَاقَ أَفِي الظُّهْرِ قَالَ نَعَمْ ‏.‏ قُلْتُ أَفِي تَعْجِيلِهَا قَالَ نَعَمْ ‏.‏\hadithno{1406}\hadithtrans{Khabbab reported:We came to the Messenger of Allah (ﷺ) and we complained to the Messenger of Allah (ﷺ) about (saying prayer) on the extremely heated ground (or sand), but he paid no heed to us. Zuhair said: I asked Abu Ishaq whether it was about the noon prayer. He said: Yes. I again said whether it concerned the (offering) of the noon (prayer) in earlier hours. He said: Yes. I said: Did it concern expediting it? He said: Yes}}
\hadithdefcmd{muslim}{1407}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ غَالِبٍ الْقَطَّانِ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي شِدَّةِ الْحَرِّ فَإِذَا لَمْ يَسْتَطِعْ أَحَدُنَا أَنْ يُمَكِّنَ جَبْهَتَهُ مِنَ الأَرْضِ بَسَطَ ثَوْبَهُ فَسَجَدَ عَلَيْهِ ‏.‏\hadithno{1407}\hadithtrans{Anas b. Malik reported:We used to say (the noonprayer) with the Messenger of Allah (ﷺ) in the intense heat, but when someone amongst us found it hard to place his forehead on the ground, he spread his cloth and prostrated on it}}
\hadithdefcmd{muslim}{1408}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ حَيَّةٌ فَيَذْهَبُ الذَّاهِبُ إِلَى الْعَوَالِي فَيَأْتِي الْعَوَالِيَ وَالشَّمْسُ مُرْتَفِعَةٌ ‏.‏ وَلَمْ يَذْكُرْ قُتَيْبَةُ فَيَأْتِي الْعَوَالِيَ ‏.‏\hadithno{1408}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) used to pray the afternoon prayer when the sun was high and bright, then one would go off to al-'Awali and get there while the sun was still high. Ibn Qutaiba made no mention of" one would go off to al-'Awali}}
\hadithdefcmd{muslim}{1409}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ بِمِثْلِهِ سَوَاءً ‏.‏\hadithno{1409}\hadithtrans{This hadith that the Messenger of Allah (ﷺ) used to offer the afternoon prayer like the one narrated above has been transmitted by Anas b. Malik by another chain of transmitters}}
\hadithdefcmd{muslim}{1410}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا نُصَلِّي الْعَصْرَ ثُمَّ يَذْهَبُ الذَّاهِبُ إِلَى قُبَاءٍ فَيَأْتِيهِمْ وَالشَّمْسُ مُرْتَفِعَةٌ ‏.‏\hadithno{1410}\hadithtrans{Anas b. Malik reported:We used to offer the 'Asr prayer, then one would go to Quba' and reach there and the sun would be still high}}
\hadithdefcmd{muslim}{1411}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا نُصَلِّي الْعَصْرَ ثُمَّ يَخْرُجُ الإِنْسَانُ إِلَى بَنِي عَمْرِو بْنِ عَوْفٍ فَيَجِدُهُمْ يُصَلُّونَ الْعَصْرَ ‏.‏\hadithno{1411}\hadithtrans{Anas b. Malik reported:We used to offer the afternoon prayer (at such a time) that a person would go to Bani 'Amr b. Auf and he would find them busy offering the afternoon prayer}}
\hadithdefcmd{muslim}{1412}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ دَخَلَ عَلَى أَنَسِ بْنِ مَالِكٍ فِي دَارِهِ بِالْبَصْرَةِ حِينَ انْصَرَفَ مِنَ الظُّهْرِ وَدَارُهُ بِجَنْبِ الْمَسْجِدِ فَلَمَّا دَخَلْنَا عَلَيْهِ قَالَ أَصَلَّيْتُمُ الْعَصْرَ فَقُلْنَا لَهُ إِنَّمَا انْصَرَفْنَا السَّاعَةَ مِنَ الظُّهْرِ ‏.‏ قَالَ فَصَلُّوا الْعَصْرَ ‏.‏ فَقُمْنَا فَصَلَّيْنَا فَلَمَّا انْصَرَفْنَا قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تِلْكَ صَلاَةُ الْمُنَافِقِ يَجْلِسُ يَرْقُبُ الشَّمْسَ حَتَّى إِذَا كَانَتْ بَيْنَ قَرْنَىِ الشَّيْطَانِ قَامَ فَنَقَرَهَا أَرْبَعًا لاَ يَذْكُرُ اللَّهَ فِيهَا إِلاَّ قَلِيلاً ‏"‏ ‏.‏\hadithno{1412}\hadithtrans{Ala' b. 'Abd al-Rahman reported that they came to the house of Anas b. Malik in Basra after saying the noon prayer. His (Anas) house was situated by the side of the mosque. As revisited him he (Anas) said:Have you said the afternoon prayer? We said to him: It is just a few minutes before that we finished the noon prayer. He said: Offer the afternoon prayer. So we stood up and said our prayer. And when we completed it, he said: I have heard the Messenger of Allah (ﷺ) saying: This is how the hypocrite prays: he sits watching the sun, and when it is between the horns of devil, he rises and strikes the ground four times (in haste) mentioning Allah a little during it}}
\hadithdefcmd{muslim}{1413}{وَحَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ أَبِي بَكْرِ بْنِ عُثْمَانَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ بْنَ سَهْلٍ، يَقُولُ صَلَّيْنَا مَعَ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ الظُّهْرَ ثُمَّ خَرَجْنَا حَتَّى دَخَلْنَا عَلَى أَنَسِ بْنِ مَالِكٍ فَوَجَدْنَاهُ يُصَلِّي الْعَصْرَ فَقُلْتُ يَا عَمِّ مَا هَذِهِ الصَّلاَةُ الَّتِي صَلَّيْتَ قَالَ الْعَصْرُ وَهَذِهِ صَلاَةُ رَسُولِ اللَّهِ صلى الله تعالى عليه وسلم الَّتِي كُنَّا نُصَلِّي مَعَهُ ‏.‏\hadithno{1413}\hadithtrans{Abu Umama b. Sahl reported:We offered the noon prayer with Umar b. 'Abd al-'Aziz. We then set out till we came to Anas b. Malik and found him busy in saying the afternoon prayer. I said to him: O uncle! which is this prayer that you are offering? He said: It is the afternoon prayer and this is the prayer of the Messenger of Allah (ﷺ) that we offered along with him}}
\hadithdefcmd{muslim}{1414}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، وَأَحْمَدُ بْنُ عِيسَى، - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالَ عَمْرٌو أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ مُوسَى بْنَ سَعْدٍ الأَنْصَارِيَّ، حَدَّثَهُ عَنْ حَفْصِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ فَلَمَّا انْصَرَفَ أَتَاهُ رَجُلٌ مِنْ بَنِي سَلِمَةَ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نُرِيدُ أَنْ نَنْحَرَ جَزُورًا لَنَا وَنَحْنُ نُحِبُّ أَنْ تَحْضُرَهَا ‏.‏ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ فَانْطَلَقَ وَانْطَلَقْنَا مَعَهُ فَوَجَدْنَا الْجَزُورَ لَمْ تُنْحَرْ فَنُحِرَتْ ثُمَّ قُطِّعَتْ ثُمَّ طُبِخَ مِنْهَا ثُمَّ أَكَلْنَا قَبْلَ أَنْ تَغِيبَ الشَّمْسُ ‏.‏ وَقَالَ الْمُرَادِيُّ حَدَّثَنَا ابْنُ وَهْبٍ عَنِ ابْنِ لَهِيعَةَ وَعَمْرِو بْنِ الْحَارِثِ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{1414}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) led us in the afternoon prayer. When he completed it, a person from Bani Salama came to him and said: Messenger of Allah, we intend to slaughter our came and we are desirous that you should also be present there (on this occasion). He (the Holy Prophet) said: Yes. He (the person) went and we also went along with him and we found that the camel had not been slaughtered yet. Then it was slaughtered, and it was cut into pieces and then some of those were cooked, and then we ate (them) before the setting of the sun. This hadith has also been narrated by another chain of transmitters}}
\hadithdefcmd{muslim}{1415}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ أَبِي النَّجَاشِيِّ، قَالَ سَمِعْتُ رَافِعَ بْنَ خَدِيجٍ، يَقُولُ كُنَّا نُصَلِّي الْعَصْرَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ تُنْحَرُ الْجَزُورُ فَتُقْسَمُ عَشَرَ قِسَمٍ ثُمَّ تُطْبَخُ فَنَأْكُلُ لَحْمًا نَضِيجًا قَبْلَ مَغِيبِ الشَّمْسِ ‏.‏\hadithno{1415}\hadithtrans{Rafi' b. Khadij reported:We used to say the afternoon prayer with the Messenger of Allah (ﷺ), and then the camel was slaughtered and ten parts of it were distributed; then it was cooked and then we ate this cooked meat before the sinking of the sun}}
\hadithdefcmd{muslim}{1416}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، وَشُعَيْبُ بْنُ إِسْحَاقَ الدِّمَشْقِيُّ، قَالاَ حَدَّثَنَا الأَوْزَاعِيُّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ كُنَّا نَنْحَرُ الْجَزُورَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ الْعَصْرِ ‏.‏ وَلَمْ يَقُلْ كُنَّا نُصَلِّي مَعَهُ ‏.‏\hadithno{1416}\hadithtrans{This hadith has been reported by 'Auza'i with the same chain of transmitters:We used to slaughter the camel during the lifetime of the Messenger of Allah (ﷺ) after the 'Asr prayer, but he made no mention of:" We used to pray along with him}}
\hadithdefcmd{muslim}{1417}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي تَفُوتُهُ صَلاَةُ الْعَصْرِ كَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏ ‏.‏\hadithno{1417}\hadithtrans{Ibn Umar reported that the Messenger of Allah (ﷺ) said:He who misses the afternoon prayer, it is as though he has been deprived of his family and his property}}
\hadithdefcmd{muslim}{1418}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، ‏.‏ قَالَ عَمْرٌو يَبْلُغُ بِهِ ‏.‏ وَقَالَ أَبُو بَكْرٍ رَفَعَهُ ‏.‏\hadithno{1418}\hadithtrans{This hadith has been narrated as Marfu by another chain of transmitters}}
\hadithdefcmd{muslim}{1419}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ فَاتَتْهُ الْعَصْرُ فَكَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏ ‏.‏\hadithno{1419}\hadithtrans{Abdullah relates on the authority of his father. He who missed his afternoon prayer it is as though he was deprived of his family and property}}
\hadithdefcmd{muslim}{1420}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، قَالَ لَمَّا كَانَ يَوْمُ الأَحْزَابِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَلأَ اللَّهُ قُبُورَهُمْ وَبُيُوتَهُمْ نَارًا كَمَا حَبَسُونَا وَشَغَلُونَا عَنِ الصَّلاَةِ الْوُسْطَى حَتَّى غَابَتِ الشَّمْسُ ‏"‏ ‏.‏\hadithno{1420}\hadithtrans{Ali reported:When it was the day (of the Battle) of Ahzab, the Messenger of Allah (ﷺ) said: May Allah fill their graves and houses with fire, as they detained us and diverted us from the middle prayer, till the sun set}}
\hadithdefcmd{muslim}{1421}{وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، جَمِيعًا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1421}\hadithtrans{This hadith has been narrated by Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{1422}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَبِي حَسَّانَ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَحْزَابِ ‏ "‏ شَغَلُونَا عَنْ صَلاَةِ الْوُسْطَى حَتَّى آبَتِ الشَّمْسُ مَلأَ اللَّهُ قُبُورَهُمْ نَارًا أَوْ بُيُوتَهُمْ أَوْ بُطُونَهُمْ ‏"‏ ‏.‏ شَكَّ شُعْبَةُ فِي الْبُيُوتِ وَالْبُطُونِ ‏.‏\hadithno{1422}\hadithtrans{Ali reported:The Messenger of Allah (ﷺ) said: On the day (of the Battle) of Ahzab we were diverted from the middle prayer, till the sun set. May Allah fill their graves or their houses, or their stomachs with fire. The narrator is in doubt about" houses" and" stomachs}}
\hadithdefcmd{muslim}{1423}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ بُيُوتَهُمْ وَقُبُورَهُمْ ‏"‏ ‏.‏ وَلَمْ يَشُكَّ ‏.‏\hadithno{1423}\hadithtrans{This hadith has heed narrated by Qatada with the same chain of transmitters. And he said:Their houses and their graves (be filled with fire), and did not express doubt over the words," houses" and" graves}}
\hadithdefcmd{muslim}{1424}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ يَحْيَى بْنِ الْجَزَّارِ، عَنْ عَلِيٍّ، ح وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ يَحْيَى، سَمِعَ عَلِيًّا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَحْزَابِ وَهُوَ قَاعِدٌ عَلَى فُرْضَةٍ مِنْ فُرَضِ الْخَنْدَقِ ‏ "‏ شَغَلُونَا عَنِ الصَّلاَةِ الْوُسْطَى حَتَّى غَرَبَتِ الشَّمْسُ مَلأَ اللَّهُ قُبُورَهُمْ وَبُيُوتَهُمْ - أَوْ قَالَ قُبُورَهُمْ وَبُطُونَهُمْ - نَارًا ‏"‏ ‏.‏\hadithno{1424}\hadithtrans{Yahya heard 'Ali saying that the Messenger of Allah (ﷺ) said on the day (of the Battle) of Ahzab, while sitting in one of the openings of the ditch:They (the enemies) have diverted us from the middle prayer till the sun set. May Allah fill their graves and their houses with fire, or their graves and stomachs with fire}}
\hadithdefcmd{muslim}{1425}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، عَنْ شُتَيْرِ بْنِ شَكَلٍ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَحْزَابِ ‏ "‏ شَغَلُونَا عَنِ الصَّلاَةِ الْوُسْطَى صَلاَةِ الْعَصْرِ مَلأَ اللَّهُ بُيُوتَهُمْ وَقُبُورَهُمْ نَارًا ‏"‏ ‏.‏ ثُمَّ صَلاَّهَا بَيْنَ الْعِشَاءَيْنِ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{1425}\hadithtrans{Ali reported:The Messenger of Allah (ﷺ) said on the day (of the Battle) of Ahzab: They diverted us from saying the middle prayer, i. e. the 'Asr prayer. May Allah fill their houses and graves with fire; he then observed this prayer between the evening prayer and the night prayer}}
\hadithdefcmd{muslim}{1426}{وَحَدَّثَنَا عَوْنُ بْنُ سَلاَّمٍ الْكُوفِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ طَلْحَةَ الْيَامِيُّ، عَنْ زُبَيْدٍ، عَنْ مُرَّةَ، عَنْ عَبْدِ اللَّهِ، قَالَ حَبَسَ الْمُشْرِكُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَةِ الْعَصْرِ حَتَّى احْمَرَّتِ الشَّمْسُ أَوِ اصْفَرَّتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شَغَلُونَا عَنِ الصَّلاَةِ الْوُسْطَى صَلاَةِ الْعَصْرِ مَلأَ اللَّهُ أَجْوَافَهُمْ وَقُبُورَهُمْ نَارًا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ حَشَا اللَّهُ أَجْوَافَهُمْ وَقُبُورَهُمْ نَارًا ‏"‏ ‏.‏\hadithno{1426}\hadithtrans{Abdullah (b. Mas'ud) reported that the polytheists detained the Messenger of Allah (ﷺ) from observing the afternoon prayer till the sun became red or it became yellow. Upon this the Messenger of Allah (ﷺ) said:They have diverted us from (offering) the middle prayer. i. e. the 'Asr prayer. May Allah fill their bellies and their graves with fire, or he said: May Allah stuff their bellies and their graves with fire}}
\hadithdefcmd{muslim}{1427}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي يُونُسَ، مَوْلَى عَائِشَةَ أَنَّهُ قَالَ أَمَرَتْنِي عَائِشَةُ أَنْ أَكْتُبَ لَهَا مُصْحَفًا وَقَالَتْ إِذَا بَلَغْتَ هَذِهِ الآيَةَ فَآذِنِّي ‏\{‏ حَافِظُوا عَلَى الصَّلَوَاتِ وَالصَّلاَةِ الْوُسْطَى‏\}‏ فَلَمَّا بَلَغْتُهَا آذَنْتُهَا فَأَمْلَتْ عَلَىَّ حَافِظُوا عَلَى الصَّلَوَاتِ وَالصَّلاَةِ الْوُسْطَى وَصَلاَةِ الْعَصْرِ ‏.‏ وَقُومُوا لِلَّهِ قَانِتِينَ ‏.‏ قَالَتْ عَائِشَةُ سَمِعْتُهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1427}\hadithtrans{Abu Yunus, the freed slave of 'A'isha said:'A'isha ordered me to transcribe a copy of the Qur'an for her and said: When you reach this verse:" Guard the prayers and the middle prayer" (ii. 238), inform me; so when I reached it, I informed her and she gave me dictation (like this): Guard the prayers and the middle prayer and the afternoon prayer, and stand up truly obedient to Allah. 'A'isha said: This is how I have heard from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1430}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ مُعَاذِ بْنِ هِشَامٍ، - قَالَ أَبُو غَسَّانَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، - حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، يَوْمَ الْخَنْدَقِ جَعَلَ يَسُبُّ كُفَّارَ قُرَيْشٍ وَقَالَ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا كِدْتُ أَنْ أُصَلِّيَ الْعَصْرَ حَتَّى كَادَتْ أَنْ تَغْرُبَ الشَّمْسُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَوَاللَّهِ إِنْ صَلَّيْتُهَا ‏"‏ ‏.‏ فَنَزَلْنَا إِلَى بُطْحَانَ فَتَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَوَضَّأْنَا فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ بَعْدَ مَا غَرَبَتِ الشَّمْسُ ثُمَّ صَلَّى بَعْدَهَا الْمَغْرِبَ ‏.‏\hadithno{1430}\hadithtrans{Jabir b. 'Abdullah reported that Umar b. al-Khattab had been cursing the pagans of the Quraish an the day (of the Battle) of Khandaq (Ditch). (He came to the Holy Prophet) and said:Messenger of Allah, by God, I could not say. the 'Asr prayer till the sun set. Upon this the Messenger (ﷺ) said: By Allah I, too, have not observed it. So we went to a valley. The Messenger of Allah (ﷺ) performed ablution and we too performed ablution, and then the Messenger of Allah (ﷺ) said the 'Asr prayer after the sun had set. and then said the evening prayer after it}}
\hadithdefcmd{muslim}{1431}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{1431}\hadithtrans{This hadith has been reported by Yahya b. Abd Kathir with the same chain of transmitters}}
\hadithdefcmd{muslim}{1432}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَتَعَاقَبُونَ فِيكُمْ مَلاَئِكَةٌ بِاللَّيْلِ وَمَلاَئِكَةٌ بِالنَّهَارِ وَيَجْتَمِعُونَ فِي صَلاَةِ الْفَجْرِ وَصَلاَةِ الْعَصْرِ ثُمَّ يَعْرُجُ الَّذِينَ بَاتُوا فِيكُمْ فَيَسْأَلُهُمْ رَبُّهُمْ وَهُوَ أَعْلَمُ بِهِمْ كَيْفَ تَرَكْتُمْ عِبَادِي فَيَقُولُونَ تَرَكْنَاهُمْ وَهُمْ يُصَلُّونَ وَأَتَيْنَاهُمْ وَهُمْ يُصَلُّونَ ‏"‏ ‏.‏\hadithno{1432}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Angels take turns among you by night and by day, and they all assemble at the dawn and afternoon prayers. Those (of the angels) who spend the night among you, then, ascend, and their Lord asks them, though He is the best informed about them: How did you leave My servants? -they say: We left them while they were praying and we came to them while they were praying}}
\hadithdefcmd{muslim}{1433}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَالْمَلاَئِكَةُ يَتَعَاقَبُونَ فِيكُمْ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ أَبِي الزِّنَادِ ‏.‏\hadithno{1433}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Angels take turns among you by night and by day, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1434}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، حَدَّثَنَا قَيْسُ بْنُ أَبِي حَازِمٍ، قَالَ سَمِعْتُ جَرِيرَ بْنَ عَبْدِ اللَّهِ، وَهُوَ يَقُولُ كُنَّا جُلُوسًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ نَظَرَ إِلَى الْقَمَرِ لَيْلَةَ الْبَدْرِ فَقَالَ ‏"‏ أَمَا إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ كَمَا تَرَوْنَ هَذَا الْقَمَرَ لاَ تُضَامُّونَ فِي رُؤْيَتِهِ فَإِنِ اسْتَطَعْتُمْ أَنْ لاَ تُغْلَبُوا عَلَى صَلاَةٍ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا ‏"‏ ‏.‏ يَعْنِي الْعَصْرَ وَالْفَجْرَ ثُمَّ قَرَأَ جَرِيرٌ ‏\{‏ وَسَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا‏\}‏ ‏.‏\hadithno{1434}\hadithtrans{Jarir b. Abdullah is reported to have said:We were sitting with the Messenger of Allah (ﷺ) that he looked at the full moon and observed: You shall see your Lord as you are seeing this moon, and you will not be harmed by seeing Him. So if you can, do not let -yourselves be overpowered in case of prayer observed before the rising of the sun and its setting, i. e. the 'Asr prayer and the morning prayer. Jarir then recited it:" Celebrate the praise of thy Lord before the rising of the sun and before Its setting" (xx)}}
\hadithdefcmd{muslim}{1435}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ وَوَكِيعٌ بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ أَمَا إِنَّكُمْ سَتُعْرَضُونَ عَلَى رَبِّكُمْ فَتَرَوْنَهُ كَمَا تَرَوْنَ هَذَا الْقَمَرَ ‏"‏ ‏.‏ وَقَالَ ثُمَّ قَرَأَ ‏.‏ وَلَمْ يَقُلْ جَرِيرٌ ‏.‏\hadithno{1435}\hadithtrans{Waki' reported (this hadith) with the same chain of transmitters (that the Holy Prophet) said:You will be soon presented before your Lord, and you will see Him as you are seeing this moon, and then recited (the above-mentioned verse). But (in this hadith) no mention is made of Jarir}}
\hadithdefcmd{muslim}{1436}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ جَمِيعًا عَنْ وَكِيعٍ، - قَالَ أَبُو كُرَيْبٍ حَدَّثَنَا وَكِيعٌ، - عَنِ ابْنِ أَبِي خَالِدٍ، وَمِسْعَرٍ، وَالْبَخْتَرِيِّ بْنِ الْمُخْتَارِ، سَمِعُوهُ مِنْ أَبِي بَكْرِ بْنِ عُمَارَةَ بْنِ رُؤَيْبَةَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَنْ يَلِجَ النَّارَ أَحَدٌ صَلَّى قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا ‏"‏ ‏.‏ يَعْنِي الْفَجْرَ وَالْعَصْرَ ‏.‏ فَقَالَ لَهُ رَجُلٌ مِنْ أَهْلِ الْبَصْرَةِ آنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏ قَالَ الرَّجُلُ وَأَنَا أَشْهَدُ أَنِّي سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏.‏\hadithno{1436}\hadithtrans{Umara b. Ruwaiba is reported to have said on the authority of his father:I heard the Messenger of Allah (ﷺ) saying: He who observes prayer before the rising of the sun and its setting, i.e. the dawn prayer and the afternoon prayer, would not enter the (Hell) fire. A person belonging to Basra said to him: Did you yourself hear it from the Messenger of Allah (ﷺ)? He said: Yes. The person (from Basra) said: I bear witness that I heard it from the Messenger of Allah (ﷺ); my ears heard it and my heart retained it}}
\hadithdefcmd{muslim}{1437}{وَحَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا شَيْبَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنِ ابْنِ عُمَارَةَ بْنِ رُؤَيْبَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَلِجُ النَّارَ مَنْ صَلَّى قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا ‏"‏ ‏.‏ وَعِنْدَهُ رَجُلٌ مِنْ أَهْلِ الْبَصْرَةِ فَقَالَ آنْتَ سَمِعْتَ هَذَا مِنَ النَّبِيِّ صلى الله عليه وسلم قَالَ نَعَمْ أَشْهَدُ بِهِ عَلَيْهِ ‏.‏ قَالَ وَأَنَا أَشْهَدُ لَقَدْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُهُ بِالْمَكَانِ الَّذِي سَمِعْتَهُ مِنْهُ ‏.‏\hadithno{1437}\hadithtrans{Umara b. Ruwaiba reported on the authority of his father that the Messenger of Allah (ﷺ) said:He who said prayer before the rising of the sun and its setting would not enter the fire (of Hell), and there was a man from Basra (sitting) beside him who said: Did you hear it from the Messenger of Allah (way peace be upon him)? He said: Yes, I bear witness to it. The man from Basra said: I bear witness that I did hear from the Messenger of Allah (ﷺ) saying it from the place that you heard from him}}
\hadithdefcmd{muslim}{1438}{وَحَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ الأَزْدِيُّ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنِي أَبُو جَمْرَةَ الضُّبَعِيُّ، عَنْ أَبِي بَكْرٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَلَّى الْبَرْدَيْنِ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{1438}\hadithtrans{Abu Bakr reported on the authority of his father that the Messenger of Allah (ﷺ) said:He who observed two prayers at two cool (hours) would enter Paradise}}
\hadithdefcmd{muslim}{1439}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، ح قَالَ وَحَدَّثَنَا ابْنُ خِرَاشٍ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالاَ جَمِيعًا حَدَّثَنَا هَمَّامٌ، بِهَذَا الإِسْنَادِ وَنَسَبَا أَبَا بَكْرٍ فَقَالاَ ابْنُ أَبِي مُوسَى ‏.‏\hadithno{1439}\hadithtrans{This hadith has been narrated by the same chain of transmitters by Hammam, and said about Abu Bakr that he was Ibn Abu Musa}}
\hadithdefcmd{muslim}{1440}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْمَغْرِبَ إِذَا غَرَبَتِ الشَّمْسُ وَتَوَارَتْ بِالْحِجَابِ ‏.‏\hadithno{1440}\hadithtrans{Salama b. al-Akwa' reported that the Messenger of Allah (ﷺ) used to pray the evening prayer when the sun had set and disappeared (behind the horizon)}}
\hadithdefcmd{muslim}{1441}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي أَبُو النَّجَاشِيِّ، قَالَ سَمِعْتُ رَافِعَ بْنَ خَدِيجٍ، يَقُولُ كُنَّا نُصَلِّي الْمَغْرِبَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَنْصَرِفُ أَحَدُنَا وَإِنَّهُ لَيُبْصِرُ مَوَاقِعَ نَبْلِهِ ‏.‏\hadithno{1441}\hadithtrans{Rafi' b. Khadij reported:We used to observe the evening prayer with the Messenger of Allah (ﷺ) and then one of us would go away and he could see the (distant) place where his arrow would fall}}
\hadithdefcmd{muslim}{1442}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا شُعَيْبُ بْنُ إِسْحَاقَ الدِّمَشْقِيُّ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي أَبُو النَّجَاشِيِّ، حَدَّثَنِي رَافِعُ بْنُ خَدِيجٍ، قَالَ كُنَّا نُصَلِّي الْمَغْرِبَ ‏.‏ بِنَحْوِهِ ‏.‏\hadithno{1442}\hadithtrans{A hadith like this, i. e." We used to observe evening prayer...." so on and so forth, has been narrated by Rafi' b. Khadij by another chain of transmitters}}
\hadithdefcmd{muslim}{1443}{وَحَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً مِنَ اللَّيَالِي بِصَلاَةِ الْعِشَاءِ وَهِيَ الَّتِي تُدْعَى الْعَتَمَةَ فَلَمْ يَخْرُجْ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى قَالَ عُمَرُ بْنُ الْخَطَّابِ نَامَ النِّسَاءُ وَالصِّبْيَانُ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لأَهْلِ الْمَسْجِدِ حِينَ خَرَجَ عَلَيْهِمْ ‏"‏ مَا يَنْتَظِرُهَا أَحَدٌ مِنْ أَهْلِ الأَرْضِ غَيْرُكُمْ ‏"‏ ‏.‏ وَذَلِكَ قَبْلَ أَنْ يَفْشُوَ الإِسْلاَمُ فِي النَّاسِ ‏.‏ زَادَ حَرْمَلَةُ فِي رِوَايَتِهِ قَالَ ابْنُ شِهَابٍ وَذُكِرَ لِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَمَا كَانَ لَكُمْ أَنْ تَنْزُرُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الصَّلاَةِ ‏"‏ ‏.‏ وَذَاكَ حِينَ صَاحَ عُمَرُ بْنُ الْخَطَّابِ ‏.‏\hadithno{1443}\hadithtrans{A'isha. the wife of the Messenger of Allah (ﷺ), reported:The Messenger of Allah (ﷺ) deferred one night the 'Isya' prayer. And this is called 'Atama. And the Messenger of Allah (ﷺ) did not come out till Umar b. Khattab told (him) that the women and children had gone to sleep. So the Messenger of Allah (ﷺ) came out towards them and said to the people of the mosque: None except you from the people of the earth waits for it (for the night prayer at this late hour), and it was before Islam had spread amongst people. And in the narration transmitted by Ibn Shihab the Messenger of Allah (ﷺ) is reported to have said: It is not meant that you should compel the Messenger of Allah (ﷺ) for prayer. And (this he said) when 'Umar b. Khattab called (the Holy Prophet) in a loud voice}}
\hadithdefcmd{muslim}{1444}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏ وَلَمْ يَذْكُرْ قَوْلَ الزُّهْرِيِّ وَذُكِرَ لِي ‏.‏ وَمَا بَعْدَهُ ‏.‏\hadithno{1444}\hadithtrans{A hadith like this has been narrated by Ibn Shihab with the same chain of transmitters, but therein no mention has been made of the words of al-Zuhri:It was narrated to me, and that which followed}}
\hadithdefcmd{muslim}{1445}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ حَاتِمٍ، كِلاَهُمَا عَنْ مُحَمَّدِ بْنِ بَكْرٍ، ح قَالَ وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، ح قَالَ وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالُوا جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي الْمُغِيرَةُ بْنُ حَكِيمٍ، عَنْ أُمِّ كُلْثُومٍ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا أَخْبَرَتْهُ عَنْ عَائِشَةَ، قَالَتْ أَعْتَمَ النَّبِيُّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ حَتَّى ذَهَبَ عَامَّةُ اللَّيْلِ وَحَتَّى نَامَ أَهْلُ الْمَسْجِدِ ثُمَّ خَرَجَ فَصَلَّى فَقَالَ ‏"‏ إِنَّهُ لَوَقْتُهَا لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي ‏"‏ ‏.‏ وَفِي حَدِيثِ عَبْدِ الرَّزَّاقِ ‏"‏ لَوْلاَ أَنْ يَشُقَّ عَلَى أُمَّتِي ‏"‏ ‏.‏\hadithno{1445}\hadithtrans{A'isha reported:The Apostle of Allah (ﷺ) one night delayed (observing the 'Isya' prayer) till a great part of the night was over and the people in the mosque had gone to sleep. He (the Holy Prophet) then came out and observed prayer and said: This is the proper time for it; were it not that I would impose a burden on my people (I would normally pray at this time). In the hadith transmitters by 'Abd al-Razzaq (the words are):" Were it not that it would impose burden on my people}}
\hadithdefcmd{muslim}{1446}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، - عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ مَكَثْنَا ذَاتَ لَيْلَةٍ نَنْتَظِرُ رَسُولَ اللَّهِ صلى الله عليه وسلم - لِصَلاَةِ الْعِشَاءِ الآخِرَةِ فَخَرَجَ إِلَيْنَا حِينَ ذَهَبَ ثُلُثُ اللَّيْلِ أَوْ بَعْدَهُ فَلاَ نَدْرِي أَشَىْءٌ شَغَلَهُ فِي أَهْلِهِ أَوْ غَيْرُ ذَلِكَ فَقَالَ حِينَ خَرَجَ ‏ "‏ إِنَّكُمْ لَتَنْتَظِرُونَ صَلاَةً مَا يَنْتَظِرُهَا أَهْلُ دِينٍ غَيْرُكُمْ وَلَوْلاَ أَنْ يَثْقُلَ عَلَى أُمَّتِي لَصَلَّيْتُ بِهِمْ هَذِهِ السَّاعَةَ ‏"‏ ‏.‏ ثُمَّ أَمَرَ الْمُؤَذِّنَ فَأَقَامَ الصَّلاَةَ وَصَلَّى ‏.‏\hadithno{1446}\hadithtrans{Abdullah b. Umar reported:We waited one night in expectation of the Messenger of Allah (ﷺ) for the last prayer of the night, and he came out to us when a third of the night had passed even after that. We do not know whether he had been occupied with family business or something else. When he came cut he said: You are waiting for prayer, for which the followers of no other religion wait. except you. Were it not a burden for my Ummah, I would have led them (in the 'Isya' prayer) at this hour. He then ordered the Mu'adhdbin (to call for prayer) and then stood up for prayer and observed prayer}}
\hadithdefcmd{muslim}{1447}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي نَافِعٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شُغِلَ عَنْهَا لَيْلَةً فَأَخَّرَهَا حَتَّى رَقَدْنَا فِي الْمَسْجِدِ ثُمَّ اسْتَيْقَظْنَا ثُمَّ رَقَدْنَا ثُمَّ اسْتَيْقَظْنَا ثُمَّ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ لَيْسَ أَحَدٌ مِنْ أَهْلِ الأَرْضِ اللَّيْلَةَ يَنْتَظِرُ الصَّلاَةَ غَيْرُكُمْ ‏"‏ ‏.‏\hadithno{1447}\hadithtrans{Abdullah b. 'Umar reported that the Messenger of Allah (ﷺ) was one night occupied (in some work) and he delayed it ('Isya' prayer) till we went to sleep in the mosque. We then woke up and again went to sleep and again woke up. The Messenger of Allah (ﷺ) then came to us and said:None among the people of the earth except you waits for prayer in the night}}
\hadithdefcmd{muslim}{1448}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ الْعَمِّيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، ‏.‏ أَنَّهُمْ سَأَلُوا أَنَسًا عَنْ خَاتَمِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَخَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْعِشَاءَ ذَاتَ لَيْلَةٍ إِلَى شَطْرِ اللَّيْلِ أَوْ كَادَ يَذْهَبُ شَطْرُ اللَّيْلِ ثُمَّ جَاءَ فَقَالَ ‏ "‏ إِنَّ النَّاسَ قَدْ صَلَّوْا وَنَامُوا وَإِنَّكُمْ لَمْ تَزَالُوا فِي صَلاَةٍ مَا انْتَظَرْتُمُ الصَّلاَةَ ‏"‏ ‏.‏ قَالَ أَنَسٌ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ خَاتَمِهِ مِنْ فِضَّةٍ وَرَفَعَ إِصْبَعَهُ الْيُسْرَى بِالْخِنْصَرِ ‏.‏\hadithno{1448}\hadithtrans{Thabit reported:They (the believers) asked Anas about the ring of the Messenger of Allah (ﷺ) and he said: One night the Messenger of Allah (ﷺ) delayed (observing) the 'Isya' prayer up to the midnight or midnight was about to be over. He then came and said: (Other) people have offered prayers and slept, but you are constantly in prayer as long as you wait for prayer. Anas said: I perceive as if I am seeing the lustre of his silver ring, and lifted his, small left finger (in order to show how the Prophet had lifted it)}}
\hadithdefcmd{muslim}{1449}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا أَبُو زَيْدٍ، سَعِيدُ بْنُ الرَّبِيعِ حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ نَظَرْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم لَيْلَةً حَتَّى كَانَ قَرِيبٌ مِنْ نِصْفِ اللَّيْلِ ثُمَّ جَاءَ فَصَلَّى ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَكَأَنَّمَا أَنْظُرُ إِلَى وَبِيصِ خَاتَمِهِ فِي يَدِهِ مِنْ فِضَّةٍ ‏.‏\hadithno{1449}\hadithtrans{Anas b. Malik reported:We waited for the Messenger of Allah (may peace be upon hi n) one night, till it was about midnight. He (the Holy Prophet) came and observed prayer and then turned his face towards us, as it I was seeing the lustre of the silver ring on his finger}}
\hadithdefcmd{muslim}{1450}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْعَطَّارُ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ الْحَنَفِيُّ، حَدَّثَنَا قُرَّةُ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ ‏.‏\hadithno{1450}\hadithtrans{This hadith has been narrated by Qurra with the same chain of transmitters, but therein he did not mention:" He turned his face towards us}}
\hadithdefcmd{muslim}{1451}{وَحَدَّثَنَا أَبُو عَامِرٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ كُنْتُ أَنَا وَأَصْحَابِي الَّذِينَ، قَدِمُوا مَعِي فِي السَّفِينَةِ نُزُولاً فِي بَقِيعِ بُطْحَانَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ فَكَانَ يَتَنَاوَبُ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ صَلاَةِ الْعِشَاءِ كُلَّ لَيْلَةٍ نَفَرٌ مِنْهُمْ قَالَ أَبُو مُوسَى فَوَافَقْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَا وَأَصْحَابِي وَلَهُ بَعْضُ الشُّغُلِ فِي أَمْرِهِ حَتَّى أَعْتَمَ بِالصَّلاَةِ حَتَّى ابْهَارَّ اللَّيْلُ ثُمَّ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى بِهِمْ فَلَمَّا قَضَى صَلاَتَهُ قَالَ لِمَنْ حَضَرَهُ ‏"‏ عَلَى رِسْلِكُمْ أُعْلِمُكُمْ وَأَبْشِرُوا أَنَّ مِنْ نِعْمَةِ اللَّهِ عَلَيْكُمْ أَنَّهُ لَيْسَ مِنَ النَّاسِ أَحَدٌ يُصَلِّي هَذِهِ السَّاعَةَ غَيْرُكُمْ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ مَا صَلَّى هَذِهِ السَّاعَةَ أَحَدٌ غَيْرُكُمْ ‏"‏ ‏.‏ لاَ نَدْرِي أَىَّ الْكَلِمَتَيْنِ قَالَ قَالَ أَبُو مُوسَى فَرَجَعْنَا فَرِحِينَ بِمَا سَمِعْنَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1451}\hadithtrans{Abu Musa reported:I and my companions who had sailed along with me in the boat landed with me in the valley of Buthan while the Messenger of Allah (ﷺ) was staying in Medina. A party of people amongst them went to the Messenger of Allah (ﷺ) every night at the time of the 'Isya' prayer turn by turn. Abu Musa said: (One night) we (I and my companions) went to the Messenger of Allah (ﷺ) and he was occupied in some matter till there was a delay in prayer so much so that it was the middle of the night. The Messenger of Allah (ﷺ) then came out and led them (Musa's companions) in prayer. And when he had observed his prayer he said to the audience present: Take it easy, I am going to give you information and glad tidings that it is the blessing of Allah upon you for there is none among the people, except you, who prays at this hour (of the night), or he said: None except you observed prayer at this. (late) hour. He (i. e. the narrator) said: I am not sure which of these two sentences he actually uttered. Abu Musa, said: We came back happy for what we heard from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1452}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ قُلْتُ لِعَطَاءٍ أَىُّ حِينٍ أَحَبُّ إِلَيْكَ أَنْ أُصَلِّيَ الْعِشَاءَ الَّتِي يَقُولُهَا النَّاسُ الْعَتَمَةَ إِمَامًا وَخِلْوًا قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ يَقُولُ أَعْتَمَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ الْعِشَاءَ - قَالَ - حَتَّى رَقَدَ نَاسٌ وَاسْتَيْقَظُوا وَرَقَدُوا وَاسْتَيْقَظُوا فَقَامَ عُمَرُ بْنُ الْخَطَّابِ فَقَالَ الصَّلاَةَ ‏.‏ فَقَالَ عَطَاءٌ قَالَ ابْنُ عَبَّاسٍ فَخَرَجَ نَبِيُّ اللَّهِ صلى الله عليه وسلم كَأَنِّي أَنْظُرُ إِلَيْهِ الآنَ يَقْطُرُ رَأْسُهُ مَاءً وَاضِعًا يَدَهُ عَلَى شِقِّ رَأْسِهِ قَالَ ‏ "‏ لَوْلاَ أَنْ يَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ أَنْ يُصَلُّوهَا كَذَلِكَ ‏"‏ ‏.‏ قَالَ فَاسْتَثْبَتُّ عَطَاءً كَيْفَ وَضَعَ النَّبِيُّ صلى الله عليه وسلم يَدَهُ عَلَى رَأْسِهِ كَمَا أَنْبَأَهُ ابْنُ عَبَّاسٍ فَبَدَّدَ لِي عَطَاءٌ بَيْنَ أَصَابِعِهِ شَيْئًا مِنْ تَبْدِيدٍ ثُمَّ وَضَعَ أَطْرَافَ أَصَابِعِهِ عَلَى قَرْنِ الرَّأْسِ ثُمَّ صَبَّهَا يُمِرُّهَا كَذَلِكَ عَلَى الرَّأْسِ حَتَّى مَسَّتْ إِبْهَامُهُ طَرَفَ الأُذُنِ مِمَّا يَلِي الْوَجْهَ ثُمَّ عَلَى الصُّدْغِ وَنَاحِيَةِ اللِّحْيَةِ لاَ يُقَصِّرُ وَلاَ يَبْطِشُ بِشَىْءٍ إِلاَّ كَذَلِكَ ‏.‏ قُلْتُ لِعَطَاءٍ كَمْ ذُكِرَ لَكَ أَخَّرَهَا النَّبِيُّ صلى الله عليه وسلم لَيْلَتَئِذٍ قَالَ لاَ أَدْرِي ‏.‏ قَالَ عَطَاءٌ أَحَبُّ إِلَىَّ أَنْ أُصَلِّيَهَا إِمَامًا وَخِلْوًا مُؤَخَّرَةً كَمَا صَلاَّهَا النَّبِيُّ صلى الله عليه وسلم لَيْلَتَئِذٍ فَإِنْ شَقَّ عَلَيْكَ ذَلِكَ خِلْوًا أَوْ عَلَى النَّاسِ فِي الْجَمَاعَةِ وَأَنْتَ إِمَامُهُمْ فَصَلِّهَا وَسَطًا لاَ مُعَجَّلَةً وَلاَ مُؤَخَّرَةً ‏.‏\hadithno{1452}\hadithtrans{Ibn Juraij reported:I said to Ata': Which time do you deem fit for me to say the 'Isya' prayer, -as an Imam or alone, -that time which is called by people 'Atama? He said: I heard Ibn 'Abbas saying: The Apostle of Allah (ﷺ) one night delayed the 'Isya' prayer till the people went to sleep. They woke up and again went to sleep and again woke up. Then 'Umar b. Khattab stood up and said (loudly)" Prayer." Ata' further reported that Ibn 'Abbas said: The Apostle of Allah (ﷺ) came out, and as if I am still seeing him with water trickling from his head, and with his hand placed on one side of the head, and he said: Were it not hard for my Ummah, I would have ordered them to observe this prayer like this (i. e. at late hours). I inquired from 'Ata' how the Messenger of Allah (ﷺ) placed his hand upon his head as Ibn Abbas had informed. So Ata' spread his fingers a little and then placed the ends of his fingers on the side of his head. He then moved them like this over his head till the thumb touched that part of the ear which is near the face and then it (went) to the earlock and the part of the heard. It (the bind) neither held nor caught anything but this is how (it moved oil). I said to Ata': Was it mentioned to you (by Ibn Abbas) how long did the Apostle (ﷺ) delay it (the prayer) during that eight? He said: I do not know (I cannot give you the exact time). Ali' said: I love that I should say prayer, whether as an Imam or alone at delayed hours as the Messenger of Allah (ﷺ) said that night, but if It is hard upon you in your individual capacity or upon people in the congregation and you are their Imam, then say prayer ('Isha') at the middle hours neither too early nor too late}}
\hadithdefcmd{muslim}{1453}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُؤَخِّرُ صَلاَةَ الْعِشَاءِ الآخِرَةِ ‏.‏\hadithno{1453}\hadithtrans{Jabir b. Samura reported that the Messenger of Allah (ﷺ) postponed the last 'Isha' prayer}}
\hadithdefcmd{muslim}{1454}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الصَّلَوَاتِ نَحْوًا مِنْ صَلاَتِكُمْ وَكَانَ يُؤَخِّرُ الْعَتَمَةَ بَعْدَ صَلاَتِكُمْ شَيْئًا وَكَانَ يُخِفُّ الصَّلاَةَ ‏.‏ وَفِي رِوَايَةِ أَبِي كَامِلٍ يُخَفِّفُ ‏.‏\hadithno{1454}\hadithtrans{Jabir b. Samura reported:The Messenger of Allah (ﷺ) used to observe prayers like your prayers, but he would delay the prayer after nightfall to a little after the time you observed it, and he would shorten the prayer}}
\hadithdefcmd{muslim}{1455}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَغْلِبَنَّكُمُ الأَعْرَابُ عَلَى اسْمِ صَلاَتِكُمْ أَلاَ إِنَّهَا الْعِشَاءُ وَهُمْ يُعْتِمُونَ بِالإِبِلِ ‏"‏ ‏.‏\hadithno{1455}\hadithtrans{Abdullah b. 'Umar reported:I heard the Messenger of Allah (ﷺ) as saying: Let the bedouin not gain upper hand over you in regard to the name of your prayer. See I (The night prayer should be called) 'Isya' (and the bedouins call it Atama (because) they milk their camels late}}
\hadithdefcmd{muslim}{1456}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَغْلِبَنَّكُمُ الأَعْرَابُ عَلَى اسْمِ صَلاَتِكُمُ الْعِشَاءِ فَإِنَّهَا فِي كِتَابِ اللَّهِ الْعِشَاءُ وَإِنَّهَا تُعْتِمُ بِحِلاَبِ الإِبِلِ ‏"‏ ‏.‏\hadithno{1456}\hadithtrans{Ibn 'Umar said:The Messenger of Allah (ﷺ) said: Let the bedouin not gain upper band over you In regard to the name of your prayer, i. e. night prayer, for it is mentioned 'Isya' in the Book of Allah (i. e. the Qur'an). (The bedouin call it 'Atama because) they make delay in milling their she-camels}}
\hadithdefcmd{muslim}{1457}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، كُلُّهُمْ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ، - قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ نِسَاءَ الْمُؤْمِنَاتِ، كُنَّ يُصَلِّينَ الصُّبْحَ مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ يَرْجِعْنَ مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ لاَ يَعْرِفُهُنَّ أَحَدٌ ‏.‏\hadithno{1457}\hadithtrans{A'isha reported:The believing women used to pray the morning prayer with the Messenger of Allah and then return wrapped in their mantles. No one could recognise them}}
\hadithdefcmd{muslim}{1458}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَقَدْ كَانَ نِسَاءٌ مِنَ الْمُؤْمِنَاتِ يَشْهَدْنَ الْفَجْرَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ ثُمَّ يَنْقَلِبْنَ إِلَى بُيُوتِهِنَّ وَمَا يُعْرَفْنَ مِنْ تَغْلِيسِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالصَّلاَةِ ‏.‏\hadithno{1458}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), reported:The believing women observed the morning prayer with the Messenger of Allah (ﷺ) wrapped in their mantles. They then went back to their houses and were unrecognisable, because of the Messenger of Allah's (ﷺ) praying in the darkness before dawn}}
\hadithdefcmd{muslim}{1459}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَإِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، قَالاَ حَدَّثَنَا مَعْنٌ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُصَلِّي الصُّبْحَ فَيَنْصَرِفُ النِّسَاءُ مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ مَا يُعْرَفْنَ مِنَ الْغَلَسِ ‏.‏ وَقَالَ الأَنْصَارِيُّ فِي رِوَايَتِهِ مُتَلَفِّفَاتٍ ‏.‏\hadithno{1459}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) used to observe the morning prayer, and the women would go back wrapped in their mantles being unrecognisable because of the darkness before dawn. (Ishaq b. Musa) al-Ansari (one of the transmitters in this chain of narration) narrated" wrapped" (only) in his narration. (No mention was made of mantles)}}
\hadithdefcmd{muslim}{1460}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ الْحَسَنِ بْنِ عَلِيٍّ، قَالَ لَمَّا قَدِمَ الْحَجَّاجُ الْمَدِينَةَ فَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الظُّهْرَ بِالْهَاجِرَةِ وَالْعَصْرَ وَالشَّمْسُ نَقِيَّةٌ وَالْمَغْرِبَ إِذَا وَجَبَتْ وَالْعِشَاءَ أَحْيَانًا يُؤَخِّرُهَا وَأَحْيَانًا يُعَجِّلُ كَانَ إِذَا رَآهُمْ قَدِ اجْتَمَعُوا عَجَّلَ وَإِذَا رَآهُمْ قَدْ أَبْطَئُوا أَخَّرَ وَالصُّبْحَ كَانُوا أَوْ - قَالَ - كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّيهَا بِغَلَسٍ ‏.‏\hadithno{1460}\hadithtrans{Muhammad b. 'Amr b. al-Hasan b. 'All reported:When Hajjaj came to Medina we asked Jabir b. Abdullah (about the timings of prayer as observed by the Holy Prophet). He said: The Messenger of Allah (ﷺ) used to pray afternoon prayer in the midday heat; the afternoon prayer when the sun was bright; the evening prayer when the sun had completely set; and as for the night prayer, he sometimes delayed and sometimes (observed it) at earlier hours. When he found them (his Companions) assembled (at earlier hours) he (prayed) early. and when he saw them coming late, he delayed the (prayer). and the morning prayer the Messenger of Allah (ﷺ) observed in the darkness before dawn}}
\hadithdefcmd{muslim}{1461}{وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدٍ، سَمِعَ مُحَمَّدَ بْنَ عَمْرِو بْنِ الْحَسَنِ بْنِ عَلِيٍّ، قَالَ كَانَ الْحَجَّاجُ يُؤَخِّرُ الصَّلَوَاتِ فَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ بِمِثْلِ حَدِيثِ غُنْدَرٍ ‏.‏\hadithno{1461}\hadithtrans{Muhammad b. 'Amr al-Hasan b. 'All reported:Hajjaj used to delay the prayers, and so we asked Jabir b. 'Abdullah, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1462}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي سَيَّارُ بْنُ سَلاَمَةَ، قَالَ سَمِعْتُ أَبِي يَسْأَلُ أَبَا بَرْزَةَ، عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - قُلْتُ آنْتَ سَمِعْتَهُ قَالَ فَقَالَ كَأَنَّمَا أَسْمَعُكَ السَّاعَةَ - قَالَ - سَمِعْتُ أَبِي يَسْأَلُهُ عَنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ كَانَ لاَ يُبَالِي بَعْضَ تَأْخِيرِهَا - قَالَ يَعْنِي الْعِشَاءَ - إِلَى نِصْفِ اللَّيْلِ وَلاَ يُحِبُّ النَّوْمَ قَبْلَهَا وَلاَ الْحَدِيثَ بَعْدَهَا ‏.‏ قَالَ شُعْبَةُ ثُمَّ لَقِيتُهُ بَعْدُ فَسَأَلْتُهُ فَقَالَ وَكَانَ يُصَلِّي الظُّهْرَ حِينَ تَزُولُ الشَّمْسُ وَالْعَصْرَ يَذْهَبُ الرَّجُلُ إِلَى أَقْصَى الْمَدِينَةِ وَالشَّمْسُ حَيَّةٌ - قَالَ - وَالْمَغْرِبَ لاَ أَدْرِي أَىَّ حِينٍ ذَكَرَ ‏.‏ قَالَ ثُمَّ لَقِيتُهُ بَعْدُ فَسَأَلْتُهُ فَقَالَ وَكَانَ يُصَلِّي الصُّبْحَ فَيَنْصَرِفُ الرَّجُلُ فَيَنْظُرُ إِلَى وَجْهِ جَلِيسِهِ الَّذِي يَعْرِفُ فَيَعْرِفُهُ ‏.‏ قَالَ وَكَانَ يَقْرَأُ فِيهَا بِالسِّتِّينَ إِلَى الْمِائَةِ ‏.‏\hadithno{1462}\hadithtrans{Sayyar b. Salama reported:I heard my father asking Abu Barza (al- Aslami) about the prayer of Allah's Messenger (ﷺ) I (Shu'ba, one of the narrators) said: Did you hear it (from Abu Barza)? He said: 1 feel as if I am bearing you at this very time. He said: I heard my father asking about the prayer of the Messenger of Allah (ﷺ) and he (Abu Barza) making this reply: He (the Holy Prophet) did not mind delaying-some (prayer) i. e. 'Isya' prayer, even up to the midnight and did not like sleeping before observing it, and talking after it. Shu'ba said: I met him subsequently and asked him (about the prayers of the Holy Prophet) and he said: He observed the noon prayer when the sun was past the meridian, he would pray the afternoon prayer, after which a person would o to the outskirts of Medina and the sun was still bright; (I forgot what he said about the evening prayer) ; I then met him on a subsequent occasion and asked him (about the prayers of the Holy Prophet; and he said: He would observe the morning prayer (at such a time) so that a man would go back and would recognise his neighbour by casting a glance at his face, and he would recite from sixty to one hundred verses in it}}
\hadithdefcmd{muslim}{1463}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سَيَّارِ بْنِ سَلاَمَةَ، قَالَ سَمِعْتُ أَبَا بَرْزَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُبَالِي بَعْضَ تَأْخِيرِ صَلاَةِ الْعِشَاءِ إِلَى نِصْفِ اللَّيْلِ وَكَانَ لاَ يُحِبُّ النَّوْمَ قَبْلَهَا وَلاَ الْحَدِيثَ بَعْدَهَا ‏.‏ قَالَ شُعْبَةُ ثُمَّ لَقِيتُهُ مَرَّةً أُخْرَى فَقَالَ أَوْ ثُلُثِ اللَّيْلِ ‏.‏\hadithno{1463}\hadithtrans{Sayyar b. Salama reported:I heard Abu Barza saying that the Messenger of Allah (ﷺ) did not mind some delay in the 'Isha' prayer even up to midnight and he did not like sleeping before (observing it) and talking after it. Shu'ba said: I again met him (Sayyar b. Salama) for the second time and he said: Even up to the third (part) of the night}}
\hadithdefcmd{muslim}{1464}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا سُوَيْدُ بْنُ عَمْرٍو الْكَلْبِيُّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ سَيَّارِ بْنِ سَلاَمَةَ أَبِي الْمِنْهَالِ، قَالَ سَمِعْتُ أَبَا بَرْزَةَ الأَسْلَمِيَّ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُؤَخِّرُ الْعِشَاءَ إِلَى ثُلُثِ اللَّيْلِ وَيَكْرَهُ النَّوْمَ قَبْلَهَا وَالْحَدِيثَ بَعْدَهَا وَكَانَ يَقْرَأُ فِي صَلاَةِ الْفَجْرِ مِنَ الْمِائَةِ إِلَى السِّتِّينَ وَكَانَ يَنْصَرِفُ حِينَ يَعْرِفُ بَعْضُنَا وَجْهَ بَعْضٍ ‏.‏\hadithno{1464}\hadithtrans{Abu Barza b. Aslami is reported to have said:The Messenger of Allah (ﷺ) delayed the night prayer till a third of the night had passed and he did not approve of sleeping before it, and talking after it, and he used to recite in the morning prayer from one hundred to sixty verses (and completed the prayer at such hours) when we recognised the faces of one another}}
\hadithdefcmd{muslim}{1465}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح قَالَ وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ ‏"‏ كَيْفَ أَنْتَ إِذَا كَانَتْ عَلَيْكَ أُمَرَاءُ يُؤَخِّرُونَ الصَّلاَةَ عَنْ وَقْتِهَا أَوْ يُمِيتُونَ الصَّلاَةَ عَنْ وَقْتِهَا ‏"‏ ‏.‏ قَالَ قُلْتُ فَمَا تَأْمُرُنِي قَالَ ‏"‏ صَلِّ الصَّلاَةَ لِوَقْتِهَا فَإِنْ أَدْرَكْتَهَا مَعَهُمْ فَصَلِّ فَإِنَّهَا لَكَ نَافِلَةٌ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ خَلَفٌ عَنْ وَقْتِهَا ‏.‏\hadithno{1465}\hadithtrans{Abu Dharr reported:The Messenger of Allah (ﷺ) said to me: How would you act when you are under the rulers who would delay the prayer beyond its prescribed time, or they would make prayer a dead thing as far as its proper time is concerned? I said: What do you command? He (the Holy Prophet) said: Observe the prayer at Its proper time, and if you can say it along with them do so, for it would be a superetogatory prayer for you. Khalaf (one of the narrators in the above hadith) has not mentioned" beyond their (prescribed) time}}
\hadithdefcmd{muslim}{1466}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَبَا ذَرٍّ إِنَّهُ سَيَكُونُ بَعْدِي أُمَرَاءُ يُمِيتُونَ الصَّلاَةَ فَصَلِّ الصَّلاَةَ لِوَقْتِهَا فَإِنْ صَلَّيْتَ لِوَقْتِهَا كَانَتْ لَكَ نَافِلَةً وَإِلاَّ كُنْتَ قَدْ أَحْرَزْتَ صَلاَتَكَ ‏"‏ ‏.‏\hadithno{1466}\hadithtrans{Abu Dharr reported:The Messenger of Allah (ﷺ) said to me: O Abu Dharr, you would soon find after me rulers who would make their prayers dead. You should say prayer at its prescribed time. If you say prayer at its prescribed time that would be a supererogatory prayer for you, otherwise you saved your prayer}}
\hadithdefcmd{muslim}{1467}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ شُعْبَةَ، عَنْ أَبِي عِمْرَانَ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ إِنَّ خَلِيلِي أَوْصَانِي أَنْ أَسْمَعَ وَأُطِيعَ وَإِنْ كَانَ عَبْدًا مُجَدَّعَ الأَطْرَافِ وَأَنْ أُصَلِّيَ الصَّلاَةَ لِوَقْتِهَا ‏ "‏ فَإِنْ أَدْرَكْتَ الْقَوْمَ وَقَدْ صَلَّوْا كُنْتَ قَدْ أَحْرَزْتَ صَلاَتَكَ وَإِلاَّ كَانَتْ لَكَ نَافِلَةً ‏"‏ ‏.‏\hadithno{1467}\hadithtrans{Abu Dharr reported:My friend (the Holy Prophet) bade me to hear and obey (the ruler) even if he is a slave having his feet and arms cut off, and observe prayer at its prescribed time. (And further said): It you find people having observed the prayer, you in fact saved your prayer, otherwise (if you join with them) that would be a Nafl prayer for you}}
\hadithdefcmd{muslim}{1468}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ بُدَيْلٍ، قَالَ سَمِعْتُ أَبَا الْعَالِيَةِ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَضَرَبَ فَخِذِي ‏"‏ كَيْفَ أَنْتَ إِذَا بَقِيتَ فِي قَوْمٍ يُؤَخِّرُونَ الصَّلاَةَ عَنْ وَقْتِهَا ‏"‏ ‏.‏ قَالَ قَالَ مَا تَأْمُرُ قَالَ ‏"‏ صَلِّ الصَّلاَةَ لِوَقْتِهَا ثُمَّ اذْهَبْ لِحَاجَتِكَ فَإِنْ أُقِيمَتِ الصَّلاَةُ وَأَنْتَ فِي الْمَسْجِدِ فَصَلِّ ‏"‏ ‏.‏\hadithno{1468}\hadithtrans{Abu Dharr reported:The Messenger of Allah (ﷺ) struck my thigh and said: How would you act if you survive among the people who would delay prayers beyond their (prescribed) time? He (Abu Dharr) said: What do you command (under this situation)? He (the Holy Prophet) slid: Observe prayer at its prescribed time, then go (to meet) your needs, and if the Iqama is pronounced, and you are present in the mosque, then observe prayer (along with the Jama'at)}}
\hadithdefcmd{muslim}{1469}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ أَبِي الْعَالِيَةِ الْبَرَّاءِ، قَالَ أَخَّرَ ابْنُ زِيَادٍ الصَّلاَةَ فَجَاءَنِي عَبْدُ اللَّهِ بْنُ الصَّامِتِ فَأَلْقَيْتُ لَهُ كُرْسِيًّا فَجَلَسَ عَلَيْهِ فَذَكَرْتُ لَهُ صَنِيعَ ابْنِ زِيَادٍ فَعَضَّ عَلَى شَفَتِهِ وَضَرَبَ فَخِذِي وَقَالَ إِنِّي سَأَلْتُ أَبَا ذَرٍّ كَمَا سَأَلْتَنِي فَضَرَبَ فَخِذِي كَمَا ضَرَبْتُ فَخِذَكَ وَقَالَ إِنِّي سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا سَأَلْتَنِي فَضَرَبَ فَخِذِي كَمَا ضَرَبْتُ فَخِذَكَ وَقَالَ ‏ "‏ صَلِّ الصَّلاَةَ لِوَقْتِهَا فَإِنْ أَدْرَكَتْكَ الصَّلاَةُ مَعَهُمْ فَصَلِّ وَلاَ تَقُلْ إِنِّي قَدْ صَلَّيْتُ فَلاَ أُصَلِّي ‏"‏ ‏.‏\hadithno{1469}\hadithtrans{Abu'l-'Aliyat al-Bara reported:Ibn Ziyad delayed the prayer. 'Abdullah b. Samit came to me and I placed a chair for him and he sat in it and I made a mention of whit Ibn Ziyad had done. He bit hit lips (as a sign of extreme anger and annoyance) and struck at my thigh and said: I asked Abu Dharr as you have asked me, and he struck my thigh just as I have struck your thigh, and said: I asked the Messenger of Allah (ﷺ) as you have asked me and he struck my thigh just as I have struck your thigh, and he (the Holy Prophet) said: Observe prayer at its prescribed time, and if you can say prayer along with them. do so, and do not say." I have observed prayer and so I shall not pray}}
\hadithdefcmd{muslim}{1470}{وَحَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي نَعَامَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ ‏ "‏ كَيْفَ أَنْتُمْ - أَوْ قَالَ كَيْفَ أَنْتَ - إِذَا بَقِيتَ فِي قَوْمٍ يُؤَخِّرُونَ الصَّلاَةَ عَنْ وَقْتِهَا فَصَلِّ الصَّلاَةَ لِوَقْتِهَا ثُمَّ إِنْ أُقِيمَتِ الصَّلاَةُ فَصَلِّ مَعَهُمْ فَإِنَّهَا زِيَادَةُ خَيْرٍ ‏"‏ ‏.‏\hadithno{1470}\hadithtrans{Abu Dharr reported:(The Messenger of Allah) said: How would you, or how would thou, act if you survive to live among people who defer prayer beyond the (prescribed) time? (The narrator said: Allah and His Messenger know best). whereupon he said: Observe prayer at its prescribed time, but if the Iqama is pronounced for (congregational) prayer, then observe prayer along with them. for herein is an excess of virtue}}
\hadithdefcmd{muslim}{1471}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، - وَهْوَ ابْنُ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ مَطَرٍ، عَنْ أَبِي الْعَالِيَةِ الْبَرَّاءِ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ الصَّامِتِ نُصَلِّي يَوْمَ الْجُمُعَةِ خَلْفَ أُمَرَاءَ فَيُؤَخِّرُونَ الصَّلاَةَ - قَالَ - فَضَرَبَ فَخِذِي ضَرْبَةً أَوْجَعَتْنِي وَقَالَ سَأَلْتُ أَبَا ذَرٍّ عَنْ ذَلِكَ فَضَرَبَ فَخِذِي وَقَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ صَلُّوا الصَّلاَةَ لِوَقْتِهَا وَاجْعَلُوا صَلاَتَكُمْ مَعَهُمْ نَافِلَةً ‏"‏ ‏.‏ قَالَ وَقَالَ عَبْدُ اللَّهِ ذُكِرَ لِي أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم ضَرَبَ فَخِذَ أَبِي ذَرٍّ ‏.‏\hadithno{1471}\hadithtrans{Abu'l-'Aliyat al-Bara' reported:I said to 'Abdullah b. Samit: We say our Jumu'a prayer behind those rulers who defer the prayer. He ('Abdullah b. Samit), struck. my thigh that I felt pain and said: I asked Abu Dharr about it, he struck my thigh and said: I asked the Messenger of Allah (ﷺ) about it. Upon this he said: Observe prayer at its prescribed time, and treat prayer along with them (along with those Imams who deter prayer) as Nafl. 'Abdullah said: It was narrated to me that the Messenger of Allah (ﷺ) struck the thigh of Abd Dharr}}
\hadithdefcmd{muslim}{1472}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الْجَمَاعَةِ أَفْضَلُ مِنْ صَلاَةِ أَحَدِكُمْ وَحْدَهُ بِخَمْسَةٍ وَعِشْرِينَ جُزْءًا ‏"‏ ‏.‏\hadithno{1472}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Prayer said in a congregation is twenty-five degrees more excellent than prayer said by a single person}}
\hadithdefcmd{muslim}{1473}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ تَفْضُلُ صَلاَةٌ فِي الْجَمِيعِ عَلَى صَلاَةِ الرَّجُلِ وَحْدَهُ خَمْسًا وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏ قَالَ ‏"‏ وَتَجْتَمِعُ مَلاَئِكَةُ اللَّيْلِ وَمَلاَئِكَةُ النَّهَارِ فِي صَلاَةِ الْفَجْرِ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏ وَقُرْآنَ الْفَجْرِ إِنَّ قُرْآنَ الْفَجْرِ كَانَ مَشْهُودًا‏\}‏\hadithno{1473}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Prayer said in a congregation is twenty-five degrees more excellent than prayer said by a single person. He (Abu Huraira further) said: The angels of the night and the angels of the day meet together. Abu Huraira said: Recite it you like:" Surely the recital of the Qur'an at dawn is witnessed" (al-Qur'an, xvii)}}
\hadithdefcmd{muslim}{1474}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدٌ، وَأَبُو سَلَمَةَ أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏.‏ بِمِثْلِ حَدِيثِ عَبْدِ الأَعْلَى عَنْ مَعْمَرٍ إِلاَّ أَنَّهُ قَالَ ‏ "‏ بِخَمْسٍ وَعِشْرِينَ جُزْءًا ‏"‏ ‏.‏\hadithno{1474}\hadithtrans{A hadith like this has been narrated by Abu Huraira with another chain of transmitters with a very slight change of words}}
\hadithdefcmd{muslim}{1475}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا أَفْلَحُ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ سَلْمَانَ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ الْجَمَاعَةِ تَعْدِلُ خَمْسًا وَعِشْرِينَ مِنْ صَلاَةِ الْفَذِّ ‏"‏ ‏.‏\hadithno{1475}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Prayer said in a congregation is equivalent to twenty-five (prayers) as compared with the prayer said by a single person}}
\hadithdefcmd{muslim}{1476}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عُمَرُ بْنُ عَطَاءِ بْنِ أَبِي الْخُوَارِ، أَنَّهُ بَيْنَا هُوَ جَالِسٌ مَعَ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ إِذْ مَرَّ بِهِمْ أَبُو عَبْدِ اللَّهِ خَتَنُ زَيْدِ بْنِ زَبَّانٍ مَوْلَى الْجُهَنِيِّينَ فَدَعَاهُ نَافِعٌ فَقَالَ سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةٌ مَعَ الإِمَامِ أَفْضَلُ مِنْ خَمْسٍ وَعِشْرِينَ صَلاَةً يُصَلِّيهَا وَحْدَهُ ‏"‏ ‏.‏\hadithno{1476}\hadithtrans{Abu Huraira reported:The Messenger of Allah (way peace be upon him) said: Prayer along with the Imam is twenty-five times more excellent than prayer said by a single person}}
\hadithdefcmd{muslim}{1477}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الْجَمَاعَةِ أَفْضَلُ مِنْ صَلاَةِ الْفَذِّ بِسَبْعٍ وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{1477}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) assaying:Prayer said in a congregation is twenty-seven degrees more excellent than prayer said by a single person}}
\hadithdefcmd{muslim}{1478}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الرَّجُلِ فِي الْجَمَاعَةِ تَزِيدُ عَلَى صَلاَتِهِ وَحْدَهُ سَبْعًا وَعِشْرِينَ ‏"‏ ‏.‏\hadithno{1478}\hadithtrans{Ibn 'Umar reported Allah's Apostle (ﷺ) as saying:The prayer of a person in congregation is twenty-seven times in excess to the prayer said alone}}
\hadithdefcmd{muslim}{1479}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَابْنُ، نُمَيْرٍ ح قَالَ وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي قَالاَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ قَالَ ابْنُ نُمَيْرٍ عَنْ أَبِيهِ، ‏"‏ بِضْعًا وَعِشْرِينَ ‏"‏ ‏.‏ وَقَالَ أَبُو بَكْرٍ فِي رِوَايَتِهِ ‏"‏ سَبْعًا وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{1479}\hadithtrans{Ibn Numair reported it on the authority of his father (a preference of) more than twenty (degrees) and Abu Bakr in his narration (has narrated it) twenty- seven degrees}}
\hadithdefcmd{muslim}{1480}{وَحَدَّثَنَاهُ ابْنُ رَافِعٍ، أَخْبَرَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بِضْعًا وَعِشْرِينَ ‏"‏ ‏.‏\hadithno{1480}\hadithtrans{Ibn 'Umar reported from the Messenger of Allah (ﷺ) as some and twenty (degrees)}}
\hadithdefcmd{muslim}{1481}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَدَ نَاسًا فِي بَعْضِ الصَّلَوَاتِ فَقَالَ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ آمُرَ رَجُلاً يُصَلِّي بِالنَّاسِ ثُمَّ أُخَالِفَ إِلَى رِجَالٍ يَتَخَلَّفُونَ عَنْهَا فَآمُرَ بِهِمْ فَيُحَرِّقُوا عَلَيْهِمْ بِحُزَمِ الْحَطَبِ بُيُوتَهُمْ وَلَوْ عَلِمَ أَحَدُهُمْ أَنَّهُ يَجِدُ عَظْمًا سَمِينًا لَشَهِدَهَا ‏"‏ ‏.‏ يَعْنِي صَلاَةَ الْعِشَاءِ ‏.‏\hadithno{1481}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) found some people absenting from certain prayers and he said: I intend that I order (a) person to lead people in prayer, and then go to the persons who do not join the (congregational prayer) and then order their houses to be burnt by the bundles of fuel. If one amongst them were to know that he would find a fat fleshy bone he would attend the night prayer}}
\hadithdefcmd{muslim}{1482}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لَهُمَا - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَثْقَلَ صَلاَةٍ عَلَى الْمُنَافِقِينَ صَلاَةُ الْعِشَاءِ وَصَلاَةُ الْفَجْرِ وَلَوْ يَعْلَمُونَ مَا فِيهِمَا لأَتَوْهُمَا وَلَوْ حَبْوًا وَلَقَدْ هَمَمْتُ أَنْ آمُرَ بِالصَّلاَةِ فَتُقَامَ ثُمَّ آمُرَ رَجُلاً فَيُصَلِّيَ بِالنَّاسِ ثُمَّ أَنْطَلِقَ مَعِي بِرِجَالٍ مَعَهُمْ حُزَمٌ مِنْ حَطَبٍ إِلَى قَوْمٍ لاَ يَشْهَدُونَ الصَّلاَةَ فَأُحَرِّقَ عَلَيْهِمْ بُيُوتَهُمْ بِالنَّارِ ‏"‏ ‏.‏\hadithno{1482}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The most burdensome prayers for the hypocrites are the night prayer and the morning prayer. If they were to know the blessings they have in store, they would have come to them, even though crawling, and I thought that I should order the prayer to be commenced and command a person to lead people in prayer, and I should then go along with some persons having a fagot of fuel with them to the people who have not attended the prayer (in congregation) and would burn their houses with fire}}
\hadithdefcmd{muslim}{1483}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقَدْ هَمَمْتُ أَنْ آمُرَ فِتْيَانِي أَنْ يَسْتَعِدُّوا لِي بِحُزَمٍ مِنْ حَطَبٍ ثُمَّ آمُرَ رَجُلاً يُصَلِّي بِالنَّاسِ ثُمَّ تُحَرَّقُ بُيُوتٌ عَلَى مَنْ فِيهَا ‏"‏ ‏.‏\hadithno{1483}\hadithtrans{Hammam b. Munabbih reported:This is what Abu Huraira reported to us from the Messenger of Allah (ﷺ) and (in this connection) he narrated some ahadith, one of them is: The Messenger of Allah (ﷺ) said: I intend that I should command my young men to gather bundles fuel for me, and then order a person to lead people in prayer, and then burn the houses with their inmates (who have not joined the congregation)}}
\hadithdefcmd{muslim}{1484}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ عَنْ وَكِيعٍ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِنَحْوِهِ ‏.‏\hadithno{1484}\hadithtrans{A hadith like this has been narrated by Abu Huraira}}
\hadithdefcmd{muslim}{1485}{وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، سَمِعَهُ مِنْهُ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِقَوْمٍ يَتَخَلَّفُونَ عَنِ الْجُمُعَةِ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ آمُرَ رَجُلاً يُصَلِّي بِالنَّاسِ ثُمَّ أُحَرِّقَ عَلَى رِجَالٍ يَتَخَلَّفُونَ عَنِ الْجُمُعَةِ بُيُوتَهُمْ ‏"‏ ‏.‏\hadithno{1485}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying about people who are absent from Jumu'a prayer:I intend that I should command a person to lead people in prayer, and then burn those persons who absent themselves from Jumu'a prayer in their houses}}
\hadithdefcmd{muslim}{1486}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَيَعْقُوبُ الدَّوْرَقِيُّ، كُلُّهُمْ عَنْ مَرْوَانَ الْفَزَارِيِّ، - قَالَ قُتَيْبَةُ حَدَّثَنَا الْفَزَارِيُّ، - عَنْ عُبَيْدِ اللَّهِ بْنِ الأَصَمِّ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ أَعْمَى فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهُ لَيْسَ لِي قَائِدٌ يَقُودُنِي إِلَى الْمَسْجِدِ ‏.‏ فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يُرَخِّصَ لَهُ فَيُصَلِّيَ فِي بَيْتِهِ فَرَخَّصَ لَهُ فَلَمَّا وَلَّى دَعَاهُ فَقَالَ ‏"‏ هَلْ تَسْمَعُ النِّدَاءَ بِالصَّلاَةِ ‏"‏ ‏.‏ فَقَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَأَجِبْ ‏"‏ ‏.‏\hadithno{1486}\hadithtrans{Abu Huraira reported:There came to the Messenger of Allah (ﷺ) a blind man and said: Messenger of Allah, I have no one to guide me to the mosque. He, therefore, asked. Allah's Messenger (ﷺ) permission to say prayer in his house. He (tee Holy Prophet) granted him permission. Then when the man turned away he called him and said: Do you hear the call to prayer? He said: Yes. He (the Prophet then) said: Respond to it}}
\hadithdefcmd{muslim}{1487}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ أَبِي زَائِدَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، عَنْ أَبِي الأَحْوَصِ، قَالَ قَالَ عَبْدُ اللَّهِ لَقَدْ رَأَيْتُنَا وَمَا يَتَخَلَّفُ عَنِ الصَّلاَةِ إِلاَّ مُنَافِقٌ قَدْ عُلِمَ نِفَاقُهُ أَوْ مَرِيضٌ إِنْ كَانَ الْمَرِيضُ لَيَمْشِي بَيْنَ رَجُلَيْنِ حَتَّى يَأْتِيَ الصَّلاَةَ - وَقَالَ - إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَّمَنَا سُنَنَ الْهُدَى وَإِنَّ مِنْ سُنَنِ الْهُدَى الصَّلاَةَ فِي الْمَسْجِدِ الَّذِي يُؤَذَّنُ فِيهِ ‏.‏\hadithno{1487}\hadithtrans{Abdullah (b. Mas'ud) reported:I have seen the time when no one stayed away from prayer except a hypocrite, whose hypocrisy was well known, or a sick man, but if a sick man could walk between two persons (i.e. with the help of two persons with one on each side) he would come to prayer. And (further) said: The Messenger of Allah (ﷺ) taught us the paths of right guidance, among which is prayer in the mosque in which the Adhan is called}}
\hadithdefcmd{muslim}{1488}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، عَنْ أَبِي الْعُمَيْسِ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ مَنْ سَرَّهُ أَنْ يَلْقَى اللَّهَ غَدًا مُسْلِمًا فَلْيُحَافِظْ عَلَى هَؤُلاَءِ الصَّلَوَاتِ حَيْثُ يُنَادَى بِهِنَّ فَإِنَّ اللَّهَ شَرَعَ لِنَبِيِّكُمْ صلى الله عليه وسلم سُنَنَ الْهُدَى وَإِنَّهُنَّ مِنْ سُنَنِ الْهُدَى وَلَوْ أَنَّكُمْ صَلَّيْتُمْ فِي بُيُوتِكُمْ كَمَا يُصَلِّي هَذَا الْمُتَخَلِّفُ فِي بَيْتِهِ لَتَرَكْتُمْ سُنَّةَ نَبِيِّكُمْ وَلَوْ تَرَكْتُمْ سُنَّةَ نَبِيِّكُمْ لَضَلَلْتُمْ وَمَا مِنْ رَجُلٍ يَتَطَهَّرُ فَيُحْسِنُ الطُّهُورَ ثُمَّ يَعْمِدُ إِلَى مَسْجِدٍ مِنْ هَذِهِ الْمَسَاجِدِ إِلاَّ كَتَبَ اللَّهُ لَهُ بِكُلِّ خَطْوَةٍ يَخْطُوهَا حَسَنَةً وَيَرْفَعُهُ بِهَا دَرَجَةً وَيَحُطُّ عَنْهُ بِهَا سَيِّئَةً وَلَقَدْ رَأَيْتُنَا وَمَا يَتَخَلَّفُ عَنْهَا إِلاَّ مُنَافِقٌ مَعْلُومُ النِّفَاقِ وَلَقَدْ كَانَ الرَّجُلُ يُؤْتَى بِهِ يُهَادَى بَيْنَ الرَّجُلَيْنِ حَتَّى يُقَامَ فِي الصَّفِّ ‏.‏\hadithno{1488}\hadithtrans{Abdullah (b. Mas'ud) reported:He who likes to meet Allah tomorrow as Muslim, he should persevere in observing these prayers, when a call is announced for them, for Allah has laid down for your Prophet the paths of right guidance, and these (prayers) are among the paths of right guidance. If you were to pray in your houses as this man why stays away (from the mosque) prays in his house, you would abandon the practice of your Prophet, and if you were to abandon the practice of your Prophet, you would go astray. No man purifies himself, doing it well, then makes for one of those mosques without Allah recording a blessing for him for every step he takes raising him a degree for it, and effacing a sin from him for it. I have seen the time when no one stayed away from it, except a hypocrite, who was well known for his hypocrisy, whereas a man would be brought swaying (due to weakness) between two men till he was set up in a row}}
\hadithdefcmd{muslim}{1489}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ إِبْرَاهِيمَ بْنِ الْمُهَاجِرِ، عَنْ أَبِي الشَّعْثَاءِ، قَالَ كُنَّا قُعُودًا فِي الْمَسْجِدِ مَعَ أَبِي هُرَيْرَةَ فَأَذَّنَ الْمُؤَذِّنُ فَقَامَ رَجُلٌ مِنَ الْمَسْجِدِ يَمْشِي فَأَتْبَعَهُ أَبُو هُرَيْرَةَ بَصَرَهُ حَتَّى خَرَجَ مِنَ الْمَسْجِدِ فَقَالَ أَبُو هُرَيْرَةَ أَمَّا هَذَا فَقَدْ عَصَى أَبَا الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{1489}\hadithtrans{Abu Sha'tha' reported:While we were sitting with Abu Huraira in a mosque a man went out of the mosque after the call to prayer had been announced. (A man stood up in the mosque and set off.) Abu Huraira's eyes followed him till he went out of the mosque. Upon this Abu Huraira said: This man has disobeyed Abu'l- Qasim (Muhammad) (ﷺ)}}
\hadithdefcmd{muslim}{1490}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، - هُوَ ابْنُ عُيَيْنَةَ - عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ الْمُحَارِبِيِّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، وَرَأَى، رَجُلاً يَجْتَازُ الْمَسْجِدَ خَارِجًا بَعْدَ الأَذَانِ فَقَالَ أَمَّا هَذَا فَقَدْ عَصَى أَبَا الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{1490}\hadithtrans{Abu Sha'tha' al-Muharibi reported on the authority of his father, who said:I heard it from Abu Huraira that he saw a person getting out of the mosque after the call to prayer had been announced. Upon this he remarked: This (man) disobeyed Abu'l-Qasim (ﷺ)}}
\hadithdefcmd{muslim}{1491}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمُغِيرَةُ بْنُ سَلَمَةَ الْمَخْزُومِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - وَهُوَ ابْنُ زِيَادٍ - حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ، قَالَ دَخَلَ عُثْمَانُ بْنُ عَفَّانَ الْمَسْجِدَ بَعْدَ صَلاَةِ الْمَغْرِبِ فَقَعَدَ وَحْدَهُ فَقَعَدْتُ إِلَيْهِ فَقَالَ يَا ابْنَ أَخِي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَلَّى الْعِشَاءَ فِي جَمَاعَةٍ فَكَأَنَّمَا قَامَ نِصْفَ اللَّيْلِ وَمَنْ صَلَّى الصُّبْحَ فِي جَمَاعَةٍ فَكَأَنَّمَا صَلَّى اللَّيْلَ كُلَّهُ ‏"‏ ‏.‏\hadithno{1491}\hadithtrans{Abd al-Rahman b. Abd 'Amr reported:'Uthman b. 'Affan (narrated the mosque after evening prayer and sat alone. I also sat alone with him, so he said: 0, son of my brother, I heard the Messenger of Allah (ﷺ) say: He who observed the 'Isha' prayer in congregation, it was as if he prayed up to midnight, and he who prayed the morning prayer in congregation, it was as if he prayed the whole night}}
\hadithdefcmd{muslim}{1492}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَسَدِيُّ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، جَمِيعًا عَنْ سُفْيَانَ، عَنْ أَبِي سَهْلٍ، عُثْمَانَ بْنِ حَكِيمٍ بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{1492}\hadithtrans{This hadith has been narrated by the chain of transmitters by Abu Sahl 'Uthman b. Hakim}}
\hadithdefcmd{muslim}{1493}{وَحَدَّثَنِي نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - عَنْ خَالِدٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَمِعْتُ جُنْدَبَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى الصُّبْحَ فَهُوَ فِي ذِمَّةِ اللَّهِ فَلاَ يَطْلُبَنَّكُمُ اللَّهُ مِنْ ذِمَّتِهِ بِشَىْءٍ فَيُدْرِكَهُ فَيَكُبَّهُ فِي نَارِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{1493}\hadithtrans{Jundab b. 'Abdullah reported Allah's Messenger (ﷺ) as saying:He who prayed the morning prayer (in congregation) he is in fact under the protection of Allah. And it can never happen that Allah should demand anything from you in connection with the protection (that He guarantees) and one should not get it. He would then throw him in the fire of Hell}}
\hadithdefcmd{muslim}{1494}{وَحَدَّثَنِيهِ يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ خَالِدٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَمِعْتُ جُنْدَبًا الْقَسْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى صَلاَةَ الصُّبْحِ فَهْوَ فِي ذِمَّةِ اللَّهِ فَلاَ يَطْلُبَنَّكُمُ اللَّهُ مِنْ ذِمَّتِهِ بِشَىْءٍ فَإِنَّهُ مَنْ يَطْلُبْهُ مِنْ ذِمَّتِهِ بِشَىْءٍ يُدْرِكْهُ ثُمَّ يَكُبَّهُ عَلَى وَجْهِهِ فِي نَارِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{1494}\hadithtrans{Anas b. Sirin reported:I heard Jundab b. Qasri saying that the Messenger of Allah (ﷺ) said: He who observed the morning prayer (in congregation), he is in fact under the protection of Allah and it never happens that Allah should make a demand in connection with the protection (that He guarantees and should not get it) for when he asks for anything in relation to His protection, he definitely secures it. He then throws him flatly in the Hell-fire}}
\hadithdefcmd{muslim}{1495}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ هَارُونَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الْحَسَنِ، عَنْ جُنْدَبِ بْنِ سُفْيَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا وَلَمْ يَذْكُرْ ‏ "‏ فَيَكُبَّهُ فِي نَارِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{1495}\hadithtrans{This hadith has been narrated by Jundab b. Sufyan in from the Messenger of Allah (ﷺ) with the same chain of transmitters, but this has not been mentioned:" He would throw him in fire}}
\hadithdefcmd{muslim}{1496}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ مَحْمُودَ بْنَ الرَّبِيعِ الأَنْصَارِيَّ، حَدَّثَهُ أَنَّ عِتْبَانَ بْنَ مَالِكٍ وَهُوَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِمَّنْ شَهِدَ بَدْرًا مِنَ الأَنْصَارِ أَنَّهُ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ أَنْكَرْتُ بَصَرِي وَأَنَا أُصَلِّي لِقَوْمِي وَإِذَا كَانَتِ الأَمْطَارُ سَالَ الْوَادِي الَّذِي بَيْنِي وَبَيْنَهُمْ وَلَمْ أَسْتَطِعْ أَنْ آتِيَ مَسْجِدَهُمْ فَأُصَلِّيَ لَهُمْ وَدِدْتُ أَنَّكَ يَا رَسُولَ اللَّهِ تَأْتِي فَتُصَلِّي فِي مُصَلًّى ‏.‏ فَأَتَّخِذَهُ مُصَلًّى ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَأَفْعَلُ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ قَالَ عِتْبَانُ فَغَدَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ الصِّدِّيقُ حِينَ ارْتَفَعَ النَّهَارُ فَاسْتَأْذَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَذِنْتُ لَهُ فَلَمْ يَجْلِسْ حَتَّى دَخَلَ الْبَيْتَ ثُمَّ قَالَ ‏"‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ مِنْ بَيْتِكِ ‏"‏ ‏.‏ قَالَ فَأَشَرْتُ إِلَى نَاحِيَةٍ مِنَ الْبَيْتِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَبَّرَ فَقُمْنَا وَرَاءَهُ فَصَلَّى رَكْعَتَيْنِ ثُمَّ سَلَّمَ - قَالَ - وَحَبَسْنَاهُ عَلَى خَزِيرٍ صَنَعْنَاهُ لَهُ - قَالَ - فَثَابَ رِجَالٌ مِنْ أَهْلِ الدَّارِ حَوْلَنَا حَتَّى اجْتَمَعَ فِي الْبَيْتِ رِجَالٌ ذَوُو عَدَدٍ فَقَالَ قَائِلٌ مِنْهُمْ أَيْنَ مَالِكُ بْنُ الدُّخْشُنِ فَقَالَ بَعْضُهُمْ ذَلِكَ مُنَافِقٌ لاَ يُحِبُّ اللَّهَ وَرَسُولَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقُلْ لَهُ ذَلِكَ أَلاَ تَرَاهُ قَدْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏.‏ يُرِيدُ بِذَلِكَ وَجْهَ اللَّهِ ‏"‏ ‏.‏ قَالَ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ فَإِنَّمَا نَرَى وَجْهَهُ وَنَصِيحَتَهُ لِلْمُنَافِقِينَ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّ اللَّهَ قَدْ حَرَّمَ عَلَى النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏.‏ يَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ ثُمَّ سَأَلْتُ الْحُصَيْنَ بْنَ مُحَمَّدٍ الأَنْصَارِيَّ - وَهُوَ أَحَدُ بَنِي سَالِمٍ وَهُوَ مِنْ سَرَاتِهِمْ - عَنْ حَدِيثِ مَحْمُودِ بْنِ الرَّبِيعِ فَصَدَّقَهُ بِذَلِكَ ‏.‏\hadithno{1496}\hadithtrans{Mahmud b. al-Rabi' reported that 'Ibn b. Malik, who was one of the Companions of the Messenger of Allah (ﷺ) and who participated in the (Battle of) Badr and was among the Ansar (of Medina), told that he came to the Messenger of Allah (ﷺ) and said:Messenger of Allah, I have lost my eyesight and I lead my people in prayer. When there is a downpour there is then a current (of water) in the valley that stands between me and them and I find it impossible to go to their mosque and lead them in prayer. Messenger of Allah, I earnestly beg of you that you should come and observe prayer at a place of worship (in my house) so that I should then use it as a place of worship. The Messenger of Allah (ﷺ) said: Well, it God so wills. I would soon do so. 'Itban said: On the following day when the day dawned, the Messenger of Allah (may peace he upon him) came along with Abu Bakr at-Siddiq, and the Messenger of Allah (ﷺ) asked permission (to get into the house). I gave him the permission, and be did not sit after entering the house, when he said: At what place in your house you desire me to say prayer? I ('Itban b. Malik) said: I pointed to a corner in the house, The Messenger of Allah (ﷺ) stood (at that place for prayer) and pronounced Allah-o-Akbar (Allah is the Greatest) (as an expression for the commencement of prayer). We too stood behind him, and he said two rak'ahs and then pronounced salutation (marking the end of the prayer). We detained him (the Holy Prophet) for the meat curry we had prepared for, him. The people of the neighbouring houses came and thus there was a good gathering in (our house). One of them said: Where is Malik b. Dukhshun? Upon this one of them remarked: He is a hypocrite; he does not love Allah and His Messenger. Thereupon the Messenger of Allah (ﷺ) said: Do not say so about him. Don't you see that he utters La ilaha ill-Allah (There is no god but Allah) and seeks the pleasure of Allah through it? They said: Allah and His Messenger know beet. One (among the audience) said: We see his inclination and wellwishing for hypocrites only. Upon this the Messenger of Allah' (ﷺ) again said: Verily Allah has forbidden the Fire for one who says: There is no god but Allah, thereby seeking Allah's pleasure. Ibn Shihab said: I asked Husain b. Muhammad al-Ansar (he was one of the leaders of Banu Salim) about the hadith transmitted by Mahmud b. Rabi' and he testified it}}
\hadithdefcmd{muslim}{1497}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، كِلاَهُمَا عَنْ عَبْدِ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي مَحْمُودُ بْنُ رَبِيعٍ، عَنْ عِتْبَانَ بْنِ مَالِكٍ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ يُونُسَ غَيْرَ أَنَّهُ قَالَ فَقَالَ رَجُلٌ أَيْنَ مَالِكُ بْنُ الدُّخْشُنِ أَوِ الدُّخَيْشِنِ وَزَادَ فِي الْحَدِيثِ قَالَ مَحْمُودٌ فَحَدَّثْتُ بِهَذَا الْحَدِيثِ نَفَرًا فِيهِمْ أَبُو أَيُّوبَ الأَنْصَارِيُّ فَقَالَ مَا أَظُنُّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ مَا قُلْتَ - قَالَ - فَحَلَفْتُ إِنْ رَجَعْتُ إِلَى عِتْبَانَ أَنْ أَسْأَلَهُ - قَالَ - فَرَجَعْتُ إِلَيْهِ فَوَجَدْتُهُ شَيْخًا كَبِيرًا قَدْ ذَهَبَ بَصَرُهُ وَهُوَ إِمَامُ قَوْمِهِ فَجَلَسْتُ إِلَى جَنْبِهِ فَسَأَلْتُهُ عَنْ هَذَا الْحَدِيثِ فَحَدَّثَنِيهِ كَمَا حَدَّثَنِيهِ أَوَّلَ مَرَّةٍ ‏.‏ قَالَ الزُّهْرِيُّ ثُمَّ نَزَلَتْ بَعْدَ ذَلِكَ فَرَائِضُ وَأُمُورٌ نُرَى أَنَّ الأَمْرَ انْتَهَى إِلَيْهَا فَمَنِ اسْتَطَاعَ أَنْ لاَ يَغْتَرَّ فَلاَ يَغْتَرَّ ‏.‏\hadithno{1497}\hadithtrans{Itban b. Malik reported:I came to the Messenger of Allah (ﷺ) and the rest of the hadith is the same as narrated (above) except this that a man said: Where is Malik b. Dukhshun or Dukhaishin, and also made this addition that Mahmud said: I narrated this ver hadith to many people and among them was Abu Ayyub al-Ansari who said: I cannot think that the Messenger of Allah (ﷺ) could have said so as you say. He (the narrator) said: I took an oath that if I ever go to 'Itban. I would ask him about it. So I went to him and found him to be a very aged man, having lost his eyesight, but he was the Imam of the people. I sat by his side and asked about this hadith and he narrated it In the same way as he had narrated it for the first time. Then so many other obligatory acts and commands were revealed which we see having been completed. So he who wants that he should not be deceived would not be deceived}}
\hadithdefcmd{muslim}{1498}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، قَالَ إِنِّي لأَعْقِلُ مَجَّةً مَجَّهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ دَلْوٍ فِي دَارِنَا ‏.‏ قَالَ مَحْمُودٌ فَحَدَّثَنِي عِتْبَانُ بْنُ مَالِكٍ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ بَصَرِي قَدْ سَاءَ ‏.‏ وَسَاقَ الْحَدِيثَ إِلَى قَوْلِهِ فَصَلَّى بِنَا رَكْعَتَيْنِ وَحَبَسْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى جَشِيشَةٍ صَنَعْنَاهَا لَهُ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ مِنْ زِيَادَةِ يُونُسَ وَمَعْمَرٍ ‏.‏\hadithno{1498}\hadithtrans{Mahmud b. Rabi' reported:I well remember the disgorge of the Messenger of Allah (ﷺ) that he did (with water) from a bucket of our house. Mahmud said: 'Itban b. Malik narrated it to me that he had said: Messenger of Allah, I have lost my eyesight, and the rest of the hadith is the same up to these words:" He led us in two rak'ahs of prayer and we detained the Messenger of Allah (ﷺ) for serving him the pudding that we had prepared for him," and no mention has been made of what follows next from the addition made by Yunus and Ma'mar}}
\hadithdefcmd{muslim}{1499}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ جَدَّتَهُ، مُلَيْكَةَ دَعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ صَنَعَتْهُ فَأَكَلَ مِنْهُ ثُمَّ قَالَ ‏ "‏ قُومُوا فَأُصَلِّيَ لَكُمْ ‏"‏ ‏.‏ قَالَ أَنَسُ بْنُ مَالِكٍ فَقُمْتُ إِلَى حَصِيرٍ لَنَا قَدِ اسْوَدَّ مِنْ طُولِ مَا لُبِسَ فَنَضَحْتُهُ بِمَاءٍ فَقَامَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَفَفْتُ أَنَا وَالْيَتِيمُ وَرَاءَهُ وَالْعَجُوزُ مِنْ وَرَائِنَا فَصَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ ثُمَّ انْصَرَفَ ‏.‏\hadithno{1499}\hadithtrans{Anas b. Malik reported that his grandmother, Mulaika, invited the Messenger of Allah (ﷺ) to a dinner which she had prepared. He (the Holy Prophet) ate out of that and then said:Stand up so that I should observe prayer (in order to bless) you Anas b. Malik said: I stood up on a mat (belonging to us) which had turned dark on account of its long use. I sprinkled water over it (in order to soften it), and the Messenger of Allah (ﷺ) stood upon it, and I and an orphan formed a row behind him (the Holy Prophet) and the old woman was behind us, and the Messenger of Allah (ﷺ) led us in two rak'ahs of prayer and then went back}}
\hadithdefcmd{muslim}{1500}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، وَأَبُو الرَّبِيعِ، كِلاَهُمَا عَنْ عَبْدِ الْوَارِثِ، قَالَ شَيْبَانُ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْسَنَ النَّاسِ خُلُقًا فَرُبَّمَا تَحْضُرُ الصَّلاَةُ وَهْوَ فِي بَيْتِنَا فَيَأْمُرُ بِالْبِسَاطِ الَّذِي تَحْتَهُ فَيُكْنَسُ ثُمَّ يُنْضَحُ ثُمَّ يَؤُمُّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَقُومُ خَلْفَهُ فَيُصَلِّي بِنَا وَكَانَ بِسَاطُهُمْ مِنْ جَرِيدِ النَّخْلِ ‏.‏\hadithno{1500}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) wits the best among people in character. On occasions, the time of prayer would come while he was in our house. He would then order to spread the mat lying under him. That was dusted and then water was sprinkled over it. The Messenger of Allah (ﷺ) then led the prayer and we stood behind him, and that mat was made of the leaves of date-palm}}
\hadithdefcmd{muslim}{1501}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا سُلَيْمَانُ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَيْنَا وَمَا هُوَ إِلاَّ أَنَا وَأُمِّي وَأُمُّ حَرَامٍ خَالَتِي فَقَالَ ‏"‏ قُومُوا فَلأُصَلِّيَ بِكُمْ ‏"‏ ‏.‏ فِي غَيْرِ وَقْتِ صَلاَةٍ فَصَلَّى بِنَا ‏.‏ فَقَالَ رَجُلٌ لِثَابِتٍ أَيْنَ جَعَلَ أَنَسًا مِنْهُ قَالَ جَعَلَهُ عَلَى يَمِينِهِ ‏.‏ ثُمَّ دَعَا لَنَا أَهْلَ الْبَيْتِ بِكُلِّ خَيْرٍ مِنْ خَيْرِ الدُّنْيَا وَالآخِرَةِ فَقَالَتْ أُمِّي يَا رَسُولَ اللَّهِ خُوَيْدِمُكَ ادْعُ اللَّهَ لَهُ ‏.‏ قَالَ فَدَعَا لِي بِكُلِّ خَيْرٍ وَكَانَ فِي آخِرِ مَا دَعَا لِي بِهِ أَنْ قَالَ ‏"‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ وَبَارِكْ لَهُ فِيهِ ‏"‏ ‏.‏\hadithno{1501}\hadithtrans{Thabit reported on the authority of Anas:The Apostle of Allah (ﷺ) came to us and there was none in our house but I, my mother and my aunt Umm Haram. He (the Holy Prophet) said: Stand up so that I may lead you in prayer (and there was no time for prescribed prayer). He led us in prayer. A person said to Thabit: Where stood Anas with him (the Holy Prophet)? He replied: He was on the right side. He then blessed us, the members of the household with every good of this world and of the Hereafter. My mother said: Messenger of Allah (and then, pointing towards Anas, said), here is your little servant, invoke the blessing of Allah upon him too. He then blessed me with every good, and he concluded his blessings for me (with these words): Allah! increase his wealth, and his children and make (them the source of) blessing for him}}
\hadithdefcmd{muslim}{1502}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُخْتَارِ، سَمِعَ مُوسَى بْنَ أَنَسٍ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِهِ وَبِأُمِّهِ أَوْ خَالَتِهِ ‏.‏ قَالَ فَأَقَامَنِي عَنْ يَمِينِهِ وَأَقَامَ الْمَرْأَةَ خَلْفَنَا ‏.‏\hadithno{1502}\hadithtrans{Abdullah b. al-Mukhtar heard Musa b. Anas narrating on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) led him, his mother or his aunt in prayer. He made me, stand on his right side and made the woman stand, behind us}}
\hadithdefcmd{muslim}{1503}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - قَالَ حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1503}\hadithtrans{This hadith has also been narrated by Shu'ba with this chain of transmitters}}
\hadithdefcmd{muslim}{1504}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، كِلاَهُمَا عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، قَالَ حَدَّثَتْنِي مَيْمُونَةُ، زَوْجُ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَأَنَا حِذَاءَهُ وَرُبَّمَا أَصَابَنِي ثَوْبُهُ إِذَا سَجَدَ وَكَانَ يُصَلِّي عَلَى خُمْرَةٍ ‏.‏\hadithno{1504}\hadithtrans{Maimuna, the wife of the Messenger of Allah (ﷺ), reported:The Messenger of Allah (ﷺ) said prayer while I was by his side, and at times when he prostrated his cloth touched me, and he prayed on a small mat}}
\hadithdefcmd{muslim}{1505}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، جَمِيعًا عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ حَدَّثَنَا أَبُو سَعِيدٍ الْخُدْرِيُّ، أَنَّهُ دَخَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَجَدَهُ يُصَلِّي عَلَى حَصِيرٍ يَسْجُدُ عَلَيْهِ ‏.‏\hadithno{1505}\hadithtrans{Abu Sa'id al-Khudri reported that he went to the Messenger of Allah (ﷺ) and found him observing prayer on a mat and prostrating on that}}
\hadithdefcmd{muslim}{1506}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، - قَالَ أَبُو كُرَيْبٍ حَدَّثَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ الرَّجُلِ فِي جَمَاعَةٍ تَزِيدُ عَلَى صَلاَتِهِ فِي بَيْتِهِ وَصَلاَتِهِ فِي سُوقِهِ بِضْعًا وَعِشْرِينَ دَرَجَةً وَذَلِكَ أَنَّ أَحَدَهُمْ إِذَا تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ أَتَى الْمَسْجِدَ لاَ يَنْهَزُهُ إِلاَّ الصَّلاَةُ لاَ يُرِيدُ إِلاَّ الصَّلاَةَ فَلَمْ يَخْطُ خَطْوَةً إِلاَّ رُفِعَ لَهُ بِهَا دَرَجَةٌ وَحُطَّ عَنْهُ بِهَا خَطِيئَةٌ حَتَّى يَدْخُلَ الْمَسْجِدَ فَإِذَا دَخَلَ الْمَسْجِدَ كَانَ فِي الصَّلاَةِ مَا كَانَتِ الصَّلاَةُ هِيَ تَحْبِسُهُ وَالْمَلاَئِكَةُ يُصَلُّونَ عَلَى أَحَدِكُمْ مَا دَامَ فِي مَجْلِسِهِ الَّذِي صَلَّى فِيهِ يَقُولُونَ اللَّهُمَّ ارْحَمْهُ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ تُبْ عَلَيْهِ مَا لَمْ يُؤْذِ فِيهِ مَا لَمْ يُحْدِثْ فِيهِ ‏"‏ ‏.‏\hadithno{1506}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A man's prayer in congregation is more valuable than twenty degrees and some above them as compared with his prayer in his house and his market, for when he performs ablution doing it well, then goes out to the mosque, and he is impelled (to do so) only by (the love of congregational) prayer, he has no other objective before him but prayer. He does not take a step without being raised a degree for it and having a sin remitted for it, till he enters the mosque, and when he is busy in prayer after having entered the mosque. the angels continue to invoke blessing on him as long as he is in his place of worship. saying: O Allah, show him mercy, and pardon him! Accept his repentance (and the angels continue this supplication for him) so long as he does not do any harm in it, or as long as his ablution is not broken}}
\hadithdefcmd{muslim}{1507}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، أَخْبَرَنَا عَبْثَرٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ بَكَّارِ بْنِ الرَّيَّانِ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، كُلُّهُمْ عَنِ الأَعْمَشِ، فِي هَذَا الإِسْنَادِ بِمِثْلِ مَعْنَاهُ ‏.‏\hadithno{1507}\hadithtrans{A hadith having the same meaning (as mentioned above) has been transmitted by A'mash}}
\hadithdefcmd{muslim}{1508}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَلاَئِكَةَ تُصَلِّي عَلَى أَحَدِكُمْ مَا دَامَ فِي مَجْلِسِهِ تَقُولُ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ مَا لَمْ يُحْدِثْ وَأَحَدُكُمْ فِي صَلاَةٍ مَا كَانَتِ الصَّلاَةُ تَحْبِسُهُ ‏"‏ ‏.‏\hadithno{1508}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The angels invoke blessings on everyone among you so long as he is in a place of worship with these words: O Allah! pardon him, O Allah, have mercy upon him, (and they continue to do so) as long as, he ablution (of the worshipper) is not broken, and one among you is in prayer and so long as he is detained for the prayer}}
\hadithdefcmd{muslim}{1509}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ الْعَبْدُ فِي صَلاَةٍ مَا كَانَ فِي مُصَلاَّهُ يَنْتَظِرُ الصَّلاَةَ وَتَقُولُ الْمَلاَئِكَةُ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ ‏.‏ حَتَّى يَنْصَرِفَ أَوْ يُحْدِثَ ‏"‏ ‏.‏ قُلْتُ مَا يُحْدِثُ قَالَ يَفْسُو أَوْ يَضْرِطُ ‏.‏\hadithno{1509}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The servant is constantly in prayer so long as he is in a place of worship waiting for the prayer (to be observed in congregation), and the angels invoke (blessings upon him in these words): O Allah! pardon him. O Allah! show mercy to him, (and they continue to do so) till he returns (from the mosque having completed the prayer) or his ablution breaks. I said: How is the ablution broken? He said: By breaking of the wind noiselessly or with noise}}
\hadithdefcmd{muslim}{1510}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ أَحَدُكُمْ فِي صَلاَةٍ مَا دَامَتِ الصَّلاَةُ تَحْبِسُهُ لاَ يَمْنَعُهُ أَنْ يَنْقَلِبَ إِلَى أَهْلِهِ إِلاَّ الصَّلاَةُ ‏"‏ ‏.‏\hadithno{1510}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) as saying:Everyone among you is constantly in prayer so long as the prayer detains him (for this noble objective) and nothing prevents him to return to his family but the prayer}}
\hadithdefcmd{muslim}{1511}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَحَدُكُمْ مَا قَعَدَ يَنْتَظِرُ الصَّلاَةَ فِي صَلاَةٍ مَا لَمْ يُحْدِثْ تَدْعُو لَهُ الْمَلاَئِكَةُ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ ‏"‏ ‏.‏\hadithno{1511}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Anyone amongst you who sat in a place of worship waiting for the prayer is in prayer and his ablution is not broken, the angels invoke blessing upon him (in these words): O Allah! pardon him. O Allah! have mercy upon him}}
\hadithdefcmd{muslim}{1512}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ هَذَا ‏.‏\hadithno{1512}\hadithtrans{A hadith like this has been narrated by Hammam b. Munabbih on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{1513}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَعْظَمَ النَّاسِ أَجْرًا فِي الصَّلاَةِ أَبْعَدُهُمْ إِلَيْهَا مَمْشًى فَأَبْعَدُهُمْ وَالَّذِي يَنْتَظِرُ الصَّلاَةَ حَتَّى يُصَلِّيَهَا مَعَ الإِمَامِ أَعْظَمُ أَجْرًا مِنَ الَّذِي يُصَلِّيهَا ثُمَّ يَنَامُ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي كُرَيْبٍ ‏"‏ حَتَّى يُصَلِّيَهَا مَعَ الإِمَامِ فِي جَمَاعَةٍ ‏"‏ ‏.‏\hadithno{1513}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:The most eminent among human beings (as a recipient of) reward (is one) who lives farthest away, and who has to walk the farthest distance, and he who waits for the prayer to observe it along with the Imam, his reward is greater than one who prays (alone) and then goes to sleep. In the narration of Abu Kuraib (the words are):" (He waits) till he prays along with the Imam in congregation}}
\hadithdefcmd{muslim}{1514}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْثَرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كَانَ رَجُلٌ لاَ أَعْلَمُ رَجُلاً أَبْعَدَ مِنَ الْمَسْجِدِ مِنْهُ وَكَانَ لاَ تُخْطِئُهُ صَلاَةٌ - قَالَ - فَقِيلَ لَهُ أَوْ قُلْتُ لَهُ لَوِ اشْتَرَيْتَ حِمَارًا تَرْكَبُهُ فِي الظَّلْمَاءِ وَفِي الرَّمْضَاءِ ‏.‏ قَالَ مَا يَسُرُّنِي أَنَّ مَنْزِلِي إِلَى جَنْبِ الْمَسْجِدِ إِنِّي أُرِيدُ أَنْ يُكْتَبَ لِي مَمْشَاىَ إِلَى الْمَسْجِدِ وَرُجُوعِي إِذَا رَجَعْتُ إِلَى أَهْلِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ جَمَعَ اللَّهُ لَكَ ذَلِكَ كُلَّهُ ‏"‏ ‏.‏\hadithno{1514}\hadithtrans{Ubayy b. Ka'b reported:There was a man, and I do not know of any other man, whose house was farther than his from the mosque and he never missed the prayer (in congregation). It was said to him or I said to him: It you were to buy a donkey you could ride upon it In the dark nights and in the burning sand. He said: I do not like my house to be situated by the side of the mosque, for I (eagerly) desire that my steps towards the mosque and back from it, should be recorded when I return to my family. Upon this the Messenger of Allah (ﷺ) said: Allah has gathered all (rewards) for you}}
\hadithdefcmd{muslim}{1515}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنَا جَرِيرٌ، كِلاَهُمَا عَنِ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ بِنَحْوِهِ ‏.‏\hadithno{1515}\hadithtrans{This hadith has been transmitted by Taimi with the same chain of narrators}}
\hadithdefcmd{muslim}{1516}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، حَدَّثَنَا عَاصِمٌ، عَنْ أَبِي عُثْمَانَ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كَانَ رَجُلٌ مِنَ الأَنْصَارِ بَيْتُهُ أَقْصَى بَيْتٍ فِي الْمَدِينَةِ فَكَانَ لاَ تُخْطِئُهُ الصَّلاَةُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - فَتَوَجَّعْنَا لَهُ فَقُلْتُ لَهُ يَا فُلاَنُ لَوْ أَنَّكَ اشْتَرَيْتَ حِمَارًا يَقِيكَ مِنَ الرَّمْضَاءِ وَيَقِيكَ مِنْ هَوَامِّ الأَرْضِ ‏.‏ قَالَ أَمَا وَاللَّهِ مَا أُحِبُّ أَنَّ بَيْتِي مُطَنَّبٌ بِبَيْتِ مُحَمَّدٍ صلى الله عليه وسلم قَالَ فَحَمَلْتُ بِهِ حِمْلاً حَتَّى أَتَيْتُ نَبِيَّ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ - قَالَ - فَدَعَاهُ فَقَالَ لَهُ مِثْلَ ذَلِكَ وَذَكَرَ لَهُ أَنَّهُ يَرْجُو فِي أَثَرِهِ الأَجْرَ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ لَكَ مَا احْتَسَبْتَ ‏"‏ ‏.‏\hadithno{1516}\hadithtrans{Ubayy b. Ka'b reported:There was a person among the Ansar whose house was situated at the farthest end of Medina, but he never in missed any prayer along with the Messenger of Allah (ﷺ). We felt pity for him and said to him: O, so and so, had you bought a donkey it would have saved you from the burning sand and would have saved you from the reptiles of the earth. He said: Listen I by Allah, I do not like my house to be situated by the side of Muhammad (ﷺ). I took (these words of his) ill and came to the Messenger of Allah (ﷺ) and informed him about (these words). He (the Holy Prophet) called him and he said exactly like that (which he had mentioned to Ubbay b. Ka'b), but made a mention of this (also) that he wanted a reward for his steps. Upon this the Messenger of Allah (ﷺ) said: In fact for you is the reward which you expect}}
\hadithdefcmd{muslim}{1517}{وَحَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، وَمُحَمَّدُ بْنُ أَبِي عُمَرَ، كِلاَهُمَا عَنِ ابْنِ عُيَيْنَةَ، ح وَحَدَّثَنَا سَعِيدُ بْنُ أَزْهَرَ الْوَاسِطِيُّ، قَالَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبِي كُلُّهُمْ، عَنْ عَاصِمٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{1517}\hadithtrans{A hadith like this has been narrated by 'Asim with the same chain of transmitters}}
\hadithdefcmd{muslim}{1518}{وَحَدَّثَنَا حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو الزُّبَيْرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ كَانَتْ دِيَارُنَا نَائِيَةً عَنِ الْمَسْجِدِ، فَأَرَدْنَا أَنْ نَبِيعَ، بُيُوتَنَا فَنَقْتَرِبَ مِنَ الْمَسْجِدِ فَنَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ لَكُمْ بِكُلِّ خُطْوَةٍ دَرَجَةً ‏"‏ ‏.‏\hadithno{1518}\hadithtrans{Jabir b. 'Abdullah narrated:Our houses were situated far away from the mosque; we, therefore, decided to sell our houses so that we may be able to come near the mosque. The Messenger of Allah (ﷺ) forbade us (to do so) and said: There is for every step (towards the mosque) a degree (of reward) for you}}
\hadithdefcmd{muslim}{1519}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، قَالَ حَدَّثَنِي الْجُرَيْرِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ خَلَتِ الْبِقَاعُ حَوْلَ الْمَسْجِدِ فَأَرَادَ بَنُو سَلِمَةَ أَنْ يَنْتَقِلُوا إِلَى قُرْبِ الْمَسْجِدِ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُمْ ‏"‏ إِنَّهُ بَلَغَنِي أَنَّكُمْ تُرِيدُونَ أَنْ تَنْتَقِلُوا قُرْبَ الْمَسْجِدِ ‏"‏ ‏.‏ قَالُوا نَعَمْ يَا رَسُولَ اللَّهِ قَدْ أَرَدْنَا ذَلِكَ ‏.‏ فَقَالَ ‏"‏ يَا بَنِي سَلِمَةَ دِيَارَكُمْ تُكْتَبْ آثَارُكُمْ دِيَارَكُمْ تُكْتَبْ آثَارُكُمْ ‏"‏ ‏.‏\hadithno{1519}\hadithtrans{Jabir b. Abdullah reported:There were some plots vacant around the mosque. Banu Salama decided to shift (to this land) and come near the mosque. This (news) reached the Messenger of Allah (ﷺ) and he said to them (Banu Salama): I have received (information) that you intend to shift near the mosque. They said: Yes, Messenger of Allah, we have taken this decision. Upon this he (the Holy Prophet) said: O Banu Salama, live in your houses, for your steps are recorded; live in your houses, for your steps are recorded}}
\hadithdefcmd{muslim}{1520}{حَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ كَهْمَسًا، يُحَدِّثُ عَنْ أَبِي نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَرَادَ بَنُو سَلِمَةَ أَنْ يَتَحَوَّلُوا، إِلَى قُرْبِ الْمَسْجِدِ ‏.‏ - قَالَ - وَالْبِقَاعُ خَالِيَةٌ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا بَنِي سَلِمَةَ دِيَارَكُمْ تُكْتَبْ آثَارُكُمْ ‏"‏ ‏.‏ فَقَالُوا مَا كَانَ يَسُرُّنَا أَنَّا كُنَّا تَحَوَّلْنَا ‏.‏\hadithno{1520}\hadithtrans{Jabir b. Abdullah reported that Banu Salama decided to shift near the mosque (as there were) some plots vacant. This (news) reached the Messenger of Allah (ﷺ), whereupon he said:O people of the Salama tribe, you better stay in your houses (where you are living), for your footsteps are recorded They said. We could not be more delighted even by shifting (near the mosque) as we were delighted (on hearing these words from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1521}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِي حَازِمٍ الأَشْجَعِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَطَهَّرَ فِي بَيْتِهِ ثُمَّ مَشَى إِلَى بَيْتٍ مِنْ بُيُوتِ اللَّهِ لِيَقْضِيَ فَرِيضَةً مِنْ فَرَائِضِ اللَّهِ كَانَتْ خَطْوَتَاهُ إِحْدَاهُمَا تَحُطُّ خَطِيئَةً وَالأُخْرَى تَرْفَعُ دَرَجَةً ‏"‏ ‏.‏\hadithno{1521}\hadithtrans{Abu Huraira reported:The Messenger of Allah (may peace be' upon him) said: He who purified himself in his house, and then he walked to one of the houses of Allah for the sake of performing a Fard (obligatory act) out of the Fara'id (obligatory acts) of Allah, both his steps (would be significant) as one of them would obliterate his sin and the second one would raise his status}}
\hadithdefcmd{muslim}{1522}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَقَالَ قُتَيْبَةُ حَدَّثَنَا بَكْرٌ، - يَعْنِي ابْنَ مُضَرَ - كِلاَهُمَا عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَفِي حَدِيثِ بَكْرٍ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَرَأَيْتُمْ لَوْ أَنَّ نَهْرًا بِبَابِ أَحَدِكُمْ يَغْتَسِلُ مِنْهُ كُلَّ يَوْمٍ خَمْسَ مَرَّاتٍ هَلْ يَبْقَى مِنْ دَرَنِهِ شَىْءٌ ‏"‏ ‏.‏ قَالُوا لاَ يَبْقَى مِنْ دَرَنِهِ شَىْءٌ ‏.‏ قَالَ ‏"‏ فَذَلِكَ مَثَلُ الصَّلَوَاتِ الْخَمْسِ يَمْحُو اللَّهُ بِه��نَّ الْخَطَايَا ‏"‏ ‏.‏\hadithno{1522}\hadithtrans{In the hadith narrated of the authority of Abd Huraira the Messenger of Allah (ﷺ) is reported to have said. while in the hadith narrated by Bakr (the words are like this):He heard the Messenger of Allah (ﷺ) as saying: just see, can anything of his filthiness remain (on the body of) any one of you if there were a river at his door in which he washed himself five times daily? They, said: Nothing of his filthiness will remain (on his body). He said: That is like the five prayers by which Allah obliterates sins}}
\hadithdefcmd{muslim}{1523}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الصَّلَوَاتِ الْخَمْسِ كَمَثَلِ نَهَرٍ جَارٍ غَمْرٍ عَلَى بَابِ أَحَدِكُمْ يَغْتَسِلُ مِنْهُ كُلَّ يَوْمٍ خَمْسَ مَرَّاتٍ ‏"‏ ‏.‏ قَالَ قَالَ الْحَسَنُ وَمَا يُبْقِي ذَلِكَ مِنَ الدَّرَنِ\hadithno{1523}\hadithtrans{Jabir b. 'Abdullah reported that the Messenger of Allah (ﷺ) said:The similitude of five prayers is like an overflowing river passing by the gate of one of you in which he washes five times daily Hasan said: No filthiness can remain on him}}
\hadithdefcmd{muslim}{1524}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا مُحَمَّدُ بْنُ مُطَرِّفٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ مَنْ غَدَا إِلَى الْمَسْجِدِ أَوْ رَاحَ أَعَدَّ اللَّهُ لَهُ فِي الْجَنَّةِ نُزُلاً كُلَّمَا غَدَا أَوْ رَاحَ ‏"‏ ‏.‏\hadithno{1524}\hadithtrans{Ata' b. Yasar reported, on the authority of Abu Huraira, the Messenger of Allah (ﷺ) as saying:He who went towards the mosque in the morning or evening, Allah would arrange a feast for him morning or evening in Paradise}}
\hadithdefcmd{muslim}{1525}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ قُلْتُ لِجَابِرِ بْنِ سَمُرَةَ أَكُنْتَ تُجَالِسُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ كَثِيرًا كَانَ لاَ يَقُومُ مِنْ مُصَلاَّهُ الَّذِي يُصَلِّي فِيهِ الصُّبْحَ أَوِ الْغَدَاةَ حَتَّى تَطْلُعَ الشَّمْسُ فَإِذَا طَلَعَتِ الشَّمْسُ قَامَ وَكَانُوا يَتَحَدَّثُونَ فَيَأْخُذُونَ فِي أَمْرِ الْجَاهِلِيَّةِ فَيَضْحَكُونَ وَيَتَبَسَّمُ ‏.‏\hadithno{1525}\hadithtrans{Simak b. Harb reported:I said to Jabir b. Samura: Did you sit in the company of the Messenger of Allah (may peace he upon him)? He said: Yes, very often. He (the Holy Prophet) used to sit at the place where he observed the morning or dawn prayer till the sun rose or when it had risen; he would stand, and they (his Companions) would talk about matters (pertaining to the days) of ignorance, and they would laugh (on these matters) while (the Holy Prophet) only smiled}}
\hadithdefcmd{muslim}{1526}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، قَالَ أَبُو بَكْرٍ وَحَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ زَكَرِيَّاءَ، كِلاَهُمَا عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا صَلَّى الْفَجْرَ جَلَسَ فِي مُصَلاَّهُ حَتَّى تَطْلُعَ الشَّمْسُ حَسَنًا ‏.‏\hadithno{1526}\hadithtrans{Simak narrated on the authority of Jabir b. Samura that when the Messenger of Allah (ﷺ) observed the dawn prayer, he sat at the place of worship till the sun had risen enough}}
\hadithdefcmd{muslim}{1527}{وَحَدَّثَنَا قُتَيْبَةُ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، ح قَالَ وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنْ سِمَاكٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَقُولاَ حَسَنًا ‏.‏\hadithno{1527}\hadithtrans{This hadith has been narrated by Simak with the same chain of transmitters, but no mention has been made of, enough}}
\hadithdefcmd{muslim}{1528}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَإِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، قَالاَ حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، - حَدَّثَنِي ابْنُ أَبِي ذُبَابٍ، فِي رِوَايَةِ هَارُونَ - وَفِي حَدِيثِ الأَنْصَارِيِّ حَدَّثَنِي الْحَارِثُ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ مِهْرَانَ مَوْلَى أَبِي هُرَيْرَةَ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَحَبُّ الْبِلاَدِ إِلَى اللَّهِ مَسَاجِدُهَا وَأَبْغَضُ الْبِلاَدِ إِلَى اللَّهِ أَسْوَاقُهَا ‏"‏ ‏.‏\hadithno{1528}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) said:The parts of land dearest to Allah are its mosques, and the parts most hateful to Allah are markets}}
\hadithdefcmd{muslim}{1529}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانُوا ثَلاَثَةً فَلْيَؤُمَّهُمْ أَحَدُهُمْ وَأَحَقُّهُمْ بِالإِمَامَةِ أَقْرَؤُهُمْ ‏"‏ ‏.‏\hadithno{1529}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:When there are three persons, one of them should lead them. The one among them most worthy to act as Imam is one who is best versed in the Qur'an}}
\hadithdefcmd{muslim}{1530}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، ح وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ - حَدَّثَنِي أَبِي كُلُّهُمْ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1530}\hadithtrans{A hadith like this has been narrated by Qatida with the same chain of transmitters}}
\hadithdefcmd{muslim}{1531}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، ح وَحَدَّثَنَا حَسَنُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ الْمُبَارَكِ، جَمِيعًا عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1531}\hadithtrans{This hadith has been narrated by Abu Sa'id al-Khudri by another chain of transmitters}}
\hadithdefcmd{muslim}{1532}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ كِلاَهُمَا عَنْ أَبِي خَالِدٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، - عَنِ الأَعْمَشِ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، عَنْ أَوْسِ بْنِ ضَمْعَجٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَؤُمُّ الْقَوْمَ أَقْرَؤُهُمْ لِكِتَابِ اللَّهِ فَإِنْ كَانُوا فِي الْقِرَاءَةِ سَوَاءً فَأَعْلَمُهُمْ بِالسُّنَّةِ فَإِنْ كَانُوا فِي السُّنَّةِ سَوَاءً فَأَقْدَمُهُمْ هِجْرَةً فَإِنْ كَانُوا فِي الْهِجْرَةِ سَوَاءً فَأَقْدَمُهُمْ سِلْمًا وَلاَ يَؤُمَّنَّ الرَّجُلُ الرَّجُلَ فِي سُلْطَانِهِ وَلاَ يَقْعُدْ فِي بَيْتِهِ عَلَى تَكْرِمَتِهِ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏ قَالَ الأَشَجُّ فِي رِوَايَتِهِ مَكَانَ سِلْمًا سِنًّا ‏.‏\hadithno{1532}\hadithtrans{Abu Mas'ud al-Ansari reported Allah's Messenger (ﷺ) as saying:The one who is most versed in Allah's Book should act as Imam for the people, but If they are equally versed in reciting it, then the one who has most knowledge regarding Sunnah if they are equal regarding the Sunnah, then the earliest one to emigrate; it they emigrated at the same time, then the earliest one to embrace Islam. No man must lead another in prayer where (the latter) has authority, or sit in his place of honour in his house, without his permission. Ashajj in his narration used the word," age" in place of" Islam}}
\hadithdefcmd{muslim}{1533}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا جَرِيرٌ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا الأَشَجُّ، حَدَّثَنَا ابْنُ فُضَيْلٍ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1533}\hadithtrans{A hadith like this has been narrated by A'mash by the same chain of transmitters}}
\hadithdefcmd{muslim}{1534}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، قَالَ سَمِعْتُ أَوْسَ بْنَ ضَمْعَجٍ، يَقُولُ سَمِعْتُ أَبَا مَسْعُودٍ، يَقُولُ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَؤُمُّ الْقَوْمَ أَقْرَؤُهُمْ لِكِتَابِ اللَّهِ وَأَقْدَمُهُمْ قِرَاءَةً فَإِنْ كَانَتْ قِرَاءَتُهُمْ سَوَاءً فَلْيَؤُمَّهُمْ أَقْدَمُهُمْ هِجْرَةً فَإِنْ كَانُوا فِي الْهِجْرَةِ سَوَاءً فَلْيَؤُمَّهُمْ أَكْبَرُهُمْ سِنًّا وَلاَ تَؤُمَّنَّ الرَّجُلَ فِي أَهْلِهِ وَلاَ فِي سُلْطَانِهِ وَلاَ تَجْلِسْ عَلَى تَكْرِمَتِهِ فِي بَيْتِهِ إِلاَّ أَنْ يَأْذَنَ لَكَ أَوْ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{1534}\hadithtrans{Abu Mas'ud al-Ansari reported:The Messenger of Allah (ﷺ) said to us: The one who is well grounded in Allah's Book and is distinguished among them in recitation should act as; Imam for the people. and if they are equally versed in reciting it, then the one who has most knowledge regarding Sunnah; if they are equal regarding the Sunnah, then the earliest one to emigrate; If they emigrated at the same time, then the oldest one in age. No man must lead another in prayer in latter's house or where (the latter) has authority, or sit in his place of honour in his house, except that he gives you permission or with his permission}}
\hadithdefcmd{muslim}{1535}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَنَحْنُ شَبَبَةٌ مُتَقَارِبُونَ فَأَقَمْنَا عِنْدَهُ عِشْرِينَ لَيْلَةً وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَحِيمًا رَقِيقًا فَظَنَّ أَنَّا قَدِ اشْتَقْنَا أَهْلَنَا فَسَأَلَنَا عَنْ مَنْ تَرَكْنَا مِنْ أَهْلِنَا فَأَخْبَرْنَاهُ فَقَالَ ‏ "‏ ارْجِعُوا إِلَى أَهْلِيكُمْ فَأَقِيمُوا فِيهِمْ وَعَلِّمُوهُمْ وَمُرُوهُمْ فَإِذَا حَضَرَتِ الصَّلاَةُ فَلْيُؤَذِّنْ لَكُمْ أَحَدُكُمْ ثُمَّ لْيَؤُمَّكُمْ أَكْبَرُكُمْ ‏"‏ ‏.‏\hadithno{1535}\hadithtrans{Malik b. Huwairith reported:We came to the Messenger of Allah (ﷺ) and we were all young men of nearly equal age. We stayed with him (the Holy Prophet) for twenty nights, and as the Messenger of Allah (ﷺ) was extremely kind and tender of heart, he therefore, thought that we were eager (to see) our family (we felt homesick). So he asked us about the members of the family that we had left behind and when we informed him, he said: Go back to your family, stay with them, and teach them (beliefs and practices of Islam) and exhort them to good, and when the time for prayer comes, one amongst you should announce Adhan and then the oldest among you should lead the prayer}}
\hadithdefcmd{muslim}{1536}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَخَلَفُ بْنُ هِشَامٍ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1536}\hadithtrans{This hadith has been transmitted by Ayyub with the same chain of narrator}}
\hadithdefcmd{muslim}{1537}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، قَالَ قَالَ لِي أَبُو قِلاَبَةَ حَدَّثَنَا مَالِكُ بْنُ الْحُوَيْرِثِ أَبُو سُلَيْمَانَ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَاسٍ وَنَحْنُ شَبَبَةٌ مُتَقَارِبُونَ ‏.‏ وَاقْتَصَّا جَمِيعًا الْحَدِيثَ بِنَحْوِ حَدِيثِ ابْنِ عُلَيَّةَ ‏.‏\hadithno{1537}\hadithtrans{Malik b. Huwairith Abu Sulaiman reported:I came to the Messenger of Allah (ﷺ) along with other persons and we were young men of nearly equal age, and the rest of the hadith was transmitted like the hadith narrated before}}
\hadithdefcmd{muslim}{1538}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم أَنَا وَصَاحِبٌ لِي فَلَمَّا أَرَدْنَا الإِقْفَالَ مِنْ عِنْدِهِ قَالَ لَنَا ‏ "‏ إِذَا حَضَرَتِ الصَّلاَةُ فَأَذِّنَا ثُمَّ أَقِيمَا وَلْيَؤُمَّكُمَا أَكْبَرُكُمَا ‏"‏ ‏.‏\hadithno{1538}\hadithtrans{Malik b Huwairith reported:I came to the Messenger of Allah (ﷺ) along with a companion of mine, and when we intended to return from him, he said: When there is time for prayer, announce prayer, pronounce Iqama, and the oldest amongst you should lead the prayer}}
\hadithdefcmd{muslim}{1539}{وَحَدَّثَنَاهُ أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، بِهَذَا الإِسْنَادِ وَزَادَ قَالَ الْحَذَّاءُ وَكَانَا مُتَقَارِبَيْنِ فِي الْقِرَاءَةِ ‏.‏\hadithno{1539}\hadithtrans{This hadith has been narrated with the same chain of transmitters, but al-Hadra' made this addition:" They both were equal in recitation}}
\hadithdefcmd{muslim}{1540}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ حِينَ يَفْرُغُ مِنْ صَلاَةِ الْفَجْرِ مِنَ الْقِرَاءَةِ وَيُكَبِّرُ وَيَرْفَعُ رَأْسَهُ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ يَقُولُ وَهُوَ قَائِمٌ ‏"‏ اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ وَسَلَمَةَ بْنَ هِشَامٍ وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ وَالْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ وَاجْعَلْهَا عَلَيْهِمْ كَسِنِي يُوسُفَ اللَّهُمَّ الْعَنْ لِحْيَانَ وَرِعْلاً وَذَكْوَانَ وَعُصَيَّةَ عَصَتِ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏ ثُمَّ بَلَغَنَا أَنَّهُ تَرَكَ ذَلِكَ لَمَّا أُنْزِلَ ‏\{‏ لَيْسَ لَكَ مِنَ الأَمْرِ شَىْءٌ أَوْ يَتُوبَ عَلَيْهِمْ أَوْ يُعَذِّبَهُمْ فَإِنَّهُمْ ظَالِمُونَ‏\}‏ ‏.‏\hadithno{1540}\hadithtrans{Abu Salama b. Abd al-Rahman b. 'Auf heard Abu Huraira say:(When) Allah's Messenger (ﷺ) (wished to invoke curse or blessing on someone, he would do so at the end) of the recitation in the dawn prayer, when he had pronounced Allah-o-Akbar (for bending) and then lifted his head (saying):" Allah listened to him who praised Him; our Lord! to Thee is all praise" ; he would then stand up and say:" Rescue al-Walid b. Walid, Salama b. Hisham, and 'Ayyash b. Abd Rabi'a, and the helpless among the Muslims. O Allah! trample severely Mudar and cause them a famine (which broke out at the time) of Joseph. O Allah! curse Lihyan, Ri'l, Dhakwan, 'Usayya, for they disobeyed Allah and His Messenger." (The narrator then adds): The news reached us that he abandoned (this) when this verse was revealed:" Thou but no concern in the matter whether He turns to them (mercifully) or chastises them; surely they are wrongdoers" (ill)}}
\hadithdefcmd{muslim}{1541}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم إِلَى قَوْلِهِ ‏ "‏ وَاجْعَلْهَا عَلَيْهِمْ كَسِنِي يُوسُفَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{1541}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira by another chain of transmitters up to the words:" And cause them a famine like that (which broke out at the time) of Joseph," but the subsequent portion was not mentioned}}
\hadithdefcmd{muslim}{1542}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَنَتَ بَعْدَ الرَّكْعَةِ فِي صَلاَةٍ شَهْرًا إِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ يَقُولُ فِي قُنُوتِهِ ‏"‏ اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ اللَّهُمَّ نَجِّ سَلَمَةَ بْنَ هِشَامٍ اللَّهُمَّ نَجِّ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ اللَّهُمَّ نَجِّ الْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ اللَّهُمَّ اجْعَلْهَا عَلَيْهِمْ سِنِينَ كَسِنِي يُوسُفَ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ ثُمَّ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَرَكَ الدُّعَاءَ بَعْدُ فَقُلْتُ أُرَى رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ تَرَكَ الدُّعَاءَ لَهُمْ - قَالَ - فَقِيلَ وَمَا تَرَاهُمْ قَدْ قَدِمُوا\hadithno{1542}\hadithtrans{Abu Salama reported it on the authority of Abu Huraira that the Messenger of Allah (ﷺ) recited Qunut after ruku' in prayer for one mouth at the time of reciting (these words):" Allah listened to him who praised Him," and he said in Qunut:" 0 Allah! rescue al-Walid b. al-Walid; O Allah! rescue Salama b. Hisham; O Allah! rescue 'Ayyash b. Abu Rabi'a; O Allah! rescue the helpless amongst the Muslims; O Allah! trample Mudar severely; O Allah! cause them a famine like that (which was caused at the time) of Joseph." Abu Huraira (further) said: I saw that the Messenger of Allah (ﷺ) afterwards abandoned this supplication. I, therefore said: I see the Messenger of Allah (ﷺ) abandoning this blessing upon them. It was raid to him (Abu Huraira): Don't you see that (those for whom was blessing invoked by the Holy Prophet) have come (i. e. they have been rescued)?}}
\hadithdefcmd{muslim}{1543}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَيْنَمَا هُوَ يُصَلِّي الْعِشَاءَ إِذْ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ قَالَ قَبْلَ أَنْ يَسْجُدَ ‏"‏ اللَّهُمَّ نَجِّ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ الأَوْزَاعِيِّ إِلَى قَوْلِهِ ‏"‏ كَسِنِي يُوسُفَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{1543}\hadithtrans{Abu Salama narrated that Abu Huraira told him that when the Messenger of Allah (ﷺ) pronounced:" Allah listened to him who praised Him." and before prostration, he would recite this in the 'Isya' prayer: O Allah! rescue 'Ayyash b. Abu Rabi'a, and the rest of the hadith is the same as narrated by Auza'i to the words:" Like the famine (at the time) if Joseph." but he made no mention of that which follows afterwards}}
\hadithdefcmd{muslim}{1544}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ وَاللَّهِ لأُقَرِّبَنَّ بِكُمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَكَانَ أَبُو هُرَيْرَةَ يَقْنُتُ فِي الظُّهْرِ وَالْعِشَاءِ الآخِرَةِ وَصَلاَةِ الصُّبْحِ وَيَدْعُو لِلْمُؤْمِنِينَ وَيَلْعَنُ الْكُفَّارَ ‏.‏\hadithno{1544}\hadithtrans{Abu Salama b. 'Abd al-Rahman is reported to have said that he had heard Abu Huraira saying:I would say prayer along with you which is near to the prayer of the Messenger of Allah (ﷺ). and Abu Huraira recited Qunut in the noon and in the 'Isya' and in the morning prayer, and invoked blessing (of Allah) upon Muslims-and curse upon the unbelievers}}
\hadithdefcmd{muslim}{1545}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الَّذِينَ قَتَلُوا أَصْحَابَ بِئْرِ مَعُونَةَ ثَلاَثِينَ صَبَاحًا يَدْعُو عَلَى رِعْلٍ وَذَكْوَانَ وَلِحْيَانَ وَعُصَيَّةَ عَصَتِ اللَّهَ وَرَسُولَهُ ‏.‏ قَالَ أَنَسٌ أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِي الَّذِينَ قُتِلُوا بِبِئْرِ مَعُونَةَ قُرْآنًا قَرَأْنَاهُ حَتَّى نُسِخَ بَعْدُ أَنْ بَلِّغُوا قَوْمَنَا أَنْ قَدْ لَقِينَا رَبَّنَا فَرَضِيَ عَنَّا وَرَضِينَا عَنْهُ ‏.‏\hadithno{1545}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) invoked curse in the morning (prayer) for thirty days upon those who killed the Companions (of the Holy Prophet) at Bi'r Ma'una. He cursed (the tribes) of Ri'l, Dhakwan, Lihyan, and Usayya, who had disobeyed Allah and His Messenger (ﷺ). Anas said:Allah the Exalted and Great revealed (a verse) regarding those who were killed at Bi'r Ma'una, and we recited it, till it was abrogated later on (and the verse was like this):, convey to it our people the tidings that we have met our Lord, and He was pleased with us and we were pleased with Him}}
\hadithdefcmd{muslim}{1546}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، قَالَ قُلْتُ لأَنَسٍ هَلْ قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةِ الصُّبْحِ قَالَ نَعَمْ بَعْدَ الرُّكُوعِ يَسِيرًا ‏.‏\hadithno{1546}\hadithtrans{Muhammad reported:I asked Anas whether the Messenger of Allah (ﷺ) observed Qunut in the dawn prayer. He said: Yes, (he did so) after the ruku', for a short while}}
\hadithdefcmd{muslim}{1547}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى - وَاللَّفْظُ لاِبْنِ مُعَاذٍ - حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ أَبِي مِجْلَزٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهْرًا بَعْدَ الرُّكُوعِ فِي صَلاَةِ الصُّبْحِ يَدْعُو عَلَى رِعْلٍ وَذَكْوَانَ وَيَقُولُ ‏ "‏ عُصَيَّةُ عَصَتِ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏\hadithno{1547}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) observed Qunut for a month in the dawn prayer after ruku' and invoked curse upon Ri'l, Dhakwan, and said that 'Usayya had disobeyed Allah and His Apostle (ﷺ)}}
\hadithdefcmd{muslim}{1548}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا أَنَسُ بْنُ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَنَتَ شَهْرًا بَعْدَ الرُّكُوعِ فِي صَلاَةِ الْفَجْرِ يَدْعُو عَلَى بَنِي عُصَيَّةَ ‏.‏\hadithno{1548}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) observed Qunut for a month in the dawn prayer after ruku' and invoked curse upon Bani Usayya}}
\hadithdefcmd{muslim}{1549}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ، عَنْ أَنَسٍ، قَالَ سَأَلْتُهُ عَنِ الْقُنُوتِ، قَبْلَ الرُّكُوعِ أَوْ بَعْدَ الرُّكُوعِ فَقَالَ قَبْلَ الرُّكُوعِ ‏.‏ قَالَ قُلْتُ فَإِنَّ نَاسًا يَزْعُمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَنَتَ بَعْدَ الرُّكُوعِ ‏.‏ فَقَالَ إِنَّمَا قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهْرًا يَدْعُو عَلَى أُنَاسٍ قَتَلُوا أُنَاسًا مِنْ أَصْحَابِهِ يُقَالُ لَهُمُ الْقُرَّاءُ ‏.‏\hadithno{1549}\hadithtrans{Asim reported:I asked Anas whether Qunut was observed (by the Holy prophet) before ruku' or after ruku'. He replied: Before ruku'. I said: People conceive that the Messenger of Allah (ﷺ) observed Qunut after the ruku'. He said: The Messenger of Allah (ﷺ) observed Qunut (after the ruku' as the people conceive it) for a mouth invoking curse upon those persons who had killed men among his Companions who were called the reciter (of the Qur'an)}}
\hadithdefcmd{muslim}{1550}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَجَدَ عَلَى سَرِيَّةٍ مَا وَجَدَ عَلَى السَّبْعِينَ الَّذِينَ أُصِيبُوا يَوْمَ بِئْرِ مَعُونَةَ كَانُوا يُدْعَوْنَ الْقُرَّاءَ فَمَكَثَ شَهْرًا يَدْعُو عَلَى قَتَلَتِهِمْ ‏.‏\hadithno{1550}\hadithtrans{Asim reported - I heard Anas saying:Never did I ace the Messenger of Allah (ﷺ) so much grieved (at the loss of a) small army as I saw him grieved at those seventy men who were called" reciters" (and were killed) at Bi'r Ma'una; and he invoked curse for full one month upon their murderers}}
\hadithdefcmd{muslim}{1551}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حَفْصٌ، وَابْنُ، فُضَيْلٍ ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ، كُلُّهُمْ عَنْ عَاصِمٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏ يَزِيدُ بَعْضُهُمْ عَلَى بَعْضٍ ‏.‏\hadithno{1551}\hadithtrans{This hadith has been narrated by Anas with another chain of transmitters and with minor additions}}
\hadithdefcmd{muslim}{1552}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَنَتَ شَهْرًا يَلْعَنُ رِعْلاً وَذَكْوَانَ وَعُصَيَّةَ عَصَوُا اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{1552}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) observed Qunut for one month Invoking curse upon Ri'l, Dhakwan, 'Usayya. those who disobeyed Allah and His Messenger (ﷺ)}}
\hadithdefcmd{muslim}{1553}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{1553}\hadithtrans{A hadith like this has been transmitted by Anas from the Messenger of Allah (way peace be upon him)}}
\hadithdefcmd{muslim}{1554}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَنَتَ شَهْرًا يَدْعُو عَلَى أَحْيَاءٍ مِنْ أَحْيَاءِ الْعَرَبِ ثُمَّ تَرَكَهُ ‏.‏\hadithno{1554}\hadithtrans{Anas reported that the Messenger of Allah (ﷺ) observed Qunut for one month invoking curse upon some tribes of Arabia (those who were responsible for the murders in Bi'r Ma'una and Raji'), but then abandoned it}}
\hadithdefcmd{muslim}{1555}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ ابْنَ أَبِي لَيْلَى، قَالَ حَدَّثَنَا الْبَرَاءُ بْنُ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْنُتُ فِي الصُّبْحِ وَالْمَغْرِبِ ‏.‏\hadithno{1555}\hadithtrans{Al-Bari' b. 'Azib reported that the Messenger of Allah (ﷺ) observed Qunut in the morning and evening (prayers)}}
\hadithdefcmd{muslim}{1556}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ، قَالَ قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْفَجْرِ وَالْمَغْرِبِ ‏.‏\hadithno{1556}\hadithtrans{Al-Bari' reported that the Messenger of Allah (ﷺ) observed Qunut in the dawn and evening (prayers)}}
\hadithdefcmd{muslim}{1557}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ الْمِصْرِيُّ قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ اللَّيْثِ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ حَنْظَلَةَ بْنِ عَلِيٍّ، عَنْ خُفَافِ بْنِ إِيمَاءٍ الْغِفَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةٍ ‏ "‏ اللَّهُمَّ الْعَنْ بَنِي لِحْيَانَ وَرِعْلاً وَذَكْوَانَ وَعُصَيَّةَ عَصَوُا اللَّهَ وَرَسُولَهُ غِفَارُ غَفَرَ اللَّهُ لَهَا وَأَسْلَمُ سَالَمَهَا اللَّهُ ‏"‏ ‏.‏\hadithno{1557}\hadithtrans{Khufaf b. Ima' al-Ghifari reported that the Messenger of Allah (ﷺ) aid in prayer:0 Allah I curse the tribes of Lihyan, Ri'l, Dhakwan, and 'Usayya for they disobeyed Allah and His Messenger (ﷺ). Allah pardoned (the tribe of) Ghifar and Allah granted protection to (the tribe of) Aslam}}
\hadithdefcmd{muslim}{1558}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ أَخْبَرَنِي مُحَمَّدٌ، - وَهُوَ ابْنُ عَمْرٍو - عَنْ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ حَرْمَلَةَ، عَنِ الْحَارِثِ بْنِ خُفَافٍ، أَنَّهُ قَالَ قَالَ خُفَافُ بْنُ إِيمَاءٍ رَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏ "‏ غِفَارُ غَفَرَ اللَّهُ لَهَا وَأَسْلَمُ سَالَمَهَا اللَّهُ وَعُصَيَّةُ عَصَتِ اللَّهَ وَرَسُولَهُ اللَّهُمَّ الْعَنْ بَنِي لِحْيَانَ وَالْعَنْ رِعْلاً وَذَكْوَانَ ‏"‏ ‏.‏ ثُمَّ وَقَعَ سَاجِدًا ‏.‏ قَالَ خُفَافٌ فَجُعِلَتْ لَعْنَةُ الْكَفَرَةِ مِنْ أَجْلِ ذَلِكَ ‏.‏\hadithno{1558}\hadithtrans{Khufaf b. Ima' reported that the Messenger of Allah (may peace he upon him), bowed (in prayer) and then lifted his head and then said:So far as the tribe of Ghifar is concerned, Allah had pardoned it, and Allah had granted protection to the tribe of Aslam, and as for the tribe of Usayya, It had disobeyed Allah and His Messenger, (and further said): O Allah! curse the tribe of Lihyan curse Ri'l, and Dhakwan, and then fell in prostration. It is after this that the cursing of the unbelievers got a sanction}}
\hadithdefcmd{muslim}{1559}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا إِسْمَاعِيلُ، قَالَ وَأَخْبَرَنِيهِ عَبْدُ الرَّحْمَنِ بْنُ حَرْمَلَةَ، عَنْ حَنْظَلَةَ بْنِ عَلِيِّ بْنِ الأَسْقَعِ، عَنْ خُفَافِ بْنِ إِيمَاءٍ، ‏.‏ بِمِثْلِهِ إِلاَّ أَنَّهُ لَمْ يَقُلْ فَجُعِلَتْ لَعْنَةُ الْكَفَرَةِ مِنْ أَجْلِ ذَلِكَ ‏.‏\hadithno{1559}\hadithtrans{A hadith like this has been transmitted by Khufaf b. Ima' except this that he did not mention (these words):" cursing of unbelievers got a sanctions}}
\hadithdefcmd{muslim}{1560}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ قَفَلَ مِنْ غَزْوَةِ خَيْبَرَ سَارَ لَيْلَهُ حَتَّى إِذَا أَدْرَكَهُ الْكَرَى عَرَّسَ وَقَالَ لِبِلاَلٍ ‏"‏ اكْلأْ لَنَا اللَّيْلَ ‏"‏ ‏.‏ فَصَلَّى بِلاَلٌ مَا قُدِّرَ لَهُ وَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ فَلَمَّا تَقَارَبَ الْفَجْرُ اسْتَنَدَ بِلاَلٌ إِلَى رَاحِلَتِهِ مُوَاجِهَ الْفَجْرِ فَغَلَبَتْ بِلاَلاً عَيْنَاهُ وَهُوَ مُسْتَنِدٌ إِلَى رَاحِلَتِهِ فَلَمْ يَسْتَيْقِظْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ بِلاَلٌ وَلاَ أَحَدٌ مِنْ أَصْحَابِهِ حَتَّى ضَرَبَتْهُمُ الشَّمْسُ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَوَّلَهُمُ اسْتِيقَاظًا فَفَزِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَىْ بِلاَلُ ‏"‏ ‏.‏ فَقَالَ بِلاَلٌ أَخَذَ بِنَفْسِي الَّذِي أَخَذَ - بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ - بِنَفْسِكَ قَالَ ‏"‏ اقْتَادُوا ‏"‏ ‏.‏ فَاقْتَادُوا رَوَاحِلَهُمْ شَيْئًا ثُمَّ تَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَرَ بِلاَلاً فَأَقَامَ الصَّلاَةَ فَصَلَّى بِهِمُ الصُّبْحَ فَلَمَّا قَضَى الصَّلاَةَ قَالَ ‏"‏ مَنْ نَسِيَ الصَّلاَةَ فَلْيُصَلِّهَا إِذَا ذَكَرَهَا فَإِنَّ اللَّهَ قَالَ ‏\{‏ أَقِمِ الصَّلاَةَ لِذِكْرِي‏\}‏ ‏"‏ ‏.‏ قَالَ يُونُسُ وَكَانَ ابْنُ شِهَابٍ يَقْرَؤُهَا لِلذِّكْرَى ‏.‏\hadithno{1560}\hadithtrans{Abu Huraira reported that when the Messenger of Allah (ﷺ) returned from the expedition to Khaibar, he travelled one night, and stopped for rest when he became sleepy. He told Bilal to remain on guard during the night and he (Bilal) prayed as much as he could, while the Messenger of Allah (ﷺ) and his Companions slept. When the time for dawn approached Bilal leaned against his camel facing the direction from which the dawn would appear but he was overcome by sleep while he was leaning against his camel, and neither the Messenger of Allah (ﷺ) nor Bilal, nor anyone else among his Companions got up, till the sun shone on them. Allah's Messenger (ﷺ) was the first of them to awake and, being startled, he called to Bilal who said:Messenger of Allah I may my father and mother be offered as ransom for thee, the same thing overpowered me which overpowered you. He (the Holy Prophet, then) said: Lead the beasts on: so they led their camels to some distance. The Messenger of Allah (ﷺ) then performed ablution and gave orders to Bilal who pronounced the Iqama and then led them in the morning prayer. When he finished the prayer he said: When anyone forgets the prayer, he should observe it when he remembers it, for Allah has said:" And observe the prayer for remembrance of Me" (Qur'an. xx. 14). Yunus said: Ibn Shilab used to recite it like this:" (And observe the prayer) for remembrance}}
\hadithdefcmd{muslim}{1561}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، كِلاَهُمَا عَنْ يَحْيَى، - قَالَ ابْنُ حَاتِمٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، - حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ عَرَّسْنَا مَعَ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَلَمْ نَسْتَيْقِظْ حَتَّى طَلَعَتِ الشَّمْسُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لِيَأْخُذْ كُلُّ رَجُلٍ بِرَأْسِ رَاحِلَتِهِ فَإِنَّ هَذَا مَنْزِلٌ حَضَرَنَا فِيهِ الشَّيْطَانُ ‏"‏ ‏.‏ قَالَ فَفَعَلْنَا ثُمَّ دَعَا بِالْمَاءِ فَتَوَضَّأَ ثُمَّ سَجَدَ سَجْدَتَيْنِ - وَقَالَ يَعْقُوبُ ثُمَّ صَلَّى سَجْدَتَيْنِ - ثُمَّ أُقِيمَتِ الصَّلاَةُ فَصَلَّى الْغَدَاةَ ‏.‏\hadithno{1561}\hadithtrans{Abu Huraira reported:We stopped for rest along with the Messenger of Allah (ﷺ) and did not awake till the sun rose. The Apostle of Allah (ﷺ) then told us that everybody should take hold of his camel's nosestring (get out of this ground) for it was the place where devil had visited us. We did accordingly. He then called for water and performed ablution and then performed two prostrations. Ya'qub said: Then he prayed (performed) two prostrations. then takbir was pronounced for prayer and then he offered the morning prayer (in congregation)}}
\hadithdefcmd{muslim}{1562}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - حَدَّثَنَا ثَابِتٌ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّكُمْ تَسِيرُونَ عَشِيَّتَكُمْ وَلَيْلَتَكُمْ وَتَأْتُونَ الْمَاءَ إِنْ شَاءَ اللَّهُ غَدًا ‏"‏ ‏.‏ فَانْطَلَقَ النَّاسُ لاَ يَلْوِي أَحَدٌ عَلَى أَحَدٍ - قَالَ أَبُو قَتَادَةَ - فَبَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَسِيرُ حَتَّى ابْهَارَّ اللَّيْلُ وَأَنَا إِلَى جَنْبِهِ - قَالَ - فَنَعَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَمَالَ عَنْ رَاحِلَتِهِ فَأَتَيْتُهُ فَدَعَمْتُهُ مِنْ غَيْرِ أَنْ أُوقِظَهُ حَتَّى اعْتَدَلَ عَلَى رَاحِلَتِهِ - قَالَ - ثُمَّ سَارَ حَتَّى تَهَوَّرَ اللَّيْلُ مَالَ عَنْ رَاحِلَتِهِ - قَالَ - فَدَعَمْتُهُ مِنْ غَيْرِ أَنْ أُوقِظَهُ حَتَّى اعْتَدَلَ عَلَى رَاحِلَتِهِ - قَالَ - ثُمَّ سَارَ حَتَّى إِذَا كَانَ مِنْ آخِرِ السَّحَرِ مَالَ مَيْلَةً هِيَ أَشَدُّ مِنَ الْمَيْلَتَيْنِ الأُولَيَيْنِ حَتَّى كَادَ يَنْجَفِلُ فَأَتَيْتُهُ فَدَعَمْتُهُ فَرَفَعَ رَأْسَهُ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ قُلْتُ أَبُو قَتَادَةَ ‏.‏ قَالَ ‏"‏ مَتَى كَانَ هَذَا مَسِيرَكَ مِنِّي ‏"‏ ‏.‏ قُلْتُ مَا زَالَ هَذَا مَسِيرِي مُنْذُ اللَّيْلَةِ ‏.‏ قَالَ ‏"‏ حَفِظَكَ اللَّهُ بِمَا حَفِظْتَ بِهِ نَبِيَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ هَلْ تَرَانَا نَخْفَى عَلَى النَّاسِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ هَلْ تَرَى مِنْ أَحَدٍ ‏"‏ ‏.‏ قُلْتُ هَذَا رَاكِبٌ ‏.‏ ثُمَّ قُلْتُ هَذَا رَاكِبٌ آخَرُ ‏.‏ حَتَّى اجْتَمَعْنَا فَكُنَّا سَبْعَةَ رَكْبٍ - قَالَ - فَمَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الطَّرِيقِ فَوَضَعَ رَأْسَهُ ثُمَّ قَالَ ‏"‏ احْفَظُوا عَلَيْنَا صَلاَتَنَا ‏"‏ ‏.‏ فَكَانَ أَوَّلَ مَنِ اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالشَّمْسُ فِي ظَهْرِهِ - قَالَ - فَقُمْنَا فَزِعِينَ ثُمَّ قَالَ ‏"‏ ارْكَبُوا ‏"‏ ‏.‏ فَرَكِبْنَا فَسِرْنَا حَتَّى إِذَا ارْتَفَعَتِ الشَّمْسُ نَزَلَ ثُمَّ دَعَا بِمِيضَأَةٍ كَانَتْ مَعِي فِيهَا شَىْءٌ مِنْ مَاءٍ - قَالَ - فَتَوَضَّأَ مِنْهَا وُضُوءًا دُونَ وُضُوءٍ - قَالَ - وَبَقِيَ فِيهَا شَىْءٌ مِنْ مَاءٍ ثُمَّ قَالَ لأَبِي قَتَادَةَ ‏"‏ احْفَظْ عَلَيْنَا مِيضَأَتَكَ فَسَيَكُونُ لَهَا نَبَأٌ ‏"‏ ‏.‏ ثُمَّ أَذَّنَ بِلاَلٌ بِالصَّلاَةِ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ ثُمَّ صَلَّى الْغَدَاةَ فَصَنَعَ كَمَا كَانَ يَصْنَعُ كُلَّ يَوْمٍ - قَالَ - وَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَكِبْنَا مَعَهُ - قَالَ - فَجَعَلَ بَعْضُنَا يَهْمِسُ إِلَى بَعْضٍ مَا كَفَّارَةُ مَا صَنَعْنَا بِتَفْرِيطِنَا فِي صَلاَتِنَا ثُمَّ قَالَ ‏"‏ أَمَا لَكُمْ فِيَّ أُسْوَةٌ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَمَا إِنَّهُ لَيْسَ فِي النَّوْمِ تَفْرِيطٌ إِنَّمَا التَّفْرِيطُ عَلَى مَنْ لَمْ يُصَلِّ الصَّلاَةَ حَتَّى يَجِيءَ وَقْتُ الصَّلاَةِ الأُخْرَى فَمَنْ فَعَلَ ذَلِكَ فَلْيُصَلِّهَا حِينَ يَنْتَبِهُ لَهَا فَإِذَا كَانَ الْغَدُ فَلْيُصَلِّهَا عِنْدَ وَقْتِهَا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ مَا تَرَوْنَ النَّاسَ صَنَعُوا ‏"‏ ‏.‏ قَالَ ثُمَّ قَالَ ‏"‏ أَصْبَحَ النَّاسُ فَقَدُوا نَبِيَّهُمْ فَقَالَ أَبُو بَكْرٍ وَعُمَرُ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَكُمْ لَمْ يَكُنْ لِيُخَلِّفَكُمْ ‏.‏ وَقَالَ النَّاسُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَيْنَ أَيْدِيكُمْ فَإِنْ يُطِيعُوا أَبَا بَكْرٍ وَعُمَرَ يَرْشُدُوا ‏"‏ ‏.‏ قَالَ فَانْتَهَيْنَا إِلَى النَّاسِ حِينَ امْتَدَّ النَّهَارُ وَحَمِيَ كُلُّ شَىْءٍ وَهُمْ يَقُولُونَ يَا رَسُولَ اللَّهِ هَلَكْنَا عَطِشْنَا ‏.‏ فَقَالَ ‏"‏ لاَ هُلْكَ عَلَيْكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَطْلِقُوا لِي غُمَرِي ‏"‏ ‏.‏ قَالَ وَدَعَا بِالْمِيضَأَةِ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُبُّ وَأَبُو قَتَادَةَ يَسْقِيهِمْ فَلَمْ يَعْدُ أَنْ رَأَى النَّاسُ مَاءً فِي الْمِيضَأَةِ تَكَابُّوا عَلَيْهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحْسِنُوا الْمَلأَ كُلُّكُمْ سَيَرْوَى ‏"‏ ‏.‏ قَالَ فَفَعَلُوا فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُبُّ وَأَسْقِيهِمْ حَتَّى مَا بَقِيَ غَيْرِي وَغَيْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - ثُمَّ صَبَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لِي ‏"‏ اشْرَبْ ‏"‏ ‏.‏ فَقُلْتُ لاَ أَشْرَبُ حَتَّى تَشْرَبَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنَّ سَاقِيَ الْقَوْمِ آخِرُهُمْ شُرْبًا ‏"‏ ‏.‏ قَالَ فَشَرِبْتُ وَشَرِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ - فَأَتَى النَّاسُ الْمَاءَ جَامِّينَ رِوَاءً ‏.‏ قَالَ فَقَالَ عَبْدُ اللَّهِ بْنُ رَبَاحٍ إِنِّي لأُحَدِّثُ هَذَا الْحَدِيثَ فِي مَسْجِدِ الْجَامِعِ إِذْ قَالَ عِمْرَانُ بْنُ حُصَيْنٍ انْظُرْ أَيُّهَا الْفَتَى كَيْفَ تُحَدِّثُ فَإِنِّي أَحَدُ الرَّكْبِ تِلْكَ اللَّيْلَةَ ‏.‏ قَالَ قُلْتُ فَأَنْتَ أَعْلَمُ بِالْحَدِيثِ ‏.‏ فَقَالَ مِمَّنْ أَنْتَ قُلْتُ مِنَ الأَنْصَارِ ‏.‏ قَالَ حَدِّثْ فَأَنْتُمْ أَعْلَمُ بِحَدِيثِكُمْ ‏.‏ قَالَ فَحَدَّثْتُ الْقَوْمَ فَقَالَ عِمْرَانُ لَقَدْ شَهِدْتُ تِلْكَ اللَّيْلَةَ وَمَا شَعَرْتُ أَنَّ أَحَدًا حَفِظَهُ كَمَا حَفِظْتُهُ ‏.‏\hadithno{1562}\hadithtrans{Abu Qatida reported:The Messenger of Allah (way peace be upon him) addressed us and said: You would travel In the evening and the might till (God willing) you would come in the morning to a place of water. So the people travelled (self absorbed) without paying any heed to one another, and the Messenger of Allah (ﷺ) also travelled till It was midnight. I was by his side. The Messenger of Allah (ﷺ) began to doze and leaned (to one side) of his camel. I came to him and I lent him support without awaking him till he sat poised on his ride. He went on travelling till a major part of the night was over and (he again) leaned (to one side) of his camel. I supported him without awaking him till he sat" bed on his ride. and then travelled till it was near dawn. He (again) leaned which was far more inclined than the two earlier leanings and he was about to fall down. So I came to him and supported him and he lifted his head and said; Who is this? I said: it is Abu Qatida. He (the Prophet again) said: Since how long have you been travelling along with me like this? I said: I have been travelling in this very state since the night. He said: May Allah protect you, as you have protected His Apostle (from falling down), and again said: Do you see that we are hidden from the people? - and again said: Do you see anyone? I said: Here is a rider. I again said: Here Is another rider till we gathered together and we were seven riders. The Messenger of Allah (ﷺ) stepped aside of the highway and placed his head (for sleep and said): Guard for us our prayers. The Messenger of Allah (ﷺ) was the first to wake up and the rays of the sun were falling on his back. We got up startled He (the Holy Prophet) said: Ride on So we rode on till the sun had (sufficiently) risen. He then came down from his camel and called for a jug of water which I had with me. There was a little water in that. He performed ablution with that which was less thorough as compared with his usual ablutions and some water of that had been left. He (the Holy Prophet) said to Abu Qatida: Keep a watch over your jug of water; it would have (a miraculous) condition about it. Then Bilal summoned (people) to prayer and then the Messenger of Allah (ﷺ) observed two rak'ahs and then said the morning prayer as he said every day. The Messenger of Allah (ﷺ) (then) rode on and we rode along with him and some of us whispered to the others saying: How would there be compensation for omission in our prayers? Upon this he (the Messenger of Allah) said: Is there not in me (my life) a model for you? There is no omission in sleeping. The (cognizable) emission is that one should not say prayer (intentionally) till the time of the other prayer comes. So he who did like it (omitted prayer in sleep or due to other unavoidable circumstances) should say prayer when he becomes aware of it and on the next day he should observe it at its prescribed time. He (the Holy Prophet) said: What do you think the people would have done (at this hour)? They would have in the morning found their Apostle missing from amongst them and then Abu Bakr and 'Umar would have told them that the Messenger of Allah (ﷺ) must be behind you, he cannot leave you behind (him), but the people said: The Messenger of Allah (ﷺ) is ahead of you. So if you had obeyed Abu Bakr and Umar, you would have gone on the right path. So we proceeded on till we came up to the people (from whom we had lagged behind) and the day had considerably risen and everything became hot, and they (the Companions of the Holy Prophet) said: Messenger of Allah, we are dying of thirst. Upon this he (the Holy Prophet) remarked: There is no destruction for you. And again said: Bring that small cup of mine and he then asked for the jug of water to be brought to him. The Messenger of Allah (ﷺ) began to pour water (in that small cup) and Abu Qatida gave them to drink. And when the people saw that there was (a little) water in the jug, they fell upon it. Upon this the Messenger of Allah (ﷺ) said: Behave well; the water (is enough) to satiate all of you. Then they (the Companions) began to receive (their share of) water with calmness (without showing any anxiety) and the Messenger of Allah (ﷺ) began to fill (the cap), and I began to serve them till no one was left except me and the Messenger of Allah (ﷺ). He then filled (the cup) with water and said to me: Drink it. I said: Messenger of Allah, I would not drink till you drink. Upon this he said: The server of the people Is the last among them to drink. So I drank and the Messenger of Allah (ﷺ) also drank and the people came to the place of water quite happy and satiated. 'Abdullah b. Rabah said: I am going to narrate this hadith in the great mosque, when 'Imran b. Husain said: See, O young man, how will you narrate for I was also one of the riders on that night? I said: So you must be knowing this hadith well. He said: Who are you? I said: I am one of the Ansar. Upon this he said: You narrate, for you know your hadith better. I, therefore, narrated it to the people. 'Imran said: I was also present that night, but I know not anyone else who learnt it so well as you have learnt}}
\hadithdefcmd{muslim}{1563}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدِ بْنِ صَخْرٍ الدَّارِمِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا سَلْمُ بْنُ زَرِيرٍ الْعُطَارِدِيُّ، قَالَ سَمِعْتُ أَبَا رَجَاءٍ الْعُطَارِدِيَّ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ كُنْتُ مَعَ نَبِيِّ اللَّهِ صلى الله عليه وسلم فِي مَسِيرٍ لَهُ فَأَدْلَجْنَا لَيْلَتَنَا حَتَّى إِذَا كَانَ فِي وَجْهِ الصُّبْحِ عَرَّسْنَا فَغَلَبَتْنَا أَعْيُنُنَا حَتَّى بَزَغَتِ الشَّمْسُ - قَالَ - فَكَانَ أَوَّلَ مَنِ اسْتَيْقَظَ مِنَّا أَبُو بَكْرٍ وَكُنَّا لاَ نُوقِظُ نَبِيَّ اللَّهِ صلى الله عليه وسلم مِنْ مَنَامِهِ إِذَا نَامَ حَتَّى يَسْتَيْقِظَ ثُمَّ اسْتَيْقَظَ عُمَرُ فَقَامَ عِنْدَ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يُكَبِّرُ وَيَرْفَعُ صَوْتَهُ بِالتَّكْبِيرِ حَتَّى اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَفَعَ رَأْسَهُ وَرَأَى الشَّمْسَ قَدْ بَزَغَتْ قَالَ ‏"‏ ارْتَحِلُوا ‏"‏ ‏.‏ فَسَارَ بِنَا حَتَّى إِذَا ابْيَضَّتِ الشَّمْسُ نَزَلَ فَصَلَّى بِنَا الْغَدَاةَ فَاعْتَزَلَ رَجُلٌ مِنَ الْقَوْمِ لَمْ يُصَلِّ مَعَنَا فَلَمَّا انْصَرَفَ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا فُلاَنُ مَا مَنَعَكَ أَنْ تُصَلِّيَ مَعَنَا ‏"‏ ‏.‏ قَالَ يَا نَبِيَّ اللَّهِ أَصَابَتْنِي جَنَابَةٌ ‏.‏ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَيَمَّمَ بِالصَّعِيدِ فَصَلَّى ثُمَّ عَجَّلَنِي فِي رَكْبٍ بَيْنَ يَدَيْهِ نَطْلُبُ الْمَاءَ وَقَدْ عَطِشْنَا عَطَشًا شَدِيدًا ‏.‏ فَبَيْنَمَا نَحْنُ نَسِيرُ إِذَا نَحْنُ بِامْرَأَةٍ سَادِلَةٍ رِجْلَيْهَا بَيْنَ مَزَادَتَيْنِ فَقُلْنَا لَهَا أَيْنَ الْمَاءُ قَالَتْ أَيْهَاهْ أَيْهَاهْ لاَ مَاءَ لَكُمْ ‏.‏ قُلْنَا فَكَمْ بَيْنَ أَهْلِكِ وَبَيْنَ الْمَاءِ ‏.‏ قَالَتْ مَسِيرَةُ يَوْمٍ وَلَيْلَةٍ ‏.‏ قُلْنَا انْطَلِقِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ وَمَا رَسُولُ اللَّهِ فَلَمْ نُمَلِّكْهَا مِنْ أَمْرِهَا شَيْئًا حَتَّى انْطَلَقْنَا بِهَا فَاسْتَقْبَلْنَا بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلَهَا فَأَخْبَرَتْهُ مِثْلَ الَّذِي أَخْبَرَتْنَا وَأَخْبَرَتْهُ أَنَّهَا مُوتِمَةٌ لَهَا صِبْيَانٌ أَيْتَامٌ فَأَمَرَ بِرَاوِيَتِهَا فَأُنِيخَتْ فَمَجَّ فِي الْعَزْلاَوَيْنِ الْعُلْيَاوَيْنِ ثُمَّ بَعَثَ بِرَاوِيَتِهَا فَشَرِبْنَا وَنَحْنُ أَرْبَعُونَ رَجُلاً عِطَاشٌ حَتَّى رَوِينَا وَمَلأْنَا كُلَّ قِرْبَةٍ مَعَنَا وَإِدَاوَةٍ وَغَسَّلْنَا صَاحِبَنَا غَيْرَ أَنَّا لَمْ نَسْقِ بَعِيرًا وَهِيَ تَكَادُ تَنْضَرِجُ مِنَ الْمَاءِ - يَعْنِي الْمَزَادَتَيْنِ - ثُمَّ قَالَ ‏"‏ هَاتُوا مَا كَانَ عِنْدَكُمْ ‏"‏ ‏.‏ فَجَمَعْنَا لَهَا مِنْ كِسَرٍ وَتَمْرٍ وَصَرَّ لَهَا صُرَّةً فَقَالَ لَهَا ‏"‏ اذْهَبِي فَأَطْعِمِي هَذَا عِيَالَكِ وَاعْلَمِي أَنَّا لَمْ نَرْزَأْ مِنْ مَائِكِ ‏"‏ ‏.‏ فَلَمَّا أَتَتْ أَهْلَهَا قَالَتْ لَقَدْ لَقِيتُ أَسْحَرَ الْبَشَرِ أَوْ إِنَّهُ لَنَبِيٌّ كَمَا زَعَمَ كَانَ مِنْ أَمْرِهِ ذَيْتَ وَذَيْتَ ‏.‏ فَهَدَى اللَّهُ ذَاكَ الصِّرْمَ بِتِلْكَ الْمَرْأَةِ فَأَسْلَمَتْ وَأَسْلَمُوا ‏.‏\hadithno{1563}\hadithtrans{Imran b. Husain reported:I was with the Messenger of Allah (ﷺ) in a journey. We travelled the whole of the night, and when it was about to dawn, we got down for rest, and were overpowered (by sleep) till the sun shone. Abu Bakr was the first to awake amongst us. and we did not awake the Messenger of Allah (ﷺ) from his sleep allowing him to wake up (of his own accord). It was 'Umar who then woke up. He stood by the side of the Messenger of Allah (ﷺ) and recited takbir in a loud voice till the Messenger of Allah (ﷺ) woke up. When he lifted his head, he saw that the sun had arisen; he then said: Proceed on. He travelled along with us till the sun shone brightly. He came down (from his camel) and led us in the morning prayer. A person, however, remained away from the people and did not say, prayer along with us. After having completed the prayer, the Messenger of Allah (ﷺ) said to him: O, so and so, what prevented you from observing prayer with us? He said: Apostle of Allah! I was not in a state of purity. The Messenger of Allah (ﷺ) ordered him arid lie performed Tayammum with dust and said prayer. He then urged me to go ahead immediately along with other riders to find out water, for we felt very thirsty. We were traveling when we came across a woman who was sitting (on a camel) with her feet hanging over two leathern water bags. We said to her: How far is water available? She, said: Far, very far, very far. You cannot get water. We (again) said: How much distance is there between (the residence of) your family and water? She said: It is a day and night journey. We said to her: You go to the Messenger of Allah (ﷺ). She said: Who is the Messenger of Allah? We somehow or the other managed to bring her to the Messenger of Allah (ﷺ) and he asked about her, and she informed him as she had informed us that she was a widow having orphan children. He ordered that her camel should be made to kneal down and he gargled in the opening (of her leathern water-bag). The camel was then raised up and we forty thirsty men drank water till we were completely satiated, and we filled up all leathern water-bags and water-skins that we had with us and we washed our companions, but we did not make any camel drink, and (the leathern water-bags) were about to burst (on account of excess of water). He then said: Bring whatever you have with you. So we collected the bits (of estable things) and dates and packed them up in a bundle, and said to her: Take it away. This is meant for your children, and know that we have not its any way done any loss to your water. W hen she came to her family she said: I have met the greatest magician amongst human beings, or he is an apostle, as he claims to be, and she then narrated what had happened and Allah guided aright those people through that woman. She affirmed her faith in Islam and so did the people embrace Islam}}
\hadithdefcmd{muslim}{1564}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا عَوْفُ بْنُ أَبِي جَمِيلَةَ الأَعْرَابِيُّ، عَنْ أَبِي رَجَاءٍ الْعُطَارِدِيِّ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَسَرَيْنَا لَيْلَةً حَتَّى إِذَا كَانَ مِنْ آخِرِ اللَّيْلِ قُبَيْلَ الصُّبْحِ وَقَعْنَا تِلْكَ الْوَقْعَةَ الَّتِي لاَ وَقْعَةَ عِنْدَ الْمُسَافِرِ أَحْلَى مِنْهَا فَمَا أَيْقَظَنَا إِلاَّ حَرُّ الشَّمْسِ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ سَلْمِ بْنِ زَرِيرٍ وَزَادَ وَنَقَصَ ‏.‏ وَقَالَ فِي الْحَدِيثِ فَلَمَّا اسْتَيْقَظَ عُمَرُ بْنُ الْخَطَّابِ وَرَأَى مَا أَصَابَ النَّاسَ وَكَانَ أَجْوَفَ جَلِيدًا فَكَبَّرَ وَرَفَعَ صَوْتَهُ بِالتَّكْبِيرِ حَتَّى اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِشِدَّةِ صَوْتِهِ بِالتَّكْبِيرِ فَلَمَّا اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَكَوْا إِلَيْهِ الَّذِي أَصَابَهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ ضَيْرَ ارْتَحِلُوا ‏"‏ ‏.‏ وَاقْتَصَّ الْحَدِيثَ ‏.‏\hadithno{1564}\hadithtrans{Imran b. Husain reported:We were with the Messenger of Allah (ﷺ) in a journey and we travelled throughout the night till at the end, just before dawn, we lay down (for rest), and nothing is sweeter for a traveller than this and none awakened us but the heat of the sun, and the rest of the hadith is the same (as mentioned above) except this additien:" When 'Umar b. Khattab woke up, he saw what had happened to the people. And he was a man having a big belly and strongly built; he recited takbir in a loud voice till the Messenger of Allah (ﷺ) woke up by the loudness of his voice in takbir. When the Messenger of Allah (ﷺ) got up, the people told him what had happened. Upon this the Messenger of Allah (ﷺ) said: There is no harm; you better proceed further," and (the rest of the hadith) was narrated}}
\hadithdefcmd{muslim}{1565}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ فِي سَفَرٍ فَعَرَّسَ بِلَيْلٍ اضْطَجَعَ عَلَى يَمِينِهِ وَإِذَا عَرَّسَ قُبَيْلَ الصُّبْحِ نَصَبَ ذِرَاعَهُ وَوَضَعَ رَأْسَهُ عَلَى كَفِّهِ ‏.‏\hadithno{1565}\hadithtrans{Abu Qatada reported that when the Messenger of Allah (ﷺ) was in a journey he got down for rest at night, and he used to lie down on his right side, and when he lay down for rest before the dawn, he used to stretch his forearm and place his head over his palm}}
\hadithdefcmd{muslim}{1566}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نَسِيَ صَلاَةً فَلْيُصَلِّهَا إِذَا ذَكَرَهَا لاَ كَفَّارَةَ لَهَا إِلاَّ ذَلِكَ ‏"‏ ‏.‏ قَالَ قَتَادَةُ وَأَقِمِ الصَّلاَةَ لِذِكْرِي ‏.‏\hadithno{1566}\hadithtrans{Qatada reported from Anas b. Malik that the Messenger of Allah (ﷺ) said:He who forgets the prayer should say it when he remembers it, there is no explation for it, except this. Qatada said: (Allah says)" And observe prayer for remembrance of Me}}
\hadithdefcmd{muslim}{1567}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، وَسَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، جَمِيعًا عَنْ أَبِي عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ ‏ "‏ لاَ كَفَّارَةَ لَهَا إِلاَّ ذَلِكَ ‏"‏ ‏.‏\hadithno{1567}\hadithtrans{This hadith has been narrated by Qatada, but here no mention has been made of" There is no explation for it except this}}
\hadithdefcmd{muslim}{1568}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَسِيَ صَلاَةً أَوْ نَامَ عَنْهَا فَكَفَّارَتُهَا أَنْ يُصَلِّيَهَا إِذَا ذَكَرَهَا ‏"‏ ‏.‏\hadithno{1568}\hadithtrans{Qatada narrated on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) said:He who forgets the prayer, or he slept (and it was omitted), its expiation is (only) that he should observe it when he remembers it}}
\hadithdefcmd{muslim}{1569}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا الْمُثَنَّى، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَقَدَ أَحَدُكُمْ عَنِ الصَّلاَةِ أَوْ غَفَلَ عَنْهَا فَلْيُصَلِّهَا إِذَا ذَكَرَهَا فَإِنَّ اللَّهَ يَقُولُ أَقِمِ الصَّلاَةَ لِذِكْرِي ‏"‏ ‏.‏\hadithno{1569}\hadithtrans{Qatada reported it on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) said:When any one of you omits the prayer due to sleep or he forgets it, he should observe it when he remembers it, for Allah has said:" Observe prayer for remembrance of Me}}
