% Auto-generated chapter 34 for bukhari
% Hadiths in this chapter: 184

\hadithdefcmd{bukhari}{2047}{حَدَّثَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ إِنَّكُمْ تَقُولُونَ إِنَّ أَبَا هُرَيْرَةَ يُكْثِرُ الْحَدِيثَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ وَتَقُولُونَ مَا بَالُ الْمُهَاجِرِينَ وَالأَنْصَارِ لاَ يُحَدِّثُونَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ أَبِي هُرَيْرَةَ وَإِنَّ إِخْوَتِي مِنَ الْمُهَاجِرِينَ كَانَ يَشْغَلُهُمْ صَفْقٌ بِالأَسْوَاقِ، وَكُنْتُ أَلْزَمُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى مِلْءِ بَطْنِي، فَأَشْهَدُ إِذَا غَابُوا وَأَحْفَظُ إِذَا نَسُوا، وَكَانَ يَشْغَلُ إِخْوَتِي مِنَ الأَنْصَارِ عَمَلُ أَمْوَالِهِمْ، وَكُنْتُ امْرَأً مِسْكِينًا مِنْ مَسَاكِينِ الصُّفَّةِ أَعِي حِينَ يَنْسَوْنَ، وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَدِيثٍ يُحَدِّثُهُ ‏ "‏ إِنَّهُ لَنْ يَبْسُطَ أَحَدٌ ثَوْبَهُ حَتَّى أَقْضِيَ مَقَالَتِي هَذِهِ، ثُمَّ يَجْمَعَ إِلَيْهِ ثَوْبَهُ إِلاَّ وَعَى مَا أَقُولُ ‏"‏‏.‏ فَبَسَطْتُ نَمِرَةً عَلَىَّ، حَتَّى إِذَا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَقَالَتَهُ جَمَعْتُهَا إِلَى صَدْرِي، فَمَا نَسِيتُ مِنْ مَقَالَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم تِلْكَ مِنْ شَىْءٍ‏.‏\hadithno{2047}\hadithtrans{Narrated Abu Huraira:You people say that Abu Huraira tells many narrations from Allah's Messenger (ﷺ) and you also wonder why the emigrants and Ansar do not narrate from Allah's Messenger (ﷺ) as Abu Huraira does. My emigrant brothers were busy in the market while I used to stick to Allah's Messenger (ﷺ) content with what fills my stomach; so I used to be present when they were absent and I used to remember when they used to forget, and my Ansari brothers used to be busy with their properties and I was one of the poor men of Suffa. I used to remember the narrations when they used to forget. No doubt, Allah's Messenger (ﷺ) once said, "Whoever spreads his garment till I have finished my present speech and then gathers it to himself, will remember whatever I will say." So, I spread my colored garment which I was wearing till Allah's Messenger (ﷺ) had finished his saying, and then I gathered it to my chest. So, I did not forget any of that narrations}}
\hadithdefcmd{bukhari}{2048}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ ـ رضى الله عنه ـ لَمَّا قَدِمْنَا الْمَدِينَةَ آخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنِي وَبَيْنَ سَعْدِ بْنِ الرَّبِيعِ فَقَالَ سَعْدُ بْنُ الرَّبِيعِ إِنِّي أَكْثَرُ الأَنْصَارِ مَالاً، فَأَقْسِمُ لَكَ نِصْفَ مَالِي، وَانْظُرْ أَىَّ زَوْجَتَىَّ هَوِيتَ نَزَلْتُ لَكَ عَنْهَا، فَإِذَا حَلَّتْ تَزَوَّجْتَهَا‏.‏ قَالَ فَقَالَ عَبْدُ الرَّحْمَنِ لاَ حَاجَةَ لِي فِي ذَلِكَ، هَلْ مِنْ سُوقٍ فِيهِ تِجَارَةٌ قَالَ سُوقُ قَيْنُقَاعَ‏.‏ قَالَ فَغَدَا إِلَيْهِ عَبْدُ الرَّحْمَنِ، فَأَتَى بِأَقِطٍ وَسَمْنٍ ـ قَالَ ـ ثُمَّ تَابَعَ الْغُدُوَّ، فَمَا لَبِثَ أَنْ جَاءَ عَبْدُ الرَّحْمَنِ عَلَيْهِ أَثَرُ صُفْرَةٍ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَزَوَّجْتَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ وَمَنْ ‏"‏‏.‏ قَالَ امْرَأَةً مِنَ الأَنْصَارِ‏.‏ قَالَ ‏"‏ كَمْ سُقْتَ ‏"‏‏.‏ قَالَ زِنَةَ نَوَاةٍ مِنْ ذَهَبٍ أَوْ نَوَاةً مِنْ ذَهَبٍ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{2048}\hadithtrans{Narrated Ibrahim bin Sa`d from his father from his grandfather:`Abdur Rahman bin `Auf said, "When we came to Medina as emigrants, Allah's Messenger (ﷺ) established a bond of brotherhood between me and Sa`d bin Ar-Rabi`. Sa`d bin Ar-Rabi` said (to me), 'I am the richest among the Ansar, so I will give you half of my wealth and you may look at my two wives and whichever of the two you may choose I will divorce her, and when she has completed the prescribed period (before marriage) you may marry her.' `Abdur-Rahman replied, "I am not in need of all that. Is there any marketplace where trade is practiced?' He replied, "The market of Qainuqa." `Abdur- Rahman went to that market the following day and brought some dried buttermilk (yogurt) and butter, and then he continued going there regularly. Few days later, `Abdur-Rahman came having traces of yellow (scent) on his body. Allah's Messenger (ﷺ) asked him whether he had got married. He replied in the affirmative. The Prophet (ﷺ) said, 'Whom have you married?' He replied, 'A woman from the Ansar.' Then the Prophet (ﷺ) asked, 'How much did you pay her?' He replied, '(I gave her) a gold piece equal in weigh to a date stone (or a date stone of gold)! The Prophet (ﷺ) said, 'Give a Walima (wedding banquet) even if with one sheep}}
\hadithdefcmd{bukhari}{2049}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَدِمَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ الْمَدِينَةَ فَآخَى النَّبِيُّ صلى الله عليه وسلم بَيْنَهُ وَبَيْنَ سَعْدِ بْنِ الرَّبِيعِ الأَنْصَارِيِّ، وَكَانَ سَعْدٌ ذَا غِنًى، فَقَالَ لِعَبْدِ الرَّحْمَنِ أُقَاسِمُكَ مَالِي نِصْفَيْنِ، وَأُزَوِّجُكَ‏.‏ قَالَ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ وَمَالِكَ، دُلُّونِي عَلَى السُّوقِ‏.‏ فَمَا رَجَعَ حَتَّى اسْتَفْضَلَ أَقِطًا وَسَمْنًا، فَأَتَى بِهِ أَهْلَ مَنْزِلِهِ، فَمَكَثْنَا يَسِيرًا ـ أَوْ مَا شَاءَ اللَّهُ ـ فَجَاءَ وَعَلَيْهِ وَضَرٌ مِنْ صُفْرَةٍ، فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَهْيَمْ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ‏.‏ قَالَ ‏"‏ مَا سُقْتَ إِلَيْهَا ‏"‏‏.‏ قَالَ نَوَاةً مِنْ ذَهَبٍ، أَوْ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ‏.‏ قَالَ ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{2049}\hadithtrans{Narrated Anas:When `Abdur-Rahman bin `Auf came to Medina, the Prophet (ﷺ) established a bond of brotherhood between him and Sa`d bin Ar-Rabi al-Ansari. Sa`d was a rich man, so he said to `Abdur-Rahman, "I will give you half of my property and will help you marry." `Abdur-Rahman said (to him), "May Allah bless you in your family and property. Show me the market." So `Abdur-Rahman did not return from the market) till he gained some dried buttermilk (yogurt) and butter (through trading). He brought that to his house-hold. We stayed for sometime (or as long as Allah wished), and then `Abdur-Rahman came, scented with yellowish perfume. The Prophet (ﷺ) said (to him) "What is this?" He replied, "I got married to an Ansari woman." The Prophet (ﷺ) asked, "What did you pay her?" He replied, "A gold stone or gold equal to the weight of a date stone." The Prophet (ﷺ) said (to him), "Give a wedding banquet even if with one sheep}}
\hadithdefcmd{bukhari}{2050}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَتْ عُكَاظٌ وَمِجَنَّةُ وَذُو الْمَجَازِ أَسْوَاقًا فِي الْجَاهِلِيَّةِ، فَلَمَّا كَانَ الإِسْلاَمُ فَكَأَنَّهُمْ تَأَثَّمُوا فِيهِ فَنَزَلَتْ ‏\{‏لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَبْتَغُوا فَضْلاً مِنْ رَبِّكُمْ ‏\}‏ فِي مَوَاسِمِ الْحَجِّ، قَرَأَهَا ابْنُ عَبَّاسٍ‏.‏\hadithno{2050}\hadithtrans{Narrated Ibn `Abbas:`Ukaz, Majanna and Dhul-Majaz were marketplaces in the Pre-Islamic period of ignorance. When Islam came, Muslims felt that marketing there might be a sin. So, the Divine Inspiration came: "There is no harm for you to seek the bounty of your Lord (in the seasons of Hajj)." (2.198) Ibn `Abbas recited the Verse in this way}}
\hadithdefcmd{bukhari}{2051}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنِ الشَّعْبِيِّ، سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ ـ رضى الله عنه ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ أَبِي فَرْوَةَ، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ النُّعْمَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ أَبِي فَرْوَةَ، سَمِعْتُ الشَّعْبِيَّ، سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي فَرْوَةَ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْحَلاَلُ بَيِّنٌ، وَالْحَرَامُ بَيِّنٌ وَبَيْنَهُمَا أُمُورٌ مُشْتَبِهَةٌ، فَمَنْ تَرَكَ مَا شُبِّهَ عَلَيْهِ مِنَ الإِثْمِ كَانَ لِمَا اسْتَبَانَ أَتْرَكَ، وَمَنِ اجْتَرَأَ عَلَى مَا يَشُكُّ فِيهِ مِنَ الإِثْمِ أَوْشَكَ أَنْ يُوَاقِعَ مَا اسْتَبَانَ، وَالْمَعَاصِي حِمَى اللَّهِ، مَنْ يَرْتَعْ حَوْلَ الْحِمَى يُوشِكْ أَنْ يُوَاقِعَهُ ‏"‏‏.‏\hadithno{2051}\hadithtrans{Narrated An-Nu`man bin Bashir:The Prophet (ﷺ) said "Both legal and illegal things are obvious, and in between them are (suspicious) doubtful matters. So whoever forsakes those doubtful things lest he may commit a sin, will definitely avoid what is clearly illegal; and whoever indulges in these (suspicious) doubtful things bravely, is likely to commit what is clearly illegal. Sins are Allah's Hima (i.e. private pasture) and whoever pastures (his sheep) near it, is likely to get in it at any moment}}
\hadithdefcmd{bukhari}{2052}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ ـ رضى الله عنه ـ أَنَّ امْرَأَةً، سَوْدَاءَ جَاءَتْ، فَزَعَمَتْ أَنَّهَا أَرْضَعَتْهُمَا، فَذَكَرَ لِلنَّبِيِّ فَأَعْرَضَ عَنْهُ، وَتَبَسَّمَ النَّبِيُّ صلى الله عليه وسلم‏.‏ قَالَ ‏ "‏ كَيْفَ وَقَدْ قِيلَ ‏"‏‏.‏ وَقَدْ كَانَتْ تَحْتَهُ ابْنَةُ أَبِي إِهَابٍ التَّمِيمِيِّ‏.‏\hadithno{2052}\hadithtrans{Narrated `Abdullah bin Abu Mulaika:`Uqba bin Al-Harith said that a black woman came and claimed that she had suckled both of them (i.e. `Uqba and his wife). So, he mentioned that to the Prophet (ﷺ) who turned his face from him and smiled and said, "How (can you keep your wife), and it was said (that both of you were suckled by the same woman)?" His wife was the daughter of Abu Ihab-al-Tamimi}}
\hadithdefcmd{bukhari}{2053}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ عُتْبَةُ بْنُ أَبِي وَقَّاصٍ عَهِدَ إِلَى أَخِيهِ سَعْدِ بْنِ أَبِي وَقَّاصٍ أَنَّ ابْنَ وَلِيدَةِ زَمْعَةَ مِنِّي فَاقْبِضْهُ‏.‏ قَالَتْ فَلَمَّا كَانَ عَامَ الْفَتْحِ أَخَذَهُ سَعْدُ بْنُ أَبِي وَقَّاصٍ وَقَالَ ابْنُ أَخِي، قَدْ عَهِدَ إِلَىَّ فِيهِ‏.‏ فَقَامَ عَبْدُ بْنُ زَمْعَةَ، فَقَالَ أَخِي، وَابْنُ وَلِيدَةِ أَبِي، وُلِدَ عَلَى فِرَاشِهِ‏.‏ فَتَسَاوَقَا إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏ فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ، ابْنُ أَخِي، كَانَ قَدْ عَهِدَ إِلَىَّ فِيهِ‏.‏ فَقَالَ عَبْدُ بْنُ زَمْعَةَ أَخِي وَابْنُ وَلِيدَةِ أَبِي، وُلِدَ عَلَى فِرَاشِهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ لَكَ يَا عَبْدُ بْنَ زَمْعَةَ ‏"‏‏.‏ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْوَلَدُ لِلْفِرَاشِ، وَلِلْعَاهِرِ الْحَجَرُ ‏"‏‏.‏ ثُمَّ قَالَ لِسَوْدَةَ بِنْتِ زَمْعَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ احْتَجِبِي مِنْهُ ‏"‏‏.‏ لِمَا رَأَى مِنْ شَبَهِهِ بِعُتْبَةَ، فَمَا رَآهَا حَتَّى لَقِيَ اللَّهَ‏.‏\hadithno{2053}\hadithtrans{Narrated Aisha:`Utba bin Abu Waqqas took a firm promise from his brother Sa`d bin Abu Waqqas to take the son of the slave-girl of Zam`a into his custody as he was his (i.e. `Utba's) son. In the year of the Conquest (of Mecca) Sa`d bin Abu Waqqas took him, and said that he was his brother's son, and his brother took a promise from him to that effect. 'Abu bin Zam`a got up and said, "He is my brother and the son of the slave-girl of my father and was born on my father's bed." Then they both went to the Prophet (ﷺ) Sa`d said, "O Allah's Messenger (ﷺ)! He is the son of my brother and he has taken a promise from me that I will take him." 'Abu bin Zam`a said, "(He is) my brother and the son of my father's slave-girl and was born on my father's bed." Allah's Messenger (ﷺ) said, "The boy is for you. O 'Abu bin Zam`a." Then the Prophet (ﷺ) said, "The son is for the bed (i.e. the man on whose bed he was born) and stones (disappointment and deprivation) for the one who has done illegal sexual intercourse." The Prophet (ﷺ) told his wife Sauda bint Zam`a to screen herself from that boy as he noticed a similarity between the boy and `Utba. So, the boy did not see her till he died}}
\hadithdefcmd{bukhari}{2054}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ ـ رضى الله عنه ـ قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنِ الْمِعْرَاضِ فَقَالَ ‏"‏ إِذَا أَصَابَ بِحَدِّهِ فَكُلْ، وَإِذَا أَصَابَ بِعَرْضِهِ فَلاَ تَأْكُلْ، فَإِنَّهُ وَقِيذٌ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أُرْسِلُ كَلْبِي وَأُسَمِّي، فَأَجِدُ مَعَهُ عَلَى الصَّيْدِ كَلْبًا آخَرَ لَمْ أُسَمِّ عَلَيْهِ، وَلاَ أَدْرِي أَيُّهُمَا أَخَذَ‏.‏ قَالَ ‏"‏ لاَ تَأْكُلْ، إِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى الآخَرِ ‏"‏‏.‏\hadithno{2054}\hadithtrans{Narrated `Adi bin Hatim:I asked Allah's Messenger (ﷺ) about Al Mirad (i.e. a sharp-edged piece of wood or a piece of wood provided with a piece of iron used for hunting). He replied, "If the game is hit by its sharp edge, eat it, and if it is hit by its broad side, do not eat it, for it has been beaten to death." I asked, "O Allah's Messenger (ﷺ)! I release my dog by the name of Allah and find with it at the game, another dog on which I have not mentioned the name of Allah, and I do not know which one of them caught the game." Allah's Messenger (ﷺ) said (to him), 'Don't eat it as you have mentioned the name of Allah on your dog and not on the other dog}}
\hadithdefcmd{bukhari}{2055}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ طَلْحَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِتَمْرَةٍ مَسْقُوطَةٍ فَقَالَ ‏"‏ لَوْلاَ أَنْ تَكُونَ صَدَقَةً لأَكَلْتُهَا ‏"‏‏.‏ وَقَالَ هَمَّامٌ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَجِدُ تَمْرَةً سَاقِطَةً عَلَى فِرَاشِي ‏"‏‏.‏\hadithno{2055}\hadithtrans{Narrated Anas:The Prophet (ﷺ) passed by a fallen date and said, "Were it not for my doubt that this might have been given in charity, I would have eaten it." And narrated Abu Huraira the Prophet (ﷺ) said, "I found a datefruit fallen on my bed}}
\hadithdefcmd{bukhari}{2056}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ شُكِيَ إِلَى النَّبِيِّ صلى الله عليه وسلم الرَّجُلُ يَجِدُ فِي الصَّلاَةِ شَيْئًا، أَيَقْطَعُ الصَّلاَةَ قَالَ ‏ "‏ لاَ، حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏‏.‏ وَقَالَ ابْنُ أَبِي حَفْصَةَ عَنِ الزُّهْرِيِّ لاَ وُضُوءَ إِلاَّ فِيمَا وَجَدْتَ الرِّيحَ أَوْ سَمِعْتَ الصَّوْتَ‏.‏\hadithno{2056}\hadithtrans{Narrated `Abbas bin Tamim:that his uncle said: "The Prophet (ﷺ) was asked: If a person feels something during his prayer; should one interrupt his prayer?" The Prophet (ﷺ) said: No! You should not give it up unless you hear a sound or smell something." Narrated Ibn Abi Hafsa: Az-Zuhri said, "There is no need of repeating ablution unless you detect a smell or hear a sound}}
\hadithdefcmd{bukhari}{2057}{حَدَّثَنِي أَحْمَدُ بْنُ الْمِقْدَامِ الْعِجْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الطُّفَاوِيُّ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ،، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ قَوْمًا، قَالُوا يَا رَسُولَ اللَّهِ، إِنَّ قَوْمًا يَأْتُونَنَا بِاللَّحْمِ لاَ نَدْرِي أَذَكَرُوا اسْمَ اللَّهِ عَلَيْهِ أَمْ لاَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَمُّوا اللَّهَ عَلَيْهِ وَكُلُوهُ ‏"‏‏.‏\hadithno{2057}\hadithtrans{Narrated `Aisha:Some people said, "O Allah's Messenger (ﷺ)! Meat is brought to us by some people and we are not sure whether the name of Allah has been mentioned on it or not (at the time of slaughtering the animals)." Allah's Messenger (ﷺ) said (to them), "Mention the name of Allah and eat it}}
\hadithdefcmd{bukhari}{2058}{حَدَّثَنَا طَلْقُ بْنُ غَنَّامٍ، حَدَّثَنَا زَائِدَةُ، عَنْ حُصَيْنٍ، عَنْ سَالِمٍ، قَالَ حَدَّثَنِي جَابِرٌ ـ رضى الله عنه ـ قَالَ بَيْنَمَا نَحْنُ نُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم إِذْ أَقْبَلَتْ مِنَ الشَّأْمِ عِيرٌ، تَحْمِلُ طَعَامًا، فَالْتَفَتُوا إِلَيْهَا، حَتَّى مَا بَقِيَ مَعَ النَّبِيِّ صلى الله عليه وسلم إِلاَّ اثْنَا عَشَرَ رَجُلاً فَنَزَلَتْ ‏\{‏وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا‏\}‏\hadithno{2058}\hadithtrans{Narrated Jabir:While we were offering the prayer with the Prophet (ﷺ) a caravan carrying food came from Sham. The people looked towards the caravan (and went to it) and only twelve persons remained with the Prophet. So, the Divine Inspiration came; "But when they see some bargain or some amusement, they disperse headlong to it}}
\hadithdefcmd{bukhari}{2059}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ، لاَ يُبَالِي الْمَرْءُ مَا أَخَذَ مِنْهُ أَمِنَ الْحَلاَلِ أَمْ مِنَ الْحَرَامِ ‏"‏‏.‏\hadithno{2059}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A time will come when one will not care how one gains one's money, legally or illegally}}
\hadithdefcmd{bukhari}{2061}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ أَبِي الْمِنْهَالِ، قَالَ كُنْتُ أَتَّجِرُ فِي الصَّرْفِ، فَسَأَلْتُ زَيْدَ بْنَ أَرْقَمَ ـ رضى الله عنه ـ فَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنِي الْفَضْلُ بْنُ يَعْقُوبَ، حَدَّثَنَا الْحَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، وَعَامِرُ بْنُ مُصْعَبٍ، أَنَّهُمَا سَمِعَا أَبَا الْمِنْهَالِ، يَقُولُ سَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ وَزَيْدَ بْنَ أَرْقَمَ عَنِ الصَّرْفِ، فَقَالاَ كُنَّا تَاجِرَيْنِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّرْفِ فَقَالَ ‏ "‏ إِنْ كَانَ يَدًا بِيَدٍ فَلاَ بَأْسَ، وَإِنْ كَانَ نَسَاءً فَلاَ يَصْلُحُ ‏"‏‏.‏\hadithno{2061}\hadithtrans{Narrated Abu Al-Minhal:I used to practice money exchange, and I asked Zaid bin 'Arqam about it, and he narrated what the Prophet said in the following: Abu Al-Minhal said, "I asked Al-Bara' bin `Azib and Zaid bin Arqam about practicing money exchange. They replied, 'We were traders in the time of Allah's Messenger (ﷺ) and I asked Allah's Messenger (ﷺ) about money exchange. He replied, 'If it is from hand to hand, there is no harm in it; otherwise it is not permissible}}
\hadithdefcmd{bukhari}{2062}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا مَخْلَدُ بْنُ يَزِيدَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، أَنَّ أَبَا مُوسَى الأَشْعَرِيَّ، اسْتَأْذَنَ عَلَى عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ فَلَمْ يُؤْذَنْ لَهُ، وَكَأَنَّهُ كَانَ مَشْغُولاً فَرَجَعَ أَبُو مُوسَى، فَفَرَغَ عُمَرُ فَقَالَ أَلَمْ أَسْمَعْ صَوْتَ عَبْدِ اللَّهِ بْنِ قَيْسٍ ائْذَنُوا لَهُ قِيلَ قَدْ رَجَعَ‏.‏ فَدَعَاهُ‏.‏ فَقَالَ كُنَّا نُؤْمَرُ بِذَلِكَ‏.‏ فَقَالَ تَأْتِينِي عَلَى ذَلِكَ بِالْبَيِّنَةِ‏.‏ فَانْطَلَقَ إِلَى مَجْلِسِ الأَنْصَارِ، فَسَأَلَهُمْ‏.‏ فَقَالُوا لاَ يَشْهَدُ لَكَ عَلَى هَذَا إِلاَّ أَصْغَرُنَا أَبُو سَعِيدٍ الْخُدْرِيُّ‏.‏ فَذَهَبَ بِأَبِي سَعِيدٍ الْخُدْرِيِّ‏.‏ فَقَالَ عُمَرُ أَخَفِيَ عَلَىَّ مِنْ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَلْهَانِي الصَّفْقُ بِالأَسْوَاقِ‏.‏ يَعْنِي الْخُرُوجَ إِلَى تِجَارَةٍ‏.‏\hadithno{2062}\hadithtrans{Narrated 'Ubaid bin `Umair:Abu Musa asked `Umar to admit him but he was not admitted as `Umar was busy, so Abu Musa went back. When `Umar finished his job he said, "Didn't I hear the voice of `Abdullah bin Qais? Let him come in." `Umar was told that he had left. So, he sent for him and on his arrival, he (Abu Musa) said, "We were ordered to do so (i.e. to leave if not admitted after asking permission thrice). `Umar told him, "Bring witness in proof of your statement." Abu Musa went to the Ansar's meeting places and asked them. They said, "None amongst us will give this witness except the youngest of us, Abu Sa`id Al-Khudri. Abu Musa then took Abu Sa`id Al-Khudri (to `Umar) and `Umar said, surprisingly, "Has this order of Allah's Messenger (ﷺ) been hidden from me?" (Then he added), "I used to be busy trading in markets}}
\hadithdefcmd{bukhari}{2063}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ ذَكَرَ رَجُلاً مِنْ بَنِي إِسْرَائِيلَ، خَرَجَ فِي الْبَحْرِ فَقَضَى حَاجَتَهُ‏.‏ وَسَاقَ الْحَدِيثَ‏.‏ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ صَالِحٍ قَالَ حَدَّثَنِي اللَّيْثُ بِهَذَا‏.‏\hadithno{2063}\hadithtrans{Abu Hurairah (ra) said, "Allah's Messenger (ﷺ) mentioned a person from Bani Israel who travelled by sea and carried out his needs." Then he narrated the whole story. (See Hadith no)}}
\hadithdefcmd{bukhari}{2064}{حَدَّثَنِي مُحَمَّدٌ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حُصَيْنٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ أَقْبَلَتْ عِيرٌ، وَنَحْنُ نُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم الْجُمُعَةَ، فَانْفَضَّ النَّاسُ إِلاَّ اثْنَىْ عَشَرَ رَجُلاً، فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا وَتَرَكُوكَ قَائِمًا ‏\}‏\hadithno{2064}\hadithtrans{Narrated Jabir:A caravan arrived (at Medina) while we were offering the Jumua prayer with the Prophet. The people left out for the caravan, with the exception of twelve persons. Then this Verse was revealed: 'But when they see some bargain or some amusement, they disperse headlong to it and leave you standing}}
\hadithdefcmd{bukhari}{2065}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ طَعَامِ بَيْتِهَا، غَيْرَ مُفْسِدَةٍ، كَانَ لَهَا أَجْرُهَا بِمَا أَنْفَقَتْ، وَلِزَوْجِهَا بِمَا كَسَبَ، وَلِلْخَازِنِ مِثْلُ ذَلِكَ، لاَ يَنْقُصُ بَعْضُهُمْ أَجْرَ بَعْضٍ شَيْئًا ‏"‏‏.‏\hadithno{2065}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "If a woman gives in charity from her house meals without wasting (i.e. being extravagant), she will get the reward for her giving, and her husband will also get the reward for his earning and the storekeeper will also get a similar reward. The acquisition of the reward of none of them will reduce the reward of the others}}
\hadithdefcmd{bukhari}{2066}{حَدَّثَنِي يَحْيَى بْنُ جَعْفَرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ كَسْبِ زَوْجِهَا عَنْ غَيْرِ أَمْرِهِ، فَلَهُ نِصْفُ أَجْرِهِ ‏"‏‏.‏\hadithno{2066}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If a woman gives something (i.e. in charity) from her husband's earnings without his permission, she will get half his reward}}
\hadithdefcmd{bukhari}{2067}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي يَعْقُوبَ الْكِرْمَانِيُّ، حَدَّثَنَا حَسَّانُ، حَدَّثَنَا يُونُسُ، حَدَّثَنَا مُحَمَّدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ سَرَّهُ أَنْ يُبْسَطَ لَهُ رِزْقُهُ أَوْ يُنْسَأَ لَهُ فِي أَثَرِهِ فَلْيَصِلْ رَحِمَهُ ‏"‏‏.‏\hadithno{2067}\hadithtrans{Narrated Anas bin Malik:I heard Allah's Messenger (ﷺ) saying, "whoever desires an expansion in his sustenance and age, should keep good relations with his Kith and kin}}
\hadithdefcmd{bukhari}{2068}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، قَالَ ذَكَرْنَا عِنْدَ إِبْرَاهِيمَ الرَّهْنَ فِي السَّلَمِ فَقَالَ حَدَّثَنِي الأَسْوَدُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم اشْتَرَى طَعَامًا مِنْ يَهُودِيٍّ إِلَى أَجَلٍ، وَرَهَنَهُ دِرْعًا مِنْ حَدِيدٍ‏.‏\hadithno{2068}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) purchased food grains from a Jew on credit and mortgaged his iron armor to him}}
\hadithdefcmd{bukhari}{2069}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، ح‏.‏ حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ، حَدَّثَنَا أَسْبَاطٌ أَبُو الْيَسَعِ الْبَصْرِيُّ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّهُ مَشَى إِلَى النَّبِيِّ صلى الله عليه وسلم بِخُبْزِ شَعِيرٍ، وَإِهَالَةٍ سَنِخَةٍ، وَلَقَدْ رَهَنَ النَّبِيُّ صلى الله عليه وسلم دِرْعًا لَهُ بِالْمَدِينَةِ عِنْدَ يَهُودِيٍّ، وَأَخَذَ مِنْهُ شَعِيرًا لأَهْلِهِ، وَلَقَدْ سَمِعْتُهُ يَقُولُ ‏ "‏ مَا أَمْسَى عِنْدَ آلِ مُحَمَّدٍ صلى الله عليه وسلم صَاعُ بُرٍّ وَلاَ صَاعُ حَبٍّ، وَإِنَّ عِنْدَهُ لَتِسْعَ نِسْوَةٍ ‏"‏‏.‏\hadithno{2069}\hadithtrans{Narrated Qatada:Anas went to the Prophet (ﷺ) with barley bread having some dissolved fat on it. The Prophet (ﷺ) had mortgaged his armor to a Jew in Medina and took from him some barley for his family. Anas heard him saying, "The household of Muhammad did not possess even a single Sa of wheat or food grains for the evening meal, although he has nine wives to look after." (See Hadith No)}}
\hadithdefcmd{bukhari}{2070}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا اسْتُخْلِفَ أَبُو بَكْرٍ الصِّدِّيقُ قَالَ لَقَدْ عَلِمَ قَوْمِي أَنَّ حِرْفَتِي لَمْ تَكُنْ تَعْجِزُ عَنْ مَئُونَةِ أَهْلِي، وَشُغِلْتُ بِأَمْرِ الْمُسْلِمِينَ، فَسَيَأْكُلُ آلُ أَبِي بَكْرٍ مِنْ هَذَا الْمَالِ وَيَحْتَرِفُ لِلْمُسْلِمِينَ فِيهِ‏.‏\hadithno{2070}\hadithtrans{Narrated `Aisha:When Abu Bakr As-Siddiq was chosen Caliph, he said, "My people know that my profession was not incapable of providing substance to my family. And as I will be busy serving the Muslim nation, my family will eat from the National Treasury of Muslims, and I will practice the profession of serving the Muslims}}
\hadithdefcmd{bukhari}{2071}{حَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنِي أَبُو الأَسْوَدِ، عَنْ عُرْوَةَ، قَالَ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ كَانَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم عُمَّالَ أَنْفُسِهِمْ، وَكَانَ يَكُونُ لَهُمْ أَرْوَاحٌ فَقِيلَ لَهُمْ لَوِ اغْتَسَلْتُمْ‏.‏ رَوَاهُ هَمَّامٌ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ عَائِشَةَ‏.‏\hadithno{2071}\hadithtrans{Narrated Aisha:The companions of Allah's Messenger (ﷺ) used to practice manual labor, so their sweat used to smell, and they were advised to take a bath}}
\hadithdefcmd{bukhari}{2072}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، عَنْ ثَوْرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَكَلَ أَحَدٌ طَعَامًا قَطُّ خَيْرًا مِنْ أَنْ يَأْكُلَ مِنْ عَمَلِ يَدِهِ، وَإِنَّ نَبِيَّ اللَّهِ دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ كَانَ يَأْكُلُ مِنْ عَمَلِ يَدِهِ ‏"‏‏.‏\hadithno{2072}\hadithtrans{Narrated Al-Miqdam:The Prophet (ﷺ) said, "Nobody has ever eaten a better meal than that which one has earned by working with one's own hands. The Prophet of Allah, David (ﷺ) used to eat from the earnings of his manual labor}}
\hadithdefcmd{bukhari}{2073}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّ دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ كَانَ لاَ يَأْكُلُ إِلاَّ مِنْ عَمَلِ يَدِهِ ‏"‏‏.‏\hadithno{2073}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Prophet David (ﷺ) used not to eat except from the earnings of his manual labor}}
\hadithdefcmd{bukhari}{2074}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَحْتَطِبَ أَحَدُكُمْ حُزْمَةً عَلَى ظَهْرِهِ خَيْرٌ مِنْ أَنْ يَسْأَلَ أَحَدًا، فَيُعْطِيَهُ أَوْ يَمْنَعَهُ ‏"‏‏.‏\hadithno{2074}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "No doubt, it is better for any one of you to cut a bundle of wood and carry it over his back rather than to ask someone who may or may not give him}}
\hadithdefcmd{bukhari}{2075}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لأَنْ يَأْخُذَ أَحَدُكُمْ أَحْبُلَهُ خَيْرٌ لَهُ مِنْ أَنْ يَسْأَلَ النَّاسَ ‏"‏‏.‏\hadithno{2075}\hadithtrans{Narrated Az-Zubair bin Al-Awwam:The Prophet (ﷺ) said, "One would rather take a rope and cut wood and carry it than ask others}}
\hadithdefcmd{bukhari}{2076}{حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو غَسَّانَ، مُحَمَّدُ بْنُ مُطَرِّفٍ قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رَحِمَ اللَّهُ رَجُلاً سَمْحًا إِذَا بَاعَ، وَإِذَا اشْتَرَى، وَإِذَا اقْتَضَى ‏"‏‏.‏\hadithno{2076}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "May Allah's mercy be on him who is lenient in his buying, selling, and in demanding back his money}}
\hadithdefcmd{bukhari}{2077}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مَنْصُورٌ، أَنَّ رِبْعِيَّ بْنَ حِرَاشٍ، حَدَّثَهُ أَنَّ حُذَيْفَةَ ـ رضى الله عنه ـ حَدَّثَهُ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَلَقَّتِ الْمَلاَئِكَةُ رُوحَ رَجُلٍ مِمَّنْ كَانَ قَبْلَكُمْ قَالُوا أَعَمِلْتَ مِنَ الْخَيْرِ شَيْئًا قَالَ كُنْتُ آمُرُ فِتْيَانِي أَنْ يُنْظِرُوا وَيَتَجَاوَزُوا عَنِ الْمُوسِرِ قَالَ قَالَ فَتَجَاوَزُوا عَنْهُ ‏"‏‏.‏ وَقَالَ أَبُو مَالِكٍ عَنْ رِبْعِيٍّ ‏"‏ كُنْتُ أُيَسِّرُ عَلَى الْمُوسِرِ وَأُنْظِرُ الْمُعْسِرَ ‏"‏‏.‏ وَتَابَعَهُ شُعْبَةُ عَنْ عَبْدِ الْمَلِكِ عَنْ رِبْعِيٍّ‏.‏ وَقَالَ أَبُو عَوَانَةَ عَنْ عَبْدِ الْمَلِكِ عَنْ رِبْعِيٍّ ‏"‏ أُنْظِرُ الْمُوسِرَ، وَأَتَجَاوَزُ عَنِ الْمُعْسِرِ ‏"‏‏.‏ وَقَالَ نُعَيْمُ بْنُ أَبِي هِنْدٍ عَنْ رِبْعِيٍّ ‏"‏ فَأَقْبَلُ مِنَ الْمُوسِرِ، وَأَتَجَاوَزُ عَنِ الْمُعْسِرِ ‏"‏‏.‏\hadithno{2077}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) said, "Before your time the angels received the soul of a man and asked him, 'Did you do any good deeds (in your life)?' He replied, 'I used to order my employees to grant time to the rich person to pay his debts at his convenience.' So Allah said to the angels; "Excuse him." Rabi said that (the dead man said), 'I used to be easy to the rich and grant time to the poor.' Or, in another narration, 'grant time to the well-off and forgive the needy,' or, 'accept from the well-off and forgive the needy}}
\hadithdefcmd{bukhari}{2078}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ تَاجِرٌ يُدَايِنُ النَّاسَ، فَإِذَا رَأَى مُعْسِرًا قَالَ لِفِتْيَانِهِ تَجَاوَزُوا عَنْهُ، لَعَلَّ اللَّهَ أَنْ يَتَجَاوَزَ عَنَّا، فَتَجَاوَزَ اللَّهُ عَنْهُ ‏"‏‏.‏\hadithno{2078}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There was a merchant who used to lend the people, and whenever his debtor was in straitened circumstances, he would say to his employees, 'Forgive him so that Allah may forgive us.' So, Allah forgave him}}
\hadithdefcmd{bukhari}{2079}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، رَفَعَهُ إِلَى حَكِيمِ بْنِ حِزَامٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا ـ أَوْ قَالَ حَتَّى يَتَفَرَّقَا ـ فَإِنْ صَدَقَا وَبَيَّنَا بُورِكَ لَهُمَا فِي بَيْعِهِمَا، وَإِنْ كَتَمَا وَكَذَبَا مُحِقَتْ بَرَكَةُ بَيْعِهِمَا ‏"‏‏.‏\hadithno{2079}\hadithtrans{Narrated Hakim bin Hizam:Allah's Messenger (ﷺ) said, "The seller and the buyer have the right to keep or return goods as long as they have not parted or till they part; and if both the parties spoke the truth and described the defects and qualities (of the goods), then they would be blessed in their transaction, and if they told lies or hid something, then the blessings of their transaction would be lost}}
\hadithdefcmd{bukhari}{2080}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ كُنَّا نُرْزَقُ تَمْرَ الْجَمْعِ، وَهْوَ الْخِلْطُ مِنَ التَّمْرِ، وَكُنَّا نَبِيعُ صَاعَيْنِ بِصَاعٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ صَاعَيْنِ بِصَاعٍ، وَلاَ دِرْهَمَيْنِ بِدِرْهَمٍ ‏"‏‏.‏\hadithno{2080}\hadithtrans{Narrated Abu Sa`id:We used to be given mixed dates (from the booty) and used to sell (barter) two Sas of those dates) for one Sa (of good dates). The Prophet (ﷺ) said (to us), "No (bartering of) two Sas for one Sa nor two Dirhams for one Dirham is permissible", (as that is a kind of usury). (See Hadith No)}}
\hadithdefcmd{bukhari}{2081}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي شَقِيقٌ، عَنْ أَبِي مَسْعُودٍ، قَالَ جَاءَ رَجُلٌ مِنَ الأَنْصَارِ يُكْنَى أَبَا شُعَيْبٍ فَقَالَ لِغُلاَمٍ لَهُ قَصَّابٍ اجْعَلْ لِي طَعَامًا يَكْفِي خَمْسَةً، فَإِنِّي أُرِيدُ أَنْ أَدْعُوَ النَّبِيَّ صلى الله عليه وسلم خَامِسَ خَمْسَةٍ، فَإِنِّي قَدْ عَرَفْتُ فِي وَجْهِهِ الْجُوعَ‏.‏ فَدَعَاهُمْ، فَجَاءَ مَعَهُمْ رَجُلٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذَا قَدْ تَبِعَنَا، فَإِنْ شِئْتَ أَنْ تَأْذَنَ لَهُ فَأْذَنْ لَهُ، وَإِنْ شِئْتَ أَنْ يَرْجِعَ رَجَعَ ‏"‏‏.‏ فَقَالَ لاَ، بَلْ قَدْ أَذِنْتُ لَهُ‏.‏\hadithno{2081}\hadithtrans{Narrated Abu Mas`ud:An Ansari man, called Abu Shu'aib, came and told his butcher slave, "Prepare meals sufficient for five persons, for I want to invite the Prophet (ﷺ) along with four other persons as I saw signs of hunger on his face." Abu Shu'aib invited them and another person came along with them. The Prophet (ﷺ) said (to Abu Shu'aib), This man followed us, so if you allow him, he will join us, and if you want him to return, he will go back." Abu Shu'aib said, "No, I have allowed him (i.e. he, too, is welcomed to the meal)}}
\hadithdefcmd{bukhari}{2082}{حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا الْخَلِيلِ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حِزَامٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا ـ أَوْ قَالَ حَتَّى يَتَفَرَّقَا ـ فَإِنْ صَدَقَا وَبَيَّنَا بُورِكَ لَهُمَا فِي بَيْعِهِمَا، وَإِنْ كَتَمَا وَكَذَبَا مُحِقَتْ بَرَكَةُ بَيْعِهِمَا ‏"‏‏.‏\hadithno{2082}\hadithtrans{Narrated Hakim bin Hizam:The Prophet (ﷺ) said, "The buyer and the seller have the option to cancel or to confirm the deal, as long as they have not parted or till they part, and if they spoke the truth and told each other the defects of the things, then blessings would be in their deal, and if they hid something and told lies, the blessing of the deal would be lost}}
\hadithdefcmd{bukhari}{2083}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَأْتِيَنَّ عَلَى النَّاسِ زَمَانٌ لاَ يُبَالِي الْمَرْءُ بِمَا أَخَذَ الْمَالَ، أَمِنْ حَلاَلٍ أَمْ مِنْ حَرَامٍ ‏"‏‏.‏\hadithno{2083}\hadithtrans{Narrated Abu Hurairah (ra):The Prophet (ﷺ) said "Certainly a time will come when people will not bother to know from where they earned the money, by lawful means or unlawful means." (See Hadith no)}}
\hadithdefcmd{bukhari}{2084}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا نَزَلَتْ آخِرُ الْبَقَرَةِ قَرَأَهُنَّ النَّبِيُّ صلى الله عليه وسلم عَلَيْهِمْ فِي الْمَسْجِدِ، ثُمَّ حَرَّمَ التِّجَارَةَ فِي الْخَمْرِ‏.‏\hadithno{2084}\hadithtrans{Narrated Aisha:When the last Verses of Surat al- Baqara were revealed, the Prophet (ﷺ) recited them in the mosque and proclaimed the trade of alcohol as illegal}}
\hadithdefcmd{bukhari}{2085}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ اللَّيْلَةَ رَجُلَيْنِ أَتَيَانِي، فَأَخْرَجَانِي إِلَى أَرْضٍ مُقَدَّسَةٍ، فَانْطَلَقْنَا حَتَّى أَتَيْنَا عَلَى نَهَرٍ مِنْ دَمٍ فِيهِ رَجُلٌ قَائِمٌ، وَعَلَى وَسَطِ النَّهْرِ رَجُلٌ بَيْنَ يَدَيْهِ حِجَارَةٌ، فَأَقْبَلَ الرَّجُلُ الَّذِي فِي النَّهَرِ فَإِذَا أَرَادَ الرَّجُلُ أَنْ يَخْرُجَ رَمَى الرَّجُلُ بِحَجَرٍ فِي فِيهِ فَرَدَّهُ حَيْثُ كَانَ، فَجَعَلَ كُلَّمَا جَاءَ لِيَخْرُجَ رَمَى فِي فِيهِ بِحَجَرٍ، فَيَرْجِعُ كَمَا كَانَ، فَقُلْتُ مَا هَذَا فَقَالَ الَّذِي رَأَيْتَهُ فِي النَّهَرِ آكِلُ الرِّبَا ‏"‏‏.‏\hadithno{2085}\hadithtrans{Narrated Samura bin Jundab:The Prophet (ﷺ) said, "This night I dreamt that two men came and took me to a Holy land whence we proceeded on till we reached a river of blood, where a man was standing, and on its bank was standing another man with stones in his hands. The man in the middle of the river tried to come out, but the other threw a stone in his mouth and forced him to go back to his original place. So, whenever he tried to come out, the other man would throw a stone in his mouth and force him to go back to his former place. I asked, 'Who is this?' I was told, 'The person in the river was a Riba-eater}}
\hadithdefcmd{bukhari}{2086}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، قَالَ رَأَيْتُ أَبِي اشْتَرَى عَبْدًا حَجَّامًا، فَسَأَلْتُهُ فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ، وَثَمَنِ الدَّمِ، وَنَهَى عَنِ الْوَاشِمَةِ وَالْمَوْشُومَةِ، وَآكِلِ الرِّبَا، وَمُوكِلِهِ، وَلَعَنَ الْمُصَوِّرَ‏.‏\hadithno{2086}\hadithtrans{Narrated `Aun bin Abu Juhaifa:My father bought a slave who practiced the profession of cupping. (My father broke the slave's instruments of cupping). I asked my father why he had done so. He replied, "The Prophet (ﷺ) forbade the acceptance of the price of a dog or blood, and also forbade the profession of tattooing, getting tattooed and receiving or giving Riba, (usury), and cursed the picture-makers}}
\hadithdefcmd{bukhari}{2087}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ ابْنُ الْمُسَيَّبِ إِنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْحَلِفُ مُنَفِّقَةٌ لِلسِّلْعَةِ مُمْحِقَةٌ لِلْبَرَكَةِ ‏"‏‏.‏\hadithno{2087}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "The swearing (by the seller) may persuade the buyer to purchase the goods but that will be deprived of Allah's blessing}}
\hadithdefcmd{bukhari}{2088}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا الْعَوَّامُ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ـ رضى الله عنه ـ أَنَّ رَجُلاً، أَقَامَ سِلْعَةً، وَهُوَ فِي السُّوقِ، فَحَلَفَ بِاللَّهِ لَقَدْ أَعْطَى بِهَا مَا لَمْ يُعْطَ، لِيُوقِعَ فِيهَا رَجُلاً مِنَ الْمُسْلِمِينَ، فَنَزَلَتْ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً ‏\}‏\hadithno{2088}\hadithtrans{Narrated `Abdullah bin Abu `Aufa:A man displayed some goods in the market and swore by Allah that he had been offered so much for that, that which was not offered, and he said so, so as to cheat a Muslim. On that occasion the following Verse was revealed: "Verily! Those who purchase a small gain at the cost of Allah's covenant and their oaths (They shall have no portion in the Hereafter ..etc)}}
\hadithdefcmd{bukhari}{2089}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ حُسَيْنَ بْنَ عَلِيٍّ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ عَلِيًّا ـ عَلَيْهِ السَّلاَمُ ـ قَالَ كَانَتْ لِي شَارِفٌ مِنْ نَصِيبِي مِنَ الْمَغْنَمِ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم أَعْطَانِي شَارِفًا مِنَ الْخُمْسِ، فَلَمَّا أَرَدْتُ أَنْ أَبْتَنِيَ بِفَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاعَدْتُ رَجُلاً صَوَّاغًا مِنْ بَنِي قَيْنُقَاعَ أَنْ يَرْتَحِلَ مَعِي فَنَأْتِيَ بِإِذْخِرٍ أَرَدْتُ أَنْ أَبِيعَهُ مِنَ الصَّوَّاغِينَ، وَأَسْتَعِينَ بِهِ فِي وَلِيمَةِ عُرُسِي‏.‏\hadithno{2089}\hadithtrans{Narrated `Ali:I got an old she-camel as my share from the booty, and the Prophet (ﷺ) had given me another from Al- Khumus. And when I intended to marry Fatima (daughter of the Prophet), I arranged that a goldsmith from the tribe of Bani Qainuqa' would accompany me in order to bring Idhkhir and then sell it to the goldsmiths and use its price for my marriage banquet}}
\hadithdefcmd{bukhari}{2090}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ اللَّهَ حَرَّمَ مَكَّةَ، وَلَمْ تَحِلَّ لأَحَدٍ قَبْلِي، وَلاَ لأَحَدٍ بَعْدِي، وَإِنَّمَا حَلَّتْ لِي سَاعَةً مِنْ نَهَارٍ، وَلاَ يُخْتَلَى خَلاَهَا، وَلاَ يُعْضَدُ شَجَرُهَا، وَلاَ يُنَفَّرُ صَيْدُهَا وَلاَ يُلْتَقَطُ لُقَطَتُهَا إِلاَّ لِمُعَرِّفٍ ‏"‏‏.‏ وَقَالَ عَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ إِلاَّ الإِذْخِرَ لِصَاغَتِنَا وَلِسُقُفِ بُيُوتِنَا‏.‏ فَقَالَ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏‏.‏ فَقَالَ عِكْرِمَةُ هَلْ تَدْرِي مَا يُنَفَّرُ صَيْدُهَا هُوَ أَنْ تُنَحِّيَهُ مِنَ الظِّلِّ، وَتَنْزِلَ مَكَانَهُ‏.‏ قَالَ عَبْدُ الْوَهَّابِ عَنْ خَالِدٍ لِصَاغَتِنَا وَقُبُورِنَا‏.‏\hadithno{2090}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) said, "Allah made Mecca a sanctuary and it was neither permitted for anyone before, nor will it be permitted for anyone after me (to fight in it). And fighting in it was made legal for me for a few hours of a day only. None is allowed to uproot its thorny shrubs or to cut down its trees or to chase its game or to pick up its Luqata (fallen things) except by a person who would announce it publicly." `Abbas bin `Abdul-Muttalib requested the Prophet, "Except Al-Idhkhir, for our goldsmiths and for the roofs of our houses." The Prophet (ﷺ) said, "Except Al-Idhkhir." `Ikrima said, "Do you know what is meant by chasing its game? It is to drive it out of the shade and sit in its place." Khalid said, "(`Abbas said: Al-Idhkhir) for our goldsmiths and our graves}}
\hadithdefcmd{bukhari}{2091}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ خَبَّابٍ، قَالَ كُنْتُ قَيْنًا فِي الْجَاهِلِيَّةِ، وَكَانَ لِي عَلَى الْعَاصِ بْنِ وَائِلٍ دَيْنٌ، فَأَتَيْتُهُ أَتَقَاضَاهُ قَالَ لاَ أُعْطِيكَ حَتَّى تَكْفُرَ بِمُحَمَّدٍ صلى الله عليه وسلم‏.‏ فَقُلْتُ لاَ أَكْفُرُ حَتَّى يُمِيتَكَ اللَّهُ، ثُمَّ تُبْعَثَ‏.‏ قَالَ دَعْنِي حَتَّى أَمُوتَ وَأُبْعَثَ، فَسَأُوتَى مَالاً وَوَلَدًا فَأَقْضِيَكَ فَنَزَلَتْ ‏\{‏أَفَرَأَيْتَ الَّذِي كَفَرَ بِآيَاتِنَا وَقَالَ لأُوتَيَنَّ مَالاً وَوَلَدًا * أَطَّلَعَ الْغَيْبَ أَمِ اتَّخَذَ عِنْدَ الرَّحْمَنِ عَهْدًا ‏\}‏\hadithno{2091}\hadithtrans{Narrated Khabbab:I was a blacksmith in the Pre-Islamic period, and 'Asi bin Wail owed me some money, so I went to him to demand it. He said (to me), "I will not pay you unless you disbelieve Muhammad." I said, "I will not disbelieve till Allah kills you and then you get resurrected." He said, "Leave me till I die and get resurrected, then I will be given wealth and children and I will pay you your debt." On that occasion it was revealed to the Prophet: 'Have you seen him who disbelieved in Our signs and says: Surely I will be given wealth and children? Has he known the unseen, or has he taken a covenant from the Beneficent (Allah)?}}
\hadithdefcmd{bukhari}{2092}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ إِنَّ خَيَّاطًا دَعَا رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ صَنَعَهُ، قَالَ أَنَسُ بْنُ مَالِكٍ فَذَهَبْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى ذَلِكَ الطَّعَامِ، فَقَرَّبَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم خُبْزًا وَمَرَقًا فِيهِ دُبَّاءٌ وَقَدِيدٌ، فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَتَتَبَّعُ الدُّبَّاءَ مِنْ حَوَالَىِ الْقَصْعَةِ ـ قَالَ ـ فَلَمْ أَزَلْ أُحِبُّ الدُّبَّاءَ مِنْ يَوْمِئِذٍ‏.‏\hadithno{2092}\hadithtrans{Narrated 'Is-haq bin `Abdullah bin Abu Talha:I heard Anas bin Malik saying, "A tailor invited Allah's Messenger (ﷺ) to a meal which he had prepared. " Anas bin Malik said, "I accompanied Allah's Messenger (ﷺ) to that meal. He served the Prophet (ﷺ) with bread and soup made with gourd and dried meat. I saw the Prophet (ﷺ) taking the pieces of gourd from the dish." Anas added, "Since that day I have continued to like gourd}}
\hadithdefcmd{bukhari}{2093}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، قَالَ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ ـ رضى الله عنه ـ قَالَ جَاءَتِ امْرَأَةٌ بِبُرْدَةٍ ـ قَالَ أَتَدْرُونَ مَا الْبُرْدَةُ فَقِيلَ لَهُ نَعَمْ، هِيَ الشَّمْلَةُ، مَنْسُوجٌ فِي حَاشِيَتِهَا ـ قَالَتْ يَا رَسُولَ اللَّهِ، إِنِّي نَسَجْتُ هَذِهِ بِيَدِي أَكْسُوكَهَا‏.‏ فَأَخَذَهَا النَّبِيُّ صلى الله عليه وسلم مُحْتَاجًا إِلَيْهَا‏.‏ فَخَرَجَ إِلَيْنَا وَإِنَّهَا إِزَارُهُ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ يَا رَسُولَ اللَّهِ، اكْسُنِيهَا، فَقَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ فَجَلَسَ النَّبِيُّ صلى الله عليه وسلم فِي الْمَجْلِسِ، ثُمَّ رَجَعَ فَطَوَاهَا، ثُمَّ أَرْسَلَ بِهَا إِلَيْهِ‏.‏ فَقَالَ لَهُ الْقَوْمُ مَا أَحْسَنْتَ، سَأَلْتَهَا إِيَّاهُ، لَقَدْ عَلِمْتَ أَنَّهُ لاَ يَرُدُّ سَائِلاً‏.‏ فَقَالَ الرَّجُلُ وَاللَّهِ مَا سَأَلْتُهُ إِلاَّ لِتَكُونَ كَفَنِي يَوْمَ أَمُوتُ‏.‏ قَالَ سَهْلٌ فَكَانَتْ كَفَنَهُ‏.‏\hadithno{2093}\hadithtrans{Narrated Abu Hazim:I heard Sahl bin Sa`d saying, "A woman brought a Burda (i.e. a square piece of cloth having edging). I asked, 'Do you know what a Burda is?' They replied in the affirmative and said, "It is a cloth sheet with woven margins." Sahl went on, "She addressed the Prophet (ﷺ) and said, 'I have woven it with my hands for you to wear.' The Prophet (ﷺ) took it as he was in need of it, and came to us wearing it as a waist sheet. One of us said, 'O Allah's Messenger (ﷺ)! Give it to me to wear.' The Prophet (ﷺ) agreed to give it to him. The Prophet (ﷺ) sat with the people for a while and then returned (home), wrapped that waist sheet and sent it to him. The people said to that man, 'You haven't done well by asking him for it when you know that he never turns down anybody's request.' The man replied, 'By Allah, I have not asked him for it except to use it as my shroud when I die." Sahl added; "Later it (i.e. that sheet) was his shroud}}
\hadithdefcmd{bukhari}{2094}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَبِي حَازِمٍ، قَالَ أَتَى رِجَالٌ إِلَى سَهْلِ بْنِ سَعْدٍ يَسْأَلُونَهُ عَنِ الْمِنْبَرِ، فَقَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى فُلاَنَةَ ـ امْرَأَةٍ قَدْ سَمَّاهَا سَهْلٌ ـ ‏ "‏ أَنْ مُرِي غُلاَمَكِ النَّجَّارَ، يَعْمَلُ لِي أَعْوَادًا أَجْلِسُ عَلَيْهِنَّ إِذَا كَلَّمْتُ النَّاسَ ‏"‏‏.‏ فَأَمَرَتْهُ يَعْمَلُهَا مِنْ طَرْفَاءِ الْغَابَةِ ثُمَّ جَاءَ بِهَا، فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِهَا، فَأَمَرَ بِهَا فَوُضِعَتْ، فَجَلَسَ عَلَيْهِ‏.‏\hadithno{2094}\hadithtrans{Narrated Abu Hazim:Some men came to Sahl bin Sa`d to ask him about the pulpit. He replied, "Allah's Messenger (ﷺ) sent for a woman (Sahl named her) (this message): 'Order your slave carpenter to make pieces of wood (i.e. a pulpit) for me so that I may sit on it while addressing the people.' So, she ordered him to make it from the tamarisk of the forest. He brought it to her and she sent it to Allah's Messenger (ﷺ) . Allah's Messenger (ﷺ) ordered it to be placed in the mosque: so, it was put and he sat on it}}
\hadithdefcmd{bukhari}{2095}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ أَيْمَنَ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ امْرَأَةً مِنَ الأَنْصَارِ قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ، أَلاَ أَجْعَلُ لَكَ شَيْئًا تَقْعُدُ عَلَيْهِ فَإِنَّ لِي غُلاَمًا نَجَّارًا‏.‏ قَالَ ‏"‏ إِنْ شِئْتِ ‏"‏‏.‏ قَالَ فَعَمِلَتْ لَهُ الْمِنْبَرَ، فَلَمَّا كَانَ يَوْمُ الْجُمُعَةِ قَعَدَ النَّبِيُّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ الَّذِي صُنِعَ، فَصَاحَتِ النَّخْلَةُ الَّتِي كَانَ يَخْطُبُ عِنْدَهَا حَتَّى كَادَتْ أَنْ تَنْشَقَّ، فَنَزَلَ النَّبِيُّ صلى الله عليه وسلم حَتَّى أَخَذَهَا فَضَمَّهَا إِلَيْهِ، فَجَعَلَتْ تَئِنُّ أَنِينَ الصَّبِيِّ الَّذِي يُسَكَّتُ حَتَّى اسْتَقَرَّتْ‏.‏ قَالَ ‏"‏ بَكَتْ عَلَى مَا كَانَتْ تَسْمَعُ مِنَ الذِّكْرِ ‏"‏‏.‏\hadithno{2095}\hadithtrans{Narrated Jabir bin `Abdullah:An Ansari woman said to Allah's Messenger (ﷺ), "O Allah's Messenger (ﷺ)! Shall I make something for you to sit on, as I have a slave who is a carpenter?" He replied, "If you wish." So, she got a pulpit made for him. When it was Friday the Prophet (ﷺ) sat on that pulpit. The date-palm stem near which the Prophet (ﷺ) used to deliver his sermons cried so much so that it was about to burst. The Prophet (ﷺ) came down from the pulpit to the stem and embraced it and it started groaning like a child being persuaded to stop crying and then it stopped crying. The Prophet (ﷺ) said, "It has cried because of (missing) what it used to hear of the religious knowledge}}
\hadithdefcmd{bukhari}{2096}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اشْتَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ يَهُودِيٍّ طَعَامًا بِنَسِيئَةٍ، وَرَهَنَهُ دِرْعَهُ‏.‏\hadithno{2096}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) bought food grains from a Jew on credit and mortgaged his armor to him}}
\hadithdefcmd{bukhari}{2097}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي غَزَاةٍ، فَأَبْطَأَ بِي جَمَلِي وَأَعْيَا، فَأَتَى عَلَىَّ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ جَابِرٌ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ مَا شَأْنُكَ ‏"‏‏.‏ قُلْتُ أَبْطَأَ عَلَىَّ جَمَلِي وَأَعْيَا، فَتَخَلَّفْتُ‏.‏ فَنَزَلَ يَحْجُنُهُ بِمِحْجَنِهِ، ثُمَّ قَالَ ‏"‏ ارْكَبْ ‏"‏‏.‏ فَرَكِبْتُ، فَلَقَدْ رَأَيْتُهُ أَكُفُّهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ تَزَوَّجْتَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ بِكْرًا أَمْ ثَيِّبًا ‏"‏‏.‏ قُلْتُ بَلْ ثَيِّبًا‏.‏ قَالَ ‏"‏ أَفَلاَ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏‏.‏ قُلْتُ إِنَّ لِي أَخَوَاتٍ، فَأَحْبَبْتُ أَنْ أَتَزَوَّجَ امْرَأَةً تَجْمَعُهُنَّ، وَتَمْشُطُهُنَّ، وَتَقُومُ عَلَيْهِنَّ‏.‏ قَالَ ‏"‏ أَمَّا إِنَّكَ قَادِمٌ، فَإِذَا قَدِمْتَ فَالْكَيْسَ الْكَيْسَ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ أَتَبِيعُ جَمَلَكَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَاشْتَرَاهُ مِنِّي بِأُوقِيَّةٍ، ثُمَّ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلِي، وَقَدِمْتُ بِالْغَدَاةِ، فَجِئْنَا إِلَى الْمَسْجِدِ، فَوَجَدْتُهُ عَلَى باب الْمَسْجِدِ، قَالَ ‏"‏ الآنَ قَدِمْتَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَدَعْ جَمَلَكَ، فَادْخُلْ فَصَلِّ رَكْعَتَيْنِ ‏"‏‏.‏ فَدَخَلْتُ فَصَلَّيْتُ، فَأَمَرَ بِلاَلاً أَنْ يَزِنَ لَهُ أُوقِيَّةً‏.‏ فَوَزَنَ لِي بِلاَلٌ، فَأَرْجَحَ فِي الْمِيزَانِ، فَانْطَلَقْتُ حَتَّى وَلَّيْتُ فَقَالَ ‏"‏ ادْعُ لِي جَابِرًا ‏"‏‏.‏ قُلْتُ الآنَ يَرُدُّ عَلَىَّ الْجَمَلَ، وَلَمْ يَكُنْ شَىْءٌ أَبْغَضَ إِلَىَّ مِنْهُ‏.‏ قَالَ ‏"‏ خُذْ جَمَلَكَ وَلَكَ ثَمَنُهُ ‏"‏‏.‏\hadithno{2097}\hadithtrans{Narrated Jabir bin `Abdullah:I was with the Prophet (ﷺ) in a Ghazwa (Military Expedition) and my camel was slow and exhausted. The Prophet came up to me and said, "O Jabir." I replied, "Yes?" He said, "What is the matter with you?" I replied, "My camel is slow and tired, so I am left behind." So, he got down and poked the camel with his stick and then ordered me to ride. I rode the camel and it became so fast that I had to hold it from going ahead of Allah's Messenger (ﷺ) . He then asked me, have you got married?" I replied in the affirmative. He asked, "A virgin or a matron?" I replied, "I married a matron." The Prophet (ﷺ) said, "Why have you not married a virgin, so that you may play with her and she may play with you?" Jabir replied, "I have sisters (young in age) so I liked to marry a matron who could collect them all and comb their hair and look after them." The Prophet (ﷺ) said, "You will reach, so when you have arrived (at home), I advise you to associate with your wife (that you may have an intelligent son)." Then he asked me, "Would you like to sell your camel?" I replied in the affirmative and the Prophet (ﷺ) purchased it for one Uqiya of gold. Allah's Messenger (ﷺ) reached before me and I reached in the morning, and when I went to the mosque, I found him at the door of the mosque. He asked me, "Have you arrived just now?" I replied in the affirmative. He said, "Leave your camel and come into (the mosque) and pray two rak`at." I entered and offered the prayer. He told Bilal to weigh and give me one Uqiya of gold. So Bilal weighed for me fairly and I went away. The Prophet (ﷺ) sent for me and I thought that he would return to me my camel which I hated more than anything else. But the Prophet (ﷺ) said to me, "Take your camel as well as its price}}
\hadithdefcmd{bukhari}{2098}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَتْ عُكَاظٌ وَمَجَنَّةُ وَذُو الْمَجَازِ أَسْوَاقًا فِي الْجَاهِلِيَّةِ، فَلَمَّا كَانَ الإِسْلاَمُ تَأَثَّمُوا مِنَ التِّجَارَةِ فِيهَا، فَأَنْزَلَ اللَّهُ ‏\{‏لَيْسَ عَلَيْكُمْ جُنَاحٌ‏\}‏ فِي مَوَاسِمِ الْحَجِّ، قَرَأَ ابْنُ عَبَّاسٍ كَذَا‏.‏\hadithno{2098}\hadithtrans{Narrated Ibn `Abbas:`Ukaz, Majanna and Dhul-Majaz were markets in the Pre-Islamic period. When the people embraced Islam they considered it a sin to trade there. So, the following Holy Verse came:-- 'There is no harm for you if you seek of the bounty of your Lord (Allah) in the Hajj season." (2.198) Ibn `Abbas recited it like this}}
\hadithdefcmd{bukhari}{2099}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو كَانَ هَا هُنَا رَجُلٌ اسْمُهُ نَوَّاسٌ، وَكَانَتْ عِنْدَهُ إِبِلٌ هِيمٌ، فَذَهَبَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ فَاشْتَرَى تِلْكَ الإِبِلَ مِنْ شَرِيكٍ لَهُ، فَجَاءَ إِلَيْهِ شَرِيكُهُ فَقَالَ بِعْنَا تِلْكَ الإِبِلَ‏.‏ فَقَالَ مِمَّنْ بِعْتَهَا قَالَ مِنْ شَيْخٍ، كَذَا وَكَذَا‏.‏ فَقَالَ وَيْحَكَ ذَاكَ ـ وَاللَّهِ ـ ابْنُ عُمَرَ‏.‏ فَجَاءَهُ فَقَالَ إِنَّ شَرِيكِي بَاعَكَ إِبِلاً هِيمًا، وَلَمْ يَعْرِفْكَ‏.‏ قَالَ فَاسْتَقْهَا‏.‏ قَالَ فَلَمَّا ذَهَبَ يَسْتَاقُهَا فَقَالَ دَعْهَا، رَضِينَا بِقَضَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ عَدْوَى‏.‏ سَمِعَ سُفْيَانُ عَمْرًا‏.‏\hadithno{2099}\hadithtrans{Narrated `Amr:Here (i.e. in Mecca) there was a man called Nawwas and he had camels suffering from the disease of excessive and unquenchable thirst. Ibn `Umar went to the partner of Nawwas and bought those camels. The man returned to Nawwas and told him that he had sold those camels. Nawwas asked him, "To whom have you sold them?" He replied, "To such and such Sheikh." Nawwas said, "Woe to you; By Allah, that Sheikh was Ibn `Umar." Nawwas then went to Ibn `Umar and said to him, "My partner sold you camels suffering from the disease of excessive thirst and he had not known you." Ibn `Umar told him to take them back. When Nawwas went to take them, Ibn `Umar said to him, "Leave them there as I am happy with the decision of Allah's Messenger (ﷺ) that there is no oppression}}
\hadithdefcmd{bukhari}{2100}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ ابْنِ أَفْلَحَ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ ـ رضى الله عنه ـ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حُنَيْنٍ، فَأَعْطَاهُ ـ يَعْنِي دِرْعًا ـ فَبِعْتُ الدِّرْعَ، فَابْتَعْتُ بِهِ مَخْرَفًا فِي بَنِي سَلِمَةَ، فَإِنَّهُ لأَوَّلُ مَالٍ تَأَثَّلْتُهُ فِي الإِسْلاَمِ‏.‏\hadithno{2100}\hadithtrans{Narrated Abu Qatada:We set out with Allah's Messenger (ﷺ) in the year of Hunain, (the Prophet (ﷺ) gave me an armor). I sold that armor and bought a garden in the region of the tribe of Bani Salama and that was the first property I got after embracing Islam}}
\hadithdefcmd{bukhari}{2101}{حَدَّثَنِي مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا أَبُو بُرْدَةَ بْنُ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ أَبَا بُرْدَةَ بْنَ أَبِي مُوسَى، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْجَلِيسِ الصَّالِحِ وَالْجَلِيسِ السَّوْءِ كَمَثَلِ صَاحِبِ الْمِسْكِ، وَكِيرِ الْحَدَّادِ، لاَ يَعْدَمُكَ مِنْ صَاحِبِ الْمِسْكِ إِمَّا تَشْتَرِيهِ، أَوْ تَجِدُ رِيحَهُ، وَكِيرُ الْحَدَّادِ يُحْرِقُ بَدَنَكَ أَوْ ثَوْبَكَ أَوْ تَجِدُ مِنْهُ رِيحًا خَبِيثَةً ‏"‏‏.‏\hadithno{2101}\hadithtrans{Narrated Abu Musa:Allah's Messenger (ﷺ) said, "The example of a good companion (who sits with you) in comparison with a bad one, is like that of the musk seller and the blacksmith's bellows (or furnace); from the first you would either buy musk or enjoy its good smell while the bellows would either burn your clothes or your house, or you get a bad nasty smell thereof}}
\hadithdefcmd{bukhari}{2102}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ حَجَمَ أَبُو طَيْبَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرَ لَهُ بِصَاعٍ مِنْ تَمْرٍ، وَأَمَرَ أَهْلَهُ أَنْ يُخَفِّفُوا مِنْ خَرَاجِهِ‏.‏\hadithno{2102}\hadithtrans{Narrated Anas bin Malik:Abu Taiba cupped Allah's Messenger (ﷺ) so he ordered that he be paid one Sa of dates and ordered his masters to reduce his tax (as he was a slave and had to pay a tax to them)}}
\hadithdefcmd{bukhari}{2103}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ ـ هُوَ ابْنُ عَبْدِ اللَّهِ ـ حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم وَأَعْطَى الَّذِي حَجَمَهُ، وَلَوْ كَانَ حَرَامًا لَمْ يُعْطِهِ‏.‏\hadithno{2103}\hadithtrans{Narrated Ibn `Abbas:Once the Prophet (ﷺ) got his blood out (medically) and paid that person who had done it. If it had been illegal, the Prophet (ﷺ) would not have paid him}}
\hadithdefcmd{bukhari}{2104}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو بَكْرِ بْنُ حَفْصٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ أَرْسَلَ النَّبِيُّ صلى الله عليه وسلم إِلَى عُمَرَ ـ رضى الله عنه ـ بِحُلَّةِ حَرِيرٍ ـ أَوْ سِيرَاءَ ـ فَرَآهَا عَلَيْهِ، فَقَالَ ‏ "‏ إِنِّي لَمْ أُرْسِلْ بِهَا إِلَيْكَ لِتَلْبَسَهَا، إِنَّمَا يَلْبَسُهَا مَنْ لاَ خَلاَقَ لَهُ، إِنَّمَا بَعَثْتُ إِلَيْكَ لِتَسْتَمْتِعَ بِهَا ‏"‏‏.‏ يَعْنِي تَبِيعُهَا‏.‏\hadithno{2104}\hadithtrans{Narrated `Abdullah bin `Umar:Once the Prophet (ﷺ) sent to `Umar a silken two-piece garment, and when he saw `Umar wearing it, he said to him, "I have not sent it to you to wear. It is worn by him who has no share in the Hereafter, and I have sent it to you so that you could benefit by it (i.e. sell it)}}
\hadithdefcmd{bukhari}{2105}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ أَنَّهَا أَخْبَرَتْهُ أَنَّهَا اشْتَرَتْ نُمْرُقَةً فِيهَا تَصَاوِيرُ، فَلَمَّا رَآهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَامَ عَلَى الْبَابِ، فَلَمْ يَدْخُلْهُ، فَعَرَفْتُ فِي وَجْهِهِ الْكَرَاهِيَةَ، فَقُلْتُ يَا رَسُولَ اللَّهِ، أَتُوبُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ صلى الله عليه وسلم مَاذَا أَذْنَبْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا بَالُ هَذِهِ النُّمْرُقَةِ ‏"‏‏.‏ قُلْتُ اشْتَرَيْتُهَا لَكَ لِتَقْعُدَ عَلَيْهَا وَتَوَسَّدَهَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يَوْمَ الْقِيَامَةِ يُعَذَّبُونَ، فَيُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏‏.‏ وَقَالَ ‏"‏ إِنَّ الْبَيْتَ الَّذِي فِيهِ الصُّوَرُ لاَ تَدْخُلُهُ الْمَلاَئِكَةُ ‏"‏‏.‏\hadithno{2105}\hadithtrans{Narrated Aisha:(mother of the faithful believers) I bought a cushion with pictures on it. When Allah's Messenger (ﷺ) saw it, he kept standing at the door and did not enter the house. I noticed the sign of disgust on his face, so I said, "O Allah's Messenger (ﷺ)! I repent to Allah and His Apostle . (Please let me know) what sin I have done." Allah's Messenger (ﷺ) said, "What about this cushion?" I replied, "I bought it for you to sit and recline on." Allah's Messenger (ﷺ) said, "The painters (i.e. owners) of these pictures will be punished on the Day of Resurrection. It will be said to them, 'Put life in what you have created (i.e. painted).' " The Prophet (ﷺ) added, "The angels do not enter a house where there are pictures}}
\hadithdefcmd{bukhari}{2106}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا بَنِي النَّجَّارِ ثَامِنُونِي بِحَائِطِكُمْ ‏"‏‏.‏ وَفِيهِ خِرَبٌ وَنَخْلٌ‏.‏\hadithno{2106}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "O Bani Najjar! Suggest a price for your garden." Part of it was a ruin and it contained some date palms}}
\hadithdefcmd{bukhari}{2107}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى، قَالَ سَمِعْتُ نَافِعًا، عَنِ ابْنِ عُمَرَ، رضى الله عنهما عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمُتَبَايِعَيْنِ بِالْخِيَارِ فِي بَيْعِهِمَا، مَا لَمْ يَتَفَرَّقَا، أَوْ يَكُونُ الْبَيْعُ خِيَارًا ‏"‏‏.‏ قَالَ نَافِعٌ وَكَانَ ابْنُ عُمَرَ إِذَا اشْتَرَى شَيْئًا يُعْجِبُهُ فَارَقَ صَاحِبَهُ‏.‏\hadithno{2107}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The buyer and the seller have the option to cancel or confirm the bargain before they separate from each other or if the sale is optional." Nafi` said, "Ibn `Umar used to separate quickly from the seller if he had bought a thing which he liked}}
\hadithdefcmd{bukhari}{2108}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حِزَامٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَفْتَرِقَا ‏"‏‏.‏ وَزَادَ أَحْمَدُ حَدَّثَنَا بَهْزٌ، قَالَ قَالَ هَمَّامٌ فَذَكَرْتُ ذَلِكَ لأَبِي التَّيَّاحِ فَقَالَ كُنْتُ مَعَ أَبِي الْخَلِيلِ لَمَّا حَدَّثَهُ عَبْدُ اللَّهِ بْنُ الْحَارِثِ بِهَذَا الْحَدِيثِ‏.‏\hadithno{2108}\hadithtrans{Narrated Hakim bin Hizam":The Prophet (ﷺ) said, "The buyer and the seller have the option of canceling or confirming the deal unless they separate}}
\hadithdefcmd{bukhari}{2109}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا، أَوْ يَقُولُ أَحَدُهُمَا لِصَاحِبِهِ اخْتَرْ ‏"‏‏.‏ وَرُبَّمَا قَالَ أَوْ يَكُونُ بَيْعَ خِيَارٍ‏.‏\hadithno{2109}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "The seller and the buyer have the option of canceling or confirming the deal unless they separate, or one of them says to the other, 'Choose (i.e. decide to cancel or confirm the bargain now)." Perhaps he said, 'Or if it is an optional sale.' " Ibn `Umar, Shuraih, Ash-Shu`bi, Tawus, Ata, and Ibn Abu Mulaika agree upon this judgment}}
\hadithdefcmd{bukhari}{2110}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا حَبَّانُ، حَدَّثَنَا شُعْبَةُ، قَالَ قَتَادَةُ أَخْبَرَنِي عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، قَالَ سَمِعْتُ حَكِيمَ بْنَ حِزَامٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا، فَإِنْ صَدَقَا وَبَيَّنَا بُورِكَ لَهُمَا فِي بَيْعِهِمَا، وَإِنْ كَذَبَا وَكَتَمَا مُحِقَتْ بَرَكَةُ بَيْعِهِمَا ‏"‏‏.‏\hadithno{2110}\hadithtrans{Narrated Hakim bin Hizam:The Prophet (ﷺ) said, "The buyer and the seller have the option of canceling or confirming the bargain unless they separate, and if they spoke the truth and made clear the defects of the goods, then they would be blessed in their bargain, and if they told lies and hid some facts, their bargain would be deprived of Allah's blessings}}
\hadithdefcmd{bukhari}{2111}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُتَبَايِعَانِ كُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ عَلَى صَاحِبِهِ مَا لَمْ يَتَفَرَّقَا، إِلاَّ بَيْعَ الْخِيَارِ ‏"‏‏.‏\hadithno{2111}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Both the buyer and the seller have the option of canceling or confirming a bargain unless they separate, or the sale is optional." (See Hadith No)}}
\hadithdefcmd{bukhari}{2112}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا تَبَايَعَ الرَّجُلاَنِ فَكُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ، مَا لَمْ يَتَفَرَّقَا، وَكَانَا جَمِيعًا، أَوْ يُخَيِّرُ أَحَدُهُمَا الآخَرَ فَتَبَايَعَا عَلَى ذَلِكَ، فَقَدْ وَجَبَ الْبَيْعُ، وَإِنْ تَفَرَّقَا بَعْدَ أَنْ يَتَبَايَعَا، وَلَمْ يَتْرُكْ وَاحِدٌ مِنْهُمَا الْبَيْعَ، فَقَدْ وَجَبَ الْبَيْعُ ‏"‏‏.‏\hadithno{2112}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Both the buyer and the seller have the option of canceling or confirming the bargain, as long as they are still together; and unless they separate or one of them gives the other the option of keeping or returning the things and a decision is concluded then, in which case the bargain is considered final. If they separate after the bargain and none of them has rejected it, then the bargain is rendered final}}
\hadithdefcmd{bukhari}{2113}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ بَيِّعَيْنِ لاَ بَيْعَ بَيْنَهُمَا حَتَّى يَتَفَرَّقَا، إِلاَّ بَيْعَ الْخِيَارِ ‏"‏‏.‏\hadithno{2113}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "No deal is settled and finalized unless the buyer and the seller separate, except if the deal is optional (whereby the validity of the bargain depends on the stipulations agreed upon)}}
\hadithdefcmd{bukhari}{2114}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حِزَامٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا ‏"‏ ـ قَالَ هَمَّامٌ وَجَدْتُ فِي كِتَابِي يَخْتَارُ ثَلاَثَ مِرَارٍ ـ ‏"‏فَإِنْ صَدَقَا وَبَيَّنَا بُورِكَ لَهُمَا فِي بَيْعِهِمَا، وَإِنْ كَذَبَا وَكَتَمَا فَعَسَى أَنْ يَرْبَحَا رِبْحًا، وَيُمْحَقَا بَرَكَةَ بَيْعِهِمَا ‏"‏‏.‏ قَالَ وَحَدَّثَنَا هَمَّامٌ، حَدَّثَنَا أَبُو التَّيَّاحِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ الْحَارِثِ، يُحَدِّثُ بِهَذَا الْحَدِيثِ عَنْ حَكِيمِ بْنِ حِزَامٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2114}\hadithtrans{Narrated Hakim bin Hizam:The Prophet (ﷺ) said, "Both the buyer and the seller have the option of canceling or confirming the bargain unless they separate." The sub-narrator, Hammam said, "I found this in my book: 'Both the buyer and the seller give the option of either confirming or canceling the bargain three times, and if they speak the truth and mention the defects, then their bargain will be blessed, and if they tell lies and conceal the defects, they might gain some financial gain but they will deprive their sale of (Allah's) blessings}}
\hadithdefcmd{bukhari}{2115}{وَقَالَ الْحُمَيْدِيُّ حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَكُنْتُ عَلَى بَكْرٍ صَعْبٍ لِعُمَرَ، فَكَانَ يَغْلِبُنِي فَيَتَقَدَّمُ أَمَامَ الْقَوْمِ، فَيَزْجُرُهُ عُمَرُ وَيَرُدُّهُ، ثُمَّ يَتَقَدَّمُ فَيَزْجُرُهُ عُمَرُ وَيَرُدُّهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِعُمَرَ ‏"‏ بِعْنِيهِ ‏"‏‏.‏ قَالَ هُوَ لَكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ بِعْنِيهِ ‏"‏‏.‏ فَبَاعَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هُوَ لَكَ يَا عَبْدَ اللَّهِ بْنَ عُمَرَ تَصْنَعُ بِهِ مَا شِئْتَ ‏"‏‏.‏\hadithno{2115}\hadithtrans{Narrated Ibn 'Umar (ra) :We were accompanying the Prophet (ﷺ) on a journey and I was riding an unmanageable camel belonging to 'Umar (ra), and I could not bring it under my control. So, it used to go ahead of the party and 'Umar would check it and force it to retreat, and again it went ahead and again 'Umar forced it to retreat. The Prophet (ﷺ) asked 'Umar to sell that camel to him. 'Umar replied, "It is for you O Allah's Messenger !" Allah's Messenger (ﷺ) told 'Umar to sell that camel to him (not to give it as gift). So, 'Umar sold it to Allah's Messenger (ﷺ). Then the Prophet (ﷺ) said to 'Abdullah bin 'Umar "This camel is for you O 'Abdullah (as a present) and you could do with it whatever you like}}
\hadithdefcmd{bukhari}{2116}{قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ اللَّيْثُ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ بِعْتُ مِنْ أَمِيرِ الْمُؤْمِنِينَ عُثْمَانَ مَالاً بِالْوَادِي بِمَالٍ لَهُ بِخَيْبَرَ، فَلَمَّا تَبَايَعْنَا رَجَعْتُ عَلَى عَقِبِي حَتَّى خَرَجْتُ مِنْ بَيْتِهِ، خَشْيَةَ أَنْ يُرَادَّنِي الْبَيْعَ، وَكَانَتِ السُّنَّةُ أَنَّ الْمُتَبَايِعَيْنِ بِالْخِيَارِ حَتَّى يَتَفَرَّقَا، قَالَ عَبْدُ اللَّهِ فَلَمَّا وَجَبَ بَيْعِي وَبَيْعُهُ رَأَيْتُ أَنِّي قَدْ غَبَنْتُهُ بِأَنِّي سُقْتُهُ إِلَى أَرْضِ ثَمُودٍ بِثَلاَثِ لَيَالٍ وَسَاقَنِي إِلَى الْمَدِينَةِ بِثَلاَثِ لَيَالٍ‏.‏\hadithno{2116}\hadithtrans{Narrated 'Abdullah bin 'Umar (ra):I bartered my property in Khaibar to 'Uthman (chief of the faithful believers) for his property in Al-Wadi. When we finished the deal, I left immediately and got out of his house lest he should cancel the deal, for the tradition was that they buyer and the seller had the option of canceling the bargain unless they separated. When our deal was completed, I came to know that I have been unfair to 'Uthman, for by selling him my land I caused him to be in a land of Thamud, at a distance of three days journey from Al-Madina, while he made me nearer to Al-Madina, at a distance of three days journey from my former land}}
\hadithdefcmd{bukhari}{2117}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَجُلاً، ذَكَرَ لِلنَّبِيِّ صلى الله عليه وسلم أَنَّهُ يُخْدَعُ فِي الْبُيُوعِ، فَقَالَ ‏ "‏ إِذَا بَايَعْتَ فَقُلْ لاَ خِلاَبَةَ ‏"‏‏.‏\hadithno{2117}\hadithtrans{Narrated `Abdullah bin `Umar:A person came to the Prophet (ﷺ) and told him that he was always betrayed in purchasing. The Prophet (ﷺ) told him to say at the time of buying, "No cheating}}
\hadithdefcmd{bukhari}{2118}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ حَدَّثَتْنِي عَائِشَةُ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَغْزُو جَيْشٌ الْكَعْبَةَ، فَإِذَا كَانُوا بِبَيْدَاءَ مِنَ الأَرْضِ يُخْسَفُ بِأَوَّلِهِمْ وَآخِرِهِمْ ‏"‏‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ يُخْسَفُ بِأَوَّلِهِمْ وَآخِرِهِمْ، وَفِيهِمْ أَسْوَاقُهُمْ وَمَنْ لَيْسَ مِنْهُمْ‏.‏ قَالَ ‏"‏ يُخْسَفُ بِأَوَّلِهِمْ وَآخِرِهِمْ، ثُمَّ يُبْعَثُونَ عَلَى نِيَّاتِهِمْ ‏"‏‏.‏\hadithno{2118}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "An army will invade the Ka`ba and when the invaders reach Al-Baida', all the ground will sink and swallow the whole army." I said, "O Allah's Messenger (ﷺ)! How will they sink into the ground while amongst them will be their markets (the people who worked in business and not invaders) and the people not belonging to them?" The Prophet (ﷺ) replied, "all of those people will sink but they will be resurrected and judged according to their intentions}}
\hadithdefcmd{bukhari}{2119}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَلاَةُ أَحَدِكُمْ فِي جَمَاعَةٍ تَزِيدُ عَلَى صَلاَتِهِ فِي سُوقِهِ وَبَيْتِهِ بِضْعًا وَعِشْرِينَ دَرَجَةً، وَذَلِكَ بِأَنَّهُ إِذَا تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ، ثُمَّ أَتَى الْمَسْجِدَ، لاَ يُرِيدُ إِلاَّ الصَّلاَةَ، لاَ يَنْهَزُهُ إِلاَّ الصَّلاَةُ، لَمْ يَخْطُ خَطْوَةً إِلاَّ رُفِعَ بِهَا دَرَجَةً، أَوْ حُطَّتْ عَنْهُ بِهَا خَطِيئَةٌ، وَالْمَلاَئِكَةُ تُصَلِّي عَلَى أَحَدِكُمْ مَا دَامَ فِي مُصَلاَّهُ الَّذِي يُصَلِّي فِيهِ اللَّهُمَّ صَلِّ عَلَيْهِ، اللَّهُمَّ ارْحَمْهُ، مَا لَمْ يُحْدِثْ فِيهِ، مَا لَمْ يُؤْذِ فِيهِ ‏"‏‏.‏ وَقَالَ ‏"‏ أَحَدُكُمْ فِي صَلاَةٍ مَا كَانَتِ الصَّلاَةُ تَحْبِسُهُ ‏"‏‏.‏\hadithno{2119}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The congregational prayer of anyone amongst you is more than twenty (five or twenty seven) times in reward than his prayer in the market or in his house, for if he performs ablution completely and then goes to the mosque with the sole intention of performing the prayer, and nothing urges him to proceed to the mosque except the prayer, then, on every step which he takes towards the mosque, he will be raised one degree or one of his sins will be forgiven. The angels will keep on asking Allah's forgiveness and blessings for everyone of you so long as he keeps sitting at his praying place. The angels will say, 'O Allah, bless him! O Allah, be merciful to him!' as long as he does not do Hadath or a thing which gives trouble to the other." The Prophet (ﷺ) further said, "One is regarded in prayer so long as one is waiting for the prayer}}
\hadithdefcmd{bukhari}{2120}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم فِي السُّوقِ، فَقَالَ رَجُلٌ يَا أَبَا الْقَاسِمِ‏.‏ فَالْتَفَتَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم فَقَالَ إِنَّمَا دَعَوْتُ هَذَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ سَمُّوا بِاسْمِي، وَلاَ تَكَنَّوْا بِكُنْيَتِي ‏"‏‏.‏\hadithno{2120}\hadithtrans{Narrated Anas bin Malik:While the Prophet (ﷺ) was in the market, somebody, called, "O Abul-Qasim." The Prophet (ﷺ) turned to him. The man said, "I have called to this (i.e. another man)." The Prophet (ﷺ) said, "Name yourselves by my name but not by my Kunya (name)." (In Arabic world it is the custom to call the man as the father of his eldest son, e.g. Abul-Qasim.) (See Hadith No. 737, Vol)}}
\hadithdefcmd{bukhari}{2121}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زُهَيْرٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ دَعَا رَجُلٌ بِالْبَقِيعِ يَا أَبَا الْقَاسِمِ‏.‏ فَالْتَفَتَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم فَقَالَ لَمْ أَعْنِكَ‏.‏ قَالَ ‏ "‏ سَمُّوا بِاسْمِي، وَلاَ تَكْتَنُوا بِكُنْيَتِي ‏"‏‏.‏\hadithno{2121}\hadithtrans{Narrated Anas:A man at Al-Baqi' called, "O Abul-Qasim!" The Prophet (ﷺ) turned to him and the man said (to the Prophet ), "I did not intend to call you." The prophet said, "Name yourselves by my name but not by my Kunya (name)}}
\hadithdefcmd{bukhari}{2122}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِي هُرَيْرَةَ الدَّوْسِيِّ ـ رضى الله عنه ـ قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم فِي طَائِفَةِ النَّهَارِ لاَ يُكَلِّمُنِي وَلاَ أُكَلِّمُهُ حَتَّى أَتَى سُوقَ بَنِي قَيْنُقَاعَ، فَجَلَسَ بِفِنَاءِ بَيْتِ فَاطِمَةَ فَقَالَ ‏"‏ أَثَمَّ لُكَعُ أَثَمَّ لُكَعُ ‏"‏‏.‏ فَحَبَسَتْهُ شَيْئًا فَظَنَنْتُ أَنَّهَا تُلْبِسُهُ سِخَابًا أَوْ تُغَسِّلُهُ، فَجَاءَ يَشْتَدُّ حَتَّى عَانَقَهُ وَقَبَّلَهُ، وَقَالَ ‏"‏ اللَّهُمَّ أَحْبِبْهُ وَأَحِبَّ مَنْ يُحِبُّهُ ‏"‏‏.‏ قَالَ سُفْيَانُ قَالَ عُبَيْدُ اللَّهِ أَخْبَرَنِي أَنَّهُ رَأَى نَافِعَ بْنَ جُبَيْرٍ أَوْتَرَ بِرَكْعَةٍ‏.‏\hadithno{2122}\hadithtrans{Narrated Abu Huraira Ad-Dausi:Once the Prophet (ﷺ) went out during the day. Neither did he talk to me nor I to him till he reached the market of Bani Qainuqa and then he sat in the compound of Fatima's house and asked about the small boy (his grandson Al-Hasan) but Fatima kept the boy in for a while. I thought she was either changing his clothes or giving the boy a bath. After a while the boy came out running and the Prophet (ﷺ) embraced and kissed him and then said, 'O Allah! Love him, and love whoever loves him}}
\hadithdefcmd{bukhari}{2124}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى، عَنْ نَافِعٍ، حَدَّثَنَا ابْنُ عُمَرَ، أَنَّهُمْ كَانُوا يَشْتَرُونَ الطَّعَامَ مِنَ الرُّكْبَانِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَيَبْعَثُ عَلَيْهِمْ مَنْ يَمْنَعُهُمْ أَنْ يَبِيعُوهُ حَيْثُ اشْتَرَوْهُ، حَتَّى يَنْقُلُوهُ حَيْثُ يُبَاعُ الطَّعَامُ‏.‏ قَالَ وَحَدَّثَنَا ابْنُ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يُبَاعَ الطَّعَامُ إِذَا اشْتَرَاهُ حَتَّى يَسْتَوْفِيَهُ‏.‏\hadithno{2124}\hadithtrans{Narrated Nafi`:Ibn `Umar told us that the people used to buy food from the caravans in the lifetime of the Prophet. The Prophet (ﷺ) used to forbid them to sell it at the very place where they had purchased it (but they were to wait) till they carried it to the market where foodstuff was sold. Ibn `Umar said, 'The Prophet (ﷺ) also forbade the reselling of foodstuff by somebody who had bought it unless he had received it with exact full measure}}
\hadithdefcmd{bukhari}{2125}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا هِلاَلٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، قَالَ لَقِيتُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنهما ـ قُلْتُ أَخْبِرْنِي عَنْ صِفَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي التَّوْرَاةِ‏.‏ قَالَ أَجَلْ، وَاللَّهِ إِنَّهُ لَمَوْصُوفٌ فِي التَّوْرَاةِ بِبَعْضِ صِفَتِهِ فِي الْقُرْآنِ يَا أَيُّهَا النَّبِيُّ إِنَّا أَرْسَلْنَاكَ شَاهِدًا وَمُبَشِّرًا وَنَذِيرًا، وَحِرْزًا لِلأُمِّيِّينَ، أَنْتَ عَبْدِي وَرَسُولِي سَمَّيْتُكَ الْمُتَوَكِّلَ، لَيْسَ بِفَظٍّ وَلاَ غَلِيظٍ وَلاَ سَخَّابٍ فِي الأَسْوَاقِ، وَلاَ يَدْفَعُ بِالسَّيِّئَةِ السَّيِّئَةَ وَلَكِنْ يَعْفُو وَيَغْفِرُ، وَلَنْ يَقْبِضَهُ اللَّهُ حَتَّى يُقِيمَ بِهِ الْمِلَّةَ الْعَوْجَاءَ بِأَنْ يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ وَيَفْتَحُ بِهَا أَعْيُنًا عُمْيًا، وَآذَانًا صُمًّا، وَقُلُوبًا غُلْفًا‏.‏ تَابَعَهُ عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ عَنْ هِلاَلٍ‏.‏ وَقَالَ سَعِيدٌ عَنْ هِلاَلٍ عَنْ عَطَاءٍ عَنِ ابْنِ سَلاَمٍ‏.‏ غُلْفٌ كُلُّ شَىْءٍ فِي غِلاَفٍ، سَيْفٌ أَغْلَفُ، وَقَوْسٌ غَلْفَاءُ، وَرَجُلٌ أَغْلَفُ إِذَا لَمْ يَكُنْ مَخْتُونًا‏.‏\hadithno{2125}\hadithtrans{Narrated Ata bin Yasar:I met `Abdullah bin `Amr bin Al-`As and asked him, "Tell me about the description of Allah's Messenger (ﷺ) which is mentioned in Torah (i.e. Old Testament.") He replied, 'Yes. By Allah, he is described in Torah with some of the qualities attributed to him in the Qur'an as follows: "O Prophet ! We have sent you as a witness (for Allah's True religion) And a giver of glad tidings (to the faithful believers), And a warner (to the unbelievers) And guardian of the illiterates. You are My slave and My messenger (i.e. Apostle). I have named you "Al-Mutawakkil" (who depends upon Allah). You are neither discourteous, harsh Nor a noisemaker in the markets And you do not do evil to those Who do evil to you, but you deal With them with forgiveness and kindness. Allah will not let him (the Prophet) Die till he makes straight the crooked people by making them say: "None has the right to be worshipped but Allah," With which will be opened blind eyes And deaf ears and enveloped hearts}}
\hadithdefcmd{bukhari}{2126}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِيعُهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏‏.‏\hadithno{2126}\hadithtrans{Narrated `Abdullah ibn `Umar:Allah's Messenger (ﷺ) said, "He who buys foodstuff should not sell it till he is satisfied with the measure with which he has bought it}}
\hadithdefcmd{bukhari}{2127}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ تُوُفِّيَ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ حَرَامٍ، وَعَلَيْهِ دَيْنٌ فَاسْتَعَنْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى غُرَمَائِهِ أَنْ يَضَعُوا مِنْ دَيْنِهِ، فَطَلَبَ النَّبِيُّ صلى الله عليه وسلم إِلَيْهِمْ، فَلَمْ يَفْعَلُوا، فَقَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ اذْهَبْ فَصَنِّفْ تَمْرَكَ أَصْنَافًا، الْعَجْوَةَ عَلَى حِدَةٍ، وَعَذْقَ زَيْدٍ عَلَى حِدَةٍ، ثُمَّ أَرْسِلْ إِلَىَّ ‏"‏‏.‏ فَفَعَلْتُ، ثُمَّ أَرْسَلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَجَلَسَ عَلَى أَعْلاَهُ، أَوْ فِي وَسَطِهِ ثُمَّ قَالَ ‏"‏ كِلْ لِلْقَوْمِ ‏"‏‏.‏ فَكِلْتُهُمْ حَتَّى أَوْفَيْتُهُمُ الَّذِي لَهُمْ، وَبَقِيَ تَمْرِي، كَأَنَّهُ لَمْ يَنْقُصْ مِنْهُ شَىْءٌ‏.‏ وَقَالَ فِرَاسٌ عَنِ الشَّعْبِيِّ حَدَّثَنِي جَابِرٌ عَنِ النَّبِيِّ صلى الله عليه وسلم، فَمَا زَالَ يَكِيلُ لَهُمْ حَتَّى أَدَّاهُ، وَقَالَ هِشَامٌ عَنْ وَهْبٍ عَنْ جَابِرٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ جُذَّ لَهُ فَأَوْفِ لَهُ ‏"‏‏.‏\hadithno{2127}\hadithtrans{Narrated Jabir:`Abdullah bin `Amr bin Haram died and was in debt to others. I asked the Prophet (ﷺ) to intercede with his creditors for some reduction in the debts. The Prophet (ﷺ) requested them (to reduce the debts) but they refused. The Prophet (ﷺ) said to me, "Go and put your dates (In heaps) according to their different kinds. The Ajwa on one side, the cluster of Ibn Zaid on another side, etc.. Then call me." I did that and called the Prophet (ﷺ) He came and sat at the head or in the middle of the heaps and ordered me. Measure (the dates) for the people (creditors)." I measured for them till I paid all the debts. My dates remained as if nothing had been taken from them. In other narrations, Jabir said; The Prophet (ﷺ) said, "He (i.e. `Abdullah) continued measuring for them till he paid all the debts." The Prophet (ﷺ) said (to `Abdullah), "Cut (clusters) for him (i.e. one of the creditors) and measure for him fully}}
\hadithdefcmd{bukhari}{2128}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا الْوَلِيدُ، عَنْ ثَوْرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كِيلُوا طَعَامَكُمْ يُبَارَكْ لَكُمْ ‏"‏‏.‏\hadithno{2128}\hadithtrans{Narrated Al-Miqdam bin Ma'diyakrib:The Prophet (ﷺ) said, "Measure your foodstuff and you will be blessed}}
\hadithdefcmd{bukhari}{2129}{حَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ عَبَّادِ بْنِ تَمِيمٍ الأَنْصَارِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ، وَدَعَا لَهَا، وَحَرَّمْتُ الْمَدِينَةَ كَمَا حَرَّمَ إِبْرَاهِيمُ مَكَّةَ، وَدَعَوْتُ لَهَا فِي مُدِّهَا وَصَاعِهَا، مِثْلَ مَا دَعَا إِبْرَاهِيمُ ـ عَلَيْهِ السَّلاَمُ ـ لِمَكَّةَ ‏"‏‏.‏\hadithno{2129}\hadithtrans{Narrated `Abdullah bin Zaid:The Prophet (ﷺ) said, "The Prophet Abraham (ﷺ) made Mecca a sanctuary, and asked for Allah's blessing in it. I made Medina a sanctuary as Abraham made Mecca a sanctuary and I asked for Allah's Blessing in its measures the Mudd and the Sa as Abraham did for Mecca}}
\hadithdefcmd{bukhari}{2130}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَهُمْ فِي مِكْيَالِهِمْ، وَبَارِكْ لَهُمْ فِي صَاعِهِمْ وَمُدِّهِمْ ‏"‏‏.‏ يَعْنِي أَهْلَ الْمَدِينَةِ‏.‏\hadithno{2130}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "O Allah bestow your blessings on their measures, bless their Mudd and Sa." The Prophet (ﷺ) meant the people of Medina}}
\hadithdefcmd{bukhari}{2131}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ رَأَيْتُ الَّذِينَ يَشْتَرُونَ الطَّعَامَ مُجَازَفَةً يُضْرَبُونَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيعُوهُ حَتَّى يُئْوُوهُ إِلَى رِحَالِهِمْ‏.‏\hadithno{2131}\hadithtrans{Narrated Salim:that his father said. "I saw those, who used to buy foodstuff without measuring or weighing in the life time of the Prophet (ﷺ) being punished if they sold it before carrying it to their own houses}}
\hadithdefcmd{bukhari}{2132}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَبِيعَ الرَّجُلُ طَعَامًا حَتَّى يَسْتَوْفِيَهُ‏.‏ قُلْتُ لاِبْنِ عَبَّاسٍ كَيْفَ ذَاكَ قَالَ ذَاكَ دَرَاهِمُ بِدَرَاهِمَ وَالطَّعَامُ مُرْجَأٌ‏.‏ قَالَ أَبُو عَبْد اللَّهِ مُرْجَئُونَ مُؤَخَّرُونَ\hadithno{2132}\hadithtrans{Narrated Tawus:Ibn `Abbas said, "Allah's Messenger (ﷺ) forbade the selling of foodstuff before its measuring and transferring into one's possession." I asked Ibn `Abbas, "How is that?" Ibn `Abbas replied, "It will be just like selling money for money, as the foodstuff has not been handed over to the first purchaser who is the present seller}}
\hadithdefcmd{bukhari}{2133}{حَدَّثَنِي أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَقْبِضَهُ ‏"‏‏.‏\hadithno{2133}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "He who buys foodstuff should not sell it till he has received it}}
\hadithdefcmd{bukhari}{2134}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، كَانَ عَمْرُو بْنُ دِينَارٍ يُحَدِّثُهُ عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسٍ، أَنَّهُ قَالَ مَنْ عِنْدَهُ صَرْفٌ فَقَالَ طَلْحَةُ أَنَا حَتَّى يَجِيءَ خَازِنُنَا مِنَ الْغَابَةِ‏.‏ قَالَ سُفْيَانُ هُوَ الَّذِي حَفِظْنَاهُ مِنَ الزُّهْرِيِّ لَيْسَ فِيهِ زِيَادَةٌ‏.‏ فَقَالَ أَخْبَرَنِي مَالِكُ بْنُ أَوْسٍ سَمِعَ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ يُخْبِرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الذَّهَبُ بِالذَّهَبِ رِبًا إِلاَّ هَاءَ وَهَاءَ، وَالْبُرُّ بِالْبُرِّ رِبًا إِلاَّ هَاءَ وَهَاءَ، وَالتَّمْرُ بِالتَّمْرِ رِبًا إِلاَّ هَاءَ وَهَاءَ، وَالشَّعِيرُ بِالشَّعِيرِ رِبًا إِلاَّ هَاءَ وَهَاءَ ‏"‏‏.‏\hadithno{2134}\hadithtrans{Narrated Az-Zuhri from Malik bin Aus:That the latter said, "Who has change?" Talha said, "I (will have change) when our storekeeper comes from the forest." Malik bin Aus narrated from `Umar bin Al-Khattab: Allah's Messenger (ﷺ) said, "The bartering of gold for gold is Riba (usury), except if it is from hand to hand and equal in amount, and wheat grain for wheat grain is usury except if it is from hand to hand and equal in amount, and dates for dates is usury except if it is from hand to hand and equal in amount, and barley for barley is usury except if it is from hand to hand and equal in amount}}
\hadithdefcmd{bukhari}{2135}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ الَّذِي حَفِظْنَاهُ مِنْ عَمْرِو بْنِ دِينَارٍ سَمِعَ طَاوُسًا، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ أَمَّا الَّذِي نَهَى عَنْهُ النَّبِيُّ صلى الله عليه وسلم فَهْوَ الطَّعَامُ أَنْ يُبَاعَ حَتَّى يُقْبَضَ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَلاَ أَحْسِبُ كُلَّ شَىْءٍ إِلاَّ مِثْلَهُ‏.‏\hadithno{2135}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) forbade the selling of foodstuff before receiving it. I consider that all types of sellings should be done similarly}}
\hadithdefcmd{bukhari}{2136}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏‏.‏ زَادَ إِسْمَاعِيلُ ‏"‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَقْبِضَهُ ‏"‏‏.‏\hadithno{2136}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The buyer of foodstuff should not sell it before it has been measured for him." Isma`il narrated instead, "He should not sell it before receiving it}}
\hadithdefcmd{bukhari}{2137}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ لَقَدْ رَأَيْتُ النَّاسَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَبْتَاعُونَ جِزَافًا ـ يَعْنِي الطَّعَامَ ـ يُضْرَبُونَ أَنْ يَبِيعُوهُ فِي مَكَانِهِمْ حَتَّى يُؤْوُوهُ إِلَى رِحَالِهِمْ‏.‏\hadithno{2137}\hadithtrans{Narrated Ibn `Umar:I saw the people buy foodstuff randomly (i.e. blindly without measuring it) in the lifetime of Allah's Apostle and they were punished (by beating), if they tried to sell it before carrying it to their own houses}}
\hadithdefcmd{bukhari}{2138}{حَدَّثَنَا فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَقَلَّ يَوْمٌ كَانَ يَأْتِي عَلَى النَّبِيِّ صلى الله عليه وسلم إِلاَّ يَأْتِي فِيهِ بَيْتَ أَبِي بَكْرٍ أَحَدَ طَرَفَىِ النَّهَارِ، فَلَمَّا أُذِنَ لَهُ فِي الْخُرُوجِ إِلَى الْمَدِينَةِ لَمْ يَرُعْنَا إِلاَّ وَقَدْ أَتَانَا ظُهْرًا، فَخُبِّرَ بِهِ أَبُو بَكْرٍ فَقَالَ مَا جَاءَنَا النَّبِيُّ صلى الله عليه وسلم فِي هَذِهِ السَّاعَةِ، إِلاَّ لأَمْرٍ حَدَثَ، فَلَمَّا دَخَلَ عَلَيْهِ قَالَ لأَبِي بَكْرٍ ‏"‏ أَخْرِجْ مَنْ عِنْدَكَ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّمَا هُمَا ابْنَتَاىَ‏.‏ يَعْنِي عَائِشَةَ وَأَسْمَاءَ‏.‏ قَالَ ‏"‏ أَشَعَرْتَ أَنَّهُ قَدْ أُذِنَ لِي فِي الْخُرُوجِ ‏"‏‏.‏ قَالَ الصُّحْبَةَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ الصُّحْبَةَ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّ عِنْدِي نَاقَتَيْنِ أَعْدَدْتُهُمَا لِلْخُرُوجِ، فَخُذْ إِحْدَاهُمَا‏.‏ قَالَ ‏"‏ قَدْ أَخَذْتُهَا بِالثَّمَنِ ‏"‏‏.‏\hadithno{2138}\hadithtrans{Narrated Aisha:Rarely did the Prophet (ﷺ) fail to visit Abu Bakr's house everyday, either in the morning or in the evening. When the permission for migration to Medina was granted, all of a sudden the Prophet (ﷺ) came to us at noon and Abu Bakr was informed, who said, "Certainly the Prophet (ﷺ) has come for some urgent matter." The Prophet (ﷺ) said to Abu Bakr, when the latter entered, "Let nobody stay in your home." Abu Bakr said, "O Allah's Messenger (ﷺ)! There are only my two daughters (namely `Aisha and Asma') present." The Prophet (ﷺ) said, "I feel (am informed) that I have been granted the permission for migration." Abu Bakr said, "I will accompany you, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said, "You will accompany me." Abu Bakr then said "O Allah's Messenger (ﷺ)! I have two she-camels I have prepared specially for migration, so I offer you one of them. The Prophet (ﷺ) said, "I have accepted it on the condition that I will pay its price}}
\hadithdefcmd{bukhari}{2139}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِيعُ بَعْضُكُمْ عَلَى بَيْعِ أَخِيهِ ‏"‏‏.‏\hadithno{2139}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Do not urge somebody to return what he has already bought (i.e. in optional sale) from another seller so as to sell him your own goods}}
\hadithdefcmd{bukhari}{2140}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ، وَلاَ تَنَاجَشُوا، وَلاَ يَبِيعُ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ يَخْطُبُ عَلَى خِطْبَةِ أَخِيهِ، وَلاَ تَسْأَلُ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَكْفَأَ مَا فِي إِنَائِهَا‏.‏\hadithno{2140}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade the selling of things by a town dweller on behalf of a desert dweller; and similarly Najsh was forbidden. And one should not urge somebody to return the goods to the seller so as to sell him his own goods; nor should one demand the hand of a girl who has already been engaged to someone else; and a woman should not try to cause some other woman to be divorced in order to take her place}}
\hadithdefcmd{bukhari}{2141}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا الْحُسَيْنُ الْمُكْتِبُ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ رَجُلاً أَعْتَقَ غُلاَمًا لَهُ عَنْ دُبُرٍ، فَاحْتَاجَ فَأَخَذَهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَنْ يَشْتَرِيهِ مِنِّي ‏"‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ بِكَذَا وَكَذَا، فَدَفَعَهُ إِلَيْهِ‏.‏\hadithno{2141}\hadithtrans{Narrated Jabir bin `Abdullah:A man decided that a slave of his would be manumitted after his death and later on he was in need of money, so the Prophet (ﷺ) took the slave and said, "Who will buy this slave from me?" Nu'aim bin `Abdullah bought him for such and such price and the Prophet (ﷺ) gave him the slave}}
\hadithdefcmd{bukhari}{2142}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ النَّجْشِ‏.‏\hadithno{2142}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) forbade Najsh}}
\hadithdefcmd{bukhari}{2143}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ حَبَلِ الْحَبَلَةِ، وَكَانَ بَيْعًا يَتَبَايَعُهُ أَهْلُ الْجَاهِلِيَّةِ، كَانَ الرَّجُلُ يَبْتَاعُ الْجَزُورَ إِلَى أَنْ تُنْتَجَ النَّاقَةُ، ثُمَّ تُنْتَجُ الَّتِي فِي بَطْنِهَا‏.‏\hadithno{2143}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) forbade the sale called 'Habal-al-Habala which was a kind of sale practiced in the Pre- Islamic Period of ignorance. One would pay the price of a she-camel which was not born yet would be born by the immediate offspring of an extant she-camel}}
\hadithdefcmd{bukhari}{2144}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَامِرُ بْنُ سَعْدٍ، أَنَّ أَبَا سَعِيدٍ ـ رضى الله عنه ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُنَابَذَةِ، وَهْىَ طَرْحُ الرَّجُلِ ثَوْبَهُ بِالْبَيْعِ إِلَى الرَّجُلِ، قَبْلَ أَنْ يُقَلِّبَهُ، أَوْ يَنْظُرَ إِلَيْهِ، وَنَهَى عَنِ الْمُلاَمَسَةِ، وَالْمُلاَمَسَةُ لَمْسُ الثَّوْبِ لاَ يَنْظُرُ إِلَيْهِ‏.‏\hadithno{2144}\hadithtrans{Narrated Abu Sa`id:Allah's Messenger (ﷺ) forbade the selling by Munabadha, i.e. to sell one's garment by casting it to the buyer not allowing him to examine or see it. Similarly he forbade the selling by Mulamasa. Mulamasa is to buy a garment, for example, by merely touching it, not looking at it}}
\hadithdefcmd{bukhari}{2145}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نُهِيَ عَنْ لِبْسَتَيْنِ، أَنْ يَحْتَبِيَ الرَّجُلُ، فِي الثَّوْبِ الْوَاحِدِ، ثُمَّ يَرْفَعَهُ عَلَى مَنْكِبِهِ، وَعَنْ بَيْعَتَيْنِ اللِّمَاسِ وَالنِّبَاذِ‏.‏\hadithno{2145}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) forbade two kinds of dressing; (one of them) is to sit with one's legs drawn up while wrapped in one garment. (The other) is to lift that garment on one's shoulders. And also forbade two kinds of sale: Al-Limais and An-Nibadh}}
\hadithdefcmd{bukhari}{2146}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، وَعَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ‏.‏\hadithno{2146}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade selling by Mulamasa and Munabadha}}
\hadithdefcmd{bukhari}{2147}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ لِبْسَتَيْنِ وَعَنْ بَيْعَتَيْنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ‏.‏\hadithno{2147}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) forbade two kinds of dresses and two kinds of sale, i.e., Mulamasa and Munabadha}}
\hadithdefcmd{bukhari}{2148}{حَدَّثَنَا ابْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ تُصَرُّوا الإِبِلَ وَالْغَنَمَ، فَمَنِ ابْتَاعَهَا بَعْدُ فَإِنَّهُ بِخَيْرِ النَّظَرَيْنِ بَعْدَ أَنْ يَحْتَلِبَهَا إِنْ شَاءَ أَمْسَكَ، وَإِنْ شَاءَ رَدَّهَا وَصَاعَ تَمْرٍ ‏"‏‏.‏ وَيُذْكَرُ عَنْ أَبِي صَالِحٍ وَمُجَاهِدٍ وَالْوَلِيدِ بْنِ رَبَاحٍ وَمُوسَى بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ صَاعَ تَمْرٍ ‏"‏‏.‏ وَقَالَ بَعْضُهُمْ عَنِ ابْنِ سِيرِينَ صَاعًا مِنْ طَعَامٍ وَهْوَ بِالْخِيَارِ ثَلاَثًا‏.‏ وَقَالَ بَعْضُهُمْ عَنِ ابْنِ سِيرِينَ صَاعًا مِنْ تَمْرٍ‏.‏ وَلَمْ يَذْكُرْ ثَلاَثًا، وَالتَّمْرُ أَكْثَرُ‏.‏\hadithno{2148}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Don't keep camels and sheep unmilked for a long time, for whoever buys such an animal has the option to milk it and then either to keep it or return it to the owner along with one Sa of dates." Some narrated from Ibn Seereen (that the Prophet (ﷺ) had said), "One Sa of wheat, and he has the option for three days." And some narrated from Ibn Seereen, " ... a Sa of dates," not mentioning the option for three days. But a Sa of dates is mentioned in most narrations}}
\hadithdefcmd{bukhari}{2149}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي يَقُولُ، حَدَّثَنَا أَبُو عُثْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ مَنِ اشْتَرَى شَاةً مُحَفَّلَةً، فَرَدَّهَا فَلْيَرُدَّ مَعَهَا صَاعًا‏.‏ وَنَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ تُلَقَّى الْبُيُوعُ‏.‏\hadithno{2149}\hadithtrans{Narrated `Abdullah bin Mas`ud:Whoever buys a sheep which has not been milked for a long time, has the option of returning it along with one Sa of dates; and the Prophet (ﷺ) forbade going to meet the seller on the way (as he has no knowledge of the market price and he may sell his goods at a low price)}}
\hadithdefcmd{bukhari}{2150}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَلَقَّوُا الرُّكْبَانَ، وَلاَ يَبِيعُ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَلاَ تَنَاجَشُوا وَلاَ يَبِيعُ حَاضِرٌ لِبَادٍ، وَلاَ تُصَرُّوا الْغَنَمَ، وَمَنِ ابْتَاعَهَا فَهْوَ بِخَيْرِ النَّظَرَيْنِ بَعْدَ أَنْ يَحْتَلِبَهَا إِنْ رَضِيَهَا أَمْسَكَهَا، وَإِنْ سَخِطَهَا رَدَّهَا وَصَاعًا مِنْ تَمْرٍ ‏"‏‏.‏\hadithno{2150}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Do not go forward to meet the caravan (to buy from it on the way before it reaches the town). And do not urge buyers to cancel their purchases to sell them (your own goods) yourselves, and do not practice Najsh. A town dweller should not sell the goods for the desert dweller. Do not leave sheep unmilked for a long time, when they are on sale, and whoever buys such an animal has the option of returning it, after milking it, along with a Sa of dates or keeping it. it has been kept unmilked for a long period by the seller (to deceive others)}}
\hadithdefcmd{bukhari}{2151}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنَا الْمَكِّيُّ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي زِيَادٌ، أَنَّ ثَابِتًا، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اشْتَرَى غَنَمًا مُصَرَّاةً فَاحْتَلَبَهَا، فَإِنْ رَضِيَهَا أَمْسَكَهَا، وَإِنْ سَخِطَهَا فَفِي حَلْبَتِهَا صَاعٌ مِنْ تَمْرٍ ‏"‏‏.‏\hadithno{2151}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever buys a sheep which has been kept unmilked for a long period, and milks it, can keep it if he is satisfied, and if he is not satisfied, he can return it, but he should pay one Sa of dates for the milk}}
\hadithdefcmd{bukhari}{2152}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَهُ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا زَنَتِ الأَمَةُ فَتَبَيَّنَ زِنَاهَا فَلْيَجْلِدْهَا، وَلاَ يُثَرِّبْ، ثُمَّ إِنْ زَنَتْ فَلْيَجْلِدْهَا، وَلاَ يُثَرِّبْ، ثُمَّ إِنْ زَنَتِ الثَّالِثَةَ فَلْيَبِعْهَا، وَلَوْ بِحَبْلٍ مِنْ شَعَرٍ ‏"‏‏.‏\hadithno{2152}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If a slave-girl commits illegal sexual intercourse and it is proved beyond doubt, then her owner should lash her and should not blame her after the legal punishment. And then if she repeats the illegal sexual intercourse he should lash her again and should not blame her after the legal punishment, and if she commits it a third time, then he should sell her even for a hair rope}}
\hadithdefcmd{bukhari}{2154}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الأَمَةِ إِذَا زَنَتْ وَلَمْ تُحْصِنْ قَالَ ‏ "‏ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَبِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ لاَ أَدْرِي بَعْدَ الثَّالِثَةِ، أَوِ الرَّابِعَةِ‏.‏\hadithno{2154}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:Allah's Messenger (ﷺ) was asked about the slave-girl, if she was a virgin and committed illegal sexual intercourse. The Prophet (ﷺ) said, "If she committed illegal sexual intercourse, lash her, and if she did it a second time, then lash her again, and if she repeated the third time, then sell her even for a hair rope." Ibn Shihab said, "I don't know whether to sell her after the third or fourth offense}}
\hadithdefcmd{bukhari}{2155}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ عُرْوَةُ بْنُ الزُّبَيْرِ قَالَتْ عَائِشَةُ ـ رضى الله عنها دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ لَهُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اشْتَرِي وَأَعْتِقِي، فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏‏.‏ ثُمَّ قَامَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْعَشِيِّ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قَالَ ‏"‏ مَا بَالُ أُنَاسٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَ فِي كِتَابِ اللَّهِ، مَنِ اشْتَرَطَ شَرْطًا لَيْسَ فِي كِتَابِ اللَّهِ فَهْوَ بَاطِلٌ، وَإِنِ اشْتَرَطَ مِائَةَ شَرْطٍ، شَرْطُ اللَّهِ أَحَقُّ وَأَوْثَقُ ‏"‏‏.‏\hadithno{2155}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) came to me and I told him about the slave-girl (Barirah) Allah's Messenger (ﷺ) said, "Buy and manumit her, for the Wala is for the one who manumits." In the evening the Prophet (ﷺ) got up and glorified Allah as He deserved and then said, "Why do some people impose conditions which are not present in Allah's Book (Laws)? Whoever imposes such a condition as is not in Allah's Laws, then that condition is invalid even if he imposes one hundred conditions, for Allah's conditions are more binding and reliable}}
\hadithdefcmd{bukhari}{2156}{حَدَّثَنَا حَسَّانُ بْنُ أَبِي عَبَّادٍ، حَدَّثَنَا هَمَّامٌ، قَالَ سَمِعْتُ نَافِعًا، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما أَنَّ عَائِشَةَ ـ رضى الله عنها ـ سَاوَمَتْ بَرِيرَةَ فَخَرَجَ إِلَى الصَّلاَةِ، فَلَمَّا جَاءَ قَالَتْ إِنَّهُمْ أَبَوْا أَنْ يَبِيعُوهَا، إِلاَّ أَنْ يَشْتَرِطُوا الْوَلاَءَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ قُلْتُ لِنَافِعٍ حُرًّا كَانَ زَوْجُهَا أَوْ عَبْدًا فَقَالَ مَا يُدْرِينِي\hadithno{2156}\hadithtrans{Narrated `Abdullah bin `Umar:Aisha wanted to buy Barirah and he (the Prophet) went out for the prayer. When he returned, she told him that they (her masters) refused to sell her except on the condition that her Wala' would go to them. The Prophet (ﷺ) replied, 'The Wala' would go to him who manumits.' " Hammam asked Nafi` whether her (Barirah's) husband was a free man or a slave. He replied that he did not know}}
\hadithdefcmd{bukhari}{2157}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، سَمِعْتُ جَرِيرًا ـ رضى الله عنه ـ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى شَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ، وَإِقَامِ الصَّلاَةِ، وَإِيتَاءِ الزَّكَاةِ، وَالسَّمْعِ وَالطَّاعَةِ، وَالنُّصْحِ لِكُلِّ مُسْلِمٍ‏.‏\hadithno{2157}\hadithtrans{Narrated Jarir:I have given a pledge of allegiance to Allah's Messenger (ﷺ) for to testify that None has the right to be worshipped but Allah, and Muhammad is His Apostle, to offer prayers perfectly, to pay Zakat, to listen to and obey (Allah's and His Prophet's orders), and to give good advice to every Muslim}}
\hadithdefcmd{bukhari}{2158}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا مَعْمَرٌ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلَقَّوُا الرُّكْبَانَ وَلاَ يَبِيعُ حَاضِرٌ لِبَادٍ ‏"‏‏.‏ قَالَ فَقُلْتُ لاِبْنِ عَبَّاسٍ مَا قَوْلُهُ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ قَالَ لاَ يَكُونُ لَهُ سِمْسَارًا‏.‏\hadithno{2158}\hadithtrans{Narrated Tawus:Ibn `Abbas said, "Allah's Messenger (ﷺ) said, 'Do not go to meet the caravans on the way (for buying their goods without letting them know the market price); a town dweller should not sell the goods of a desert dweller on behalf of the latter.' I asked Ibn `Abbas, 'What does he mean by not selling the goods of a desert dweller by a town dweller?' He said, 'He should not become his broker}}
\hadithdefcmd{bukhari}{2159}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ صَبَّاحٍ، حَدَّثَنَا أَبُو عَلِيٍّ الْحَنَفِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ دِينَارٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ‏.‏ وَبِهِ قَالَ ابْنُ عَبَّاسٍ‏.‏\hadithno{2159}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) forbade the selling of the goods of a desert dweller by a town person}}
\hadithdefcmd{bukhari}{2160}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَبْتَاعُ الْمَرْءُ عَلَى بَيْعِ أَخِيهِ، وَلاَ تَنَاجَشُوا، وَلاَ يَبِعْ حَاضِرٌ لِبَادٍ ‏"‏\hadithno{2160}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A buyer should not urge a seller to restore a purchase so as to buy it himself, and do not practice Najsh; and a town dweller should not sell goods of a desert dweller}}
\hadithdefcmd{bukhari}{2161}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذٌ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، قَالَ أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ نُهِينَا أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ‏.‏\hadithno{2161}\hadithtrans{Narrated Anas bin Malik:We were forbidden that a town dweller should sell goods of a desert dweller}}
\hadithdefcmd{bukhari}{2162}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ التَّلَقِّي، وَأَنْ يَبِيعَ حَاضِرٌ لِبَادٍ‏.‏\hadithno{2162}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) forbade the meeting (of caravans) on the way and the selling of goods by an inhabitant of the town on behalf of a desert dweller}}
\hadithdefcmd{bukhari}{2163}{حَدَّثَنِي عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ مَا مَعْنَى قَوْلِهِ ‏ "‏ لاَ يَبِيعَنَّ حَاضِرٌ لِبَادٍ ‏"‏‏.‏ فَقَالَ لاَ يَكُنْ لَهُ سِمْسَارًا‏.‏\hadithno{2163}\hadithtrans{Narrated Tawus:I asked Ibn `Abbas, "What is the meaning of, 'No town dweller should sell (or buy) for a desert dweller'?" Ibn `Abbas said, "It means he should not become his broker}}
\hadithdefcmd{bukhari}{2164}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنِي التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ مَنِ اشْتَرَى مُحَفَّلَةً فَلْيَرُدَّ مَعَهَا صَاعًا‏.‏ قَالَ وَنَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ تَلَقِّي الْبُيُوعِ‏.‏\hadithno{2164}\hadithtrans{Narrated `Abdullah:Whoever buys an animal which has been kept unmilked for a long time, could return it, but has to pay a Sa of dates along with it. And the Prophet (ﷺ) forbade meeting the owners of goods on the way away from the market}}
\hadithdefcmd{bukhari}{2165}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِيعُ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ، وَلاَ تَلَقَّوُا السِّلَعَ حَتَّى يُهْبَطَ بِهَا إِلَى السُّوقِ ‏"‏‏.‏\hadithno{2165}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "You should not try to cancel the purchases of one another (to get a benefit thereof), and do not go ahead to meet the caravan (for buying the goods) (but wait) till it reaches the market}}
\hadithdefcmd{bukhari}{2166}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كُنَّا نَتَلَقَّى الرُّكْبَانَ فَنَشْتَرِي مِنْهُمُ الطَّعَامَ، فَنَهَانَا النَّبِيُّ صلى الله عليه وسلم أَنْ نَبِيعَهُ حَتَّى يُبْلَغَ بِهِ سُوقُ الطَّعَامِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ هَذَا فِي أَعْلَى السُّوقِ، يُبَيِّنُهُ حَدِيثُ عُبَيْدِ اللَّهِ‏.‏\hadithno{2166}\hadithtrans{Narrated `Abdullah:We used to go ahead to meet the caravan and used to buy foodstuff from them. The Prophet (ﷺ) forbade us to sell it till it was carried to the market}}
\hadithdefcmd{bukhari}{2167}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كَانُوا يَبْتَاعُونَ الطَّعَامَ فِي أَعْلَى السُّوقِ فَيَبِيعُونَهُ فِي مَكَانِهِمْ، فَنَهَاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيعُوهُ فِي مَكَانِهِ حَتَّى يَنْقُلُوهُ‏.‏\hadithno{2167}\hadithtrans{Narrated `Abdullah:Some people used to buy foodstuff at the head of the market and used to sell it on the spot. Allah's Apostle forbade them to sell it till they brought it to (their) places}}
\hadithdefcmd{bukhari}{2168}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ جَاءَتْنِي بَرِيرَةُ فَقَالَتْ كَاتَبْتُ أَهْلِي عَلَى تِسْعِ أَوَاقٍ فِي كُلِّ عَامٍ وَقِيَّةٌ، فَأَعِينِينِي‏.‏ فَقُلْتُ إِنْ أَحَبَّ أَهْلُكِ أَنْ أَعُدَّهَا لَهُمْ وَيَكُونَ وَلاَؤُكِ لِي فَعَلْتُ‏.‏ فَذَهَبَتْ بَرِيرَةُ إِلَى أَهْلِهَا، فَقَالَتْ لَهُمْ فَأَبَوْا عَلَيْهَا، فَجَاءَتْ مِنْ عِنْدِهِمْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ، فَقَالَتْ إِنِّي قَدْ عَرَضْتُ ذَلِكَ عَلَيْهِمْ فَأَبَوْا، إِلاَّ أَنْ يَكُونَ الْوَلاَءُ لَهُمْ‏.‏ فَسَمِعَ النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَتْ عَائِشَةُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ خُذِيهَا وَاشْتَرِطِي لَهُمُ الْوَلاَءَ، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ فَفَعَلَتْ عَائِشَةُ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ، فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ مَا بَالُ رِجَالٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ، مَا كَانَ مِنْ شَرْطٍ لَيْسَ فِي كِتَابِ اللَّهِ فَهُوَ بَاطِلٌ وَإِنْ كَانَ مِائَةَ شَرْطٍ، قَضَاءُ اللَّهِ أَحَقُّ، وَشَرْطُ اللَّهِ أَوْثَقُ، وَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{2168}\hadithtrans{Narrated `Urwa:Aisha said, "Barira came to me and said, 'I have agreed with my masters to pay them nine Uqiyas (of gold) (in installments) one Uqiya per year; please help me.' I said, 'I am ready to pay the whole amount now provided your masters agree that your Wala' will be for me.' So, Barira went to her masters and told them about that offer but they refused to accept it. She returned, and at that time, Allah's Messenger (ﷺ) was sitting (present). Barira said, 'I told them of the offer but they did not accept it and insisted on having the Wala'.' The Prophet (ﷺ) heard that." `Aisha narrated the whole story to the Prophet. He said to her, "Buy her and stipulate that her Wala' would be yours as the Wala' is for the manumitter." `Aisha did so. Then Allah's Messenger (ﷺ) stood up in front of the people, and after glorifying Allah he said, "Amma Ba`du (i.e. then after)! What about the people who impose conditions which are not in Allah's Book (Laws)? Any condition that is not in Allah's Book (Laws) is invalid even if they were one hundred conditions, for Allah's decisions are the right ones and His conditions are the strong ones (firmer) and the Wala' will be for the manumitter}}
\hadithdefcmd{bukhari}{2169}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ عَائِشَةَ، أُمَّ الْمُؤْمِنِينَ أَرَادَتْ أَنْ تَشْتَرِيَ جَارِيَةً فَتُعْتِقَهَا، فَقَالَ أَهْلُهَا نَبِيعُكِهَا عَلَى أَنَّ وَلاَءَهَا لَنَا‏.‏ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ يَمْنَعُكِ ذَلِكَ، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{2169}\hadithtrans{Narrated `Abdullah bin `Umar:Aisha, (mother of the faithful believers) wanted to buy a slave girl and manumit her, but her masters said that they would sell her only on the condition that her Wala' would be for them. `Aisha told Allah's Messenger (ﷺ) of that. He said, "What they stipulate should not hinder you from buying her, as the Wala' is for the manumitted}}
\hadithdefcmd{bukhari}{2170}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسٍ، سَمِعَ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبُرُّ بِالْبُرِّ رِبًا إِلاَّ هَاءَ وَهَاءَ، وَالشَّعِيرُ بِالشَّعِيرِ رِبًا إِلاَّ هَاءَ وَهَاءَ، وَالتَّمْرُ بِالتَّمْرِ رِبًا إِلاَّ هَاءَ وَهَاءَ ‏"‏‏.‏\hadithno{2170}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The selling of wheat for wheat is Riba (usury) except if it is handed from hand to hand and equal in amount. Similarly the selling of barley for barley, is Riba except if it is from hand to hand and equal in amount, and dates for dates is usury except if it is from hand to hand and equal in amount. (See Riba-Fadl in the glossary)}}
\hadithdefcmd{bukhari}{2171}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ، وَالْمُزَابَنَةُ بَيْعُ الثَّمَرِ بِالتَّمْرِ كَيْلاً، وَبَيْعُ الزَّبِيبِ بِالْكَرْمِ كَيْلاً‏.‏\hadithno{2171}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) forbade Muzabana; and Muzabana is the selling of fresh dates for dried old dates by measure, and the selling of fresh grapes for dried grapes by measure}}
\hadithdefcmd{bukhari}{2173}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ قَالَ وَالْمُزَابَنَةُ أَنْ يَبِيعَ الثَّمَرَ بِكَيْلٍ، إِنْ زَادَ فَلِي وَإِنْ نَقَصَ فَعَلَىَّ‏.‏ قَالَ وَحَدَّثَنِي زَيْدُ بْنُ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ فِي الْعَرَايَا بِخَرْصِهَا‏.‏\hadithno{2173}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) forbade Muzabana; and Muzabana is the selling of fresh fruit (without measuring it) for something by measure on the basis that if that thing turns to be more than the fruit, the increase would be for the seller of the fruit, and if it turns to be less, that would be of his lot. Narrated Ibn `Umar from Zaid bin Thabit that the Prophet (ﷺ) allowed the selling of the fruits on the trees after estimation (when they are ripe)}}
\hadithdefcmd{bukhari}{2174}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسٍ، أَخْبَرَهُ أَنَّهُ الْتَمَسَ، صَرْفًا بِمِائَةِ دِينَارٍ، فَدَعَانِي طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ فَتَرَاوَضْنَا، حَتَّى اصْطَرَفَ مِنِّي، فَأَخَذَ الذَّهَبَ يُقَلِّبُهَا فِي يَدِهِ، ثُمَّ قَالَ حَتَّى يَأْتِيَ خَازِنِي مِنَ الْغَابَةِ، وَعُمَرُ يَسْمَعُ ذَلِكَ، فَقَالَ وَاللَّهِ لاَ تُفَارِقُهُ حَتَّى تَأْخُذَ مِنْهُ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالذَّهَبِ رِبًا إِلاَّ هَاءَ وَهَاءَ، وَالْبُرُّ بِالْبُرِّ رِبًا إِلاَّ هَاءَ وَهَاءَ، وَالشَّعِيرُ بِالشَّعِيرِ رِبًا إِلاَّ هَاءَ وَهَاءَ، وَالتَّمْرُ بِالتَّمْرِ رِبًا إِلاَّ هَاءَ وَهَاءَ ‏"‏‏.‏\hadithno{2174}\hadithtrans{Narrated Ibn Shihab:that Malik bin Aus said, "I was in need of change for one-hundred Dinars. Talha bin 'Ubaidullah called me and we discussed the matter, and he agreed to change (my Dinars). He took the gold pieces in his hands and fidgeted with them, and then said, "Wait till my storekeeper comes from the forest." `Umar was listening to that and said, "By Allah! You should not separate from Talha till you get the money from him, for Allah's Messenger (ﷺ) said, 'The selling of gold for gold is Riba (usury) except if the exchange is from hand to hand and equal in amount, and similarly, the selling of wheat for wheat is Riba (usury) unless it is from hand to hand and equal in amount, and the selling of barley for barley is usury unless it is from hand to hand and equal in amount, and dates for dates, is usury unless it is from hand to hand and equal in amount}}
\hadithdefcmd{bukhari}{2175}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي إِسْحَاقَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، قَالَ قَالَ أَبُو بَكْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ إِلاَّ سَوَاءً بِسَوَاءٍ، وَالْفِضَّةَ بِالْفِضَّةِ إِلاَّ سَوَاءً بِسَوَاءٍ، وَبِيعُوا الذَّهَبَ بِالْفِضَّةِ وَالْفِضَّةَ بِالذَّهَبِ كَيْفَ شِئْتُمْ ‏"‏‏.‏\hadithno{2175}\hadithtrans{Narrated Abu Bakra:Allah's Messenger (ﷺ) said, "Don't sell gold for gold unless equal in weight, nor silver for silver unless equal in weight, but you could sell gold for silver or silver for gold as you like}}
\hadithdefcmd{bukhari}{2176}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ، حَدَّثَنَا عَمِّي، حَدَّثَنَا ابْنُ أَخِي الزُّهْرِيِّ، عَنْ عَمِّهِ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ أَبَا سَعِيدٍ، حَدَّثَهُ مِثْلَ، ذَلِكَ حَدِيثًا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَقِيَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ فَقَالَ يَا أَبَا سَعِيدٍ، مَا هَذَا الَّذِي تُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَبُو سَعِيدٍ فِي الصَّرْفِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الذَّهَبُ بِالذَّهَبِ مِثْلاً بِمِثْلٍ وَالْوَرِقُ بِالْوَرِقِ مِثْلاً بِمِثْلٍ ‏"‏‏.‏\hadithno{2176}\hadithtrans{Narrated Abu Sa`id:(Concerning exchange) that he heard Allah's Messenger (ﷺ) saying, "Do not sell gold for gold unless equal in weight, and do not sell silver unless equal in weight}}
\hadithdefcmd{bukhari}{2177}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ إِلاَّ مِثْلاً بِمِثْلٍ، وَلاَ تُشِفُّوا بَعْضَهَا عَلَى بَعْضٍ، وَلاَ تَبِيعُوا الْوَرِقَ بِالْوَرِقِ إِلاَّ مِثْلاً بِمِثْلٍ، وَلاَ تُشِفُّوا بَعْضَهَا عَلَى بَعْضٍ، وَلاَ تَبِيعُوا مِنْهَا غَائِبًا بِنَاجِزٍ ‏"‏\hadithno{2177}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "Do not sell gold for gold unless equivalent in weight, and do not sell less amount for greater amount or vice versa; and do not sell silver for silver unless equivalent in weight, and do not sell less amount for greater amount or vice versa and do not sell gold or silver that is not present at the moment of exchange for gold or silver that is present}}
\hadithdefcmd{bukhari}{2179}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّ أَبَا صَالِحٍ الزَّيَّاتَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ يَقُولُ الدِّينَارُ بِالدِّينَارِ، وَالدِّرْهَمُ بِالدِّرْهَمِ‏.‏ فَقُلْتُ لَهُ فَإِنَّ ابْنَ عَبَّاسٍ لاَ يَقُولُهُ‏.‏ فَقَالَ أَبُو سَعِيدٍ سَأَلْتُهُ فَقُلْتُ سَمِعْتَهُ مِنَ النَّبِيِّ، صلى الله عليه وسلم، أَوْ وَجَدْتَهُ فِي كِتَابِ اللَّهِ قَالَ كُلُّ ذَلِكَ لاَ أَقُولُ، وَأَنْتُمْ أَعْلَمُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنِّي، وَلَكِنَّنِي أَخْبَرَنِي أُسَامَةُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ رِبًا إِلاَّ فِي النَّسِيئَةِ ‏"‏‏.‏\hadithno{2179}\hadithtrans{Narrated Abu Salih Az-Zaiyat:I heard Abu Sa`id Al-Khudri saying, "The selling of a Dinar for a Dinar, and a Dirham for a Dirham (is permissible)." I said to him, "Ibn `Abbas does not say the same." Abu Sa`id replied, "I asked Ibn `Abbas whether he had heard it from the Prophet (ﷺ) or seen it in the Holy Book. Ibn `Abbas replied, "I do not claim that, and you know Allah's Messenger (ﷺ) better than I, but Usama informed me that the Prophet had said, 'There is no Riba (in money exchange) except when it is not done from hand to hand (i.e. when there is delay in payment)}}
\hadithdefcmd{bukhari}{2181}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي حَبِيبُ بْنُ أَبِي ثَابِتٍ، قَالَ سَمِعْتُ أَبَا الْمِنْهَالِ، قَالَ سَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ وَزَيْدَ بْنَ أَرْقَمَ ـ رضى الله عنهم ـ عَنِ الصَّرْفِ،، فَكُلُّ وَاحِدٍ مِنْهُمَا يَقُولُ هَذَا خَيْرٌ مِنِّي‏.‏ فَكِلاَهُمَا يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الذَّهَبِ بِالْوَرِقِ دَيْنًا‏.‏\hadithno{2181}\hadithtrans{Narrated Abu Al-Minhal:I asked Al-Bara' bin `Azib and Zaid bin Arqam about money exchanges. Each of them said, "This is better than I," and both of them said, "Allah's Messenger (ﷺ) forbade the selling of silver for gold on credit}}
\hadithdefcmd{bukhari}{2182}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، أَخْبَرَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الْفِضَّةِ بِالْفِضَّةِ وَالذَّهَبِ بِالذَّهَبِ، إِلاَّ سَوَاءً بِسَوَاءٍ، وَأَمَرَنَا أَنْ نَبْتَاعَ الذَّهَبَ بِالْفِضَّةِ كَيْفَ شِئْنَا، وَالْفِضَّةَ بِالذَّهَبِ كَيْفَ شِئْنَا‏.‏\hadithno{2182}\hadithtrans{Narrated `Abdur-Rahman bin Abu Bakra:that his father said, "The Prophet (ﷺ) forbade the selling of gold for gold and silver for silver except if they are equivalent in weight, and allowed us to sell gold for silver and vice versa as we wished}}
\hadithdefcmd{bukhari}{2184}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبِيعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ، وَلاَ تَبِيعُوا الثَّمَرَ بِالتَّمْرِ ‏"‏ قَالَ سَالِمٌ وَأَخْبَرَنِي عَبْدُ اللَّهِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ بَعْدَ ذَلِكَ فِي بَيْعِ الْعَرِيَّةِ بِالرُّطَبِ أَوْ بِالتَّمْرِ، وَلَمْ يُرَخِّصْ فِي غَيْرِهِ‏.‏\hadithno{2184}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Do not sell fruits of dates until they become free from all the dangers of being spoilt or blighted; and do not sell fresh dates for dry dates." Narrated Salim and `Abdullah from Zaid bin Thabit: "Later on Allah's Messenger (ﷺ) permitted the selling of ripe fruits on trees for fresh dates or dried dates in Bai'-al-'Araya, and did not allow it for any other kind of sale}}
\hadithdefcmd{bukhari}{2185}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ‏.‏ وَالْمُزَابَنَةُ اشْتِرَاءُ الثَّمَرِ بِالتَّمْرِ كَيْلاً، وَبَيْعُ الْكَرْمِ بِالزَّبِيبِ كَيْلاً‏.‏\hadithno{2185}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) forbade Muzabana; and Muzabana means the selling of fresh dates (on the trees) for dried dates by measure and also the selling of fresh grapes for dried grapes by measure}}
\hadithdefcmd{bukhari}{2186}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي سُفْيَانَ، مَوْلَى ابْنِ أَبِي أَحْمَدَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ وَالْمُحَاقَلَةِ‏.‏ وَالْمُزَابَنَةُ اشْتِرَاءُ الثَّمَرِ بِالتَّمْرِ فِي رُءُوسِ النَّخْلِ‏.‏\hadithno{2186}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) forbade Muzabana and Muhaqala; and Muzabana means the selling of ripe dates for dates still on the trees}}
\hadithdefcmd{bukhari}{2187}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الشَّيْبَانِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ‏.‏\hadithno{2187}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) forbade Muzabana and Muhaqala}}
\hadithdefcmd{bukhari}{2188}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ زَيْدِ بْنِ ثَابِتٍ ـ رضى الله عنهم ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَرْخَصَ لِصَاحِبِ الْعَرِيَّةِ أَنْ يَبِيعَهَا بِخَرْصِهَا‏.‏\hadithno{2188}\hadithtrans{Narrated Zaid bin Thabit:Allah's Messenger (ﷺ) allowed the owner of 'Araya to sell the fruits on the trees by means of estimation}}
\hadithdefcmd{bukhari}{2189}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، وَأَبِي الزُّبَيْرِ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ الثَّمَرِ حَتَّى يَطِيبَ، وَلاَ يُبَاعُ شَىْءٌ مِنْهُ إِلاَّ بِالدِّينَارِ وَالدِّرْهَمِ إِلاَّ الْعَرَايَا‏.‏\hadithno{2189}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) forbade the selling of fruits unless they get ripe, and none of them should be sold except for Dinar or Dirham (i.e. money), except the 'Araya trees (the dates of which could be sold for dates)}}
\hadithdefcmd{bukhari}{2190}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، قَالَ سَمِعْتُ مَالِكًا، وَسَأَلَهُ، عُبَيْدُ اللَّهِ بْنُ الرَّبِيعِ أَحَدَّثَكَ دَاوُدُ عَنْ أَبِي سُفْيَانَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا فِي خَمْسَةِ أَوْسُقٍ أَوْ دُونَ خَمْسَةِ أَوْسُقٍ قَالَ نَعَمْ‏.‏\hadithno{2190}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) allowed the sale of the dates of 'Araya provided they were about five Awsuq (singular: Wasaq which means sixty Sa's) or less (in amount)}}
\hadithdefcmd{bukhari}{2191}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ قَالَ يَحْيَى بْنُ سَعِيدٍ سَمِعْتُ بُشَيْرًا، قَالَ سَمِعْتُ سَهْلَ بْنَ أَبِي حَثْمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ بِالتَّمْرِ، وَرَخَّصَ فِي الْعَرِيَّةِ أَنْ تُبَاعَ بِخَرْصِهَا يَأْكُلُهَا أَهْلُهَا رُطَبًا‏.‏ وَقَالَ سُفْيَانُ مَرَّةً أُخْرَى إِلاَّ أَنَّهُ رَخَّصَ فِي الْعَرِيَّةِ يَبِيعُهَا أَهْلُهَا بِخَرْصِهَا، يَأْكُلُونَهَا رُطَبًا‏.‏ قَالَ هُوَ سَوَاءٌ‏.‏ قَالَ سُفْيَانُ فَقُلْتُ لِيَحْيَى وَأَنَا غُلاَمٌ إِنَّ أَهْلَ مَكَّةَ يَقُولُونَ إِنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا‏.‏ فَقَالَ وَمَا يُدْرِي أَهْلَ مَكَّةَ قُلْتُ إِنَّهُمْ يَرْوُونَهُ عَنْ جَابِرٍ‏.‏ فَسَكَتَ‏.‏ قَالَ سُفْيَانُ إِنَّمَا أَرَدْتُ أَنَّ جَابِرًا مِنْ أَهْلِ الْمَدِينَةِ‏.‏ قِيلَ لِسُفْيَانَ وَلَيْسَ فِيهِ نَهْىٌ عَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهُ قَالَ لاَ‏.‏\hadithno{2191}\hadithtrans{Narrated Sahl bin Abu Hathma:Allah's Messenger (ﷺ) forbade the selling of fruits (fresh dates) for dried dates but allowed the sale of fruits on the 'Araya by estimation and their new owners might eat their dates fresh. Sufyan (in another narration) said, "I told Yahya (a sub-narrator) when I was a mere boy, 'Meccans say that the Prophet (ﷺ) allowed them the sale of the fruits on 'Araya by estimation.' Yahya asked, 'How do the Meccans know about it?' I replied, 'They narrated it (from the Prophet (ﷺ) ) through Jabir.' On that, Yahya kept quiet." Sufyan said, "I meant that Jabir belonged to Medina." Sufyan was asked whether in Jabir's narration there was any prohibition of selling fruits before their benefit is evident (i.e. no dangers of being spoilt or blighted). He replied that there was none}}
\hadithdefcmd{bukhari}{2192}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ زَيْدِ بْنِ ثَابِتٍ ـ رضى الله عنهم ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي الْعَرَايَا أَنْ تُبَاعَ بِخَرْصِهَا كَيْلاً‏.‏ قَالَ مُوسَى بْنُ عُقْبَةَ وَالْعَرَايَا نَخَلاَتٌ مَعْلُومَاتٌ تَأْتِيهَا فَتَشْتَرِيهَا‏.‏\hadithno{2192}\hadithtrans{Narrated Ibn `Umar from Zaid bin Thabit:Allah's Messenger (ﷺ) allowed the sale of 'Araya by estimating the dates on them for measured amounts of dried dates. Musa bin `Uqba said, "Al- 'Araya were distinguished date palms; one could come and buy them (i.e. their fruits)}}
\hadithdefcmd{bukhari}{2193}{وَقَالَ اللَّيْثُ عَنْ أَبِي الزِّنَادِ، كَانَ عُرْوَةُ بْنُ الزُّبَيْرِ يُحَدِّثُ عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ الأَنْصَارِيِّ، مِنْ بَنِي حَارِثَةَ أَنَّهُ حَدَّثَهُ عَنْ زَيْدِ بْنِ ثَابِتٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّاسُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَتَبَايَعُونَ الثِّمَارَ، فَإِذَا جَدَّ النَّاسُ وَحَضَرَ تَقَاضِيهِمْ قَالَ الْمُبْتَاعُ إِنَّهُ أَصَابَ الثَّمَرَ الدُّمَانُ أَصَابَهُ مُرَاضٌ أَصَابَهُ قُشَامٌ ـ عَاهَاتٌ يَحْتَجُّونَ بِهَا ـ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَمَّا كَثُرَتْ عِنْدَهُ الْخُصُومَةُ فِي ذَلِكَ ‏ "‏ فَإِمَّا لاَ فَلاَ يَتَبَايَعُوا حَتَّى يَبْدُوَ صَلاَحُ الثَّمَرِ ‏"‏‏.‏ كَالْمَشُورَةِ يُشِيرُ بِهَا لِكَثْرَةِ خُصُومَتِهِمْ‏.‏ وَأَخْبَرَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ أَنَّ زَيْدَ بْنَ ثَابِتٍ لَمْ يَكُنْ يَبِيعُ ثِمَارَ أَرْضِهِ حَتَّى تَطْلُعَ الثُّرَيَّا فَيَتَبَيَّنَ الأَصْفَرُ مِنَ الأَحْمَرِ‏.‏ قَالَ أَبُو عَبْد اللَّهِ رَوَاهُ عَلِيُّ بْنُ بَحْرٍ حَدَّثَنَا حَكَّامٌ حَدَّثَنَا عَنْبَسَةُ عَنْ زَكَرِيَّاءَ عَنْ أَبِي الزِّنَادِ عَنْ عُرْوَةَ عَنْ سَهْلٍ عَنْ زَيْدٍ\hadithno{2193}\hadithtrans{Zaid bin Thabit (ra) said, "In the lifetime of Allah's Messenger (ﷺ), the people used to trade with fruits. When they cut their date-fruits and the purchasers came to recieve their rights, the seller would say, 'My dates have got rotten, they are blighted with disease, they are afflicted with Qusham (a disease which causes the fruit to fall before ripening).' They would go on complaining of defects in their purchases. Allah's Messenger (ﷺ) said, "Do not sell the fruits before their benefit is evident (i.e. free from all the dangers of being spoiled or blighted), by way of advice for they quarrelled too much." Kharija bin Zaid bin Thabit said that Zaid bin Thabit (ra) used not to sell the fruits of his land till Pleiades appeared and one could distinguish the yellow fruits from the red (ripe) ones}}
\hadithdefcmd{bukhari}{2194}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثِّمَارِ حَتَّى يَبْدُوَ صَلاَحُهَا، نَهَى الْبَائِعَ وَالْمُبْتَاعَ‏.‏\hadithno{2194}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) forbade the sale of fruits till their benefit is evident. He forbade both the seller and the buyer (such sale)}}
\hadithdefcmd{bukhari}{2195}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ تُبَاعَ ثَمَرَةُ النَّخْلِ حَتَّى تَزْهُوَ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ يَعْنِي حَتَّى تَحْمَرَّ‏.‏\hadithno{2195}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) forbade the sale of date fruits till they were ripe. Abu `Abdullah (Al-Bukhari) said, "That means till they were red (can be eaten)}}
\hadithdefcmd{bukhari}{2196}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سَلِيمِ بْنِ حَيَّانَ، حَدَّثَنَا سَعِيدُ بْنُ مِينَا، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ تُبَاعَ الثَّمَرَةُ حَتَّى تُشَقِّحَ‏.‏ فَقِيلَ مَا تُشَقِّحُ قَالَ تَحْمَارُّ وَتَصْفَارُّ وَيُؤْكَلُ مِنْهَا‏.‏\hadithno{2196}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) forbade the sale of (date) fruits till they were red or yellow and fit for eating}}
\hadithdefcmd{bukhari}{2197}{حَدَّثَنِي عَلِيُّ بْنُ الْهَيْثَمِ، حَدَّثَنَا مُعَلًّى، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حُمَيْدٌ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ بَيْعِ الثَّمَرَةِ حَتَّى يَبْدُوَ صَلاَحُهَا، وَعَنِ النَّخْلِ حَتَّى يَزْهُوَ‏.‏ قِيلَ وَمَا يَزْهُو قَالَ يَحْمَارُّ أَوْ يَصْفَارُّ‏.‏\hadithno{2197}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) forbade the sale of fruits till their benefit is evident; and the sale of date palms till the dates are almost ripe. He was asked what 'are almost ripe' meant. He replied, "Got red and yellow}}
\hadithdefcmd{bukhari}{2198}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثِّمَارِ حَتَّى تُزْهِيَ‏.‏ فَقِيلَ لَهُ وَمَا تُزْهِي قَالَ حَتَّى تَحْمَرَّ‏.‏ فَقَالَ ‏ "‏ أَرَأَيْتَ إِذَا مَنَعَ اللَّهُ الثَّمَرَةَ، بِمَ يَأْخُذُ أَحَدُكُمْ مَالَ أَخِيهِ ‏"‏‏.‏\hadithno{2198}\hadithtrans{Narrated Anas bin Malik: Allah's Messenger (ﷺ) forbade the sale of fruits till they are almost ripe. He was asked what is meant by 'are almost ripe.' He replied, "Till they become red." Allah's Messenger (ﷺ) further said, "If Allah spoiled the fruits, what right would one have to take the money of one's brother (i.e. other people)?}}
\hadithdefcmd{bukhari}{2199}{قَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ لَوْ أَنَّ رَجُلاً، ابْتَاعَ ثَمَرًا قَبْلَ أَنْ يَبْدُوَ صَلاَحُهُ، ثُمَّ أَصَابَتْهُ عَاهَةٌ، كَانَ مَا أَصَابَهُ عَلَى رَبِّهِ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَتَبَايَعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهَا، وَلاَ تَبِيعُوا الثَّمَرَ بِالتَّمْرِ ‏"‏‏.‏\hadithno{2199}\hadithtrans{Narrated Ibn Shihab:If somebody bought fruits before their benefit is evident and then the fruits were spoiled with blights, the loss would be suffered by the owner (not the buyer). Narrated Salim bin 'Abdullah from Ibn Umar: Allah's Messenger (ﷺ) said, "Do not sell or buy fruits before their benefit was evident and do not sell fresh fruits (dates) for dried dates}}
\hadithdefcmd{bukhari}{2200}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ ذَكَرْنَا عِنْدَ إِبْرَاهِيمَ الرَّهْنَ فِي السَّلَفِ، فَقَالَ لاَ بَأْسَ بِهِ‏.‏ ثُمَّ حَدَّثَنَا عَنِ الأَسْوَدِ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم اشْتَرَى طَعَامًا مِنْ يَهُودِيٍّ إِلَى أَجَلٍ، فَرَهَنَهُ دِرْعَهُ‏.‏\hadithno{2200}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) bought some foodstuff from a Jew on credit and mortgaged his armor to him}}
\hadithdefcmd{bukhari}{2202}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَعَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً عَلَى خَيْبَرَ، فَجَاءَهُ بِتَمْرٍ جَنِيبٍ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ، إِنَّا لَنَأْخُذُ الصَّاعَ مِنْ هَذَا بِالصَّاعَيْنِ، وَالصَّاعَيْنِ بِالثَّلاَثَةِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَفْعَلْ، بِعِ الْجَمْعَ بِالدَّرَاهِمِ، ثُمَّ ابْتَعْ بِالدَّرَاهِمِ جَنِيبًا ‏"‏‏.‏\hadithno{2202}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:Allah's Messenger (ﷺ) appointed somebody as a governor of Khaibar. That governor brought to him an excellent kind of dates (from Khaibar). The Prophet (ﷺ) asked, "Are all the dates of Khaibar like this?" He replied, "By Allah, no, O Allah's Messenger (ﷺ)! But we barter one Sa of this (type of dates) for two Sas of dates of ours and two Sas of it for three of ours." Allah's Messenger (ﷺ) said, "Do not do so (as that is a kind of usury) but sell the mixed dates (of inferior quality) for money, and then buy good dates with that money}}
\hadithdefcmd{bukhari}{2203}{قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ لِي إِبْرَاهِيمُ أَخْبَرَنَا هِشَامٌ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، يُخْبِرُ عَنْ نَافِعٍ، مَوْلَى ابْنِ عُمَرَ أَنَّ أَيُّمَا، نَخْلٍ بِيعَتْ قَدْ أُبِّرَتْ لَمْ يُذْكَرِ الثَّمَرُ، فَالثَّمَرُ لِلَّذِي أَبَّرَهَا، وَكَذَلِكَ الْعَبْدُ وَالْحَرْثُ‏.‏ سَمَّى لَهُ نَافِعٌ هَؤُلاَءِ الثَّلاَثَ‏.‏\hadithno{2203}\hadithtrans{Narrated Nafi', the freed slave of Ibn 'Umar:If pollinated date-palms are sold and nothing is mentioned (in the contract) about their fruits, the fruits will go to the person who has pollinated them, and so will be the case with the slave and the cultivator. Nafi' mentioned those three things}}
\hadithdefcmd{bukhari}{2204}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ بَاعَ نَخْلاً قَدْ أُبِّرَتْ فَثَمَرُهَا لِلْبَائِعِ، إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏‏.‏\hadithno{2204}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "If somebody sells pollinated date palms, the fruits will be for the seller unless the buyer stipulates that they will be for himself (and the seller agrees)}}
\hadithdefcmd{bukhari}{2205}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُزَابَنَةِ أَنْ يَبِيعَ ثَمَرَ حَائِطِهِ إِنْ كَانَ نَخْلاً بِتَمْرٍ كَيْلاً، وَإِنْ كَانَ كَرْمًا أَنْ يَبِيعَهُ بِزَبِيبٍ كَيْلاً أَوْ كَانَ زَرْعًا أَنْ يَبِيعَهُ بِكَيْلِ طَعَامٍ، وَنَهَى عَنْ ذَلِكَ كُلِّهِ‏.‏\hadithno{2205}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) forbade Al-Muzabana, i.e. to sell ungathered dates of one's garden for measured dried dates or fresh ungathered grapes for measured dried grapes; or standing crops for measured quantity of foodstuff. He forbade all such bargains}}
\hadithdefcmd{bukhari}{2206}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرِئٍ أَبَّرَ نَخْلاً ثُمَّ بَاعَ أَصْلَهَا، فَلِلَّذِي أَبَّرَ ثَمَرُ النَّخْلِ، إِلاَّ أَنْ يَشْتَرِطَهُ الْمُبْتَاعُ ‏"‏‏.‏\hadithno{2206}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Whoever pollinates date palms and then sells them, the fruits will belong to him unless the buyer stipulates that the fruits should belong to him (and the seller agrees)}}
\hadithdefcmd{bukhari}{2207}{حَدَّثَنَا إِسْحَاقُ بْنُ وَهْبٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِسْحَاقُ بْنُ أَبِي طَلْحَةَ الأَنْصَارِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ، وَالْمُخَاضَرَةِ، وَالْمُلاَمَسَةِ، وَالْمُنَابَذَةِ، وَالْمُزَابَنَةِ‏.‏\hadithno{2207}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) forbade Muhaqala, Mukhadara, Mulamasa, Munabadha and Muzabana. (See glossary and previous Hadiths for the meanings of these terms)}}
\hadithdefcmd{bukhari}{2208}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ ثَمَرِ التَّمْرِ حَتَّى تَزْهُوَ‏.‏ فَقُلْنَا لأَنَسٍ مَا زَهْوُهَا قَالَ تَحْمَرُّ وَتَصْفَرُّ، أَرَأَيْتَ إِنْ مَنَعَ اللَّهُ الثَّمَرَةَ بِمَ تَسْتَحِلُّ مَالَ أَخِيكَ\hadithno{2208}\hadithtrans{Narrated Humaid:Anas said, "The Prophet (ﷺ) forbade the selling of dates till they were almost ripe." We asked Anas, "What does 'almost ripe' mean?" He replied, "They get red and yellow. The Prophet (ﷺ) added, 'If Allah destroyed the fruits present on the trees, what right would the seller have to take the money of his brother (somebody else)?}}
\hadithdefcmd{bukhari}{2209}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم وَهْوَ يَأْكُلُ جُمَّارًا، فَقَالَ ‏"‏ مِنَ الشَّجَرِ شَجَرَةٌ كَالرَّجُلِ الْمُؤْمِنِ ‏"‏‏.‏ فَأَرَدْتُ أَنْ أَقُولَ هِيَ النَّخْلَةُ‏.‏ فَإِذَا أَنَا أَحْدَثُهُمْ قَالَ ‏"‏ هِيَ النَّخْلَةُ ‏"‏‏.‏\hadithno{2209}\hadithtrans{Narrated Ibn `Umar:I was with the Prophet (ﷺ) while he was eating fresh dates. He said, "From the trees there is a tree which resembles a faithful believer." I wanted to say that it was the date palm, but I was the youngest among them (so I kept quiet). He added, "It is the date palm}}
\hadithdefcmd{bukhari}{2210}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ حَجَمَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَبُو طَيْبَةَ، فَأَمَرَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَاعٍ مِنْ تَمْرٍ، وَأَمَرَ أَهْلَهُ أَنْ يُخَفِّفُوا عَنْهُ مِنْ خَرَاجِهِ‏.‏\hadithno{2210}\hadithtrans{Narrated Anas bin Malik:Abu Taiba cupped Allah's Messenger (ﷺ) and so Allah's Messenger (ﷺ) ordered that a Sa of dates be paid to him and ordered his masters (for he was a slave) to reduce his tax}}
\hadithdefcmd{bukhari}{2211}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ هِنْدٌ أُمُّ مُعَاوِيَةَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ أَبَا سُفْيَانَ رَجُلٌ شَحِيحٌ، فَهَلْ عَلَىَّ جُنَاحٌ أَنْ آخُذَ مِنْ مَالِهِ سِرًّا قَالَ ‏ "‏ خُذِي أَنْتِ وَبَنُوكِ مَا يَكْفِيكِ بِالْمَعْرُوفِ ‏"‏‏.‏\hadithno{2211}\hadithtrans{Narrated `Aisha:Hind, the mother of Mu'awiya said to Allah's Messenger (ﷺ), "Abu Sufyan (her husband) is a miser. Am I allowed to take from his money secretly?" The Prophet (ﷺ) said to her, "You and your sons may take what is sufficient reasonably and fairly}}
\hadithdefcmd{bukhari}{2212}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا ابْنُ نُمَيْرٍ، أَخْبَرَنَا هِشَامٌ، وَحَدَّثَنِي مُحَمَّدٌ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ فَرْقَدٍ، قَالَ سَمِعْتُ هِشَامَ بْنَ عُرْوَةَ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّهُ سَمِعَ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ ‏\{‏وَمَنْ كَانَ غَنِيًّا فَلْيَسْتَعْفِفْ وَمَنْ كَانَ فَقِيرًا فَلْيَأْكُلْ بِالْمَعْرُوفِ‏\}‏ أُنْزِلَتْ فِي وَالِي الْيَتِيمِ الَّذِي يُقِيمُ عَلَيْهِ، وَيُصْلِحُ فِي مَالِهِ، إِنْ كَانَ فَقِيرًا أَكَلَ مِنْهُ بِالْمَعْرُوفِ‏.‏\hadithno{2212}\hadithtrans{Narrated Hisham bin `Urwa from his father:who heard Aisha saying, "The Holy Verse; 'Whoever amongst the guardians is rich, he should take no wages (from the property of the orphans) but If he is poor, let him have for himself what is just and reasonable (according to his labors)' (4.6) was revealed concerning the guardian of the orphans who looks after them and manages favorably their financial affairs; If the guardian Is poor, he could have from It what Is just and reasonable, (according to his labors)}}
\hadithdefcmd{bukhari}{2213}{حَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ ـ رضى الله عنه ـ جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الشُّفْعَةَ فِي كُلِّ مَالٍ لَمْ يُقْسَمْ، فَإِذَا وَقَعَتِ الْحُدُودُ وَصُرِّفَتِ الطُّرُقُ فَلاَ شُفْعَةَ‏.‏\hadithno{2213}\hadithtrans{Narrated Jabir:Allah's Messenger (ﷺ) gave preemption (to the partner) in every joint property, but if the boundaries of the property were demarcated or the ways and streets were fixed, then there was no pre-emption}}
\hadithdefcmd{bukhari}{2214}{حَدَّثَنَا مُحَمَّدُ بْنُ مَحْبُوبٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَضَى النَّبِيُّ صلى الله عليه وسلم بِالشُّفْعَةِ فِي كُلِّ مَالٍ لَمْ يُقْسَمْ، فَإِذَا وَقَعَتِ الْحُدُودُ وَصُرِّفَتِ الطُّرُقُ فَلاَ شُفْعَةَ‏.‏\hadithno{2214}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) decided the validity of preemption in every joint undivided property, but if the boundaries were well marked or the ways and streets were fixed, then there was no pre-emption}}
\hadithdefcmd{bukhari}{2214p2}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، بِهَذَا وَقَالَ فِي كُلِّ مَا لَمْ يُقْسَمْ‏.‏ تَابَعَهُ هِشَامٌ عَنْ مَعْمَرٍ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ فِي كُلِّ مَالٍ‏.‏ رَوَاهُ عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ عَنِ الزُّهْرِيِّ‏.‏\hadithno{2214.2}\hadithtrans{Narrated Mussaddad from `Abdul Wahid:the same as above but said, "... in every joint undivided thing..." Narrated Hisham from Ma`mar the same as above but said, " ... in every property}}
\hadithdefcmd{bukhari}{2215}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَرَجَ ثَلاَثَةٌ يَمْشُونَ فَأَصَابَهُمُ الْمَطَرُ، فَدَخَلُوا فِي غَارٍ فِي جَبَلٍ، فَانْحَطَّتْ عَلَيْهِمْ صَخْرَةٌ‏.‏ قَالَ فَقَالَ بَعْضُهُمْ لِبَعْضٍ ادْعُوا اللَّهَ بِأَفْضَلِ عَمَلٍ عَمِلْتُمُوهُ‏.‏ فَقَالَ أَحَدُهُمُ اللَّهُمَّ، إِنِّي كَانَ لِي أَبَوَانِ شَيْخَانِ كَبِيرَانِ، فَكُنْتُ أَخْرُجُ فَأَرْعَى، ثُمَّ أَجِيءُ فَأَحْلُبُ، فَأَجِيءُ بِالْحِلاَبِ فَآتِي بِهِ أَبَوَىَّ فَيَشْرَبَانِ، ثُمَّ أَسْقِي الصِّبْيَةَ وَأَهْلِي وَامْرَأَتِي، فَاحْتَبَسْتُ لَيْلَةً‏.‏ فَجِئْتُ فَإِذَا هُمَا نَائِمَانِ ـ قَالَ ـ فَكَرِهْتُ أَنْ أُوقِظَهُمَا، وَالصِّبِيْةُ يَتَضَاغَوْنَ عِنْدَ رِجْلَىَّ، فَلَمْ يَزَلْ ذَلِكَ دَأْبِي وَدَأْبَهُمَا، حَتَّى طَلَعَ الْفَجْرُ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ عَنَّا فُرْجَةً نَرَى مِنْهَا السَّمَاءَ‏.‏ قَالَ فَفُرِجَ عَنْهُمْ‏.‏ وَقَالَ الآخَرُ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنِّي كُنْتُ أُحِبُّ امْرَأَةً مِنْ بَنَاتِ عَمِّي كَأَشَدِّ مَا يُحِبُّ الرَّجُلُ النِّسَاءَ، فَقَالَتْ لاَ تَنَالُ ذَلِكَ مِنْهَا حَتَّى تُعْطِيَهَا مِائَةَ دِينَارٍ‏.‏ فَسَعَيْتُ فِيهَا حَتَّى جَمَعْتُهَا، فَلَمَّا قَعَدْتُ بَيْنَ رِجْلَيْهَا قَالَتِ اتَّقِ اللَّهَ، وَلاَ تَفُضَّ الْخَاتَمَ إِلاَّ بِحَقِّهِ‏.‏ فَقُمْتُ وَتَرَكْتُهَا، فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ عَنَّا فُرْجَةً، قَالَ فَفَرَجَ عَنْهُمُ الثُّلُثَيْنِ‏.‏ وَقَالَ الآخَرُ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنِّي اسْتَأْجَرْتُ أَجِيرًا بِفَرَقٍ مِنْ ذُرَةٍ فَأَعْطَيْتُهُ، وَأَبَى ذَاكَ أَنْ يَأْخُذَ، فَعَمَدْتُ إِلَى ذَلِكَ الْفَرَقِ، فَزَرَعْتُهُ حَتَّى اشْتَرَيْتُ مِنْهُ بَقَرًا وَرَاعِيَهَا، ثُمَّ جَاءَ فَقَالَ يَا عَبْدَ اللَّهِ أَعْطِنِي حَقِّي‏.‏ فَقُلْتُ انْطَلِقْ إِلَى تِلْكَ الْبَقَرِ وَرَاعِيهَا، فَإِنَّهَا لَكَ‏.‏ فَقَالَ أَتَسْتَهْزِئُ بِي‏.‏ قَالَ فَقُلْتُ مَا أَسْتَهْزِئُ بِكَ وَلَكِنَّهَا لَكَ‏.‏ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ عَنَّا‏.‏ فَكُشِفَ عَنْهُمْ ‏"‏‏.‏\hadithno{2215}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "While three persons were walking, rain began to fall and they had to enter a cave in a mountain. A big rock rolled over and blocked the mouth of the cave. They said to each other, 'Invoke Allah with the best deed you have performed (so Allah might remove the rock)'. One of them said, 'O Allah! My parents were old and I used to go out for grazing (my animals). On my return I would milk (the animals) and take the milk in a vessel to my parents to drink. After they had drunk from it, I would give it to my children, family and wife. One day I was delayed and on my return I found my parents sleeping, and I disliked to wake them up. The children were crying at my feet (because of hunger). That state of affairs continued till it was dawn. O Allah! If You regard that I did it for Your sake, then please remove this rock so that we may see the sky.' So, the rock was moved a bit. The second said, 'O Allah! You know that I was in love with a cousin of mine, like the deepest love a man may have for a woman, and she told me that I would not get my desire fulfilled unless I paid her one-hundred Dinars (gold pieces). So, I struggled for it till I gathered the desired amount, and when I sat in between her legs, she told me to be afraid of Allah, and asked me not to deflower her except rightfully (by marriage). So, I got up and left her. O Allah! If You regard that I did it for Your sake, kindly remove this rock.' So, two-thirds of the rock was removed. Then the third man said, 'O Allah! No doubt You know that once I employed a worker for one Faraq (three Sa's) of millet, and when I wanted to pay him, he refused to take it, so I sowed it and from its yield I bought cows and a shepherd. After a time that man came and demanded his money. I said to him: Go to those cows and the shepherd and take them for they are for you. He asked me whether I was joking with him. I told him that I was not joking with him, and all that belonged to him. O Allah! If You regard that I did it sincerely for Your sake, then please remove the rock.' So, the rock was removed completely from the mouth of the cave}}
\hadithdefcmd{bukhari}{2216}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ أَبِي عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ جَاءَ رَجُلٌ مُشْرِكٌ مُشْعَانٌّ طَوِيلٌ بِغَنَمٍ يَسُوقُهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بَيْعًا أَمْ عَطِيَّةً أَوْ قَالَ أَمْ هِبَةً ‏"‏‏.‏ قَالَ لاَ بَلْ بَيْعٌ‏.‏ فَاشْتَرَى مِنْهُ شَاةً‏.‏\hadithno{2216}\hadithtrans{Narrated `Abdur-Rahman bin Abu Bakr:We were with the Prophet (ﷺ) when a tall pagan with long matted unkempt hair came driving his sheep. The Prophet (ﷺ) asked him, "Are those sheep for sale or for gifts?" The pagan replied, "They are for sale." The Prophet (ﷺ) bought one sheep from him}}
\hadithdefcmd{bukhari}{2217}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ هَاجَرَ إِبْرَاهِيمُ ـ عَلَيْهِ السَّلاَمُ ـ بِسَارَةَ، فَدَخَلَ بِهَا قَرْيَةً فِيهَا مَلِكٌ مِنَ الْمُلُوكِ، أَوْ جَبَّارٌ مِنَ الْجَبَابِرَةِ، فَقِيلَ دَخَلَ إِبْرَاهِيمُ بِامْرَأَةٍ، هِيَ مِنْ أَحْسَنِ النِّسَاءِ‏.‏ فَأَرْسَلَ إِلَيْهِ أَنْ يَا إِبْرَاهِيمُ، مَنْ هَذِهِ الَّتِي مَعَكَ قَالَ أُخْتِي‏.‏ ثُمَّ رَجَعَ إِلَيْهَا، فَقَالَ لاَ تُكَذِّبِي حَدِيثِي فَإِنِّي أَخْبَرْتُهُمْ أَنَّكِ أُخْتِي، وَاللَّهِ إِنْ عَلَى الأَرْضِ مُؤْمِنٌ غَيْرِي وَغَيْرُكِ‏.‏ فَأَرْسَلَ بِهَا إِلَيْهِ، فَقَامَ إِلَيْهَا، فَقَامَتْ تَوَضَّأُ وَتُصَلِّي فَقَالَتِ اللَّهُمَّ إِنْ كُنْتُ آمَنْتُ بِكَ وَبِرَسُولِكَ وَأَحْصَنْتُ فَرْجِي، إِلاَّ عَلَى زَوْجِي فَلاَ تُسَلِّطْ عَلَىَّ الْكَافِرَ‏.‏ فَغُطَّ حَتَّى رَكَضَ بِرِجْلِهِ ‏"‏‏.‏ قَالَ الأَعْرَجُ قَالَ أَبُو سَلَمَةَ بْنُ عَبْدُ الرَّحْمَنِ إِنَّ أَبَا هُرَيْرَةَ قَالَ قَالَتِ اللَّهُمَّ إِنْ يَمُتْ يُقَالُ هِيَ قَتَلَتْهُ‏.‏ فَأُرْسِلَ ثُمَّ قَامَ إِلَيْهَا، فَقَامَتْ تَوَضَّأُ تُصَلِّي، وَتَقُولُ اللَّهُمَّ إِنْ كُنْتُ آمَنْتُ بِكَ وَبِرَسُولِكَ، وَأَحْصَنْتُ فَرْجِي، إِلاَّ عَلَى زَوْجِي، فَلاَ تُسَلِّطْ عَلَىَّ هَذَا الْكَافِرَ، فَغُطَّ حَتَّى رَكَضَ بِرِجْلِهِ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ قَالَ أَبُو سَلَمَةَ قَالَ أَبُو هُرَيْرَةَ فَقَالَتِ اللَّهُمَّ إِنْ يَمُتْ فَيُقَالُ هِيَ قَتَلَتْهُ، فَأُرْسِلَ فِي الثَّانِيَةِ، أَوْ فِي الثَّالِثَةِ، فَقَالَ وَاللَّهِ مَا أَرْسَلْتُمْ إِلَىَّ إِلاَّ شَيْطَانًا، ارْجِعُوهَا إِلَى إِبْرَاهِيمَ، وَأَعْطُوهَا آجَرَ‏.‏ فَرَجَعَتْ إِلَى إِبْرَاهِيمَ ـ عَلَيْهِ السَّلاَمُ ـ فَقَالَتْ أَشَعَرْتَ أَنَّ اللَّهَ كَبَتَ الْكَافِرَ وَأَخْدَمَ وَلِيدَةً‏.‏\hadithno{2217}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Prophet Abraham (ﷺ) emigrated with Sarah and entered a village where there was a king or a tyrant. (The king) was told that Abraham had entered (the village) accompanied by a woman who was one of the most charming women. So, the king sent for Abraham and asked, 'O Abraham! Who is this lady accompanying you?' Abraham replied, 'She is my sister (i.e. in religion).' Then Abraham returned to her and said, 'Do not contradict my statement, for I have informed them that you are my sister. By Allah, there are no true believers on this land except you and I.' Then Abraham sent her to the king. When the king got to her, she got up and performed ablution, prayed and said, 'O Allah! If I have believed in You and Your Apostle, and have saved my private parts from everybody except my husband, then please do not let this pagan overpower me.' On that the king fell in a mood of agitation and started moving his legs. Seeing the condition of the king, Sarah said, 'O Allah! If he should die, the people will say that I have killed him.' The king regained his power, and proceeded towards her but she got up again and performed ablution, prayed and said, 'O Allah! If I have believed in You and Your Apostle and have kept my private parts safe from all except my husband, then please do not let this pagan overpower me.' The king again fell in a mood of agitation and started moving his legs. On seeing that state of the king, Sarah said, 'O Allah! If he should die, the people will say that I have killed him.' The king got either two or three attacks, and after recovering from the last attack he said, 'By Allah! You have sent a satan to me. Take her to Abraham and give her Ajar.' So she came back to Abraham and said, 'Allah humiliated the pagan and gave us a slave-girl for service}}
\hadithdefcmd{bukhari}{2218}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتِ اخْتَصَمَ سَعْدُ بْنُ أَبِي وَقَّاصٍ وَعَبْدُ بْنُ زَمْعَةَ فِي غُلاَمٍ، فَقَالَ سَعْدٌ هَذَا يَا رَسُولَ اللَّهِ ابْنُ أَخِي عُتْبَةَ بْنِ أَبِي وَقَّاصٍ، عَهِدَ إِلَىَّ أَنَّهُ ابْنُهُ، انْظُرْ إِلَى شَبَهِهِ‏.‏ وَقَالَ عَبْدُ بْنُ زَمْعَةَ هَذَا أَخِي يَا رَسُولَ اللَّهِ وُلِدَ عَلَى فِرَاشِ أَبِي مِنْ وَلِيدَتِهِ‏.‏ فَنَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى شَبَهِهِ، فَرَأَى شَبَهًا بَيِّنًا بِعُتْبَةَ، فَقَالَ ‏ "‏ هُوَ لَكَ يَا عَبْدُ، الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ وَاحْتَجِبِي مِنْهُ يَا سَوْدَةُ بِنْتَ زَمْعَةَ ‏"‏‏.‏ فَلَمْ تَرَهُ سَوْدَةُ قَطُّ‏.‏\hadithno{2218}\hadithtrans{Narrated `Aisha:Sa`d bin Abi Waqqas and 'Abu bin Zam`a quarreled over a boy. Sa`d said, "O Allah's Messenger (ﷺ)! This boy is the son of my brother (`Utba bin Abi Waqqas) who took a promise from me that I would take him as he was his (illegal) son. Look at him and see whom he resembles." 'Abu bin Zam`a said, "O Allah's Messenger (ﷺ)! This is my brother and was born on my father's bed from his slave-girl." Allah's Apostle cast a look at the boy and found definite resemblance to `Utba and then said, "The boy is for you, O 'Abu bin Zam`a. The child goes to the owner of the bed and the adulterer gets nothing but the stones (despair, i.e. to be stoned to death). Then the Prophet (ﷺ) said, "O Sauda bint Zama! Screen yourself from this boy." So, Sauda never saw him again}}
\hadithdefcmd{bukhari}{2219}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدٍ، عَنْ أَبِيهِ، قَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ ـ رضى الله عنه ـ لِصُهَيْبٍ اتَّقِ اللَّهَ وَلاَ تَدَّعِ إِلَى غَيْرِ أَبِيكَ‏.‏ فَقَالَ صُهَيْبٌ مَا يَسُرُّنِي أَنَّ لِي كَذَا وَكَذَا، وَأَنِّي قُلْتُ ذَلِكَ، وَلَكِنِّي سُرِقْتُ وَأَنَا صَبِيٌّ‏.‏\hadithno{2219}\hadithtrans{Narrated Sa`d that his father said:`Abdur-Rahman bin `Auf said to Suhaib, 'Fear Allah and do not ascribe yourself to somebody other than your father.' Suhaib replied, 'I would not like to say it even if I were given large amounts of money, but I say I was kidnapped in my childhood}}
\hadithdefcmd{bukhari}{2220}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ حَكِيمَ بْنَ حِزَامٍ، أَخْبَرَهُ أَنَّهُ، قَالَ يَا رَسُولَ اللَّهِ، أَرَأَيْتَ أُمُورًا كُنْتُ أَتَحَنَّثُ ـ أَوْ أَتَحَنَّتُ بِهَا ـ فِي الْجَاهِلِيَّةِ مِنْ صِلَةٍ وَعَتَاقَةٍ وَصَدَقَةٍ، هَلْ لِي فِيهَا أَجْرٌ قَالَ حَكِيمٌ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَسْلَمْتَ عَلَى مَا سَلَفَ لَكَ مِنْ خَيْرٍ ‏"‏‏.‏\hadithno{2220}\hadithtrans{Narrated `Urwa bin Az-Zubair:Hakim bin Hizam said, "O Allah's Messenger (ﷺ)! I used to do good deeds in the Pre-Islamic period of Ignorance, e.g., keeping good relations with my Kith and kin, manumitting slaves and giving alms. Shall I receive a reward for all that?" Allah's Messenger (ﷺ) replied, "You embraced Islam with all the good deeds which you did in the past}}
\hadithdefcmd{bukhari}{2221}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِشَاةٍ مَيِّتَةٍ فَقَالَ ‏"‏ هَلاَّ اسْتَمْتَعْتُمْ بِإِهَابِهَا ‏"‏‏.‏ قَالُوا إِنَّهَا مَيِّتَةٌ‏.‏ قَالَ ‏"‏ إِنَّمَا حَرُمَ أَكْلُهَا ‏"‏‏.‏\hadithno{2221}\hadithtrans{Narrated `Abdullah bin `Abbas:Once Allah's Messenger (ﷺ) passed by a dead sheep and said to the people, "Wouldn't you benefit by its skin?" The people replied that it was dead. The Prophet (ﷺ) said, "But its eating only is illegal}}
\hadithdefcmd{bukhari}{2222}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَيُوشِكَنَّ أَنْ يَنْزِلَ فِيكُمُ ابْنُ مَرْيَمَ حَكَمًا مُقْسِطًا فَيَكْسِرَ الصَّلِيبَ، وَيَقْتُلَ الْخِنْزِيرَ، وَيَضَعَ الْجِزْيَةَ، وَيَفِيضَ الْمَالُ حَتَّى لاَ يَقْبَلَهُ أَحَدٌ ‏"‏‏.‏\hadithno{2222}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "By Him in Whose Hands my soul is, son of Mary (Jesus) will shortly descend amongst you people (Muslims) as a just ruler and will break the Cross and kill the pig and abolish the Jizya (a tax taken from the non-Muslims, who are in the protection, of the Muslim government). Then there will be abundance of money and nobody will accept charitable gifts}}
\hadithdefcmd{bukhari}{2223}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ أَخْبَرَنِي طَاوُسٌ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ بَلَغَ عُمَرَ أَنَّ فُلاَنًا بَاعَ خَمْرًا فَقَالَ قَاتَلَ اللَّهُ فُلاَنًا، أَلَمْ يَعْلَمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ، حُرِّمَتْ عَلَيْهِمُ الشُّحُومُ فَجَمَلُوهَا فَبَاعُوهَا ‏"‏‏.‏\hadithno{2223}\hadithtrans{Narrated Ibn `Abbas:Once `Umar was informed that a certain man sold alcohol. `Umar said, "May Allah curse him! Doesn't he know that Allah's Messenger (ﷺ) said, 'May Allah curse the Jews, for Allah had forbidden them to eat the fat of animals but they melted it and sold it}}
\hadithdefcmd{bukhari}{2224}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَاتَلَ اللَّهُ يَهُودًا حُرِّمَتْ عَلَيْهِمُ الشُّحُومُ فَبَاعُوهَا، وَأَكَلُوا أَثْمَانَهَا ‏"‏‏.‏ قَالَ أَبُو عَبْد اللَّهِ قَاتَلَهُمْ اللَّهُ لَعَنَهُمْ قُتِلَ لُعِنَ الْخَرَّاصُونَ الْكَذَّابُونَ\hadithno{2224}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "May Allah curse the Jews, because Allah made fat illegal for them but they sold it and ate its price}}
\hadithdefcmd{bukhari}{2225}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَخْبَرَنَا عَوْفٌ، عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، قَالَ كُنْتُ عِنْدَ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ إِذْ أَتَاهُ رَجُلٌ فَقَالَ يَا أَبَا عَبَّاسٍ إِنِّي إِنْسَانٌ، إِنَّمَا مَعِيشَتِي مِنْ صَنْعَةِ يَدِي، وَإِنِّي أَصْنَعُ هَذِهِ التَّصَاوِيرَ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ لاَ أُحَدِّثُكَ إِلاَّ مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ سَمِعْتُهُ يَقُولُ ‏ "‏ مَنْ صَوَّرَ صُورَةً فَإِنَّ اللَّهَ مُعَذِّبُهُ، حَتَّى يَنْفُخَ فِيهَا الرُّوحَ، وَلَيْسَ بِنَافِخٍ فِيهَا أَبَدًا ‏"‏‏.‏ فَرَبَا الرَّجُلُ رَبْوَةً شَدِيدَةً وَاصْفَرَّ وَجْهُهُ‏.‏ فَقَالَ وَيْحَكَ إِنْ أَبَيْتَ إِلاَّ أَنْ تَصْنَعَ، فَعَلَيْكَ بِهَذَا الشَّجَرِ، كُلِّ شَىْءٍ لَيْسَ فِيهِ رُوحٌ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ سَمِعَ سَعِيدُ بْنُ أَبِي عَرُوبَةَ مِنَ النَّضْرِ بْنِ أَنَسٍ هَذَا الْوَاحِدَ‏.‏\hadithno{2225}\hadithtrans{Narrated Sa`id bin Abu Al-Hasan:While I was with Ibn `Abbas a man came and said, "O father of `Abbas! My sustenance is from my manual profession and I make these pictures." Ibn `Abbas said, "I will tell you only what I heard from Allah's Messenger (ﷺ) . I heard him saying, 'Whoever makes a picture will be punished by Allah till he puts life in it, and he will never be able to put life in it.' " Hearing this, that man heaved a sigh and his face turned pale. Ibn `Abbas said to him, "What a pity! If you insist on making pictures I advise you to make pictures of trees and any other unanimated objects}}
\hadithdefcmd{bukhari}{2226}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ لَمَّا نَزَلَتْ آيَاتُ سُورَةِ الْبَقَرَةِ عَنْ آخِرِهَا خَرَجَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ حُرِّمَتِ التِّجَارَةُ فِي الْخَمْرِ ‏"‏‏.‏\hadithno{2226}\hadithtrans{Narrated `Aisha:When the last verses of Surat-al-Baqara were revealed, the Prophet (ﷺ) went out (of his house to the Mosque) and said, "The trade of alcohol has become illegal}}
\hadithdefcmd{bukhari}{2227}{حَدَّثَنِي بِشْرُ بْنُ مَرْحُومٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ ثَلاَثَةٌ أَنَا خَصْمُهُمْ يَوْمَ الْقِيَامَةِ، رَجُلٌ أَعْطَى بِي ثُمَّ غَدَرَ، وَرَجُلٌ بَاعَ حُرًّا فَأَكَلَ ثَمَنَهُ، وَرَجُلٌ اسْتَأْجَرَ أَجِيرًا فَاسْتَوْفَى مِنْهُ، وَلَمْ يُعْطِ أَجْرَهُ ‏"‏‏.‏\hadithno{2227}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah says, 'I will be against three persons on the Day of Resurrection: -1. One who makes a covenant in My Name, but he proves treacherous. -2. One who sells a free person (as a slave) and eats the price, -3. And one who employs a laborer and gets the full work done by him but does not pay him his wages}}
\hadithdefcmd{bukhari}{2228}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ فِي السَّبْىِ صَفِيَّةُ، فَصَارَتْ إِلَى دَحْيَةَ الْكَلْبِيِّ، ثُمَّ صَارَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2228}\hadithtrans{Narrated Anas:Amongst the captives was Safiya. First she was given to Dihya Al-Kalbi and then to the Prophet}}
\hadithdefcmd{bukhari}{2229}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي ابْنُ مُحَيْرِيزٍ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ أَخْبَرَهُ أَنَّهُ، بَيْنَمَا هُوَ جَالِسٌ عِنْدَ النَّبِيِّ صلى الله عليه وسلم قَالَ يَا رَسُولَ اللَّهِ إِنَّا نُصِيبُ سَبْيًا، فَنُحِبُّ الأَثْمَانَ، فَكَيْفَ تَرَى فِي الْعَزْلِ فَقَالَ ‏ "‏ أَوَإِنَّكُمْ تَفْعَلُونَ ذَلِكَ لاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا ذَلِكُمْ، فَإِنَّهَا لَيْسَتْ نَسَمَةٌ كَتَبَ اللَّهُ أَنْ تَخْرُجَ إِلاَّ هِيَ خَارِجَةٌ ‏"‏‏.‏\hadithno{2229}\hadithtrans{Narrated Abu Sa`id Al-Khudri:that while he was sitting with Allah's Messenger (ﷺ) he said, "O Allah's Messenger (ﷺ)! We get female captives as our share of booty, and we are interested in their prices, what is your opinion about coitus interruptus?" The Prophet (ﷺ) said, "Do you really do that? It is better for you not to do it. No soul that which Allah has destined to exist, but will surely come into existence}}
\hadithdefcmd{bukhari}{2230}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ بَاعَ النَّبِيُّ صلى الله عليه وسلم الْمُدَبَّرَ‏.‏\hadithno{2230}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) sold a Mudabbar (on behalf of his master who was still living and in need of money)}}
\hadithdefcmd{bukhari}{2231}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ بَاعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2231}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) sold a Mudabbar}}
\hadithdefcmd{bukhari}{2233}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، قَالَ حَدَّثَ ابْنُ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ، أَخْبَرَهُ أَنَّ زَيْدَ بْنَ خَالِدٍ وَأَبَا هُرَيْرَةَ رضى الله عنهما أَخْبَرَاهُ أَنَّهُمَا، سَمِعَا رَسُولَ اللَّهِ صلى الله عليه وسلم يُسْأَلُ عَنِ الأَمَةِ تَزْنِي وَلَمْ تُحْصَنْ قَالَ ‏ "‏ اجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ بِيعُوهَا بَعْدَ الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏"‏‏.‏\hadithno{2233}\hadithtrans{Narrated Zaid bin Khalid and Abu Huraira:that Allah's Messenger (ﷺ) was asked about an unmarried slave-girl who committed illegal sexual intercourse. They heard him saying, "Flog her, and if she commits illegal sexual intercourse after that, flog her again, and on the third (or the fourth) offense, sell her}}
\hadithdefcmd{bukhari}{2234}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ أَخْبَرَنِي اللَّيْثُ، عَنْ سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا زَنَتْ أَمَةُ أَحَدِكُمْ، فَتَبَيَّنَ زِنَاهَا فَلْيَجْلِدْهَا الْحَدَّ، وَلاَ يُثَرِّبْ عَلَيْهَا، ثُمَّ إِنْ زَنَتْ فَلْيَجْلِدْهَا الْحَدَّ وَلاَ يُثَرِّبْ، ثُمَّ إِنْ زَنَتِ الثَّالِثَةَ فَتَبَيَّنَ زِنَاهَا فَلْيَبِعْهَا وَلَوْ بِحَبْلٍ مِنْ شَعَرٍ ‏"‏‏.‏\hadithno{2234}\hadithtrans{Narrated Abu Huraira:I heard the Prophet (ﷺ) saying, "If a slave-girl of yours commits illegal sexual intercourse and her illegal sexual intercourse is proved, she should be lashed, and after that nobody should blame her, and if she commits illegal sexual intercourse the second time, she should be lashed and nobody should blame her after that, and if she does the offense for the third time and her illegal sexual intercourse is proved, she should be sold even for a hair rope}}
\hadithdefcmd{bukhari}{2235}{حَدَّثَنَا عَبْدُ الْغَفَّارِ بْنُ دَاوُدَ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم خَيْبَرَ، فَلَمَّا فَتَحَ اللَّهُ عَلَيْهِ الْحِصْنَ ذُكِرَ لَهُ جَمَالُ صَفِيَّةَ بِنْتِ حُيَىِّ بْنِ أَخْطَبَ، وَقَدْ قُتِلَ زَوْجُهَا، وَكَانَتْ عَرُوسًا، فَاصْطَفَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَفْسِهِ فَخَرَجَ بِهَا، حَتَّى بَلَغْنَا سَدَّ الرَّوْحَاءِ حَلَّتْ، فَبَنَى بِهَا، ثُمَّ صَنَعَ حَيْسًا فِي نِطَعٍ صَغِيرٍ، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ آذِنْ مَنْ حَوْلَكَ ‏"‏‏.‏ فَكَانَتْ تِلْكَ وَلِيمَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى صَفِيَّةَ، ثُمَّ خَرَجْنَا إِلَى الْمَدِينَةِ، قَالَ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُحَوِّي لَهَا وَرَاءَهُ بِعَبَاءَةٍ، ثُمَّ يَجْلِسُ عِنْدَ بَعِيرِهِ فَيَضَعُ رُكْبَتَهُ، فَتَضَعُ صَفِيَّةُ رِجْلَهَا عَلَى رُكْبَتِهِ، حَتَّى تَرْكَبَ‏.‏\hadithno{2235}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) came to Khaibar and when Allah made him victorious and he conquered the town by breaking the enemy's defense, the beauty of Safiya bint Huyai bin Akhtab was mentioned to him and her husband had been killed while she was a bride. Allah's Messenger (ﷺ) selected her for himself and he set out in her company till he reached Sadd-ar-Rawha' where her menses were over and he married her. Then Hais (a kind of meal) was prepared and served on a small leather sheet (used for serving meals). Allah's Messenger (ﷺ) then said to me, "Inform those who are around you (about the wedding banquet)." So that was the marriage banquet given by Allah's Messenger (ﷺ) for (his marriage with) Safiya. After that we proceeded to Medina and I saw that Allah's Messenger (ﷺ) was covering her with a cloak while she was behind him. Then he would sit beside his camel and let Safiya put her feet on his knees to ride (the camel)}}
\hadithdefcmd{bukhari}{2236}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَامَ الْفَتْحِ، وَهُوَ بِمَكَّةَ ‏"‏ إِنَّ اللَّهَ وَرَسُولَهُ حَرَّمَ بَيْعَ الْخَمْرِ وَالْمَيْتَةِ وَالْخِنْزِيرِ وَالأَصْنَامِ ‏"‏‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ، أَرَأَيْتَ شُحُومَ الْمَيْتَةِ فَإِنَّهَا يُطْلَى بِهَا السُّفُنُ، وَيُدْهَنُ بِهَا الْجُلُودُ، وَيَسْتَصْبِحُ بِهَا النَّاسُ‏.‏ فَقَالَ ‏"‏ لاَ، هُوَ حَرَامٌ ‏"‏‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ قَاتَلَ اللَّهُ الْيَهُودَ، إِنَّ اللَّهَ لَمَّا حَرَّمَ شُحُومَهَا جَمَلُوهُ ثُمَّ بَاعُوهُ فَأَكَلُوا ثَمَنَهُ ‏"‏‏.‏ قَالَ أَبُو عَاصِمٍ حَدَّثَنَا عَبْدُ الْحَمِيدِ، حَدَّثَنَا يَزِيدُ، كَتَبَ إِلَىَّ عَطَاءٌ سَمِعْتُ جَابِرًا ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2236}\hadithtrans{Narrated Jabir bin `Abdullah:I heard Allah's Messenger (ﷺ), in the year of the Conquest of Mecca, saying, "Allah and His Apostle made illegal the trade of alcohol, dead animals, pigs and idols." The people asked, "O Allah's Messenger (ﷺ)! What about the fat of dead animals, for it was used for greasing the boats and the hides; and people use it for lights?" He said, "No, it is illegal." Allah's Messenger (ﷺ) further said, "May Allah curse the Jews, for Allah made the fat (of animals) illegal for them, yet they melted the fat and sold it and ate its price}}
\hadithdefcmd{bukhari}{2237}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ‏.‏\hadithno{2237}\hadithtrans{Narrated Abu Mas`ud Al-Ansari:Allah's Messenger (ﷺ) forbade taking the price of a dog, money earned by prostitution and the earnings of a soothsayer}}
\hadithdefcmd{bukhari}{2238}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَوْنُ بْنُ أَبِي جُحَيْفَةَ، قَالَ رَأَيْتُ أَبِي اشْتَرَى حَجَّامًا، فَسَأَلْتُهُ عَنْ ذَلِكَ،‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الدَّمِ، وَثَمَنِ الْكَلْبِ، وَكَسْبِ الأَمَةِ، وَلَعَنَ الْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ، وَآكِلَ الرِّبَا، وَمُوكِلَهُ، وَلَعَنَ الْمُصَوِّرَ‏.‏\hadithno{2238}\hadithtrans{Narrated `Aun bin Abu Juhaifa:I saw my father buying a slave whose profession was cupping, and ordered that his instruments (of cupping) be broken. I asked him the reason for doing so. He replied, "Allah's Messenger (ﷺ) prohibited taking money for blood, the price of a dog, and the earnings of a slave-girl by prostitution; he cursed her who tattoos and her who gets tattooed, the eater of Riba (usury), and the maker of pictures}}
