% Auto-generated chapter 26 for nasai
% Hadiths in this chapter: 193

\hadithdefcmd{nasai}{3196}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ قَالَ حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ حَضَرْنَا مَعَ ابْنِ عَبَّاسٍ جَنَازَةَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم بِسَرِفَ فَقَالَ ابْنُ عَبَّاسٍ هَذِهِ مَيْمُونَةُ إِذَا رَفَعْتُمْ جَنَازَتَهَا فَلاَ تُزَعْزِعُوهَا وَلاَ تُزَلْزِلُوهَا فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ مَعَهُ تِسْعُ نِسْوَةٍ فَكَانَ يَقْسِمُ لِثَمَانٍ وَوَاحِدَةٌ لَمْ يَكُنْ يَقْسِمُ لَهَا ‏.‏\hadithno{3196}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Ata':It was narrated that 'Ata' said: "We attended the funeral of Maimunah, the wife of the Prophet, with Ibn 'Abbas in Sarif. Ibn 'Abbas said: 'This is Maimunah; when you lift up her bier, do not rock it nor shake it. The Messenger of Allah had nine wives and he used to give a share of his time to eight of them and not to one}}
\hadithdefcmd{nasai}{3197}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، قَالَ حَدَّثَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ تِسْعُ نِسْوَةٍ يُصِيبُهُنَّ إِلاَّ سَوْدَةَ فَإِنَّهَا وَهَبَتْ يَوْمَهَا وَلَيْلَتَهَا لِعَائِشَةَ ‏.‏\hadithno{3197}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas:It was narrated that Ibn 'Abbas said: "When the Messenger of Allah died he had nine wives; he used to be intimate with all of them except one, who had given her day and night to 'Aishah}}
\hadithdefcmd{nasai}{3198}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، أَنَّ أَنَسًا، حَدَّثَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَطُوفُ عَلَى نِسَائِهِ فِي اللَّيْلَةِ الْوَاحِدَةِ وَلَهُ يَوْمَئِذٍ تِسْعُ نِسْوَةٍ ‏.‏\hadithno{3198}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas:Anas narrated that the Prophet used to go around to his wives in a single night, and at that time he had nine wives}}
\hadithdefcmd{nasai}{3199}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغَارُ عَلَى اللاَّتِي وَهَبْنَ أَنْفُسَهُنَّ لِلنَّبِيِّ صلى الله عليه وسلم فَأَقُولُ أَوَتَهَبُ الْحُرَّةُ نَفْسَهَا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ تُرْجِي مَنْ تَشَاءُ مِنْهُنَّ وَتُؤْوِي إِلَيْكَ مَنْ تَشَاءُ ‏\}‏ قُلْتُ وَاللَّهِ مَا أَرَى رَبَّكَ إِلاَّ يُسَارِعُ لَكَ فِي هَوَاكَ ‏.‏\hadithno{3199}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:It was narrated that 'Aishah said: "I used to feel jealous of those (women) who offered themselves (in marriage) to the Prophet and I said: 'Would a free woman offer herself?' Then Allah, the Mighty and Sublime, revealed: 'You can postpone whom you will of them, and you may receive whom you will.' I said: 'By Allah, I see that your Lord is quick to respond to your wishes}}
\hadithdefcmd{nasai}{3200}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ أَنَا فِي الْقَوْمِ، إِذْ قَالَتِ امْرَأَةٌ إِنِّي قَدْ وَهَبْتُ نَفْسِي لَكَ يَا رَسُولَ اللَّهِ فَرَأْ فِيَّ رَأْيَكَ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ زَوِّجْنِيهَا ‏.‏ فَقَالَ ‏"‏ اذْهَبْ فَاطْلُبْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ فَذَهَبَ فَلَمْ يَجِدْ شَيْئًا وَلاَ خَاتَمًا مِنْ حَدِيدٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَعَكَ مِنْ سُوَرِ الْقُرْآنِ شَىْءٌ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ فَزَوَّجَهُ بِمَا مَعَهُ مِنْ سُوَرِ الْقُرْآنِ ‏.‏\hadithno{3200}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sahl bin Sa'd:It was narrated that Sahl bin Sa'd said: "I was among the people when a woman said: 'I offer myself (in marriage) to you, O Messenger of Allah, see what you think of me.' A man stood up and said: 'Marry me to her.' He said: 'Go and find (something), even if it is an iron ring.' So he went, but he could not find anything, not even an iron ring. So the Messenger of Allah said: 'Do you have (memorized) any surahs of the Qur'an?' He said: 'Yes.' So he married him to her on the basis of what he knew of surahs of the Qur'an}}
\hadithdefcmd{nasai}{3201}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ خَالِدٍ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى بْنِ أَعْيَنَ، قَالَ حَدَّثَنَا أَبِي، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَهَا حِينَ أَمَرَهُ اللَّهُ أَنْ يُخَيِّرَ أَزْوَاجَهُ - قَالَتْ عَائِشَةُ - فَبَدَأَ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ لاَ تُعَجِّلِي حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏ ‏.‏ قَالَتْ وَقَدْ عَلِمَ أَنَّ أَبَوَىَّ لاَ يَأْمُرَانِّي بِفِرَاقِهِ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏ يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ إِنْ كُنْتُنَّ تُرِدْنَ الْحَيَاةَ الدُّنْيَا وَزِينَتَهَا فَتَعَالَيْنَ أُمَتِّعْكُنَّ ‏\}‏ فَقُلْتُ فِي هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ ‏.‏\hadithno{3201}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:It was narrated from 'Aishah, the wife of the Prophet, that the Messenger of Allah came to her when Allah commanded him to give his wives the choice. 'Aishah said: "The Messenger of Allah started with me and said: 'I am going to tell you something, but you do not have to rush until you consult your parents.'" She said: "He knew that my parents would not tell me to leave him." Then the Messenger of Allah said: 'O Prophet! Say to your wives: If you desire the life of this world, and its glitter, then come! I will make a provision for you and set you free in a handsome manner.' "I said: 'Do I need to consult my parents about this? I choose Allah and His Messenger, and the abode of the Hereafter}}
\hadithdefcmd{nasai}{3202}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ الْعَسْكَرِيُّ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبَا الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَدْ خَيَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ أَوَكَانَ طَلاَقًا ‏.‏\hadithno{3202}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:It was narrated that 'Aishah, may Allah be pleased with her, said: "The Messenger of Allah gave his wives the choice (of staying with him) was it divorce?}}
\hadithdefcmd{nasai}{3203}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ إِسْمَاعِيلَ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَرْنَاهُ فَلَمْ يَكُنْ طَلاَقًا ‏.‏\hadithno{3203}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:It was narrated that 'Aishah said: "The Messenger of Allah gave us the choice, and we chose him, so there was no divorce}}
\hadithdefcmd{nasai}{3204}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ حَفِظْنَاهُ مِنْ عَمْرٍو عَنْ عَطَاءٍ، قَالَ قَالَتْ عَائِشَةُ مَا مَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أُحِلَّ لَهُ النِّسَاءُ ‏.‏\hadithno{3204}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ata':It was narrated that 'Ata' said: "Aishah said: 'The Messenger of Allah did not die until women had been made lawful to him}}
\hadithdefcmd{nasai}{3205}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ، - وَهُوَ الْمُغِيرَةُ بْنُ سَلَمَةَ الْمَخْزُومِيُّ - قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، قَالَتْ مَا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَحَلَّ اللَّهُ لَهُ أَنْ يَتَزَوَّجَ مِنَ النِّسَاءِ مَا شَاءَ ‏.‏\hadithno{3205}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah:It was narrated that 'Aishah said: "The Messenger of Allah did not die until Allah permitted him to marry whatever women he wanted}}
\hadithdefcmd{nasai}{3206}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا يُونُسُ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ كُنْتُ مَعَ ابْنِ مَسْعُودٍ وَهُوَ عِنْدَ عُثْمَانَ رضى الله عنه فَقَالَ عُثْمَانُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى فِتْيَةٍ - قَالَ أَبُو عَبْدِ الرَّحْمَنِ فَلَمْ أَفْهَمْ فِتْيَةً كَمَا أَرَدْتُ - فَقَالَ ‏ "‏ مَنْ كَانَ مِنْكُمْ ذَا طَوْلٍ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لاَ فَالصَّوْمُ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{3206}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Alqamah:It was narrated that 'Alqamah said: "I was with Ibn Mas'ud while he was with 'Uthman, may Allah be pleased with him, and 'Uthman said: 'The Messenger of Allah came out to some fityah (young men)--Abu 'AbdurRahman said, 'I did not understand (the word) fityah as I would want'-- and said: 'Whoever among you can afford it, let him get married, for it is more effective in lowering the gaze and guarding chastity, and whoever cannot, then fasting will be a restraint (wija') for him}}
\hadithdefcmd{nasai}{3207}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، أَنَّ عُثْمَانَ، قَالَ لاِبْنِ مَسْعُودٍ هَلْ لَكَ فِي فَتَاةٍ أُزَوِّجُكَهَا ‏.‏ فَدَعَا عَبْدُ اللَّهِ عَلْقَمَةَ فَحَدَّثَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اسْتَطَاعَ الْبَاءَةَ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لَمْ يَسْتَطِعْ فَلْيَصُمْ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{3207}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Alqamah:It was narrated from 'Alqamah, that 'Uthman said to Ibn Mas'ud: "Shall I arrange for you to marry a young girl?" 'Abdullah called 'Alqamah and he told the people that the Prophet said: "Whoever among you can afford it, let him get married, for it is more effective in lowering the gaze and guarding chastity. And whoever cannot afford it, then let him fast, for it will be a restraint for him}}
\hadithdefcmd{nasai}{3208}{أَخْبَرَنِي هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ الْكُوفِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدٍ الْمُحَارِبِيُّ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ وَمَنْ لَمْ يَسْتَطِعْ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الأَسْوَدُ فِي هَذَا الْحَدِيثِ لَيْسَ بِمَحْفُوظٍ ‏.‏\hadithno{3208}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Alqamah:It was narrated from 'Alqamah and Al-Aswad that 'Abdullah said: "The Messenger of Allah said to us: 'Whoever among you can afford it, let him get married, and whoever cannot then he should fast, for it will be a restraint (wija') for him.'" Abu Abdur-Rahman said: (The mention of) Al-Aswad in this hadith is not preserved}}
\hadithdefcmd{nasai}{3209}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَنْكِحْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لاَ فَلْيَصُمْ فَإِنَّ الصَّوْمَ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{3209}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abdullah:It was narrated that 'Abdullah said: "The Messenger of Allah said to us: 'O young men, whoever among you can afford it, let him get married, for it is more effective in lowering the gaze and guarding chastity, and whoever cannot then he should fast, for it will be a restraint (wija') for him}}
\hadithdefcmd{nasai}{3210}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{3210}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abdullah:It was narrated that 'Abdullah said: "The Messenger of Allah said to us: 'O young men, whoever among you can afford it, let him get married,'" and he quoted the same hadith}}
\hadithdefcmd{nasai}{3211}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ كُنْتُ أَمْشِي مَعَ عَبْدِ اللَّهِ بِمِنًى فَلَقِيَهُ عُثْمَانُ فَقَامَ مَعَهُ يُحَدِّثُهُ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ أَلاَ أُزَوِّجُكَ جَارِيَةً شَابَّةً فَلَعَلَّهَا أَنْ تُذَكِّرَكَ بَعْضَ مَا مَضَى مِنْكَ فَقَالَ عَبْدُ اللَّهِ أَمَا لَئِنْ قُلْتَ ذَاكَ لَقَدْ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ ‏"‏ ‏.‏\hadithno{3211}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Alqamah:It was narrated that 'Alqamah said: "I was walking with 'Abdullah in Mina and he was met by 'Uthman who stood with him and spoke with him. He said: 'O Abu Abdur-Rahman! Shall I not marry you to a young girl? Perhaps she will remind you of when you were younger?' 'Abdullah said: 'As you say that (it reminds me that) the Messenger of Allah said to us: O young men, whoever among you can afford it, let him get married}}
\hadithdefcmd{nasai}{3212}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ لَقَدْ رَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عُثْمَانَ التَّبَتُّلَ وَلَوْ أَذِنَ لَهُ لاَخْتَصَيْنَا ‏.‏\hadithno{3212}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sa'd bin Abi Waqqas:It was narrated that Sa'd bin Abi Waqqas said: "The Messenger of Allah forbade 'Uthman to be celibate. If he had given him permission we would have castrated ourselves}}
\hadithdefcmd{nasai}{3213}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَشْعَثَ، عَنِ الْحَسَنِ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ التَّبَتُّلِ ‏.‏\hadithno{3213}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:It was narrated from 'Aishah that the Messenger of Allah forbade celibacy}}
\hadithdefcmd{nasai}{3214}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ أَنَّهُ نَهَى عَنِ التَّبَتُّلِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ قَتَادَةُ أَثْبَتُ وَأَحْفَظُ مِنْ أَشْعَثَ وَحَدِيثُ أَشْعَثَ أَشْبَهُ بِالصَّوَابِ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{3214}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Samurah bin Jundab:It was narrated from Samurah bin Jundab that the Prophet forbade celibacy. Abu Abdur-Rahman said: Qatadah is more reliable and better preserves narrations than Ash'ath but the hadith of Ash'ath (here) appears to be the correct one. Allah, Most High, knows best}}
\hadithdefcmd{nasai}{3215}{أَخْبَرَنَا يَحْيَى بْنُ مُوسَى، قَالَ حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ شَابٌّ قَدْ خَشِيتُ عَلَى نَفْسِي الْعَنَتَ وَلاَ أَجِدُ طَوْلاً أَتَزَوَّجُ النِّسَاءَ أَفَأَخْتَصِي فَأَعْرَضَ عَنْهُ النَّبِيُّ صلى الله عليه وسلم حَتَّى قَالَ ثَلاَثًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَبَا هُرَيْرَةَ جَفَّ الْقَلَمُ بِمَا أَنْتَ لاَقٍ فَاخْتَصِ عَلَى ذَلِكَ أَوْ دَعْ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الأَوْزَاعِيُّ لَمْ يَسْمَعْ هَذَا الْحَدِيثَ مِنَ الزُّهْرِيِّ وَهَذَا حَدِيثٌ صَحِيحٌ قَدْ رَوَاهُ يُونُسُ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{3215}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Salamah:It was narrated from Abu Salamah that Abu Hurairah said: "I said: 'O Messenger of Allah, I am a young man and I fear hardship for myself, but I cannot afford to marry; should I castrate myself?'" The Prophet turned away from him until he said it three times. Then the Prophet said: "O Abu Hurairah, the pen is dried concerning what you are going to face, so (it is up to you whether) you castrate yourself or not." Abu Abdur-Rahman (An-Nasai) said: Al-Awzai did not hear this narration from Az-Zuhri, and this hadith is sahih, Yunus reported it from Az-Zuhri}}
\hadithdefcmd{nasai}{3216}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْخَلَنْجِيُّ، قَالَ حَدَّثَنَا أَبُو سَعِيدٍ، مَوْلَى بَنِي هَاشِمٍ قَالَ حَدَّثَنَا حُصَيْنُ بْنُ نَافِعٍ الْمَازِنِيُّ، قَالَ حَدَّثَنِي الْحَسَنُ، عَنْ سَعْدِ بْنِ هِشَامٍ، أَنَّهُ دَخَلَ عَلَى أُمِّ الْمُؤْمِنِينَ عَائِشَةَ قَالَ قُلْتُ إِنِّي أُرِيدُ أَنْ أَسْأَلَكِ عَنِ التَّبَتُّلِ فَمَا تَرَيْنَ فِيهِ قَالَتْ فَلاَ تَفْعَلْ أَمَا سَمِعْتَ اللَّهَ عَزَّ وَجَلَّ يَقُولُ ‏\{‏ وَلَقَدْ أَرْسَلْنَا رُسُلاً مِنْ قَبْلِكَ وَجَعَلْنَا لَهُمْ أَزْوَاجًا وَذُرِّيَّةً ‏\}‏ فَلاَ تَتَبَتَّلْ ‏.‏\hadithno{3216}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'd bin Hisham:It was narrated from Sa'd bin Hisham that he came to the Mother of the Believers, 'Aishah. He said: "I want to ask you about celibacy, what do you think about it?" She said: "Do not do that; have you not heard that Allah, the Mighty and Sublime, says: 'And indeed We sent Messengers before you, and made for them wives and offspring'? So do not be celibate}}
\hadithdefcmd{nasai}{3217}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَفَّانُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ نَفَرًا، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ بَعْضُهُمْ لاَ أَتَزَوَّجُ النِّسَاءَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ آكُلُ اللَّحْمَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ أَنَامُ عَلَى فِرَاشٍ ‏.‏ وَقَالَ بَعْضُهُمْ أَصُومُ فَلاَ أُفْطِرُ ‏.‏ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ مَا بَالُ أَقْوَامٍ يَقُولُونَ كَذَا وَكَذَا لَكِنِّي أُصَلِّي وَأَنَامُ وَأَصُومُ وَأُفْطِرُ وَأَتَزَوَّجُ النِّسَاءَ فَمَنْ رَغِبَ عَنْ سُنَّتِي فَلَيْسَ مِنِّي ‏"‏ ‏.‏\hadithno{3217}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas:It was narrated from Anas that there was a group of the Companions of the Prophet, one of whom said: "I will not marry women." Another said: "I will not eat meat." Another said: "I will not sleep on a bed." Another said: "I will fast and not break my fast." News of that reached the Messenger of Allah and he praised Allah then said: "What is the matter with people who say such and such? But I pray and I sleep, I fast and I break my fast, and I marry women. Whoever turns away from my Sunnah is not of me}}
\hadithdefcmd{nasai}{3218}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ حَقٌّ عَلَى اللَّهِ عَزَّ وَجَلَّ عَوْنُهُمُ الْمُكَاتَبُ الَّذِي يُرِيدُ الأَدَاءَ وَالنَّاكِحُ الَّذِي يُرِيدُ الْعَفَافَ وَالْمُجَاهِدُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{3218}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah:It was narrated from Abu Hurairah that the Messenger of Allah said: "There are three who are promised the help of Allah: The Mukatab who wants to buy his freedom, the one who gets married seeking to keep himself chaste, and the Mujahid who fights in the cause of Allah." *Mukatab: the slave who has made a contract of manumission}}
\hadithdefcmd{nasai}{3219}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، قَالَ تَزَوَّجْتُ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتَزَوَّجْتَ يَا جَابِرُ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ بِكْرًا أَمْ ثَيِّبًا ‏"‏ ‏.‏ فَقُلْتُ ثَيِّبًا ‏.‏ قَالَ ‏"‏ فَهَلاَّ بِكْرًا تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏ ‏.‏\hadithno{3219}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir:It was narrated that Jabir said: "I got married then I came to the Prophet and he said: 'Have you got married, O Jabir?' I said: 'Yes.' He said: 'To a virgin or to a previously married woman?' I said: 'To a previously married woman.' He said: 'Why not a virgin, so you could play with her and she could play with you?}}
\hadithdefcmd{nasai}{3220}{أَخْبَرَنَا الْحَسَنُ بْنُ قَزَعَةَ، قَالَ حَدَّثَنَا سُفْيَانُ، - وَهُوَ ابْنُ حَبِيبٍ - عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ لَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا جَابِرُ هَلْ أَصَبْتَ امْرَأَةً بَعْدِي ‏"‏ ‏.‏ قُلْتُ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ أَبِكْرًا أَمْ أَيِّمًا ‏"‏ ‏.‏ قُلْتُ أَيِّمًا ‏.‏ قَالَ ‏"‏ فَهَلاَّ بِكْرًا تُلاَعِبُكَ ‏"‏ ‏.‏\hadithno{3220}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Jabir:It was narrated that Jabir said: "The Messenger of Allah met me and said: 'O Jabir, have you got married to a woman since I last saw you?' I said: 'Yes, O Messenger of Allah.' He said: 'To a virgin or to a previously-married woman?' I said: 'To a previously-married woman.' He said: 'Why not a virgin, so she could play with you?}}
\hadithdefcmd{nasai}{3221}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ خَطَبَ أَبُو بَكْرٍ وَعُمَرُ رضى الله عنهما فَاطِمَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهَا صَغِيرَةٌ ‏"‏ ‏.‏ فَخَطَبَهَا عَلِيٌّ فَزَوَّجَهَا مِنْهُ ‏.‏\hadithno{3221}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdullah bin Buraidah:It was narrated from 'Abdullah bin Buraidah that his father said: "Abu Bakr and 'Umar, may Allah be pleased with them, proposed marriage to Fatimah but the Messenger of Allah said: 'She is young.' Then 'Ali proposed marriage to her and he married her to him}}
\hadithdefcmd{nasai}{3222}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ عُثْمَانَ، طَلَّقَ وَهُوَ غُلاَمٌ شَابٌّ فِي إِمَارَةِ مَرْوَانَ ابْنَةَ سَعِيدِ بْنِ زَيْدٍ وَأُمُّهَا بِنْتُ قَيْسٍ الْبَتَّةَ فَأَرْسَلَتْ إِلِيْهَا خَالَتُهَا فَاطِمَةُ بِنْتُ قَيْسٍ تَأْمُرُهَا بِالاِنْتِقَالِ مِنْ بَيْتِ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَسَمِعَ بِذَلِكَ مَرْوَانُ فَأَرْسَلَ إِلَى ابْنَةِ سَعِيدٍ فَأَمَرَهَا أَنْ تَرْجِعَ إِلَى مَسْكَنِهَا وَسَأَلَهَا مَا حَمَلَهَا عَلَى الاِنْتِقَالِ مِنْ قَبْلِ أَنْ تَعْتَدَّ فِي مَسْكَنِهَا حَتَّى تَنْقَضِيَ عِدَّتُهَا فَأَرْسَلَتْ إِلَيْهِ تُخْبِرُهُ أَنَّ خَالَتَهَا أَمَرَتْهَا بِذَلِكَ فَزَعَمَتْ فَاطِمَةُ بِنْتُ قَيْسٍ أَنَّهَا كَانَتْ تَحْتَ أَبِي عَمْرِو بْنِ حَفْصٍ فَلَمَّا أَمَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيَّ بْنَ أَبِي طَالِبٍ عَلَى الْيَمَنِ خَرَجَ مَعَهُ وَأَرْسَلَ إِلَيْهَا بِتَطْلِيقَةٍ هِيَ بَقِيَّةُ طَلاَقِهَا وَأَمَرَ لَهَا الْحَارِثَ بْنَ هِشَامٍ وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ بِنَفَقَتِهَا فَأَرْسَلَتْ - زَعَمَتْ - إِلَى الْحَارِثِ وَعَيَّاشٍ تَسْأَلُهُمَا الَّذِي أَمَرَ لَهَا بِهِ زَوْجُهَا فَقَالاَ وَاللَّهِ مَا لَهَا عِنْدَنَا نَفَقَةٌ إِلاَّ أَنْ تَكُونَ حَامِلاً وَمَا لَهَا أَنْ تَكُونَ فِي مَسْكَنِنَا إِلاَّ بِإِذْنِنَا فَزَعَمَتْ أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ فَصَدَّقَهُمَا ‏.‏ قَالَتْ فَاطِمَةُ فَأَيْنَ أَنْتَقِلُ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ انْتَقِلِي عِنْدَ ابْنِ أُمِّ مَكْتُومٍ الأَعْمَى الَّذِي سَمَّاهُ اللَّهُ عَزَّ وَجَلَّ فِي كِتَابِهِ ‏"‏ ‏.‏ قَالَتْ فَاطِمَةُ فَاعْتَدَدْتُ عِنْدَهُ وَكَانَ رَجُلاً قَدْ ذَهَبَ بَصَرُهُ فَكُنْتُ أَضَعُ ثِيَابِي عِنْدَهُ حَتَّى أَنْكَحَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أُسَامَةَ بْنَ زَيْدٍ فَأَنْكَرَ ذَلِكَ عَلَيْهَا مَرْوَانُ وَقَالَ لَمْ أَسْمَعْ هَذَا الْحَدِيثَ مِنْ أَحَدٍ قَبْلَكِ وَسَآخُذُ بِالْقَضِيَّةِ الَّتِي وَجَدْنَا النَّاسَ عَلَيْهَا ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{3222}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Ubaidullah bin 'Abdullah bin 'Utbah:It was narrated from 'Ubaidullah bin 'Abdullah bin 'Utbah that during the reign of Marwan, 'Abdullah bin 'Amr bin 'Uthman, who was a young man, issued a final divorce to the daughter of Sa'eed bin Zaid, whose mother was Bint Qais. Her maternal aunt, Fatimah bint Qais, sent word to her telling her to move from the house of 'Abdullah bin 'Amr. Marwan heard of that and he sent word to the daughter of Sa'eed, telling her to go back to her home, and asking her why she had moved from her home before her 'Iddah was over? She sent word to him telling him that her maternal aunt had told her to do that. Fatimah bint Qais said that she had been married to Abu 'Amr bin Hafs, and when the Messenger of Allah appointed 'Ali bin Abi Talib as governor of Yemen, he went out with him and sent word to her that she was divorced with the third Talaq. He told Al-Harith bin Hisham and 'Ayyash bin Abi Rai'ah to spend on her. She sent word to Al-Harith and 'Ayyash asking them what her husband had told them to spend on her, and they said: 'By Allah, she has no right to any maintenance from us, unless she is pregnant, and she cannot come into our home without our permission.' She said that she came to the Messenger of Allah and told him about that, and he stated that they were correct. Fatimah said: 'Where should I move to, O Messenger of Allah?' He said: 'Move to the home of Ibn Umm Maktum, the blind man whom Allah, the Mighty and Sublime, named in His Book.' Fatimah said: 'So I observed my 'Iddah there. He was a man who has lost his sight, so I used to take off my garments in his house, until the Messenger of Allah married me to Usamah bin Zaid.' Marwan criticized her for that and said: 'I have never heard this Hadith from anyone before you. I will continue to follow the ruling that the people have been following}}
\hadithdefcmd{nasai}{3223}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارِ بْنِ رَاشِدٍ، قَالَ حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَنْبَأَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ أَبَا حُذَيْفَةَ بْنَ عُتْبَةَ بْنِ رَبِيعَةَ بْنِ عَبْدِ شَمْسٍ، - وَكَانَ مِمَّنْ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم - تَبَنَّى سَالِمًا وَأَنْكَحَهُ ابْنَةَ أَخِيهِ هِنْدَ بِنْتَ الْوَلِيدِ بْنِ عُتْبَةَ بْنِ رَبِيعَةَ بْنِ عَبْدِ شَمْسٍ وَهُوَ مَوْلًى لاِمْرَأَةٍ مِنَ الأَنْصَارِ كَمَا تَبَنَّى رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْدًا وَكَانَ مَنْ تَبَنَّى رَجُلاً فِي الْجَاهِلِيَّةِ دَعَاهُ النَّاسُ ابْنَهُ فَوَرِثَ مِنْ مِيرَاثِهِ حَتَّى أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِي ذَلِكَ ‏\{‏ ادْعُوهُمْ لآبَائِهِمْ هُوَ أَقْسَطُ عِنْدَ اللَّهِ فَإِنْ لَمْ تَعْلَمُوا آبَاءَهُمْ فَإِخْوَانُكُمْ فِي الدِّينِ وَمَوَالِيكُمْ ‏\}‏ فَمَنْ لَمْ يُعْلَمْ لَهُ أَبٌ كَانَ مَوْلًى وَأَخًا فِي الدِّينِ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{3223}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Aishah:It was narrated from 'Aishah that Abu Hudhaifah bin 'Utbah bin Rabi'ah bin 'Abd Shams --who was one of those who had been present at Badr with the Messenger of Allah-- adopted Salim and married him to his brother's daughter, Hind bint Al-Walid bin 'Utbah bin Rabi'ah bin 'Abd Shams, and he was a freed slave of an Ansari woman --as the Messenger of Allah had adopted Zaid. During the Jahiliyyah, if a man adopted someone, the people would call him his son, and he would inherit from his legacy, until Allah, the Mighty and Sublime, revealed about that: 'Call them by (the names of) their fathers, that is more just with Allah. But if you know not their fathers' (names, call them) your brothers in Faith and Mawalikum (your freed slaves)." Then if a person's father's name was not known, he would be their freed slave and brother in faith}}
\hadithdefcmd{nasai}{3224}{أَخْبَرَنَا مُحَمَّدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ بْنِ بِلاَلٍ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي أُوَيْسٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، قَالَ قَالَ يَحْيَى - يَعْنِي ابْنَ سَعِيدٍ - وَأَخْبَرَنِي ابْنُ شِهَابٍ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، وَابْنُ عَبْدِ اللَّهِ بْنِ رَبِيعَةَ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَأُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ أَبَا حُذَيْفَةَ بْنَ عُتْبَةَ بْنِ رَبِيعَةَ بْنِ عَبْدِ شَمْسٍ - وَكَانَ مِمَّنْ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم - تَبَنَّى سَالِمًا وَهُوَ مَوْلًى لاِمْرَأَةٍ مِنَ الأَنْصَارِ كَمَا تَبَنَّى رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْدَ بْنَ حَارِثَةَ وَأَنْكَحَ أَبُو حُذَيْفَةَ بْنُ عُتْبَةَ سَالِمًا ابْنَةَ أَخِيهِ هِنْدَ ابْنَةَ الْوَلِيدِ بْنِ عُتْبَةَ بْنِ رَبِيعَةَ وَكَانَتْ هِنْدُ بِنْتُ الْوَلِيدِ بْنِ عُتْبَةَ مِنَ الْمُهَاجِرَاتِ الأُوَلِ وَهِيَ يَوْمَئِذٍ مِنْ أَفْضَلِ أَيَامَى قُرَيْشٍ فَلَمَّا أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِي زَيْدِ بْنِ حَارِثَةَ ‏\{‏ ادْعُوهُمْ لآبَائِهِمْ هُوَ أَقْسَطُ عِنْدَ اللَّهِ ‏\}‏ رُدَّ كُلُّ أَحَدٍ يَنْتَمِي مِنْ أُولَئِكَ إِلَى أَبِيهِ فَإِنْ لَمْ يَكُنْ يُعْلَمُ أَبُوهُ رُدَّ إِلَى مَوَالِيهِ ‏.‏\hadithno{3224}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah:It was narrated from 'Aishah the wife of the Prophet, and Umm Salamah the wife of the Prophet that Abu Hudhaifah bin 'Utbah bin Rabi'ah bin Abd Shams --who was one of those who had been present at Badr with the Messenger of Allah-- adopted Salim --who was the freed slave of an Ansari woman-- as the Messenger of Allah had adopted Zaid bin Harithah. Abu Hudhaifah bin 'Utbah married Salim to his brother's daughter Hind bint Al-Walid bin 'Utbah bin Rabi'ah. Hind bint Al-Walid bin 'Utbah was one of the first Muhajir women, and at that time she was one of the best single women of the Quraish. When Allah, the Mighty and Sublime, revealed the following concerning Zaid bin Harithah: "Call them by (the names of) their fathers, that is more just with Allah. But if you know not their fathers' (names, call them) your brothers in Faith and Mawalikum (your freed slaves).' Each of them went back to being called after his father, and if a person's father was unknown, he was named after his former masters}}
\hadithdefcmd{nasai}{3225}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو تُمَيْلَةَ، عَنْ حُسَيْنِ بْنِ وَاقِدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحْسَابَ أَهْلِ الدُّنْيَا الَّذِي يَذْهَبُونَ إِلَيْهِ الْمَالُ ‏"‏ ‏.‏\hadithno{3225}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn Buraidah:It was narrated from Ibn Buraidah that his father said: "The Messenger of Allah said: 'The nobility of the people of this world, that which they (always) go to, is wealth}}
\hadithdefcmd{nasai}{3226}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّهُ تَزَوَّجَ امْرَأَةً عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَقِيَهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتَزَوَّجْتَ يَا جَابِرُ ‏"‏ ‏.‏ قَالَ قُلْتُ نَعَمْ قَالَ ‏"‏ بِكْرًا أَمْ ثَيِّبًا ‏"‏ ‏.‏ قَالَ قُلْتُ بَلْ ثَيِّبًا ‏.‏ قَالَ ‏"‏ فَهَلاَّ بِكْرًا تُلاَعِبُكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ كُنَّ لِي أَخَوَاتٌ فَخَشِيتُ أَنْ تَدْخُلَ بَيْنِي وَبَيْنَهُنَّ ‏.‏ قَالَ ‏"‏ فَذَاكَ إِذًا إِنَّ الْمَرْأَةَ تُنْكَحُ عَلَى دِينِهَا وَمَالِهَا وَجَمَالِهَا فَعَلَيْكَ بِذَاتِ الدِّينِ تَرِبَتْ يَدَاكَ ‏"‏ ‏.‏\hadithno{3226}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir:It was narrated from Jabir that he married a woman at the time of the Messenger of Allah, and the Prophet met him and said: "Have you got married, O Jabir?" He said: 'Yes.' He said: 'A virgin or a previously-married woman?' I said: 'A previously-married woman.' He said: 'Why not a virgin who would play with you?' I said: 'O Messenger of Allah, I have sisters, and I did not want her to come between them and I.' He said: 'That's better then. A woman may be married for her religious commitment, her wealth or her beauty. You should choose the one who is religiously committed, may your hands be rubbed with dust (may you prosper)}}
\hadithdefcmd{nasai}{3227}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا الْمُسْتَلِمُ بْنُ سَعِيدٍ، عَنْ مَنْصُورِ بْنِ زَاذَانَ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي أَصَبْتُ امْرَأَةً ذَاتَ حَسَبٍ وَمَنْصِبٍ إِلاَّ أَنَّهَا لاَ تَلِدُ أَفَأَتَزَوَّجُهَا فَنَهَاهُ ثُمَّ أَتَاهُ الثَّانِيَةَ فَنَهَاهُ ثُمَّ أَتَاهُ الثَّالِثَةَ فَنَهَاهُ فَقَالَ ‏ "‏ تَزَوَّجُوا الْوَلُودَ الْوَدُودَ فَإِنِّي مُكَاثِرٌ بِكُمْ ‏"‏ ‏.‏\hadithno{3227}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ma'qil bin Yasar:It was narrated that Ma'qil bin Yasar said: "A man came to the Messenger of Allah and said: 'I have found a woman who is from a good family and of good status, but she does not bear children, should I marry her?' He told him not to. Then he came to him a second time and he told him not to (marry her). Then he came to him a third time and he told him not to (marry her), then he said: 'Marry the one who is fertile and loving, for I will boast of your great numbers}}
\hadithdefcmd{nasai}{3228}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ التَّيْمِيُّ، قَالَ حَدَّثَنَا يَحْيَى، - هُوَ ابْنُ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ مَرْثَدَ بْنَ أَبِي مَرْثَدٍ الْغَنَوِيَّ، - وَكَانَ رَجُلاً شَدِيدًا - وَكَانَ يَحْمِلُ الأُسَارَى مِنْ مَكَّةَ إِلَى الْمَدِينَةِ ‏.‏ قَالَ فَدَعَوْتُ رَجُلاً لأَحْمِلَهُ وَكَانَ بِمَكَّةَ بَغِيٌّ يُقَالُ لَهَا عَنَاقُ وَكَانَتْ صَدِيقَتَهُ خَرَجَتْ فَرَأَتْ سَوَادِي فِي ظِلِّ الْحَائِطِ فَقَالَتْ مَنْ هَذَا مَرْثَدٌ مَرْحَبًا وَأَهْلاً يَا مَرْثَدُ انْطَلِقِ اللَّيْلَةَ فَبِتْ عِنْدَنَا فِي الرَّحْلِ ‏.‏ قُلْتُ يَا عَنَاقُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّمَ الزِّنَا ‏.‏ قَالَتْ يَا أَهْلَ الْخِيَامِ هَذَا الدُّلْدُلُ هَذَا الَّذِي يَحْمِلُ أُسَرَاءَكُمْ مِنْ مَكَّةَ إِلَى الْمَدِينَةِ ‏.‏ فَسَلَكْتُ الْخَنْدَمَةَ فَطَلَبَنِي ثَمَانِيَةٌ فَجَاءُوا حَتَّى قَامُوا عَلَى رَأْسِي فَبَالُوا فَطَارَ بَوْلُهُمْ عَلَىَّ وَأَعْمَاهُمُ اللَّهُ عَنِّي فَجِئْتُ إِلَى صَاحِبِي فَحَمَلْتُهُ فَلَمَّا انْتَهَيْتُ بِهِ إِلَى الأَرَاكِ فَكَكْتُ عَنْهُ كَبْلَهُ فَجِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ أَنْكِحُ عَنَاقَ فَسَكَتَ عَنِّي فَنَزَلَتِ ‏\{‏ الزَّانِيَةُ لاَ يَنْكِحُهَا إِلاَّ زَانٍ أَوْ مُشْرِكٌ ‏\}‏ فَدَعَانِي فَقَرَأَهَا عَلَىَّ وَقَالَ ‏"‏ لاَ تَنْكِحْهَا ‏"‏ ‏.‏\hadithno{3228}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib:It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that Marthad bin Abi Marthad Al-Ghanawi --a strong man who used to take the prisoners from Makkah to Al-Madinah-- said: "I arranged with a man to bring him (from Makkah to Al-Madinah). There was a prostitute in Makkah who was called 'Anaq, and she was his friend. She came out and saw my shadow on the wall, and said: 'Who is this? Marthad? Welcome, O Marthad, come tonight and stay at our place.' I said: 'O 'Anaq, the Messenger of Allah has forbidden adultery.' She said: 'O people of the tents, this porcupine is the one who is taking your prisoners from Makkah to Al-Madinah!' I headed toward (the mountain of) Al-Khandamah, and eight men came after me. They came and stood over my head, and they urinated, and their urine reached me, but Allah caused them not to see me. Then I went to my companion (the prisoner) and brought him to Al-Arak, where I undid his fetters. Then I came to the Messenger of Allah and said: 'O Messenger of Allah, shall I marry 'Anaq?' He remained silent and did not answer me, then the following was revealed: 'And the adulteress-fornicator, none marries her except an adulterer-fornicator or an idolater.' He called me and recited them to me and said: 'Do not marry her}}
\hadithdefcmd{nasai}{3229}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، وَغَيْرُهُ، عَنْ هَارُونَ بْنِ رِئَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، وَعَبْدِ الْكَرِيمِ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - عَبْدُ الْكَرِيمِ يَرْفَعُهُ إِلَى ابْنِ عَبَّاسٍ وَهَارُونُ لَمْ يَرْفَعْهُ - قَالاَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ عِنْدِي امْرَأَةً هِيَ مِنْ أَحَبِّ النَّاسِ إِلَىَّ وَهِيَ لاَ تَمْنَعُ يَدَ لاَمِسٍ ‏.‏ قَالَ ‏"‏ طَلِّقْهَا ‏"‏ ‏.‏ قَالَ لاَ أَصْبِرُ عَنْهَا ‏.‏ قَالَ ‏"‏ اسْتَمْتِعْ بِهَا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الْحَدِيثُ لَيْسَ بِثَابِتٍ وَعَبْدُ الْكَرِيمِ لَيْسَ بِالْقَوِيِّ وَهَارُونُ بْنُ رِئَابٍ أَثْبَتُ مِنْهُ وَقَدْ أَرْسَلَ الْحَدِيثَ وَهَارُونُ ثِقَةٌ وَحَدِيثُهُ أَوْلَى بِالصَّوَابِ مِنْ حَدِيثِ عَبْدِ الْكَرِيمِ ‏.‏\hadithno{3229}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Abbas:It was narrated from Ibn 'Abbas that a man came to the Messenger of Allah and said: "I have a wife who is one of the most beloved of the people to me, but she does not object if anyone touches her." He said: "Divorce her." He said: "I cannot do without her." He said: "Then stay with her as much as you need to}}
\hadithdefcmd{nasai}{3230}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُنْكَحُ النِّسَاءُ لأَرْبَعَةٍ لِمَالِهَا وَلِحَسَبِهَا وَلِجَمَالِهَا وَلِدِينِهَا فَاظْفَرْ بِذَاتِ الدِّينِ تَرِبَتْ يَدَاكَ ‏"‏ ‏.‏\hadithno{3230}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:It was narrated from Abu Hurairah that the Prophet said: "Women are married for four things: their wealth, their nobility, their beauty and their religious commitment. Choose the one who is religiously committed, may your hands be rubbed with dust}}
\hadithdefcmd{nasai}{3231}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَىُّ النِّسَاءِ خَيْرٌ قَالَ ‏ "‏ الَّتِي تَسُرُّهُ إِذَا نَظَرَ وَتُطِيعُهُ إِذَا أَمَرَ وَلاَ تُخَالِفُهُ فِي نَفْسِهَا وَمَالِهَا بِمَا يَكْرَهُ ‏"‏ ‏.‏\hadithno{3231}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:It was narrated that Abu Hurairah said: "It was said to the Messenger of Allah: 'Which woman is best?' He said: 'The one who makes him happy when he looks at her, obeys him when he commands her, and she does not go against his wishes with regard to herself nor her wealth}}
\hadithdefcmd{nasai}{3232}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَيْوَةُ، وَذَكَرَ، آخَرَ أَنْبَأَنَا شُرَحْبِيلُ بْنُ شَرِيكٍ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الدُّنْيَا كُلَّهَا مَتَاعٌ وَخَيْرُ مَتَاعِ الدُّنْيَا الْمَرْأَةُ الصَّالِحَةُ ‏"‏ ‏.‏\hadithno{3232}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Abdullah bin 'Amr bin Al-'As:It was narrated from 'Abdullah bin 'Amr bin Al-'As that the Messenger of Allah said: "This world is all temporary conveniences, and the best temporary convenience of this world is a righteous woman}}
\hadithdefcmd{nasai}{3233}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَنْبَأَنَا النَّضْرُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسٍ، قَالُوا يَا رَسُولَ اللَّهِ أَلاَ تَتَزَوَّجُ مِنْ نِسَاءِ الأَنْصَارِ قَالَ ‏ "‏ إِنَّ فِيهِمْ لَغَيْرَةً شَدِيدَةً ‏"‏ ‏.‏\hadithno{3233}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas:It was narrated from Anas that they said: "O Messenger of Allah, why don't you marry a woman from the Ansar?" He said: "They are very jealous}}
\hadithdefcmd{nasai}{3234}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مَرْوَانُ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ كَيْسَانَ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَطَبَ رَجُلٌ امْرَأَةً مِنَ الأَنْصَارِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَلْ نَظَرْتَ إِلَيْهَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ فَأَمَرَهُ أَنْ يَنْظُرَ إِلَيْهَا ‏.‏\hadithno{3234}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:It was narrated that Abu Hurairah said: "A man proposed to a woman from among the Ansar and the Messenger of Allah said to him: 'Have you seen her?' He said: 'No.' So he told him to look at her}}
\hadithdefcmd{nasai}{3235}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، قَالَ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، قَالَ حَدَّثَنَا عَاصِمٌ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ خَطَبْتُ امْرَأَةً عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَنَظَرْتَ إِلَيْهَا ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَانْظُرْ إِلَيْهَا فَإِنَّهُ أَجْدَرُ أَنْ يُؤْدَمَ بَيْنَكُمَا ‏"‏ ‏.‏\hadithno{3235}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Mughirah bin Shu'bah:It was narrated that Al-Mughirah bin Shu'bah said: "I proposed marriage to a woman during the time of the Messenger of Allah, and the Prophet said: 'Have you seen her?' I said: 'No.' He said: 'Look at her, for that is more likely to create love between you}}
\hadithdefcmd{nasai}{3236}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أُمَيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي شَوَّالٍ وَأُدْخِلْتُ عَلَيْهِ فِي شَوَّالٍ وَكَانَتْ عَائِشَةُ تُحِبُّ أَنْ تُدْخِلَ نِسَاءَهَا فِي شَوَّالٍ فَأَىُّ نِسَائِهِ كَانَتْ أَحْظَى عِنْدَهُ مِنِّي\hadithno{3236}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim}\hadithtrans{Narrated 'Urwah:It was narrated from 'Urwah, that 'Aishah said: "The Messenger of Allah married me in Shawwal and my marriage was consummated in Shawwal." --'Aishah liked for her women's marriages to be consummated in Shawwal --"and which of his wives was more beloved to him than me?}}
\hadithdefcmd{nasai}{3237}{أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ حَدَّثَنِي عَامِرُ بْنُ شَرَاحِيلَ الشَّعْبِيُّ، أَنَّهُ سَمِعَ فَاطِمَةَ بِنْتَ قَيْسٍ، - وَكَانَتْ مِنَ الْمُهَاجِرَاتِ الأُوَلِ - قَالَتْ خَطَبَنِي عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ فِي نَفَرٍ مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم وَخَطَبَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى مَوْلاَهُ أُسَامَةَ بْنِ زَيْدٍ وَقَدْ كُنْتُ حُدِّثْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَحَبَّنِي فَلْيُحِبَّ أُسَامَةَ ‏"‏ ‏.‏ فَلَمَّا كَلَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ أَمْرِي بِيَدِكَ فَأَنْكِحْنِي مَنْ شِئْتَ ‏.‏ فَقَالَ ‏"‏ انْطَلِقِي إِلَى أُمِّ شَرِيكٍ ‏"‏ ‏.‏ وَأُمُّ شَرِيكٍ امْرَأَةٌ غَنِيَّةٌ مِنَ الأَنْصَارِ عَظِيمَةُ النَّفَقَةِ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ يَنْزِلُ عَلَيْهَا الضِّيفَانُ فَقُلْتُ سَأَفْعَلُ ‏.‏ قَالَ ‏"‏ لاَ تَفْعَلِي فَإِنَّ أُمَّ شَرِيكٍ كَثِيرَةُ الضِّيفَانِ فَإِنِّي أَكْرَهُ أَنْ يَسْقُطَ عَنْكِ خِمَارُكِ أَوْ يَنْكَشِفَ الثَّوْبُ عَنْ سَاقَيْكِ فَيَرَى الْقَوْمُ مِنْكِ بَعْضَ مَا تَكْرَهِينَ وَلَكِنِ انْتَقِلِي إِلَى ابْنِ عَمِّكِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏ وَهُوَ رَجُلٌ مِنْ بَنِي فِهْرٍ فَانْتَقَلْتُ إِلَيْهِ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{3237}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Amir bin Shurahbil Ash-Sha'bi:'Amir bin Shurahbil Ash-Sha'bi narrated that he heard Fatimah bint Qais--who was one of the first Muhajir women-- say: 'Abdur-Rahman bin 'Awf proposed marriage to me, along with others of the Companions of Muhammad. And the Messenger of Allah proposed that I marry his freed slave, Usamah bin Zaid. I was told that the Messenger of Allah had said: 'Whoever loves me, let him love Usamah.' When the Messenger of Allah spoke to me I said: 'My affairs are in your hands; marry me to whomever you wish.' He said: 'Go to Umm Sharik.' Umm Sharik was a rich Ansari woman who used to spend a great deal in the cause of Allah, and she always had a lot of guests. I said: 'I will do that.' He said: 'Do not do that, for Umm Sharik has a lot of guests, and I would not like your Khimar to fall off, or your shins to become uncovered, and the people to see something of you that you do not want them to see. Rather go to your cousin (son of your paternal uncle) 'Abdullah bin 'Amr bin Umm Maktum, who is a man of Banu Fihr.' So I went to him}}
\hadithdefcmd{nasai}{3238}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَخْطُبْ أَحَدُكُمْ عَلَى خِطْبَةِ بَعْضٍ ‏"‏ ‏.‏\hadithno{3238}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Umar:It was narrated from Ibn 'Umar that the Prophet said: "None of you should propose marriage to a woman when someone else has already proposed to her}}
\hadithdefcmd{nasai}{3239}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ مُحَمَّدٌ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لاَ تَنَاجَشُوا وَلاَ يَبِعْ حَاضِرٌ لِبَادٍ وَلاَ يَبِعِ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ يَخْطُبْ عَلَى خِطْبَةِ أَخِيهِ وَلاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَكْتَفِئَ مَا فِي إِنَائِهَا ‏"‏ ‏.‏\hadithno{3239}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:It was narrated that Abu Hurairah said: "The Messenger of Allah said: 'Do not artificially inflate prices, a resident should not sell for a Bedouin, a man should not offer more for something that has already been bought by his brother, no one should propose marriage to a woman when someone else has already proposed to her, and no woman should try to bring about the divorce of her sister, in order to deprive her of the blessings that she has}}
\hadithdefcmd{nasai}{3240}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، ح وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَخْطُبْ أَحَدُكُمْ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{3240}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:It was narrated from Abu Hurairah that the Prophet said: "None of you should propose marriage to a woman when someone else has already proposed to her}}
\hadithdefcmd{nasai}{3241}{أَخْبَرَنِي يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَخْطُبْ أَحَدُكُمْ عَلَى خِطْبَةِ أَخِيهِ حَتَّى يَنْكِحَ أَوْ يَتْرُكَ ‏"‏ ‏.‏\hadithno{3241}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"None of you should propose marriage to a woman when someone else has already proposed to her, unless he marries (and he gives up the idea), or gives him permission}}
\hadithdefcmd{nasai}{3242}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَخْطُبْ أَحَدُكُمْ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{3242}\hadithgrade{Abu Ghuddah: -; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"None of you should propose marriage to a woman when someone else has already proposed to her}}
\hadithdefcmd{nasai}{3243}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا الْحَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ سَمِعْتُ نَافِعًا، يُحَدِّثُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيعَ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَلاَ يَخْطُبُ الرَّجُلُ عَلَى خِطْبَةِ الرَّجُلِ حَتَّى يَتْرُكَ الْخَاطِبُ قَبْلَهُ أَوْ يَأْذَنَ لَهُ الْخَاطِبُ ‏.‏\hadithno{3243}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin 'Amr used to say:"The Messenger of Allah forbade offering more for something that has already been bought by his brother, or for a man to propose marriage to a woman when someone else has already proposed to her, unless the previous suitor gave up the idea or gave him permission}}
\hadithdefcmd{nasai}{3244}{أَخْبَرَنِي حَاجِبُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، وَيَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَعَنِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، أَنَّهُمَا سَأَلاَ فَاطِمَةَ بِنْتَ قَيْسٍ عَنْ أَمْرِهَا، فَقَالَتْ طَلَّقَنِي زَوْجِي ثَلاَثًا فَكَانَ يَرْزُقُنِي طَعَامًا فِيهِ شَىْءٌ فَقُلْتُ وَاللَّهِ لَئِنْ كَانَتْ لِي النَّفَقَةُ وَالسُّكْنَى لأَطْلُبَنَّهَا وَلاَ أَقْبَلُ هَذَا ‏.‏ فَقَالَ الْوَكِيلُ لَيْسَ لَكِ سُكْنَى وَلاَ نَفَقَةٌ ‏.‏ قَالَتْ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏"‏ لَيْسَ لَكِ سُكْنَى وَلاَ نَفَقَةٌ فَاعْتَدِّي عِنْدَ فُلاَنَةَ ‏"‏ ‏.‏ قَالَتْ وَكَانَ يَأْتِيهَا أَصْحَابُهُ ثُمَّ قَالَ ‏"‏ اعْتَدِّي عِنْدَ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ أَعْمَى فَإِذَا حَلَلْتِ فَآذِنِينِي ‏"‏ ‏.‏ قَالَتْ فَلَمَّا حَلَلْتُ آذَنْتُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَنْ خَطَبَكِ ‏"‏ ‏.‏ فَقُلْتُ مُعَاوِيَةُ وَرَجُلٌ آخَرُ مِنْ قُرَيْشٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمَّا مُعَاوِيَةُ فَإِنَّهُ غُلاَمٌ مِنْ غِلْمَانِ قُرَيْشٍ لاَ شَىْءَ لَهُ وَأَمَّا الآخَرُ فَإِنَّهُ صَاحِبُ شَرٍّ لاَ خَيْرَ فِيهِ وَلَكِنِ انْكِحِي أُسَامَةَ بْنَ زَيْدٍ ‏"‏ ‏.‏ قَالَتْ فَكَرِهْتُهُ ‏.‏ فَقَالَ لَهَا ذَلِكَ ثَلاَثَ مَرَّاتٍ فَنَكَحَتْهُ ‏.‏\hadithno{3244}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Muhammad bin 'Abdur-Rahman bin Thawban that they asked Fatimah bint Qais about her story and she said:"My husband divorced me three times, and he used to provide me with food that was not good." She said: "By Allah, if I were entitled to maintenance and accommodation I would demand them and I would not accept this." The deputy said: "You are not entitled to accommodation or maintenance." She said: "I came to the Prophet and told him about that, and he said: 'You are not entitled to accommodation nor maintenance; observe your 'Iddah in the house of so-and-so.' She said: 'His Companions used to go to her.' Then he said: 'Observe your 'Iddah in the house of Ibn Umm Maktum, who is blind, and when your 'Iddah is over, let me know.'" She said: "When my 'Iddah was over, I let him know. The Messenger of Allah said: 'Who has proposed marriage to you?' I said: 'Mu'awiyah and another man from the Quraish.' He said: 'As for Mu'awiyah, he is a boy among the Quraish and does not have anything, and as for the other he is a bad man with no goodness in him. Rather you should marry Usamah bin Zaid.'" She said: "I did not like the idea." But he said that to her three times so she married him}}
\hadithdefcmd{nasai}{3245}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لِمُحَمَّدٍ - عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّ أَبَا عَمْرِو بْنَ حَفْصٍ، طَلَّقَهَا الْبَتَّةَ وَهُوَ غَائِبٌ فَأَرْسَلَ إِلَيْهَا وَكِيلُهُ بِشَعِيرٍ فَسَخِطَتْهُ ‏.‏ فَقَالَ وَاللَّهِ مَا لَكِ عَلَيْنَا مِنْ شَىْءٍ ‏.‏ فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ فَقَالَ ‏"‏ لَيْسَ لَكِ نَفَقَةٌ ‏"‏ ‏.‏ فَأَمَرَهَا أَنْ تَعْتَدَّ فِي بَيْتِ أُمِّ شَرِيكٍ ثُمَّ قَالَ ‏"‏ تِلْكَ امْرَأَةٌ يَغْشَاهَا أَصْحَابِي فَاعْتَدِّي عِنْدَ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ رَجُلٌ أَعْمَى تَضَعِينَ ثِيَابَكِ فَإِذَا حَلَلْتِ فَآذِنِينِي ‏"‏ ‏.‏ قَالَتْ فَلَمَّا حَلَلْتُ ذَكَرْتُ لَهُ أَنَّ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ وَأَبَا جَهْمٍ خَطَبَانِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا أَبُو جَهْمٍ فَلاَ يَضَعُ عَصَاهُ عَنْ عَاتِقِهِ وَأَمَّا مُعَاوِيَةُ فَصُعْلُوكٌ لاَ مَالَ لَهُ وَلَكِنِ انْكِحِي أُسَامَةَ بْنَ زَيْدٍ ‏"‏ ‏.‏ فَكَرِهْتُهُ ثُمَّ قَالَ ‏"‏ انْكِحِي أُسَامَةَ بْنَ زَيْدٍ ‏"‏ ‏.‏ فَنَكَحْتُهُ فَجَعَلَ اللَّهُ عَزَّ وَجَلَّ فِيهِ خَيْرًا وَاغْتَبَطْتُ بِهِ ‏.‏\hadithno{3245}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Fatimah bint Qais that Abu 'Amr bin Hafs issued a final divorce to her while he was absent. His deputy sent some barley to her but she did not like it. He said:"By Allah, you have no rights over us." She went to the Messenger of Allah and told him about that, and he said: "You have no right to maintenance." He told her to observe her 'Iddah in the house of Umm Sharik, then he said: "She is a woman whose house is frequented by my Companions. Observe your 'Iddah in the house of Ibn Umm Maktum, for he is a blind man and you can take off your garment. And when your 'Iddah is over, let me know." She said: "When my 'Iddah was over I told him that Mu'awiyah bin Abi Sufyan and Abu Jahm had proposed marriage to me. The Messenger of Allah said: 'As for Abu Jahm, his stick never leaves his shoulder, and as for Mu'awiyah he is a poor man who has no wealth. Rather you should marry Usamah bin Zaid.' I did not like the idea, then he said: 'Marry Usamah bin Zaid.' So I married him and Allah created a lot of good in him, and others felt jealous of my good fortune}}
\hadithdefcmd{nasai}{3246}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ هَاشِمِ بْنِ الْبَرِيدِ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ مِنَ الأَنْصَارِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي تَزَوَّجْتُ امْرَأَةً ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَلاَ نَظَرْتَ إِلَيْهَا فَإِنَّ فِي أَعْيُنِ الأَنْصَارِ شَيْئًا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَجَدْتُ هَذَا الْحَدِيثَ فِي مَوْضِعٍ آخَرَ عَنْ يَزِيدَ بْنِ كَيْسَانَ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ حَدَّثَ وَالصَّوَابُ أَبُو هُرَيْرَةَ ‏.‏\hadithno{3246}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"A man of the Ansar came to the Messenger of Allah and said: 'I have married a woman.' He said: 'Did you look at her? For there is something in the eyes of the Ansar}}
\hadithdefcmd{nasai}{3247}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، أَرَادَ أَنْ يَتَزَوَّجَ، امْرَأَةً فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ انْظُرْ إِلَيْهَا فَإِنَّ فِي أَعْيُنِ الأَنْصَارِ شَيْئًا ‏"‏ ‏.‏\hadithno{3247}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that a man wanted to marry a woman and the Prophet said:"Look at her, for there is something in the eyes of the Ansar}}
\hadithdefcmd{nasai}{3248}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ تَأَيَّمَتْ حَفْصَةُ بِنْتُ عُمَرَ مِنْ خُنَيْسٍ - يَعْنِي ابْنَ حُذَافَةَ - وَكَانَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِمَّنْ شَهِدَ بَدْرًا فَتُوُفِّيَ بِالْمَدِينَةِ فَلَقِيتُ عُثْمَانَ بْنَ عَفَّانَ فَعَرَضْتُ عَلَيْهِ حَفْصَةَ فَقُلْتُ إِنْ شِئْتَ أَنْكَحْتُكَ حَفْصَةَ ‏.‏ فَقَالَ سَأَنْظُرُ فِي ذَلِكَ ‏.‏ فَلَبِثْتُ لَيَالِيَ فَلَقِيتُهُ فَقَالَ مَا أُرِيدُ أَنْ أَتَزَوَّجَ يَوْمِي هَذَا ‏.‏ قَالَ عُمَرُ فَلَقِيتُ أَبَا بَكْرٍ الصِّدِّيقَ رضى الله عنه فَقُلْتُ إِنْ شِئْتَ أَنْكَحْتُكَ حَفْصَةَ فَلَمْ يَرْجِعْ إِلَىَّ شَيْئًا فَكُنْتُ عَلَيْهِ أَوْجَدَ مِنِّي عَلَى عُثْمَانَ رَضِيَ اللَّهُ عَنْهُ فَلَبِثْتُ لَيَالِيَ فَخَطَبَهَا إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَنْكَحْتُهَا إِيَّاهُ فَلَقِيَنِي أَبُو بَكْرٍ فَقَالَ لَعَلَّكَ وَجَدْتَ عَلَىَّ حِينَ عَرَضْتَ عَلَىَّ حَفْصَةَ فَلَمْ أَرْجِعْ إِلَيْكَ شَيْئًا ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ فَإِنَّهُ لَمْ يَمْنَعْنِي حِينَ عَرَضْتَ عَلَىَّ أَنْ أَرْجِعَ إِلَيْكَ شَيْئًا إِلاَّ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُهَا وَلَمْ أَكُنْ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَوْ تَرَكَهَا نَكَحْتُهَا ‏.‏\hadithno{3248}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Umar said:"Hafsah bint 'Umar became single when (her husband) Khunais -meaning bin Hudhafah- (died). He was one of the Companions of the Prophet who had been present at Badr, and he died in Al-Madinah. I met 'Uthman bin 'Affan and offered Hafsah in marriage to him. I said: 'If you wish, I will marry you to Hafsah.' He said: 'I will think about it.' A few days passed, then I met him and he said: 'I do not want to get married at the moment.'" 'Umar said: "Then I met Abu Bakr As-Siddiq, may Allah be pleased with him, and said: 'If you wish, I will marry Hafsah to you.' He did not give me any answer, and I felt more upset with him than I had with 'Uthman, may Allah be pleased with him. Several days passed, then the Messenger of Allah proposed marriage to her, and I married her to him. Abu Bakr met me and said: 'Perhaps you felt upset with me when you offered Hafsah in marriage to me and I did not give you an answer?' I said: 'Yes.' He said: 'Nothing prevented me from giving you an answer when you made the offer to me except the fact that I had heard the Messenger of Allah speak of her, and I did not want to disclose the secret of the Messenger of Allah; if he had left her, then I would have married her}}
\hadithdefcmd{nasai}{3249}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ الْعَطَّارُ أَبُو عَبْدِ الصَّمَدِ، قَالَ سَمِعْتُ ثَابِتًا الْبُنَانِيَّ، يَقُولُ كُنْتُ عِنْدَ أَنَسِ بْنِ مَالِكٍ وَعِنْدَهُ ابْنَةٌ لَهُ فَقَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَرَضَتْ عَلَيْهِ نَفْسَهَا فَقَالَتْ يَا رَسُولَ اللَّهِ أَلَكَ فِيَّ حَاجَةٌ\hadithno{3249}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Thabit Al-Bunani said:"I was with Anas bin Malik and a daughter of his was with him. He said: 'A woman came to the Messenger of Allah and offered herself in marriage to him. She said: O Messenger of Allah, do you want to marry me?}}
\hadithdefcmd{nasai}{3250}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مَرْحُومٌ، قَالَ حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ امْرَأَةً، عَرَضَتْ نَفْسَهَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَضَحِكَتِ ابْنَةُ أَنَسٍ فَقَالَتْ مَا كَانَ أَقَلَّ حَيَاءَهَا ‏.‏ فَقَالَ أَنَسٌ هِيَ خَيْرٌ مِنْكِ عَرَضَتْ نَفْسَهَا عَلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3250}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that a woman offered herself in marriage to the Prophet. The daughter of Anas laughed and said:"How little was her modesty." Anas said: "She was better than you; she offered herself in marriage to the Prophet}}
\hadithdefcmd{nasai}{3251}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ لَمَّا انْقَضَتْ عِدَّةُ زَيْنَبَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِزَيْدٍ ‏ "‏ اذْكُرْهَا عَلَىَّ ‏"‏ ‏.‏ قَالَ زَيْدٌ فَانْطَلَقْتُ فَقُلْتُ يَا زَيْنَبُ أَبْشِرِي أَرْسَلَنِي إِلَيْكِ رَسُولُ اللَّهِ صلى الله عليه وسلم يَذْكُرُكِ ‏.‏ فَقَالَتْ مَا أَنَا بِصَانِعَةٍ شَيْئًا حَتَّى أَسْتَأْمِرَ رَبِّي فَقَامَتْ إِلَى مَسْجِدِهَا وَنَزَلَ الْقُرْآنُ وَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ بِغَيْرِ أَمْرٍ ‏.‏\hadithno{3251}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"When the 'Iddah of Zainab was over, the Messenger of Allah said to Zaid: 'Propose marriage to her on my behalf.' Zaid went and said: 'O Zainab, rejoice, for the Messenger of Allah has sent me to you to propose marriage on his behalf.' She said: 'I will not do anything until I consult my Lord.' She went to her prayer place and Qur'an was revealed, then the Messenger of Allah came and entered upon her without any formalities}}
\hadithdefcmd{nasai}{3252}{أَخْبَرَنِي أَحْمَدُ بْنُ يَحْيَى الصُّوفِيُّ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا عِيسَى بْنُ طَهْمَانَ أَبُو بَكْرٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَتْ زَيْنَبُ بِنْتُ جَحْشٍ تَفْخَرُ عَلَى نِسَاءِ النَّبِيِّ صلى الله عليه وسلم تَقُولُ إِنَّ اللَّهَ عَزَّ وَجَلَّ أَنْكَحَنِي مِنَ السَّمَاءِ ‏.‏ وَفِيهَا نَزَلَتْ آيَةُ الْحِجَابِ ‏.‏\hadithno{3252}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas bin Malik said:Zainab bint Jahsh used to boast to the other wives of the Prophet and say: "Allah married me to him from above the Heavens." And the Verse of Hijab was revealed concerning her}}
\hadithdefcmd{nasai}{3253}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي الْمَوَالِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا الاِسْتِخَارَةَ فِي الأُمُورِ كُلِّهَا كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ ‏ "‏ إِذَا هَمَّ أَحَدُكُمْ بِالأَمْرِ فَلْيَرْكَعْ رَكْعَتَيْنِ مِنْ غَيْرِ الْفَرِيضَةِ ثُمَّ يَقُولُ اللَّهُمَّ إِنِّي أَسْتَخِيرُكَ بِعِلْمِكَ وَأَسْتَعِينُكَ بِقُدْرَتِكَ وَأَسْأَلُكَ مِنْ فَضْلِكَ الْعَظِيمِ فَإِنَّكَ تَقْدِرُ وَلاَ أَقْدِرُ وَتَعْلَمُ وَلاَ أَعْلَمُ وَأَنْتَ عَلاَّمُ الْغُيُوبِ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ خَيْرٌ لِي فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي - أَوْ قَالَ فِي عَاجِلِ أَمْرِي وَآجِلِهِ - فَاقْدُرْهُ لِي وَيَسِّرْهُ لِي ثُمَّ بَارِكْ لِي فِيهِ وَإِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ شَرٌّ لِي فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي - أَوْ قَالَ فِي عَاجِلِ أَمْرِي وَآجِلِهِ - فَاصْرِفْهُ عَنِّي وَاصْرِفْنِي عَنْهُ وَاقْدُرْ لِي الْخَيْرَ حَيْثُ كَانَ ثُمَّ أَرْضِنِي بِهِ - قَالَ - وَيُسَمِّي حَاجَتَهُ ‏"‏ ‏.‏\hadithno{3253}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah used to teach his Companions to perform Istikharah in all matters, just as he used to teach them Surahs from the Qur'an. He said: 'If any one of you is deliberating about a decision he has to make, then let him pray two Rak'ahs of non-obligatory prayer, then say: Allahumma inni astakhiruka bi 'ilmika wa astaqdiruka bi qudratika wa as'aluka min fadlika, fa innaka taqdiru wa la aqdir, wa ta'lamu wa la a'lam, wa anta 'allam al-ghuyub. Allahumma in kunta ta'lamu anna hadhal-amra khayrun li fi dini wa ma'ashi wa aqibati amri faqdurhu li wa yassirhu li thumma barik li fihi. Allahumma, wa in kunta ta'lamu annahu sharrun li fi dini wa ma'ashi wa 'aqibati amri fasrifhu 'anni wasrifni 'anhu waqdur li al-khayr haythu kana, thumma radini bihi. (O Allah, I seek Your guidance (in making a choice) by virtue of Your knowledge, and I seek ability by virtue of Your power, and I ask You of Your great bounty. You have power, I have none. And You know, I know not. You are the Knower of hidden things. O Allah, if in Your knowledge, this matter (then it should be mentioned by name) is good for me in my religion, my livelihood and my affairs (or: both in this world and in the Hereafter), then ordain it for me, make it easy for me, and bless it for me. And if in Your knowledge it is bad for me and for my religion, my livelihood and my affairs (or: for me both in this world and the next), then turn it away from me and turn me away from it, and ordain for me the good wherever it may be and make me pleased with it}}
\hadithdefcmd{nasai}{3254}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، حَدَّثَنِي ابْنُ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، لَمَّا انْقَضَتْ عِدَّتُهَا بَعَثَ إِلَيْهَا أَبُو بَكْرٍ يَخْطُبُهَا عَلَيْهِ فَلَمْ تَزَوَّجْهُ فَبَعَثَ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم عُمَرَ بْنَ الْخَطَّابِ يَخْطُبُهَا عَلَيْهِ فَقَالَتْ أَخْبِرْ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنِّي امْرَأَةٌ غَيْرَى وَأَنِّي امْرَأَةٌ مُصْبِيَةٌ وَلَيْسَ أَحَدٌ مِنْ أَوْلِيَائِي شَاهِدٌ ‏.‏ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏ "‏ ارْجِعْ إِلَيْهَا فَقُلْ لَهَا أَمَّا قَوْلُكِ إِنِّي امْرَأَةٌ غَيْرَى فَسَأَدْعُو اللَّهَ لَكِ فَيُذْهِبُ غَيْرَتَكِ وَأَمَّا قَوْلُكِ إِنِّي امْرَأَةٌ مُصْبِيَةٌ فَسَتُكْفَيْنَ صِبْيَانَكِ وَأَمَّا قَوْلُكِ أَنْ لَيْسَ أَحَدٌ مِنْ أَوْلِيَائِي شَاهِدٌ فَلَيْسَ أَحَدٌ مِنْ أَوْلِيَائِكِ شَاهِدٌ وَلاَ غَائِبٌ يَكْرَهُ ذَلِكَ ‏"‏ ‏.‏ فَقَالَتْ لاِبْنِهَا يَا عُمَرُ قُمْ فَزَوِّجْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَزَوَّجَهُ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{3254}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Umm Salamah, that when her 'Iddah had ended, Abu Bakr sent word to her proposing marriage to her, but she did not marry him. Then the Messenger of Allah sent 'Umar bin Al-Khattab with a proposal of marriage. She said:"Tell the Messenger of Allah that I am a jealous woman and that I have sons, and none of my guardians are present." He went to the Messenger of Allah and told him that. He said: "Go back to her and tell her: As for your saying that you are a jealous woman, I will pray to Allah for you to take away your jealousy. As for your saying that you have sons, your sons will be taken care of. And as for your saying that none of your guardians are present, none of your guardians, present or absent, would object to that." She said to her son: "O 'Umar, get up and perform the marriage to the Messenger of Allah," so he performed the marriage}}
\hadithdefcmd{nasai}{3255}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَهَا وَهِيَ بِنْتُ سِتٍّ وَبَنَى بِهَا وَهِيَ بِنْتُ تِسْعٍ ‏.‏\hadithno{3255}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah married her when she was six years old, and consummated the marriage with her when she was nine}}
\hadithdefcmd{nasai}{3256}{أَخْبَرَنَا مُحَمَّدُ بْنُ النَّضْرِ بْنِ مُسَاوِرٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم لِسَبْعِ سِنِينَ وَدَخَلَ عَلَىَّ لِتِسْعِ سِنِينَ ‏.‏\hadithno{3256}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah married me when I was seven years old, and he consummated the marriage with me when I was nine}}
\hadithdefcmd{nasai}{3257}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْثَرٌ، عَنْ مُطَرِّفٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، قَالَ قَالَتْ عَائِشَةُ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم لِتِسْعِ سِنِينَ وَصَحِبْتُهُ تِسْعًا ‏.‏\hadithno{3257}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu 'Ubaidah said:"Aishah said: 'The Messenger of Allah married me when I was nine and I lived with him for nine years}}
\hadithdefcmd{nasai}{3258}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَأَحْمَدُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، تَزَوَّجَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهِيَ بِنْتُ تِسْعٍ وَمَاتَ عَنْهَا وَهِيَ بِنْتُ ثَمَانِيَ عَشْرَةَ ‏.‏\hadithno{3258}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah married her when she was nine and he died when she was eighteen years old}}
\hadithdefcmd{nasai}{3259}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، يُحَدِّثُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رضى الله عنه حَدَّثَنَا قَالَ يَعْنِي تَأَيَّمَتْ حَفْصَةُ بِنْتُ عُمَرَ مِنْ خُنَيْسِ بْنِ حُذَافَةَ السَّهْمِيِّ - وَكَانَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَتُوُفِّيَ بِالْمَدِينَةِ - قَالَ عُمَرُ فَأَتَيْتُ عُثْمَانَ بْنَ عَفَّانَ رَضِيَ اللَّهُ عَنْهُ فَعَرَضْتُ عَلَيْهِ حَفْصَةَ بِنْتَ عُمَرَ قَالَ قُلْتُ إِنْ شِئْتَ أَنْكَحْتُكَ حَفْصَةَ ‏.‏ قَالَ سَأَنْظُرُ فِي أَمْرِي فَلَبِثْتُ لَيَالِيَ ثُمَّ لَقِيَنِي فَقَالَ قَدْ بَدَا لِي أَنْ لاَ أَتَزَوَّجَ يَوْمِي هَذَا ‏.‏ قَالَ عُمَرُ فَلَقِيتُ أَبَا بَكْرٍ الصِّدِّيقَ رضى الله عنه فَقُلْتُ إِنْ شِئْتَ زَوَّجْتُكَ حَفْصَةَ بِنْتَ عُمَرَ ‏.‏ فَصَمَتَ أَبُو بَكْرٍ فَلَمْ يَرْجِعْ إِلَىَّ شَيْئًا فَكُنْتُ عَلَيْهِ أَوْجَدَ مِنِّي عَلَى عُثْمَانَ فَلَبِثْتُ لَيَالِيَ ثُمَّ خَطَبَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَنْكَحْتُهَا إِيَّاهُ فَلَقِيَنِي أَبُو بَكْرٍ فَقَالَ لَعَلَّكَ وَجَدْتَ عَلَىَّ حِينَ عَرَضْتَ عَلَىَّ حَفْصَةَ فَلَمْ أَرْجِعْ إِلَيْكَ شَيْئًا ‏.‏ قَالَ عُمَرُ قُلْتُ نَعَمْ ‏.‏ قَالَ فَإِنَّهُ لَمْ يَمْنَعْنِي أَنْ أَرْجِعَ إِلَيْكَ شَيْئًا فِيمَا عَرَضْتَ عَلَىَّ إِلاَّ أَنِّي قَدْ كُنْتُ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ ذَكَرَهَا وَلَمْ أَكُنْ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَوْ تَرَكَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَبِلْتُهَا ‏.‏\hadithno{3259}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Umar bin Al-Khattab, may Allah be pleased with him, narrated:"Hafsah bint 'Umar became single when (her husband) Khunais bin Hudhafah As-Sahmi (died). He was one of the Companions of the Prophet, and he died in Al-Madinah." Umar said: "I went to 'Uthman bin 'Affan and offered Hafsah in marriage to him. I said: 'If you wish, I will marry you to Hafsah bint 'Umar.' He said: 'I will think about it.' A few days passed, then I met him and he said: 'It seems that I do not want to get married at the moment.'" 'Umar said: "Then I met Abu Bakr As-Siddiq, may Allah be pleased with him, and said: 'If you wish, I will marry Hafsah bint 'Umar to you.' Abu Bakr remained silent, and did not give me any answer, and I felt more upset with him than I had with 'Uthman. Several days passed, then the Messenger of Allah proposed marriage to her and I married her to him. Abu Bakr met me and said: 'Perhaps you felt upset with me when you offered Hafsah in marriage to me, and I did not give you any answer?' I said: 'Yes.' He said: 'Nothing prevented me from giving you an answer when you made the offer to me, except the fact that I had heard the Messenger of Allah speak of her, and I did not want to disclose the secret of the Messenger of Allah. If he had left her, then I would have married her}}
\hadithdefcmd{nasai}{3260}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الأَيِّمُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ تُسْتَأْذَنُ فِي نَفْسِهَا وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏\hadithno{3260}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah said:"A previously married woman has more right to decide about herself (with regard to marriage) than her guardian, and a virgin should be asked for permission with regard to marriage, and her permission is her silence}}
\hadithdefcmd{nasai}{3261}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، قَالَ سَمِعْتُهُ مِنْهُ، بَعْدَ مَوْتِ نَافِعٍ بِسَنَةٍ وَلَهُ يَوْمَئِذٍ حَلْقَةٌ قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ الْفَضْلِ عَنْ نَافِعِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الأَيِّمُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْيَتِيمَةُ تُسْتَأْمَرُ وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏\hadithno{3261}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet said:"A previously married woman has more right to decide about herself (with regard to marriage) than her guardian, and an orphan girl should be consulted, and her permission is her silence}}
\hadithdefcmd{nasai}{3262}{أَخْبَرَنِي أَحْمَدُ بْنُ سَعِيدٍ الرِّبَاطِيُّ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنِي أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي صَالِحُ بْنُ كَيْسَانَ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ بْنِ عَبَّاسِ بْنِ رَبِيعَةَ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الأَيِّمُ أَوْلَى بِأَمْرِهَا وَالْيَتِيمَةُ تُسْتَأْمَرُ فِي نَفْسِهَا وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏\hadithno{3262}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah said:"A previously married woman has more right (to decide) about herself (with regard to marriage) than her guardian, and an orphan girl should be consulted with regard to marriage, and her permission is her silence}}
\hadithdefcmd{nasai}{3263}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ لِلْوَلِيِّ مَعَ الثَّيِّبِ أَمْرٌ وَالْيَتِيمَةُ تُسْتَأْمَرُ فَصَمْتُهَا إِقْرَارُهَا ‏"‏ ‏.‏\hadithno{3263}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet said:"The guardian has no right (to force) the previously married woman (into a marriage). And an orphan girl should be consulted, and her silence is her approval}}
\hadithdefcmd{nasai}{3264}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الثَّيِّبُ أَحَقُّ بِنَفْسِهَا وَالْبِكْرُ يَسْتَأْمِرُهَا أَبُوهَا وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏\hadithno{3264}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet said:"A previously married woman has more right (to decide) about herself (with regard to marriage), and a virgin should be consulted by her father, and her permission is her silence}}
\hadithdefcmd{nasai}{3265}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُنْكَحُ الثَّيِّبُ حَتَّى تُسْتَأْذَنَ وَلاَ تُنْكَحُ الْبِكْرُ حَتَّى تُسْتَأْمَرَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ إِذْنُهَا قَالَ ‏"‏ إِذْنُهَا أَنْ تَسْكُتَ ‏"‏ ‏.‏\hadithno{3265}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"A previously married woman should not be married until her permission has been sought, and a virgin should not be married until her consent is sought." They said: "O Messenger of Allah, how does she give her permission?" He said: "Her permission is if she keeps silent}}
\hadithdefcmd{nasai}{3266}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، يُحَدِّثُ عَنْ ذَكْوَانَ أَبِي عَمْرٍو، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ اسْتَأْمِرُوا النِّسَاءَ فِي أَبْضَاعِهِنَّ ‏"‏ ‏.‏ قِيلَ فَإِنَّ الْبِكْرَ تَسْتَحِي وَتَسْكُتُ ‏.‏ قَالَ ‏"‏ هُوَ إِذْنُهَا ‏"‏ ‏.‏\hadithno{3266}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"Seek the permission of women with regard to marriage." It was said: "What if a virgin is too shy and remains silent?" He said: "That is her permission}}
\hadithdefcmd{nasai}{3267}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُنْكَحُ الأَيِّمُ حَتَّى تُسْتَأْمَرَ وَلاَ تُنْكَحُ الْبِكْرُ حَتَّى تُسْتَأْذَنَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ إِذْنُهَا قَالَ ‏"‏ أَنْ تَسْكُتَ ‏"‏ ‏.‏\hadithno{3267}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"A previously married woman should not be married until her consent has been sought, and a virgin should not be married until her permission has been sought." They said: "O Messenger of Allah, what is her permission?" He said: "If she remains silent}}
\hadithdefcmd{nasai}{3268}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، وَأَنْبَأَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَبْدِ الرَّحْمَنِ، وَمُجَمِّعِ، ابْنَىْ يَزِيدَ بْنِ جَارِيَةَ الأَنْصَارِيِّ عَنْ خَنْسَاءَ بِنْتِ خِذَامٍ، أَنَّ أَبَاهَا، زَوَّجَهَا وَهِيَ ثَيِّبٌ فَكَرِهَتْ ذَلِكَ فَأَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَدَّ نِكَاحَهُ ‏.‏\hadithno{3268}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Khansa' bint Khidham that her father married her off when she had been previously married, and she was unwilling. She went to the Messenger of Allah and he annulled the marriage}}
\hadithdefcmd{nasai}{3269}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ غُرَابٍ، قَالَ حَدَّثَنَا كَهْمَسُ بْنُ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عَائِشَةَ، أَنَّ فَتَاةً، دَخَلَتْ عَلَيْهَا فَقَالَتْ إِنَّ أَبِي زَوَّجَنِي ابْنَ أَخِيهِ لِيَرْفَعَ بِي خَسِيسَتَهُ وَأَنَا كَارِهَةٌ ‏.‏ قَالَتِ اجْلِسِي حَتَّى يَأْتِيَ النَّبِيُّ صلى الله عليه وسلم فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَتْهُ فَأَرْسَلَ إِلَى أَبِيهَا فَدَعَاهُ فَجَعَلَ الأَمْرَ إِلَيْهَا فَقَالَتْ يَا رَسُولَ اللَّهِ قَدْ أَجَزْتُ مَا صَنَعَ أَبِي وَلَكِنْ أَرَدْتُ أَنْ أَعْلَمَ أَلِلنِّسَاءِ مِنَ الأَمْرِ شَىْءٌ\hadithno{3269}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah:"A girl came to her and said: 'My father married me to his brother's son so that he might raise his own status thereby, and I was unwilling.' She said: 'Sit here until the Prophet comes.' Then the Messenger of Allah came, and I told him (what she had said). He sent word to her father, calling him, and he left the matter up to her. She said: 'O Messenger of Allah, I accept what my father did, but I wanted to know whether women have any say in the matter}}
\hadithdefcmd{nasai}{3270}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تُسْتَأْمَرُ الْيَتِيمَةُ فِي نَفْسِهَا فَإِنْ سَكَتَتْ فَهُوَ إِذْنُهَا وَإِنْ أَبَتْ فَلاَ جَوَازَ عَلَيْهَا ‏"‏ ‏.‏\hadithno{3270}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'An orphan girl should be consulted with regard to marriage, and if she remains silent, that is her permission. If she refuses then she is not to be forced}}
\hadithdefcmd{nasai}{3271}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ مُحَمَّدِ بْنِ سَوَاءٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، وَيَعْلَى بْنِ حَكِيمٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تَزَوَّجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَيْمُونَةَ بِنْتَ الْحَارِثِ وَهُوَ مُحْرِمٌ وَفِي حَدِيثِ يَعْلَى بِسَرِفَ ‏.‏\hadithno{3271}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah married Maimunah bint Al-Harith when he was a Muhrim." According to the Hadith of Ya'la (one of the narrators): "In Sarif}}
\hadithdefcmd{nasai}{3272}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي الشَّعْثَاءِ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{3272}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Ash-Sha'tha' that Ibn 'Abbas told him:"The Prophet married Maimunah when he was a Muhrim}}
\hadithdefcmd{nasai}{3273}{أَخْبَرَنَا عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْحَجَّاجِ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَكَحَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ جَعَلَتْ أَمْرَهَا إِلَى الْعَبَّاسِ فَأَنْكَحَهَا إِيَّاهُ ‏.‏\hadithno{3273}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet married Maimunah when he was a Muhrim, and she appointed Al-'Abbas in charge of her marriage, and he married her to him}}
\hadithdefcmd{nasai}{3274}{أَخْبَرَنَا أَحْمَدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، - وَهُوَ ابْنُ مُوسَى - عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{3274}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah married Maimunah when he was a Muhrim}}
\hadithdefcmd{nasai}{3275}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، أَنَّ أَبَانَ بْنَ عُثْمَانَ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ، رضى الله عنه يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْكِحُ الْمُحْرِمُ وَلاَ يُنْكِحُ وَلاَ يَخْطُبُ ‏"‏ ‏.‏\hadithno{3275}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Uthman bin 'Affan, may Allah be pleased with him, said:"The Messenger of Allah said: 'The Muhrim should not get married, or arrange a marriage for someone else, or propose marriage}}
\hadithdefcmd{nasai}{3276}{حَدَّثَنَا أَبُو الأَشْعَثِ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ مَطَرٍ، وَيَعْلَى بْنِ حَكِيمٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، عَنْ أَبَانَ بْنِ عُثْمَانَ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، رضى الله عنه حَدَّثَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَنْكِحُ الْمُحْرِمُ وَلاَ يُنْكِحُ وَلاَ يَخْطُبُ ‏"‏ ‏.‏\hadithno{3276}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Uthman bin 'Affan, may Allah be pleased with him, narrated that the Prophet said:"The Muhrim should not get married, arrange a marriage for someone else, nor propose marriage}}
\hadithdefcmd{nasai}{3277}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْثَرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم التَّشَهُّدَ فِي الصَّلاَةِ وَالتَّشَهُّدَ فِي الْحَاجَةِ قَالَ التَّشَهُّدُ فِي الْحَاجَةِ ‏ "‏ أَنِ الْحَمْدُ لِلَّهِ نَسْتَعِينُهُ وَنَسْتَغْفِرُهُ وَنَعُوذُ بِاللَّهِ مِنْ شُرُورِ أَنْفُسِنَا مَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلِ اللَّهُ فَلاَ هَادِيَ لَهُ وَأَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ وَيَقْرَأُ ثَلاَثَ آيَاتٍ ‏.‏\hadithno{3277}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah taught us the Tashahhud for Salah and the Tashahhud upon Al-Hajah. He said: 'The Tashahhud upon the occasion of marriage is: Alhamdu lillahi nasta'inahu wa nastaghfiruhu, wa na'udhu billahi min shururi anfusina, man yahdih Illahu fala mudilla lahu wa man yudlil Illahu fala hadiya lahu, wa ashhadu an la ilaha illallah, wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Praise be to Allah, we seek His help and His forgiveness. We seek refuge with Allah from the evil of our own souls. Whomsoever Allah guides will never be led astray, and whomsoever Allah leaves astray, no one can guide. I bear witness that there is none worthy of worship but Allah, and I bear witness that Muhammad is His slave and Messenger).' Then he recited three Verses}}
\hadithdefcmd{nasai}{3278}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، قَالَ حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ دَاوُدَ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، كَلَّمَ النَّبِيَّ صلى الله عليه وسلم فِي شَىْءٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ الْحَمْدَ لِلَّهِ نَحْمَدُهُ وَنَسْتَعِينُهُ مَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلِ اللَّهُ فَلاَ هَادِيَ لَهُ وَأَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ أَمَّا بَعْدُ ‏"‏ ‏.‏\hadithno{3278}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that a man spoke to the Prophet about something and the Prophet said:"Innal-hamda lillahi nahmaduhu wa nasta'inahu, man yahdih Illahu fala mudilla lahu wa man yudlil Illahu fala hadiya lahu, wa ashhadu an la ilaha illallahu (wahdahu lasharika lahu) wa ashhadu anna Muhammadan 'abdahu wa rasuluhu. Amma ba'd (Praise be to Allah, we seek His help. Whomsoever Allah guides will never be led astray, and whomsoever Allah leaves astray, no one can guide. I bear witness that there is none worthy of worship but Allah (alone with no partners) and I bear witness that Muhammad is His slave and Messenger. To proceed}}
\hadithdefcmd{nasai}{3279}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ تَشَهَّدَ رَجُلاَنِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا مَنْ يُطِعِ اللَّهَ وَرَسُولَهُ فَقَدْ رَشَدَ وَمَنْ يَعْصِهِمَا فَقَدْ غَوَى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بِئْسَ الْخَطِيبُ أَنْتَ ‏"‏ ‏.‏\hadithno{3279}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"Two men recited a Tashahhud before the Prophet and one of them said: 'Whoever obeys Allah and His Messenger has been guided aright and whoever disobeys them has gone astray.' The Messenger of Allah said: 'What a bad speaker you are}}
\hadithdefcmd{nasai}{3280}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ سَمِعْتُ أَبَا حَازِمٍ، يَقُولُ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ، يَقُولُ إِنِّي لَفِي الْقَوْمِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَامَتِ امْرَأَةٌ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ وَهَبَتْ نَفْسَهَا لَكَ فَرَأْ فِيهَا رَأْيَكَ ‏.‏ فَسَكَتَ فَلَمْ يُجِبْهَا النَّبِيُّ صلى الله عليه وسلم بِشَىْءٍ ثُمَّ قَامَتْ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ وَهَبَتْ نَفْسَهَا لَكَ فَرَأْ فِيهَا رَأْيَكَ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ زَوِّجْنِيهَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ هَلْ مَعَكَ شَىْءٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ اذْهَبْ فَاطْلُبْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ فَذَهَبَ فَطَلَبَ ثُمَّ جَاءَ فَقَالَ لَمْ أَجِدْ شَيْئًا وَلاَ خَاتَمًا مِنْ حَدِيدٍ ‏.‏ قَالَ ‏"‏ هَلْ مَعَكَ مِنَ الْقُرْآنِ شَىْءٌ ‏"‏ ‏.‏ قَالَ نَعَمْ مَعِي سُورَةُ كَذَا وَسُورَةُ كَذَا ‏.‏ قَالَ ‏"‏ قَدْ أَنْكَحْتُكَهَا عَلَى مَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{3280}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Sahl bin Sa'd said:"I was among the people with the Prophet when a woman stood up and said: 'O Messenger of Allah, she has offered herself in marriage to you, so see what you think of her.' He remained silent and the Prophet did not give any answer. Then she stood up (again) and said: 'O Messenger of Allah, she has offered herself in marriage to you, so see what you think of her.' A man stood up and said: 'Marry her to me, O Messenger of Allah!' He said: 'Do you have anything?' He said: 'No.' He said: 'Go and look, even if it is just an iron ring.' So he went and looked then he came and said: 'I could not find anything, not even an iron ring.' He said: 'Have you memorized anything of the Qur'an?' He said: 'Yes, Surah such-and-such and Surah such-and-such.' He said: 'I will marry you to her on the basis of what you have memorized of the Qur'an}}
\hadithdefcmd{nasai}{3281}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَقَّ الشُّرُوطِ أَنْ يُوَفَّى بِهِ مَا اسْتَحْلَلْتُمْ بِهِ الْفُرُوجَ ‏"‏ ‏.‏\hadithno{3281}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Utbah bin 'Amir that the Messenger of Allah said:"The conditions that are most deserving of fulfillment, are those by means of which the private parts become allowed to you}}
\hadithdefcmd{nasai}{3282}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ تَمِيمٍ، قَالَ سَمِعْتُ حَجَّاجًا، يَقُولُ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ أَبَا الْخَيْرِ، حَدَّثَهُ عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَقَّ الشُّرُوطِ أَنْ يُوَفَّى بِهِ مَا اسْتَحْلَلْتُمْ بِهِ الْفُرُوجَ ‏"‏ ‏.‏\hadithno{3282}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Utbah bin 'Amir that the Messenger of Allah said:"The conditions that are most deserving of fulfillment are those by means of which the private parts become permitted to you}}
\hadithdefcmd{nasai}{3283}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتِ امْرَأَةُ رِفَاعَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنَّ رِفَاعَةَ طَلَّقَنِي فَأَبَتَّ طَلاَقِي وَإِنِّي تَزَوَّجْتُ بَعْدَهُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ وَمَا مَعَهُ إِلاَّ مِثْلُ هُدْبَةِ الثَّوْبِ ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ لَعَلَّكِ تُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى يَذُوقَ عُسَيْلَتَكِ وَتَذُوقِي عُسَيْلَتَهُ ‏"‏ ‏.‏\hadithno{3283}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The wife of Rifa'ah came to the Messenger of Allah and said: 'Rifa'ah divorced me and made it irrevocable. Then I married 'Abdur-Rahman bin Az-Zubair, and what he has is like the fringe of a garment.' The Messenger of Allah smiled and said: 'Do you want to go back to Rifa'ah? No, not unitl he ('Abdur-Rahman) tastes your sweetness and you taste his sweetness}}
\hadithdefcmd{nasai}{3284}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَنْبَأَنَا شُعَيْبٌ، قَالَ أَخْبَرَنِي الزُّهْرِيُّ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، - وَأُمُّهَا أُمُّ سَلَمَةَ زَوْجُ النَّبِيِّ صلى الله عليه وسلم - أَخْبَرَتْهُ أَنَّ أُمَّ حَبِيبَةَ بِنْتَ أَبِي سُفْيَانَ أَخْبَرَتْهَا أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ أَنْكِحْ أُخْتِي بِنْتَ أَبِي سُفْيَانَ ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوَتُحِبِّينَ ذَلِكِ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ لَسْتُ لَكَ بِمُخْلِيَةٍ وَأَحَبُّ مَنْ يُشَارِكُنِي فِي خَيْرٍ أُخْتِي ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ أُخْتَكِ لاَ تَحِلُّ لِي ‏"‏ ‏.‏ فَقُلْتُ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنَّا لَنَتَحَدَّثُ أَنَّكَ تُرِيدُ أَنْ تَنْكِحَ دُرَّةَ بِنْتَ أَبِي سَلَمَةَ ‏.‏ فَقَالَ ‏"‏ بِنْتُ أُمِّ سَلَمَةَ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ ‏"‏ وَاللَّهِ لَوْلاَ أَنَّهَا رَبِيبَتِي فِي حَجْرِي مَا حَلَّتْ لِي إِنَّهَا لاَبْنَةُ أَخِي مِنَ الرَّضَاعَةِ أَرْضَعَتْنِي وَأَبَا سَلَمَةَ ثُوَيْبَةُ فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏ ‏.‏\hadithno{3284}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Urwah narrated that Zainab bint Abi Salamah -whose mother was Umm Salamah, the wife of the Prophet- told him that Umm Habibah bint Abi Sufyan told her that she said:"O Messenger of Allah, marry my sister, the daughter of Abu Sufyan." She said: "The Messenger of Allah said: 'Would you like that?' I said: 'Yes; I do not have you all to myself and I would like to share this goodness with my sister.' The Prophet said: 'Your sister is not permissible for me (to marry).' I said: 'By Allah, O Messenger of Allah, we have been saying that you want to marry Durrah bint Abi Salamah.' He said: 'The daughter of Umm Salamah?' I said: 'Yes.' He said: 'By Allah, even if she were not my stepdaughter who is in my care, she would not be permissible for me (to marry), because she is the daughter of my brother through breast-feeding. Thuwaibah breastfed Abu Salamah and I. So do not offer your daughters or sisters to me in marriage}}
\hadithdefcmd{nasai}{3285}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّ أُمَّ حَبِيبَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ يَا رَسُولَ اللَّهِ أَنْكِحْ بِنْتَ أَبِي تَعْنِي أُخْتَهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَتُحِبِّينَ ذَلِكِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ لَسْتُ لَكَ بِمُخْلِيَةٍ وَأَحَبُّ مَنْ شَرِكَتْنِي فِي خَيْرٍ أُخْتِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ ذَلِكَ لاَ يَحِلُّ ‏"‏ ‏.‏ قَالَتْ أُمُّ حَبِيبَةَ يَا رَسُولَ اللَّهِ وَاللَّهِ لَقَدْ تَحَدَّثْنَا أَنَّكَ تَنْكِحُ دُرَّةَ بِنْتَ أَبِي سَلَمَةَ ‏.‏ فَقَالَ ‏"‏ بِنْتُ أُمِّ سَلَمَةَ ‏"‏ ‏.‏ قَالَتْ أُمُّ حَبِيبَةَ نَعَمْ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَوَاللَّهِ لَوْ أَنَّهَا لَمْ تَكُنْ رَبِيبَتِي فِي حَجْرِي مَا حَلَّتْ إِنَّهَا لاَبْنَةُ أَخِي مِنَ الرَّضَاعَةِ أَرْضَعَتْنِي وَأَبَا سَلَمَةَ ثُوَيْبَةُ فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏ ‏.‏\hadithno{3285}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab bint Abi Salamah that Umm Habibah, the wife of the Prophet said:"O Messenger of Allah, marry the daughter of my father" - meaning her sister. The Messenger of Allah said: "Would you like that?" She said: "Yes; I do not have you all to myself, and I would like to share this goodness with my sister." The Prophet said: "That is not permissible for me." Umm Habibah said: "O Messenger of Allah, by Allah, we have been saying that you want to marry Durrah bint Abi Salamah." He said: "The daughter of Umm Salamah?" I said: "Yes." He said: "By Allah, even if she were not my stepdaughter who is in my care, she would not be permissible for me (to marry), because she is the daughter of my brother through breast-feeding. Thuwaibah breastfed Abu Salamah and I. So do not offer your daughters or sisters to me in marriage}}
\hadithdefcmd{nasai}{3286}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ أَنَّ أُمَّ حَبِيبَةَ قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّا قَدْ تَحَدَّثْنَا أَنَّكَ نَاكِحٌ دُرَّةَ بِنْتَ أَبِي سَلَمَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعَلَى أُمِّ سَلَمَةَ لَوْ أَنِّي لَمْ أَنْكِحْ أُمَّ سَلَمَةَ مَا حَلَّتْ لِي إِنَّ أَبَاهَا أَخِي مِنَ الرَّضَاعَةِ ‏"‏ ‏.‏\hadithno{3286}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Irak bin Malik that Zainab bint Abi Salamah told him, that Umm Habibah said to the Messenger of Allah:"We have been saying that you want to marry Durrah bint Abi Salamah." The Messenger of Allah said: "As a co-wife to Umm Salamah? Even if I were not married to Umm Salamah, she would not be permissible to me, for her father is my brother through breast-feeding}}
\hadithdefcmd{nasai}{3287}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ حَبِيبَةَ، أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ هَلْ لَكَ فِي أُخْتِي قَالَ ‏"‏ فَأَصْنَعُ مَاذَا ‏"‏ ‏.‏ قَالَتْ تَزَوَّجُهَا ‏.‏ قَالَ ‏"‏ فَإِنَّ ذَلِكَ أَحَبُّ إِلَيْكِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ لَسْتُ لَكَ بِمُخْلِيَةٍ وَأَحَبُّ مَنْ يَشْرَكُنِي فِي خَيْرٍ أُخْتِي ‏.‏ قَالَ ‏"‏ إِنَّهَا لاَ تَحِلُّ لِي ‏"‏ ‏.‏ قَالَتْ فَإِنَّهُ قَدْ بَلَغَنِي أَنَّكَ تَخْطُبُ دُرَّةَ بِنْتَ أُمِّ سَلَمَةَ ‏.‏ قَالَ ‏"‏ بِنْتُ أَبِي سَلَمَةَ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ وَاللَّهِ لَوْ لَمْ تَكُنْ رَبِيبَتِي مَا حَلَّتْ لِي إِنَّهَا لاَبْنَةُ أَخِي مِنَ الرَّضَاعَةِ فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏ ‏.‏\hadithno{3287}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Umm Habibah that she said:"O Messenger of Allah, what do you think of my sister?" He said: "What for?" She said: "For marriage." He said: "Would you like that?" She said: "Yes; I do not have you all to myself, and I would like to share this goodness with my sister." He said: "She is not permissible for me (to marry)." She said: "But I heard that you want to marry Durrah, the daughter of Umm Salamah." He said: "The daughter of Umm Salamah?" She said: "Yes." He said: "By Allah, even if she were not my stepdaughter she would not be permissible for me (to marry), because she is the daughter of my brother through breast-feeding. Do not offer your daughters and sisters to me in marriage}}
\hadithdefcmd{nasai}{3288}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُجْمَعُ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا وَلاَ بَيْنَ الْمَرْأَةِ وَخَالَتِهَا ‏"‏ ‏.‏\hadithno{3288}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: '(A man should not be married to) a woman and her paternal aunt nor to a woman and her maternal aunt at the same time}}
\hadithdefcmd{nasai}{3289}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَعْقُوبَ بْنِ عَبْدِ الْوَهَّابِ بْنِ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ بْنِ الْعَوَّامِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، عَنْ يُونُسَ، قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي قَبِيصَةُ بْنُ ذُؤَيْبٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُجْمَعَ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا وَالْمَرْأَةِ وَخَالَتِهَا ‏.‏\hadithno{3289}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Qabisah bin Dhu'aib said that he heard Abu Hurairah say:"The Messenger of Allah forbade (being married to) a woman and her paternal aunt or to a woman and her maternal aunt at the same time}}
\hadithdefcmd{nasai}{3290}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، أَنَّ جَعْفَرَ بْنَ رَبِيعَةَ، حَدَّثَهُ عَنْ عِرَاكِ بْنِ مَالِكٍ، وَعَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا أَوْ خَالَتِهَا ‏.‏\hadithno{3290}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah forbade being married to a woman and her paternal aunt or maternal aunt at the same time}}
\hadithdefcmd{nasai}{3291}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَرْبَعِ نِسْوَةٍ يُجْمَعُ بَيْنَهُنَّ الْمَرْأَةِ وَعَمَّتِهَا وَالْمَرْأَةِ وَخَالَتِهَا ‏.‏\hadithno{3291}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah forbade being married to four kinds of women at the same time:a woman and her paternal aunt or a woman and her maternal aunt}}
\hadithdefcmd{nasai}{3292}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ أَخْبَرَنِي أَيُّوبُ بْنُ مُوسَى، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ تُنْكَحُ الْمَرْأَةُ عَلَى عَمَّتِهَا وَلاَ عَلَى خَالَتِهَا ‏"‏ ‏.‏\hadithno{3292}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"A woman should not be taken as a co-wife to her paternal aunt or her maternal aunt}}
\hadithdefcmd{nasai}{3293}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا أَوْ عَلَى خَالَتِهَا ‏.‏\hadithno{3293}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah forbade taking a woman as a co-wife to her paternal aunt or her maternal aunt}}
\hadithdefcmd{nasai}{3294}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ تُنْكَحُ الْمَرْأَةُ عَلَى عَمَّتِهَا وَلاَ عَلَى خَالَتِهَا ‏"‏ ‏.‏\hadithno{3294}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"A woman should not be taken as a co-wife to her paternal aunt or her maternal aunt}}
\hadithdefcmd{nasai}{3295}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا مُحَمَّدٌ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُنْكَحُ الْمَرْأَةُ عَلَى عَمَّتِهَا وَلاَ عَلَى خَالَتِهَا ‏"‏ ‏.‏\hadithno{3295}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"A woman should not be taken as a co-wife to her paternal aunt or her maternal aunt}}
\hadithdefcmd{nasai}{3296}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمُعْتَمِرُ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا وَالْعَمَّةُ عَلَى بِنْتِ أَخِيهَا ‏.‏\hadithno{3296}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah forbade taking a woman as a co-wife to her paternal aunt or her maternal aunt}}
\hadithdefcmd{nasai}{3297}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَاصِمٌ، قَالَ قَرَأْتُ عَلَى الشَّعْبِيِّ كِتَابًا فِيهِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُنْكَحُ الْمَرْأَةُ عَلَى عَمَّتِهَا وَلاَ عَلَى خَالَتِهَا ‏"‏ ‏.‏ قَالَ سَمِعْتُ هَذَا مِنْ جَابِرٍ ‏.‏\hadithno{3297}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Asim said:"I read a book to Ash-Sha'bi in which it was narrated from Jabir that the Prophet said: 'A woman should not be taken as a co-wife to her paternal aunt or her maternal aunt.' He said: 'I heard that from Jabir}}
\hadithdefcmd{nasai}{3298}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا وَخَالَتِهَا ‏.‏\hadithno{3298}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Jabir bin 'Abdullah said:"The Messenger of Allah forbade taking a woman as a co-wife to her paternal aunt or maternal aunt}}
\hadithdefcmd{nasai}{3299}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا أَوْ عَلَى خَالَتِهَا ‏.‏\hadithno{3299}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah forbade taking a woman as a co-wife to her paternal aunt or maternal aunt}}
\hadithdefcmd{nasai}{3300}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ أَنْبَأَنَا مَالِكٌ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَرَّمَتْهُ الْوِلاَدَةُ حَرَّمَهُ الرَّضَاعُ ‏"‏ ‏.‏\hadithno{3300}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"What becomes unlawful (for marriage) through birth becomes unlawful through breast-feeding}}
\hadithdefcmd{nasai}{3301}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا أَخْبَرَتْهُ أَنَّ عَمَّهَا مِنَ الرَّضَاعَةِ يُسَمَّى أَفْلَحَ اسْتَأْذَنَ عَلَيْهَا فَحَجَبَتْهُ فَأُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَحْتَجِبِي مِنْهُ فَإِنَّهُ يَحْرُمُ مِنَ الرَّضَاعِ مَا يَحْرُمُ مِنَ النَّسَبِ ‏"‏ ‏.‏\hadithno{3301}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that her paternal uncle through breast-feeding, whose name was Aflah, asked permission to meet her, and she observed Hijab before him. The Messenger of Allah was told about that and he said:"Do not observe Hijab before him, for what becomes unlawful (for marriage) through breast-feeding is that which becomes unlawful through lineage}}
\hadithdefcmd{nasai}{3302}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَحْرُمُ مِنَ الرَّضَاعِ مَا يَحْرُمُ مِنَ النَّسَبِ ‏"‏ ‏.‏\hadithno{3302}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"What becomes unlawful (for marriage) through breast-feeding is that which becomes unlawful through lineage}}
\hadithdefcmd{nasai}{3303}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ هَاشِمٍ، ‏\{‏ عَنْ هِشَامِ بْنِ عُرْوَةَ، ‏\}‏ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ، قَالَتْ سَمِعْتُ عَائِشَةَ، تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَحْرُمُ مِنَ الرَّضَاعِ مَا يَحْرُمُ مِنَ الْوِلاَدَةِ ‏"‏ ‏.‏\hadithno{3303}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Amrah said:"I heard 'Aishah say: The Messenger of Allah said: 'What becomes unlawful (for marriage) through breast-feeding is that which becomes unlawful through birth}}
\hadithdefcmd{nasai}{3304}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا لَكَ تَنَوَّقُ فِي قُرَيْشٍ وَتَدَعُنَا قَالَ ‏"‏ وَعِنْدَكَ أَحَدٌ ‏"‏ ‏.‏ قُلْتُ نَعَمْ بِنْتُ حَمْزَةَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا لاَ تَحِلُّ لِي إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ ‏"‏ ‏.‏\hadithno{3304}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ali, may Allah be pleased with him, said:"I said: 'O Messenger of Allah, why do you choose wives from among Quraish and not from among us?' He said: 'Do you have anyone in mind?' I said: 'Yes, the daughter of Hamzah.' The Messenger of Allah said: 'She is not permissible for me (to marry); she is the daughter of my brother through breast-feeding}}
\hadithdefcmd{nasai}{3305}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ذُكِرَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم بِنْتُ حَمْزَةَ فَقَالَ ‏ "‏ إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ ‏"‏ ‏.‏ قَالَ شُعْبَةُ هَذَا سَمِعَهُ قَتَادَةُ مِنْ جَابِرِ بْنِ زَيْدٍ ‏.‏\hadithno{3305}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"Mention was made to the Messenger of Allah of the daughter of Hamzah (as a potential wife). He said: 'She is the daughter of my brother through breast-feeding.'" (One of the narrators) Shu'bah said: "Qatadah heard this from Jabir bin Zaid}}
\hadithdefcmd{nasai}{3306}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُرِيدَ عَلَى بِنْتِ حَمْزَةَ فَقَالَ ‏ "‏ إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ وَإِنَّهُ يَحْرُمُ مِنَ الرَّضَاعِ مَا يَحْرُمُ مِنَ النَّسَبِ ‏"‏ ‏.‏\hadithno{3306}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that the daughter of Hamzah was suggested to Messenger of Allah (as a potential wife). He said:"She is the daughter of my brother through breast-feeding, and what becomes unlawful (for marriage) through breast-feeding is the same as that which becomes unlawful through lineage}}
\hadithdefcmd{nasai}{3307}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ فِيمَا أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ - وَقَالَ الْحَارِثُ فِيمَا أُنْزِلَ مِنَ الْقُرْآنِ - عَشْرُ رَضَعَاتٍ مَعْلُومَاتٍ يُحَرِّمْنَ ثُمَّ نُسِخْنَ بِخَمْسٍ مَعْلُومَاتٍ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهِيَ مِمَّا يُقْرَأُ مِنَ الْقُرْآنِ ‏.‏\hadithno{3307}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"One of the things that Allah, the Mighty and Sublime, revealed" -(one of the narrators) Al-Harith said (in his narration): "One of the things that were revealed in the Qur'an"- "was that ten known breast-feedings make marriage prohibited, then that was abrogated and changed to five known breast-feedings. Then the Messenger of Allah passed away when this was something that was still being recited in the Qur'an}}
\hadithdefcmd{nasai}{3308}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، وَأَيُّوبَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، عَنْ أُمِّ الْفَضْلِ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الرَّضَاعِ فَقَالَ ‏"‏ لاَ تُحَرِّمُ الإِمْلاَجَةُ وَلاَ الإِمْلاَجَتَانِ ‏"‏ ‏.‏ وَقَالَ قَتَادَةُ ‏"‏ الْمَصَّةُ وَالْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{3308}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Umm Fadl that the Prophet of Allah was asked about breast-feeding and said:"Suckling (Al-Imlajah) once or twice does not make (marriage) prohibited." And (one of the narrators) Qatadah said (in his narration): "Suckling (Al-Massah) once or twice does not make (marriage) prohibited}}
\hadithdefcmd{nasai}{3309}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، عَنْ يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُحَرِّمُ الْمَصَّةُ وَالْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{3309}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin Az-Zubair that the Prophet said:"Suckling once or twice does not make (marriage) prohibited}}
\hadithdefcmd{nasai}{3310}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُحَرِّمُ الْمَصَّةُ وَالْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{3310}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'Suckling once or twice does not make (marriage) prohibited}}
\hadithdefcmd{nasai}{3311}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، قَالَ كَتَبْنَا إِلَى إِبْرَاهِيمَ بْنِ يَزِيدَ النَّخَعِيِّ نَسْأَلُهُ عَنِ الرَّضَاعِ، فَكَتَبَ أَنَّ شُرَيْحًا، حَدَّثَنَا أَنَّ عَلِيًّا وَابْنَ مَسْعُودٍ كَانَا يَقُولاَنِ يُحَرِّمُ مِنَ الرَّضَاعِ قَلِيلُهُ وَكَثِيرُهُ ‏.‏ وَكَانَ فِي كِتَابِهِ أَنَّ أَبَا الشَّعْثَاءِ الْمُحَارِبِيَّ حَدَّثَنَا أَنَّ عَائِشَةَ حَدَّثَتْهُ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ لاَ تُحَرِّمُ الْخَطْفَةُ وَالْخَطْفَتَانِ ‏"‏ ‏.‏\hadithno{3311}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Sa'eed narrated from Qatadah:"We wrote to Ibrahim bin Yazid An-Nakha'i asking him about breast-feeding. He wrote back saying that Shuraih had narrated that 'Ali and Ibn Mas'ud used to say: 'A little or a lot of breast-feeding makes marriage prohibited.'" In his book, it said that Abu Ash-Sha'tha' Al-Muharibi narrated that 'Aishah had told him that the Prophet of Allah used to say: "Suckling (Al-Khatfah) once or twice does not make (marriage) prohibited}}
\hadithdefcmd{nasai}{3312}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، فِي حَدِيثِهِ عَنْ أَبِي الأَحْوَصِ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، قَالَ قَالَتْ عَائِشَةُ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي رَجُلٌ قَاعِدٌ فَاشْتَدَّ ذَلِكَ عَلَيْهِ وَرَأَيْتُ الْغَضَبَ فِي وَجْهِهِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُ أَخِي مِنَ الرَّضَاعَةِ ‏.‏ فَقَالَ ‏ "‏ انْظُرْنَ مَا إِخْوَانُكُنَّ - وَمَرَّةً أُخْرَى - انْظُرْنَ مَنْ إِخْوَانُكُنَّ مِنَ الرَّضَاعَةِ فَإِنَّ الرَّضَاعَةَ مِنَ الْمَجَاعَةِ ‏"‏ ‏.‏\hadithno{3312}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Masruq said:"Aishah said: 'The Messenger of Allah entered upon me and there was a man sitting with me. He got upset about that, and I saw the anger in his face.' I said: "O Messenger of Allah, he is my brother through breast-feeding." He said: "Be careful who you count as your brothers" --or: "be careful who you count as your brothers through breast-feeding"-- "for the breast-feeding (which makes marriage prohibited) is from hunger}}
\hadithdefcmd{nasai}{3313}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عِنْدَهَا وَأَنَّهَا سَمِعَتْ رَجُلاً يَسْتَأْذِنُ فِي بَيْتِ حَفْصَةَ قَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا رَجُلٌ يَسْتَأْذِنُ فِي بَيْتِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أُرَاهُ فُلاَنًا ‏"‏ ‏.‏ لِعَمِّ حَفْصَةَ مِنَ الرَّضَاعَةِ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ لَوْ كَانَ فُلاَنٌ حَيًّا - لِعَمِّهَا مِنَ الرَّضَاعَةِ - دَخَلَ عَلَىَّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الرَّضَاعَةَ تُحَرِّمُ مَا يُحَرَّمُ مِنَ الْوِلاَدَةِ ‏"‏ ‏.‏\hadithno{3313}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Amrah that 'Aishah told her that the Messenger of Allah was with her, and she heard a man asking permission to enter Hafsah's house. 'Aishah said:"I said: 'O Messenger of Allah, there is a man asking permission to enter your house.' The Messenger of Allah said: 'I think it is so-and-so the paternal uncle of Hafsah through breast-feeding.' 'Aishah said: If so-and-so (her own paternal uncle through breast-feeding) were alive, would he be allowed to enter upon me?' The Messenger of Allah said: 'What becomes unlawful (for marriage) through breast-feeding is that which becomes unlawful through birth}}
\hadithdefcmd{nasai}{3314}{أَخْبَرَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، قَالَتْ جَاءَ عَمِّي أَبُو الْجَعْدِ مِنَ الرَّضَاعَةِ فَرَدَدْتُهُ - قَالَ وَقَالَ هِشَامٌ هُوَ أَبُو الْقُعَيْسِ - فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ائْذَنِي لَهُ ‏"‏ ‏.‏\hadithno{3314}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Urwah that 'Aishah told him:"My paternal uncle through breast-feeding, Abu Al-Ja'd, came to me, and I sent him away. -He (one of the narrators) said: "Hisham said: 'He was Abu Al-Qu'ais." - "Then the Messenger of Allah came, and I told him. The Messenger of Allah said: 'Give him permission (to enter)}}
\hadithdefcmd{nasai}{3315}{أَخْبَرَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنِي أَبِي، ‏\{‏ عَنْ أَبِيهِ، ‏\}‏ عَنْ أَيُّوبَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَخَا أَبِي الْقُعَيْسِ، اسْتَأْذَنَ عَلَى عَائِشَةَ بَعْدَ آيَةِ الْحِجَابِ فَأَبَتْ أَنْ تَأْذَنَ لَهُ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ ائْذَنِي لَهُ فَإِنَّهُ عَمُّكِ ‏"‏ ‏.‏ فَقُلْتُ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ ‏.‏ فَقَالَ ‏"‏ إِنَّهُ عَمُّكِ فَلْيَلِجْ عَلَيْكِ ‏"‏ ‏.‏\hadithno{3315}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that the brother of Abu Al-Qu'ais asked permission to enter upon 'Aishah after the Verse of Hijab had been revealed, and she refused to let him in. Mention of that was made to the Prophet and he said:"Let him in, for he is your paternal uncle." She said: "The woman breast-fed me, not the man." He said: "He is your paternal uncle, so let him visit you}}
\hadithdefcmd{nasai}{3316}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، أَنْبَأَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ أَفْلَحُ أَخُو أَبِي الْقُعَيْسِ يَسْتَأْذِنُ عَلَىَّ وَهُوَ عَمِّي مِنَ الرَّضَاعَةِ فَأَبَيْتُ أَنْ آذَنَ لَهُ حَتَّى جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏ "‏ ائْذَنِي لَهُ فَإِنَّهُ عَمُّكِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ وَذَلِكَ بَعْدَ أَنْ نَزَلَ الْحِجَابُ ‏.‏\hadithno{3316}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Aflah, the brother of Abu Al-Qu'ais, who was my paternal uncle through breast-feeding, used to ask permission to enter upon me, and I refused to let him in until the Messenger of Allah came, and I told him about that. He said: 'Let him in, for he is your paternal uncle.'" 'Aishah said: "That was after the (Verse of) Hijab had been revealed}}
\hadithdefcmd{nasai}{3317}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، وَهِشَامِ بْنِ ع��رْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اسْتَأْذَنَ عَلَىَّ عَمِّي أَفْلَحُ بَعْدَ مَا نَزَلَ الْحِجَابُ فَلَمْ آذَنْ لَهُ فَأَتَانِي النَّبِيُّ صلى الله عليه وسلم فَسَأَلْتُهُ فَقَالَ ‏"‏ ائْذَنِي لَهُ فَإِنَّهُ عَمُّكِ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ ‏.‏ قَالَ ‏"‏ ائْذَنِي لَهُ تَرِبَتْ يَمِينُكِ فَإِنَّهُ عَمُّكِ ‏"‏ ‏.‏\hadithno{3317}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"My paternal uncle Aflah asked permission to enter upon me after the (Verse of) Hijab had been revealed, but I did not let him in. The Prophet came to me and I asked him (about that) and he said: 'Let him in, for he is your paternal uncle.' I said: 'O Messenger of Allah, the woman breast-fed me, not the man.' He said: 'Let him in, may your hands be rubbed with dust, for he is your uncle}}
\hadithdefcmd{nasai}{3318}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ، قَالَ حَدَّثَنَا أَبُو الأَسْوَدِ، وَإِسْحَاقُ بْنُ بَكْرٍ، قَالاَ حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَ أَفْلَحُ أَخُو أَبِي الْقُعَيْسِ يَسْتَأْذِنُ فَقُلْتُ لاَ آذَنُ لَهُ حَتَّى أَسْتَأْذِنَ نَبِيَّ اللَّهِ صلى الله عليه وسلم فَلَمَّا جَاءَ نَبِيُّ اللَّهِ صلى الله عليه وسلم قُلْتُ لَهُ جَاءَ أَفْلَحُ أَخُو أَبِي الْقُعَيْسِ يَسْتَأْذِنُ فَأَبَيْتُ أَنْ آذَنَ لَهُ ‏.‏ فَقَالَ ‏"‏ ائْذَنِي لَهُ فَإِنَّهُ عَمُّكِ ‏"‏ ‏.‏ قُلْتُ إِنَّمَا أَرْضَعَتْنِي امْرَأَةُ أَبِي الْقُعَيْسِ وَلَمْ يُرْضِعْنِي الرَّجُلُ ‏.‏ قَالَ ‏"‏ ائْذَنِي لَهُ فَإِنَّهُ عَمُّكِ ‏"‏ ‏.‏\hadithno{3318}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"Aflah, the brother of Abu Al-Qu'ais, came and asked permission to enter, and I said: 'I will not let him in until I seek the permission of the Prophet of Allah.' When the Prophet of Allah came, I said to him: 'Aflah, the brother of Abu Al-Qu'ais, came and asked permission to enter, but I refused to let him in.' He said: 'Let him in, for he is your paternal uncle.' I said: 'The wife of Abu Al-Qu'ais breast-fed me; the man did not breast-feed me.' He said: 'Let him in, for he is your paternal uncle}}
\hadithdefcmd{nasai}{3319}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ حُمَيْدَ بْنَ نَافِعٍ، يَقُولُ سَمِعْتُ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، تَقُولُ سَمِعْتُ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ جَاءَتْ سَهْلَةُ بِنْتُ سُهَيْلٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي لأَرَى فِي وَجْهِ أَبِي حُذَيْفَةَ مِنْ دُخُولِ سَالِمٍ عَلَىَّ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْضِعِيهِ ‏"‏ ‏.‏ قُلْتُ إِنَّهُ لَذُو لِحْيَةٍ ‏.‏ فَقَالَ ‏"‏ أَرْضِعِيهِ يَذْهَبْ مَا فِي وَجْهِ أَبِي حُذَيْفَةَ ‏"‏ ‏.‏ قَالَتْ وَاللَّهِ مَا عَرَفْتُهُ فِي وَجْهِ أَبِي حُذَيْفَةَ بَعْدُ ‏.‏\hadithno{3319}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Zainab bint Abi Salamah said:"I heard 'Aisha, the wife of the Prophet say: 'Sahlah bint Suhail came to the Messenger of Allah and said: 'O Messenger of Allah, I see (displeasure) in the face of Abu Hudhaifah when Salim enters upon me.' The Messenger of Allah said: 'Breast-feed him.' She said: 'He has a beard.' He said: 'Breast-feed him, and that will take away (the displeasure) in the face of Abu Hudhaifah.' She said: 'By Allah, I never saw that on the face of Abu Hudhaifah after that}}
\hadithdefcmd{nasai}{3320}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْنَاهُ مِنْ عَبْدِ الرَّحْمَنِ، - وَهُوَ ابْنُ الْقَاسِمِ - عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ سَهْلَةُ بِنْتُ سُهَيْلٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي أَرَى فِي وَجْهِ أَبِي حُذَيْفَةَ مِنْ دُخُولِ سَالِمٍ عَلَىَّ ‏.‏ قَالَ ‏"‏ فَأَرْضِعِيهِ ‏"‏ ‏.‏ قَالَتْ وَكَيْفَ أُرْضِعُهُ وَهُوَ رَجُلٌ كَبِيرٌ فَقَالَ ‏"‏ أَلَسْتُ أَعْلَمُ أَنَّهُ رَجُلٌ كَبِيرٌ ‏"‏ ‏.‏ ثُمَّ جَاءَتْ بَعْدُ فَقَالَتْ وَالَّذِي بَعَثَكَ بِالْحَقِّ نَبِيًّا مَا رَأَيْتُ فِي وَجْهِ أَبِي حُذَيْفَةَ بَعْدُ شَيْئًا أَكْرَهُ ‏.‏\hadithno{3320}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"Sahlah bint Suhail came to the Messenger of Allah and said: 'I see (displeasure) in the face of Abu Hudhaifah when Salim enters upon me.' The Messenger of Allah said: 'Breast-feed him.' She said: 'How can I breast-feed him when he is a grown man?' He said: 'Don't I know that he is a grown man?' Then she came after that and said: 'By the One Who sent you with the truth as a Prophet, I have never seen anything I dislike on the face of Abu Hudhaifah after that}}
\hadithdefcmd{nasai}{3321}{أَخْبَرَنَا أَحْمَدُ بْنُ يَحْيَى بْنِ الْوَزِيرِ، قَالَ سَمِعْتُ ابْنَ وَهْبٍ، قَالَ أَخْبَرَنِي سُلَيْمَانُ، عَنْ يَحْيَى، وَرَبِيعَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ النَّبِيُّ صلى الله عليه وسلم امْرَأَةَ أَبِي حُذَيْفَةَ أَنْ تُرْضِعَ سَالِمًا مَوْلَى أَبِي حُذَيْفَةَ حَتَّى تَذْهَبَ غَيْرَةُ أَبِي حُذَيْفَةَ فَأَرْضَعَتْهُ وَهُوَ رَجُلٌ ‏.‏ قَالَ رَبِيعَةُ فَكَانَتْ رُخْصَةً لِسَالِمٍ ‏.‏\hadithno{3321}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah commanded the wife of Abu Hudhaifah to breast-feed Salim, the freed slave of Abu Hudhaifah, so that the protective jealousy of Abu Hudhaifah would be dispelled. She breast-fed him when he was a man." (One of the narrators) Rabi'ah said: "That was a concession granted to Salim}}
\hadithdefcmd{nasai}{3322}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ، - وَهُوَ ابْنُ حَبِيبٍ - عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ سَهْلَةُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ سَالِمًا يَدْخُلُ عَلَيْنَا وَقَدْ عَقَلَ مَا يَعْقِلُ الرِّجَالُ وَعَلِمَ مَا يَعْلَمُ الرِّجَالُ ‏.‏ قَالَ ‏ "‏ أَرْضِعِيهِ تَحْرُمِي عَلَيْهِ بِذَلِكَ ‏"‏ ‏.‏ فَمَكَثْتُ حَوْلاً لاَ أُحَدِّثُ بِهِ وَلَقِيتُ الْقَاسِمَ فَقَالَ حَدِّثْ بِهِ وَلاَ تَهَابُهُ ‏.‏\hadithno{3322}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"Sahlah came to the Messenger of Allah and said: 'O Messenger of Allah, Salim enters upon us and he understands what men understand, and knows what men know.' He said: 'Breast-feed him, and you will become unlawful to him thereby.' (Ibn Abi Mulaikah, one of the narrators said:) For a year I did not narrate this, then I met Al-Qasim and he said: 'Narrate it and do not worry about it}}
\hadithdefcmd{nasai}{3323}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ عَبْدِ الْوَهَّابِ، قَالَ أَنْبَأَنَا أَيُّوبُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّ سَالِمًا، مَوْلَى أَبِي حُذَيْفَةَ كَانَ مَعَ أَبِي حُذَيْفَةَ وَأَهْلِهِ فِي بَيْتِهِمْ فَأَتَتْ بِنْتُ سُهَيْلٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنَّ سَالِمًا قَدْ بَلَغَ مَا يَبْلُغُ الرِّجَالُ وَعَقَلَ مَا عَقَلُوهُ وَإِنَّهُ يَدْخُلُ عَلَيْنَا وَإِنِّي أَظُنُّ فِي نَفْسِ أَبِي حُذَيْفَةَ مِنْ ذَلِكَ شَيْئًا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَرْضِعِيهِ تَحْرُمِي عَلَيْهِ ‏"‏ ‏.‏ فَأَرْضَعْتُهُ فَذَهَبَ الَّذِي فِي نَفْسِ أَبِي حُذَيْفَةَ فَرَجَعْتُ إِلَيْهِ فَقُلْتُ إِنِّي قَدْ أَرْضَعْتُهُ فَذَهَبَ الَّذِي فِي نَفْسِ أَبِي حُذَيْفَةَ ‏.‏\hadithno{3323}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that Salim, the freed slave of Abu Hudhaifah, was with Abu Hudhaifah and his family in their house. The daughter of Suhail came to the Prophet and said:"Salim has reached the age of manhood, and understands what men understand. He enters upon us, and I think that Abu Hudhaifah is not happy about that." The Prophet said: "Breast-feed him, and you will become unlawful to him." So she breast-fed him, and the displeasure of Abu Hudhaifah disappeared. She came back to him and said: "I breast-fed him and the displeasure of Abu Hudhaifah has disappeared}}
\hadithdefcmd{nasai}{3324}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، وَمَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، قَالَ أَبَى سَائِرُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم أَنْ يَدْخُلَ عَلَيْهِنَّ بِتِلْكَ الرَّضْعَةِ أَحَدٌ مِنَ النَّاسِ - يُرِيدُ رَضَاعَةَ الْكَبِيرِ - وَقُلْنَ لِعَائِشَةَ وَاللَّهِ مَا نُرَى الَّذِي أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَهْلَةَ بِنْتَ سُهَيْلٍ إِلاَّ رُخْصَةً فِي رَضَاعَةِ سَالِمٍ وَحْدَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاللَّهِ لاَ يَدْخُلُ عَلَيْنَا أَحَدٌ بِهَذِهِ الرَّضْعَةِ وَلاَ يَرَانَا ‏.‏\hadithno{3324}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Urwah said:"The rest of the wives of the Prophet refused for anyone to enter upon them on the basis of that type of breast-feeding, meaning breast-feeding of an adult. They said to 'Aishah: 'By Allah, we think that what the Messenger of Allah told Sahlah bint Suhail to do was a concession which was granted by the Messenger of Allah only with regard to breast-feeding Salim. By Allah, no one will enter upon us, nor see us on the basis of this type of breast-feeding}}
\hadithdefcmd{nasai}{3325}{أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، قَالَ أَخْبَرَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو عُبَيْدَةَ بْنُ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، أَنَّ أُمَّهُ، زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ أَخْبَرَتْهُ أَنَّ أُمَّهَا أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تَقُولُ أَبَى سَائِرُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم أَنْ يُدْخَلَ عَلَيْهِنَّ بِتِلْكَ الرَّضَاعَةِ وَقُلْنَ لِعَائِشَةَ وَاللَّهِ مَا نُرَى هَذِهِ إِلاَّ رُخْصَةً رَخَّصَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم خَاصَّةً لِسَالِمٍ فَلاَ يَدْخُلْ عَلَيْنَا أَحَدٌ بِهَذِهِ الرَّضَاعَةِ وَلاَ يَرَانَا ‏.‏\hadithno{3325}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Zainab bint Abu Salamah narrated that her mother Umm Salamah, the wife of the Prophet, used to say:"The rest of the wives of the Prophet refused for anyone to enter upon them on the basis of that type of breast-feeding, meaning breast-feeding of an adult. They said to 'Aishah: 'By Allah, we think that this is a concession which the Messenger of Allah granted only to Salim. No one will enter upon us, nor see us on the basis of this type of breast-feeding}}
\hadithdefcmd{nasai}{3326}{أَخْبَرَنَا عُبَيْدُ اللَّهِ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ جُدَامَةَ بِنْتَ وَهْبٍ، حَدَّثَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَقَدْ هَمَمْتُ أَنْ أَنْهَى عَنِ الْغِيلَةِ حَتَّى ذَكَرْتُ أَنَّ فَارِسَ وَالرُّومَ يَصْنَعُهُ ‏"‏ ‏.‏ وَقَالَ إِسْحَاقُ ‏"‏ يَصْنَعُونَهُ فَلاَ يَضُرُّ أَوْلاَدَهُمْ ‏"‏ ‏.‏\hadithno{3326}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that Judamah bint Wahb told her that the Messenger of Allah said:"I was thinking of forbidding Ghilah until I remembered that it is done by the Persians and Romans" -(one of the narrators) Ishaq said: "(They) do that -and it does not harm their children}}
\hadithdefcmd{nasai}{3327}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بِشْرِ بْنِ مَسْعُودٍ، وَرَدَّ الْحَدِيثَ حَتَّى رَدَّهُ إِلَى أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَ ذُكِرَ ذَلِكَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَمَا ذَاكُمْ ‏"‏ ‏.‏ قُلْنَا الرَّجُلُ تَكُونُ لَهُ الْمَرْأَةُ فَيُصِيبُهَا وَيَكْرَهُ الْحَمْلَ وَتَكُونُ لَهُ الأَمَةُ فَيُصِيبُ مِنْهَا وَيَكْرَهُ أَنْ تَحْمِلَ مِنْهُ ‏.‏ قَالَ ‏"‏ لاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا فَإِنَّمَا هُوَ الْقَدَرُ ‏"‏ ‏.‏\hadithno{3327}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdur-Rahman bin Bishr bin Mas'ud, who attributed the Hadith to Abu Sa'eed Al-Khudri, that mention of that (coitus interruptus) was made to the Messenger of Allah and he said:"Why do you do that?" We said: "A man may have a wife, and he has intercourse with her, but he does not want her to get pregnant, or he may have a concubine, and he has intercourse with her, but he does not want her to get pregnant." He said: "It does not make any difference if you do that, for it is the matter of Al-Qadr}}
\hadithdefcmd{nasai}{3328}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي الْفَيْضِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُرَّةَ الزُّرَقِيَّ، عَنْ أَبِي سَعِيدٍ الزُّرَقِيِّ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْعَزْلِ فَقَالَ إِنَّ امْرَأَتِي تُرْضِعُ وَأَنَا أَكْرَهُ أَنْ تَحْمِلَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ مَا قَدْ قُدِّرَ فِي الرَّحِمِ سَيَكُونُ ‏"‏ ‏.‏\hadithno{3328}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed Az-Zuraqi that a man asked the Messenger of Allah about coitus interruptus and said:"My wife is breast-feeding and I do not want her to get pregnant." The Prophet said: "What has been decreed in the womb will come to be}}
\hadithdefcmd{nasai}{3329}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ وَحَدَّثَنِي أَبِي، عَنْ حَجَّاجِ بْنِ حَجَّاجٍ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا يُذْهِبُ عَنِّي مَذَمَّةَ الرَّضَاعِ قَالَ ‏ "‏ غُرَّةُ عَبْدٍ أَوْ أَمَةٍ ‏"‏ ‏.‏\hadithno{3329}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Hajjaj bin Hajjaj that his father said:"I said: 'O Messenger of Allah, how can I pay back the dues of the one who breast-fed me?' He said: 'By giving a male or female slave}}
\hadithdefcmd{nasai}{3330}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ حَدَّثَنِي عُبَيْدُ بْنُ أَبِي مَرْيَمَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ وَقَدْ سَمِعْتُهُ مِنْ، عُقْبَةَ وَلَكِنِّي لِحَدِيثِ عُبَيْدٍ أَحْفَظُ قَالَ تَزَوَّجْتُ امْرَأَةً فَجَاءَتْنَا امْرَأَةٌ سَوْدَاءُ فَقَالَتْ إِنِّي قَدْ أَرْضَعْتُكُمَا ‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقُلْتُ إِنِّي تَزَوَّجْتُ فُلاَنَةَ بِنْتَ فُلاَنٍ فَجَاءَتْنِي امْرَأَةٌ سَوْدَاءُ فَقَالَتْ إِنِّي قَدْ أَرْضَعْتُكُمَا ‏.‏ فَأَعْرَضَ عَنِّي فَأَتَيْتُهُ مِنْ قِبَلِ وَجْهِهِ فَقُلْتُ إِنَّهَا كَاذِبَةٌ ‏.‏ قَالَ ‏ "‏ وَكَيْفَ بِهَا وَقَدْ زَعَمَتْ أَنَّهَا قَدْ أَرْضَعَتْكُمَا دَعْهَا عَنْكَ ‏"‏ ‏.‏\hadithno{3330}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Uqbah bin Al-Harith said:I married a woman, then a black woman came to us and said: I breast-fed you both. I went to the Prophet and said: I married so and so and a black woman came to me and said: I breast-fed you both. He turned away from me so I came to him from the other side and said: She is lying. He said: "How can you be intimate with your wife when she says that she breast-fed you both? Leave her (divorce her)}}
\hadithdefcmd{nasai}{3331}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ صَالِحٍ، عَنِ السُّدِّيِّ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ، قَالَ لَقِيتُ خَالِي وَمَعَهُ الرَّايَةُ فَقُلْتُ أَيْنَ تُرِيدُ قَالَ أَرْسَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى رَجُلٍ تَزَوَّجَ امْرَأَةَ أَبِيهِ مِنْ بَعْدِهِ أَنْ أَضْرِبَ عُنُقَهُ أَوْ أَقْتُلَهُ ‏.‏\hadithno{3331}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Bara' said:"I met my maternal uncle who was carrying a flag (for an expedition) and I said: 'Where are you going?' He said: 'The Messenger of Allah is sending me to a man who has married his father's wife after he died, to strike his neck or kill him}}
\hadithdefcmd{nasai}{3332}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ يَزِيدَ بْنِ الْبَرَاءِ، عَنْ أَبِيهِ، قَالَ أَصَبْتُ عَمِّي وَمَعَهُ رَايَةٌ فَقُلْتُ أَيْنَ تُرِيدُ فَقَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى رَجُلٍ نَكَحَ امْرَأَةَ أَبِيهِ فَأَمَرَنِي أَنْ أَضْرِبَ عُنُقَهُ وَآخُذَ مَالَهُ ‏.‏\hadithno{3332}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Yazid bin Al-Bara' that his father said:"I met my maternal uncle who was carrying a flag (for an expedition) and I said: 'Where are you going?' He said: 'The Messenger of Allah is sending me to a man who has married his father's wife, and he has commanded me to strike his neck (kill him) and seize his wealth}}
\hadithdefcmd{nasai}{3333}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ أَبِي عَلْقَمَةَ الْهَاشِمِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم بَعَثَ جَيْشًا إِلَى أَوْطَاسٍ فَلَقُوا عَدُوًّا فَقَاتَلُوهُمْ وَظَهَرُوا عَلَيْهِمْ فَأَصَابُوا لَهُمْ سَبَايَا لَهُنَّ أَزْوَاجٌ فِي الْمُشْرِكِينَ فَكَانَ الْمُسْلِمُونَ تَحَرَّجُوا مِنْ غِشْيَانِهِنَّ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَالْمُحْصَنَاتُ مِنَ النِّسَاءِ إِلاَّ مَا مَلَكَتْ أَيْمَانُكُمْ ‏\}‏ أَىْ هَذَا لَكُمْ حَلاَلٌ إِذَا انْقَضَتْ عِدَّتُهُنَّ ‏.‏\hadithno{3333}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Prophet of Allah sent an army to Awtas. They met the enemy, fought them, and prevailed over them. They acquired female prisoners who had husbands among the idolaters. The Muslims felt reluctant to be intimate with them. Then Allah, the Mighty and Sublime revealed:"Also (forbidden are) women already married, except those (slaves) whom your right hands possess," meaning, this is permissible for you once they have completed their 'Iddah}}
\hadithdefcmd{nasai}{3334}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ ‏.‏\hadithno{3334}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah forbade Ash-Shighar}}
\hadithdefcmd{nasai}{3335}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا بِشْرٌ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ جَلَبَ وَلاَ جَنَبَ وَلاَ شِغَارَ فِي الإِسْلاَمِ وَمَنِ انْتَهَبَ نُهْبَةً فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{3335}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Imran bin Husain that the Messenger of Allah said:"There is no 'bringing', no 'avoidance' and no Shighar in Islam, and whoever robs, he is not one of us}}
\hadithdefcmd{nasai}{3336}{أَخْبَرَنَا عَلِيُّ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنِ الْفَزَارِيِّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ جَلَبَ وَلاَ جَنَبَ وَلاَ شِغَارَ فِي الإِسْلاَمِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ فَاحِشٌ وَالصَّوَابُ حَدِيثُ بِشْرٍ ‏.‏\hadithno{3336}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah said: 'There is no 'bringing', no 'avoidance' and no Shighar in Islam, and whoever robs, he is not one of us}}
\hadithdefcmd{nasai}{3337}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، ح وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ مَالِكٌ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ وَالشِّغَارُ أَنْ يُزَوِّجَ الرَّجُلُ الرَّجُلَ ابْنَتَهُ عَلَى أَنْ يُزَوِّجَهُ ابْنَتَهُ وَلَيْسَ بَيْنَهُمَا صَدَاقٌ ‏.‏\hadithno{3337}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah forbade Ash-Shighar. Ash-Shighar means when a man marries his daughter to another man, on the condition that that man marries his daughter to him, and no dowry is exchanged between them}}
\hadithdefcmd{nasai}{3338}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالاَ حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الشِّغَارِ ‏.‏ قَالَ عُبَيْدُ اللَّهِ وَالشِّغَارُ كَانَ الرَّجُلُ يُزَوِّجُ ابْنَتَهُ عَلَى أَنْ يُزَوِّجَهُ أُخْتَهُ ‏.‏\hadithno{3338}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah forbade Ash-Shighar." (One of the narrators) 'Ubaidullah said: "Ash-Shighar means when a man gives his daughter in marriage on condition that (the other man) gives him his sister in marriage}}
\hadithdefcmd{nasai}{3339}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَعْقُوبُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ امْرَأَةً، جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ جِئْتُ لأَهَبَ نَفْسِي لَكَ ‏.‏ فَنَظَرَ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَعَّدَ النَّظَرَ إِلَيْهَا وَصَوَّبَهُ ثُمَّ طَأْطَأَ رَأْسَهُ فَلَمَّا رَأَتِ الْمَرْأَةُ أَنَّهُ لَمْ يَقْضِ فِيهَا شَيْئًا جَلَسَتْ فَقَامَ رَجُلٌ مِنْ أَصْحَابِهِ فَقَالَ أَىْ رَسُولَ اللَّهِ إِنْ لَمْ يَكُنْ لَكَ بِهَا حَاجَةٌ فَزَوِّجْنِيهَا ‏.‏ قَالَ ‏"‏ هَلْ عِنْدَكَ مِنْ شَىْءٍ ‏"‏ ‏.‏ فَقَالَ لاَ وَاللَّهِ مَا وَجَدْتُ شَيْئًا ‏.‏ فَقَالَ ‏"‏ انْظُرْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ وَلاَ خَاتَمًا مِنْ حَدِيدٍ وَلَكِنْ هَذَا إِزَارِي - قَالَ سَهْلٌ مَا لَهُ رِدَاءٌ - فَلَهَا نِصْفُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَصْنَعُ بِإِزَارِكَ إِنْ لَبِسْتَهُ لَمْ يَكُنْ عَلَيْهَا مِنْهُ شَىْءٌ وَإِنْ لَبِسَتْهُ لَمْ يَكُنْ عَلَيْكَ مِنْهُ شَىْءٌ ‏"‏ ‏.‏ فَجَلَسَ الرَّجُلُ حَتَّى طَالَ مَجْلِسُهُ ثُمَّ قَامَ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مُوَلِّيًا فَأَمَرَ بِهِ فَدُعِيَ فَلَمَّا جَاءَ قَالَ ‏"‏ مَاذَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ مَعِي سُورَةُ كَذَا وَسُورَةُ كَذَا ‏.‏ عَدَّدَهَا ‏.‏ فَقَالَ ‏"‏ هَلْ تَقْرَؤُهُنَّ عَنْ ظَهْرِ قَلْبٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ مَلَّكْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{3339}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sahl bin Sa'd that a woman came to the Messenger of Allah and said:"O Messenger of Allah, I have come to offer myself to you (in marriage)." The Messenger of Allah looked her up and down then lowered his head. When the woman saw that he was not saying anything about her, she sat down. A man among his Companions stood up and said: "O Messenger of Allah, if you do not want to marry her, then marry me to her." He said: "Do you have anything?" He said: "No, by Allah, I do not have anything." He said: "Look, even if it is only an iron ring." He went, then he came back and said: "No, by Allah, O Messenger of Allah, not even an iron ring, but this is my Izar (lower garment)" - Sahl said: "He did not have a Rida' (upper garment)" - "she can have half of it." The Messenger of Allah said: "What could she do with your Izar? If you wear it, she will not have any of it, and if she wears it, you will not have any of it." The man sat down for a long time, then he got up, and the Messenger of Allah saw him leaving, so he ordered that he be called back. When he came, he said: "What do you know of the Qur'an?" He said: "I know Surah such-and-such, and Surah such-and-such," and listed them. He said: "Can you recite them by heart?" He said: "Yes." He said: "Then I marry you to her on the basis of what you know of the Qur'an}}
\hadithdefcmd{nasai}{3340}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسٍ، قَالَ تَزَوَّجَ أَبُو طَلْحَةَ أُمَّ سُلَيْمٍ فَكَانَ صَدَاقُ مَا بَيْنَهُمَا الإِسْلاَمَ أَسْلَمَتْ أُمُّ سُلَيْمٍ قَبْلَ أَبِي طَلْحَةَ فَخَطَبَهَا فَقَالَتْ إِنِّي قَدْ أَسْلَمْتُ فَإِنْ أَسْلَمْتَ نَكَحْتُكَ ‏.‏ فَأَسْلَمَ فَكَانَ صَدَاقَ مَا بَيْنَهُمَا ‏.‏\hadithno{3340}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"Abu Talhah married Umm Sulaim and the dowry between them was Islam. Umm Sulaim became Muslim before Abu Talhah, and he proposed to her but she said: 'I have become Muslim; if you become Muslim I will marry you.' So he became Muslim, and that was the dowry between them}}
\hadithdefcmd{nasai}{3341}{أَخْبَرَنَا مُحَمَّدُ بْنُ النَّضْرِ بْنِ مُسَاوِرٍ، قَالَ أَنْبَأَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ خَطَبَ أَبُو طَلْحَةَ أُمَّ سُلَيْمٍ فَقَالَتْ وَاللَّهِ مَا مِثْلُكَ يَا أَبَا طَلْحَةَ يُرَدُّ وَلَكِنَّكَ رَجُلٌ كَافِرٌ وَأَنَا امْرَأَةٌ مُسْلِمَةٌ وَلاَ يَحِلُّ لِي أَنْ أَتَزَوَّجَكَ فَإِنْ تُسْلِمْ فَذَاكَ مَهْرِي وَمَا أَسْأَلُكَ غَيْرَهُ ‏.‏ فَأَسْلَمَ فَكَانَ ذَلِكَ مَهْرَهَا - قَالَ ثَابِتٌ فَمَا سَمِعْتُ بِامْرَأَةٍ قَطُّ كَانَتْ أَكْرَمَ مَهْرًا مِنْ أُمِّ سُلَيْمٍ الإِسْلاَمَ - فَدَخَلَ بِهَا فَوَلَدَتْ لَهُ ‏.‏\hadithno{3341}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"Abu Talhah proposed marriage to Umm Sulaim and she said: 'By Allah, a man like you is not to be rejected, O Abu Talhah, but you are a disbeliever and I am a Muslim, and it is not permissible for me to marry you. If you become Muslim, that will be my dowry, and I will not ask you for anything else.' So he became Muslim and that was her dowry." (one of the narrators) Thabit said: "I have never heard of a woman whose dowry was more precious than Umm Sulaim (whose dowry was) Islam. And he consummated the marriage with her, and she bore him a child}}
\hadithdefcmd{nasai}{3342}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، وَعَبْدَ الْعَزِيزِ، - يَعْنِي ابْنَ صُهَيْبٍ - عَنْ أَنَسِ بْنِ مَالِكٍ، ح وَأَنْبَأَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، وَشُعَيْبٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْتَقَ صَفِيَّةَ وَجَعَلَهُ صَدَاقَهَا ‏.‏\hadithno{3342}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that the Messenger of Allah manumitted Safiyyah and made that her dowry}}
\hadithdefcmd{nasai}{3343}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا سُفْيَانُ، ح وَأَنْبَأَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يُونُسَ، عَنِ ابْنِ الْحَبْحَابِ، عَنْ أَنَسٍ، أَعْتَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَفِيَّةَ وَجَعَلَ عِتْقَهَا مَهْرَهَا ‏.‏ وَاللَّفْظُ لِمُحَمَّدٍ ‏.‏\hadithno{3343}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Messenger of Allah manumitted Safiyyah and made her freedom her dowry}}
\hadithdefcmd{nasai}{3344}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، قَالَ حَدَّثَنِي صَالِحُ بْنُ صَالِحٍ، عَنْ عَامِرٍ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ يُؤْتَوْنَ أَجْرَهُمْ مَرَّتَيْنِ رَجُلٌ كَانَتْ لَهُ أَمَةٌ فَأَدَّبَهَا فَأَحْسَنَ أَدَبَهَا وَعَلَّمَهَا فَأَحْسَنَ تَعْلِيمَهَا ثُمَّ أَعْتَقَهَا وَتَزَوَّجَهَا وَعَبْدٌ يُؤَدِّي حَقَّ اللَّهِ وَحَقَّ مَوَالِيهِ وَمُؤْمِنُ أَهْلِ الْكِتَابِ ‏"‏ ‏.‏\hadithno{3344}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah said: 'There are three who will be given a twofold reward: A man who has a slave woman whom he disciplines and disciplines her well, and teaches and teaches her well, then he manumits her and marries her; a slave who fulfills his duty toward Allah and toward his masters; and a believer from among the People of the Book}}
\hadithdefcmd{nasai}{3345}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي زُبَيْدٍ، عَبْثَرِ بْنِ الْقَاسِمِ عَنْ مُطَرِّفٍ، عَنْ عَامِرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ جَارِيَتَهُ ثُمَّ تَزَوَّجَهَا فَلَهُ أَجْرَانِ ‏"‏ ‏.‏\hadithno{3345}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah said: 'Whoever manumits his female slave, then marries her, he will have two rewards}}
\hadithdefcmd{nasai}{3346}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، وَسُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ قَوْلِ اللَّهِ، عَزَّ وَجَلَّ ‏\{‏ وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ ‏\}‏ قَالَتْ يَا ابْنَ أُخْتِي هِيَ الْيَتِيمَةُ تَكُونُ فِي حِجْرِ وَلِيِّهَا فَتُشَارِكُهُ فِي مَالِهِ فَيُعْجِبُهُ مَالُهَا وَجَمَالُهَا فَيُرِيدُ وَلِيُّهَا أَنْ يَتَزَوَّجَهَا بِغَيْرِ أَنْ يُقْسِطَ فِي صَدَاقِهَا فَيُعْطِيَهَا مِثْلَ مَا يُعْطِيهَا غَيْرُهُ فَنُهُوا أَنْ يَنْكِحُوهُنَّ إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ وَيَبْلُغُوا بِهِنَّ أَعْلَى سُنَّتِهِنَّ مِنَ الصَّدَاقِ فَأُمِرُوا أَنْ يَنْكِحُوا مَا طَابَ لَهُمْ مِنَ النِّسَاءِ سِوَاهُنَّ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ ثُمَّ إِنَّ النَّاسَ اسْتَفْتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدُ فِيهِنَّ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَيَسْتَفْتُونَكَ فِي النِّسَاءِ قُلِ اللَّهُ يُفْتِيكُمْ فِيهِنَّ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ ‏\}‏ قَالَتْ عَائِشَةُ وَالَّذِي ذَكَرَ اللَّهُ تَعَالَى أَنَّهُ يُتْلَى فِي الْكِتَابِ الآيَةُ الأُولَى الَّتِي فِيهَا ‏\{‏ وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ ‏\}‏ قَالَتْ عَائِشَةُ وَقَوْلُ اللَّهِ فِي الآيَةِ الأُخْرَى ‏\{‏ وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ ‏\}‏ رَغْبَةَ أَحَدِكُمْ عَنْ يَتِيمَتِهِ الَّتِي تَكُونُ فِي حَجْرِهِ حِينَ تَكُونُ قَلِيلَةَ الْمَالِ وَالْجَمَالِ فَنُهُوا أَنْ يَنْكِحُوا مَا رَغِبُوا فى مَالِهَا مِنْ يَتَامَى النِّسَاءِ إِلاَّ بِالْقِسْطِ مِنْ أَجْلِ رَغْبَتِهِمْ عَنْهُنَّ ‏.‏\hadithno{3346}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Urwah bin Az-Zubair narrated that he asked 'Aishah about the saying of Allah, the Mighty and Sublime:"And if you fear that you shall not be able to deal justly with the orphan girls then marry (other) women of your choice." She said: "O son of my sister, this refers to a female orphan who is in the care of her guardian, and her wealth is joined to his, and he is attracted to her wealth and her beauty. So her guardian wants to marry her without being fair with regard to her dowry, and without giving her what someone else would give her. So they were forbidden to marry them unless they were fair to them and gave them the highest possible dowry that is customarily given, and they were commanded to marry other women of their choice." 'Urwah said: "'Aishah said: 'Then later on, Allah, the Mighty and Sublime, revealed concerning them: 'They ask your legal instruction concerning women, say: Allah instructs you about them, and about what is recited unto you in the Book concerning the orphan girls whom you give not the prescribed portions and yet whom you desire to marry.' 'Aishah said: 'What Allah, Most High, mentioned here that is recited in the Book is the first Verse in which it says: And if you fear that you shall not be able to deal justly with orphan girls then marry (other) women of your choice.' 'Aishah said: 'What is referred to in the other Verse -and yet whom you desire to marry- is the desire of one of you not to marry orphan girl who is under his care if she is lacking in wealth and beauty. So they were forbidden to marry those orphan women to whose wealth they were attracted unless they were fair, because of their desire not to marry (those who were lacking in wealth and beauty)}}
\hadithdefcmd{nasai}{3347}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ ذَلِكَ، فَقَالَتْ فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى اثْنَتَىْ عَشْرَةَ أُوقِيَّةً وَنَشٍّ وَذَلِكَ خَمْسُمِائَةِ دِرْهَمٍ ‏.‏\hadithno{3347}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Salamah said:"I asked 'Aishah about that and she said: 'The Messenger of Allah got married (and married his daughters) for twelve Uqiyah and a Nashsh'" which is five hundred Dirhams}}
\hadithdefcmd{nasai}{3348}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ مُوسَى بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ الصَّدَاقُ إِذْ كَانَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَشْرَةَ أَوَاقٍ ‏.‏\hadithno{3348}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The dowry, when the Messenger of Allah was among us, was ten Awaq}}
\hadithdefcmd{nasai}{3349}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرِ بْنِ إِيَاسِ بْنِ مُقَاتِلِ بْنِ مُشَمْرِخِ بْنِ خَالِدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، وَابْنِ، عَوْنٍ وَسَلَمَةَ بْنِ عَلْقَمَةَ وَهِشَامِ بْنِ حَسَّانَ - دَخَلَ حَدِيثُ بَعْضِهِمْ فِي بَعْضٍ - عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ سَلَمَةُ عَنِ ابْنِ سِيرِينَ، نُبِّئْتُ عَنْ أَبِي الْعَجْفَاءِ، - وَقَالَ الآخَرُونَ عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي الْعَجْفَاءِ، - قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ أَلاَ لاَ تَغْلُوا صُدُقَ النِّسَاءِ فَإِنَّهُ لَوْ كَانَ مَكْرُمَةً فِي الدُّنْيَا أَوْ تَقْوَى عِنْدَ اللَّهِ عَزَّ وَجَلَّ كَانَ أَوْلاَكُمْ بِهِ النَّبِيُّ صلى الله عليه وسلم مَا أَصْدَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم امْرَأَةً مِنْ نِسَائِهِ وَلاَ أُصْدِقَتِ امْرَأَةٌ مِنْ بَنَاتِهِ أَكْثَرَ مِنْ ثِنْتَىْ عَشْرَةَ أُوقِيَّةً وَإِنَّ الرَّجُلَ لَيُغْلِي بِصَدُقَةِ امْرَأَتِهِ حَتَّى يَكُونَ لَهَا عَدَاوَةٌ فِي نَفْسِهِ وَحَتَّى يَقُولَ كُلِّفْتُ لَكُمْ عَلَقَ الْقِرْبَةِ وَكُنْتُ غُلاَمًا عَرَبِيًّا مُوَلَّدًا فَلَمْ أَدْرِ مَا عَلَقُ الْقِرْبَةِ قَالَ وَأُخْرَى يَقُولُونَهَا لِمَنْ قُتِلَ فِي مَغَازِيكُمْ أَوْ مَاتَ قُتِلَ فُلاَنٌ شَهِيدًا أَوْ مَاتَ فُلاَنٌ شَهِيدًا وَلَعَلَّهُ أَنْ يَكُونَ قَدْ أَوْقَرَ عَجُزَ دَابَّتِهِ أَوْ دَفَّ رَاحِلَتِهِ ذَهَبًا أَوْ وَرِقًا يَطْلُبُ التِّجَارَةَ فَلاَ تَقُولُوا ذَاكُمْ وَلَكِنْ قُولُوا كَمَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ فِي سَبِيلِ اللَّهِ أَوْ مَاتَ فَهُوَ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{3349}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Al-'Ajfa' said:"Umar bin Al-Khattab said: 'Do not go to extremes with regard to the dowries of women, for if that were a sign of honor and dignity in this world, or a sign of piety before Allah, the Mighty and Sublime, then Muhammad would have done that before you. But he did not give any of his wives, and none of his daughters were given, more than twelve Uqiyyah. A man may increase the dowry until he feels resentment against her and says: You cost me everything I own ('Alaqul-Qirbah)'" "And I was a man born among the 'Arabs, but I did not know the meaning of 'Alaqul-Qirbah' and others of you are saying -about those killed in this or that battle of yours, or who died: 'So-and-so was martyred' or 'so and so died as a martyr.' While perhaps he merely overloaded the backside of his beast, or lined his saddle with gold or silver seeking trade. So do not say that, rather say as the Prophet said: 'Whoever is killed in the cause of Allah, or dies, then he is in Paradise}}
\hadithdefcmd{nasai}{3350}{أَخْبَرَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ أُمِّ حَبِيبَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَهَا وَهِيَ بِأَرْضِ الْحَبَشَةِ زَوَّجَهَا النَّجَاشِيُّ وَأَمْهَرَهَا أَرْبَعَةَ آلاَفٍ وَجَهَّزَهَا مِنْ عِنْدِهِ وَبَعَثَ بِهَا مَعَ شُرَحْبِيلَ ابْنِ حَسَنَةَ وَلَمْ يَبْعَثْ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَىْءٍ وَكَانَ مَهْرُ نِسَائِهِ أَرْبَعَمِائَةِ دِرْهَمٍ ‏.‏\hadithno{3350}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Habibah that the Messenger of Allah married her when she was in Ethiopia. An-NajaShi performed the marriage for her and gave her a dowry of four thousand, and he fitted her out from his own wealth, and sent her with Shurahbil bin Hasanah. The Messenger of Allah did not send her anything, and the dowry of his wives was four hundred Dirhams}}
\hadithdefcmd{nasai}{3351}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لِمُحَمَّدٍ - عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَبِهِ أَثَرُ الصُّفْرَةِ فَسَأَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ أَنَّهُ تَزَوَّجَ امْرَأَةً مِنَ الأَنْصَارِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَمْ سُقْتَ إِلَيْهَا ‏"‏ ‏.‏ قَالَ زِنَةَ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{3351}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that 'Abdur-Rahman bin 'Awf came to the Prophet with traces of yellow perfume on him. The Messenger of Allah asked him (about that) and he told him that he had married a woman from among the Ansar. The Messenger of Allah said:"How much did you give her?" He said: "A Nawah (five Dirhams) of gold." The Messenger of Allah said: "Give a Walimah (wedding feast) even if it is with one sheep}}
\hadithdefcmd{nasai}{3352}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ رَآنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَىَّ بَشَاشَةُ الْعُرْسِ فَقُلْتُ تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ ‏.‏ قَالَ ‏ "‏ كَمْ أَصْدَقْتَهَا ‏"‏ ‏.‏ قَالَ زِنَةَ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏\hadithno{3352}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdur-Rahman bin 'Awf said:"The Messenger of Allah saw me looking cheerful as I had just got married." I said: "I have gotten married to a woman of the Ansar." He said: "How much did you give her as a dowry?" He said: "A Nawah (five Dirhams) of gold}}
\hadithdefcmd{nasai}{3353}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، ح وَأَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ تَمِيمٍ، قَالَ سَمِعْتُ حَجَّاجًا، يَقُولُ قَالَ ابْنُ جُرَيْجٍ عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرَأَةٍ نُكِحَتْ عَلَى صَدَاقٍ أَوْ حِبَاءٍ أَوْ عِدَةٍ قَبْلَ عِصْمَةِ النِّكَاحِ فَهُوَ لَهَا وَمَا كَانَ بَعْدَ عِصْمَةِ النِّكَاحِ فَهُوَ لِمَنْ أُعْطِيَهُ وَأَحَقُّ مَا أُكْرِمَ عَلَيْهِ الرَّجُلُ ابْنَتُهُ أَوْ أُخْتُهُ ‏"‏ ‏.‏ اللَّفْظُ لِعَبْدِ اللَّهِ ‏.‏\hadithno{3353}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman bin 'Amr:"The Messenger of Allah said: 'Whatever is given as a dowry, or gift or is promised her before the marriage belongs to her. Whatever is given after the marriage belongs to the one to whom it was given. And the most deserving for which a (man) is to be honored is (when marrying off) his daughter or sister.'" This is the wording of 'Abdullah (one of the narrators)}}
\hadithdefcmd{nasai}{3354}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا أَبُو سَعِيدٍ عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ، عَنْ زَائِدَةَ بْنِ قُدَامَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، قَالاَ أُتِيَ عَبْدُ اللَّهِ فِي رَجُلٍ تَزَوَّجَ امْرَأَةً وَلَمْ يَفْرِضْ لَهَا فَتُوُفِّيَ قَبْلَ أَنْ يَدْخُلَ بِهَا فَقَالَ عَبْدُ اللَّهِ سَلُوا هَلْ تَجِدُونَ فِيهَا أَثَرًا قَالُوا يَا أَبَا عَبْدِ الرَّحْمَنِ مَا نَجِدُ فِيهَا يَعْنِي أَثَرًا ‏.‏ قَالَ أَقُولُ بِرَأْيِي فَإِنْ كَانَ صَوَابًا فَمِنَ اللَّهِ لَهَا كَمَهْرِ نِسَائِهَا لاَ وَكْسَ وَلاَ شَطَطَ وَلَهَا الْمِيرَاثُ وَعَلَيْهَا الْعِدَّةُ فَقَامَ رَجُلٌ مِنْ أَشْجَعَ فَقَالَ فِي مِثْلِ هَذَا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِينَا فِي امْرَأَةٍ يُقَالُ لَهَا بِرْوَعُ بِنْتُ وَاشِقٍ تَزَوَّجَتْ رَجُلاً فَمَاتَ قَبْلَ أَنْ يَدْخُلَ بِهَا فَقَضَى لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِ صَدَاقِ نِسَائِهَا وَلَهَا الْمِيرَاثُ وَعَلَيْهَا الْعِدَّةُ ‏.‏ فَرَفَعَ عَبْدُ اللَّهِ يَدَيْهِ وَكَبَّرَ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ أَعْلَمُ أَحَدًا قَالَ فِي هَذَا الْحَدِيثِ الأَسْوَدُ غَيْرُ زَائِدَةَ ‏.‏\hadithno{3354}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Alqamah and Al-Aswad said:"A man was brought to 'Abdullah who had married a woman without naming a dowry for her, then he died before consummating the marriage with her. 'Abdullah said: 'Ask whether they can find any report about that.' They said: 'O Abu 'Abdur-Rahman, we cannot find any report about that.' He said: 'I will say what I think, and if it is correct then it is from Allah. She should have a dowry like that of her peers and no less, with no injustice, and she may inherit from him, and she has to observe the 'Iddah.' A man from Ashja' stood up and said: "The Messenger of Allah passed a similar judgment among us concerning a woman called Birwa' bint Washiq. She married a man who died before consummating the marriage with her, and the Messenger of Allah ruled that she should be given a dowry like that of her peers, and she could inherit, and she had to observe the 'Iddah.' 'Abdullah raised his hands and said the Takbir}}
\hadithdefcmd{nasai}{3355}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ أُتِيَ فِي امْرَأَةٍ تَزَوَّجَهَا رَجُلٌ فَمَاتَ عَنْهَا وَلَمْ يَفْرِضْ لَهَا صَدَاقًا وَلَمْ يَدْخُلْ بِهَا فَاخْتَلَفُوا إِلَيْهِ قَرِيبًا مِنْ شَهْرٍ لاَ يُفْتِيهِمْ ثُمَّ قَالَ أَرَى لَهَا صَدَاقَ نِسَائِهَا لاَ وَكْسَ وَلاَ شَطَطَ وَلَهَا الْمِيرَاثُ وَعَلَيْهَا الْعِدَّةُ ‏.‏ فَشَهِدَ مَعْقِلُ بْنُ سِنَانٍ الأَشْجَعِيُّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي بِرْوَعَ بِنْتِ وَاشِقٍ بِمِثْلِ مَا قَضَيْتَ ‏.‏\hadithno{3355}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah that a woman was brought to him who had married a man then he had died without naming any dowry for her and without consummating the marriage with her. They kept coming to him for nearly a month, and he did not issue any ruling to them. Then he said:"I think that she should have a dowry like that of her peers no less, with no injustice and she may inherit from him and she has to observe the 'Iddah." Ma'qil bin Sinan Al-Ashja'i testified: "The Messenger of Allah passed a similar judgment concerning Birwa' bint Washiq}}
\hadithdefcmd{nasai}{3356}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ فِرَاسٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، فِي رَجُلٍ تَزَوَّجَ امْرَأَةً فَمَاتَ وَلَمْ يَدْخُلْ بِهَا وَلَمْ يَفْرِضْ لَهَا قَالَ لَهَا الصَّدَاقُ وَعَلَيْهَا الْعِدَّةُ وَلَهَا الْمِيرَاثُ ‏.‏ فَقَالَ مَعْقِلُ بْنُ سِنَانٍ فَقَدْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم قَضَى بِهِ فِي بِرْوَعَ بِنْتِ وَاشِقٍ ‏.‏\hadithno{3356}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said, concerning a man who married a woman, then died before consummating the marriage with her, and without naming a dowry:"She should have the dowry, and she has to observe the 'Iddah, and she may inherit." Ma'qil bin Sinan said: "I heard the Prophet pass the same judgment concerning Birwa' bint Washiq}}
\hadithdefcmd{nasai}{3357}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، مِثْلَهُ ‏.‏\hadithno{3357}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) with a similar narration}}
\hadithdefcmd{nasai}{3358}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ أَتَاهُ قَوْمٌ فَقَالُوا إِنَّ رَجُلاً مِنَّا تَزَوَّجَ امْرَأَةً وَلَمْ يَفْرِضْ لَهَا صَدَاقًا وَلَمْ يَجْمَعْهَا إِلَيْهِ حَتَّى مَاتَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ مَا سُئِلْتُ مُنْذُ فَارَقْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَشَدَّ عَلَىَّ مِنْ هَذِهِ فَأْتُوا غَيْرِي ‏.‏ فَاخْتَلَفُوا إِلَيْهِ فِيهَا شَهْرًا ثُمَّ قَالُوا لَهُ فِي آخِرِ ذَلِكَ مَنْ نَسْأَلُ إِنْ لَمْ نَسْأَلْكَ وَأَنْتَ مِنْ جِلَّةِ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم بِهَذَا الْبَلَدِ وَلاَ نَجِدُ غَيْرَكَ ‏.‏ قَالَ سَأَقُولُ فِيهَا بِجَهْدِ رَأْيِي فَإِنْ كَانَ صَوَابًا فَمِنَ اللَّهِ وَحْدَهُ لاَ شَرِيكَ لَهُ وَإِنْ كَانَ خَطَأً فَمِنِّي وَمِنَ الشَّيْطَانِ وَاللَّهُ وَرَسُولُهُ مِنْهُ بُرَآءُ أُرَى أَنْ أَجْعَلَ لَهَا صَدَاقَ نِسَائِهَا لاَ وَكْسَ وَلاَ شَطَطَ وَلَهَا الْمِيرَاثُ وَعَلَيْهَا الْعِدَّةُ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏.‏ قَالَ وَذَلِكَ بِسَمْعِ أُنَاسٍ مِنْ أَشْجَعَ فَقَامُوا فَقَالُوا نَشْهَدُ أَنَّكَ قَضَيْتَ بِمَا قَضَى بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي امْرَأَةٍ مِنَّا يُقَالُ لَهَا بِرْوَعُ بِنْتُ وَاشِقٍ ‏.‏ قَالَ فَمَا رُئِيَ عَبْدُ اللَّهِ فَرِحَ فَرْحَةً يَوْمَئِذٍ إِلاَّ بِإِسْلاَمِهِ ‏.‏\hadithno{3358}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah that some people came to him and said:"A man among us married a woman, but he did not name a dowry for her, and he did not have intercourse with her before he died." 'Abdullah said: 'Since I left the Messenger of Allah I have never been asked a more difficult question than this. Go to someone else.' They kept coming to him for a month, then at the end of that they said: 'Who shall we ask if we do not ask you? You are one of the most prominent Companions of Muhammad in this land and we cannot find anyone else.' He said: 'I will say what I think, and if it is correct then it is from Allah alone, with no partner, and if it is wrong then it is from me and from the Shaitan, and Allah and His Messenger have nothing to do with it. I think she should be given a dowry like that of her peers and no less, with no injustice, and she may inherit from him, and she has to observe the 'Iddah, four months and ten days.'" He said: "And that was heard by some people from Ashja', who stood up and said: 'We bear witness that you have passed the same judgment as the Messenger of Allah did concerning a woman from among us who was called Birwa' bint Washiq.'" He said: "Abdullah was never seen looking so happy as he did on that day, except with having accepted Islam}}
\hadithdefcmd{nasai}{3359}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَتْهُ امْرَأَةٌ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي قَدْ وَهَبْتُ نَفْسِي لَكَ ‏.‏ فَقَامَتْ قِيَامًا طَوِيلاً فَقَامَ رَجُلٌ فَقَالَ زَوِّجْنِيهَا إِنْ لَمْ يَكُنْ لَكَ بِهَا حَاجَةٌ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ عِنْدَكَ شَىْءٌ ‏"‏ ‏.‏ قَالَ مَا أَجِدُ شَيْئًا ‏.‏ قَالَ ‏"‏ الْتَمِسْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ فَالْتَمَسَ فَلَمْ يَجِدْ شَيْئًا فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ مَعَكَ مِنَ الْقُرْآنِ شَىْءٌ ‏"‏ ‏.‏ قَالَ نَعَمْ سُورَةُ كَذَا وَسُورَةُ كَذَا ‏.‏ لِسُوَرٍ سَمَّاهَا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ زَوَّجْتُكَهَا عَلَى مَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{3359}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sahl bin Sa'd that a woman came to the Messenger of Allah and said:"O Messenger of Allah, I give myself in marriage to you." She stood for a long time, then a man stood up and said: "Marry her to me if you do not want to marry her." The Messenger of Allah said: "Do you have anything?" He said: "I cannot find anything." He said: "Look (for something), even if it is only an iron ring." So he looked but he could not find anything. The Messenger of Allah said to him: "Have you (memorized) anything of the Qur'an?" He said: "Yes, Surah such and such and Surah such and such," naming them. The Messenger of Allah said: "I marry her to you for what you know of the Qur'an}}
\hadithdefcmd{nasai}{3360}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ خَالِدِ بْنِ عُرْفُطَةَ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرَّجُلِ يَأْتِي جَارِيَةَ امْرَأَتِهِ قَالَ ‏ "‏ إِنْ كَانَتْ أَحَلَّتْهَا لَهُ جَلَدْتُهُ مِائَةً وَإِنْ لَمْ تَكُنْ أَحَلَّتْهَا لَهُ رَجَمْتُهُ ‏"‏ ‏.‏\hadithno{3360}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from An-Nu'man bin Bashir that the Prophet said, concerning a man who had intercourse with his wife's slave woman:"If she let him do that, I will flog him with one hundred stripes , and if she did not let him, I will stone him (to death)}}
\hadithdefcmd{nasai}{3361}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا أَبَانُ، عَنْ قَتَادَةَ، عَنْ خَالِدِ بْنِ عُرْفُطَةَ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَجُلاً، يُقَالُ لَهُ عَبْدُ الرَّحْمَنِ بْنُ حُنَيْنٍ وَيُنْبَزُ قُرْقُورًا أَنَّهُ وَقَعَ بِجَارِيَةِ امْرَأَتِهِ فَرُفِعَ إِلَى النُّعْمَانِ بْنِ بَشِيرٍ فَقَالَ لأَقْضِيَنَّ فِيهَا بِقَضِيَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنْ كَانَتْ أَحَلَّتْهَا لَكَ جَلَدْتُكَ وَإِنْ لَمْ تَكُنْ أَحَلَّتْهَا لَكَ رَجَمْتُكَ بِالْحِجَارَةِ فَكَانَتْ أَحَلَّتْهَا لَهُ فَجُلِدَ مِائَةً ‏.‏ قَالَ قَتَادَةُ فَكَتَبْتُ إِلَى حَبِيبِ بْنِ سَالِمٍ فَكَتَبَ إِلَىَّ بِهَذَا ‏.‏\hadithno{3361}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from An-Nu'man bin Bashir that a man called 'Abdur-Rahman bin Hunain or Yunbaz Qurqur had intercourse with his wife's slave woman, and it was brought to An-Nu'man bin Bashir. He said:"I will pass the same judgment concerning her as the Messenger of Allah did. If she let you do that, I will flog you, but if she did not let you do that, I will stone you (to death)." She had let him do that so he flogged him with one hundred stripes. (One of the narrators) Qatadah said: "I wrote to Habib bin Salim and he wrote back to me with this information}}
\hadithdefcmd{nasai}{3362}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا عَارِمٌ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي رَجُلٍ وَقَعَ بِجَارِيَةِ امْرَأَتِهِ ‏ "‏ إِنْ كَانَتْ أَحَلَّتْهَا لَهُ فَأَجْلِدْهُ مِائَةً وَإِنْ لَمْ تَكُنْ أَحَلَّتْهَا لَهُ فَأَرْجُمْهُ ‏"‏ ‏.‏\hadithno{3362}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from An-Nu'man bin Bashir that the Messenger of Allah said, concerning a man who had intercourse with his wife's slave woman:"If she let him do that, I will flog him with one hundred stripes, and if she did not let him do that, I will stone him (to death)}}
\hadithdefcmd{nasai}{3363}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ قَبِيصَةَ بْنِ حُرَيْثٍ، عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ، قَالَ قَضَى النَّبِيُّ صلى الله عليه وسلم فِي رَجُلٍ وَطِئَ جَارِيَةَ امْرَأَتِهِ ‏ "‏ إِنْ كَانَ اسْتَكْرَهَهَا فَهِيَ حُرَّةٌ وَعَلَيْهِ لِسَيِّدَتِهَا مِثْلُهَا وَإِنْ كَانَتْ طَاوَعَتْهُ فَهِيَ لَهُ وَعَلَيْهِ لِسَيِّدَتِهَا مِثْلُهَا ‏"‏ ‏.‏\hadithno{3363}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Salamah bin Al-Muhabbaq said:"The Prophet passed judgment concerning a man who had intercourse with his wife's slave woman: 'If he forced her, then she is free, and he has to give her mistress a similar slave as a replacement; if she obeyed him in that, then she belongs to him, and he has to give her mistress a similar slave as a replacement}}
\hadithdefcmd{nasai}{3364}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ، أَنَّ رَجُلاً، غَشِيَ جَارِيَةً لاِمْرَأَتِهِ فَرُفِعَ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنْ كَانَ اسْتَكْرَهَهَا فَهِيَ حُرَّةٌ مِنْ مَالِهِ وَعَلَيْهِ الشَّرْوَى لِسَيِّدَتِهَا وَإِنْ كَانَتْ طَاوَعَتْهُ فَهِيَ لِسَيِّدَتِهَا وَمِثْلُهَا مِنْ مَالِهِ ‏"‏ ‏.‏\hadithno{3364}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salamah bin Al-Muhabbaq that a man had intercourse with a slave woman belonging to his wife, and was brought to the Messenger of Allah. He said:"If he forced her, then she is free at his expense and he has to give her mistress a similar slave as a replacement. If she obeyed him in that, then she belongs to her mistress, and he has to give her mistress a similar slave as well}}
\hadithdefcmd{nasai}{3365}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنِ الْحَسَنِ، وَعَبْدِ اللَّهِ، ابْنَىْ مُحَمَّدٍ عَنْ أَبِيهِمَا، أَنَّ عَلِيًّا، بَلَغَهُ أَنَّ رَجُلاً، لاَ يَرَى بِالْمُتْعَةِ بَأْسًا فَقَالَ إِنَّكَ تَائِهٌ إِنَّهُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْهَا وَعَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ يَوْمَ خَيْبَرَ ‏.‏\hadithno{3365}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Al-Hasan and 'Abdullah, the sons of Muhammad, from their father, that 'Ali heard that a man did not see anything wrong with Mut'ah (temporary marriage). He said:"You are confused, the Messenger of Allah forbade it, and the meat of domestic donkeys on the day of Khaibar}}
\hadithdefcmd{nasai}{3366}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ، وَالْحَسَنِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ مُتْعَةِ النِّسَاءِ يَوْمَ خَيْبَرَ وَعَنْ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{3366}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah and Al-Hasan, the sons of Muhammad bin 'Ali, from their father, from 'Ali bin Abi Talib, that the Messenger of Allah on the Day of Khaibar forbade temporary marriage to women, and (he also forbade) the meat of tame donkeys}}
\hadithdefcmd{nasai}{3367}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالُوا أَنْبَأَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ وَالْحَسَنَ ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ أَخْبَرَاهُ أَنَّ أَبَاهُمَا مُحَمَّدَ بْنَ عَلِيٍّ أَخْبَرَهُمَا أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ رضى الله عنه قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ عَنْ مُتْعَةِ النِّسَاءِ ‏.‏ قَالَ ابْنُ الْمُثَنَّى يَوْمَ حُنَيْنٍ وَقَالَ هَكَذَا حَدَّثَنَا عَبْدُ الْوَهَّابِ مِنْ كِتَابِهِ ‏.‏\hadithno{3367}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Malik bin Anas narrated that Ibn Shihab told him that 'Abdullah and Al-Hasan, the sons of Muhammad bin 'Ali, told him, that their father Muhammad bin 'Ali told them, that 'Ali bin Abi Talib, may Allah be pleased with him, said:"The Messenger of Allah on the Day of Khaibar forbade temporary marriage to women." (One of the narrators) Ibn Al-Muthanna said: "The Day of Hunain." He said: "This is what 'Abdul-Wahhab narrated to us from his book}}
\hadithdefcmd{nasai}{3368}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ الرَّبِيعِ بْنِ سَبْرَةَ الْجُهَنِيِّ، عَنْ أَبِيهِ، قَالَ أَذِنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمُتْعَةِ فَانْطَلَقْتُ أَنَا وَرَجُلٌ إِلَى امْرَأَةٍ مِنْ بَنِي عَامِرٍ فَعَرَضْنَا عَلَيْهَا أَنْفُسَنَا فَقَالَتْ مَا تُعْطِينِي فَقُلْتُ رِدَائِي ‏.‏ وَقَالَ صَاحِبِي رِدَائِي ‏.‏ وَكَانَ رِدَاءُ صَاحِبِي أَجْوَدَ مِنْ رِدَائِي وَكُنْتُ أَشَبَّ مِنْهُ فَإِذَا نَظَرَتْ إِلَى رِدَاءِ صَاحِبِي أَعْجَبَهَا وَإِذَا نَظَرَتْ إِلَىَّ أَعْجَبْتُهَا ثُمَّ قَالَتْ أَنْتَ وَرِدَاؤُكَ يَكْفِينِي ‏.‏ فَمَكَثْتُ مَعَهَا ثَلاَثًا ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ عِنْدَهُ مِنْ هَذِهِ النِّسَاءِ اللاَّتِي يَتَمَتَّعُ فَلْيُخَلِّ سَبِيلَهَا ‏"‏ ‏.‏\hadithno{3368}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ar-Rabi' bin Sabrah Al-Juhani that his father said:"The Messenger of Allah gave permission for Mut'ah, so I and another man went to a woman from Bani 'Amir and offered ourselves to her (for Mut'ah). She said: 'What will you give me?' I said: 'My Rida' (upper garment).' My companion also said: 'My Rida'.' My companion's Rida' was finer than mine, but I was younger than him. When she looked at my companion's Rida' she liked it, but when she looked at me, she liked me. Then she said: 'You and your Rida' are sufficient for me.' I stayed with her for three (days), then the Messenger of Allah said: 'Whoever has any of these women whom he married temporarily should let them go}}
\hadithdefcmd{nasai}{3369}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بَلْجٍ، عَنْ مُحَمَّدِ بْنِ حَاطِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَصْلُ مَا بَيْنَ الْحَلاَلِ وَالْحَرَامِ الدُّفُّ وَالصَّوْتُ فِي النِّكَاحِ ‏"‏ ‏.‏\hadithno{3369}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Muhammad bin Hatib said:"The Messenger of Allah said: 'What differentiates between the lawful and the unlawful is the Duff, and the voice (singing) for the wedding}}
\hadithdefcmd{nasai}{3370}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ أَبِي بَلْجٍ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ حَاطِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ فَصْلَ مَا بَيْنَ الْحَلاَلِ وَالْحَرَامِ الصَّوْتُ ‏"‏ ‏.‏\hadithno{3370}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Balj said:"I heard Muhammad bin Hatib say: 'What differentiates between the lawful and the unlawful is the voice (singing)}}
\hadithdefcmd{nasai}{3371}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا خَالِدٌ، عَنْ أَشْعَثَ، عَنِ الْحَسَنِ، قَالَ تَزَوَّجَ عَقِيلُ بْنُ أَبِي طَالِبٍ امْرَأَةً مِنْ بَنِي جُشَمٍ فَقِيلَ لَهُ بِالرِّفَاءِ وَالْبَنِينِ ‏.‏ قَالَ قُولُوا كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَارَكَ اللَّهُ فِيكُمْ وَبَارَكَ لَكُمْ ‏"‏ ‏.‏\hadithno{3371}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Al-Hasan said:"Aqil bin Abi Talib married a woman from Banu Jusham, and it was said to him: 'May you live in harmony and have many sons.' He said: 'Say what the Messenger of Allah said: Barak Allahu fikum, wa baraka lakum. (May Allah bless you and bestow blessings upon you)}}
\hadithdefcmd{nasai}{3372}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى عَلَى عَبْدِ الرَّحْمَنِ أَثَرَ صُفْرَةٍ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالَ تَزَوَّجْتُ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ فَقَالَ ‏"‏ بَارَكَ اللَّهُ لَكَ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{3372}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah saw traces of yellow perfume on 'Abdur-Rahman and said: 'What is this?' He said: 'I married a woman for a Nawah (five Dirhams) of gold.' He said: 'May Allah bless you. Give a Walimah (wedding feast) even if it is with one sheep}}
\hadithdefcmd{nasai}{3373}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، جَاءَ وَعَلَيْهِ رَدْعٌ مِنْ زَعْفَرَانٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَهْيَمْ ‏"‏ ‏.‏ قَالَ تَزَوَّجْتُ امْرَأَةً ‏.‏ قَالَ ‏"‏ وَمَا أَصْدَقْتَ ‏"‏ ‏.‏ قَالَ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ قَالَ ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{3373}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that 'Abdur-Rahman bin 'Awf came with a trace of saffron on him, and the Messenger of Allah said:"What's this for?" He said: "I have married a woman." He said: "What dowry did you give?" He said: "The weight of a Nawah (five Dirhams) of gold." He said: "Give a Walimah (wedding feast) even if it is with one sheep}}
\hadithdefcmd{nasai}{3374}{أَخْبَرَنِي أَحْمَدُ بْنُ يَحْيَى بْنِ الْوَزِيرِ بْنِ سُلَيْمَانَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ كَثِيرِ بْنِ عُفَيْرٍ، قَالَ أَنْبَأَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسٍ، قَالَ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَىَّ - كَأَنَّهُ يَعْنِي عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ - أَثَرَ صُفْرَةٍ فَقَالَ ‏"‏ مَهْيَمْ ‏"‏ ‏.‏ قَالَ تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ ‏.‏ فَقَالَ ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{3374}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah saw a trace of yellow perfume on me" -as if he meant 'Abdur-Rahman bin 'Awf- "and said: 'What's this for?' He said: 'I have married a woman from among the Ansar.' He said: 'Give a Walimah (wedding feast) even if it is with one sheep}}
\hadithdefcmd{nasai}{3375}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ عَلِيًّا، قَالَ تَزَوَّجْتُ فَاطِمَةَ رضى الله عنها فَقُلْتُ يَا رَسُولَ اللَّهِ ابْنِ بِي ‏.‏ قَالَ ‏"‏ أَعْطِهَا شَيْئًا ‏"‏ ‏.‏ قُلْتُ مَا عِنْدِي مِنْ شَىْءٍ ‏.‏ قَالَ ‏"‏ فَأَيْنَ دِرْعُكَ الْحُطَمِيَّةُ ‏"‏ ‏.‏ قُلْتُ هِيَ عِنْدِي ‏.‏ قَالَ ‏"‏ فَأَعْطِهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{3375}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that 'Ali said:"I got married to Fatimah, may Allah be pleased with her, and I said: 'O Messenger of Allah, let me consummate the marriage.' He said: 'Give her something.' I said: 'I do not have anything.' He said: 'Where is your Hutami armor?' I said: 'It is with me.' He said: 'Give it to her}}
\hadithdefcmd{nasai}{3376}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ، عَنْ عَبْدَةَ، عَنْ سَعِيدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا تَزَوَّجَ عَلِيٌّ رضى الله عنه فَاطِمَةَ رضى الله عنها قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْطِهَا شَيْئًا ‏"‏ ‏.‏ قَالَ مَا عِنْدِي ‏.‏ قَالَ ‏"‏ فَأَيْنَ دِرْعُكَ الْحُطَمِيَّةُ ‏"‏ ‏.‏\hadithno{3376}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"When Ali, may Allah be pleased with him, married Fatimah, may Allah be pleased with her, the Messenger of Allah said to him: 'Give her something.' He said: 'I do not have anything.' He said: 'Where is your Hutami armor?}}
\hadithdefcmd{nasai}{3377}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي شَوَّالٍ وَأُدْخِلْتُ عَلَيْهِ فِي شَوَّالٍ فَأَىُّ نِسَائِهِ كَانَ أَحْظَى عِنْدَهُ مِنِّي ‏.‏\hadithno{3377}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Prophet married me in Shawwal, and he consummated the marriage with me in Shawwal, and which of his wives find more favor with him than me?}}
\hadithdefcmd{nasai}{3378}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا بِنْتُ سِتٍّ وَدَخَلَ عَلَىَّ وَأَنَا بِنْتُ تِسْعِ سِنِينَ وَكُنْتُ أَلْعَبُ بِالْبَنَاتِ ‏.‏\hadithno{3378}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah married me when I was six, and consummated the marriage with me when I was nine, and I used to play with dolls}}
\hadithdefcmd{nasai}{3379}{أَخْبَرَنَا أَحْمَدُ بْنُ سَعْدِ بْنِ الْحَكَمِ بْنِ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، قَالَ أَخْبَرَنِي عُمَارَةُ بْنُ غَزِيَّةَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَهِيَ بِنْتُ سِتِّ سِنِينَ وَبَنَى بِهَا وَهِيَ بِنْتُ تِسْعٍ ‏.‏\hadithno{3379}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah married me when I was six, and consummated the marriage with me when I was nine}}
\hadithdefcmd{nasai}{3380}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَزَا خَيْبَرَ فَصَلَّيْنَا عِنْدَهَا الْغَدَاةَ بِغَلَسٍ فَرَكِبَ النَّبِيُّ صلى الله عليه وسلم وَرَكِبَ أَبُو طَلْحَةَ وَأَنَا رَدِيفُ أَبِي طَلْحَةَ فَأَخَذَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فِي زُقَاقِ خَيْبَرَ وَإِنَّ رُكْبَتِي لَتَمَسُّ فَخِذَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِنِّي لأَرَى بَيَاضَ فَخِذِ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَلَمَّا دَخَلَ الْقَرْيَةَ قَالَ ‏"‏ اللَّهُ أَكْبَرُ خَرِبَتْ خَيْبَرُ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏ قَالَهَا ثَلاَثَ مَرَّاتٍ قَالَ وَخَرَجَ الْقَوْمُ إِلَى أَعْمَالِهِمْ - قَالَ عَبْدُ الْعَزِيزِ - فَقَالُوا مُحَمَّدٌ - قَالَ عَبْدُ الْعَزِيزِ وَقَالَ بَعْضُ أَصْحَابِنَا وَالْخَمِيسُ - وَأَصَبْنَاهَا عَنْوَةً فَجَمَعَ السَّبْىَ فَجَاءَ دِحْيَةُ فَقَالَ يَا نَبِيَّ اللَّهِ أَعْطِنِي جَارِيَةً مِنَ السَّبْىِ ‏.‏ قَالَ ‏"‏ اذْهَبْ فَخُذْ جَارِيَةً ‏"‏ ‏.‏ فَأَخَذَ صَفِيَّةَ بِنْتَ حُيَىٍّ فَجَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ أَعْطَيْتَ دِحْيَةَ صَفِيَّةَ بِنْتَ حُيَىٍّ سَيِّدَةَ قُرَيْظَةَ وَالنَّضِيرِ مَا تَصْلُحُ إِلاَّ لَكَ ‏.‏ قَالَ ‏"‏ ادْعُوهُ بِهَا ‏"‏ ‏.‏ فَجَاءَ بِهَا فَلَمَّا نَظَرَ إِلَيْهَا النَّبِيُّ صلى الله عليه وسلم قَالَ ‏"‏ خُذْ جَارِيَةً مِنَ السَّبْىِ غَيْرَهَا ‏"‏ ‏.‏ قَالَ وَإِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم أَعْتَقَهَا وَتَزَوَّجَهَا ‏.‏ فَقَالَ لَهُ ثَابِتٌ يَا أَبَا حَمْزَةَ مَا أَصْدَقَهَا قَالَ نَفْسَهَا أَعْتَقَهَا وَتَزَوَّجَهَا - قَالَ - حَتَّى إِذَا كَانَ بِالطَّرِيقِ جَهَّزَتْهَا لَهُ أُمُّ سُلَيْمٍ فَأَهْدَتْهَا إِلَيْهِ مِنَ اللَّيْلِ فَأَصْبَحَ عَرُوسًا قَالَ ‏"‏ مَنْ كَانَ عِنْدَهُ شَىْءٌ فَلْيَجِئْ بِهِ ‏"‏ ‏.‏ قَالَ وَبَسَطَ نِطَعًا فَجَعَلَ الرَّجُلُ يَجِيءُ بِالأَقِطِ وَجَعَلَ الرَّجُلُ يَجِيءُ بِالتَّمْرِ وَجَعَلَ الرَّجُلُ يَجِيءُ بِالسَّمْنِ فَحَاسُوا حَيْسَةً فَكَانَتْ وَلِيمَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3380}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas:"The Messenger of Allah invaded Khaibar and we prayed Al-Ghadah (Fajr) there (early in the morning) when it was still dark. Then the Prophet rode and Abu Talha rode, and I was riding behind Abu Talha. The Prophet of Allah passed through the lane of Khaibar quickly, and my knee was touching the thigh of the Messenger of Allah, and I could see the whiteness of the thigh of the Prophet. When he entered the town he said: 'Allahu Akbar, Khaibar is destroyed! Whenever we approach a (hostile) nation to fight, evil will be the morning for those who have been warned.' He said this three times. The people came out for their work." (One of the narrators) 'Abdul-'Aziz said: "They said: 'Muhammad (has come)!'" 'Abdul-'Aziz said: "Some of our companions said: 'With his army.'" "We conquered Khaibar and gathered the captives. Dihyah came and said: 'O Prophet of Allah, give me a slave girl from among the captives.' He said: 'Go and take a slave girl.' He took Safiyyah bint Huyayy. Then a man came to the Prophet and said: 'O Messenger of Allah, you gave Dihyah Safiyyah bint Huyayy, and she is the chief mistress of Quraizah and An-Nadir, and she is fit for no one but you.' He said: 'Call him to bring her.' When the Prophet saw her, he said: 'Take any other slave girl from among the captives.'" He said: "The Prophet of Allah set her free and married her." (One of the narrators) Thabit said to him: "O Abu Hamzah, what dowry did he give her?" He (Anas) said: "Herself; he set her free and married her." He said: "While on the road, Umm Sulaim fitted her out and presented her to him in the night, and the following morning he was a bridegroom. He said: 'Whoever has anything, let him bring it.' He spread out a leather cloth and men came with cottage cheese, dates, and ghee, and they made Hais, and that was the Walimah (wedding feast) of the Messenger of Allah}}
\hadithdefcmd{nasai}{3381}{أَخْبَرَنَا مُحَمَّدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي أُوَيْسٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ يَحْيَى، عَنْ حُمَيْدٍ، أَنَّهُ سَمِعَ أَنَسًا، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقَامَ عَلَى صَفِيَّةَ بِنْتِ حُيَىِّ بْنِ أَخْطَبَ بِطَرِيقِ خَيْبَرَ ثَلاَثَةَ أَيَّامٍ حِينَ عَرَّسَ بِهَا ثُمَّ كَانَتْ فِيمَنْ ضُرِبَ عَلَيْهَا الْحِجَابُ ‏.‏\hadithno{3381}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Humaid that he heard Anas say:"The Messenger of Allah stayed with Safiyyah bint Huyayy bin Akhtab on the way (back from) Khaibar for three days when he married her, then she was among those who were commanded to observe Hijab}}
\hadithdefcmd{nasai}{3382}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ أَقَامَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ خَيْبَرَ وَالْمَدِينَةِ ثَلاَثًا يَبْنِي بِصَفِيَّةَ بِنْتِ حُيَىٍّ فَدَعَوْتُ الْمُسْلِمِينَ إِلَى وَلِيمَتِهِ فَمَا كَانَ فِيهَا مِنْ خُبْزٍ وَلاَ لَحْمٍ أَمَرَ بِالأَنْطَاعِ وَأَلْقَى عَلَيْهَا مِنَ التَّمْرِ وَالأَقِطِ وَالسَّمْنِ فَكَانَتْ وَلِيِمَتَهُ فَقَالَ الْمُسْلِمُونَ إِحْدَى أُمَّهَاتِ الْمُؤْمِنِينَ أَوْ مِمَّا مَلَكَتْ يَمِينُهُ فَقَالُوا إِنْ حَجَبَهَا فَهِيَ مِنْ أُمَّهَاتِ الْمُؤْمِنِينَ وَإِنْ لَمْ يَحْجُبْهَا فَهِيَ مِمَّا مَلَكَتْ يَمِينُهُ فَلَمَّا ارْتَحَلَ وَطَّأَ لَهَا خَلْفَهُ وَمَدَّ الْحِجَابَ بَيْنَهَا وَبَيْنَ النَّاسِ ‏.‏\hadithno{3382}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:"The Prophet stayed between Khaibar and Al-Madinah for three days when he consummated his marriage to Safiyyah bint Huyayy, and I invited the Muslims to his Walimah, in which there was no bread or meat. He commanded that a leather cloth (be spread) and dates, cottage cheese and ghee were placed on it, and that was his Walimah. The Muslims said: '(Will she be) one of the Mothers of the Believers, or a female slave whom his right hand possesses?' They said: 'If he has a Hijab for her, then she will be one of the Mothers of the Believers and if she does not have a Hijab then she will be a female slave whom his right hand possesses.' When he rode on, he set aside a plate for her behind him and extended a Hijab between her and the people}}
\hadithdefcmd{nasai}{3383}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَامِرِ بْنِ سَعْدٍ، قَالَ دَخَلْتُ عَلَى قَرَظَةَ بْنِ كَعْبٍ وَأَبِي مَسْعُودٍ الأَنْصَارِيِّ فِي عُرْسٍ وَإِذَا جَوَارٍ يُغَنِّينَ فَقُلْتُ أَنْتُمَا صَاحِبَا رَسُولِ اللَّهِ صلى الله عليه وسلم وَمِنْ أَهْلِ بَدْرٍ يُفْعَلُ هَذَا عِنْدَكُمْ ‏.‏ فَقَالاَ اجْلِسْ إِنْ شِئْتَ فَاسْمَعْ مَعَنَا وَإِنْ شِئْتَ اذْهَبْ قَدْ رُخِّصَ لَنَا فِي اللَّهْوِ عِنْدَ الْعُرْسِ ‏.‏\hadithno{3383}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Amir bin Sa'd said:"I entered upon Qurazah bin Ka'b and Abu Mas'ud Al-Ansari during a wedding and there were some young girls singing. I said: 'You are two of the Companions of the Messenger of Allah who were present at Badr, and this is being done in your presence!' They said: 'Sit down if you want and listen with us, or if you want you can go away. We were granted a concession allowing entertainment at weddings}}
\hadithdefcmd{nasai}{3384}{أَخْبَرَنَا نُصَيْرُ بْنُ الْفَرَجِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَائِدَةَ، قَالَ حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ جَهَّزَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاطِمَةَ فِي خَمِيلٍ وَقِرْبَةٍ وَوِسَادَةٍ حَشْوُهَا إِذْخِرٌ ‏.‏\hadithno{3384}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali, may Allah be pleased with him, said:"The Messenger of Allah fitted out Fatimah with a velvet dress, a water-skin and a pillow stuffed with Idhkhar}}
\hadithdefcmd{nasai}{3385}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، يَقُولُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِرَاشٌ لِلرَّجُلِ وَفِرَاشٌ لأَهْلِهِ وَالثَّالِثُ لِلضَّيْفِ وَالرَّابِعُ لِلشَّيْطَانِ ‏"‏ ‏.‏\hadithno{3385}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah said:"A bed for a man, a bed for his wife, a third for his guest and the fourth is for the Shaitan}}
\hadithdefcmd{nasai}{3386}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ تَزَوَّجْتَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ هَلِ اتَّخَذْتُمْ أَنْمَاطًا ‏"‏ ‏.‏ قُلْتُ وَأَنَّى لَنَا أَنْمَاطٌ قَالَ ‏"‏ إِنَّهَا سَتَكُونُ ‏"‏ ‏.‏\hadithno{3386}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah said to me: 'Have you got married?' I said: 'Yes.' He said: 'Have you got any Anmat?' I said: 'How can we afford Anmat?' He said: 'You will be able to}}
\hadithdefcmd{nasai}{3387}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا جَعْفَرٌ، - وَهُوَ ابْنُ سُلَيْمَانَ - عَنِ الْجَعْدِ أَبِي عُثْمَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ تَزَوَّجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ بِأَهْلِهِ - قَالَ - وَصَنَعَتْ أُمِّي أُمُّ سُلَيْمٍ حَيْسًا - قَالَ - فَذَهَبْتُ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنَّ أُمِّي تُقْرِئُكَ السَّلاَمَ وَتَقُولُ لَكَ إِنَّ هَذَا لَكَ مِنَّا قَلِيلٌ ‏.‏ قَالَ ‏"‏ ضَعْهُ - ثُمَّ قَالَ - اذْهَبْ فَادْعُ فُلاَنًا وَفُلاَنًا وَمَنْ لَقِيتَ ‏"‏ ‏.‏ وَسَمَّى رِجَالاً فَدَعَوْتُ مَنْ سَمَّى وَمَنْ لَقِيتُهُ قُلْتُ لأَنَسٍ عِدَّةُ كَمْ كَانُوا قَالَ يَعْنِي زُهَاءَ ثَلاَثِمِائَةٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِيَتَحَلَّقْ عَشَرَةٌ عَشَرَةٌ فَلْيَأْكُلْ كُلُّ إِنْسَانٍ مِمَّا يَلِيهِ ‏"‏ ‏.‏ فَأَكَلُوا حَتَّى شَبِعُوا فَخَرَجَتْ طَائِفَةٌ وَدَخَلَتْ طَائِفَةٌ قَالَ لِي ‏"‏ يَا أَنَسُ ارْفَعْ ‏"‏ ‏.‏ فَرَفَعْتُ فَمَا أَدْرِي حِينَ رَفَعْتُ كَانَ أَكْثَرَ أَمْ حِينَ وَضَعْتُ ‏.‏\hadithno{3387}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Al-Ja'd bin Abi 'Uthman, that Anas bin Malik said:"The Messenger of Allah got married and consummated the marriage with his wife." He said: "My mother Umm Sulaim made some Hais, and I brought it to the Messenger of Allah and said: 'My mother sends you greetings of Salam, and says to you: 'This is a little from us.'' He said: 'Put it down.' Then he said: 'Go and call so-and-so, and so-and-so, and whoever you meet,' and he named some men. So I called those whom he named and those whom I met." I said to Anas: "How many were they?" He said: "About three hundred. Then the Messenger of Allah said: 'Let them sit around the dish of food in groups of ten, one after the other, and let each person eat from what is closest to him.' They ate until they were full, then one group went out and another group came in. He said to me: 'O Anas, clear it away.' So I cleared it away, and I do not know whether there was more when I cleared it away, or when I put it down}}
\hadithdefcmd{nasai}{3388}{أَخْبَرَنَا أَحْمَدُ بْنُ يَحْيَى بْنِ الْوَزِيرِ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ كَثِيرِ بْنِ عُفَيْرٍ، قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسٍ، أَنَّهُ سَمِعَهُ يَقُولُ آخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ قُرَيْشٍ وَالأَنْصَارِ فَآخَى بَيْنَ سَعْدِ بْنِ الرَّبِيعِ وَعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ فَقَالَ لَهُ سَعْدٌ إِنَّ لِي مَالاً فَهُوَ بَيْنِي وَبَيْنَكَ شَطْرَانِ وَلِي امْرَأَتَانِ فَانْظُرْ أَيُّهُمَا أَحَبُّ إِلَيْكَ فَأَنَا أُطَلِّقُهَا فَإِذَا حَلَّتْ فَتَزَوَّجْهَا ‏.‏ قَالَ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ وَمَالِكَ دُلُّونِي - أَىْ - عَلَى السُّوقِ ‏.‏ فَلَمْ يَرْجِعْ حَتَّى رَجَعَ بِسَمْنٍ وَأَقِطٍ قَدْ أَفْضَلَهُ ‏.‏ قَالَ وَرَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَىَّ أَثَرَ صُفْرَةٍ فَقَالَ ‏"‏ مَهْيَمْ ‏"‏ ‏.‏ فَقُلْتُ تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ ‏.‏ فَقَالَ ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{3388}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Humaid At-Tawil that he heard Anas say:"The Messenger of Allah established the bond of brotherhood between (some of) the Quraish and (some of) the Ansar, and he established the bond of brotherhood between Sa'd bin Ar-Rabi' and 'Abdur-Rahman bin 'Awf. Sa'd said to him: 'I have wealth, which I will share equally between you and me. And I have two wives, so look and see which one you like better, and I will divorce her, and when her 'Iddah is over you can marry her.' He said: 'May Allah bless your family and your wealth for you. Show me -i.e., where the market is.' And he did not come back until he brought some ghee, and cottage cheese that he had left over. He said: 'The Messenger of Allah saw traces of yellow perfume on me and he said: 'What is this for?' I said: 'I have married a woman from among the Ansar.' He said: 'Give a Walimah (wedding feast) even if it is with one sheep}}
