% Auto-generated chapter 14 for tirmidhi
% Hadiths in this chapter: 117

\hadithdefcmd{tirmidhi}{1205}{\hadithno{1205}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1206}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم آكِلَ الرِّبَا وَمُوكِلَهُ وَشَاهِدَيْهِ وَكَاتِبَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَجَابِرٍ وَأَبِي جُحَيْفَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1206}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Mas'ud narrated:"The Messenger of Allah (ﷺ) cursed the one who consumed Riba, and the one who charged it, those who witnessed it, and the one who recorded it." He said: There are narrations on this topic from 'Umar, 'Ali, Jabir [and Abu Juhaifah]. The Hadith of 'Abdullah (bin Mas'ud) is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1207}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ شُعْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْكَبَائِرِ قَالَ ‏ "‏ الشِّرْكُ بِاللَّهِ وَعُقُوقُ الْوَالِدَيْنِ وَقَتْلُ النَّفْسِ وَقَوْلُ الزُّورِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَكْرَةَ وَأَيْمَنَ بْنِ خُرَيْمٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1207}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas narrated that the Prophet (ﷺ) said about the major sins:"Associating partners with Allah, disobeying parents, killing oneself, and false speech." He said: There are narrations on this topic from Abu Bakrah, Ayman bin Khuraim, and Ibn 'Umar Abu 'Eisa said: The Hadith of Anas is a Hasan Sahih Gharib Hadith}}
\hadithdefcmd{tirmidhi}{1208}{\hadithno{1208}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1209}{\hadithno{1209}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1210}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ خَرَجَ مَعَ النَّبِيِّ صلى الله عليه وسلم إِلَى الْمُصَلَّى فَرَأَى النَّاسَ يَتَبَايَعُونَ فَقَالَ ‏"‏ يَا مَعْشَرَ التُّجَّارِ ‏"‏ ‏.‏ فَاسْتَجَابُوا لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَرَفَعُوا أَعْنَاقَهُمْ وَأَبْصَارَهُمْ إِلَيْهِ فَقَالَ ‏"‏ إِنَّ التُّجَّارَ يُبْعَثُونَ يَوْمَ الْقِيَامَةِ فُجَّارًا إِلاَّ مَنِ اتَّقَى اللَّهَ وَبَرَّ وَصَدَقَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُقَالُ إِسْمَاعِيلُ بْنُ عُبَيْدِ اللَّهِ بْنِ رِفَاعَةَ أَيْضًا ‏.‏\hadithno{1210}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Isma'il bin 'Ubaid bin Rifa'ah: From his father, from his grandfather, that he went with the Messenger of Allah (ﷺ) to the Musalla, and he saw the people doing business so he said: 'O people of trade!' and they replied to the Messenger of Allah (ﷺ) turning their necks and their gazes towards him, and he said: Indeed the merchants will be resurrected on the Day of judgement with the wicked, except the one who has Taqwa of Allah, who behaves charitably and is truthful.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih. And they also say Isma'il bin 'Ubaidullah bin Rifa'ah}}
\hadithdefcmd{tirmidhi}{1211}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَلِيُّ بْنُ مُدْرِكٍ، قَالَ سَمِعْتُ أَبَا زُرْعَةَ بْنَ عَمْرِو بْنِ جَرِيرٍ، يُحَدِّثُ عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ ثَلاَثَةٌ لاَ يَنْظُرُ اللَّهُ إِلَيْهِمْ يَوْمَ الْقِيَامَةِ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ ‏"‏ ‏.‏ قُلْتُ مَنْ هُمْ يَا رَسُولَ اللَّهِ فَقَدْ خَابُوا وَخَسِرُوا فَقَالَ ‏"‏ الْمَنَّانُ وَالْمُسْبِلُ إِزَارَهُ وَالْمُنْفِقُ سِلْعَتَهُ بِالْحَلِفِ الْكَاذِبِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ وَأَبِي أُمَامَةَ بْنِ ثَعْلَبَةَ وَعِمْرَانَ بْنِ حُصَيْنٍ وَمَعْقِلِ بْنِ يَسَارٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي ذَرٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1211}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Dharr: That the Prophet (ﷺ) said: "There are three whom Allah will not look at on the Day of Judgement, nor will He purify them, and theirs is a painful punishment." We said: "Who are they O Messenger of Allah ? For they have indeed failed and are lost!" He sai: "The Mannan, the one whose Izar hangs (below the ankels) and the one who promotes his merchandise with false oath." [He said:] There are narrations on this topic from Ibn Mas'ud, Abu Hurairah, Abu Umamah bin Tha'labah, 'Imran bin Husain, and Ma'qil bin Yasar [Abu 'Eisa said:] The Hadith of Abu Dharr is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1212}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا يَعْلَى بْنُ عَطَاءٍ، عَنْ عُمَارَةَ بْنِ حَدِيدٍ، عَنْ صَخْرٍ الْغَامِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ بَارِكْ لأُمَّتِي فِي بُكُورِهَا ‏"‏ ‏.‏ قَالَ وَكَانَ إِذَا بَعَثَ سَرِيَّةً أَوْ جَيْشًا بَعَثَهُمْ أَوَّلَ النَّهَارِ وَكَانَ صَخْرٌ رَجُلاً تَاجِرًا وَكَانَ إِذَا بَعَثَ تِجَارَةً بَعَثَهُمْ أَوَّلَ النَّهَارِ فَأَثْرَى وَكَثُرَ مَالُهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ مَسْعُودٍ وَبُرَيْدَةَ وَأَنَسٍ وَابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ صَخْرٍ الْغَامِدِيِّ حَدِيثٌ حَسَنٌ ‏.‏ وَلاَ نَعْرِفُ لِصَخْرٍ الْغَامِدِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا الْحَدِيثِ ‏.‏ وَقَدْ رَوَى سُفْيَانُ الثَّوْرِيُّ عَنْ شُعْبَةَ عَنْ يَعْلَى بْنِ عَطَاءٍ هَذَا الْحَدِيثَ ‏.‏\hadithno{1212}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Umarah bin Hadid: From Shakr Al-Ghamidi that the Messenger of Allah (ﷺ) said: "O Allah bless my Ummah in what they do early (in the day)." He said: "Whenever he (ﷺ) would dispatch a military expedition or an army, he would send them in the first part of the day." And Sakhr, a man who was a merchant, used to send his goods for trade during the beginning of the day, so he became rich, and his wealth increased. [He said:] There are narrations on this topic from 'Ali, Buraidah, Ibn Mas'ud, Anas, Ibn 'Umar, Ibn 'Abbas, and Jabir. [Abu 'Eisa said:] The Hadith is Sakhr Al-Ghamidi is a Hasan Hadith. We do not know of a narration that Sakhr Al-Ghamidi reported from the Prophet (ﷺ) other than this Hadith. Sufyan Ath-Thawri reported this Hadith from Shu'bah, from Ya'la bin 'Ata}}
\hadithdefcmd{tirmidhi}{1213}{حَدَّثَنَا أَبُو حَفْصٍ، عُمَرُ بْنُ عَلِيٍّ أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَخْبَرَنَا عُمَارَةُ بْنُ أَبِي حَفْصَةَ، أَخْبَرَنَا عِكْرِمَةُ، عَنْ عَائِشَةَ، قَالَتْ كَانَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثَوْبَانِ قِطْرِيَّانِ غَلِيظَانِ فَكَانَ إِذَا قَعَدَ فَعَرِقَ ثَقُلاَ عَلَيْهِ فَقَدِمَ بَزٌّ مِنَ الشَّامِ لِفُلاَنٍ الْيَهُودِيِّ ‏.‏ فَقُلْتُ لَوْ بَعَثْتَ إِلَيْهِ فَاشْتَرَيْتَ مِنْهُ ثَوْبَيْنِ إِلَى الْمَيْسَرَةِ ‏.‏ فَأَرْسَلَ إِلَيْهِ فَقَالَ قَدْ عَلِمْتُ مَا يُرِيدُ إِنَّمَا يُرِيدُ أَنْ يَذْهَبَ بِمَالِي أَوْ بِدَرَاهِمِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَذَبَ قَدْ عَلِمَ أَنِّي مِنْ أَتْقَاهُمْ لِلَّهِ وَآدَاهُمْ لِلأَمَانَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَنَسٍ وَأَسْمَاءَ بِنْتِ يَزِيدَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ أَيْضًا عَنْ عُمَارَةَ بْنِ أَبِي حَفْصَةَ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ فِرَاسٍ الْبَصْرِيَّ يَقُولُ سَمِعْتُ أَبَا دَاوُدَ الطَّيَالِسِيَّ يَقُولُ سُئِلَ شُعْبَةُ يَوْمًا عَنْ هَذَا الْحَدِيثِ فَقَالَ لَسْتُ أُحَدِّثُكُمْ حَتَّى تَقُومُوا إِلَى حَرَمِيِّ بْنِ عُمَارَةَ بْنِ أَبِي حَفْصَةَ فَتُقَبِّلُوا رَأْسَهُ ‏.‏ قَالَ وَحَرَمِيٌّ فِي الْقَوْمِ ‏.‏ قَالَ أَبُو عِيسَى أَىْ إِعْجَابًا بِهَذَا الْحَدِيثِ ‏.‏\hadithno{1213}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah:"The Messenger of Allah (ﷺ) was wearing two thick Qitri garments on. When he would sit, he would sweat since they were so heavy for him. Some clothes arrived from Ash-Sham for so-and-so, the Jew. I said: 'Perhaps you could dispatch a request to him to buy some garments (on credit) from him until it is easy (to pay). So he sent a message to him and he said: 'I know what he wants. He only wants to take away my wealth' or 'my Dirham.' So the Messenger of Allah (ﷺ) said: 'He has lied, indeed he knows that I am the one with the most Taqwa among them, and the best at fulfilling trusts among them.'" [He said:] There are narrations on this topic from Ibn 'Abbas, Anas, and Asma' bint Yazid. [Abu 'Eisa said:] The Hadith of 'Aishah is Hasan Sahih Gharib Hadith. Shu'bah has also reported it from 'Umarah bin Abi Hafsah. He said: I heard Muhammad bin Firas Al-Basri saying: "I heard Abu Dawud At-Tayalisi saying: 'One day Shu'bah was asked about this Hadith, and he said: "I will not narrate it to you (people) until you stand up before Harami bin 'Umarah [bin Hafsah] to kiss his head." He said: 'And Harami was there among the people.'" [Abu 'Eisa said:] Meaning: "approving of this Hadith}}
\hadithdefcmd{tirmidhi}{1214}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَعُثْمَانُ بْنُ عُمَرَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم وَدِرْعُهُ مَرْهُونَةٌ بِعِشْرِينَ صَاعًا مِنْ طَعَامٍ أَخَذَهُ لأَهْلِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1214}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas: "The Prophet (ﷺ) died while his armour was pawned for twenty Sa' of food that he got for his family." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1215}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، ح قَالَ مُحَمَّدٌ وَحَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ مَشَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم بِخُبْزِ شَعِيرٍ وَإِهَالَةٍ سَنِخَةٍ وَلَقَدْ رُهِنَ لَهُ دِرْعٌ عِنْدَ يَهُودِيٍّ بِعِشْرِينَ صَاعًا مِنْ طَعَامٍ أَخَذَهُ لأَهْلِهِ وَلَقَدْ سَمِعْتُهُ ذَاتَ يَوْمٍ يَقُولُ ‏ "‏ مَا أَمْسَى فِي آلِ مُحَمَّدٍ صلى الله عليه وسلم صَاعُ تَمْرٍ وَلاَ صَاعُ حَبٍّ ‏"‏ ‏.‏ وَإِنَّ عِنْدَهُ يَوْمَئِذٍ لَتِسْعُ نِسْوَةٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1215}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas: I walked to the Prophet (ﷺ) with some barley bread that has some rancid oil poured over it. The Prophet (ﷺ) had pawned his armour with a Jew for twenty Sa' of food that he got for his family. That day (he pawned it), I heard him saying: 'Not for one evening has the household of Muhammad had a Sa' of dates or a Sa' of grain.' And on that day he had nine wives." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1216}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، أَخْبَرَنَا عَبَّادُ بْنُ لَيْثٍ، صَاحِبُ الْكَرَابِيسِيِّ الْبَصْرِيُّ أَخْبَرَنَا عَبْدُ الْمَجِيدِ بْنُ وَهْبٍ، قَالَ قَالَ لِي الْعَدَّاءُ بْنُ خَالِدِ بْنِ هَوْذَةَ أَلاَ أُقْرِئُكَ كِتَابًا كَتَبَهُ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ قُلْتُ بَلَى ‏.‏ فَأَخْرَجَ لِي كِتَابًا ‏ "‏ هَذَا مَا اشْتَرَى الْعَدَّاءُ بْنُ خَالِدِ بْنِ هَوْذَةَ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ صلى الله عليه وسلم اشْتَرَى مِنْهُ عَبْدًا أَوْ أَمَةً لاَ دَاءَ وَلاَ غَائِلَةَ وَلاَ خِبْثَةَ بَيْعَ الْمُسْلِمِ الْمُسْلِمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبَّادِ بْنِ لَيْثٍ وَقَدْ رَوَى عَنْهُ هَذَا الْحَدِيثَ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{1216}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abbad bin Laith Al-Karabisi [Al-Basri]: "Abdul Majid bin Wahb narrated to us, he said: 'Al-'Adda' bin Khalid bin Hawdhah said to me: "Shall I not read to you a letter that was written for me from the Messenger of Allah (ﷺ) ?'" He said: 'I said: "Of course." So he took out a letter for me: "This is what Al-'Adda' bin Khalid bin Hawdhah purchased from Muhammad, the Messenger of Allah (ﷺ): He purchased from him a slave' - or - 'a female slave, having no ailments, nor being a runaway, nor having any malicious behavior. Sold by a Muslim to a Muslim.'" [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it except from 'Abbad bin Laith. More than one of the people of Hadith have reported this Hadith from him}}
\hadithdefcmd{tirmidhi}{1217}{حَدَّثَنَا سَعِيدُ بْنُ يَعْقُوبَ الطَّالْقَانِيُّ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ، عَنْ حُسَيْنِ بْنِ قَيْسٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِ الْمِكْيَالِ وَالْمِيزَانِ ‏ "‏ إِنَّكُمْ قَدْ وُلِّيتُمْ أَمْرَيْنِ هَلَكَتْ فِيهِ الأُمَمُ السَّالِفَةُ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ حُسَيْنِ بْنِ قَيْسٍ ‏.‏ وَحُسَيْنُ بْنُ قَيْسٍ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ وَقَدْ رُوِيَ هَذَا بِإِسْنَادٍ صَحِيحٍ عَنِ ابْنِ عَبَّاسٍ مَوْقُوفًا ‏.‏\hadithno{1217}\hadithgrade{Ahmad Muhammad Shakir: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas: That the Messenger of Allah (ﷺ) said to the people of weights and measures: "Indeed you have been entrusted with two matters that nations preceding you in the past were destroyed for." [Abu 'Eisa said:] We do not know this Hadith to be Marfu' except through the narration of Husain bin Qais, and Husain bin Qais was graded weak in Hadith. This has been reported as Maquf narration from Ibn 'Abbas with a Sahih chain of narration}}
\hadithdefcmd{tirmidhi}{1218}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ شُمَيْطِ بْنِ عَجْلاَنَ، حَدَّثَنَا الأَخْضَرُ بْنُ عَجْلاَنَ، عَنْ عَبْدِ اللَّهِ الْحَنَفِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَاعَ حِلْسًا وَقَدَحًا وَقَالَ ‏"‏ مَنْ يَشْتَرِي هَذَا الْحِلْسَ وَالْقَدَحَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَخَذْتُهُمَا بِدِرْهَمٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ يَزِيدُ عَلَى دِرْهَمٍ مَنْ يَزِيدُ عَلَى دِرْهَمٍ ‏"‏ فَأَعْطَاهُ رَجُلٌ دِرْهَمَيْنِ فَبَاعَهُمَا مِنْهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الأَخْضَرِ بْنِ عَجْلاَنَ ‏.‏ وَعَبْدُ اللَّهِ الْحَنَفِيُّ الَّذِي رَوَى عَنْ أَنَسٍ هُوَ أَبُو بَكْرٍ الْحَنَفِيُّ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ لَمْ يَرَوْا بَأْسًا بِبَيْعِ مَنْ يَزِيدُ فِي الْغَنَائِمِ وَالْمَوَارِيثِ ‏.‏ وَقَدْ رَوَى الْمُعْتَمِرُ بْنُ سُلَيْمَانَ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الْحَدِيثِ عَنِ الأَخْضَرِ بْنِ عَجْلاَنَ هَذَا الْحَدِيثَ ‏.‏\hadithno{1218}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas bin Malik: That the Messenger of Allah (ﷺ) sold a saddle blanket and a drinking bowl. He (ﷺ) said: "Who will buy saddle blanket and drinking bowl ?". So a man said: "I will take them for a Dirham." So the Prophet (ﷺ) said: "Who will give more than a Dirham ? Who will give more that a Dirham ?" A man agreed to give him two Dirham, so he sold them to him. [Abu 'Eisa said:] This Hadith is Hasan. We do not know of it except from the narration of Al-Akhdar bin 'Ajlan, and 'Abdullah Al-Hanafi who is reporting from Anas, is Abu Bakr Al-Hanafi. This is acted upon according to some of the people of knowledge, they did not see any harm in auctioning the spolis of war and inheritance. Al-Mu'tamir bin Sulaiman and others among the people of Hadith reported from Al-Akhdar bin 'Ajlan}}
\hadithdefcmd{tirmidhi}{1219}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ دَبَّرَ غُلاَمًا لَهُ فَمَاتَ وَلَمْ يَتْرُكْ مَالاً غَيْرَهُ فَبَاعَهُ النَّبِيُّ صلى الله عليه وسلم فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ بْنِ النَّحَّامِ ‏.‏ قَالَ جَابِرٌ عَبْدًا قِبْطِيًّا مَاتَ عَامَ الأَوَّلِ فِي إِمَارَةِ ابْنِ الزُّبَيْرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لَمْ يَرَوْا بِبَيْعِ الْمُدَبَّرِ بَأْسًا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَكَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ بَيْعَ الْمُدَبَّرِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكٍ وَالأَوْزَاعِيِّ ‏.‏\hadithno{1219}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir: "A man among the Ansar decided to free a slave of his after his death. He died but he left no wealth behind beside the slave. So the Prophet (ﷺ) sold him and Nu'aim [bin 'Abdullah] bin An-Nah-ham bought him." Jabir said: "He was Coptic slave who died during the first year of the leadership of Ibn Az-Zubair." [Abu 'Eisa said:] This Hadith is Hasan Sahih and it has been reported through more than one route from Jabir bin 'Abdullah. This Hadith is acted upon according to some of the people of knowledge among the Companions of the Prophet (ﷺ) and others. They did not see any harm in the sale of Mudabbar. This is the view of Ash-Shafi'i, Ahmad and Ishaq. There are those among people of knowledge, among the Companions of the Prophet (ﷺ) and others, who disliked selling the Mudabbar. This is the view of Sufyan Ath-Thawri, Malik and Al-Awza'i}}
\hadithdefcmd{tirmidhi}{1220}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ تَلَقِّي الْبُيُوعِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ وَابْنِ عُمَرَ وَرَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1220}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn Mas'ud: From the Prophet (ﷺ): "He prohibited meeting the owners of the goods." [He said:] There are narrations on this topic from 'Ali, Ibn 'Abbas, Abu Hurairah, Abu Sa'eed, Ibn 'Umar, and a man from the Companions of the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1221}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو الرَّقِّيُّ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يُتَلَقَّى الْجَلَبُ فَإِنْ تَلَقَّاهُ إِنْسَانٌ فَابْتَاعَهُ فَصَاحِبُ السِّلْعَةِ فِيهَا بِالْخِيَارِ إِذَا وَرَدَ السُّوقَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَيُّوبَ وَحَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ تَلَقِّيَ الْبُيُوعِ وَهُوَ ضَرْبٌ مِنَ الْخَدِيعَةِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَغَيْرِهِ مِنْ أَصْحَابِنَا ‏.‏\hadithno{1221}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah: "The Prophet (ﷺ) prohibited meeting the goods being brought (to the market). If someone were to meet them and buy them, then the owner of the goods retains the option when he reaches the market." [Abu 'Eisa said:] This Hadith is Hasan Gharib narration of Ayyub (a narrator). The Hadith if Ibn Mas'ud is a Hasan Sahih Hadith. There are those among the people of knowledge who disliked meeting the owners of the goods, saying that it is a type of deception. This is the view of Ash-Shafi'i, and others among our companions}}
\hadithdefcmd{tirmidhi}{1222}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ مَنِيعٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ قُتَيْبَةُ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ طَلْحَةَ وَجَابِرٍ وَأَنَسٍ وَابْنِ عَبَّاسٍ وَحَكِيمِ بْنِ أَبِي يَزِيدَ عَنْ أَبِيهِ وَعَمْرِو بْنِ عَوْفٍ الْمُزَنِيِّ جَدِّ كَثِيرِ بْنِ عَبْدِ اللَّهِ وَرَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1222}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "The dweller of the town is not to sell for the Bedouin." [He said:] There are narrations on this topic from Talhah, Jabir, Anas, Ibn 'Abbas, Hakim bin Abi Yazid from his father, 'Amr bin 'Awf Al-Muzani the grandfather of Kathir bin 'Abdullah, and a man from the Companions of the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1223}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَأَحْمَدُ بْنُ مَنِيعٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ دَعُوا النَّاسَ يَرْزُقُ اللَّهُ بَعْضَهُمْ مِنْ بَعْضٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَدِيثُ جَابِرٍ فِي هَذَا هُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ أَيْضًا ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ كَرِهُوا أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ ‏.‏ وَرَخَّصَ بَعْضُهُمْ فِي أَنْ يَشْتَرِيَ حَاضِرٌ لِبَادٍ ‏.‏ وَقَالَ الشَّافِعِيُّ يُكْرَهُ أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ وَإِنْ بَاعَ فَالْبَيْعُ جَائِزٌ ‏.‏\hadithno{1223}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir: That the Messenger of Allah (ﷺ) said: "The dweller of the town is not to sell for the Bedouin, leave the people ; Allah provides for some of them through others." [Abu 'Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith, and this Hadith of Jabir is a Hasan Sahih Hadith as well. This Hadith is acted upon according to some of the people of knowledge among the Companions of the Prophet (ﷺ) and others. They dislike the dweller of the town to sell for the Bedouin, while some of them permitted the town dweller to purchase for the Bedouin. Ash-Shafi'i said: "It is disliked for the dweller of the town to sell for the Bedouin, and if he does sell, then the sale is permissible}}
\hadithdefcmd{tirmidhi}{1224}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ الإِسْكَنْدَرَانِيُّ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَزَيْدِ بْنِ ثَابِتٍ وَسَعْدٍ وَجَابِرٍ وَرَافِعِ بْنِ خَدِيجٍ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْمُحَاقَلَةُ بَيْعُ الزَّرْعِ بِالْحِنْطَةِ ‏.‏ وَالْمُزَابَنَةُ بَيْعُ الثَّمَرِ عَلَى رُءُوسِ النَّخْلِ بِالتَّمْرِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ كَرِهُوا بَيْعَ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ ‏.‏\hadithno{1224}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah: The Messenger of Allah (ﷺ) prohibited Muhaqalah and Muzabanah. [He said:] There are narrations on this topic from Ibn 'Umar, Ibn 'Abbas, Zaid bin Thabit, Sa'd, Jabir, Rafi' bin Khadij, and Abu Sa'eed. [Abu 'Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith. Muhaqalah is selling corps for wheat, and Muzabanah is selling dates that are on the date-palm for dried dates. This is acted upon according to the most of the people of knowledge, they disliked sales of Muhaqalah and Muzabanah}}
\hadithdefcmd{tirmidhi}{1225}{\hadithno{1225}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1226}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ النَّخْلِ حَتَّى يَزْهُوَ ‏.‏\hadithno{1226}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Umar:"The Messenger of Allah (ﷺ) prohibited selling date-palms until they have blossomed}}
\hadithdefcmd{tirmidhi}{1227}{وَبِهَذَا الإِسْنَادِ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ السُّنْبُلِ حَتَّى يَبْيَضَّ وَيَأْمَنَ الْعَاهَةَ نَهَى الْبَائِعَ وَالْمُشْتَرِيَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَعَائِشَةَ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَجَابِرٍ وَأَبِي سَعِيدٍ وَزَيْدِ بْنِ ثَابِتٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ كَرِهُوا بَيْعَ الثِّمَارِ قَبْلَ أَنْ يَبْدُوَ صَلاَحُهَا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1227}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{With this (same as no. 1226) chain:"The Prophet (ﷺ) prohibited selling ears (of grain) until they have whitened (shown their kernals) and are safe from blight, he forbade it for the seller and the buyer." [He said:] There are narrations on this topic from Anas, Ibn 'Abbas, Jabir, Abu Sa'eed, and Zaid bin Thabit. [Abu 'Eisa said:] The Hadith of Ibn 'Umar is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge among the Companions of the Prophet (ﷺ) and others. They dislike selling fruits before their usefulness appears, this is the view of Ash-Shafi'i, Ahmad and Ishaq}}
\hadithdefcmd{tirmidhi}{1228}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا أَبُو الْوَلِيدِ، وَعَفَّانُ، وَسُلَيْمَانُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْعِنَبِ حَتَّى يَسْوَدَّ وَعَنْ بَيْعِ الْحَبِّ حَتَّى يَشْتَدَّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏\hadithno{1228}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas: "The Messenger of Allah (ﷺ) prohibited selling grapes until they appear and selling grains until they become firm." [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it being Marfu' except from the narration of Hammad bin Salamah}}
\hadithdefcmd{tirmidhi}{1229}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ حَبَلِ الْحَبَلَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ الْخُدْرِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَحَبَلُ الْحَبَلَةِ نِتَاجُ النِّتَاجِ وَهُوَ بَيْعٌ مَفْسُوخٌ عِنْدَ أَهْلِ الْعِلْمِ وَهُوَ مِنْ بُيُوعِ الْغَرَرِ ‏.‏ وَقَدْ رَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ أَيُّوبَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَرَوَى عَبْدُ الْوَهَّابِ الثَّقَفِيُّ وَغَيْرُهُ عَنْ أَيُّوبَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ وَنَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهَذَا أَصَحُّ ‏.‏\hadithno{1229}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar: "The Prophet (ﷺ) prohibited the sale of Habalil-Habalah." [He said:] There are narrations on this topic from 'Abdullah bin 'Abbas and Abu Sa'eed Al-Khudri [Abu 'Eisa said:] The Hadith of Ibn 'Umar is Hasan Sahih Hadith. This is acted upon according to the people of knowledge. And Hababil-Habalah is the offspring of the offspring (of an animal). It is an invalid sale according to the people of knowledge and it is type of Gharar sale. Shu'bah reported this Hadith from Ayyub, from Sa'eed bin Jubair, from Ibn 'Abbas. 'Abdul Wahhab Ath-Thaqafi and others reported it from Ayyub, from Sa'eed bin Jubair and Nafi', from Ibn 'Umar, from the Prophet (ﷺ), and this is more correct}}
\hadithdefcmd{tirmidhi}{1230}{حَدَّثَنَا أَبُو كُرَيْبٍ، أَنْبَأَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْغَرَرِ وَبَيْعِ الْحَصَاةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا بَيْعَ الْغَرَرِ ‏.‏ قَالَ الشَّافِعِيُّ وَمِنْ بُيُوعِ الْغَرَرِ بَيْعُ السَّمَكِ فِي الْمَاءِ وَبَيْعُ الْعَبْدِ الآبِقِ وَبَيْعُ الطَّيْرِ فِي السَّمَاءِ وَنَحْوُ ذَلِكَ مِنَ الْبُيُوعِ ‏.‏ وَمَعْنَى بَيْعِ الْحَصَاةِ أَنْ يَقُولَ الْبَائِعُ لِلْمُشْتَرِي إِذَا نَبَذْتُ إِلَيْكَ بِالْحَصَاةِ فَقَدْ وَجَبَ الْبَيْعُ فِيمَا بَيْنِي وَبَيْنَكَ ‏.‏ وَهَذَا شَبِيهٌ بِبَيْعِ الْمُنَابَذَةِ وَكَانَ هَذَا مِنْ بُيُوعِ أَهْلِ الْجَاهِلِيَّةِ ‏.‏\hadithno{1230}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) prohibited the Gharar sale, and the Hasah sale." [He said:] There are narrations on this topic from Ibn 'Umar, Ibn 'Abbas, Abu Sa'eed, and Anas. [Abu 'Eisa said:] This Hadith of Abu Hurairah is Hasan Sahih Hadith. This Hadith is acted upon according to the people of knowledge, they dislike the Gharar. Ash-Shafi'i said: "The Gharar sale includes selling fish that are in the wate, selling a slave that has escaped, selling birds that are in the sky, and similar type of sales. And the meaning of Hasah sale is when the seller says to the buyer: 'When I toss the pebble at you, then the sale between you and I is final.' This resembles the sale of Munabadhah and this is one of the selling practices of the people of Jahiliyyah}}
\hadithdefcmd{tirmidhi}{1231}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعَتَيْنِ فِي بَيْعَةٍ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عُمَرَ وَابْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَقَدْ فَسَّرَ بَعْضُ أَهْلِ الْعِلْمِ قَالُوا بَيْعَتَيْنِ فِي بَيْعَةٍ ‏.‏ أَنْ يَقُولَ أَبِيعُكَ هَذَا الثَّوْبَ بِنَقْدٍ بِعَشَرَةٍ وَبِنَسِيئَةٍ بِعِشْرِينَ وَلاَ يُفَارِقُهُ عَلَى أَحَدِ الْبَيْعَيْنِ فَإِذَا فَارَقَهُ عَلَى أَحَدِهِمَا فَلاَ بَأْسَ إِذَا كَانَتِ الْعُقْدَةُ عَلَى وَاحِدٍ مِنْهُمَا ‏.‏ قَالَ الشَّافِعِيُّ وَمِنْ مَعْنَى نَهْىِ النَّبِيِّ صلى الله عليه وسلم عَنْ بَيْعَتَيْنِ فِي بَيْعَةٍ أَنْ يَقُولَ أَبِيعُكَ دَارِي هَذِهِ بِكَذَا عَلَى أَنْ تَبِيعَنِي غُلاَمَكَ بِكَذَا فَإِذَا وَجَبَ لِي غُلاَمُكَ وَجَبَ لَكَ دَارِي ‏.‏ وَهَذَا يُفَارِقُ عَنْ بَيْعٍ بِغَيْرِ ثَمَنٍ مَعْلُومٍ وَلاَ يَدْرِي كُلُّ وَاحِدٍ مِنْهُمَا عَلَى مَا وَقَعَتْ عَلَيْهِ صَفْقَتُهُ ‏.‏\hadithno{1231}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) prohibited two sales in one." There are narrations on this topic from 'Abdullah bin 'Amr, Ibn 'Umar, and Ibn Mas'ud. [Abu Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge. Some of the people of knowledge have explained it by saying that two sales in one is when one says: "I will sell you this garment for ten in cash, and twenty on credit." He does not distinguish between either of the two sales. But when he distinguishes it as being one of them, then there is no harm when one of them is agreed upon. Ash-Shafi'i said: "Included in the meaning of what the Prophet (ﷺ) prohibited of regarding two sales in one, is if one said: 'I will sell you the house of mine for that (price), upon the condition that you sell me you alve for this (price). When I get the slave, then you get the house.' In this way the sales are distinguished without the prices being known, and neither of them knows what will happen at the conclusion of it (the agreement)}}
\hadithdefcmd{tirmidhi}{1232}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَأْتِينِي الرَّجُلُ يَسْأَلُنِي مِنَ الْبَيْعِ مَا لَيْسَ عِنْدِي أَبْتَاعُ لَهُ مِنَ السُّوقِ ثُمَّ أَبِيعُهُ قَالَ ‏ "‏ لاَ تَبِعْ مَا لَيْسَ عِنْدَكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏\hadithno{1232}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hakim b. Hizam:"I asked Messenger of Allah (ﷺ), I said: 'A man came to me asking to buy something that I did not have. Can I buy it from the market for him and then give it to him?' He said: 'Do not sell what is not with you.'" He said: There are narrations on this topic from 'Abdullah bin 'Umar}}
\hadithdefcmd{tirmidhi}{1233}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَبِيعَ مَا لَيْسَ عِنْدِي ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏ قَالَ إِسْحَاقُ بْنُ مَنْصُورٍ قُلْتُ لأَحْمَدَ مَا مَعْنَى نَهَى عَنْ سَلَفٍ وَبَيْعٍ قَالَ أَنْ يَكُونَ يُقْرِضُهُ قَرْضًا ثُمَّ يُبَايِعُهُ عَلَيْهِ بَيْعًا يَزْدَادُ عَلَيْهِ وَيَحْتَمِلُ أَنْ يَكُونَ يُسْلِفُ إِلَيْهِ فِي شَيْءٍ فَيَقُولُ إِنْ لَمْ يَتَهَيَّأْ عِنْدَكَ فَهُوَ بَيْعٌ عَلَيْكَ ‏.‏ قَالَ إِسْحَاقُ يَعْنِي ابْنَ رَاهَوَيْهِ كَمَا قَالَ قُلْتُ لأَحْمَدَ وَعَنْ بَيْعِ مَا لَمْ تَضْمَنْ قَالَ لاَ يَكُونُ عِنْدِي إِلاَّ فِي الطَّعَامِ مَا لَمْ تَقْبِضْ ‏.‏ قَالَ إِسْحَاقُ كَمَا قَالَ فِي كُلِّ مَا يُكَالُ أَوْ يُوزَنُ ‏.‏ قَالَ أَحْمَدُ إِذَا قَالَ أَبِيعُكَ هَذَا الثَّوْبَ وَعَلَىَّ خِيَاطَتُهُ وَقَصَارَتُهُ فَهَذَا مِنْ نَحْوِ شَرْطَيْنِ فِي بَيْعٍ وَإِذَا قَالَ أَبِيعُكَهُ وَعَلَىَّ خِيَاطَتُهُ فَلاَ بَأْسَ بِهِ أَوْ قَالَ أَبِيعُكَهُ وَعَلَىَّ قَصَارَتُهُ فَلاَ بَأْسَ بِهِ إِنَّمَا هُوَ شَرْطٌ وَاحِدٌ ‏.‏ قَالَ إِسْحَاقُ كَمَا قَالَ ‏.‏\hadithno{1233}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hakim b. Hizam: "The Messenger of Allah (ﷺ) prohibited me from selling what was not with me." [Abu 'Eisa said:] This Hadith is Hasan. He said: There is something on this topic from 'Abdullah bin 'Umar. Ishaq bin Mansur said: "I said to Ahmad: 'What is the meaning of the prohibition from a loan along with a sale? He said: 'That he gives him a loan and then he makes a sale to him greater then it's actual worth. And, it carries the meaning of him loaning it to him in exchange for something (as collateral), so he says: 'If you are unable to pay it (the loan), the it (the collateral) will be a sale for you.' Ishaq [bin Rahuwyah] said as he said. And I said to Ahmad: 'What about selling what one does not possess?' He said: 'To me it does not apply except in cases of food - meaning one has not taken possession of it.' And Ishaq said the same for all of what is measured or weighed. Ahmad said: 'When he says: "I will sell you this garment, with the condition that I am the tailor for it, and I am the one who bleaches it.' This is an example of two conditions in one sale. But if he says: "I am selling it to you with the condition that I am its tailor," then there is no harm in it. And, if he said: "I am selling it to you with the condition that I am the one who bleaches it" then there is no harm in it, because this is only one condition.' And Ishaq said as he said}}
\hadithdefcmd{tirmidhi}{1234}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، حَدَّثَنَا عَمْرُو بْنُ شُعَيْبٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، حَتَّى ذَكَرَ عَبْدَ اللَّهِ بْنَ عَمْرٍو أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ سَلَفٌ وَبَيْعٌ وَلاَ شَرْطَانِ فِي بَيْعٍ وَلاَ رِبْحُ مَا لَمْ يُضْمَنْ وَلاَ بَيْعُ مَا لَيْسَ عِنْدَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ حَكِيمِ بْنِ حِزَامٍ حَدِيثٌ حَسَنٌ قَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ رَوَى أَيُّوبُ السَّخْتِيَانِيُّ وَأَبُو بِشْرٍ عَنْ يُوسُفَ بْنِ مَاهَكَ عَنْ حَكِيمِ بْنِ حِزَامٍ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى هَذَا الْحَدِيثَ عَوْفٌ وَهِشَامُ بْنُ حَسَّانَ عَنِ ابْنِ سِيرِينَ عَنْ حَكِيمِ بْنِ حِزَامٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهَذَا حَدِيثٌ مُرْسَلٌ إِنَّمَا رَوَاهُ ابْنُ سِيرِينَ عَنْ أَيُّوبَ السَّخْتِيَانِيِّ عَنْ يُوسُفَ بْنِ مَاهَكَ عَنْ حَكِيمِ بْنِ حِزَامٍ ‏.‏\hadithno{1234}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ayyub: 'Amr bin Shu'aib narrated to us, saying: My father narrated to me from his father' until he mentioned 'Abdullah bin 'Amr: "The Messenger of Allah (ﷺ) said: 'It is not lawful to lend and sell, nor two conditions in a sale, nor to profit from what is not possessed, nor to sell what one does not have.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih. [Abu 'Eisa said:] The Hadith of Hakim bin Hizam is a Hasan Hadith, it has been reported from him through other routes. Ayyub As-Sakhtiyani and Abu Bishr report from Yusuf bin Mahak, from Hakim bin Hizam. [Abu 'Eisa said:] 'Awf and Hisham bin Hassan reported this Hadith from Ibn Sirin, from Hakim bin Hizam from the Prophet (ﷺ). And this is a Mursal Hadith. Ibn Sirin only reported it from Ayyub As-Sikhtiyani from Yusuf bin Mahak, from Hakim bin Hizam like this}}
\hadithdefcmd{tirmidhi}{1235}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَعَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ الْبَصْرِيُّ أَبُو سَهْلٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، عَنْ يَزِيدَ بْنِ إِبْرَاهِيمَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَيُّوبَ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَبِيعَ مَا لَيْسَ عِنْدِي ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى وَكِيعٌ هَذَا الْحَدِيثَ عَنْ يَزِيدَ بْنِ إِبْرَاهِيمَ عَنِ ابْنِ سِيرِينَ عَنْ أَيُّوبَ عَنْ حَكِيمِ بْنِ حِزَامٍ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ عَنْ يُوسُفَ بْنِ مَاهَكَ وَرِوَايَةُ عَبْدِ الصَّمَدِ أَصَحُّ ‏.‏ وَقَدْ رَوَى يَحْيَى بْنُ أَبِي كَثِيرٍ هَذَا الْحَدِيثَ عَنْ يَعْلَى بْنِ حَكِيمٍ عَنْ يُوسُفَ بْنِ مَاهَكَ عَنْ عَبْدِ اللَّهِ بْنِ عِصْمَةَ عَنْ حَكِيمِ بْنِ حِزَامٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ كَرِهُوا أَنْ يَبِيعَ الرَّجُلُ مَا لَيْسَ عِنْدَهُ ‏.‏\hadithno{1235}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hakim b. Hizam: "The Messenger of Allah (ﷺ) prohibited me from selling what was not with me." [Abu 'Eisa said:] Waki' reported this Hadith from Yazid bin Ibrahim, from Ibn Sirin, from Ayyub, from Hakim bin Hizam, and he did not mention in it: "From Yusuf bin Mahak." And the narration of 'Abdus-Samad (a narrator in the chain of Hadith no. 1235) is more correct. Yahya bin Abi Kathir reported this Hadith from Ya'la bin Hakim, from Yusuf bin Mahak, from 'Abdullah bin 'Ismah, from Hakim bin Hizam, from the Prophet (ﷺ). This Hadith is acted upon according to most of the people of knowledge, they dislike for a man to sell what is not with him}}
\hadithdefcmd{tirmidhi}{1236}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا سُفْيَانُ، وَشُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْوَلاَءِ وَهِبَتِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَقَدْ رَوَى يَحْيَى بْنُ سُلَيْمٍ هَذَا الْحَدِيثَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ بَيْعِ الْوَلاَءِ وَهِبَتِهِ ‏.‏ وَهُوَ وَهَمٌ وَهِمَ فِيهِ يَحْيَى بْنُ سُلَيْمٍ ‏.‏ وَرَوَى عَبْدُ الْوَهَّابِ الثَّقَفِيُّ وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ وَغَيْرُ وَاحِدٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ يَحْيَى بْنِ سُلَيْمٍ ‏.‏\hadithno{1236}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: "The Messenger of Allah (ﷺ) prohibited selling the Wala' and conferring it." [Abu 'Eisa said:] This Hadith is Hasan Sahih. We do not know of it except as a narration of 'Abdullah bin Dinar, from Ibn 'Umar. This Hadith is acted upon according to the people of knowledge. Yahya bin Sulaim reported this Hadith from 'Ubaidullah bin 'Umar, from Nafi' from Ibn 'Umar from the Prophet (ﷺ), saying "That he prohibited selling the Wala' and conferring it." But this is mistake from Yahya bin Sulaim. Because 'Abdul Wahhab Ath-Thaqafi, 'Abdullah bin Numair and others reported it from 'Ubaidullah bin 'Umar, from Ibn 'Umar, from the Prophet (ﷺ). And this is more correct than the narration of Yahya bin Sulaim}}
\hadithdefcmd{tirmidhi}{1237}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ مُثَنَّى حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْحَيَوَانِ بِالْحَيَوَانِ نَسِيئَةً ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَجَابِرٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَمُرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَسَمَاعُ الْحَسَنِ مِنْ سَمُرَةَ صَحِيحٌ هَكَذَا قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ وَغَيْرُهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي بَيْعِ الْحَيَوَانِ بِالْحَيَوَانِ نَسِيئَةً وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَبِهِ يَقُولُ أَحْمَدُ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي بَيْعِ الْحَيَوَانِ بِالْحَيَوَانِ نَسِيئَةً وَهُوَ قَوْلُ الشَّافِعِيِّ وَإِسْحَاقَ ‏.‏\hadithno{1237}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Samurah: "The Messenger of Allah (ﷺ) prohibited bartering animals on credit." He said: There are narration on this topic from Ibn 'Abbas, Jabir, Ibn 'Umar. [Abu 'Eisa said:] The Hadith of Samurah is Hasan Sahih Hadith. It is correct that Al-Hasan heard from Samurah, this is what 'Ali bin Al-Madini and others said. Regarding (the prohibition of) bartering animals on credit, this is acted upon according to most of the people of knowledge among the Companions of the Prophet (ﷺ) and others. This is the view of Sufyan Ath-Thawri and the people of Al-Kufah, and it is the view of Ahmad. Some of the people of knowledge, among the Companions of the Prophet (ﷺ) and others, permitted bartering animals for animals on credit. This is the view of Ash-Shafi'i and Ishaq}}
\hadithdefcmd{tirmidhi}{1238}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنِ الْحَجَّاجِ، وَهُوَ ابْنُ أَرْطَاةَ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْحَيَوَانُ اثْنَانِ بِوَاحِدٍ لاَ يَصْلُحُ نَسِيئًا وَلاَ بَأْسَ بِهِ يَدًا بِيَدٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1238}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir: That the Messenger of Allah (ﷺ) said: "Animals [two for one] are not proper on credit, and there is no harm in a hand to hand (exchange)." The Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1239}{حَدَّثَنَا قُتَيْبَةُ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جَاءَ عَبْدٌ فَبَايَعَ النَّبِيَّ صلى الله عليه وسلم عَلَى الْهِجْرَةِ وَلاَ يَشْعُرُ النَّبِيُّ صلى الله عليه وسلم أَنَّهُ عَبْدٌ فَجَاءَ سَيِّدُهُ يُرِيدُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بِعْنِيهِ ‏"‏ ‏.‏ فَاشْتَرَاهُ بِعَبْدَيْنِ أَسْوَدَيْنِ ثُمَّ لَمْ يُبَايِعْ أَحَدًا بَعْدُ حَتَّى يَسْأَلَهُ أَعَبْدٌ هُوَ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ لاَ بَأْسَ بِعَبْدٍ بِعَبْدَيْنِ يَدًا بِيَدٍ ‏.‏ وَاخْتَلَفُوا فِيهِ إِذَا كَانَ نَسِيئًا ‏.‏\hadithno{1239}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir: "A slave came to give the pledge to the Prophet (ﷺ) for Hijrah, but the Prophet (ﷺ) did not realize that he was a slave. So his master came to get him and the Prophet (ﷺ) said: 'Sell him to me.' So he purchased him for two black slaves. Then he would not pledge from anyone until he asked him if he was a slave." [He said:] There is something on this topic from Anas. [Abu 'Eisa said:] The Hadith of Jabir is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge. There is no harm in a slave for two slaves in hand to hand exchange, but they differ when it is on credit}}
\hadithdefcmd{tirmidhi}{1240}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا سُفْيَانُ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الذَّهَبُ بِالذَّهَبِ مِثْلاً بِمِثْلٍ وَالْفِضَّةُ بِالْفِضَّةِ مِثْلاً بِمِثْلٍ وَالتَّمْرُ بِالتَّمْرِ مِثْلاً بِمِثْلٍ وَالْبُرُّ بِالْبُرِّ مِثْلاً بِمِثْلٍ وَالْمِلْحُ بِالْمِلْحِ مِثْلاً بِمِثْلٍ وَالشَّعِيرُ بِالشَّعِيرِ مِثْلاً بِمِثْلٍ فَمَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى بِيعُوا الذَّهَبَ بِالْفِضَّةِ كَيْفَ شِئْتُمْ يَدًا بِيَدٍ وَبِيعُوا الْبُرَّ بِالتَّمْرِ كَيْفَ شِئْتُمْ يَدًا بِيَدٍ وَبِيعُوا الشَّعِيرَ بِالتَّمْرِ كَيْفَ شِئْتُمْ يَدًا بِيَدٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَبِلاَلٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُبَادَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ خَالِدٍ بِهَذَا الإِسْنَادِ وَقَالَ ‏"‏ بِيعُوا الْبُرَّ بِالشَّعِيرِ كَيْفَ شِئْتُمْ يَدًا بِيَدٍ ‏"‏ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ خَالِدٍ عَنْ أَبِي قِلاَبَةَ عَنْ أَبِي الأَشْعَثِ عَنْ عُبَادَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم الْحَدِيثَ وَزَادَ فِيهِ قَالَ خَالِدٌ قَالَ أَبُو قِلاَبَةَ ‏"‏ بِيعُوا الْبُرَّ بِالشَّعِيرِ كَيْفَ شِئْتُمْ ‏"‏ فَذَكَرَ الْحَدِيثَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ أَنْ يُبَاعَ الْبُرُّ بِالْبُرِّ إِلاَّ مِثْلاً بِمِثْلٍ وَالشَّعِيرُ بِالشَّعِيرِ إِلاَّ مِثْلاً بِمِثْلٍ فَإِذَا اخْتَلَفَ الأَصْنَافُ فَلاَ بَأْسَ أَنْ يُبَاعَ مُتَفَاضِلاً إِذَا كَانَ يَدًا بِيَدٍ ‏.‏ وَهَذَا قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ الشَّافِعِيُّ وَالْحُجَّةُ فِي ذَلِكَ قَوْلُ النَّبِيِّ صلى الله عليه وسلم ‏"‏ بِيعُوا الشَّعِيرَ بِالْبُرِّ كَيْفَ شِئْتُمْ يَدًا بِيَدٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ أَنْ تُبَاعَ الْحِنْطَةُ بِالشَّعِيرِ إِلاَّ مِثْلاً بِمِثْلٍ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1240}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Ubadah bin As-Samit: That the Prophet (ﷺ) said: "Gold for gold, kind for kind; silver for silver, kind for kind; dried-dates for dried-dates, kind for kind; wheat for wheat, kind for kind; salt for salt, kind for kind; and barley for barley, kind for kind. Whoever increases or seeks an increase, then he dealt with Riba. Sell gold for silver as you wish, hand to hand; and sell wheat for dried-dates as you wish, hand to hand; and sell barley for dried-dates as you wish, hand to hand." [He said:] There are narrations on this topic from Abu Sa'eed, Abu Hurairah, Bilal, And Anas. [Abu 'Eisa said:] The Hadith of 'Ubadah bin As-Samit is Hasan Sahih. Some of them reported this Hadith from Khalid, with this chain, and he said: "Sell wheat for barley as you wish, hand to hand." Some of them reported this Hadith from Khalid, from Abu Qilabah, from Ash'ath, from 'Ubadah from the Prophet (ﷺ). In that Hadith, they added that Khalid said: "Abu Qilabah said: "Sell wheat for barley as you wish, hand to hand." This Hadith is acted upon according to the people of knowledge, they do not think that one may sell wheat for wheat except when it is the same kind for the same kind, and (the same for) barely in exchange for barley, kind for kind. When the items are themselves different, then there is no harm in one being more than the other if it is hand to hand. This is saying of most of the people of knowledge among the Companions of the Prophet (ﷺ) and others. It is the view of Sufyan Ath-Thawri, Ash-Shafi'i, Ahmad, and Ishaq. Ash-Shafi'i said: "And the proof for that is the saying of the Prophet (ﷺ): 'Sell barley for wheat as you wish, hand to hand.'" [Abu 'Eisa said:] Some of the people of knowledge considered it disliked that wheat be sold for barely unless it was kind for kind. This is the view of Malik bin Anas, but the first view is more correct}}
\hadithdefcmd{tirmidhi}{1241}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، أَخْبَرَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا شَيْبَانُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ نَافِعٍ، قَالَ انْطَلَقْتُ أَنَا وَابْنُ، عُمَرَ إِلَى أَبِي سَعِيدٍ فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعَتْهُ أُذُنَاىَ هَاتَانِ يَقُولُ ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ إِلاَّ مِثْلاً بِمِثْلٍ وَالْفِضَّةَ بِالْفِضَّةِ إِلاَّ مِثْلاً بِمِثْلٍ لاَ يُشَفُّ بَعْضُهُ عَلَى بَعْضٍ وَلاَ تَبِيعُوا مِنْهُ غَائِبًا بِنَاجِزٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ وَأَبِي هُرَيْرَةَ وَهِشَامِ بْنِ عَامِرٍ وَالْبَرَاءِ وَزَيْدِ بْنِ أَرْقَمَ وَفَضَالَةَ بْنِ عُبَيْدٍ وَأَبِي بَكْرَةَ وَابْنِ عُمَرَ وَأَبِي الدَّرْدَاءِ وَبِلاَلٍ ‏.‏ قَالَ وَحَدِيثُ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرِّبَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِلاَّ مَا رُوِيَ عَنِ ابْنِ عَبَّاسٍ أَنَّهُ كَانَ لاَ يَرَى بَأْسًا أَنْ يُبَاعَ الذَّهَبُ بِالذَّهَبِ مُتَفَاضِلاً وَالْفِضَّةُ بِالْفِضَّةِ مُتَفَاضِلاً إِذَا كَانَ يَدًا بِيَدٍ ‏.‏ وَقَالَ إِنَّمَا الرِّبَا فِي النَّسِيئَةِ ‏.‏ وَكَذَلِكَ رُوِيَ عَنْ بَعْضِ أَصْحَابِهِ شَيْءٌ مِنْ هَذَا وَقَدْ رُوِيَ عَنِ ابْنِ عَبَّاسٍ أَنَّهُ رَجَعَ عَنْ قَوْلِهِ حِينَ حَدَّثَهُ أَبُو سَعِيدٍ الْخُدْرِيُّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَرُوِيَ عَنِ ابْنِ الْمُبَارَكِ أَنَّهُ قَالَ لَيْسَ فِي الصَّرْفِ اخْتِلاَفٌ ‏.‏\hadithno{1241}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Nafi': "Ibn 'Umar and I went to Abu Sa'eed and he narrated to us: 'the Messenger of Allah (ﷺ) said - and I heard him with these [two] ears: "Do not sell gold for gold except kind for kind, nor sliver for silver except kind for kind, do not exchange more of one than the other, and do not sell what is not present from them for what is present." [Abu 'Eisa said:] There are narrations on this topic from Abu Bakr, 'Umar, 'Uthman, Abu Hurairah, Hisham bin 'Amir, Al-Bara', Zaid bin Arqam, Fadalah bin 'Ubaid, Abu Bakrah, Ibn 'Umar, Abu Ad-Darda', and Bilal. [He said:] The Hadith of Abu Sa'eed, from the Prophet (ﷺ) [about Riba] is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge among the Companions of the Prophet (ﷺ) and others, except for what has been related from Ibn 'Abbas; he did not see any harm in exchanging gold for gold or silver for silver, more for less, when it is done hand in hand, and he said: "Riba' is only in credit." Similar it has been related from some of his companions. It has been related that Ibn 'Abbas changed his opinion when Abu Sa'eed narrated it to him from the Prophet (ﷺ). The first view is more correct. And this is acted upon according to the people of knowledge [among the Companions of the Prophet (ﷺ) and others]. It is the view of Sufyan Ath-Thawri, Ibn Al-Mubarak, Ash-Shafi'i, Ahmad, and Ishaq. It has been reported that Ibn Al-Mubarak said: "There is no difference over exchange}}
\hadithdefcmd{tirmidhi}{1242}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنْتُ أَبِيعُ الإِبِلَ بِالْبَقِيعِ فَأَبِيعُ بِالدَّنَانِيرِ فَآخُذُ مَكَانَهَا الْوَرِقَ وَأَبِيعُ بِالْوَرِقِ فَآخُذُ مَكَانَهَا الدَّنَانِيرَ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَوَجَدْتُهُ خَارِجًا مِنْ بَيْتِ حَفْصَةَ فَسَأَلْتُهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ لاَ بَأْسَ بِهِ بِالْقِيمَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ سِمَاكِ بْنِ حَرْبٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَرَوَى دَاوُدُ بْنُ أَبِي هِنْدٍ هَذَا الْحَدِيثَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عُمَرَ مَوْقُوفًا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ أَنْ لاَ بَأْسَ أَنْ يَقْتَضِيَ الذَّهَبَ مِنَ الْوَرِقِ وَالْوَرِقَ مِنَ الذَّهَبِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ذَلِكَ ‏.‏\hadithno{1242}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Umar: "I would sell camels at Al-Baqi', so I would sell them for Dinar but take in place of them Dirham, and, I would sell for silver and take Dinar in its place. So I went to the Messenger of Allah (ﷺ) and found him leaving the house of Hafsah. I asked him about that and he said: 'There is no harm in that when it (equals) the price.'" [Abu 'Eisa said:] We do not know of this Hadith being Marfu' except from the narration of Simak bin Harb from Sa'eed bin Jubair, from Ibn 'Umar. Dawud bin Abi Hind narrated this Hadith from Abu Sa'eed bin Jubair, from Ibn 'Umar in Mawquf form. This is acted upon according to some of the people of knowledge. There is no harm in paying for gold with silver and silver with gold. This is the view of Ahmad and Ishaq. Some of the people of knowledge, among the Companions and others, disliked that}}
\hadithdefcmd{tirmidhi}{1243}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، أَنَّهُ قَالَ أَقْبَلْتُ أَقُولُ مَنْ يَصْطَرِفُ الدَّرَاهِمَ فَقَالَ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ وَهُوَ عِنْدَ عُمَرَ بْنِ الْخَطَّابِ أَرِنَا ذَهَبَكَ ثُمَّ ائْتِنَا إِذَا جَاءَ خَادِمُنَا نُعْطِكَ وَرِقَكَ ‏.‏ فَقَالَ عُمَرُ كَلاَّ وَاللَّهِ لَتُعْطِيَنَّهُ وَرِقَهُ أَوْ لَتَرُدَّنَّ إِلَيْهِ ذَهَبَهُ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْوَرِقُ بِالذَّهَبِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالْبُرُّ بِالْبُرِّ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالشَّعِيرُ بِالشَّعِيرِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالتَّمْرُ بِالتَّمْرِ رِبًا إِلاَّ هَاءَ وَهَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ إِلاَّ هَاءَ وَهَاءَ ‏"‏ يَقُولُ يَدًا بِيَدٍ ‏.‏\hadithno{1243}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn Shihab: From Malik bin Aws bin Hadathan that he said: "I once said: 'Who can change some Dirham?' So Talhah bin 'Ubaidullah - and he was with 'Umar bin Al-Khattab - said: "Leave your gold with us, then return to us when our servant comes and we will give you your silver." 'Umar bin Al-Khattab said: "No! By Allah! Either give him his silver or return his gold to him. Indeed the Messenger of Allah (ﷺ) said: 'Silver for gold is Riba, except for hand to hand; and wheat for wheat is Riba except for hand to hand; and barley for barley is Riba except hand to hand; and dried-dates for dried-dates is Riba except for hand to hand.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih. This is acted upon according to the people of knowledge. And the meaning of Ha' Wa Ha' is hand to hand}}
\hadithdefcmd{tirmidhi}{1244}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنِ ابْتَاعَ نَخْلاً بَعْدَ أَنْ تُؤَبَّرَ فَثَمَرَتُهَا لِلَّذِي بَاعَهَا إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ وَمَنِ ابْتَاعَ عَبْدًا وَلَهُ مَالٌ فَمَالُهُ لِلَّذِي بَاعَهُ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ وَحَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ هَكَذَا رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنِ ابْتَاعَ نَخْلاً بَعْدَ أَنْ تُؤَبَّرَ فَثَمَرَتُهَا لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ وَمَنْ بَاعَ عَبْدًا وَلَهُ مَالٌ فَمَالُهُ لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏ وَقَدْ رُوِيَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ ابْتَاعَ نَخْلاً قَدْ أُبِّرَتْ فَثَمَرَتُهَا لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏ وَقَدْ رُوِيَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنْ عُمَرَ أَنَّهُ قَالَ مَنْ بَاعَ عَبْدًا وَلَهُ مَالٌ فَمَالُهُ لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏.‏ هَكَذَا رَوَى عُبَيْدُ اللَّهِ بْنُ عُمَرَ وَغَيْرُهُ عَنْ نَافِعٍ الْحَدِيثَيْنِ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا ‏.‏ وَرَوَى عِكْرِمَةُ بْنُ خَالِدٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ سَالِمٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ حَدِيثُ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَصَحُّ مَا جَاءَ فِي هَذَا الْبَابِ ‏.‏\hadithno{1244}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Salim: From his father that the Messenger of Allah (ﷺ) said: 'Whoever purchases a date-palm after it has been pollinated then its fruits are for the one who sold it, unless the buyer made it a condition. And whoever purchases slave who has property, then his property is for the one who sold him, unless the buyer made it a condition." [He said:] There is something on this topic from Jabir. The Hadith of Ibn 'Umar is a Hasan Sahih Hadith. Similarly, it has been reported by more than one route from Az-Zuhri, from Salim, from Ibn 'Umar, that the Prophet (ﷺ) "Whoever purchases a date-palm after it has been pollinated, then its fruits are for seller, unless the buyer made it a condition. And whoever purchases a slave who has property, then his property is for the seller, unless the buyer made it a condition." And it has been reported from Nafi', from Ibn 'Umar, that the Prophet (ﷺ) said: "Whoever purchases a date-palm that has been pollinated, then its fruits are for the seller, unless the buyer made it a condition." It has been reported from Nafi', from Ibn 'Umar, from 'Umar, that he (ﷺ) said: "Whoever sold a slave who has property, his property is for the seller, unless the buyer made it a condition." This is how the two Ahadith were reported by 'Ubaidullah bin 'Umar and others from Nafi'. Some of them have also reported this Hadith from Nafi', from Ibn 'Umar, from the Prophet (ﷺ). 'Ikrimah bin Khalid reported similar to the Hadith of Salim, from Ibn 'Umar, from the Prophet (ﷺ). This Hadith is acted upon according to some of the people of knowledge. It is the view of Ash-Shafi'i, Ahmad, and Ishaq. Muhammad bin Isma'il said: "The Hadith of Az-Zuhri from Salim, from his father, from the Prophet (ﷺ) is the most correct [of what has been reported on this topic]}}
\hadithdefcmd{tirmidhi}{1245}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الْكُوفِيُّ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا أَوْ يَخْتَارَا ‏"‏ ‏.‏ قَالَ فَكَانَ ابْنُ عُمَرَ إِذَا ابْتَاعَ بَيْعًا وَهُوَ قَاعِدٌ قَامَ لِيَجِبَ لَهُ الْبَيْعُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَاب عَنْ أَبِي بَرْزَةَ وَحَكِيمِ بْنِ حِزَامٍ وَعَبْدِ اللَّهِ بْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَسَمُرَةَ وَأَبِي هُرَيْرَةَ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ وَغَيْرِهِمْ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَقَ وَقَالُوا الْفُرْقَةُ بِالْأَبْدَانِ لَا بِالْكَلَامِ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ مَعْنَى قَوْلِ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ مَا لَمْ يَتَفَرَّقَا يَعْنِي الْفُرْقَةَ بِالْكَلَامِ وَالْقَوْلُ الْأَوَّلُ أَصَحُّ لِأَنَّ ابْنَ عُمَرَ هُوَ رَوَى عَنْ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ وَهُوَ أَعْلَمُ بِمَعْنَى مَا رَوَى وَرُوِيَ عَنْهُ أَنَّهُ كَانَ إِذَا أَرَادَ أَنْ يُوجِبَ الْبَيْعَ مَشَى لِيَجِبَ لَهُ وَهَكَذَا رُوِيَ عَنْ أَبِي بَرْزَةَ الْأَسْلَمِيِّ\hadithno{1245}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Nafi': From Ibn 'Umar, that the Messenger of Allah (ﷺ) said: "Both the buyer and the seller retain the option as long as they have not separated or they give each other than option." He (Nafi') said: "So when Ibn 'Umar purchased something while he was sitting, he would stand to complete the sale}}
\hadithdefcmd{tirmidhi}{1246}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا فَإِنْ صَدَقَا وَبَيَّنَا بُورِكَ لَهُمَا فِي بَيْعِهِمَا وَإِنْ كَتَمَا وَكَذَبَا مُحِقَتْ بَرَكَةُ بَيْعِهِمَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي بَرْزَةَ وَحَكِيمِ بْنِ حِزَامٍ وَعَبْدِ اللَّهِ بْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَسَمُرَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ وَقَالُوا الْفُرْقَةُ بِالأَبْدَانِ لاَ بِالْكَلاَمِ ‏.‏ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ مَعْنَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ مَا لَمْ يَتَفَرَّقَا ‏"‏ ‏.‏ يَعْنِي الْفُرْقَةَ بِالْكَلاَمِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ لأَنَّ ابْنَ عُمَرَ هُوَ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ أَعْلَمُ بِمَعْنَى مَا رَوَى وَرُوِيَ عَنْهُ أَنَّهُ كَانَ إِذَا أَرَادَ أَنْ يُوجِبَ الْبَيْعَ مَشَى لِيَجِبَ لَهُ ‏.‏ وَهَكَذَا رُوِيَ عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَيْهِ فِي فَرَسٍ بَعْدَ مَا تَبَايَعَا ‏.‏ وَكَانُوا فِي سَفِينَةٍ فَقَالَ لاَ أَرَاكُمَا افْتَرَقْتُمَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا ‏"‏ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ إِلَى أَنَّ الْفُرْقَةَ بِالْكَلاَمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَهَكَذَا رُوِيَ عَنْ مَالِكِ بْنِ أَنَسٍ ‏.‏ وَرُوِيَ عَنِ ابْنِ الْمُبَارَكِ أَنَّهُ قَالَ كَيْفَ أَرُدُّ هَذَا وَالْحَدِيثُ فِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم صَحِيحٌ ‏.‏ وَقَوَّى هَذَا الْمَذْهَبَ ‏.‏ وَمَعْنَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏ مَعْنَاهُ أَنْ يُخَيِّرَ الْبَائِعُ الْمُشْتَرِيَ بَعْدَ إِيجَابِ الْبَيْعِ فَإِذَا خَيَّرَهُ فَاخْتَارَ الْبَيْعَ فَلَيْسَ لَهُ خِيَارٌ بَعْدَ ذَلِكَ فِي فَسْخِ الْبَيْعِ وَإِنْ لَمْ يَتَفَرَّقَا ‏.‏ هَكَذَا فَسَّرَهُ الشَّافِعِيُّ وَغَيْرُهُ ‏.‏ وَمِمَّا يُقَوِّي قَوْلَ مَنْ يَقُولُ الْفُرْقَةُ بِالأَبْدَانِ لاَ بِالْكَلاَمِ حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1246}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Hakim b. Hizam: That the Messenger of Allah (ﷺ) said: "Both the buyer and the seller retain the option as long as they have not separated. If they spoke the truth and clarified (any defects or conditions), then they would be blessed in their sale, and if they hid something and lied then their sale would be deprived of blessings." And this is a Sahih Hadith. This is how it was reported from Abu Barzah Al-Aslami, that two men came disputing to him after the sale of a horse, and they were on a ship, so he said: "I did not see the two of your separate, and the Messenger of Allah (ﷺ) said: 'The buyer and the seller retain the choice as long as they did not separate.'" Some of the people of knowledge, among the people of Al-Kufah and others, held the view that the separation refers to speech. This is the saying of [Sufyan] Ath-Thawri. This has been reported from Malik bin Anas, and it has been reported from Ibn al-Mubarak that he said: "How could this be refuted ?" And the Hadith about it from the Prophet (ﷺ) is Sahih, and it strenghtens this view. And the meaning of the saying of the Prophet (ﷺ): "Except for the optional sale" is, that (while they are still together) the seller gives the buyer the option to cancel after the conclusion of the sale. If he chooses to agree to the sale, then he does not have the choice to cancel the sale after then, even if they did not separate. This is how Ash-Shafi'i and others explained it. And what strenghtens the view of those who said that the separation refers to them parting, (and) it does not refer to speech, is the (following) Hadith of 'Abdullah bin 'Amr from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1247}{أَخْبَرَنَا بِذَلِكَ، قُتَيْبَةُ بْنُ سَعِيدٍ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا إِلاَّ أَنْ تَكُونَ صَفْقَةَ خِيَارٍ وَلاَ يَحِلُّ لَهُ أَنْ يُفَارِقَ صَاحِبَهُ خَشْيَةَ أَنْ يَسْتَقِيلَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَمَعْنَى هَذَا أَنْ يُفَارِقَهُ بَعْدَ الْبَيْعِ خَشْيَةَ أَنْ يَسْتَقِيلَهُ وَلَوْ كَانَتِ الْفُرْقَةُ بِالْكَلاَمِ وَلَمْ يَكُنْ لَهُ خِيَارٌ بَعْدَ الْبَيْعِ لَمْ يَكُنْ لِهَذَا الْحَدِيثِ مَعْنًى حَيْثُ قَالَ صلى الله عليه وسلم ‏"‏ وَلاَ يَحِلُّ لَهُ أَنْ يُفَارِقَهُ خَشْيَةَ أَنْ يَسْتَقِيلَهُ ‏"‏ ‏.‏\hadithno{1247}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib: From his father, from his grandfather, that the Messenger of Allah (ﷺ) said: "Both the buyer and the seller retain the option as long as they did not separate, unless they agreed to making it optional. And it is not lawful for him to separate from his companion, fearing that he will change his mind." [Abu 'Eisa said:] This Hadith is Hasan and this means separating from him after the sale, fearing that he will change his mind. And if the separation referred to speech, and there was no option left for him after the sale, then this Hadith would be meaningless, since he (ﷺ) said: "And it is not lawful for him to separate from his companion, fearing that he will change his mind}}
\hadithdefcmd{tirmidhi}{1248}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَهُوَ الْبَجَلِيُّ الْكُوفِيُّ قَالَ سَمِعْتُ أَبَا زُرْعَةَ بْنَ عَمْرِو بْنِ جَرِيرٍ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَفَرَّقَنَّ عَنْ بَيْعٍ إِلاَّ عَنْ تَرَاضٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{1248}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: That the Prophet (ﷺ) said: "They (the two) are not separate from a sale except in agreement. [Abu 'Eisa said:] This Hadith is Gharib}}
\hadithdefcmd{tirmidhi}{1249}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ الشَّيْبَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَيَّرَ أَعْرَابِيًّا بَعْدَ الْبَيْعِ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1249}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir: "The Prophet (ﷺ) gave a Bedouin the option after a sale." This Hadith is Hasan Gharib}}
\hadithdefcmd{tirmidhi}{1250}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، كَانَ فِي عُقْدَتِهِ ضَعْفٌ وَكَانَ يُبَايِعُ وَأَنَّ أَهْلَهُ أَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ احْجُرْ عَلَيْهِ ‏.‏ فَدَعَاهُ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَنَهَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي لاَ أَصْبِرُ عَنِ الْبَيْعِ ‏.‏ فَقَالَ ‏ "‏ إِذَا بَايَعْتَ فَقُلْ هَاءَ وَهَاءَ وَلاَ خِلاَبَةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ وَحَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَقَالُوا يُحْجَرُ عَلَى الرَّجُلِ الْحُرِّ فِي الْبَيْعِ وَالشِّرَاءِ إِذَا كَانَ ضَعِيفَ الْعَقْلِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَلَمْ يَرَ بَعْضُهُمْ أَنْ يُحْجَرَ عَلَى الْحُرِّ الْبَالِغِ ‏.‏\hadithno{1250}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas: That there was a man who was not very sensible and he would make purchases. So his family came to the Prophet (ﷺ) and said: "O Messenger of Allah! Stop him (from making purchases)." So Allah's Prophet (ﷺ) called him to prohibit him, and he said: "O Messenger of Allah! I have no patience for business." So he said: "When you are buying, say: 'Hand to hand, and no cheating.'" [Abu 'Eisa said:] There is a narration on this topic from Ibn 'Umar. The Hadith of Anas is a Hasan Sahih Gharib Hadith. This is acted upon according to the people of knowledge. They say that the free man can be prevented from selling and buying when his intellect is weak. This is the view of Ahmad and Ishaq. Some of the scholars did not think that the free person who had attained the age of responsibility could be prevented from that}}
\hadithdefcmd{tirmidhi}{1251}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنِ اشْتَرَى مُصَرَّاةً فَهُوَ بِالْخِيَارِ إِذَا حَلَبَهَا إِنْ شَاءَ رَدَّهَا وَرَدَّ مَعَهَا صَاعًا مِنْ تَمْرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ وَرَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1251}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah: That the Prophet (ﷺ) said: "Whoever purchased an animal that has not been milked, then he the choice when he milks it, if he wishes he may return it, returning a Sa' of dried dates along with it." [Abu 'Eisa said:] There are narration on this topic from Anas, and a man from the Companions of the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1252}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اشْتَرَى مُصَرَّاةً فَهُوَ بِالْخِيَارِ ثَلاَثَةَ أَيَّامٍ فَإِنْ رَدَّهَا رَدَّ مَعَهَا صَاعًا مِنْ طَعَامٍ لاَ سَمْرَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَصْحَابِنَا مِنْهُمُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ لاَ سَمْرَاءَ ‏"‏ ‏.‏ يَعْنِي لاَ بُرَّ ‏.‏\hadithno{1252}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah: That the Prophet (ﷺ) said: "Whoever purchases an animal that has not been milked, then he retains the option for three days. If he returns it, then he is to return with it a Sa' of food, not Samra' " [Abu 'Eisa said:] The meaning of "Not Samra'" is "not wheat." This Hadith is Hasan Sahih. This Hadith is acted upon according to our companions, among them Ash-Shafi'i, Ahmad, and Ishaq}}
\hadithdefcmd{tirmidhi}{1253}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا وَكِيعٌ، عَنْ زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ بَاعَ مِنَ النَّبِيِّ صلى الله عليه وسلم بَعِيرًا وَاشْتَرَطَ ظَهْرَهُ إِلَى أَهْلِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ يَرَوْنَ الشَّرْطَ فِي الْبَيْعِ جَائِزًا إِذَا كَانَ شَرْطًا وَاحِدًا ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يَجُوزُ الشَّرْطُ فِي الْبَيْعِ وَلاَ يَتِمُّ الْبَيْعُ إِذَا كَانَ فِيهِ شَرْطٌ ‏.‏\hadithno{1253}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir bin ‘Abdullah : That he sold a camel to the Prophet (ﷺ) and made a condition that he could ride it to (return to) his family. [Abu 'Eisa said:] This Hadith is Hasan Sahih. It has been reported through other routes from Jabir. This is acted upon according to some of the people of knowledge among the Companions of the Prophet (ﷺ) and others. They consider it allowed to make a condition in a sale when it is one condition. This is the view of Ahmad and Ishaq. Some of the people of knowledge said that it is not allowed to make a condition in a sale, nor to complete a sale when there is a condition for it}}
\hadithdefcmd{tirmidhi}{1254}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَيُوسُفُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ زَكَرِيَّا، عَنْ عَامِرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الظَّهْرُ يُرْكَبُ إِذَا كَانَ مَرْهُونًا وَلَبَنُ الدَّرِّ يُشْرَبُ إِذَا كَانَ مَرْهُونًا وَعَلَى الَّذِي يَرْكَبُ وَيَشْرَبُ نَفَقَتُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ عَامِرٍ الشَّعْبِيِّ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ مَوْقُوفًا ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لَيْسَ لَهُ أَنْ يَنْتَفِعَ مِنَ الرَّهْنِ بِشَيْءٍ ‏.‏\hadithno{1254}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ): "A riding animal can be ridden while it is pawned, and a milking animal can be milked while it is pawned, and it is up to the one riding and drinking (the milk) to maintain it." [Abu 'Eisa said:] This Hadith is Hasan Sahih. We do now know of it being Marfu' except by the narration of 'Amir Ash-Sha'bi from Abu Hurairah. Others have reported this Hadith from Al-A'mash, from Abu Salih, from Abu Hurairah in Mawquf form. This is acted upon according to some of the people of knowledge, and it is the view of Ahmad and Ishaq. Some of the people of knowledge said that one may not benefit in any way from what is pawned}}
\hadithdefcmd{tirmidhi}{1255}{\hadithno{1255}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1256}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ، بَرِيرَةَ فَاشْتَرَطُوا الْوَلاَءَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اشْتَرِيهَا فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْطَى الثَّمَنَ أَوْ لِمَنْ وَلِيَ النِّعْمَةَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ قَالَ وَمَنْصُورُ بْنُ الْمُعْتَمِرِ يُكْنَى أَبَا عَتَّابٍ ‏.‏ حَدَّثَنَا أَبُو بَكْرٍ الْعَطَّارُ الْبَصْرِيُّ عَنْ عَلِيِّ بْنِ الْمَدِينِيِّ قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ يَقُولُ إِذَا حُدِّثْتَ عَنْ مَنْصُورٍ فَقَدْ مَلأْتَ يَدَكَ مِنَ الْخَيْرِ لاَ تُرِدْ غَيْرَهُ ‏.‏ ثُمَّ قَالَ يَحْيَى مَا أَجِدُ فِي إِبْرَاهِيمَ النَّخَعِيِّ وَمُجَاهِدٍ أَثْبَتَ مِنْ مَنْصُورٍ ‏.‏ قَالَ وَأَخْبَرَنِي مُحَمَّدٌ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الأَسْوَدِ قَالَ قَالَ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ مَنْصُورٌ أَثْبَتُ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{1256}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Al-Aswad: From 'Aishah that she wanted to purchase Barirah, but they (he owners) made the condition that they would retain the Wala'. So the Prophet (ﷺ) said: "Buy her, the Wala' is only for the one who gives the price, or for the one who grants the favor." [He said:] There is something on this topic from Ibn 'Umar. [Abu 'Eisa said:] The Hadith of 'Aishah is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge. And Mansur bin Al-Mu'tamir's Kunyah is Abu 'Attab. Abu Bakr Al-'Attar Al-Basri narrated to us from 'Ali bin Al-Madini who said: "I heard Yahya bin Sa'eed saying: 'When you get a narration from Mansur, then your hand has been filled with goodness without needing others.' Then Yahya said: 'I did not find anyone more reliable in (narrating from) Ibrahim An-Nakha'i and Mujahid than Mansur." [He said:] Muhammad informed me from 'Abdullah bin Abi Al-Aswad who said: " 'Abdur-Rahman bin Mahdi said: 'Mansur is the most reliable of the people of Al-Kufah}}
\hadithdefcmd{tirmidhi}{1257}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حُصَيْنٍ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ حَكِيمِ بْنِ حِزَامٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ حَكِيمَ بْنَ حِزَامٍ يَشْتَرِي لَهُ أُضْحِيَّةً بِدِينَارٍ فَاشْتَرَى أُضْحِيَّةً فَأُرْبِحَ فِيهَا دِينَارًا فَاشْتَرَى أُخْرَى مَكَانَهَا فَجَاءَ بِالأُضْحِيَّةِ وَالدِّينَارِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ ضَحِّ بِالشَّاةِ وَتَصَدَّقْ بِالدِّينَارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ حَكِيمِ بْنِ حِزَامٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَحَبِيبُ بْنُ أَبِي ثَابِتٍ لَمْ يَسْمَعْ عِنْدِي مِنْ حَكِيمِ بْنِ حِزَامٍ ‏.‏\hadithno{1257}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Habib bin Abi Thabit: From Hakim bin Hizam, that the Messenger of Allah (ﷺ) sent Hakim bin Hizam with a Dinar to buy an animal for Udhiyyah (an animal for sacrifice) for him. He purchases an Udhiyyah which he sold and profited a Dinar from, so he purchased another in its place. And he returned to the Messenger of Allah (ﷺ) with Udhiyyah and the Dinar, so he said: 'The sheep is for sacrifice and Dinar is for charity.'" [Abu 'Eisa said:] We do not know of the Hadith of Hakim bin Hizam except through this route, and Habib bin Abi Thabit did not hear from Hakim bin Hizam - in my view}}
\hadithdefcmd{tirmidhi}{1258}{\hadithno{1258}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1259}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْبَزَّازُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَصَابَ الْمُكَاتَبُ حَدًّا أَوْ مِيرَاثًا وَرِثَ بِحِسَابِ مَا عَتَقَ مِنْهُ ‏"‏ ‏.‏ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يُؤَدِّي الْمُكَاتَبُ بِحِصَّةِ مَا أَدَّى دِيَةَ حُرٍّ وَمَا بَقِيَ دِيَةَ عَبْدٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَهَكَذَا رَوَى يَحْيَى بْنُ أَبِي كَثِيرٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى خَالِدٌ الْحَذَّاءُ عَنْ عِكْرِمَةَ عَنْ عَلِيٍّ قَوْلَهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ وَقَالَ أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ الْمُكَاتَبُ عَبْدٌ مَا بَقِيَ عَلَيْهِ دِرْهَمٌ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1259}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas: That the Prophet (ﷺ) said: "When the penalty (of blood money) goes to a Mukatab, or an inheritance, then he inherits in accordance with as much as he is freed from it." And the Prophet (ﷺ) said: "The Mukatab is given the blood-money of a free person in accordance to what he has paid (for his freedom), and that of a slave in accordance to what remains." [He said:] There is something on this from Umm Salamah. [Abu 'Eisa said:] The Hadith of Ibn 'Abbas is a Hasan Hadith. This is how it was reported from Yahya bin Abi Kathir from 'Ikrimah, from Ibn 'Abbas, from the Prophet (ﷺ). Khalid bin Al-Hadh-dha' reported it from 'Ikrimah, from 'Ali as his saying. This is acted upon according to some of the people of knowledge among the Companions of the Prophet (ﷺ) and others. Most of the people of knowledge among the Companions of the Prophet (ﷺ) and others said that the Mukatab remains a slave as long as he still owes a Dirham. This is the view of Sufyan Ath-Thawri, Ash-Shafi'i, Ahmad, and Ishaq}}
\hadithdefcmd{tirmidhi}{1260}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ يَحْيَى بْنِ أَبِي أُنَيْسَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ يَقُولُ ‏ "‏ مَنْ كَاتَبَ عَبْدَهُ عَلَى مِائَةِ أُوقِيَّةٍ فَأَدَّاهَا إِلاَّ عَشْرَ أَوَاقٍ أَوْ قَالَ عَشَرَةَ دَرَاهِمَ ثُمَّ عَجَزَ فَهُوَ رَقِيقٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْمُكَاتَبَ عَبْدٌ مَا بَقِيَ عَلَيْهِ شَيْءٌ مِنْ كِتَابَتِهِ ‏.‏ وَقَدْ رَوَى الْحَجَّاجُ بْنُ أَرْطَاةَ عَنْ عَمْرِو بْنِ شُعَيْبٍ نَحْوَهُ ‏.‏\hadithno{1260}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib: From his father, from his grandfather that he heard the Messenger of Allah (ﷺ) delivering a Khutbah in which he said: "Whoever gives a writ of emancipation to his slave, for one hundred Uqiyyah, and he pays it to him less then ten Uqiyah." - or he said: "Ten Dirham" - "then he becomes incapable (of paying the remainder), the he remains a slave." [Abu 'Eisa said:] This Hadith is Hasan Gharib. And this acted upon according to most of the people of knowledge among the Companions of the Prophet (ﷺ) and others: The Mukatab is a slave as long as something remains due from him for his Kitabah. Al-Hajjaj bin Artat reported similarly from 'Amr bin Shu'aib}}
\hadithdefcmd{tirmidhi}{1261}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ نَبْهَانَ، مَوْلَى أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ عِنْدَ مُكَاتَبِ إِحْدَاكُنَّ مَا يُؤَدِّي فَلْتَحْتَجِبْ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ عَلَى التَّوَرُّعِ وَقَالُوا لاَ يُعْتَقُ الْمُكَاتَبُ وَإِنْ كَانَ عِنْدَهُ مَا يُؤَدِّي حَتَّى يُؤَدِّيَ ‏.‏\hadithno{1261}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah: That the Messenger of Allah (ﷺ) said: "When one of you (women) has a Mukatab ho has with him what will fulfill (the Kitabah) then observe Hijab from him." [Abu 'Eisa said:] This Hadith is Hasan Sahih. And the meaning of this Hadith according to the people of knowledge is that of caution. They say that the Mukatab is not freed, even if he has the amount to pay, until he pays it}}
\hadithdefcmd{tirmidhi}{1262}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ أَيُّمَا امْرِئٍ أَفْلَسَ وَوَجَدَ رَجُلٌ سِلْعَتَهُ عِنْدَهُ بِعَيْنِهَا فَهُوَ أَوْلَى بِهَا مِنْ غَيْرِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَمُرَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ هُوَ أُسْوَةُ الْغُرَمَاءِ ‏.‏ وَهُوَ قَوْلُ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{1262}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Whichever person becomes bankrupt, and a man finds his particular merchandise with him, then he is more deserving of it than others. [He said:] There are narrations on this topic from Samurah and Ibn 'Umar. [Abu 'Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith. This is acted upon according to some of the people of knowledge and it is the view of Ash-Shafi'i, Ahmad, and Ishaq. Some of the people of knowledge said that he is just like one of the debtors. This is the view of the people of Al-Kufah}}
\hadithdefcmd{tirmidhi}{1263}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ مُجَالِدٍ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ، قَالَ كَانَ عِنْدَنَا خَمْرٌ لِيَتِيمٍ فَلَمَّا نَزَلَتِ الْمَائِدَةُ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْهُ وَقُلْتُ إِنَّهُ لِيَتِيمٍ ‏.‏ فَقَالَ ‏ "‏ أَهْرِيقُوهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏ وَقَالَ بِهَذَا بَعْضُ أَهْلِ الْعِلْمِ وَكَرِهُوا أَنْ تُتَّخَذَ الْخَمْرُ خَلاًّ وَإِنَّمَا كُرِهَ مِنْ ذَلِكَ وَاللَّهُ أَعْلَمُ أَنْ يَكُونَ الْمُسْلِمُ فِي بَيْتِهِ خَمْرٌ حَتَّى يَصِيرَ خَلاًّ ‏.‏ وَرَخَّصَ بَعْضُهُمْ فِي خَلِّ الْخَمْرِ إِذَا وُجِدَ قَدْ صَارَ خَلاًّ ‏.‏ أَبُو الْوَدَّاكِ اسْمُهُ جَبْرُ بْنُ نَوْفٍ ‏.‏\hadithno{1263}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Al-Waddak: That Abu Sa'eed said: "We had some wine that belonged to an orphan. When Al-Ma'idah was revealed I asked the Messenger of Allah (ﷺ) about it, I said: 'It belongs to an orphan.' He said: 'Spill it out.'" [He said:] There is something on this topic from Anas bin Malik. [Abu 'Eisa said:] The Hadith of Abu Sa'eed is a Hasan [Sahih] Hadith. Similar to this has been reported through other routes from the Prophet (ﷺ). Some of the people of knowledge stated according to this, they dislike the usage of wine for making vinegar. And the only thing that they disliked about it, and Allah knows best, is for a Muslim to have wine in his house until it becomes vinegar. Abu Al-Waddak's name is Jabr bin Nawf}}
\hadithdefcmd{tirmidhi}{1264}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا طَلْقُ بْنُ غَنَّامٍ، عَنْ شَرِيكٍ، وَقَيْسٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَدِّ الأَمَانَةَ إِلَى مَنِ ائْتَمَنَكَ وَلاَ تَخُنْ مَنْ خَانَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا الْحَدِيثِ وَقَالُوا إِذَا كَانَ لِلرَّجُلِ عَلَى آخَرَ شَيْءٌ فَذَهَبَ بِهِ فَوَقَعَ لَهُ عِنْدَهُ شَيْءٌ فَلَيْسَ لَهُ أَنْ يَحْبِسَ عَنْهُ بِقَدْرِ مَا ذَهَبَ لَهُ عَلَيْهِ ‏.‏ وَرَخَّصَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَقَالَ إِنْ كَانَ لَهُ عَلَيْهِ دَرَاهِمُ فَوَقَعَ لَهُ عِنْدَهُ دَنَانِيرُ فَلَيْسَ لَهُ أَنْ يَحْبِسَ بِمَكَانِ دَرَاهِمِهِ إِلاَّ أَنْ يَقَعَ عِنْدَهُ لَهُ دَرَاهِمُ فَلَهُ حِينَئِذٍ أَنْ يَحْبِسَ مِنْ دَرَاهِمِهِ بِقَدْرِ مَا لَهُ عَلَيْهِ ‏.‏\hadithno{1264}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: That the Prophet (ﷺ) said: "Fulfill the trust for the one who entrusted you, and do not cheat the one who cheated you." [Abu 'Eisa said:] This Hadith is Hasan Gharib. Some of the people of knowledge followed this Hadith, they said that when something belonging to a man is with another and he leaves (with it), then he has something that belongs to him, he may not withhold from him an equivalent to what the other took of his. Some of the people of knowledge among the Tabi'in allowed that. This is the view of Sufyan Ath-Thawri, he said: "If one man has some Dirham that belong to another, and the second has some Dinar belonging to the first, he may not withhold any in place of his Dirham, unless it so happens that he has some Dirham of his, then in that case he can withhold some of his Dirham equal to what he is owed by the first}}
\hadithdefcmd{tirmidhi}{1265}{حَدَّثَنَا هَنَّادٌ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ شُرَحْبِيلَ بْنِ مُسْلِمٍ الْخَوْلاَنِيِّ، عَنْ أَبِي أُمَامَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ فِي خُطْبَتِهِ عَامَ حَجَّةِ الْوَدَاعِ ‏ "‏ الْعَارِيَةُ مُؤَدَّاةٌ وَالزَّعِيمُ غَارِمٌ وَالدَّيْنُ مَقْضِيٌّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ سَمُرَةَ وَصَفْوَانَ بْنِ أُمَيَّةَ وَأَنَسٍ ‏.‏ قَالَ وَحَدِيثُ أَبِي أُمَامَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي أُمَامَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{1265}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Umamah: "During the year of the Farewell Pilgrimage, I heard the Prophet (ﷺ) saying during the Khutbah: "The borrowed is to be returned, and the guarantor is responsible, and the debt is to be repaid." [Abu 'Eisa said:] There are narrations on this topic from Samurah, Safwan bin Umayyah, and Anas. [He said:] The Hadith of Abu Umamah is a Hasan Gharib Hadith. It has also been reported through other routes besides this, from Abu Umamah, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1266}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَى الْيَدِ مَا أَخَذَتْ حَتَّى تُؤَدِّيَ ‏"‏ ‏.‏ قَالَ قَتَادَةُ ثُمَّ نَسِيَ الْحَسَنُ فَقَالَ هُوَ أَمِينُكَ لاَ ضَمَانَ عَلَيْهِ ‏.‏ يَعْنِي الْعَارِيَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِلَى هَذَا وَقَالُوا يَضْمَنُ صَاحِبُ الْعَارِيَةِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لَيْسَ عَلَى صَاحِبِ الْعَارِيَةِ ضَمَانٌ إِلاَّ أَنْ يُخَالِفَ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَبِهِ يَقُولُ إِسْحَاقُ ‏.‏\hadithno{1266}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qatadah: From Al-Hasan, from Samurah, that the Prophet (ﷺ) said: "Upon the hand is what it took, until it is returned." Qatadah said: "Then Al-Hasan forgot, so he said: 'It is something you entrusted, he is not liable for it.' " Meaning the borrowed property. [Abu 'Eisa said:] This Hadith is Hasan Sahih. Some of the people pf knowledge, among the Companions of the Prophet (ﷺ) and others, followed this Hadith. They said that the possessor of the borrowed thing is liable. This is the view of Ash-Shafi'i and Ahmad. Some of the people of knowledge among the Companions and others said that the possessor of the borrowed this is not liable unless there is dispute. This is the view of Sufyan Ath-Thawri and the people of Al-Kufah, and it is the view of Ishaq}}
\hadithdefcmd{tirmidhi}{1267}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ مَعْمَرِ بْنِ عَبْدِ اللَّهِ بْنِ نَضْلَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحْتَكِرُ إِلاَّ خَاطِئٌ ‏"‏ ‏.‏ فَقُلْتُ لِسَعِيدٍ يَا أَبَا مُحَمَّدٍ إِنَّكَ تَحْتَكِرُ ‏.‏ قَالَ وَمَعْمَرٌ قَدْ كَانَ يَحْتَكِرُ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا رُوِيَ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ أَنَّهُ كَانَ يَحْتَكِرُ الزَّيْتَ وَالْحِنْطَةَ وَنَحْوَ هَذَا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَأَبِي أُمَامَةَ وَابْنِ عُمَرَ ‏.‏ وَحَدِيثُ مَعْمَرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا احْتِكَارَ الطَّعَامِ ‏.‏ وَرَخَّصَ بَعْضُهُمْ فِي الاِحْتِكَارِ فِي غَيْرِ الطَّعَامِ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ لاَ بَأْسَ بِالاِحْتِكَارِ فِي الْقُطْنِ وَالسَّخْتِيَانِ وَنَحْوِ ذَلِكَ ‏.‏\hadithno{1267}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Muhammad bin Ibrahim : From Sa'eed bin Al-Musayyab, from Ma'mar bin 'Abdullah bin Nadlah who said: "I heard the Messenger of Allah (ﷺ) saying: 'Hoarding is nothing but sin.' So I (Muhammad) said to Sa'eed: "O Abu Muhammad! You hoard?" He said: "And Ma'mar would hoard." It is also been reported that Sa'eed bin Musayyab would hoard oil, (camel) fodder, and the like. [Abu 'Eisa said:] There are narrations on this topic from 'Umar, 'Ali, Abu Umamah, and Ibn 'Umar. The Hadith of Ma'mar is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge, they dislike hoarding food, and some of them make a concession for hoarding things other than food. Ibn Al-Mubarak said: "There is no harm in hoarding cotton, goat pelts and like}}
\hadithdefcmd{tirmidhi}{1268}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَسْتَقْبِلُوا السُّوقَ وَلاَ تُحَفِّلُوا وَلاَ يُنَفِّقْ بَعْضُكُمْ لِبَعْضٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ ‏.‏ وَحَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا بَيْعَ الْمُحَفَّلَةِ وَهِيَ الْمُصَرَّاةُ لاَ يَحْلُبُهَا صَاحِبُهَا أَيَّامًا أَوْ نَحْوَ ذَلِكَ لِيَجْتَمِعَ اللَّبَنُ فِي ضَرْعِهَا فَيَغْتَرَّ بِهَا الْمُشْتَرِي ‏.‏ وَهَذَا ضَرْبٌ مِنَ الْخَدِيعَةِ وَالْغَرَرِ ‏.‏\hadithno{1268}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas: That the Prophet (ﷺ) said: "Do not go out to meet the market (caravan), do not leave animals un-milked (to deceive the buyer), nor out-spend one another." [Abu 'Eisa said:] There are narrations on this topic from Ibn Mas'ud and Abu Hurairah. The Hadith if Ibn 'Abbas is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge, they dislike selling the Muhaffalah, and it is the Musarrah that has not been milked by its owner in days or more than that, so the milk accumulates in its udder to impress the purchaser. This is a type of deceit and misrepresentation}}
\hadithdefcmd{tirmidhi}{1269}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ وَهُوَ فِيهَا فَاجِرٌ لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ لَقِيَ اللَّهَ وَهُوَ عَلَيْهِ غَضْبَانُ ‏"‏ ‏.‏ فَقَالَ الأَشْعَثُ بْنُ قَيْسٍ فِيَّ وَاللَّهِ لَقَدْ كَانَ ذَلِكَ كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنَ الْيَهُودِ أَرْضٌ فَجَحَدَنِي فَقَدَّمْتُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ فَقَالَ لِلْيَهُودِيِّ ‏"‏ احْلِفْ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفَ فَيَذْهَبَ بِمَالِي ‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى‏:‏ ‏(‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً ‏)‏ ‏.‏ إِلَى آخِرِ الآيَةِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ وَائِلِ بْنِ حُجْرٍ وَأَبِي مُوسَى وَأَبِي أُمَامَةَ بْنِ ثَعْلَبَةَ الأَنْصَارِيِّ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ وَحَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1269}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Mas'ud: That the Messenger of Allah (ﷺ) said: "Whoever takes a false oath to deprive a Muslim of his wealth, he will meet Allah while He is angry with him." Al-Ash'ath bin Qais said: "It is about me, by Allah! There was a dispute about some land between myself and a man from the Jews who denied my ownership of it, so I took him to the Prophet (ﷺ). The Messenger of Allah (ﷺ) said to me: 'Do you have any proof ?' I said: 'No'. So he said to Jew: 'Take an oath.' I said: 'O Messenger of Allah! If he takes an oath then my property will be gone!' So Allah, Most High revealed: Verily those who purchase a small gain at the cost of Allah's Covenant and their oaths.. until the end of the Ayah." [Abu 'Eisa said:] There are narrations on this topic from Wa'il bin Hujr, Abu Musa, Abu Umamah bin Tha'labah Al-Ansari, and 'Imran bin Husain. The Hadith of Ibn Mas'ud is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1270}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اخْتَلَفَ الْبَيِّعَانِ فَالْقَوْلُ قَوْلُ الْبَائِعِ وَالْمُبْتَاعُ بِالْخِيَارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُرْسَلٌ عَوْنُ بْنُ عَبْدِ اللَّهِ لَمْ يُدْرِكِ ابْنَ مَسْعُودٍ ‏.‏ وَقَدْ رُوِيَ عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ عَنِ ابْنِ مَسْعُودٍ عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثُ أَيْضًا وَهُوَ مُرْسَلٌ أَيْضًا ‏.‏ قَالَ أَبُو عِيسَى قَالَ إِسْحَاقُ بْنُ مَنْصُورٍ قُلْتُ لأَحْمَدَ إِذَا اخْتَلَفَ الْبَيِّعَانِ وَلَمْ تَكُنْ بَيِّنَةٌ قَالَ الْقَوْلُ مَا قَالَ رَبُّ السِّلْعَةِ أَوْ يَتَرَادَّانِ ‏.‏ قَالَ إِسْحَاقُ كَمَا قَالَ وَكُلُّ مَنْ كَانَ الْقَوْلُ قَوْلَهُ فَعَلَيْهِ الْيَمِينُ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رُوِيَ عَنْ بَعْضِ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ مِنْهُمْ شُرَيْحٌ وَغَيْرُهُ نَحْوُ هَذَا ‏.‏\hadithno{1270}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn Mas'ud: That the Messenger of Allah (ﷺ) said: "When the two parties (in a deal) disagree then the seller's statement is taken as valid, and the purchaser retains the option." [Abu 'Eisa said:] This Hadith is Mursal. 'Awn bin 'Abdullah did not see Ibn Mas'ud. This Hadith has also been reported from Al-Qasim bin 'Abdur-Rahman, from Ibn Mas'ud from the Prophet (ﷺ). But it also Mursal. [Abu 'Eisa said:] Ishaq bin Mansur said: "I said to Ahmad: what if when the two parties disagree and there is no proof (what is done)?' He said: 'The saying of the owner of the merchandise is taken as valid or they both refuse.' And Ishaq said as he did, and that in every case where his saying is taken, he must swear.'" [Abu 'Eisa said:] Similar to this has been reported from some of the people of knowledge among the Tabi'in, Shuraih is among those}}
\hadithdefcmd{tirmidhi}{1271}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الْمِنْهَالِ، عَنْ إِيَاسِ بْنِ عَبْدٍ الْمُزَنِيِّ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ الْمَاءِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَبُهَيْسَةَ عَنْ أَبِيهَا وَأَبِي هُرَيْرَةَ وَعَائِشَةَ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ إِيَاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ أَنَّهُمْ كَرِهُوا بَيْعَ الْمَاءِ ‏.‏ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي بَيْعِ الْمَاءِ ‏.‏ مِنْهُمُ الْحَسَنُ الْبَصْرِيُّ ‏.‏\hadithno{1271}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Al-Minhal: From Iyas bin 'Abd al-Muzani who said: "The Prophet (ﷺ) prohibited selling water." [He said:] There are narrations on this topic from Jabir, Buhaisah from her father, Abu Hurairah, 'Aishah, Anas and 'Abdullah bin 'Amr. [Abu 'Eisa said:] The Hadith is Iyas is a Hasan Sahih Hadith. This is acted upon according to most of the people of knowledge, they dislike selling water. This is the view of Ibn Al-Mubarak, Ash-Shafi'i, Ahmad, and Ishaq. Some of the people of knowledge permitted selling water, Al-Hasan al-Basri is one of them}}
\hadithdefcmd{tirmidhi}{1272}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُمْنَعُ فَضْلُ الْمَاءِ لِيُمْنَعَ بِهِ الْكَلأُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الْمِنْهَالِ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ مُطْعِمٍ كُوفِيٌّ وَهُوَ الَّذِي رَوَى عَنْهُ حَبِيبُ بْنُ أَبِي ثَابِتٍ ‏.‏ وَأَبُو الْمِنْهَالِ سَيَّارُ بْنُ سَلاَمَةَ بَصْرِيٌّ صَاحِبُ أَبِي بَرْزَةَ الأَسْلَمِيِّ ‏.‏\hadithno{1272}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih Agreed Upon}\hadithtrans{Narrated Abu Hurairah: That the Prophet (ﷺ) said: "Do not withhold surplus water so that it is prevented from the pasture." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Abu Al-Munhal's name is 'Abdur-Rahman bin Mut'im, he is from Al-Kufah, and he is oen that Habib bin Abi Thabit reports from. Abu Al-Munhal Sayyar bin Salamah is from Al-Basrah, he is the companion of Abu Barzah Al-Aslami}}
\hadithdefcmd{tirmidhi}{1273}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَأَبُو عَمَّارٍ قَالاَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، قَالَ أَخْبَرَنَا عَلِيُّ بْنُ الْحَكَمِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ عَسْبِ الْفَحْلِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَنَسٍ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَقَدْ رَخَّصَ بَعْضُهُمْ فِي قَبُولِ الْكَرَامَةِ عَلَى ذَلِكَ ‏.‏\hadithno{1273}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Ibn 'Umar: "The Prophet (ﷺ) prohibited studding the stallion." [He said:] There are narrations on this topic from Abu Hurairah, Anas, and Abu Sa'eed. [Abu 'Eisa said:] The Hadith is Ibn 'Umar is a Hasan Sahih Hadith. This is acted upon according to some of the people of knowledge. There are those who made concession for accepting an honorarium for that}}
\hadithdefcmd{tirmidhi}{1274}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ الْبَصْرِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِبْرَاهِيمَ بْنِ حُمَيْدٍ الرُّؤَاسِيِّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، مِنْ كِلاَبٍ سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ عَسْبِ الْفَحْلِ فَنَهَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نُطْرِقُ الْفَحْلَ فَنُكْرَمُ ‏.‏ فَرَخَّصَ لَهُ فِي الْكَرَامَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِبْرَاهِيمَ بْنِ حُمَيْدٍ عَنْ هِشَامِ بْنِ عُرْوَةَ ‏.‏\hadithno{1274}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas bin Malik: "A man from (the tribe of) Kilab asked the Messenger of Allah (ﷺ) about studding a stallion and he prohibited it. So he said: 'O Messenger of Allah! We stud the stallions so that we get honorarium (from the owners of the female horse)!' So he permitted it for honorarium." [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it except as a narration of Ibrahim bin Humaid, from Hisham bin 'Urwah}}
\hadithdefcmd{tirmidhi}{1275}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ قَارِظٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَسْبُ الْحَجَّامِ خَبِيثٌ وَمَهْرُ الْبَغِيِّ خَبِيثٌ وَثَمَنُ الْكَلْبِ خَبِيثٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَابْنِ مَسْعُودٍ وَأَبِي مَسْعُودٍ وَجَابِرٍ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ جَعْفَرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ رَافِعٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ كَرِهُوا ثَمَنَ الْكَلْبِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي ثَمَنِ كَلْبِ الصَّيْدِ ‏.‏\hadithno{1275}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Rafi' b. Khadij: That the Messenger of Allah (ﷺ) said: "The earnings of the cupper is filth, the earnings of the fornicator (from harlotry) is filth, and the price of a dog is filth." [He said:] There are narrations on this topic from 'Umar, 'Ali, Ibn Mas'ud, Abu Masu'd, Jabir, Abu Hurairah, Ibn 'Abbas, Ibn 'Umar, and 'Abdullah bin Ja'far. [Abu 'Eisa said:] The Hadith is Rafi' is a Hasan Sahih Hadith. This is acted upon according to most of the people of knowledge, they disliked the price of a dog. This the view of Ash-Shafi'i, Ahmad, and Ishaq. Some of the people of knowledge permitted the price of the hunting dog}}
\hadithdefcmd{tirmidhi}{1276}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، ح وَحَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1276}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Mas'ud Al-Ansari: "The Messenger of Allah (ﷺ) prohibited the price of a dog, the earnings of the fornicator (from harlotry), and the news of the fortune-teller." This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1277}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ مُحَيِّصَةَ، أَخِي بَنِي حَارِثَةَ عَنْ أَبِيهِ، أَنَّهُ اسْتَأْذَنَ النَّبِيَّ صلى الله عليه وسلم فِي إِجَارَةِ الْحَجَّامِ فَنَهَاهُ عَنْهَا فَلَمْ يَزَلْ يَسْأَلُهُ وَيَسْتَأْذِنُهُ حَتَّى قَالَ ‏ "‏ اعْلِفْهُ نَاضِحَكَ وَأَطْعِمْهُ رَقِيقَكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ رَافِعِ بْنِ خَدِيجٍ وَأَبِي جُحَيْفَةَ وَجَابِرٍ وَالسَّائِبِ بْنِ يَزِيدَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مُحَيِّصَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ وَقَالَ أَحْمَدُ إِنْ سَأَلَنِي حَجَّامٌ نَهَيْتُهُ وَآخُذُ بِهَذَا الْحَدِيثِ ‏.‏\hadithno{1277}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn Muhayyisah of Banu Harithah: From his father, that he sought permission from the Prophet (ﷺ) to take the wages for cupping and he (ﷺ) forbade him from it. He continued asking him and seeking his permission until he said: "Use it to give fodder to your water-carrying camels, and to feed your slaves." [He said:] There are narrations on this topic from Rafi' bin Khadij, Abu Juhaifah, Jabir, and As-Sa'ib bin Yazid. [Abu 'Eisa said:] The Hadith of Muhayyisah is a Hasan Sahih Hadith. This is acted upon according to some of the people of knowledge. Ahmad said: "If I am asked for something by cupper then I deny him, acting upon this Hadith}}
\hadithdefcmd{tirmidhi}{1278}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، قَالَ سُئِلَ أَنَسٌ عَنْ كَسْبِ الْحَجَّامِ، فَقَالَ أَنَسٌ احْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَحَجَمَهُ أَبُو طَيْبَةَ فَأَمَرَ لَهُ بِصَاعَيْنِ مِنْ طَعَامٍ وَكَلَّمَ أَهْلَهُ فَوَضَعُوا عَنْهُ مِنْ خَرَاجِهِ وَقَالَ ‏"‏ إِنَّ أَفْضَلَ مَا تَدَاوَيْتُمْ بِهِ الْحِجَامَةُ ‏"‏ ‏.‏ أَوْ ‏"‏ إِنَّ مِنْ أَمْثَلِ دَوَائِكُمُ الْحِجَامَةَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عَبَّاسٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي كَسْبِ الْحَجَّامِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{1278}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Anas: "The Messenger of Allah (ﷺ) was cupped. Abu Talhah did the cupping. So he ordered that he be given two Sa' of food, and he spoke to his masters to reduce his taxes. He said: 'The most virtuous of what you treat with is cupping.' Or, he said: 'The best of your treatments is cupping.'" [He said:] There are narrations on this topic from 'Ali, Ibn 'Abbas, and Ibn 'Umar. [Abu 'Eisa said:] The Hadith of Anas is a Hasan Sahih. Some of the people of knowledge among the Companions of the Prophet (ﷺ), and others permitted paying the cupper. This is the view of Ash-Shafi'i}}
\hadithdefcmd{tirmidhi}{1279}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ وَالسِّنَّوْرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ فِي إِسْنَادِهِ اضْطِرَابٌ وَلاَ يَصِحُّ فِي ثَمَنِ السِّنَّوْرِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ الأَعْمَشِ عَنْ بَعْضِ أَصْحَابِهِ عَنْ جَابِرٍ ‏.‏ وَاضْطَرَبُوا عَلَى الأَعْمَشِ فِي رِوَايَةِ هَذَا الْحَدِيثِ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ ثَمَنَ الْهِرِّ وَرَخَّصَ فِيهِ بَعْضُهُمْ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَرَوَى ابْنُ فُضَيْلٍ عَنِ الأَعْمَشِ عَنْ أَبِي حَازِمٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{1279}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir: "The Messenger of Allah (ﷺ) prohibited the price of the dog and the cat." [Abu 'Eisa said:] There is some confusion (Idtirab) in the chain for this Hadith. The price of a cat is not correct. This Hadith has been reported from Al-A'mash, from some of his companions, from Jabir, and they caused some confusion for Al-A'mash in this narration. There are those among the people of knowledge who disliked the price of a cat, and some of them permitted it. This is the view of Ahmad and Ishaq. It has been reported from Ibn Al-Fudail, from Al-A'mash, from Abu Hazim, from Abu Hurairah from the Prophet (ﷺ), through other than this route}}
\hadithdefcmd{tirmidhi}{1280}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا عُمَرُ بْنُ زَيْدٍ الصَّنْعَانِيُّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ أَكْلِ الْهِرِّ وَثَمَنِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَعُمَرُ بْنُ زَيْدٍ لاَ نَعْرِفُ كَبِيرَ أَحَدٍ رَوَى عَنْهُ غَيْرَ عَبْدِ الرَّزَّاقِ ‏.‏\hadithno{1280}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir: "The Messenger of Allah (ﷺ) prohibited eating the cat and from its price." [Abu 'Eisa said:] This Hadith is Gharib. We do not know of any major (known) narrators who reports from 'Umar bin Zaid (one of the narrators) besides 'Abdur-Razzaq}}
\hadithdefcmd{tirmidhi}{1281}{أَخْبَرَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الْمُهَزِّمِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى عَنْ ثَمَنِ الْكَلْبِ، إِلاَّ كَلْبَ الصَّيْدِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ يَصِحُّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو الْمُهَزِّمِ اسْمُهُ يَزِيدُ بْنُ سُفْيَانَ وَتَكَلَّمَ فِيهِ شُعْبَةُ بْنُ الْحَجَّاجِ وَضَعَّفَهُ ‏.‏ وَقَدْ رُوِيَ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا وَلاَ يَصِحُّ إِسْنَادُهُ أَيْضًا ‏.‏\hadithno{1281}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Al-Muhazzim: From Abu Hurairah who said: "The price of a dog was prohibited, except for the hunting dog." [Abu 'Eisa said:] This Hadith is not correct from this route. Abu Al-Muhazzim's name is Yazid bin Sufyan, and Shu'bah bin Al-Hajjaj criticized him and graded him weak. Similar to this has been reported from Jabir, from the Prophet (ﷺ), but its chain is also not correct}}
\hadithdefcmd{tirmidhi}{1282}{حَدَّثَنَا قُتَيْبَةُ، أَخْبَرَنَا بَكْرُ بْنُ مُضَرَ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَبِيعُوا الْقَيْنَاتِ وَلاَ تَشْتَرُوهُنَّ وَلاَ تُعَلِّمُوهُنَّ وَلاَ خَيْرَ فِي تِجَارَةٍ فِيهِنَّ وَثَمَنُهُنَّ حَرَامٌ فِي مِثْلِ هَذَا أُنْزِلَتْ هَذِهِ الآيَةُ ‏:‏ ‏(‏ وَمِنَ النَّاسِ مَنْ يَشْتَرِي لَهْوَ الْحَدِيثِ لِيُضِلَّ عَنْ سَبِيلِ اللَّهِ ‏)‏ إِلَى آخِرِ الآيَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ بْنِ الْخَطَّابِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي أُمَامَةَ إِنَّمَا نَعْرِفُهُ مِثْلَ هَذَا مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي عَلِيِّ بْنِ يَزِيدَ وَضَعَّفَهُ وَهُوَ شَامِيٌّ ‏.‏\hadithno{1282}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Umamah: That the Messenger of Allah (ﷺ) said: "Do not sell the (slave) female singers, not purchase them, nor teach them (to sing). And there is no good in trading in them, and their prices are unlawful. It was about the likes of this that this Ayah was revealed: And among mankind is he who purchases idle talk to divert from the way of Allah." [He said:] There is narration about this from 'Umar bin Al-Khattab. [Abu 'Eisa said:] We only know of the Hadith of Abu Umamah, like this, from this route. Some of the people of knowledge have criticized 'Ali bin Yazid (one of the narrators) and graded him weak, and he is from Ash-Sham}}
\hadithdefcmd{tirmidhi}{1283}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ الشَّيْبَانِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي حُيَىُّ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ أَبِي أَيُّوبَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ فَرَّقَ بَيْنَ الْوَالِدَةِ وَوَلَدِهَا فَرَّقَ اللَّهُ بَيْنَهُ وَبَيْنَ أَحِبَّتِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1283}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Ayyub: "I narrated heard the Messenger of Allah (ﷺ) saying: 'Whoever seperates a mother from her child, Allah seperates him and his most beloved on the Day of Judgement.'" [Abu 'Eisa said:] This Hadith is Hasan Gharib}}
\hadithdefcmd{tirmidhi}{1284}{حَدَّثَنَا الْحَسَنُ بْنُ قَزَعَةَ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنِ الْحَجَّاجِ، عَنِ الْحَكَمِ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ عَلِيٍّ، قَالَ وَهَبَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم غُلاَمَيْنِ أَخَوَيْنِ فَبِعْتُ أَحَدَهُمَا فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَلِيُّ مَا فَعَلَ غُلاَمُكَ ‏"‏ ‏.‏ فَأَخْبَرْتُهُ فَقَالَ ‏"‏ رُدَّهُ رُدَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ كَرِهَ بَعْض�� أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ التَّفْرِيقَ بَيْنَ السَّبْىِ فِي الْبَيْعِ وَيُكْرَهُ أَنْ يُفَرَّقَ بَيْنَ الْوَالِدَةِ وَوَلَدِهَا وَبَيْنَ الْوَالِدِ وَالْوَلَدِ وَبَيْنَ الإِخْوَةِ وَالأَخَوَاتِ فِي الْبَيْعِ ‏.‏ وَرَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي التَّفْرِيقِ بَيْنَ الْمُوَلَّدَاتِ الَّذِينَ وُلِدُوا فِي أَرْضِ الإِسْلاَمِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏ وَرُوِيَ عَنْ إِبْرَاهِيمَ النَّخَعِيِّ أَنَّهُ فَرَّقَ بَيْنَ وَالِدَةٍ وَوَلَدِهَا فِي الْبَيْعِ فَقِيلَ لَهُ فِي ذَلِكَ فَقَالَ إِنِّي قَدِ اسْتَأْذَنْتُهَا بِذَلِكَ فَرَضِيَتْ ‏.‏\hadithno{1284}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali : "The Messenger of Allah (ﷺ) gave me two boys who were brothers, so I sold one of them, and the Messenger of Allah (ﷺ) said to me: 'O, 'Ali! What happened to your boy?' So I informed him, and he said: 'Return him, return him.'" [Abu 'Eisa said:] This Hadith is Hasan Gharib. Some of the people of knowledge among the Companions of the Prophet (ﷺ) and others, disliked separating between the captives when selling them. Some of the people of knowledge permitted separating the children that were born in the land of Islam, but the first view is more correct. It has been related that Ibrahim An-Nakha'i seperated a mother and her child in a sale, so he was asked about that. He said: "I sought her permission for that and she approved}}
\hadithdefcmd{tirmidhi}{1285}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، وَأَبُو عَامِرٍ الْعَقَدِيُّ عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ مَخْلَدِ بْنِ خُفَافٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّ الْخَرَاجَ بِالضَّمَانِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1285}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah: That the Messenger of Allah (ﷺ) judged: "The produce is for the responsible one." [Abu 'Eisa said:] This Hadith is Hasan Sahih. This Hadith has been reported through routes other than this, and this acted upon according to the people of knowledge}}
\hadithdefcmd{tirmidhi}{1286}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ أَخْبَرَنَا عُمَرُ بْنُ عَلِيٍّ الْمُقَدَّمِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى أَنَّ الْخَرَاجَ بِالضَّمَانِ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ هِشَامِ بْنِ عُرْوَةَ ‏.‏ قَالَ أَبُو عِيسَى اسْتَغْرَبَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ هَذَا الْحَدِيثَ مِنْ حَدِيثِ عُمَرَ بْنِ عَلِيٍّ ‏.‏ قُلْتُ تَرَاهُ تَدْلِيسًا قَالَ لاَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى مُسْلِمُ بْنُ خَالِدٍ الزَّنْجِيُّ هَذَا الْحَدِيثَ عَنْ هِشَامِ بْنِ عُرْوَةَ وَرَوَاهُ جَرِيرٌ عَنْ هِشَامٍ أَيْضًا ‏.‏ وَحَدِيثُ جَرِيرٍ يُقَالُ تَدْلِيسٌ دَلَّسَ فِيهِ جَرِيرٌ ‏.‏ لَمْ يَسْمَعْهُ مِنْ هِشَامِ بْنِ عُرْوَةَ ‏.‏ وَتَفْسِيرُ الْخَرَاجِ بِالضَّمَانِ هُوَ الرَّجُلُ يَشْتَرِي الْعَبْدَ فَيَسْتَغِلُّهُ ثُمَّ يَجِدُ بِهِ عَيْبًا فَيَرُدُّهُ عَلَى الْبَائِعِ فَالْغَلَّةُ لِلْمُشْتَرِي لأَنَّ الْعَبْدَ لَوْ هَلَكَ هَلَكَ مِنْ مَالِ الْمُشْتَرِي ‏.‏ وَنَحْوُ هَذَا مِنَ الْمَسَائِلِ يَكُونُ فِيهِ الْخَرَاجُ بِالضَّمَانِ ‏.‏ قَالَ أَبُو عِيسَى اسْتَغْرَبَ مُحَمَّدُ بْنُ إِسْمَعِيلَ هَذَا الْحَدِيثَ مِنْ حَدِيثِ عُمَرَ بْنِ عَلِيٍّ قُلْتُ تَرَاهُ تَدْلِيسًا قَالَ لَا\hadithno{1286}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Aishah: "The Prophet (ﷺ) judged that the produce is produce is for the responsible one." [He said:] This Hadith is Hasan Sahih, Gharib as a Hadith of Hisham bin 'Urwah (a narrator). [Abu 'Eisa said:] Muslim bin Khalid Az-Zanji reported this Hadith from Hisham, from 'Urwah. Jarir reported it from Hisham as well. It is said that the narration of Jarir has Tadlis in in it, that Jarir committed the Tadlis, he did not hear it from Hisham bin 'Urwah. As for the meaning of "the produce is for the responsible one," he is the man who purchased the slave then the slave produced for him, and he found some defect in him so he returned him to the seller. Then the produce (of his work) is the purchaser's. In cases similar to this, the produce is for the responsible one. [Abu 'Eisa said:] Muhammad bin Isma'il called this Hadith Gharib, as a narration of 'Umar bin 'Ali (one of the narrators). I said: "Do you think that he committed Tadlis?" He said:"No}}
\hadithdefcmd{tirmidhi}{1287}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ دَخَلَ حَائِطًا فَلْيَأْكُلْ وَلاَ يَتَّخِذْ خُبْنَةً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَبَّادِ بْنِ شُرَحْبِيلَ وَرَافِعِ بْنِ عَمْرٍو وَعُمَيْرٍ مَوْلَى آبِي اللَّحْمِ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ سُلَيْمٍ ‏.‏ وَقَدْ رَخَّصَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ لاِبْنِ السَّبِيلِ فِي أَكْلِ الثِّمَارِ وَكَرِهَهُ بَعْضُهُمْ إِلاَّ بِالثَّمَنِ ‏.‏\hadithno{1287}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar: That the Prophet (ﷺ) said: "Whoever enters an orchard then let him eat, but not take any in his garment." [He said:] There are narrations on this topic from 'Abdullah bin 'Amr, 'Abbad bin Shurahbil, Rafi' bin 'Amr, 'Umair the freed slave of Abi Al-Lahm, and Abu Hurairah. [Abu 'Eisa said:] The Hadith of Ibn 'Umar is Gharib Hadith. We do not know of it from this route except from Yahya bin Sulaim. Some of the people of knowledge have permitted the wayfarer to eat from the fruits, and some of them disliked it without paying}}
\hadithdefcmd{tirmidhi}{1288}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ الْخُزَاعِيُّ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ صَالِحِ بْنِ أَبِي جُبَيْرٍ، عَنْ أَبِيهِ، عَنْ رَافِعِ بْنِ عَمْرٍو، قَالَ كُنْتُ أَرْمِي نَخْلَ الأَنْصَارِ فَأَخَذُونِي فَذَهَبُوا بِي إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا رَافِعُ لِمَ تَرْمِي نَخْلَهُمْ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ الْجُوعُ ‏.‏ قَالَ ‏"‏ لاَ تَرْمِ وَكُلْ مَا وَقَعَ أَشْبَعَكَ اللَّهُ وَأَرْوَاكَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1288}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Rafi' bin 'Amr: "I was throwing stones at a date-palm belonging to some of the Ansar. They took me along with them to the Prophet (ﷺ). He said: "O Rafi'! Why were you throwing stones at their date-palm?'" He said: "I said: 'Out of hunger, O Messenger of Allah! He said: 'Do not throw stones at them, eat what falls. May Allah fill you and quench your thirst.'" This Hadith is Hasan Gharib Sahih}}
\hadithdefcmd{tirmidhi}{1289}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنِ الثَّمَرِ الْمُعَلَّقِ فَقَالَ ‏ "‏ مَنْ أَصَابَ مِنْهُ مِنْ ذِي حَاجَةٍ غَيْرَ مُتَّخِذٍ خُبْنَةً فَلاَ شَىْءَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1289}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib: From his father, from his grandfather, that the Prophet (ﷺ) was asked about hanging fruits (on the trees), so he said: "Whoever is in need and picks some of it without taking any in his garment, then there is no sin upon him." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1290}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ الْبَغْدَادِيُّ، أَخْبَرَنَا عَبَّادُ بْنُ الْعَوَّامِ، قَالَ أَخْبَرَنِي سُفْيَانُ بْنُ حُسَيْنٍ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَالْمُخَابَرَةِ وَالثُّنْيَا إِلاَّ أَنْ تُعْلَمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ يُونُسَ بْنِ عُبَيْدٍ عَنْ عَطَاءٍ عَنْ جَابِرٍ ‏.‏\hadithno{1290}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir: "The Messenger of Allah (ﷺ) prohibited Al-Muhaqalah, Al-Muzabanah, Al-Mukhabarah, and making an exception (in a sale) unless it is made known." [Abu 'Eisa said:] This Hadith is Hasan Sahih, Gharib from this route as narration of Yunus bin 'Ubaid, from 'Ata, from Jabir}}
\hadithdefcmd{tirmidhi}{1291}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَأَحْسِبُ كُلَّ شَيْءٍ مِثْلَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ كَرِهُوا بَيْعَ الطَّعَامِ حَتَّى يَقْبِضَهُ الْمُشْتَرِي ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِيمَنِ ابْتَاعَ شَيْئًا مِمَّا لاَ يُكَالُ وَلاَ يُوزَنُ مِمَّا لاَ يُؤْكَلُ وَلاَ يُشْرَبُ أَنْ يَبِيعَهُ قَبْلَ أَنْ يَسْتَوْفِيَهُ ‏.‏ وَإِنَّمَا التَّشْدِيدُ عِنْدَ أَهْلِ الْعِلْمِ فِي الطَّعَامِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1291}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas: That the Prophet (ﷺ) said: "Whoever buys food, then he is not to sell it until he takes possession of it." Ibn 'Abbas said: "All things are considered the same (in this regard)." [He said:] There are narrations on this topic from Jabir, Ibn 'Umar, and Abu Hurairah. [Abu 'Eisa said:] The Hadith of Ibn 'Abbas is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1292}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَبِيعُ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَلاَ يَخْطُبُ بَعْضُكُمْ عَلَى خِطْبَةِ بَعْضٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَسَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ يَسُومُ الرَّجُلُ عَلَى سَوْمِ أَخِيهِ ‏"‏ ‏.‏ وَمَعْنَى الْبَيْعِ فِي هَذَا الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ هُوَ السَّوْمُ ‏.‏\hadithno{1292}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: That the Messenger of Allah (ﷺ) said: "None of you is to sell over the sale of others, nor to propose over the proposal of others." [He said:] There are narration on this topic from Abu Hurairah and Samurah. [Abu 'Eisa said:] The Hadith of Ibn 'Umar is a Hasan Sahih Hadith. And it has been reported from the Prophet (ﷺ) that he said: "Do not haggle in competition with your brother's haggling." And the meaning of sale in this Hadith of the Prophet (ﷺ), according to some of the people of knowledge is to haggle}}
\hadithdefcmd{tirmidhi}{1293}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ لَيْثًا، يُحَدِّثُ عَنْ يَحْيَى بْنِ عَبَّادٍ، عَنْ أَنَسٍ، عَنْ أَبِي طَلْحَةَ، أَنَّهُ قَالَ يَا نَبِيَّ اللَّهِ إِنِّي اشْتَرَيْتُ خَمْرًا لأَيْتَامٍ فِي حِجْرِي ‏.‏ قَالَ ‏ "‏ أَهْرِقِ الْخَمْرَ وَاكْسِرِ الدِّنَانَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَعَائِشَةَ وَأَبِي سَعِيدٍ وَابْنِ مَسْعُودٍ وَابْنِ عُمَرَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي طَلْحَةَ رَوَى الثَّوْرِيُّ هَذَا الْحَدِيثَ عَنِ السُّدِّيِّ عَنْ يَحْيَى بْنِ عَبَّادٍ عَنْ أَنَسٍ أَنَّ أَبَا طَلْحَةَ كَانَ عِنْدَهُ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ اللَّيْثِ ‏.‏\hadithno{1293}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas: From Abu Talhah that he said: "O Prophet of Allah! I had purchased some wine for the orphans under my care. He said: 'Spill out the wine, and break the jugs.'" [He said:] There are narrations on this topic from Jabir, 'Aishah, Abu Sa'eed, Ibn Mas'ud, Ibn 'Umar, and Anas. [Abu 'Eisa said:] The Hadith of Abu Talhah, Ath-Thawri reported this Hadith from As-Suddi, from Yahya bin 'Abbad, from Anas: "That Abu Talhah was with him" and this is more correct than the narration of Al-laith (no)}}
\hadithdefcmd{tirmidhi}{1294}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ السُّدِّيِّ، عَنْ يَحْيَى بْنِ عَبَّادٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم أَيُتَّخَذُ الْخَمْرُ خَلاًّ قَالَ ‏ "‏ لاَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1294}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas bin Malik: "I asked the Messenger of Allah (ﷺ) 'Can wine be used for vinegar?' He said: 'No'" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1295}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، قَالَ سَمِعْتُ أَبَا عَاصِمٍ، عَنْ شَبِيبِ بْنِ بِشْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْخَمْرِ عَشَرَةً عَاصِرَهَا وَمُعْتَصِرَهَا وَشَارِبَهَا وَحَامِلَهَا وَالْمَحْمُولَةَ إِلَيْهِ وَسَاقِيَهَا وَبَائِعَهَا وَآكِلَ ثَمَنِهَا وَالْمُشْتَرِيَ لَهَا وَالْمُشْتَرَاةَ لَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ أَنَسٍ ‏.‏ وَقَدْ رُوِيَ نَحْوُ هَذَا عَنِ ابْنِ عَبَّاسٍ وَابْنِ مَسْعُودٍ وَابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1295}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas bin Malik: "The Messenger of Allah (ﷺ) cursed ten involved in wine: The one who presses it, the one who has it pressed, its drinker, its carrier, and the one it is carried to, its server, its seller, the consumption of its price, the one who purchases it and the one it was purchased for." [Abu 'Eisa said:] This Hadith is Gharib as a narration of Anas. Similar to this has been reported from Ibn 'Abbas, Ibn Mas'ud, and Ibn 'Umar, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1296}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَتَى أَحَدُكُمْ عَلَى مَاشِيَةٍ فَإِنْ كَانَ فِيهَا صَاحِبُهَا فَلْيَسْتَأْذِنْهُ فَإِنْ أَذِنَ لَهُ فَلْيَحْتَلِبْ وَلْيَشْرَبْ وَلاَ يَحْمِلْ وَإِنْ لَمْ يَكُنْ فِيهَا أَحَدٌ فَلْيُصَوِّتْ ثَلاَثًا فَإِنْ أَجَابَهُ أَحَدٌ فَلْيَسْتَأْذِنْهُ فَإِنْ لَمْ يُجِبْهُ أَحَدٌ فَلْيَحْتَلِبْ وَلْيَشْرَبْ وَلاَ يَحْمِلْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَمُرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ قَالَ أَبُو عِيسَى وَقَالَ عَلِيُّ بْنُ الْمَدِينِيِّ سَمَاعُ الْحَسَنِ مِنْ سَمُرَةَ صَحِيحٌ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْحَدِيثِ فِي رِوَايَةِ الْحَسَنِ عَنْ سَمُرَةَ وَقَالُوا إِنَّمَا يُحَدِّثُ عَنْ صَحِيفَةِ سَمُرَةَ ‏.‏\hadithno{1296}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah bin Jundab: That the Prophet (ﷺ) said: "When one of you comes upon livestock, if its owner is with it then seek his permission. If he permits him then let him milk it and drink. If there is no one with it then call out three times, if someone answers then seek his permission. If no one answers then let him milk it and drink without carrying (any of it away)." [He said:] There are narrations on this topic from Ibn 'Umar and Abu Sa'eed. [Abu 'Eisa said:] The Hadith of Samurah is a Hasan Gharib Sahih Hadith. This is acted upon according to some of the people of knowledge, and it is the view of Ahmad and Ishaq. [Abu 'Eisa said:] 'Ali bin Al-Madini said: "It is correct that Al-Hasan heard this from Samurah." Some of the people of Hadith criticized the narrations of Al-Hasan from Samurah, they said that he only narrated from a writing of Samurah}}
\hadithdefcmd{tirmidhi}{1297}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ وَهُوَ بِمَكَّةَ يَقُولُ ‏"‏ إِنَّ اللَّهَ وَرَسُولَهُ حَرَّمَ بَيْعَ الْخَمْرِ وَالْمَيْتَةِ وَالْخِنْزِيرِ وَالأَصْنَامِ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ شُحُومَ الْمَيْتَةِ فَإِنَّهُ يُطْلَى بِهَا السُّفُنُ وَيُدْهَنُ بِهَا الْجُلُودُ وَيَسْتَصْبِحُ بِهَا النَّاسُ قَالَ ‏"‏ لاَ هُوَ حَرَامٌ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ قَاتَلَ اللَّهُ الْيَهُودَ إِنَّ اللَّهَ حَرَّمَ عَلَيْهِمُ الشُّحُومَ فَأَجْمَلُوهُ ثُمَّ بَاعُوهُ فَأَكَلُوا ثَمَنَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1297}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir bin ‘Abdullah : That during the Year of the Conquest, while he was in Makkah, he heard the Messenger of Allah (ﷺ) saying: "Indeed Allah and His Messenger unlawful the sale of wine, dead carcasses, the pig, and idols." They said: "O Messenger of Allah! What about the fat of carcasses? For indeed it is used to coat the ships, skins are oiled with it, and people use it for lamps?" He said: "No. It is unlawful." Then, with that, the Messenger of Allah (ﷺ) said: "May Allah fight (curse) the Jews! Indeed Allah made the fat unlawful for them, they melted it, sold it, and consumed its price." [He said:] There are narrations of this topic from 'Umar and Ibn 'Abbas. [Abu 'Eisa said:] The Hadith of Jabir is Hasan Sahih Hadith. This is acted upon according to the people of knowledge}}
\hadithdefcmd{tirmidhi}{1298}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ لَنَا مَثَلُ السَّوْءِ الْعَائِدُ فِي هِبَتِهِ كَالْكَلْبِ يَعُودُ فِي قَيْئِهِ ‏"‏ ‏. قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ يَحِلُّ لأَحَدٍ أَنْ يُعْطِيَ عَطِيَّةً فَيَرْجِعَ فِيهَا إِلاَّ الْوَالِدَ فِيمَا يُعْطِي وَلَدَهُ ‏"‏ ‏.‏\hadithno{1298}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Abbas: That the Messenger of Allah (ﷺ) said: "Ours is not a bad example: The one who takes back his gift is like the dog who takes back his vomit." [He said:] On this topic, there is the narration from Ibn 'Umar from the Prophet (ﷺ) that he said: "It is not lawful for anyone that has given a gift to take it back, except for a father who gives something to his son}}
\hadithdefcmd{tirmidhi}{1299}{حَدَّثَنَا بِذَلِكَ مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ عَنْ حُسَيْنٍ الْمُعَلِّمِ عَنْ عَمْرِو بْنِ شُعَيْبٍ أَنَّهُ سَمِعَ طَاوُسًا يُحَدِّثُ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ يَرْفَعَانِ الْحَدِيثَ إِلَى النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ رضى الله عنهما حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ قَالُوا مَنْ وَهَبَ هِبَةً لِذِي رَحِمٍ مَحْرَمٍ فَلَيْسَ لَهُ أَنْ يَرْجِعَ فِيهَا وَمَنْ وَهَبَ هِبَةً لِغَيْرِ ذِي رَحِمٍ مَحْرَمٍ فَلَهُ أَنْ يَرْجِعَ فِيهَا مَا لَمْ يُثَبْ مِنْهَا ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ ‏.‏ وَقَالَ الشَّافِعِيُّ لاَ يَحِلُّ لأَحَدٍ أَنْ يُعْطِيَ عَطِيَّةً فَيَرْجِعَ فِيهَا إِلاَّ الْوَالِدَ فِيمَا يُعْطِي وَلَدَهُ ‏.‏ وَاحْتَجَّ الشَّافِعِيُّ بِحَدِيثِ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لأَحَدٍ أَنْ يُعْطِيَ عَطِيَّةً فَيَرْجِعَ فِيهَا إِلاَّ الْوَالِدَ فِيمَا يُعْطِي وَلَدَهُ ‏"‏ ‏.‏\hadithno{1299}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib: That he heard Tawus narrating from Ibn 'Umar and Ibn 'Abbas, and they both narrated this Hadith from the Prophet (ﷺ). (A Hadith similar to no. 1298). [Abu 'Eisa said:] The Hadith of Ibn 'Abbas (ra), is a Hasan Sahih Hadith. This Hadith is acted upon according to soe of the people of knowledge among the Companions of the Prophet (ﷺ). They said whoever gives a gift to a closely related relative, then he is not to take back his gift. And whoever gives a gift to someone other then a close relative, then he may take it back as long as it has not been reciprocated. This is the view of Ath-Thawri. Ash-Shafi'i said: "It is not lawful for any that has given a gift to take it back except for what the father gave to his son." Ash-Shafi'i argued with the Hadith of 'Abdullah bin 'Umar from the Prophet (ﷺ): "It is not lawful for anyone that has given a gift to take it back, except for a father who give something to his son}}
\hadithdefcmd{tirmidhi}{1300}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ إِلاَّ أَنَّهُ قَدْ أَذِنَ لأَهْلِ الْعَرَايَا أَنْ يَبِيعُوهَا بِمِثْلِ خَرْصِهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْدِ بْنِ ثَابِتٍ هَكَذَا رَوَى مُحَمَّدُ بْنُ إِسْحَاقَ هَذَا الْحَدِيثَ ‏.‏ وَرَوَى أَيُّوبُ وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ وَمَالِكُ بْنُ أَنَسٍ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ ابْنِ عُمَرَ عَنْ زَيْدِ بْنِ ثَابِتٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ رَخَّصَ فِي الْعَرَايَا ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ إِسْحَاقَ ‏.‏\hadithno{1300}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar: From Zaid bin Thabit that the Prophet (ﷺ) prohibited Al-Muhalaqah and Al-Muzabanah, except that he permitted those practice Al-'Araya to sell it for a like estimation. [He said:] There are narrations on this topic from Abu Hurairah and Jabir. [Abu 'Eisa said:] The Hadith if Zaid bin Thabit: This is how Muhammad bin Ishaq reported this Hadith. Ayyub, 'Ubaidullah bin 'Umar, and Malik bin Anas reported it from Nafi', from 'Ibn Umar: "The Prophet (ﷺ) prohibited Al-Muhalaqah and Al-Muzabanah." With this chain of narration, it has been reported from Ibn 'Umar, from Zaid bin Thabit, from the Prophet (ﷺ) that he permitted Al-'Araya in cases less that five Wasq. This is more correct than the narration of Muhammad bin Ishaq}}
\hadithdefcmd{tirmidhi}{1301}{\hadithno{1301}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1302}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَرْخَصَ فِي بَيْعِ الْعَرَايَا بِخَرْصِهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْهُمُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ وَقَالُوا إِنَّ الْعَرَايَا مُسْتَثْنَاةٌ مِنْ جُمْلَةِ نَهْىِ النَّبِيِّ صلى الله عليه وسلم إِذْ نَهَى عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَاحْتَجُّوا بِحَدِيثِ زَيْدِ بْنِ ثَابِتٍ وَحَدِيثِ أَبِي هُرَيْرَةَ وَقَالُوا لَهُ أَنْ يَشْتَرِيَ مَا دُونَ خَمْسَةِ أَوْسُقٍ ‏.‏ وَمَعْنَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَرَادَ التَّوْسِعَةَ عَلَيْهِمْ فِي هَذَا لأَنَّهُمْ شَكَوْا إِلَيْهِ وَقَالُوا لاَ نَجِدُ مَا نَشْتَرِي مِنَ الثَّمَرِ إِلاَّ بِالتَّمْرِ فَرَخَّصَ لَهُمْ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ أَنْ يَشْتَرُوهَا فَيَأْكُلُوهَا رُطَبًا ‏.‏\hadithno{1302}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: From Zaid bin Thabit that the Messenger of Allah (ﷺ) permitted selling in Al-'Araya by estimating it. [Abu 'Eisa said:] This Hadith is Hasan Sahih. The Hadith of Abu Hurairah is Hasan Sahih. And this is acted upon according to some of the people of knowledge. Among them Ash-Shafi'i, Ahmad and Ishaq. They said Al-'Araya is an exception from the general scope of the prohibition of the Prophet (ﷺ) when he prohibited Al-Muhaqalah and Al-Muzabanah. They argued using this Hadith of Zaid bin Thabit and the Hadith of Abu Hurairah. They said that he may buy what is less than five Wasq. According to some of the people of knowledge, this means that the Prophet (ﷺ) wanted to make less restriction for them on this matter because they complained to him saying: "We dont by anything with dried dates except fruit." So he permitted them to buy less than five Wasq worth so they could eat fresh dates}}
\hadithdefcmd{tirmidhi}{1303}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ الْخَلاَّلُ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، حَدَّثَنَا بُشَيْرُ بْنُ يَسَارٍ، مَوْلَى بَنِي حَارِثَةَ أَنَّ رَافِعَ بْنَ خَدِيجٍ، وَسَهْلَ بْنَ أَبِي حَثْمَةَ، حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْمُزَابَنَةِ الثَّمَرِ بِالتَّمْرِ إِلاَّ لأَصْحَابِ الْعَرَايَا فَإِنَّهُ قَدْ أَذِنَ لَهُمْ وَعَنْ بَيْعِ الْعِنَبِ بِالزَّبِيبِ وَعَنْ كُلِّ ثَمَرٍ بِخَرْصِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1303}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Bushair bin Yasar, the freed slave of Banu Harithah: Rafi' bin Khadij and Sahl bin Abi Hathmah narrated to him that the Messenger of Allah (ﷺ) prohibited Al-Muzabanah sales, (buying) fruits with dried dates, except for those who practice Al-'Araya - for he permitted it for them - and from buying grapes with raisins, and from every fruit by its estimation. [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib from this route}}
\hadithdefcmd{tirmidhi}{1304}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ مَنِيعٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ قُتَيْبَةُ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنَاجَشُوا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ كَرِهُوا النَّجْشَ ‏.‏ قَالَ أَبُو عِيسَى وَالنَّجْشُ أَنْ يَأْتِيَ الرَّجُلُ الَّذِي يَفْصِلُ السِّلْعَةَ إِلَى صَاحِبِ السِّلْعَةِ فَيَسْتَامُ بِأَكْثَرَ مِمَّا تَسْوَى وَذَلِكَ عِنْدَمَا يَحْضُرُهُ الْمُشْتَرِي يُرِيدُ أَنْ يَغْتَرَّ الْمُشْتَرِي بِهِ وَلَيْسَ مِنْ رَأْيِهِ الشِّرَاءُ إِنَّمَا يُرِيدُ أَنْ يَخْدَعَ الْمُشْتَرِيَ بِمَا يَسْتَامُ وَهَذَا ضَرْبٌ مِنَ الْخَدِيعَةِ ‏.‏ قَالَ الشَّافِعِيُّ وَإِنْ نَجَشَ رَجُلٌ فَالنَّاجِشُ آثِمٌ فِيمَا يَصْنَعُ وَالْبَيْعُ جَائِزٌ لأَنَّ الْبَائِعَ غَيْرُ النَّاجِشِ ‏.‏\hadithno{1304}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Do not practice An-Najsh." [He said:] There are narrations on this topic from Ibn 'Umar and Anas. [Abu 'Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge, they disliked An-Najsh. [Abu 'Eisa said:] An-Najsh is when a man who knows about the goods comes to the owner of the goods to offer him more than what it is worth, doing so in the presence of the buyer. He intends to seduce the buyer while he himself does not want to buy it, rather he only wants to deceive the buyer with his offer. And this is type of deceit. Ash-Shafi'i said: "If a man commits An-Najsh the he has sinned due to what he has done, but the sale is permissible, because the buyer did not commit An-Najsh}}
\hadithdefcmd{tirmidhi}{1305}{حَدَّثَنَا هَنَّادٌ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، قَالَ جَلَبْتُ أَنَا وَمَخْرَفَةُ الْعَبْدِيُّ، بَزًّا مِنْ هَجَرَ فَجَاءَنَا النَّبِيُّ صلى الله عليه وسلم فَسَاوَمَنَا بِسَرَاوِيلَ وَعِنْدِي وَزَّانٌ يَزِنُ بِالأَجْرِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِلْوَزَّانِ ‏ "‏ زِنْ وَأَرْجِحْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سُوَيْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَهْلُ الْعِلْمِ يَسْتَحِبُّونَ الرُّجْحَانَ فِي الْوَزْنِ ‏.‏ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ سِمَاكٍ فَقَالَ عَنْ أَبِي صَفْوَانَ وَذَكَرَ الْحَدِيثَ ‏.‏\hadithno{1305}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Suwaid bin Qais: "Makhrafah Al-'Abdi and I brought linens from Hajar. The Prophet (ﷺ) came to us in bargain with us with some pants. There was someone with me who weighed (the goods) to determine the value. So the the Prophet (ﷺ) said to the one weighing: 'Weigh and add more.'" [He said:] There are narrations on this topic from Jabir and Abu Hurairah. [Abu 'Eisa said:] The Hadith of Suwaid is a Hasan Sahih Hadith. The people of knowledge consider it recommended to add more when weighing. Shu'bah reported this Hadith from Simak, so he said: "From Abu Safwan" and he mentioned the narration}}
\hadithdefcmd{tirmidhi}{1306}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ الرَّازِيُّ، عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَنْظَرَ مُعْسِرًا أَوْ وَضَعَ لَهُ أَظَلَّهُ اللَّهُ يَوْمَ الْقِيَامَةِ تَحْتَ ظِلِّ عَرْشِهِ يَوْمَ لاَ ظِلَّ إِلاَّ ظِلُّهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي الْيَسَرِ وَأَبِي قَتَادَةَ وَحُذَيْفَةَ وَابْنِ مَسْعُودٍ وَعُبَادَةَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1306}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Whoever grants respite to an indigent or alleviates it for him, Allah will shade him on the Day of Judgement under His Throne, a Day in which there is no shade except His shade." [He said:] There are narrations on this topic from Abu Al-Yasar, Abu Qatadah, Hudhaifah, Abu Mas'ud, 'Ubadah, and Jabir. [Abu 'Eisa said:] The Hadith if Abu Hurairah is a Hasan Sahih Gharib Hadith from this route}}
\hadithdefcmd{tirmidhi}{1307}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حُوسِبَ رَجُلٌ مِمَّنْ كَانَ قَبْلَكُمْ فَلَمْ يُوجَدْ لَهُ مِنَ الْخَيْرِ شَيْءٌ إِلاَّ أَنَّهُ كَانَ رَجُلاً مُوسِرًا وَكَانَ يُخَالِطُ النَّاسَ وَكَانَ يَأْمُرُ غِلْمَانَهُ أَنْ يَتَجَاوَزُوا عَنِ الْمُعْسِرِ فَقَالَ اللَّهُ عَزَّ وَجَلَّ نَحْنُ أَحَقُّ بِذَلِكَ مِنْهُ تَجَاوَزُوا عَنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الْيَسَرِ كَعْبُ بْنُ عَمْرٍو ‏.‏\hadithno{1307}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Mas'ud: That the Messenger of Allah (ﷺ) said: "A man among those before you was called to reckon and nothing good was found with him. Except that he was a wealthy man so he used to mix with the pople and he would tell his servant to be lenient with the insolvent. So Allah, Mighty and Sublime is He, said: 'We are more worthy of that than him, so be lenient with him.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih. Abu Al-Yasar is Ka'b bin 'Amr}}
\hadithdefcmd{tirmidhi}{1308}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَطْلُ الْغَنِيِّ ظُلْمٌ وَإِذَا أُتْبِعَ أَحَدُكُمْ عَلَى مَلِيٍّ فَلْيَتْبَعْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَالشَّرِيدِ بْنِ سُوَيْدٍ الثَّقَفِيِّ ‏.‏\hadithno{1308}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah: That the Prophet (ﷺ) said: "Procrastination (in paying a debt) by a rich person is oppression. So if your debt is transferred from your debtor to a rich debtor, you should agree." He said: There are narrations on this topic from Ibn 'Umar, and Ash-Sharid bin Suwaid Ath-Thaqafi}}
\hadithdefcmd{tirmidhi}{1309}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ الْهَرَوِيُّ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَطْلُ الْغَنِيِّ ظُلْمٌ وَإِذَا أُحِلْتَ عَلَى مَلِيءٍ فَاتْبَعْهُ وَلاَ تَبِعْ بَيْعَتَيْنِ فِي بَيْعَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَاهُ أَنَّهُ إِذَا أُحِيلَ أَحَدُكُمْ عَلَى مَلِيٍّ فَلْيَتْبَعْ ‏.‏ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا أُحِيلَ الرَّجُلُ عَلَى مَلِيٍّ فَاحْتَالَهُ فَقَدْ بَرِئَ الْمُحِيلُ وَلَيْسَ لَهُ أَنْ يَرْجِعَ عَلَى الْمُحِيلِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا تَوِيَ مَالُ هَذَا بِإِفْلاَسِ الْمُحَالِ عَلَيْهِ فَلَهُ أَنْ يَرْجِعَ عَلَى الأَوَّلِ ‏.‏ وَاحْتَجُّوا بِقَوْلِ عُثْمَانَ وَغَيْرِهِ حِينَ قَالُوا لَيْسَ عَلَى مَالِ مُسْلِمٍ تَوًى ‏.‏ قَالَ إِسْحَاقُ مَعْنَى هَذَا الْحَدِيثِ ‏"‏ لَيْسَ عَلَى مَالِ مُسْلِمٍ تَوًى ‏"‏ ‏.‏ هَذَا إِذَا أُحِيلَ الرَّجُلُ عَلَى آخَرَ وَهُوَ يَرَى أَنَّهُ مَلِيٌّ فَإِذَا هُوَ مُعْدِمٌ فَلَيْسَ عَلَى مَالِ مُسْلِمٍ تَوًى ‏.‏\hadithno{1309}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar: That the Prophet (ﷺ) said: "Procrastination (in paying a debt) by a rich person is oppression. So if your debt is transfered from your debtor you should agree, and do not make two sales in one sale." [Abu 'Eisa said:] The Hadith is the Abu Hurairah (no. 1308) is a Hasan Sahih Hadith. And its meaning is that when the debt of one of you is transferred then agree. Some of the people of knowledge said when a man is offered to transfer his debt to a rich man and he does so, then the transferor is free of it, he is not to seek its return from the transferor. This is the view of Ash-Shafi'i, Ahmad, and Ishaq. Some of the people of knowledge said: "When this wealth could not be collected due to bankruptcy of the one it was transferred to, then he may seek its return to the first one." They argue this view with the saying of 'Uthman and others, when they said: "There is nothing due on a Muslim's wealth that is lost." Ishaq said: "The meaning of this Hadith: 'There is nothing due on a Muslim's wealth that is lost' this is when a man transfers it to another whom he thinks is wealthy, then he becomes bankrupt, so there is nothing due on the Muslim's wealth that is lost}}
\hadithdefcmd{tirmidhi}{1310}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْمُنَابَذَةِ وَالْمُلاَمَسَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ أَنْ يَقُولَ إِذَا نَبَذْتُ إِلَيْكَ الشَّىْءَ فَقَدْ وَجَبَ الْبَيْعُ بَيْنِي وَبَيْنَكَ ‏.‏ وَالْمُلاَمَسَةُ أَنْ يَقُولَ إِذَا لَمَسْتَ الشَّىْءَ فَقَدْ وَجَبَ الْبَيْعُ وَإِنْ كَانَ لاَ يَرَى مِنْهُ شَيْئًا مِثْلَ مَا يَكُونُ فِي الْجِرَابِ أَوْ غَيْرِ ذَلِكَ وَإِنَّمَا كَانَ هَذَا مِنْ بُيُوعِ أَهْلِ الْجَاهِلِيَّةِ فَنَهَى عَنْ ذَلِكَ ‏.‏\hadithno{1310}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) prohibited sales of Al-Munabadhah and Al-Mulamasah." He said: There are narrations on this topic from Abu Sa'eed and Ibn 'Umar. [Abu 'Eisa said:] The Hadith is Abu Hurairah is a Hasan Sahih Hadith. And the meaning of (Munabadhah) in this Hadith is when it is said: "When I throw something to you then the sale between you and I is concluded." And Al-Mulamasah is that he says: "When you touch something then the sale is concluded." Even if he did not see it at all, like if it was inside of a bag or something else. There are merely sales practices of the people of Jahiliyyah so they were prohibited}}
\hadithdefcmd{tirmidhi}{1311}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ أَبِي الْمِنْهَالِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وَهُمْ يُسْلِفُونَ فِي الثَّمَرِ فَقَالَ ‏ "‏ مَنْ أَسْلَفَ فَلْيُسْلِفْ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ أَبِي أَوْفَى وَعَبْدِ الرَّحْمَنِ بْنِ أَبْزَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَجَازُوا السَّلَفَ فِي الطَّعَامِ وَالثِّيَابِ وَغَيْرِ ذَلِكَ مِمَّا يُعْرَفُ حَدُّهُ وَصِفَتُهُ وَاخْتَلَفُوا فِي السَّلَمِ فِي الْحَيَوَانِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ السَّلَمَ فِي الْحَيَوَانِ جَائِزًا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَكَرِهَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ السَّلَمَ فِي الْحَيَوَانِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏ أَبُو الْمِنْهَالِ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ مُطْعِمٍ ‏.‏\hadithno{1311}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas: "When the Prophet (ﷺ) arrived in Al-Madinah, they were paying in advance for fruits. So he said: 'Whoever pays in advance, then let him pay in advance for known measurements (of dates), and known weights for a specified period of time.'" He said: There are narrations on this topic from Ibn Abi Awfa and 'Abdur-Rahman bin Abza. [Abu 'Eisa said:] The Hadith of Ibn 'Abbas is a Hasan Sahih Hadith. This is acted upon according to the people of knowledge among the Companions of the Prophet (ﷺ) and others. They allow for advanced payments on food, garments and other things in which the limits and description are known. They differed over delay in delivery of animals. Some of the people of knowledge among the Companions of the Prophet (ﷺ) and others thought that delay in delivery of animals is allowed. This is the view of Ash-Shafi'i, Ahmad and Ishaq. Some of the people of knowledge among the Companions of the Prophet (ﷺ) and others, disliked delay in delivery of animals. This is the saying of Sufyan and the people of Al-Kufah. And Abu Al-Minhal's (a narrator) name is 'Abdur-Rahman bin Mut'im}}
\hadithdefcmd{tirmidhi}{1312}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ سُلَيْمَانَ الْيَشْكُرِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ لَهُ شَرِيكٌ فِي حَائِطٍ فَلاَ يَبِيعُ نَصِيبَهُ مِنْ ذَلِكَ حَتَّى يَعْرِضَهُ عَلَى شَرِيكِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِسْنَادُهُ لَيْسَ بِمُتَّصِلٍ ‏.‏ سَمِعْتُ مُحَمَّدًا يَقُولُ سُلَيْمَانُ الْيَشْكُرِيُّ يُقَالُ إِنَّهُ مَاتَ فِي حَيَاةِ جَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ وَلَمْ يَسْمَعْ مِنْهُ قَتَادَةُ وَلاَ أَبُو بِشْرٍ ‏.‏ قَالَ مُحَمَّدٌ وَلاَ نَعْرِفُ لأَحَدٍ مِنْهُمْ سَمَاعًا مِنْ سُلَيْمَانَ الْيَشْكُرِيِّ إِلاَّ أَنْ يَكُونَ عَمْرُو بْنُ دِينَارٍ فَلَعَلَّهُ سَمِعَ مِنْهُ فِي حَيَاةِ جَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ وَإِنَّمَا يُحَدِّثُ قَتَادَةُ عَنْ صَحِيفَةِ سُلَيْمَانَ الْيَشْكُرِيِّ وَكَانَ لَهُ كِتَابٌ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ حَدَّثَنَا أَبُو بَكْرٍ الْعَطَّارُ عَبْدُ الْقُدُّوسِ قَالَ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ قَالَ سُلَيْمَانُ التَّيْمِيُّ ذَهَبُوا بِصَحِيفَةِ جَابِرِ بْنِ عَبْدِ اللَّهِ إِلَى الْحَسَنِ الْبَصْرِيِّ فَأَخَذَهَا أَوْ قَالَ فَرَوَاهَا وَذَهَبُوا بِهَا إِلَى قَتَادَةَ فَرَوَاهَا وَأَتَوْنِي بِهَا فَلَمْ أَرْوِهَا ‏.‏ يَقُولُ رَدَدْتُهَا ‏.‏\hadithno{1312}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir bin ‘Abdullah : That Allah's Prophet (ﷺ) said: "Whoever has a partner in an orchard, then he is not to sell his share of that until he proposes that to his partner." [Abu 'Eisa said:] The chain of this Hadith is not connected. I heard Muhammad bin Isma'il saying: It is said that "Sulaiman Al-Yashkuri died during the lifetime of Jabir bin 'Abdullah." He said: "And Qatadah did not hear from him, nor did Abu Bishr." Muhammad said: "We do not know of any of them hearing from Sulaiman Al-Yashkuri except that 'Amr bin Dinar possibly heard from his during the lifetome of Jabir bin 'Abdullah." He said: "Qatadah only narrated from a writing of Sulaiman Al-Yashkuri, and he has a book from Jabir bin 'Abdullah." Abu Bakr Al-'Attar 'Abdul Quddus narrates to us, he said: " 'Ali bin Al-Madini said: 'Yahya bin Sa'eed said: "Sulaiman At-Taymi said: 'They went with the book of Jabir bin 'Abdullah to Al-Hasan Al-Basri and he took it' - or he said - 'and they reported it. Then they took it to Qatadah and reported it, so they gave it to me but I did not report it [he said: 'I refused it'] This was narrated to us by Abu Bakr Al-'Attar from 'Ali bin Al-Madini}}
\hadithdefcmd{tirmidhi}{1313}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَالْمُخَابَرَةِ وَالْمُعَاوَمَةِ وَرَخَّصَ فِي الْعَرَايَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1313}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Az-Zubair: From Jabir that the Prophet (ﷺ) prohibited Al-Muhaqalah, Al-Muzabanah, Al-Mukhabarah, and Al-Mu'awamah, and he permitted it in the case of Al-'Araya. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1314}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا الْحَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَتَادَةَ، وَثَابِتٍ، وَحُمَيْدٍ، عَنْ أَنَسٍ، قَالَ غَلاَ السِّعْرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ سَعِّرْ لَنَا ‏.‏ فَقَالَ ‏ "‏ إِنَّ اللَّهَ هُوَ الْمُسَعِّرُ الْقَابِضُ الْبَاسِطُ الرَّزَّاقُ وَإِنِّي لأَرْجُو أَنْ أَلْقَى رَبِّي وَلَيْسَ أَحَدٌ مِنْكُمْ يَطْلُبُنِي بِمَظْلَمَةٍ فِي دَمٍ وَلاَ مَالٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1314}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas: "Prices became excessive during the time of the Messenger of Allah (ﷺ), so they said: 'O Messenger of Allah! Set prices for us!' So he said: 'Indeed Allah is Al-Musa'ir, Al-Qabid, Al-Basir, Ar-Razzaq. And I am hopeful that I meet my Lord and none of you are seeking (recompense from) me for an injustice involving blood or wealth.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1315}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ عَلَى صُبْرَةٍ مِنْ طَعَامٍ فَأَدْخَلَ يَدَهُ فِيهَا فَنَالَتْ أَصَابِعُهُ بَلَلاً فَقَالَ ‏"‏ يَا صَاحِبَ الطَّعَامِ مَا هَذَا ‏"‏ ‏.‏ قَالَ أَصَابَتْهُ السَّمَاءُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ أَفَلاَ جَعَلْتَهُ فَوْقَ الطَّعَامِ حَتَّى يَرَاهُ النَّاسُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ غَشَّ فَلَيْسَ مِنَّا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي الْحَمْرَاءِ وَابْنِ عَبَّاسٍ وَبُرَيْدَةَ وَأَبِي بُرْدَةَ بْنِ نِيَارٍ وَحُذَيْفَةَ بْنِ الْيَمَانِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا الْغِشَّ وَقَالُوا الْغِشُّ حَرَامٌ ‏.‏\hadithno{1315}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) passed by a pile of food. He put his fingers in it and felt wetness. He said: 'O owner of the food! What is this ?' He replied: 'It was rained upon O Messenger of Allah.' He said: 'Why not put it on top of the food so the people can see it?' Then he said: 'Whoever cheats, he is not one of us.'" He said: There are narrations on this topic from Ibn 'Umar, Abu Al-Hamra', Ibn 'Abbas, Buraidah, Abu Burdah bin Niyar, and Hudhaifah bin Al-Yaman. [Abu 'Eisa said:] The Hadith of Abu Hurairah is Hasan Sahih Hadith. This is acted upon according to the people of knowledge. They dislike cheating and they say that cheating is unlawful}}
\hadithdefcmd{tirmidhi}{1316}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ صَالِحٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ اسْتَقْرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم سِنًّا فَأَعْطَاهُ سِنًّا خَيْرًا مِنْ سِنِّهِ وَقَالَ ‏ "‏ خِيَارُكُمْ أَحَاسِنُكُمْ قَضَاءً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي رَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ وَسُفْيَانُ عَنْ سَلَمَةَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ لَمْ يَرَوْا بِاسْتِقْرَاضِ السِّنِّ بَأْسًا مِنَ الإِبِلِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَكَرِهَ بَعْضُهُمْ ذَلِكَ ‏.‏\hadithno{1316}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) took a camel of a particular age on loan. He gave back to him a camel of a better age than the one he was given. He said: 'The best among you is the best in repaying.'" He said: There is something on this topic from Abu Rafi'. [Abu 'Eisa said:] The Hadith of Abu Hurairah is a Hasan Sahih Hadith. Shu'bah and Sufyan reported it from Salamah. This is acted upon according to some of the people of knowledge, they saw no harm is taking a camel of a particular age as a loan. This is the view of Ash-Shafi'i, Ahmad, and Ishaq. But some of them disliked that}}
\hadithdefcmd{tirmidhi}{1317}{\hadithno{1317}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih Hadith; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1318}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي رَافِعٍ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ اسْتَسْلَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَكْرًا فَجَاءَتْهُ إِبِلٌ مِنَ الصَّدَقَةِ ‏.‏ قَالَ أَبُو رَافِعٍ فَأَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَقْضِيَ الرَّجُلَ بَكْرَهُ ‏.‏ فَقُلْتُ لاَ أَجِدُ فِي الإِبِلِ إِلاَّ جَمَلاً خِيَارًا رَبَاعِيًّا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعْطِهِ إِيَّاهُ فَإِنَّ خِيَارَ النَّاسِ أَحْسَنُهُمْ قَضَاءً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1318}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Rafi', the freed slave of the Messenger of Allah (ﷺ): "The Messenger of Allah got a camel in advance. Some camels from the charity." Abu Rafi' said: "So the Messenger of Allah (ﷺ) told me to pay the man back for his camel. I said: 'I did not find among the camels but a superior selection of Raba'. The Messenger of Allah (ﷺ) said: 'Give it to him, for indeed the base of people is the best of them in repaying.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1319}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ الرَّازِيُّ، عَنْ مُغِيرَةَ بْنِ مُسْلِمٍ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ يُحِبُّ سَمْحَ الْبَيْعِ سَمْحَ الشِّرَاءِ سَمْحَ الْقَضَاءِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ يُونُسَ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1319}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Indeed Allah loves tolerance in selling, tolerance in buying, and tolerance in repaying." He said: There is something on this topic from Jabir. [Abu 'Eisa said:] This Hadith is Gharib. Some of them reported this Hadith from Yunus, from Sa'eed Al-Maqburi, from Abu Hurairah}}
\hadithdefcmd{tirmidhi}{1320}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ زَيْدِ بْنِ عَطَاءِ بْنِ السَّائِبِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَفَرَ اللَّهُ لِرَجُلٍ كَانَ قَبْلَكُمْ كَانَ سَهْلاً إِذَا بَاعَ سَهْلاً إِذَا اشْتَرَى سَهْلاً إِذَا اقْتَضَى ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ صَحِيحٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1320}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir: That the Messenger of Allah (ﷺ) said: "Allah forgave a man who was before you: He was tolerant when selling, tolerant when purchasing, and tolerant when repaying." He said: This Hadith is Gharib Sahih Hasan from this route}}
\hadithdefcmd{tirmidhi}{1321}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَارِمٌ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، أَخْبَرَنَا يَزِيدُ بْنُ خُصَيْفَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتُمْ مَنْ يَبِيعُ أَوْ يَبْتَاعُ فِي الْمَسْجِدِ فَقُولُوا لاَ أَرْبَحَ اللَّهُ تِجَارَتَكَ وَإِذَا رَأَيْتُمْ مَنْ يَنْشُدُ فِيهِ ضَالَّةً فَقُولُوا لاَ رَدَّ اللَّهُ عَلَيْكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ كَرِهُوا الْبَيْعَ وَالشِّرَاءَ فِي الْمَسْجِدِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي الْبَيْعِ وَالشِّرَاءِ فِي الْمَسْجِدِ ‏\hadithno{1321}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "When you see someone selling or buying in the Masjid then say: 'May Allah not profit your business.' And when you see someone announcing about something lost then say: 'May Allah not return it to you.'" The Hadith of Abu Hurairah is Hasan Gharib. This is acted upon according to some of the people of knowledge. They dislike selling and buying in the Masjid. This is the view of Ahmad and Ishaq. Some of the people of knowledge permitted selling and buying in the Masjid}}
