% Auto-generated chapter 37 for ibnmajah
% Hadiths in this chapter: 242

\hadithdefcmd{ibnmajah}{4100}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَمْرُو بْنُ وَاقِدٍ الْقُرَشِيُّ، حَدَّثَنَا يُونُسُ بْنُ مَيْسَرَةَ بْنِ حَلْبَسٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ذَرٍّ الْغِفَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ الزَّهَادَةُ فِي الدُّنْيَا بِتَحْرِيمِ الْحَلاَلِ وَلاَ فِي إِضَاعَةِ الْمَالِ وَلَكِنِ الزَّهَادَةُ فِي الدُّنْيَا أَنْ لاَ تَكُونَ بِمَا فِي يَدَيْكَ أَوْثَقَ مِنْكَ بِمَا فِي يَدِ اللَّهِ وَأَنْ تَكُونَ فِي ثَوَابِ الْمُصِيبَةِ إِذَا أُصِبْتَ بِهَا أَرْغَبَ مِنْكَ فِيهَا لَوْ أَنَّهَا أُبْقِيَتْ لَكَ ‏"‏ ‏.‏ قَالَ هِشَامٌ كَانَ أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ يَقُولُ مِثْلُ هَذَا الْحَدِيثِ فِي الأَحَادِيثِ كَمِثْلِ الإِبْرِيزِ فِي الذَّهَبِ ‏.‏\hadithno{4100}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Dharr Al-Ghifari that the Messenger of Allah (ﷺ) said:“Indifference towards this world does not mean forbidding what is permitted, or squandering wealth, rather indifference towards this world means not thinking that what you have in your hand is more reliable than what is in Allah’s Hand, and it means feeling that the reward for a calamity that befalls you is greater than that which the calamity makes you miss out on.’”}}
\hadithdefcmd{ibnmajah}{4101}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْحَكَمُ بْنُ هِشَامٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ أَبِي فَرْوَةَ، عَنْ أَبِي خَلاَّدٍ، - وَكَانَتْ لَهُ صُحْبَةٌ - قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا رَأَيْتُمُ الرَّجُلَ قَدْ أُعْطِيَ زُهْدًا فِي الدُّنْيَا وَقِلَّةَ مَنْطِقٍ فَاقْتَرِبُوا مِنْهُ فَإِنَّهُ يُلَقَّى الْحِكْمَةَ ‏"‏ ‏.‏\hadithno{4101}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif}\hadithtrans{It was narrated that Abu Khallad, who was one of the Companions of the Prophet (ﷺ), said:“The Messenger of Allah (ﷺ) said: ‘If you see a man who has been given indifference with regard to this world and who speaks little, then draw close to him for he will indeed offer wisdom.’”}}
\hadithdefcmd{ibnmajah}{4102}{حَدَّثَنَا أَبُو عُبَيْدَةَ بْنُ أَبِي السَّفَرِ، حَدَّثَنَا شِهَابُ بْنُ عَبَّادٍ، حَدَّثَنَا خَالِدُ بْنُ عَمْرٍو الْقُرَشِيُّ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ دُلَّنِي عَلَى عَمَلٍ إِذَا أَنَا عَمِلْتُهُ أَحَبَّنِيَ اللَّهُ وَأَحَبَّنِيَ النَّاسُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ازْهَدْ فِي الدُّنْيَا يُحِبَّكَ اللَّهُ وَازْهَدْ فِيمَا فِي أَيْدِي النَّاسِ يُحِبُّوكَ ‏"‏ ‏.‏\hadithno{4102}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sahl bin Sa’d As-Sa’idi said:“A man came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, show me a deed which, if I do it, Allah will love me and people will love me. The Messenger of Allah (ﷺ) said: “Be indifferent towards this world, and Allah will love you. Be indifferent to what is in people’s hands, and they will love you.”}}
\hadithdefcmd{ibnmajah}{4103}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ سَمُرَةَ بْنِ سَهْمٍ، - رَجُلٌ مِنْ قَوْمِهِ - قَالَ نَزَلْتُ عَلَى أَبِي هَاشِمِ بْنِ عُتْبَةَ وَهُوَ طَعِينٌ فَأَتَاهُ مُعَاوِيَةُ يَعُودُهُ فَبَكَى أَبُو هَاشِمٍ فَقَالَ مُعَاوِيَةُ مَا يُبْكِيكَ أَىْ خَالِ أَوَجَعٌ يُشْئِزُكَ أَمْ عَلَى الدُّنْيَا فَقَدْ ذَهَبَ صَفْوُهَا قَالَ عَلَى كُلٍّ لاَ وَلَكِنْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَهِدَ إِلَىَّ عَهْدًا وَدِدْتُ أَنِّي كُنْتُ تَبِعْتُهُ قَالَ ‏ "‏ إِنَّكَ لَعَلَّكَ تُدْرِكُ أَمْوَالاً تُقْسَمُ بَيْنَ أَقْوَامٍ وَإِنَّمَا يَكْفِيكَ مِنْ ذَلِكَ خَادِمٌ وَمَرْكَبٌ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ فَأَدْرَكْتُ فَجَمَعْتُ ‏.‏\hadithno{4103}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Wa’il that a man from his people – Samurah bin Sahm – said:“We stopped with Abu Hashim bin ‘Utbah, who had been stabbed, and Mu’awiyah came to visit him. Abu Hashim wept and Mu’awiyah said to him: ‘Why are you weeping, O maternal uncle? Is there some pain bothering you, or is it because of this world, the best of which has already passed?’ He said: ‘It is not for any of these reasons. But the Messenger of Allah (ﷺ) gave me some advice and I wish that I had followed it. He (ﷺ) said: “There may come a time when you will see wealth divided among the people, and all you will need of that is a servant and a mount to ride in the cause of Allah.” That time came, but I accumulated wealth.’”}}
\hadithdefcmd{ibnmajah}{4104}{حَدَّثَنَا الْحَسَنُ بْنُ أَبِي الرَّبِيعِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ اشْتَكَى سَلْمَانُ فَعَادَهُ سَعْدٌ فَرَآهُ يَبْكِي فَقَالَ لَهُ سَعْدٌ مَا يُبْكِيكَ يَا أَخِي أَلَيْسَ قَدْ صَحِبْتَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَلَيْسَ أَلَيْسَ قَالَ سَلْمَانُ مَا أَبْكِي وَاحِدَةً مِنَ اثْنَتَيْنِ مَا أَبْكِي صَبًّا لِلدُّنْيَا وَلاَ كَرَاهِيَةً لِلآخِرَةِ وَلَكِنْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَهِدَ إِلَىَّ عَهْدًا فَمَا أُرَانِي إِلاَّ قَدْ تَعَدَّيْتُ ‏.‏ قَالَ وَمَا عَهِدَ إِلَيْكَ قَالَ عَهِدَ إِلَىَّ أَنَّهُ يَكْفِي أَحَدَكُمْ مِثْلُ زَادِ الرَّاكِبِ وَلاَ أُرَانِي إِلاَّ قَدْ تَعَدَّيْتُ وَأَمَّا أَنْتَ يَا سَعْدُ فَاتَّقِ اللَّهَ عِنْدَ حُكْمِكَ إِذَا حَكَمْتَ وَعِنْدَ قَسْمِكَ إِذَا قَسَمْتَ وَعِنْدَ هَمِّكَ إِذَا هَمَمْتَ ‏.‏ قَالَ ثَابِتٌ فَبَلَغَنِي أَنَّهُ مَا تَرَكَ إِلاَّ بِضْعَةً وَعِشْرِينَ دِرْهَمًا مِنْ نَفَقَةٍ كَانَتْ عِنْدَهُ ‏.‏\hadithno{4104}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Thabit that Anas said:“Salman felt sick and Sa’d came to visit him, and when he saw him he wept. Sa’d said to him: ‘Why are you weeping, my brother? Are you not a Companion of the Messenger of Allah (ﷺ)? Are you not? Are you not?’ Salman said: ‘I am only weeping for one reason: I am not weeping because of longing for this world or for dislike of the Hereafter. But the Messenger of Allah (ﷺ) gave me some advice and I think that I have transgressed.’ He said: ‘What was his advice to you?’ He said: ‘He advised me that something like the provision of a rider is sufficient for anyone of you, and I think that I have transgressed that. As for you, O Sa’d, fear Allah when you pass a verdict, and when you distribute (spoils of war), and when you decide to do anything.’”}}
\hadithdefcmd{ibnmajah}{4105}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عُمَرَ بْنِ سُلَيْمَانَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبَانَ بْنِ عُثْمَانَ بْنِ عَفَّانَ، عَنْ أَبِيهِ، قَالَ خَرَجَ زَيْدُ بْنُ ثَابِتٍ مِنْ عِنْدِ مَرْوَانَ بِنِصْفِ النَّهَارِ فَقُلْتُ مَا بَعَثَ إِلَيْهِ هَذِهِ السَّاعَةَ إِلاَّ لِشَىْءٍ سَأَلَ عَنْهُ ‏.‏ فَسَأَلْتُهُ فَقَالَ سَأَلَنَا عَنْ أَشْيَاءَ سَمِعْنَاهَا مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ كَانَتِ الدُّنْيَا هَمَّهُ فَرَّقَ اللَّهُ عَلَيْهِ أَمْرَهُ وَجَعَلَ فَقْرَهُ بَيْنَ عَيْنَيْهِ وَلَمْ يَأْتِهِ مِنَ الدُّنْيَا إِلاَّ مَا كُتِبَ لَهُ وَمَنْ كَانَتِ الآخِرَةُ نِيَّتَهُ جَمَعَ اللَّهُ لَهُ أَمْرَهُ وَجَعَلَ غِنَاهُ فِي قَلْبِهِ وَأَتَتْهُ الدُّنْيَا وَهِيَ رَاغِمَةٌ ‏"‏ ‏.‏\hadithno{4105}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Abdur-Rahman bin Aban bin ‘Uthman bin ‘Affan narrated that his father said:“Zaid bin Thabit departed from Marwan at mid-day. I said: ‘He has not sent him out at this time of the day except for something he asked.’ So I asked him, and he said: ‘He asked me about some things we heard from the Messenger of Allah (ﷺ) say: “Whoever is focused only on this world, Allah will confound his affairs and make him fear poverty constantly, and he will not get anything of this world except that which has been decreed for him. Whoever is focused on the Hereafter, Allah will settle his affairs for him and make him feel content with his lot, and his provision and worldly gains will undoubtedly come to him.”}}
\hadithdefcmd{ibnmajah}{4106}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَالْحُسَيْنُ بْنُ عَبْدِ الرَّحْمَنِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُعَاوِيَةَ النَّصْرِيِّ، عَنْ نَهْشَلٍ، عَنِ الضَّحَّاكِ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، قَالَ قَالَ عَبْدُ اللَّهِ سَمِعْتُ نَبِيَّكُمْ، ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ جَعَلَ الْهُمُومَ هَمًّا وَاحِدًا هَمَّ الْمَعَادِ كَفَاهُ اللَّهُ هَمَّ دُنْيَاهُ وَمَنْ تَشَعَّبَتْ بِهِ الْهُمُومُ فِي أَحْوَالِ الدُّنْيَا لَمْ يُبَالِ اللَّهُ فِي أَىِّ أَوْدِيَتِهِ هَلَكَ ‏"‏ ‏.‏\hadithno{4106}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{‘Abdullah said:“I heard your Prophet (ﷺ) say: ‘Whoever focuses all his concerns on one thing, the Hereafter, Allah will relieve him of worldly concerns, but whoever has disparate concerns scattered among a number of worldly issues, Allah will not care in which of its valleys he died.’”}}
\hadithdefcmd{ibnmajah}{4107}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ عِمْرَانَ بْنِ زَائِدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي خَالِدٍ الْوَالِبِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ - وَلاَ أَعْلَمُهُ إِلاَّ قَدْ رَفَعَهُ - قَالَ ‏ "‏ يَقُولُ اللَّهُ سُبْحَانَهُ يَا ابْنَ آدَمَ تَفَرَّغْ لِعِبَادَتِي أَمْلأْ صَدْرَكَ غِنًى وَأَسُدَّ فَقْرَكَ وَإِنْ لَمْ تَفْعَلْ مَلأْتُ صَدْرَكَ شُغْلاً وَلَمْ أَسُدَّ فَقْرَكَ ‏"‏ ‏.‏\hadithno{4107}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Abu) Khalid Al-Walibi narrated from Abu Hurairah and he (one of the narrators) said:“I do not know except that he attributed it to the Prophet (ﷺ)” – “Allah says: ‘O son of Adam, devote yourself to My worship, and I will fill your heart with contentment and take care of your poverty; but if you do not do that, then I will fill your heart with worldly concerns and will not take care of your poverty.’”}}
\hadithdefcmd{ibnmajah}{4108}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، قَالَ سَمِعْتُ الْمُسْتَوْرِدَ، أَخَا بَنِي فِهْرٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا مَثَلُ الدُّنْيَا فِي الآخِرَةِ إِلاَّ مَثَلُ مَا يَجْعَلُ أَحَدُكُمْ إِصْبَعَهُ فِي الْيَمِّ فَلْيَنْظُرْ بِمَ يَرْجِعُ ‏"‏ ‏.‏\hadithno{4108}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Mustawrid, a brother of Banu Fihr, said:“I heard the Messenger of Allah (ﷺ) say: ‘The likeness of this world in comparison to the Hereafter is that of anyone of you dipping his finger into the sea: let him see what he brings forth.’”}}
\hadithdefcmd{ibnmajah}{4109}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا الْمَسْعُودِيُّ، أَخْبَرَنِي عَمْرُو بْنُ مُرَّةَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ اضْطَجَعَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَلَى حَصِيرٍ فَأَثَّرَ فِي جِلْدِهِ فَقُلْتُ بِأَبِي وَأُمِّي يَا رَسُولَ اللَّهِ لَوْ كُنْتَ آذَنْتَنَا فَفَرَشْنَا لَكَ عَلَيْهِ شَيْئًا يَقِيكَ مِنْهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا أَنَا وَالدُّنْيَا إِنَّمَا أَنَا وَالدُّنْيَا كَرَاكِبٍ اسْتَظَلَّ تَحْتَ شَجَرَةٍ ثُمَّ رَاحَ وَتَرَكَهَا ‏"‏ ‏.‏\hadithno{4109}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Abdullah said:“The Prophet (ﷺ) lay down on a reed mat, and it left marks on his skin. I said: ‘May my father and mother be ransomed for you, O Messenger of Allah! If you had told us we would have provided you with something that would save you this trouble.’ The Messenger of Allah (ﷺ) said: ‘What is there between myself and the world? This world and I are just like a rider who stops to rest beneath the shade of a tree then goes and leaves it.’”}}
\hadithdefcmd{ibnmajah}{4110}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَإِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالُوا حَدَّثَنَا أَبُو يَحْيَى، زَكَرِيَّا بْنُ مَنْظُورٍ حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِذِي الْحُلَيْفَةِ فَإِذَا هُوَ بِشَاةٍ مَيِّتَةٍ شَائِلَةٍ بِرِجْلِهَا فَقَالَ ‏ "‏ أَتُرَوْنَ هَذِهِ هَيِّنَةً عَلَى صَاحِبِهَا فَوَالَّذِي نَفْسِي بِيَدِهِ لَلدُّنْيَا أَهْوَنُ عَلَى اللَّهِ مِنْ هَذِهِ عَلَى صَاحِبِهَا وَلَوْ كَانَتِ الدُّنْيَا تَزِنُ عِنْدَ اللَّهِ جَنَاحَ بَعُوضَةٍ مَا سَقَى كَافِرًا مِنْهَا قَطْرَةً أَبَدًا ‏"‏ ‏.‏\hadithno{4110}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sahl bin Sa’d said:“We were with the Messenger of Allah (ﷺ) in Dhul-Hulaifah, when we saw a dead sheep lifting its leg (because of bloating). He said: ‘Don’t you think this is worthless to its owner? By the One in Whose hand is my soul, this world is more worthless to Allah than this (dead sheep) is to its owner. If this world was worth the wing of a mosquito to Allah, the disbeliever would not have a drop to drink from it.’”}}
\hadithdefcmd{ibnmajah}{4111}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مُجَالِدِ بْنِ سَعِيدٍ الْهَمْدَانِيِّ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ الْهَمْدَانِيِّ، قَالَ حَدَّثَنَا الْمُسْتَوْرِدُ بْنُ شَدَّادٍ، قَالَ إِنِّي لَفِي الرَّكْبِ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِذْ أَتَى عَلَى سَخْلَةٍ مَنْبُوذَةٍ قَالَ فَقَالَ ‏"‏ أَتُرَوْنَ هَذِهِ هَانَتْ عَلَى أَهْلِهَا ‏"‏ ‏.‏ قَالَ قِيلَ يَا رَسُولَ اللَّهِ مِنْ هَوَانِهَا أَلْقَوْهَا ‏.‏ أَوْ كَمَا قَالَ قَالَ ‏"‏ فَوَالَّذِي نَفْسِي بِيَدِهِ لَلدُّنْيَا أَهْوَنُ عَلَى اللَّهِ مِنْ هَذِهِ عَلَى أَهْلِهَا ‏"‏ ‏.‏\hadithno{4111}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Mustawrid bin Shaddad said:“I was riding with the Messenger of Allah (ﷺ) when he came across a dead lamb that had been thrown out.’ He said: ‘Don’t you think that this is worthless to its owners?’ It was said: ‘O Messenger of Allah, it is because it is worthless that they have thrown it out, - or words to that effect. He said: ‘By the One in Whose Hand is my soul, this world is more worthless to Allah than this is to its owners.’”}}
\hadithdefcmd{ibnmajah}{4112}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا أَبُو خُلَيْدٍ، عُتْبَةُ بْنُ حَمَّادٍ الدِّمَشْقِيُّ عَنِ ابْنِ ثَوْبَانَ، عَنْ عَطَاءِ بْنِ قُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ ضَمْرَةَ السَّلُولِيِّ، قَالَ حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ يَقُولُ ‏ "‏ الدُّنْيَا مَلْعُونَةٌ مَلْعُونٌ مَا فِيهَا إِلاَّ ذِكْرَ اللَّهِ وَمَا وَالاَهُ أَوْ عَالِمًا أَوْ مُتَعَلِّمًا ‏"‏ ‏.‏\hadithno{4112}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said:“I heard the Messenger of Allah (ﷺ) saying: ‘This world is cursed and what is in it is cursed, except the remembrance of Allah (dhikr) and what is conducive to that, or one who has knowledge or who acquires knowledge.’”}}
\hadithdefcmd{ibnmajah}{4113}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الدُّنْيَا سِجْنُ الْمُؤْمِنِ وَجَنَّةُ الْكَافِرِ ‏"‏ ‏.‏\hadithno{4113}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“This world is a prison for the believer and a paradise for the disbeliever.’”}}
\hadithdefcmd{ibnmajah}{4114}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ لَيْثٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَخَذَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِبَعْضِ جَسَدِي فَقَالَ ‏ "‏ يَا عَبْدَ اللَّهِ كُنْ فِي الدُّنْيَا كَأَنَّكَ غَرِيبٌ أَوْ كَأَنَّكَ عَابِرُ سَبِيلٍ وَعُدَّ نَفْسَكَ مِنْ أَهْلِ الْقُبُورِ ‏"‏ ‏.‏\hadithno{4114}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) took hold of some part of my body and said: ‘O ‘Abdullah, be in this world like a stranger, or one who is passing through, and consider yourself as one of the people of the graves.’”}}
\hadithdefcmd{ibnmajah}{4115}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُوَيْدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ زَيْدِ بْنِ وَاقِدٍ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَلاَ أُخْبِرُكَ عَنْ مُلُوكِ الْجَنَّةِ ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏ قَالَ ‏"‏ رَجُلٌ ضَعِيفٌ مُسْتَضْعَفٌ ذُو طِمْرَيْنِ لاَ يُؤْبَهُ لَهُ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏ ‏.‏\hadithno{4115}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mu’adh bin Jabal that the Messenger of Allah (ﷺ) said:“Shall I not tell you about the kings of Paradise?’ I said: ‘Yes.’ He said: ‘A weak and oppressed man who wears tattered clothes and is not paid any heed. If he swears (an oath) by Allah, Allah fulfills it.’”}}
\hadithdefcmd{ibnmajah}{4116}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، قَالَ سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَلاَ أُنَبِّئُكُمْ بِأَهْلِ الْجَنَّةِ كُلُّ ضَعِيفٍ مُتَضَعِّفٍ أَلاَ أُنَبِّئُكُمْ بِأَهْلِ النَّارِ كُلُّ عُتُلٍّ جَوَّاظٍ مُسْتَكْبِرٍ ‏"‏ ‏.‏\hadithno{4116}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Harithah bin Wahb narrated that the Messenger of Allah (ﷺ) said:“Shall I not tell you about the people of Paradise? Every weak and oppressed one. Shall I not tell you about the people of Hell? Every harsh, haughty and arrogant one.”}}
\hadithdefcmd{ibnmajah}{4117}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، عَنْ صَدَقَةَ بْنِ عَبْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ مُرَّةَ، عَنْ أَيُّوبَ بْنِ سُلَيْمَانَ، عَنْ أَبِي أُمَامَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ أَغْبَطَ النَّاسِ عِنْدِي مُؤْمِنٌ خَفِيفُ الْحَاذِ ذُو حَظٍّ مِنْ صَلاَةٍ غَامِضٌ فِي النَّاسِ لاَ يُؤْبَهُ لَهُ كَانَ رِزْقُهُ كَفَافًا وَصَبَرَ عَلَيْهِ عَجِلَتْ مَنِيَّتُهُ وَقَلَّ تُرَاثُهُ وَقَلَّتْ بَوَاكِيهِ ‏"‏ ‏.‏\hadithno{4117}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that the Messenger of Allah (ﷺ) said:“The one who most deserved to be envied, un my view, is the one who has the least burden, who prays a great deal and finds joy in prayer, and who is unknown among people and is not paid any heed. His provision will be sufficient, he will be content with it, his death will come quickly, his estate will be small and his mourners will be few.”}}
\hadithdefcmd{ibnmajah}{4118}{حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ الْحِمْصِيُّ، حَدَّثَنَا أَيُّوبُ بْنُ سُوَيْدٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أُمَامَةَ الْحَارِثِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْبَذَاذَةُ مِنَ الإِيمَانِ ‏"‏ ‏.‏ قَالَ الْبَذَاذَةُ الْقَشَافَةُ يَعْنِي التَّقَشُّفَ ‏.‏\hadithno{4118}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin Abi Umamah Al-Harithi that his father said:“The Messenger of Allah (ﷺ) said: ‘Simplicity is part of faith.’”}}
\hadithdefcmd{ibnmajah}{4119}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنِ ابْنِ خُثَيْمٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ أَلاَ أُنَبِّئُكُمْ بِخِيَارِكُمْ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ خِيَارُكُمُ الَّذِينَ إِذَا رُءُوا ذُكِرَ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4119}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Asma’ bint Yazid that she heard the Messenger of Allah (ﷺ) say:“Shall I not tell you of the best of you?” They said: “Yes, O Messenger of Allah.” He said: “The best of you are those who, when they are seen, Allah the Mighty, the Majestic, is remembered.”}}
\hadithdefcmd{ibnmajah}{4120}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ مَرَّ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ رَجُلٌ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مَا تَقُولُونَ فِي هَذَا الرَّجُلِ قَالُوا رَأْيَكَ فِي ‏.‏ هَذَا نَقُولُ هَذَا مِنْ أَشْرَافِ النَّاسِ هَذَا حَرِيٌّ إِنْ خَطَبَ أَنْ يُخَطَّبَ وَإِنْ شَفَعَ أَنْ يُشَفَّعَ وَإِنْ قَالَ أَنْ يُسْمَعَ لِقَوْلِهِ ‏.‏ فَسَكَتَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَمَرَّ رَجُلٌ آخَرُ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مَا تَقُولُونَ فِي هَذَا ‏"‏ ‏.‏ قَالُوا نَقُولُ وَاللَّهِ يَا رَسُولَ اللَّهِ هَذَا مِنْ فُقَرَاءِ الْمُسْلِمِينَ هَذَا حَرِيٌّ إِنْ خَطَبَ لَمْ يُنْكَحْ وَإِنْ شَفَعَ لاَ يُشَفَّعْ وَإِنْ قَالَ لاَ يُسْمَعْ لِقَوْلِهِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ لَهَذَا خَيْرٌ مِنْ مِلْءِ الأَرْضِ مِثْلَ هَذَا ‏"‏ ‏.‏\hadithno{4120}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Sahl bin Sa’d As-Sa’idi said:“A man passed by the Messenger of Allah (ﷺ) and the Prophet (ﷺ) said: ‘What do you say about this man?’ They said: ‘We agree with your opinion concerning him. We say: He is one of the noblest of people. If he proposes marriage, his proposal deserves to be accepted; and if he intercedes, his intercession deserves to be accepted; and if he speaks, he deserves to be listened to.’ The Prophet (ﷺ) remained silent, and another man passed by. The Prophet (ﷺ) said: ‘What do you think about this man?’ We said: ‘By Allah, O Messenger of Allah, this is one of the poor Muslims. If he proposes marriage, he does not deserve to get married; and if he intercedes, his intercession does not deserve to be accepted; and if he speaks, he does not deserve to be listened to.’ The Prophet (ﷺ) said: ‘This one is better than an earthful of (men like) the other man.’”}}
\hadithdefcmd{ibnmajah}{4121}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ يُوسُفَ الْجُبَيْرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ عِيسَى، حَدَّثَنَا مُوسَى بْنُ عُبَيْدَةَ، أَخْبَرَنِي الْقَاسِمُ بْنُ مِهْرَانَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ يُحِبُّ عَبْدَهُ الْمُؤْمِنَ الْفَقِيرَ الْمُتَعَفِّفَ أَبَا الْعِيَالِ ‏"‏ ‏.‏\hadithno{4121}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Imran bin Husain that the Messenger of Allah (ﷺ) said:“Allah loves His believing slave who is poor, does not beg and has many children.”}}
\hadithdefcmd{ibnmajah}{4122}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَدْخُلُ فُقَرَاءُ الْمُؤْمِنِينَ الْجَنَّةَ قَبْلَ الأَغْنِيَاءِ بِنِصْفِ يَوْمٍ خَمْسِمِائَةِ عَامٍ ‏"‏ ‏.‏\hadithno{4122}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The poor believers will enter Paradise half a day – five hundred years – before the rich.’”}}
\hadithdefcmd{ibnmajah}{4123}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا بَكْرُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عِيسَى بْنُ الْمُخْتَارِ، عَنْ مُحَمَّدِ بْنِ أَبِي لَيْلَى، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ فُقَرَاءَ الْمُهَاجِرِينَ يَدْخُلُونَ الْجَنَّةَ قَبْلَ أَغْنِيَائِهِمْ بِمِقْدَارِ خَمْسِمِائَةِ سَنَةٍ ‏"‏ ‏.‏\hadithno{4123}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“The poor Muhajirun will enter Paradise before the rich, the equivalent of five hundred years.”}}
\hadithdefcmd{ibnmajah}{4124}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا أَبُو غَسَّانَ، بُهْلُولٌ حَدَّثَنَا مُوسَى بْنُ عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ اشْتَكَى فُقَرَاءُ الْمُهَاجِرِينَ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مَا فَضَّلَ اللَّهُ بِهِ عَلَيْهِمْ أَغْنِيَاءَهُمْ فَقَالَ ‏"‏ يَا مَعْشَرَ الْفُقَرَاءِ أَلاَ أُبَشِّرُكُمْ أَنَّ فُقَرَاءَ الْمُؤْمِنِينَ يَدْخُلُونَ الْجَنَّةَ قَبْلَ أَغْنِيَائِهِمْ بِنِصْفِ يَوْمٍ خَمْسِمِائَةِ عَامٍ ‏"‏ ‏. ثُمَّ تَلاَ مُوسَى هَذِهِ الآيَةَ ‏\{وَإِنَّ يَوْمًا عِنْدَ رَبِّكَ كَأَلْفِ سَنَةٍ مِمَّا تَعُدُّونَ \}‏\hadithno{4124}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“The poor Muhajirun complained to the Messenger of Allah (ﷺ) about that with which Allah had favored the rich over them. He said: ‘O poor people, shall I not give you the glad tidings that the poor believers will enter Paradise half a day, five hundred years, before the rich?’”}}
\hadithdefcmd{ibnmajah}{4125}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ التَّيْمِيُّ أَبُو يَحْيَى، حَدَّثَنَا إِبْرَاهِيمُ أَبُو إِسْحَاقَ الْمَخْزُومِيُّ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ جَعْفَرُ بْنُ أَبِي طَالِبٍ يُحِبُّ الْمَسَاكِينَ وَيَجْلِسُ إِلَيْهِمْ وَيُحَدِّثُهُمْ وَيُحَدِّثُونَهُ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَكْنِيهِ أَبَا الْمَسَاكِينِ ‏.‏\hadithno{4125}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“Ja’far bin Abu Talib used to like the poor; he would sit with them and talk to them, and they would talk to him. And the Messenger of Allah (ﷺ) gave him the Kunyah of Abul-Masakin (Father of the Poor).”}}
\hadithdefcmd{ibnmajah}{4126}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ يَزِيدَ بْنِ سِنَانٍ، عَنْ أَبِي الْمُبَارَكِ، عَنْ عَطَاءٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَحِبُّوا الْمَسَاكِينَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ فِي دُعَائِهِ ‏ "‏ اللَّهُمَّ أَحْيِنِي مِسْكِينًا وَأَمِتْنِي مِسْكِينًا وَاحْشُرْنِي فِي زُمْرَةِ الْمَسَاكِينِ ‏"‏ ‏.‏\hadithno{4126}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“Love the poor, for I heard the Messenger of Allah (ﷺ) say in his supplication: ‘O Allah, cause me to live poor and cause me to die poor, and gather me among the poor (on the Day of Resurrection).’”}}
\hadithdefcmd{ibnmajah}{4127}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ، حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ الْعَنْقَزِيُّ، حَدَّثَنَا أَسْبَاطُ بْنُ نَصْرٍ، عَنِ السُّدِّيِّ، عَنْ أَبِي سَعْدٍ الأَزْدِيِّ، وَكَانَ، قَارِئَ الأَزْدِ عَنْ أَبِي الْكَنُودِ، عَنْ خَبَّابٍ، فِي قَوْلِهِ تَعَالَى ‏\{وَلاَ تَطْرُدِ الَّذِينَ يَدْعُونَ رَبَّهُمْ بِالْغَدَاةِ وَالْعَشِيِّ\}‏ إِلَى قَوْلِهِ ‏\{فَتَكُونَ مِنَ الظَّالِمِينَ\}‏ قَالَ جَاءَ الأَقْرَعُ بْنُ حَابِسٍ التَّمِيمِيُّ وَعُيَيْنَةُ بْنُ حِصْنٍ الْفَزَارِيُّ فَوَجَدُوا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَعَ صُهَيْبٍ وَبِلاَلٍ وَعَمَّارٍ وَخَبَّابٍ قَاعِدًا فِي نَاسٍ مِنَ الضُّعَفَاءِ مِنَ الْمُؤْمِنِينَ فَلَمَّا رَأَوْهُمْ حَوْلَ النَّبِيِّ ـ صلى الله عليه وسلم ـ حَقَرُوهُمْ فَأَتَوْهُ فَخَلَوْا بِهِ وَقَالُوا إِنَّا نُرِيدُ أَنْ تَجْعَلَ لَنَا مِنْكَ مَجْلِسًا تَعْرِفُ لَنَا بِهِ الْعَرَبُ فَضْلَنَا فَإِنَّ وُفُودَ الْعَرَبِ تَأْتِيكَ فَنَسْتَحْيِي أَنْ تَرَانَا الْعَرَبُ مَعَ هَذِهِ الأَعْبُدِ فَإِذَا نَحْنُ جِئْنَاكَ فَأَقِمْهُمْ عَنْكَ فَإِذَا نَحْنُ فَرَغْنَا فَاقْعُدْ مَعَهُمْ إِنْ شِئْتَ ‏.‏ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالُوا فَاكْتُبْ لَنَا عَلَيْكَ كِتَابًا ‏.‏ قَالَ فَدَعَا بِصَحِيفَةٍ وَدَعَا عَلِيًّا لِيَكْتُبَ وَنَحْنُ قُعُودٌ فِي نَاحِيَةٍ فَنَزَلَ جِبْرَائِيلُ عَلَيْهِ السَّلاَمُ فَقَالَ ‏\{وَلاَ تَطْرُدِ الَّذِينَ يَدْعُونَ رَبَّهُمْ بِالْغَدَاةِ وَالْعَشِيِّ يُرِيدُونَ وَجْهَهُ مَا عَلَيْكَ مِنْ حِسَابِهِمْ مِنْ شَىْءٍ وَمَا مِنْ حِسَابِكَ عَلَيْهِمْ مِنْ شَىْءٍ فَتَطْرُدَهُمْ فَتَكُونَ مِنَ الظَّالِمِينَ\}‏ ثُمَّ ذَكَرَ الأَقْرَعَ بْنَ حَابِسٍ وَعُيَيْنَةَ بْنَ حِصْنٍ فَقَالَ ‏\{وَكَذَلِكَ فَتَنَّا بَعْضَهُمْ بِبَعْضٍ لِيَقُولُوا أَهَؤُلاَءِ مَنَّ اللَّهُ عَلَيْهِمْ مِنْ بَيْنِنَا أَلَيْسَ اللَّهُ بِأَعْلَمَ بِالشَّاكِرِينَ\}‏ ‏.‏ ثُمَّ قَالَ ‏\{وَإِذَا جَاءَكَ الَّذِينَ يُؤْمِنُونَ بِآيَاتِنَا فَقُلْ سَلاَمٌ عَلَيْكُمْ كَتَبَ رَبُّكُمْ عَلَى نَفْسِهِ الرَّحْمَةَ \}‏ ‏.‏ قَالَ فَدَنَوْنَا مِنْهُ حَتَّى وَضَعْنَا رُكَبَنَا عَلَى رُكْبَتِهِ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَجْلِسُ مَعَنَا فَإِذَا أَرَادَ أَنْ يَقُومُ قَامَ وَتَرَكَنَا فَأَنْزَلَ اللَّهُ ‏\{وَاصْبِرْ نَفْسَكَ مَعَ الَّذِينَ يَدْعُونَ رَبَّهُمْ بِالْغَدَاةِ وَالْعَشِيِّ يُرِيدُونَ وَجْهَهُ وَلاَ تَعْدُ عَيْنَاكَ عَنْهُمْ\}‏ وَلاَ تُجَالِسِ الأَشْرَافَ ‏\{تُرِيدُ زِينَةَ الْحَيَاةِ الدُّنْيَا وَلاَ تُطِعْ مَنْ أَغْفَلْنَا قَلْبَهُ عَنْ ذِكْرِنَا\}‏ - يَعْنِي عُيَيْنَةَ وَالأَقْرَعَ - ‏\{وَاتَّبَعَ هَوَاهُ وَكَانَ أَمْرُهُ فُرُطًا \}‏ - قَالَ هَلاَكًا - قَالَ أَمْرُ عُيَيْنَةَ وَالأَقْرَعِ ‏.‏ ثُمَّ ضَرَبَ لَهُمْ مَثَلَ الرَّجُلَيْنِ وَمَثَلَ الْحَيَاةِ الدُّنْيَا ‏.‏ قَالَ خَبَّابٌ فَكُنَّا نَقْعُدُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَإِذَا بَلَغْنَا السَّاعَةَ الَّتِي يَقُومُ فِيهَا قُمْنَا وَتَرَكْنَاهُ حَتَّى يَقُومَ ‏.‏\hadithno{4127}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Khabbab, concerning the Verse:“And turn not away those who invoke their Lord, morning and afternoon...” up to His saying: “...and thus become of the unjust.” [6:52] He said: “Aqra’ bin Habis At-Tamimi and ‘Uyainah bin Hisn Al-Fazri came and found the Messenger of Allah (ﷺ) with Suhaib, Bilal, ‘Ammar and Khabbab, sitting with some of the believers who were weak (i.e., socially). When they saw them around the Prophet (ﷺ) they looked down on them. They took him aside and said: ‘We want you to sit with us along, so that the ‘Arabs will recognize our superiority. If the delegations of the Arabs come to you we will feel ashamed if the Arabs see us with these slaves. So, when we come to you, make them get up from your presence, then when we have finished, sit with them if you wish.’ He said: ‘Yes.’ They said: ‘Write a document for us (binding you to that).’ So he called for a piece of paper and he called ‘Ali to write, and we were sitting in a corner. Then Jibra’il (as), came down and said: “And turn not away those who invoke their Lord, morning and afternoon seeking His Face. You are accountable for them in nothing, and they are accountable for you in nothing, that you may turn them away, and thus become of the unjust.” [6:52] Then he mentioned Aqra’ bin Habis and ‘Uyaynah bin Hisn, then he said: “Thus We have tried some of them with others, that they might say: ‘Is it these (poor believers) whom Allah has favored from amongst us?’ Does not Allah know best those who are grateful.” [6:53] Then he said: “When those who believe in Our Ayat come to you, say: Salamun ‘Alaykum (peace be on you); your Lord has written (prescribed) mercy for Himself”.” [6:54] He said: “Then we got so close to him that our knees were touching his, and the Messenger of Allah (ﷺ) was sitting with us. When he wanted to get up, he stood up and left us. Then Allah revealed: “And keep yourself patiently with those who call on their Lord morning and afternoon, seeking His Face; and let not your eyes overlook them,” – and do not sit with the nobles – “desiring the pomp and glitter of the life of the world; and obey not him whose heart We have made heedless of Our remembrance,” – meaning ‘Uyainah and Aqra’ – “and who follows his own lusts, and those affair (deeds) has been lost” [18:28] He said: ‘May they be doomed.’ He said: ‘May ‘Uyainah and Aqra’ be doomed.’ Then he made the parable for them of two men and the parable of this world. Khabbab said: “We used to sit with the Prophet (ﷺ) and if the time came for him to leave, we would get up and leave him, then he would leave.”}}
\hadithdefcmd{ibnmajah}{4128}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا قَيْسُ بْنُ الرَّبِيعِ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، قَالَ نَزَلَتْ هَذِهِ الآيَةُ فِينَا سِتَّةٍ فِيَّ وَفِي ابْنِ مَسْعُودٍ وَصُهَيْبٍ وَعَمَّارٍ وَالْمِقْدَادِ وَبِلاَلٍ ‏.‏ قَالَ قَالَتْ قُرَيْشٌ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِنَّا لاَ نَرْضَى أَنْ نَكُونَ أَتْبَاعًا لَهُمْ فَاطْرُدْهُمْ عَنْكَ ‏.‏ قَالَ فَدَخَلَ قَلْبَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ ذَلِكَ مَا شَاءَ اللَّهُ أَنْ يَدْخُلَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{وَلاَ تَطْرُدِ الَّذِينَ يَدْعُونَ رَبَّهُمْ بِالْغَدَاةِ وَالْعَشِيِّ يُرِيدُونَ وَجْهَهُ\}‏ الآيَةَ ‏.‏\hadithno{4128}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Sa’d said:“This Verse was revealed concerning us six: Myself, Ibn Mas’ud, Suhaib, ‘Ammar, Miqdad and Bilal. The Quraish said to the Messenger of Allah (ﷺ): ‘We do not want to join them, send them away.’ Thoughts of that entered the heart of the Messenger of Allah (ﷺ) as much as Allah willed, then Allah revealed: “And turn not away those who invoke their Lord, morning and afternoon seeking His Face. You are accountable for them in nothing, and they are accountable for you in nothing, that you may turn them away, and thus become of the unjust.” [6:]}}
\hadithdefcmd{ibnmajah}{4129}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا بَكْرُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عِيسَى بْنُ الْمُخْتَارِ، عَنْ مُحَمَّدِ بْنِ أَبِي لَيْلَى، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ وَيْلٌ لِلْمُكْثِرِينَ إِلاَّ مَنْ قَالَ بِالْمَالِ هَكَذَا وَهَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ أَرْبَعٌ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ وَمِنْ قُدَّامِهِ وَمِنْ وَرَائِهِ ‏.‏\hadithno{4129}\hadithgrade{Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“Woe to the most wealthy except those who do such and such with the money, and such and such” – four things, (pointing) to his right, to his left, in front of him and behind him}}
\hadithdefcmd{ibnmajah}{4130}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي أَبُو زُمَيْلٍ، - هُوَ سِمَاكٌ - عَنْ مَالِكِ بْنِ مَرْثَدٍ الْحَنَفِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ ـ صلى الله عليه وسلم ـ ‏ "‏ الأَكْثَرُونَ هُمُ الأَسْفَلُونَ يَوْمَ الْقِيَامَةِ إِلاَّ مَنْ قَالَ بِالْمَالِ هَكَذَا وَهَكَذَا وَكَسَبَهُ مِنْ طَيِّبٍ ‏"‏ ‏.‏\hadithno{4130}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Dharr that the Messenger of Allah (ﷺ) said:“The wealthiest will be the lowest on the Day of Resurrection, except those who do such and such with their money, and earn it from good sources.”}}
\hadithdefcmd{ibnmajah}{4131}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الأَكْثَرُونَ هُمُ الأَسْفَلُونَ إِلاَّ مَنْ قَالَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ ثَلاَثًا ‏.‏\hadithno{4131}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The wealthiest will be the lowest, except one who does such and such,’ three things.”}}
\hadithdefcmd{ibnmajah}{4132}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا أُحِبُّ أَنَّ أُحُدًا عِنْدِي ذَهَبًا فَتَأْتِي عَلَىَّ ثَالِثَةٌ وَعِنْدِي مِنْهُ شَىْءٌ إِلاَّ شَىْءٌ أُرْصِدُهُ فِي قَضَاءِ دَيْنٍ ‏"‏ ‏.‏\hadithno{4132}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“I would not like to have (the equivalent of) Uhud in gold, then a third night comes to me and I have anything of it left, except something that I set aside to pay off a debt.”}}
\hadithdefcmd{ibnmajah}{4133}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي مَرْيَمَ، عَنْ أَبِي عُبَيْدِ اللَّهِ، مُسْلِمِ بْنِ مِشْكَمٍ عَنْ عَمْرِو بْنِ غَيْلاَنَ الثَّقَفِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُمَّ مَنْ آمَنَ بِي وَصَدَّقَنِي وَعَلِمَ أَنَّ مَا جِئْتُ بِهِ هُوَ الْحَقُّ مِنْ عِنْدِكَ - فَأَقْلِلْ مَالَهُ وَوَلَدَهُ وَحَبِّبْ إِلَيْهِ لِقَاءَكَ وَعَجِّلْ لَهُ الْقَضَاءَ وَمَنْ لَمْ يُؤْمِنْ بِي وَلَمْ يُصَدِّقْنِي وَلَمْ يَعْلَمْ أَنَّ مَا جِئْتُ بِهِ هُوَ الْحَقُّ مِنْ عِنْدِكَ فَأَكْثِرْ مَالَهُ وَوَلَدَهُ وَأَطِلْ عُمْرَهُ ‏"‏ ‏.‏\hadithno{4133}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Amr bin Ghailan Ath-Thaqafi that the Messenger of Allah (ﷺ) said:“O Allah, whoever believes in my and knows that what I have brought is the truth from You, decrease his wealth and his children, and make the meeting with You dear to him, and hasten his death. Whoever does not believe in me and does not know that what I have brought is the truth from You, increase his wealth and his children and make his life long.’”}}
\hadithdefcmd{ibnmajah}{4134}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا غَسَّانُ بْنُ بُرْزِينَ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا غَسَّانُ بْنُ بُرْزِينَ، حَدَّثَنَا سَيَّارُ بْنُ سَلاَمَةَ، عَنِ الْبَرَاءِ السَّلِيطِيِّ، عَنْ نُقَادَةَ الأَسَدِيِّ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى رَجُلٍ يَسْتَمْنِحُهُ نَاقَةً فَرَدَّهُ ثُمَّ بَعَثَنِي إِلَى رَجُلٍ آخَرَ فَأَرْسَلَ إِلَيْهِ بِنَاقَةٍ فَلَمَّا أَبْصَرَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ اللَّهُمَّ بَارِكْ فِيهَا وَفِيمَنْ بَعَثَ بِهَا ‏"‏ ‏.‏ قَالَ نُقَادَةُ فَقُلْتُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَفِيمَنْ جَاءَ بِهَا قَالَ ‏"‏ وَفِيمَنْ جَاءَ بِهَا ‏"‏ ‏.‏ ثُمَّ أَمَرَ بِهَا فَحُلِبَتْ فَدَرَّتْ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اللَّهُمَّ أَكْثِرْ مَالَ فُلاَنٍ ‏"‏ ‏.‏ لِلْمَانِعِ الأَوَّلِ ‏"‏ وَاجْعَلْ رِزْقَ فُلاَنٍ يَوْمًا بِيَوْمٍ ‏"‏ ‏.‏ لِلَّذِي بَعَثَ بِالنَّاقَةِ ‏.‏\hadithno{4134}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Nuqadah Al-Asadi said:“The Messenger of Allah (ﷺ) sent me to a man whom he was talking to lend him a she-camel (for milking) and to be returned, but he refused. Then he sent me to another man, who sent a she-camel to him. When the Messenger of Allah (ﷺ) saw it, he said: ‘O Allah, bless it and bless the one who sent it.’” Nuqadah said: "I said to the Messenger of Allah (ﷺ): 'And for the one who brought it.' He said: 'And (bless) the one who brought it.' Then he ordered that it should be milked and it yielded plenty of milk. The Messenger of Allah (ﷺ) said: 'O Allah, increase the wealth of so-and-so,' meaning the first one who did not give a camel; 'and give so-and-so provision day by day,' meaning the one who had sent the she-camel}}
\hadithdefcmd{ibnmajah}{4135}{حَدَّثَنَا الْحَسَنُ بْنُ حَمَّادٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَعِسَ عَبْدُ الدِّينَارِ وَعَبْدُ الدِّرْهَمِ وَعَبْدُ الْقَطِيفَةِ وَعَبْدُ الْخَمِيصَةِ إِنْ أُعْطِيَ رَضِيَ وَإِنْ لَمْ يُعْطَ لَمْ يَفِ ‏"‏ ‏.‏\hadithno{4135}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Wretched is the slave of the Dinar and the slave of the Dirham, and the slave of velvet and the slave of the Khamisah.* If he is given, he is pleased and if he is not given, he does not fulfill (his oath of allegiance).”}}
\hadithdefcmd{ibnmajah}{4136}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَعِسَ عَبْدُ الدِّينَارِ وَعَبْدُ الدِّرْهَمِ وَعَبْدُ الْخَمِيصَةِ تَعِسَ وَانْتَكَسَ وَإِذَا شِيكَ فَلاَ انْتَقَشَ ‏"‏ ‏.‏\hadithno{4136}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Wretched is the slave of the Dinar, the slave of the Dirham and the slave of the Khamisah. He is wretched and will be thrown (into Hell) on his face, and if he is pricked with a thorn may find no relief.”}}
\hadithdefcmd{ibnmajah}{4137}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ الْغِنَى عَنْ كَثْرَةِ الْعَرَضِ وَلَكِنَّ الْغِنَى غِنَى النَّفْسِ ‏"‏ ‏.‏\hadithno{4137}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Richness is not an abundance of worldly goods, rather richness is contentment with one’s lot.”}}
\hadithdefcmd{ibnmajah}{4138}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ لَهِيعَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، وَحُمَيْدِ بْنِ هَانِئٍ الْخَوْلاَنِيِّ، أَنَّهُمَا سَمِعَا أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، يُخْبِرُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ قَدْ أَفْلَحَ مَنْ هُدِيَ إِلَى الإِسْلاَمِ وَرُزِقَ الْكَفَافَ وَقَنِعَ بِهِ ‏"‏ ‏.‏\hadithno{4138}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr bin ‘As that the Messenger of Allah (ﷺ) said:“He has succeeded who is guided to Islam and is granted sufficient provision and is content with it.”}}
\hadithdefcmd{ibnmajah}{4139}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُمَّ اجْعَلْ رِزْقَ آلِ مُحَمَّدٍ قُوتًا ‏"‏ ‏.‏\hadithno{4139}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah hat the Messenger of Allah (ﷺ) said:“O Allah, make the provision of the family of Muhammad sufficient for them.”}}
\hadithdefcmd{ibnmajah}{4140}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَيَعْلَى، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ نُفَيْعٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ غَنِيٍّ وَلاَ فَقِيرٍ إِلاَّ وَدَّ يَوْمَ الْقِيَامَةِ أَنَّهُ أُتِيَ مِنَ الدُّنْيَا قُوتًا ‏"‏ ‏.‏\hadithno{4140}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:“There is no rich man or poor man but he will wish on the Day of Resurrection that he had been given the bare minimum of provision.”}}
\hadithdefcmd{ibnmajah}{4141}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، وَمُجَاهِدُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي شُمَيْلَةَ، عَنْ سَلَمَةَ بْنِ عُبَيْدِ اللَّهِ بْنِ مِحْصَنٍ الأَنْصَارِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَصْبَحَ مِنْكُمْ مُعَافًى فِي جَسَدِهِ آمِنًا فِي سِرْبِهِ عِنْدَهُ قُوتُ يَوْمِهِ فَكَأَنَّمَا حِيزَتْ لَهُ الدُّنْيَا ‏"‏ ‏.‏\hadithno{4141}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salamah bin ‘Ubaidullah bin Mihsan Al-Ansari that his father said:“The Messenger of Allah (ﷺ) said: ‘Whoever among you wakes up physically healthy, feeling safe and secure within himself, with food for the day, it is as if he acquired the whole world.’”}}
\hadithdefcmd{ibnmajah}{4142}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ انْظُرُوا إِلَى مَنْ هُوَ أَسْفَلَ مِنْكُمْ وَلاَ تَنْظُرُوا إِلَى مَنْ هُوَ فَوْقَكُمْ فَإِنَّهُ أَجْدَرُ أَنْ لاَ تَزْدَرُوا نِعْمَةَ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو مُعَاوِيَةَ ‏"‏ عَلَيْكُمْ ‏"‏ ‏.‏\hadithno{4142}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Look at those who are beneath you and do not look at those who are above you, for it is more suitable that you should not consider as less the blessing of Allah.”}}
\hadithdefcmd{ibnmajah}{4143}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، حَدَّثَنَا يَزِيدُ بْنُ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، رَفَعَهُ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ لاَ يَنْظُرُ إِلَى صُوَرِكُمْ وَأَمْوَالِكُمْ وَلَكِنْ إِنَّمَا يَنْظُرُ إِلَى أَعْمَالِكُمْ وَقُلُوبِكُمْ ‏"‏ ‏.‏\hadithno{4143}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah, who attributed it to the Prophet (ﷺ), said:“Allah does not look at your forms or your wealth, rather He looks at your deeds and your hearts.”}}
\hadithdefcmd{ibnmajah}{4144}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كُنَّا آلَ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ لَنَمْكُثُ شَهْرًا مَا نُوقِدُ فِيهِ بِنَارٍ مَا هُوَ إِلاَّ التَّمْرُ وَالْمَاءُ ‏.‏ إِلاَّ أَنَّ ابْنَ نُمَيْرٍ قَالَ نَلْبَثُ شَهْرًا ‏.‏\hadithno{4144}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“We, the family of Muhammad (ﷺ), would stay for a month during which no fire would be lit (for cooking) and we had only dates and water.”}}
\hadithdefcmd{ibnmajah}{4145}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ كَانَ يَأْتِي عَلَى آلِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ الشَّهْرُ مَا يُرَى فِي بَيْتٍ مِنْ بُيُوتِهِ الدُّخَانُ ‏.‏ قُلْتُ فَمَا كَانَ طَعَامُهُمْ قَالَتِ الأَسْوَدَانِ التَّمْرُ وَالْمَاءُ غَيْرَ أَنَّهُ كَانَ لَنَا جِيرَانٌ مِنَ الأَنْصَارِ جِيرَانُ صِدْقٍ وَكَانَتْ لَهُمْ رَبَائِبُ فَكَانُوا يَبْعَثُونَ إِلَيْهِ أَلْبَانَهَا ‏.‏ قَالَ مُحَمَّدٌ وَكَانُوا تِسْعَةَ أَبْيَاتٍ ‏.‏\hadithno{4145}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Salamah that ‘Aishah said:“There would come a month when no smoke was seen in any of the households of the family of Muhammad (ﷺ). I said: "What did you eat?" She said: "The two black ones - dates and water." But we had neighbors among the Ansar, sincere neighbors, who had domestic sheep, and they used to send some of their milk to us. (One of the narrators) Muhammad said: "And they were nine households}}
\hadithdefcmd{ibnmajah}{4146}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَلْتَوِي فِي الْيَوْمِ مِنَ الْجُوعِ مَا يَجِدُ مِنَ الدَّقَلِ مَا يَمْلأُ بِهِ بَطْنَهُ ‏.‏\hadithno{4146}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Nu’man bin Bashir said:“I heard ‘Umar bin Khattab say: ‘I saw the Messenger of Allah (ﷺ) writhing with hunger during the day, and he could not even find the worst of dates with which to fill his stomach.’”}}
\hadithdefcmd{ibnmajah}{4147}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، أَنْبَأَنَا شَيْبَانُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ مِرَارًا ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ مَا أَصْبَحَ عِنْدَ آلِ مُحَمَّدٍ صَاعُ حَبٍّ وَلاَ صَاعُ تَمْرٍ ‏"‏ ‏.‏ وَإِنَّ لَهُ يَوْمَئِذٍ تِسْعَ نِسْوَةٍ ‏.‏\hadithno{4147}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“I heard the Messenger of Allah (ﷺ) say several times: ‘By the One in Whose Hand is the soul of Muhammad, the family of Muhammad does not have a Sa’ of food grains or a Sa’ of dates.’ And at that time he had nine wives.”}}
\hadithdefcmd{ibnmajah}{4148}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ الْمَسْعُودِيُّ، عَنْ عَلِيِّ بْنِ بَذِيمَةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَا أَصْبَحَ فِي آلِ مُحَمَّدٍ إِلاَّ مُدٌّ مِنْ طَعَامٍ ‏"‏ ‏.‏ أَوْ ‏"‏ مَا أَصْبَحَ فِي آلِ مُحَمَّدٍ مُدٌّ مِنْ طَعَامٍ ‏"‏ ‏.‏\hadithno{4148}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu ‘Ubaidah that ‘Abdullah said:“The Messenger of Allah (ﷺ) said: ‘The family of Muhammad has only a Mudd of food,’ or ‘The family of Muhammad does not have even a Mud of food.’”}}
\hadithdefcmd{ibnmajah}{4149}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ عَبْدِ الأَكْرَمِ، - رَجُلٌ مِنْ أَهْلِ الْكُوفَةِ - عَنْ أَبِيهِ، عَنْ سُلَيْمَانَ بْنِ صُرَدٍ، قَالَ أَتَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَمَكَثْنَا ثَلاَثَ لَيَالٍ لاَ نَقْدِرُ - أَوْ لاَ يَقْدِرُ - عَلَى طَعَامٍ ‏.‏\hadithno{4149}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sulaiman bin Surad said:“The Messenger of Allah (ﷺ) came to us and we stayed for three nights without having anything to eat.”}}
\hadithdefcmd{ibnmajah}{4150}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمًا بِطَعَامٍ سُخْنٍ فَأَكَلَ فَلَمَّا فَرَغَ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ مَا دَخَلَ بَطْنِي طَعَامٌ سُخْنٌ مُنْذُ كَذَا وَكَذَا ‏"‏ ‏.‏\hadithno{4150}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“One day some hot food was brought to the Messenger of Allah (ﷺ), and he ate. Then when he had finished he said: ‘Praise is to Allah, no hot food has entered my stomach since such and such a time.’”}}
\hadithdefcmd{ibnmajah}{4151}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو خَالِدٍ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ ضِجَاعُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَدَمًا حَشْوُهُ لِيفٌ ‏.‏\hadithno{4151}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The bed of the Messenger of Allah (ﷺ) was made of leather, stuffed with fibers of date-palm trees.”}}
\hadithdefcmd{ibnmajah}{4152}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَتَى عَلِيًّا وَفَاطِمَةَ وَهُمَا فِي خَمِيلٍ لَهُمَا - وَالْخَمِيلُ الْقَطِيفَةُ الْبَيْضَاءُ مِنَ الصُّوفِ - قَدْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ جَهَّزَهُمَا بِهَا وَوِسَادَةٍ مَحْشُوَّةٍ إِذْخِرًا وَقِرْبَةٍ ‏.‏\hadithno{4152}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Ata’ bin Sa’ib from his father, from ‘Ali that the Messenger of Allah (ﷺ) came to ‘Ali and Fatimah, when they were covered with a Khamil belonging to them. And a Khamil is a white velvet made of wool. The Messenger of Allah (ﷺ) had given this to them as a wedding gift, along with a pillow stuffed with Idhkhir* and a water skin}}
\hadithdefcmd{ibnmajah}{4153}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي سِمَاكٌ الْحَنَفِيُّ أَبُو زُمَيْلٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ الْعَبَّاسِ، حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ، قَالَ دَخَلْتُ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ عَلَى حَصِيرٍ قَالَ فَجَلَسْتُ فَإِذَا عَلَيْهِ إِزَارٌ وَلَيْسَ عَلَيْهِ غَيْرُهُ وَإِذَا الْحَصِيرُ قَدْ أَثَّرَ فِي جَنْبِهِ وَإِذَا أَنَا بِقَبْضَةٍ مِنْ شَعِيرٍ نَحْوَ الصَّاعِ وَقَرَظٍ فِي نَاحِيةٍ فِي الْغُرْفَةِ وَإِذَا إِهَابٌ مُعَلَّقٌ فَابْتَدَرَتْ عَيْنَاىَ فَقَالَ ‏"‏ مَا يُبْكِيكَ يَا ابْنَ الْخَطَّابِ ‏"‏ ‏.‏ فَقُلْتُ يَا نَبِيَّ اللَّهِ وَمَا لِيَ لاَ أَبْكِي وَهَذَا الْحَصِيرُ قَدْ أَثَّرَ فِي جَنْبِكَ وَهَذِهِ خِزَانَتُكَ لاَ أَرَى فِيهَا إِلاَّ مَا أَرَى وَذَلِكَ كِسْرَى وَقَيْصَرُ فِي الثِّمَارِ وَالأَنْهَارِ وَأَنْتَ نَبِيُّ اللَّهِ وَصَفْوَتُهُ وَهَذِهِ خِزَانَتُكَ ‏.‏ قَالَ ‏"‏ يَا ابْنَ الْخَطَّابِ أَلاَ تَرْضَى أَنْ تَكُونَ لَنَا الآخِرَةُ وَلَهُمُ الدُّنْيَا ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏\hadithno{4153}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{‘Umar bin Khattab said:“I entered upon the Messenger of Allah (ﷺ) when he was (sitting) on a reed mat. I sat down and (saw that) he was wearing a waist wrap, and there was no other barrier between him and the mat but his waist wrap, and the reed mat had made marks on his side. And I saw a handful of barley, nearly a Sa’, and some acacia leaves, in a corner of the room, and a skin hanging up. My eyes flowed with tears, and he said: ‘Why are you weeping, O son of Khattab?’ I said: ‘O Prophet of Allah, why should I not weep? This mat has made marks on your side, and this is all you have accumulated, I cannot see anything other than what I see (here), while Chosroes and Caesar live among fruits and rivers. You are the Prophet of Allah and His Chosen One, and this is what you have accumulated.’ He said: ‘O son of Khattab, does it not please you (to know) that (these things) are for us in the Hereafter and for them in this world?’ He said: ‘Yes.’”}}
\hadithdefcmd{ibnmajah}{4154}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ مُجَالِدٍ، عَنْ عَامِرٍ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ أُهْدِيَتِ ابْنَةُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَىَّ فَمَا كَانَ فِرَاشُنَا لَيْلَةَ أُهْدِيَتْ إِلاَّ مَسْكَ كَبْشٍ ‏.‏\hadithno{4154}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The daughter of the Messenger of Allah (ﷺ) was permitted to me as a bride, and our bed on the night when she was presented to me, was no more than the hide of a ram.”}}
\hadithdefcmd{ibnmajah}{4155}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَائِدَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْمُرُ بِالصَّدَقَةِ فَيَنْطَلِقُ أَحَدُنَا يَتَحَامَلُ حَتَّى يَجِيءَ بِالْمُدِّ وَإِنَّ لأَحَدِهِمُ الْيَوْمَ مِائَةَ أَلْفٍ ‏.‏ قَالَ شَقِيقٌ كَأَنَّهُ يُعَرِّضُ بِنَفْسِهِ ‏.‏\hadithno{4155}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Mas’ud said:“The Messenger of Allah (ﷺ) used to enjoin charity, then one of us would go out and carry goods for others until he earned a Mudd, but one of them nowadays has one hundred thousand (Dinar or Dirham).” Shaqiq said: "It was as if he was hinting that this was he himself}}
\hadithdefcmd{ibnmajah}{4156}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي نَعَامَةَ، سَمِعَهُ مِنْ، خَالِدِ بْنِ عُمَيْرٍ قَالَ خَطَبَنَا عُتْبَةُ بْنُ غَزْوَانَ عَلَى الْمِنْبَرِ فَقَالَ لَقَدْ رَأَيْتُنِي سَابِعَ سَبْعَةٍ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مَا لَنَا طَعَامٌ نَأْكُلُهُ إِلاَّ وَرَقُ الشَّجَرِ حَتَّى قَرِحَتْ أَشْدَاقُنَا ‏.‏\hadithno{4156}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“Utbah bin Ghazwan delivered a sermon on the pulpit and said: ‘I saw myself the seventh of seven with the Messenger of Allah (ﷺ), and we did not have any food to eat except the leaves of trees, until our gums hurt.’”}}
\hadithdefcmd{ibnmajah}{4157}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ عَبَّاسٍ الْجُرَيْرِيِّ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُمْ أَصَابَهُمْ جُوعٌ وَهُمْ سَبْعَةٌ قَالَ فَأَعْطَانِي النَّبِيُّ ـ صلى الله عليه وسلم ـ سَبْعَ تَمَرَاتٍ لِكُلِّ إِنْسَانٍ تَمْرَةٌ ‏.‏\hadithno{4157}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that they suffered from hunger and they were seven. He said:“Then the Prophet (ﷺ) gave me seven dates, one date for each man.”}}
\hadithdefcmd{ibnmajah}{4158}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ بْنِ الْعَوَّامِ، عَنْ أَبِيهِ، قَالَ لَمَّا نَزَلَتْ ‏\{ثُمَّ لَتُسْأَلُنَّ يَوْمَئِذٍ عَنِ النَّعِيمِ\}‏ قَالَ الزُّبَيْرُ وَأَىُّ نَعِيمٍ نُسْأَلُ عَنْهُ وَإِنَّمَا هُوَ الأَسْوَدَانِ التَّمْرُ وَالْمَاءُ ‏.‏ قَالَ ‏"‏ أَمَا إِنَّهُ سَيَكُونُ ‏"‏ ‏.‏\hadithno{4158}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Abdullah bin Zubair bin ‘Awwam that his father said:“When the following was reveled: “Then on that Day you shall be asked about the delights (you indulged in, in this world)! [102:8] Zubair said: ‘What delights shall we be asked about? It is only the two black ones, dates and water.’ He said: ‘It is going to happen.’”}}
\hadithdefcmd{ibnmajah}{4159}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَحْنُ ثَلاَثُمِائَةٍ نَحْمِلُ أَزْوَادَنَا عَلَى رِقَابِنَا فَفَنِيَ أَزْوَادُنَا حَتَّى كَانَ يَكُونُ لِلرَّجُلِ مِنَّا تَمْرَةٌ ‏.‏ فَقِيلَ يَا أَبَا عَبْدِ اللَّهِ وَأَيْنَ تَقَعُ التَّمْرَةُ مِنَ الرَّجُلِ فَقَالَ لَقَدْ وَجَدْنَا فَقْدَهَا حِينَ فَقَدْنَاهَا وَأَتَيْنَا الْبَحْرَ فَإِذَا نَحْنُ بِحُوتٍ قَدْ قَذَفَهُ الْبَحْرُ فَأَكَلْنَا مِنْهُ ثَمَانِيَةَ عَشَرَ يَوْمًا ‏.‏\hadithno{4159}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) sent us, (we were) three hundred men, carrying our provisions on our necks. Our provisions ran out until there would be for (every) man among us one date (a day).” Then it was said: “O Abu ‘Abdullah, how can one date satisfy a man?” He said: “When we no longer had it, we realized how much it was worth. Then we came to the sea and found a whale that had been thrown up by the sea, and we ate from it for eighteen days.”}}
\hadithdefcmd{ibnmajah}{4160}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي السَّفَرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ مَرَّ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَحْنُ نُعَالِجُ خُصًّا لَنَا فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَقُلْتُ خُصٌّ لَنَا وَهَى نَحْنُ نُصْلِحُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَا أُرَى الأَمْرَ إِلاَّ أَعْجَلَ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{4160}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“The Messenger of Allah (ﷺ) passed by us when we were fixing a hut of ours, and said: ‘What is this?’ I said: ‘It is a hut of ours that has fallen into disrepair.’ The Messenger of Allah (ﷺ) said: ‘The matter (of death) may come sooner than that.’”}}
\hadithdefcmd{ibnmajah}{4161}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عِيسَى بْنُ عَبْدِ الأَعْلَى بْنِ أَبِي فَرْوَةَ، حَدَّثَنِي إِسْحَاقُ بْنُ أَبِي طَلْحَةَ، عَنْ أَنَسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِقُبَّةٍ عَلَى بَابِ رَجُلٍ مِنَ الأَنْصَارِ فَقَالَ ‏"‏ مَا هَذِهِ ‏"‏ ‏.‏ قَالُوا قُبَّةٌ بَنَاهَا فُلاَنٌ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ كُلُّ مَالٍ يَكُونُ هَكَذَا فَهُوَ وَبَالٌ عَلَى صَاحِبِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَبَلَغَ الأَنْصَارِيَّ ذَلِكَ فَوَضَعَهَا فَمَرَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ بَعْدُ فَلَمْ يَرَهَا فَسَأَلَ عَنْهَا فَأُخْبِرَ أَنَّهُ وَضَعَهَا لِمَا بَلَغَهُ عَنْكَ فَقَالَ ‏"‏ يَرْحَمُهُ اللَّهُ يَرْحَمُهُ اللَّهُ ‏"‏ ‏.‏\hadithno{4161}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:“The Messenger of Allah (ﷺ) passed by a dome-shaped structure at the door of a man among the Ansar and said: ‘What is this? ‘They said: ‘A dome that was built by so-and-so.’ The Messenger of Allah (ﷺ) said: ‘All wealth that is like this (extravagant) will bring evil consequences to its owner on the Day of Resurrection.’ News of that reached the Ansari, so he demolished it. Then the Prophet (ﷺ) passed by (that place) later on and did not see it. He asked about it and was told that its owner had demolished it because of what he had heard from him. He said: ‘May Allah have mercy on him, may Allah have mercy on him.’”}}
\hadithdefcmd{ibnmajah}{4162}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدِ بْنِ عَمْرِو بْنِ سَعِيدِ بْنِ الْعَاصِ، عَنْ أَبِيهِ، سَعِيدٍ عَنِ ابْنِ عُمَرَ، قَالَ لَقَدْ رَأَيْتُنِي مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بَنَيْتُ بَيْتًا يُكِنُّنِي مِنَ الْمَطَرِ وَيُكِنُّنِي مِنَ الشَّمْسِ مَا أَعَانَنِي عَلَيْهِ خَلْقُ اللَّهِ تَعَالَى ‏.‏\hadithno{4162}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Umar said:“I had built a house to shelter me from the rain and the sun, during the time of Allah’s Messenger (ﷺ), and no creature of Allah helped me in building it.”}}
\hadithdefcmd{ibnmajah}{4163}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ مُضَرِّبٍ، قَالَ أَتَيْنَا خَبَّابًا نَعُودُهُ فَقَالَ لَقَدْ طَالَ سُقْمِي وَلَوْلاَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ لاَ تَتَمَنَّوُا الْمَوْتَ ‏"‏ ‏.‏ لَتَمَنَّيْتُهُ وَقَالَ ‏"‏ إِنَّ الْعَبْدَ لَيُؤْجَرُ فِي نَفَقَتِهِ كُلِّهَا إِلاَّ فِي التُّرَابِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فِي الْبِنَاءِ ‏"‏ ‏.‏\hadithno{4163}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Harithah bin Mudarrib said:“We came to Khabbab to visit him (when he was sick), and he said: ‘I have been sick for a long time, and were it not that I heard the Messenger of Allah (ﷺ) say: “Do not wish for death,” I would have wished for it.’ And he said: “A person will be rewarded for all his spending, except for (what he spends) on dust,” or he said, “on building.”}}
\hadithdefcmd{ibnmajah}{4164}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، عَنِ ابْنِ هُبَيْرَةَ، عَنْ أَبِي تَمِيمٍ الْجَيْشَانِيِّ، قَالَ سَمِعْتُ عُمَرَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لَوْ أَنَّكُمْ تَوَكَّلْتُمْ عَلَى اللَّهِ حَقَّ تَوَكُّلِهِ لَرَزَقَكُمْ كَمَا يَرْزُقُ الطَّيْرَ تَغْدُو خِمَاصًا وَتَرُوحُ بِطَانًا ‏"‏ ‏.‏\hadithno{4164}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{‘Umar said:“I heard the Messenger of Allah (ﷺ) say: ‘If you were to rely upon Allah with the reliance He is due, you would be given provision like the birds: They go out hungry in the morning and come back with full bellies in the evening.”}}
\hadithdefcmd{ibnmajah}{4165}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ سَلاَّمِ بْنِ شُرَحْبِيلَ أَبِي شُرَحْبِيلَ، عَنْ حَبَّةَ، وَسَوَاءٍ، ابْنَىْ خَالِدٍ قَالاَ دَخَلْنَا عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَهُوَ يُعَالِجُ شَيْئًا فَأَعَنَّاهُ عَلَيْهِ فَقَالَ ‏ "‏ لاَ تَيْأَسَا مِنَ الرِّزْقِ مَا تَهَزَّزَتْ رُءُوسُكُمَا فَإِنَّ الإِنْسَانَ تَلِدُهُ أُمُّهُ أَحْمَرَ لَيْسَ عَلَيْهِ قِشْرٌ ثُمَّ يَرْزُقُهُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4165}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Habbah and Sawa’, the two daughters of Khalid, said:“We entered upon the Prophet (ﷺ) when he was doing something, so we helped him with it. Then he said: ‘Do not despair of provision so long as your heads are still moving, for a person’s mother bears him red with raw skin, then Allah provides for him.’”}}
\hadithdefcmd{ibnmajah}{4166}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا أَبُو شُعَيْبٍ، صَالِحُ بْنُ رُزَيْقٍ الْعَطَّارُ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْجُمَحِيُّ، عَنْ مُوسَى بْنِ عُلَىِّ بْنِ رَبَاحٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِنْ قَلْبِ ابْنِ آدَمَ بِكُلِّ وَادٍ شُعْبَةً فَمَنِ اتَّبَعَ قَلْبُهُ الشُّعَبَ كُلَّهَا لَمْ يُبَالِ اللَّهُ بِأَىِّ وَادٍ أَهْلَكَهُ وَمَنْ تَوَكَّلَ عَلَى اللَّهِ كَفَاهُ التَّشَعُّبَ ‏"‏ ‏.‏\hadithno{4166}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Amr bin ‘As that the Messenger of Allah (ﷺ) said:“The heart of the son of Adam has an inclination towards every desirable thing, so whoever follows all of those inclinations, Allah will not care which one will cause his doom. And whoever relies upon Allah, Allah will protect him from the pain of scattered inclinations.”}}
\hadithdefcmd{ibnmajah}{4167}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ يَمُوتَنَّ أَحَدٌ مِنْكُمْ إِلاَّ وَهُوَ يُحْسِنُ الظَّنَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{4167}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“I heard the Messenger of Allah (ﷺ) say: ‘No one of you should die except thinking positively of Allah.’”}}
\hadithdefcmd{ibnmajah}{4168}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْمُؤْمِنُ الْقَوِيُّ خَيْرٌ وَأَحَبُّ إِلَى اللَّهِ مِنَ الْمُؤْمِنِ الضَّعِيفِ وَفِي كُلٍّ خَيْرٌ احْرِصْ عَلَى مَا يَنْفَعُكَ وَلاَ تَعْجِزْ فَإِنْ غَلَبَكَ أَمْرٌ فَقُلْ قَدَّرَ اللَّهُ وَمَا شَاءَ فَعَلَ وَإِيَّاكَ وَاللَّوْ فَإِنَّ اللَّوْ تَفْتَحُ عَمَلَ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{4168}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said, attributing it to the Prophet (ﷺ):“The stronger believer is better and more beloved to Allah than the weak believer, although both are good. Strive to seek that which will benefit you and do not feel helpless. If something overwhelms you, then say: Qaddarallah, wa ma sha'a fa’al (It is the decree of Allah and what He wills He does). And beware of (saying) ‘If only,’ for ‘If only’ opens the door to Satan.”}}
\hadithdefcmd{ibnmajah}{4169}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ إِبْرَاهِيمَ بْنِ الْفَضْلِ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْكَلِمَةُ الْحِكْمَةُ ضَالَّةُ الْمُؤْمِنِ حَيْثُمَا وَجَدَهَا فَهُوَ أَحَقُّ بِهَا ‏"‏ ‏.‏\hadithno{4169}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A wise word is the lost property of the believer, so wherever he finds it, he has more right to it.”}}
\hadithdefcmd{ibnmajah}{4170}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نِعْمَتَانِ مَغْبُونٌ فِيهِمَا كَثِيرٌ مِنَ النَّاسِ الصِّحَّةُ وَالْفَرَاغُ ‏"‏ ‏.‏\hadithno{4170}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from ‘Abdullah bin Sa’eed bin Abu Hind that his father said:“I heard Ibn ‘Abbas saying that the Messenger of Allah (ﷺ) said: ‘Two blessings which many people squander: Good health and free time.’”}}
\hadithdefcmd{ibnmajah}{4171}{حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، حَدَّثَنِي عُثْمَانُ بْنُ جُبَيْرٍ، - مَوْلَى أَبِي أَيُّوبَ - عَنْ أَبِي أَيُّوبَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ عَلِّمْنِي وَأَوْجِزْ ‏.‏ قَالَ ‏ "‏ إِذَا قُمْتَ فِي صَلاَتِكَ فَصَلِّ صَلاَةَ مُوَدِّعٍ وَلاَ تَكَلَّمْ بِكَلاَمٍ تَعْتَذِرُ مِنْهُ وَأَجْمِعِ الْيَأْسَ عَمَّا فِي أَيْدِي النَّاسِ ‏"‏ ‏.‏\hadithno{4171}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Ayyub said:“A man came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, teach me but make it concise.’ He said: ‘When you stand to pray, pray like a man bidding farewell. Do not say anything for which you will have to apologize. And give up hope for what other people have.’”}}
\hadithdefcmd{ibnmajah}{4172}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أَوْسِ بْنِ خَالِدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَثَلُ الَّذِي يَجْلِسُ يَسْمَعُ الْحِكْمَةَ ثُمَّ لاَ يُحَدِّثُ عَنْ صَاحِبِهِ إِلاَّ بِشَرِّ مَا يَسْمَعُ كَمَثَلِ رَجُلٍ أَتَى رَاعِيًا فَقَالَ يَا رَاعِي أَجْزِرْنِي شَاةً مِنْ غَنَمِكَ ‏.‏ قَالَ اذْهَبْ فَخُذْ بِأُذُنِ خَيْرِهَا ‏.‏ فَذَهَبَ فَأَخَذَ بِأُذُنِ كَلْبِ الْغَنَمِ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ بْنُ سَلَمَةَ حَدَّثَنَاهُ إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُوسَى، حَدَّثَنَا حَمَّادٌ، فَذَكَرَ نَحْوَهُ وَقَالَ فِيهِ ‏"‏ بِأُذُنِ خَيْرِهَا شَاةً ‏"‏ ‏.‏\hadithno{4172}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The likeness of the one who sits and listen to wisdom then only speaks of the bad things that he had heard, is that of a man who comes to a shepherd and says: “O shepherd, give me one of your sheep to slaughter,” and (the shepherd) says: “Go and grab the ear of the best of them.” Then he goes and grabs the ear of the sheepdog.’” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{4173}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا سَعِيدُ بْنُ مَسْلَمَةَ، جَمِيعًا عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ مِنْ كِبْرٍ وَلاَ يَدْخُلُ النَّارَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏\hadithno{4173}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“No one will enter Paradise who has pride in his heart equal to the weight of a grain of mustard seed, and no one will enter Hell who has faith in his heart equal to the weight of a grain of mustard seed.”}}
\hadithdefcmd{ibnmajah}{4174}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَقُولُ اللَّهُ سُبْحَانَهُ الْكِبْرِيَاءُ رِدَائِي وَالْعَظَمَةُ إِزَارِي مَنْ نَازَعَنِي وَاحِدًا مِنْهُمَا أَلْقَيْتُهُ فِي جَهَنَّمَ ‏"‏ ‏.‏\hadithno{4174}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Allah, the Glorified, says: ‘Pride is My cloak and greatness My robe, and whoever competes with Me with regard to either of them, I shall throw him into Hell.’”}}
\hadithdefcmd{ibnmajah}{4175}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، وَهَارُونُ بْنُ إِسْحَاقَ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَقُولُ اللَّهُ سُبْحَانَهُ الْكِبْرِيَاءُ رِدَائِي وَالْعَظَمَةُ إِزَارِي فَمَنْ نَازَعَنِي وَاحِدًا مِنْهُمَا أَلْقَيْتُهُ فِي النَّارِ ‏"‏ ‏.‏\hadithno{4175}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Allah the Glorified, says: ‘Pride is My cloak and greatness My robe, and whoever competes with Me with regard to either of them, I shall throw him into Hell.”}}
\hadithdefcmd{ibnmajah}{4176}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ دَرَّاجًا، حَدَّثَهُ عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ يَتَوَاضَعْ لِلَّهِ سُبْحَانَهُ دَرَجَةً يَرْفَعْهُ اللَّهُ بِهِ دَرَجَةً وَمَنْ يَتَكَبَّرْ عَلَى اللَّهِ دَرَجَةً يَضَعْهُ اللَّهُ بِهِ دَرَجَةً حَتَّى يَجْعَلَهُ فِي أَسْفَلِ السَّافِلِينَ ‏"‏ ‏.‏\hadithno{4176}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“Whoever humbles himself one degree for the sake of Allah, Allah will raise him in status one degree, and whoever behaves arrogantly towards Allah one degree, Allah will lower him in status one degree, until He makes him among the lowest of the low.”}}
\hadithdefcmd{ibnmajah}{4177}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، وَسَلْمُ بْنُ قُتَيْبَةَ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ إِنْ كَانَتِ الأَمَةُ مِنْ أَهْلِ الْمَدِينَةِ لَتَأْخُذُ بِيَدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَمَا يَنْزِعُ يَدَهُ مِنْ يَدِهَا حَتَّى تَذْهَبَ بِهِ حَيْثُ شَاءَتْ مِنَ الْمَدِينَةِ فِي حَاجَتِهَا ‏.‏\hadithno{4177}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“If a female slave among the people of Al-Madinah were to take the hand of the Messenger of Allah (ﷺ), he would not take his hand away from hers until she had taken him wherever she wanted in Al-Madinah so that her needs may be met.”}}
\hadithdefcmd{ibnmajah}{4178}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُسْلِمٍ الأَعْوَرِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَعُودُ الْمَرِيضَ وَيُشَيِّعُ الْجِنَازَةَ وَيُجِيبُ دَعْوَةَ الْمَمْلُوكِ وَيَرْكَبُ الْحِمَارَ وَكَانَ يَوْمَ قُرَيْظَةَ وَالنَّضِيرِ عَلَى حِمَارٍ وَيَوْمَ خَيْبَرَ عَلَى حِمَارٍ مَخْطُومٍ بِرَسَنٍ مِنْ لِيفٍ وَتَحْتَهُ إِكَافٌ مِنْ لِيفٍ ‏"‏ ‏.‏\hadithno{4178}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) used to visit the sick, attend funerals, accept the invitations of slaves and ride donkeys. On the day (of the battle) of Quraizah and Nadir, he was riding a donkey. On the day of Khaibar he was riding a donkey that was bridled with palmfibers and beneath him was a packsaddle made of palmfibers.”}}
\hadithdefcmd{ibnmajah}{4179}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، حَدَّثَنَا أَبِي، عَنْ مَطَرٍ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ عِيَاضِ بْنِ حِمَارٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ خَطَبَهُمْ فَقَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ أَوْحَى إِلَىَّ أَنْ تَوَاضَعُوا حَتَّى لاَ يَفْخَرَ أَحَدٌ عَلَى أَحَدٍ ‏"‏ ‏.‏\hadithno{4179}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Iyad bin Himar that the Prophet (ﷺ) addressed them and said:“Allah has revealed to me that you should be humble towards one another so that none of you boasts to another.”}}
\hadithdefcmd{ibnmajah}{4180}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي عُتْبَةَ، - مَوْلًى لأَنَسِ بْنِ مَالِكٍ - عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَشَدَّ حَيَاءً مِنْ عَذْرَاءَ فِي خِدْرِهَا وَكَانَ إِذَا كَرِهَ شَيْئًا رُئِيَ ذَلِكَ فِي وَجْهِهِ ‏.‏\hadithno{4180}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) was more modest than a virgin in her chamber. If he disliked something, that could be seen in his face.”}}
\hadithdefcmd{ibnmajah}{4181}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ مُعَاوِيَةَ بْنِ يَحْيَى، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لِكُلِّ دِينٍ خُلُقًا وَخُلُقُ الإِسْلاَمِ الْحَيَاءُ ‏"‏ ‏.‏\hadithno{4181}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:“Every religion has its distinct characteristic, and the distinct characteristic of Islam is modesty.”}}
\hadithdefcmd{ibnmajah}{4182}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ الْوَرَّاقُ، حَدَّثَنَا صَالِحُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لِكُلِّ دِينٍ خُلُقًا وَإِنَّ خُلُقَ الإِسْلاَمِ الْحَيَاءُ ‏"‏ ‏.‏\hadithno{4182}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Every religion has its distinct characteristic, and the distinct characteristic of Islam is modesty.’”}}
\hadithdefcmd{ibnmajah}{4183}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ عُقْبَةَ بْنِ عَمْرٍو أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِمَّا أَدْرَكَ النَّاسُ مِنْ كَلاَمِ النُّبُوَّةِ الأُولَى إِذَا لَمْ تَسْتَحِي فَاصْنَعْ مَا شِئْتَ ‏"‏ ‏.‏\hadithno{4183}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from ‘Uqbah bin ‘Amr, Abu Mas’ud, that the Messenger of Allah (ﷺ) said:“Among the words that people learned from the earlier Prophets are: ‘If you feel no shame, then do as you wish.’”}}
\hadithdefcmd{ibnmajah}{4184}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا هُشَيْمٌ، عَنْ مَنْصُورٍ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْحَيَاءُ مِنَ الإِيمَانِ وَالإِيمَانُ فِي الْجَنَّةِ وَالْبَذَاءُ مِنَ الْجَفَاءِ وَالْجَفَاءُ فِي النَّارِ ‏"‏ ‏.‏\hadithno{4184}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Bakrah that the Messenger of Allah (ﷺ) said:“Modesty is part of faith, and faith will be in Paradise. Obscenity in speech is part of harshness and harshness will be in Hell.’”}}
\hadithdefcmd{ibnmajah}{4185}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا كَانَ الْفُحْشُ فِي شَىْءٍ قَطُّ إِلاَّ شَانَهُ وَلاَ كَانَ الْحَيَاءُ فِي شَىْءٍ قَطُّ إِلاَّ زَانَهُ ‏"‏ ‏.‏\hadithno{4185}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:“There is never any obscenity in a thing, but it mars it, and there is never any modesty in a thing, but it adorns it.”}}
\hadithdefcmd{ibnmajah}{4186}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ أَبِي مَرْحُومٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ كَظَمَ غَيْظًا وَهُوَ قَادِرٌ عَلَى أَنْ يُنْفِذَهُ دَعَاهُ اللَّهُ عَلَى رُءُوسِ الْخَلاَئِقِ يَوْمَ الْقِيَامَةِ حَتَّى يُخَيِّرَهُ فِي أَىِّ الْحُورِ شَاءَ ‏"‏ ‏.‏\hadithno{4186}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sahl bin Mu’adh bin Anas, from his father, that the Messenger of Allah (ﷺ) said:“Whoever restrains his anger when he is able to implement it, Allah will call him before all of creation on the Day of Resurrection, and will give him his choice of any houri that he wants.”}}
\hadithdefcmd{ibnmajah}{4187}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنَا خَالِدُ بْنُ دِينَارٍ الشَّيْبَانِيُّ، عَنْ عُمَارَةَ الْعَبْدِيِّ، حَدَّثَنَا أَبُو سَعِيدٍ الْخُدْرِيُّ، قَالَ كُنَّا جُلُوسًا عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ أَتَتْكُمْ وُفُودُ عَبْدِ الْقَيْسِ ‏"‏ ‏.‏ وَمَا يَرَى أَحَدٌ فَبَيْنَا نَحْنُ كَذَلِكَ إِذْ جَاءُوا فَنَزَلُوا فَأَتَوْا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَبَقِيَ الأَشَجُّ الْعَصَرِيُّ فَجَاءَ بَعْدُ فَنَزَلَ مَنْزِلاً فَأَنَاخَ رَاحِلَتَهُ وَوَضَعَ ثِيَابَهُ جَانِبًا ثُمَّ جَاءَ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ لَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ يَا أَشَجُّ إِنَّ فِيكَ لَخَصْلَتَيْنِ يُحِبُّهُمَا اللَّهُ الْحِلْمَ وَالتُّؤَدَةَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ أَشَىْءٌ جُبِلْتُ عَلَيْهِ أَمْ شَىْءٌ حَدَثَ لِي قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ بَلَ شَىْءٌ جُبِلْتَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4187}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa’eed Al-Khudri said:“We were sitting with the Messenger of Allah (ﷺ) and he said: ‘The delegations of ‘Abdul-Qais have come to you,’ and no one had seen anyone. While we were like that, they came and alighted. They came to the Messenger of Allah (ﷺ) and Ashajj ‘Ansari was left behind. He came afterwards, and halted at the halting-place, made his she-camel kneel down, and changed of his traveling clothes, then he came to the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said to him: ‘O Ashajj, you have two characteristics that Allah likes: Forbearance and deliberation.’ He said: ‘O Messenger of Allah, was I born with them or are they acquired?’ He said: ‘No, rather it is something that you were born with.’”}}
\hadithdefcmd{ibnmajah}{4188}{حَدَّثَنَا أَبُو إِسْحَاقَ الْهَرَوِيُّ، حَدَّثَنَا الْعَبَّاسُ بْنُ الْفَضْلِ الأَنْصَارِيُّ، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ لِلأَشَجِّ الْعَصَرِيِّ ‏ "‏ إِنَّ فِيكَ خَصْلَتَيْنِ يُحِبُّهُمَا اللَّهُ الْحِلْمَ وَالْحَيَاءَ ‏"‏ ‏.‏\hadithno{4188}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said to Ashajj ‘Ansari:“You have two characteristics that Allah likes: Forbearance and modesty.”}}
\hadithdefcmd{ibnmajah}{4189}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ جُرْعَةٍ أَعْظَمُ أَجْرًا عِنْدَ اللَّهِ مِنْ جُرْعَةِ غَيْظٍ كَظَمَهَا عَبْدٌ ابْتِغَاءَ وَجْهِ اللَّهِ ‏"‏ ‏.‏\hadithno{4189}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“There is no gulp that brings greater reward with Allah than a gulp of anger that a man swallows (suppresses), seeking thereby the Face of Allah.”}}
\hadithdefcmd{ibnmajah}{4190}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، أَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا إِسْرَائِيلُ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ مُجَاهِدٍ، عَنْ مُوَرِّقٍ الْعِجْلِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي أَرَى مَا لاَ تَرَوْنَ وَأَسْمَعُ مَا لاَ تَسْمَعُونَ إِنَّ السَّمَاءَ أَطَّتْ وَحُقَّ لَهَا أَنْ تَئِطَّ مَا فِيهَا مَوْضِعُ أَرْبَعِ أَصَابِعَ إِلاَّ وَمَلَكٌ وَاضِعٌ جَبْهَتَهُ سَاجِدًا لِلَّهِ ‏.‏ وَاللَّهِ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا وَمَا تَلَذَّذْتُمْ بِالنِّسَاءِ عَلَى الْفُرُشَاتِ وَلَخَرَجْتُمْ إِلَى الصُّعُدَاتِ تَجْأَرُونَ إِلَى اللَّهِ ‏"‏ ‏.‏ وَاللَّهِ لَوَدِدْتُ أَنِّي كُنْتُ شَجَرَةً تُعْضَدُ ‏.‏\hadithno{4190}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Dharr that the Messenger of Allah (ﷺ) said:“I see what you do not see, and I hear what you do not hear. The heaven is creaking and it should creak, for there is no space in it the width of four fingers but there is an angel there, prostrating to Allah. By Allah, if you knew what I know, you would laugh little and weep much, and you would never enjoy women in your beds, and you would go out in the streets, beseeching Allah.’”}}
\hadithdefcmd{ibnmajah}{4191}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏ ‏.‏\hadithno{4191}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“If you knew what I know, you would laugh little and weep much.”}}
\hadithdefcmd{ibnmajah}{4192}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي فُدَيْكٍ، عَنْ مُوسَى بْنِ يَعْقُوبَ الزَّمْعِيِّ، عَنْ أَبِي حَازِمٍ، أَنَّ عَامِرَ بْنَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَخْبَرَهُ أَنَّ أَبَاهُ أَخْبَرَهُ أَنَّهُ، لَمْ يَكُنْ بَيْنَ إِسْلاَمِهِمْ وَبَيْنَ أَنْ نَزَلَتْ هَذِهِ الآيَةُ يُعَاتِبُهُمُ اللَّهُ بِهَا إِلاَّ أَرْبَعُ سِنِينَ ‏\{وَلاَ يَكُونُوا كَالَّذِينَ أُوتُوا الْكِتَابَ مِنْ قَبْلُ فَطَالَ عَلَيْهِمُ الأَمَدُ فَقَسَتْ قُلُوبُهُمْ وَكَثِيرٌ مِنْهُمْ فَاسِقُونَ\}‏ ‏.‏\hadithno{4192}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{‘Amir bin ‘Abdullah bin Zubair narrated that his father told him that there was no more than four years between their becoming Muslim and the revelation of this Verse, by which Allah reprimanded them:“Lest they become as those who received the Scripture before, and the term was prolonged for them and so their hearts were hardened? And many of them were rebellious.” [57:]}}
\hadithdefcmd{ibnmajah}{4193}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُكْثِرُوا الضَّحِكَ فَإِنَّ كَثْرَةَ الضَّحِكِ تُمِيتُ الْقَلْبَ ‏"‏ ‏.‏\hadithno{4193}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Do not laugh a lot, for laughing a lot deadens the heart.”}}
\hadithdefcmd{ibnmajah}{4194}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ لِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ اقْرَأْ عَلَىَّ ‏"‏ ‏.‏ فَقَرَأْتُ عَلَيْهِ بِسُورَةِ النِّسَاءِ حَتَّى إِذَا بَلَغْتُ ‏\{فَكَيْفَ إِذَا جِئْنَا مِنْ كُلِّ أُمَّةٍ بِشَهِيدٍ وَجِئْنَا بِكَ عَلَى هَؤُلاَءِ شَهِيدًا\}‏ فَنَظَرْتُ إِلَيْهِ فَإِذَا عَيْنَاهُ تَدْمَعَانِ ‏.‏\hadithno{4194}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah said:“The Prophet (ﷺ) said to me: ‘Recite Qur’an to me,’ so I recited Surat An-Nisa’ to him, and when I reached (the Verse): “How (will it be) then, when We bring forth from each nation a witness and We bring you as a witness against these people?” [4:41] I looked at him, and his eyes were filled with tears.”}}
\hadithdefcmd{ibnmajah}{4195}{حَدَّثَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو رَجَاءٍ الْخُرَاسَانِيُّ، عَنْ مُحَمَّدِ بْنِ مَالِكٍ، عَنِ الْبَرَاءِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي جِنَازَةٍ فَجَلَسَ عَلَى شَفِيرِ الْقَبْرِ فَبَكَى حَتَّى بَلَّ الثَّرَى ثُمَّ قَالَ ‏ "‏ يَا إِخْوَانِي لِمِثْلِ هَذَا فَأَعِدُّوا ‏"‏ ‏.‏\hadithno{4195}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Bara’ said:“We were with the Messenger of Allah (ﷺ) at a funeral, and he sat at the edge of the grave weeping, until the ground became wet. Then he said: ‘O my brothers, prepare yourselves for something like this.’”}}
\hadithdefcmd{ibnmajah}{4196}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ بَشِيرِ بْنِ ذَكْوَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو رَافِعٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ السَّائِبِ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ابْكُوا فَإِنْ لَمْ تَبْكُوا فَتَبَاكَوْا ‏"‏ ‏.‏\hadithno{4196}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa’d bin Abu Waqqas that the Messenger of Allah (ﷺ) said:‘Weep, and if you cannot weep then pretend to weep.”}}
\hadithdefcmd{ibnmajah}{4197}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، وَإِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي حَمَّادُ بْنُ أَبِي حُمَيْدٍ الزُّرَقِيُّ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ عَبْدٍ مُؤْمِنٍ يَخْرُجُ مِنْ عَيْنَيْهِ دُمُوعٌ وَإِنْ كَانَ مِثْلَ رَأْسِ الذُّبَابِ مِنْ خَشْيَةِ اللَّهِ ثُمَّ تُصِيبُ شَيْئًا مِنْ حُرِّ وَجْهِهِ - إِلاَّ حَرَّمَهُ اللَّهُ عَلَى النَّارِ ‏"‏ ‏.‏\hadithno{4197}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Messenger of Allah (ﷺ) said:“There is no believing slave who sheds tears, even if they are like the head of a fly, out of fear of Allah, and they roll down his cheeks, but Allah will forbid him to the Fire.”}}
\hadithdefcmd{ibnmajah}{4198}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَعِيدٍ الْهَمْدَانِيِّ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ ‏\{وَالَّذِينَ يُؤْتُونَ مَا آتَوْا وَقُلُوبُهُمْ وَجِلَةٌ\}‏ أَهُوَ الرَّجُلُ الَّذِي يَزْنِي وَيَسْرِقُ وَيَشْرَبُ الْخَمْرَ قَالَ ‏"‏ لاَ يَا بِنْتَ أَبِي بَكْرٍ - أَوْ يَا بِنْتَ الصِّدِّيقِ - وَلَكِنَّهُ الرَّجُلُ يَصُومُ وَيَتَصَدَّقُ وَيُصَلِّي وَهُوَ يَخَافُ أَنْ لاَ يُتَقَبَّلَ مِنْهُ ‏"‏ ‏.‏\hadithno{4198}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Aishah said:“I said: ‘O Messenger of Allah, ‘And those who give that (their charity) which they give (and also do other good deeds) with their hearts full of fear.” [23:60] Is this the one who commits adultery, steals and drinks alcohol?’ He said: ‘No, O daughter of Abu Bakr’ – O daughter of Siddiq – rather it is a man who fasts and gives charity and prays, but he fears that those will not be accepted from him.’”}}
\hadithdefcmd{ibnmajah}{4199}{حَدَّثَنَا عُثْمَانُ بْنُ إِسْمَاعِيلَ بْنِ عِمْرَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، حَدَّثَنِي أَبُو عَبْدِ رَبٍّ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّمَا الأَعْمَالُ كَالْوِعَاءِ إِذَا طَابَ أَسْفَلُهُ طَابَ أَعْلاَهُ وَإِذَا فَسَدَ أَسْفَلُهُ فَسَدَ أَعْلاَهُ ‏"‏ ‏.‏\hadithno{4199}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Mu’awiyah bin Abu Sufyan said:“I heard the Messenger of Allah (ﷺ) say: ‘Deeds are like vessels. If the lower part is good then the upper part will be good, and if the lower part is bad then the upper part will be bad.’”}}
\hadithdefcmd{ibnmajah}{4200}{حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ وَرْقَاءَ بْنِ عُمَرَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ ذَكْوَانَ أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ الْعَبْدَ إِذَا صَلَّى فِي الْعَلاَنِيَةِ فَأَحْسَنَ وَصَلَّى فِي السِّرِّ فَأَحْسَنَ - قَالَ اللَّهُ عَزَّ وَجَلَّ هَذَا عَبْدِي حَقًّا ‏"‏ ‏.‏\hadithno{4200}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“If a person prays in public and does it well, and he prays in secret and does it well, then Allah says: ‘This man is truly My slave.’”}}
\hadithdefcmd{ibnmajah}{4201}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، وَإِسْمَاعِيلُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ قَارِبُوا وَسَدِّدُوا فَإِنَّهُ لَيْسَ أَحَدٌ مِنْكُمْ بِمُنْجِيهِ عَمَلُهُ ‏"‏ ‏.‏ قَالُوا وَلاَ أَنْتَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِيَ اللَّهُ بِرَحْمَةٍ مِنْهُ وَفَضْلٍ ‏"‏ ‏.‏\hadithno{4201}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Be moderate and adhere to moderation, for there is no one among you who will be saved by his deeds.” They said: “Not even you, O Messenger of Allah?” He said: “Not even me. Unless Allah encompasses me with mercy and grace from Him.”}}
\hadithdefcmd{ibnmajah}{4202}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ أَنَا أَغْنَى الشُّرَكَاءِ عَنِ الشِّرْكِ فَمَنْ عَمِلَ لِي عَمَلاً أَشْرَكَ فِيهِ غَيْرِي فَأَنَا مِنْهُ بَرِيءٌ وَهُوَ لِلَّذِي أَشْرَكَ ‏"‏ ‏.‏\hadithno{4202}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Allah says: ‘I am the Most Self-Sufficient and I have no need for an associate. Thus he who does an action for someone else’s sake as well as Mine will have that action renounced by Me to him whom he associated with Me.’”}}
\hadithdefcmd{ibnmajah}{4203}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، أَنْبَأَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، أَخْبَرَنِي أَبِي، عَنْ زِيَادِ بْنِ مِينَاءَ، عَنْ أَبِي سَعْدِ بْنِ أَبِي فَضَالَةَ الأَنْصَارِيِّ، - وَكَانَ مِنَ الصَّحَابَةِ - قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا جَمَعَ اللَّهُ الأَوَّلِينَ وَالآخِرِينَ لِيَوْمِ الْقِيَامَةِ لِيَوْمٍ لاَ رَيْبَ فِيهِ نَادَى مُنَادٍ مَنْ كَانَ أَشْرَكَ فِي عَمَلٍ عَمَلَهُ لِلَّهِ فَلْيَطْلُبْ ثَوَابَهُ مِنْ عِنْدِ غَيْرِ اللَّهِ فَإِنَّ اللَّهَ أَغْنَى الشُّرَكَاءِ عَنِ الشِّرْكِ ‏"‏ ‏.‏\hadithno{4203}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa’d bin Abu Fadalah Al-Ansari, who was one of the Companions, that the Messenger of Allah (ﷺ) said:“When Allah assembles the first and the last on the Day of Resurrection, a day concerning which there is no doubt, a caller will cry out: ‘Whoever used to associate anyone else in an action that he did for Allah, let him seek his reward from someone other than Allah, for Allah is so self-sufficient that He has no need of any associate.’”}}
\hadithdefcmd{ibnmajah}{4204}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنْ رُبَيْحِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَحْنُ نَتَذَاكَرُ الْمَسِيحَ الدَّجَّالَ فَقَالَ ‏"‏ أَلاَ أُخْبِرُكُمْ بِمَا هُوَ أَخْوَفُ عَلَيْكُمْ عِنْدِي مِنَ الْمَسِيحِ الدَّجَّالِ ‏"‏ ‏.‏ قَالَ قُلْنَا بَلَى ‏.‏ فَقَالَ ‏"‏ الشِّرْكُ الْخَفِيُّ أَنْ يَقُومَ الرَّجُلُ يُصَلِّي فَيُزَيِّنُ صَلاَتَهُ لِمَا يَرَى مِنْ نَظَرِ رَجُلٍ ‏"‏ ‏.‏\hadithno{4204}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) came out to us when we were discussing Dajjal (False Christ) and said: ‘Shall I not tell you of that which I fear more for you than Dajjal?’ We said: ‘Yes.’ He said: ‘Hidden polytheism, when a man stands to pray and makes it look good because he sees a man looking at him.’”}}
\hadithdefcmd{ibnmajah}{4205}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا رَوَّادُ بْنُ الْجَرَّاحِ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ، عَنِ الْحَسَنِ بْنِ ذَكْوَانَ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَخْوَفَ مَا أَتَخَوَّفُ عَلَى أُمَّتِي الإِشْرَاكُ بِاللَّهِ أَمَا إِنِّي لَسْتُ أَقُولُ يَعْبُدُونَ شَمْسًا وَلاَ قَمَرًا وَلاَ وَثَنًا وَلَكِنْ أَعْمَالاً لِغَيْرِ اللَّهِ وَشَهْوَةً خَفِيَّةً ‏"‏ ‏.‏\hadithno{4205}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Shaddad bin Aws that the Messenger of Allah (ﷺ) said:“The thing that I fear most for my nation is associating others with Allah. I do not say that they will worship the sun or the moon or idols, but deeds done for the sake of anyone other than Allah, and hidden desires.”}}
\hadithdefcmd{ibnmajah}{4206}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا بَكْرُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عِيسَى بْنُ الْمُخْتَارِ، عَنْ مُحَمَّدِ بْنِ أَبِي لَيْلَى، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ يُسَمِّعْ يُسَمِّعِ اللَّهُ بِهِ وَمَنْ يُرَاءِ يُرَاءِ اللَّهُ بِهِ ‏"‏ ‏.‏\hadithno{4206}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) said:“Whoever wants to be heard of, Allah will make him heard of, and whoever wants to be seen, Allah will show him (i.e., make known to the people his true motives and intentions).”}}
\hadithdefcmd{ibnmajah}{4207}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ، حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الْوَهَّابِ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ يُرَاءِ يُرَاءِ اللَّهُ بِهِ وَمَنْ يُسَمِّعْ يُسَمِّعِ اللَّهُ بِهِ ‏"‏ ‏.‏\hadithno{4207}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jundab that the Messenger of Allah (ﷺ) said:“Whoever wants to be heard of, Allah will make him heard of, and whoever wants to be seen, Allah will show him (i.e., expose his real motives).”}}
\hadithdefcmd{ibnmajah}{4208}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ مَالاً فَسَلَّطَهُ عَلَى هَلَكَتِهِ فِي الْحَقِّ وَرَجُلٌ آتَاهُ اللَّهُ حِكْمَةً فَهُوَ يَقْضِي بِهَا وَيُعَلِّمُهَا ‏"‏ ‏.‏\hadithno{4208}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Messenger of Allah (ﷺ) said:“There is no (permissible) envy except in two cases: A man whom Allah has given wealth and caused him to dispose of it in a proper manner, and a man to whom Allah has given wisdom, and he acts in accordance with it and teaches it (to others).”}}
\hadithdefcmd{ibnmajah}{4209}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ الْقُرْآنَ فَهُوَ يَقُومُ بِهِ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ وَرَجُلٌ آتَاهُ اللَّهُ مَالاً فَهُوَ يُنْفِقُهُ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ ‏"‏ ‏.‏\hadithno{4209}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that his father said:“The Messenger of Allah (ﷺ) said: ‘There is no envy except in two cases. A man to whom Allah has given (knowledge of) the Qur’an, so he recites it night and day, and a man to whom Allah has given wealth, so he spends it night and day.’”}}
\hadithdefcmd{ibnmajah}{4210}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، وَأَحْمَدُ بْنُ الأَزْهَرِ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عِيسَى بْنِ أَبِي عِيسَى الْحَنَّاطِ، عَنْ أَبِي الزِّنَادِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْحَسَدُ يَأْكُلُ الْحَسَنَاتِ كَمَا تَأْكُلُ النَّارُ الْحَطَبَ وَالصَّدَقَةُ تُطْفِئُ الْخَطِيئَةَ كَمَا يُطْفِئُ الْمَاءُ النَّارَ وَالصَّلاَةُ نُورُ الْمُؤْمِنِ وَالصِّيَامُ جُنَّةٌ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{4210}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:“Envy consumes good deeds just as fire consumes wood, and charity extinguishes bad deeds just as water extinguishes fire. Prayer is the light of the believer and fasting is a shield against the Fire.”}}
\hadithdefcmd{ibnmajah}{4211}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، وَابْنُ، عُلَيَّةَ عَنْ عُيَيْنَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ ذَنْبٍ أَجْدَرُ أَنْ يُعَجِّلَ اللَّهُ لِصَاحِبِهِ الْعُقُوبَةَ فِي الدُّنْيَا مَعَ مَا يَدَّخِرُ لَهُ فِي الآخِرَةِ - مِنَ الْبَغْىِ وَقَطِيعَةِ الرَّحِمِ ‏"‏ ‏.‏\hadithno{4211}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Bakrah that the Messenger of Allah (ﷺ) said:“There is no sin more deserving that Allah hasten the punishment in this world, in addition to what is stored up for him in the Hereafter – than injustice and severing the ties of kinship.”}}
\hadithdefcmd{ibnmajah}{4212}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا صَالِحُ بْنُ مُوسَى، عَنْ مُعَاوِيَةَ بْنِ إِسْحَاقَ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَسْرَعُ الْخَيْرِ ثَوَابًا الْبِرُّ وَصِلَةُ الرَّحِمِ وَأَسْرَعُ الشَّرِّ عُقُوبَةً الْبَغْىُ وَقَطِيعَةُ الرَّحِمِ ‏"‏ ‏.‏\hadithno{4212}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah, the Mother of the Believers, that the Messenger of Allah (ﷺ) said:“The most quickly rewarded of good deeds are kindness and upholding the ties of kinship, and the most quickly punished evil deeds are injustice and severing the ties of kinship.”}}
\hadithdefcmd{ibnmajah}{4213}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدٍ الْمَدَنِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ أَبِي سَعِيدٍ، - مَوْلَى بَنِي عَامِرٍ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ حَسْبُ امْرِئٍ مِنَ الشَّرِّ أَنْ يَحْقِرَ أَخَاهُ الْمُسْلِمَ ‏"‏ ‏.‏\hadithno{4213}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“It is sufficient evil for a man to look down on his Muslim brother.”}}
\hadithdefcmd{ibnmajah}{4214}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا عَمْرُو بْنُ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سِنَانِ بْنِ سَعْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ أَوْحَى إِلَىَّ أَنْ تَوَاضَعُوا وَلاَ يَبْغِي بَعْضُكُمْ عَلَى بَعْضٍ ‏"‏ ‏.‏\hadithno{4214}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Allah has revealed to me that you should be humble towards one another and should not wrong one another.”}}
\hadithdefcmd{ibnmajah}{4215}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا أَبُو عَقِيلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ، وَعَطِيَّةُ بْنُ قَيْسٍ، عَنْ عَطِيَّةَ السَّعْدِيِّ، - وَكَانَ مِنْ أَصْحَابِ النَّبِيِّ ـ صلى الله عليه وسلم ـ - قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَبْلُغُ الْعَبْدُ أَنْ يَكُونَ مِنَ الْمُتَّقِينَ حَتَّى يَدَعَ مَا لاَ بَأْسَ بِهِ حَذَرًا لِمَا بِهِ الْبَأْسُ ‏"‏ ‏.‏\hadithno{4215}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Atiyyah As-Sa’di, who was one of the Companions of the Prophet (ﷺ), that the Messenger of Allah (ﷺ) said:“A person will not reach the status of being one of those who have piety until he refrains from doing something in which there is no sin, for fear of falling into something in which there is sin.”}}
\hadithdefcmd{ibnmajah}{4216}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، حَدَّثَنَا مُغِيثُ بْنُ سُمَىٍّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قِيلَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَىُّ النَّاسِ أَفْضَلُ قَالَ ‏"‏ كُلُّ مَخْمُومِ الْقَلْبِ صَدُوقِ اللِّسَانِ ‏"‏ ‏.‏ قَالُوا صَدُوقُ اللِّسَانِ نَعْرِفُهُ فَمَا مَخْمُومُ الْقَلْبِ قَالَ ‏"‏ هُوَ التَّقِيُّ النَّقِيُّ لاَ إِثْمَ فِيهِ وَلاَ بَغْىَ وَلاَ غِلَّ وَلاَ حَسَدَ ‏"‏ ‏.‏\hadithno{4216}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“It was said to the Messenger of Allah (ﷺ): ‘Which of the people is best?’ He said: ‘Everyone who is pure of heart and sincere in speech.’ They said: ‘Sincere in speech, we know what this is, but what is pure of heart?’ He said: ‘It is (the heart) that is pious and pure, with no sin, injustice, rancor or envy in it.’”}}
\hadithdefcmd{ibnmajah}{4217}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ أَبِي رَجَاءٍ، عَنْ بُرْدِ بْنِ سِنَانٍ، عَنْ مَكْحُولٍ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا أَبَا هُرَيْرَةَ كُنْ وَرِعًا تَكُنْ أَعْبَدَ النَّاسِ وَكُنْ قَنِعًا تَكُنْ أَشْكَرَ النَّاسِ وَأَحِبَّ لِلنَّاسِ مَا تُحِبُّ لِنَفْسِكَ تَكُنْ مُؤْمِنًا وَأَحَسِنْ جِوَارَ مَنْ جَاوَرَكَ تَكُنْ مُسْلِمًا وَأَقِلَّ الضَّحِكَ فَإِنَّ كَثْرَةَ الضَّحِكِ تُمِيتُ الْقَلْبَ ‏"‏ ‏.‏\hadithno{4217}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“O Abu Hurairah, be cautious, and you will be the most devoted of people to Allah. Be content, and you will be the most grateful of people to Allah. Love for people what you love for yourself, and you will be a (true) believer. Be a good neighbor to your neighbors, and you will be a (true) Muslim. And laugh little, for laughing a lot deadens the heart.”}}
\hadithdefcmd{ibnmajah}{4218}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ رُمْحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنِ الْمَاضِي بْنِ مُحَمَّدٍ، عَنْ عَلِيِّ بْنِ سُلَيْمَانَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ عَقْلَ كَالتَّدْبِيرِ وَلاَ وَرَعَ كَالْكَفِّ وَلاَ حَسَبَ كَحُسْنِ الْخُلُقِ ‏"‏ ‏.‏\hadithno{4218}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Dharr that the Messenger of Allah (ﷺ) said:“There is no wisdom like reflection, and no honor like good manners.”}}
\hadithdefcmd{ibnmajah}{4219}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سَلاَّمُ بْنُ أَبِي مُطِيعٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْحَسَبُ الْمَالُ وَالْكَرَمُ التَّقْوَى ‏"‏ ‏.‏\hadithno{4219}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Samurah bin Jundab that the Messenger of Allah (ﷺ) said:“Being honorable is wealth and noble character is piety.’}}
\hadithdefcmd{ibnmajah}{4220}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ كَهْمَسِ بْنِ الْحَسَنِ، عَنْ أَبِي السَّلِيلِ، ضُرَيْبِ بْنِ نُقَيْرٍ عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنِّي لأَعْرِفُ كَلِمَةً - وَقَالَ عُثْمَانُ آيَةً - لَوْ أَخَذَ النَّاسُ كُلُّهُمْ بِهَا لَكَفَتْهُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَيَّةُ آيَةٍ قَالَ ‏"‏ وَمَنْ يَتَّقِ اللَّهَ يَجْعَلْ لَهُ مَخْرَجًا ‏"‏ ‏.‏\hadithno{4220}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Dharr that the Messenger of Allah (ﷺ) said:“I know a word – (one of the narrators) ‘Uthman said: “a Verse” – which if all the people followed it, it would suffice them.” They said: “O Messenger of Allah, which Verse?” He said: “And whosoever fears Allah, He will make a way out for him.” [65:]}}
\hadithdefcmd{ibnmajah}{4221}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنْ أُمَيَّةَ بْنِ صَفْوَانَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي زُهَيْرٍ الثَّقَفِيِّ، عَنْ أَبِيهِ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِالنَّبَا أَوِ النَّبَاوَةِ - قَالَ وَالنَّبَاوَةُ مِنَ الطَّائِفِ - قَالَ ‏"‏ يُوشِكُ أَنْ تَعْرِفُوا أَهْلَ الْجَنَّةِ مِنْ أَهْلِ النَّارِ ‏"‏ ‏.‏ قَالُوا بِمَ ذَاكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ بِالثَّنَاءِ الْحَسَنِ وَالثَّنَاءِ السَّيِّئِ أَنْتُمْ شُهَدَاءُ اللَّهِ بَعْضُكُمْ عَلَى بَعْضٍ ‏"‏ ‏.‏\hadithno{4221}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Bakr bin Abu Zuhair Ath-Thaqafi, that his father said:“The Messenger of Allah (ﷺ) addressed us in Nabawah” or Banawah – he (one of the narrators) said: “Nabawah is near Ta’if” – “And said: ‘Soon you will be able to tell the people of Paradise from the people of Hell.’ They said: ‘How O Messenger of Allah?’ He said: ‘By praise and condemnation. You are Allah’s witnesses over one another.’”}}
\hadithdefcmd{ibnmajah}{4222}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ جَامِعِ بْنِ شَدَّادٍ، عَنْ كُلْثُومٍ الْخُزَاعِيِّ، قَالَ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ لِي أَنْ أَعْلَمَ إِذَا أَحْسَنْتُ أَنِّي قَدْ أَحْسَنْتُ وَإِذَا أَسَأْتُ أَنِّي قَدْ أَسَأْتُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا قَالَ جِيرَانُكَ إِنَّكَ قَدْ أَحْسَنْتَ فَقَدْ أَحْسَنْتَ وَإِذَا قَالُوا إِنَّكَ قَدْ أَسَأْتَ فَقَدْ أَسَأْتَ ‏"‏ ‏.‏\hadithno{4222}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Kulthum Al-Khuza’i said:“A man came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, how can I know, when I have done something good, that I have done well, and if I have done something bad, that I have done a bad deed?’ The Messenger of Allah (ﷺ) said: ‘If your neighbors say that you have done something good, then you have done well, and if they say that you have done something bad, then you have done something bad.’”}}
\hadithdefcmd{ibnmajah}{4223}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَجُلٌ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ كَيْفَ لِي أَنْ أَعْلَمَ إِذَا أَحْسَنْتُ وَإِذَا أَسَأْتُ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ إِذَا سَمِعْتَ جِيرَانَكَ يَقُولُونَ قَدْ أَحْسَنْتَ فَقَدْ أَحْسَنْتَ وَإِذَا سَمِعْتَهُمْ يَقُولُونَ ‏:‏ قَدْ أَسَأْتَ فَقَدْ أَسَأْتَ ‏"‏ ‏.‏\hadithno{4223}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Abdullah said:“A man said to the Messenger of Allah (ﷺ): ‘How can I know when I have done well and when I have done something bad?’ The Prophet (ﷺ) said: ‘If you hear your neighbors saying that you have done well, then you have done well, and if you hear them saying that you have done something bad, then you have done something bad.’”}}
\hadithdefcmd{ibnmajah}{4224}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَزَيْدُ بْنُ أَخْزَمَ، قَالاَ حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبُو هِلاَلٍ، حَدَّثَنَا عُقْبَةُ بْنُ أَبِي ثُبَيْتٍ، عَنْ أَبِي الْجَوْزَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ أَهْلُ الْجَنَّةِ مَنْ مَلأَ اللَّهُ أُذُنَيْهِ مِنْ ثَنَاءِ النَّاسِ خَيْرًا وَهُوَ يَسْمَعُ، وَأَهْلُ النَّارِ مَنْ مَلأَ أُذُنَيْهِ مِنْ ثَنَاءِ النَّاسِ شَرًّا وَهُوَ يَسْمَعُ ‏"‏ ‏.‏\hadithno{4224}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“The people of Paradise are those whose ears Allah fills with the praise of people when they are listening, and the people of Hell- fire are those whom He fills their ears with condemnation when they are listening.”}}
\hadithdefcmd{ibnmajah}{4225}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ قُلْتُ لَهُ ‏:‏ الرَّجُلُ يَعْمَلُ الْعَمَلَ لِلَّهِ فَيُحِبُّهُ النَّاسُ عَلَيْهِ قَالَ ‏:‏ ‏ "‏ ذَلِكَ عَاجِلُ بُشْرَى الْمُؤْمِنِ ‏"‏ ‏.‏\hadithno{4225}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Dharr:“I said to the Prophet (ﷺ): ‘(What do you say about when) a man does a deed for the sake of Allah, and people love him for it?’ He said: ‘That is the immediate glad tidings of the believer.’”}}
\hadithdefcmd{ibnmajah}{4226}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا سَعِيدُ بْنُ سِنَانٍ أَبُو سِنَانٍ الشَّيْبَانِيُّ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَجُلٌ ‏:‏ يَا رَسُولَ اللَّهِ إِنِّي أَعْمَلُ الْعَمَلَ فَيُطَّلَعُ عَلَيْهِ فَيُعْجِبُنِي قَالَ ‏:‏ ‏ "‏ لَكَ أَجْرَانِ ‏:‏ أَجْرُ السِّرِّ وَأَجْرُ الْعَلاَنِيَةِ ‏"‏ ‏.‏\hadithno{4226}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“A man said: ‘O Messenger of Allah, I do a good deed, then others find out about it and that pleases me.’ He said: ‘You will have two rewards, the reward for doing it in secret and the reward for doing it openly (so that others may follow your example).’”}}
\hadithdefcmd{ibnmajah}{4227}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، قَالاَ أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، أَنَّ مُحَمَّدَ بْنَ إِبْرَاهِيمَ التَّيْمِيَّ، أَخْبَرَهُ أَنَّهُ، سَمِعَ عَلْقَمَةَ بْنَ وَقَّاصٍ، أَنَّهُ سَمِعَ عُمَرَ بْنَ الْخَطَّابِ، وَهُوَ يَخْطُبُ النَّاسَ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏:‏ ‏ "‏ إِنَّمَا الأَعْمَالُ بِالنِّيَّاتِ وَلِكُلِّ امْرِئٍ مَا نَوَى فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ وَمَنْ كَانَتْ هِجْرَتُهُ لِدُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا، فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{4227}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{‘Alqamah bin Waqqas (said) that he heard ‘Umar bin Khattab, when he was addressing the people, saying:“I heard the Messenger of Allah (ﷺ) say: ‘Actions are but by the intention and every man will have but that which he intended. So he whose emigration was for Allah and His Messenger, his emigration was for Allah and His Messenger. But he whose emigration was for some worldly benefit or to take some woman in marriage, his emigration was for that which he migrated.”}}
\hadithdefcmd{ibnmajah}{4228}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِي كَبْشَةَ الأَنْمَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏"‏ مَثَلُ هَذِهِ الأُمَّةِ كَمَثَلِ أَرْبَعَةِ نَفَرٍ ‏:‏ رَجُلٌ آتَاهُ اللَّهُ مَالاً وَعِلْمًا فَهُوَ يَعْمَلُ بِعِلْمِهِ فِي مَالِهِ يُنْفِقُهُ فِي حَقِّهِ وَرَجُلٌ آتَاهُ اللَّهُ عِلْمًا وَلَمْ يُؤْتِهِ مَالاً فَهُوَ يَقُولُ ‏:‏ لَوْ كَانَ لِي مِثْلُ هَذَا عَمِلْتُ فِيهِ مِثْلَ الَّذِي يَعْمَلُ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏"‏ فَهُمَا فِي الأَجْرِ سَوَاءٌ وَرَجُلٌ آتَاهُ اللَّهُ مَالاً وَلَمْ يُؤْتِهِ عِلْمًا فَهُوَ يَخْبِطُ فِي مَالِهِ يُنْفِقُهُ فِي غَيْرِ حَقِّهِ وَرَجُلٌ لَمْ يُؤْتِهِ اللَّهُ عِلْمًا وَلاَ مَالاً فَهُوَ يَقُولُ ‏:‏ لَوْ كَانَ لِي مِثْلُ مَالِ هَذَا عَمِلْتُ فِيهِ مِثْلَ الَّذِي يَعْمَلُ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏"‏ فَهُمَا فِي الْوِزْرِ سَوَاءٌ ‏"‏ ‏.‏ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنِ ابْنِ أَبِي كَبْشَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مُفَضَّلٍ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنِ ابْنِ أَبِي كَبْشَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{4228}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Kabshah Al-Anmari said:“The Messenger of Allah (ﷺ) said: ‘The likeness of this nation is that of four people: A man to whom Allah gives wealth and knowledge, so he acts according to his knowledge with regard to his wealth, spending it as it should be spent; a man to whom Allah gives knowledge, but he does not give him wealth, so he says: “If I had been given (wealth) like this one, I would have done what (the first man) did.” The Messenger of Allah (ﷺ) said: ‘They will be equal in reward. And a man to whom Allah gives wealth but does not give knowledge, so he squanders his wealth and spends it in inappropriate ways; and a man to whom Allah gives neither knowledge nor wealth, and he says: “If I had (wealth) like this one, I would do what (the third man) did.” The Messenger of Allah (ﷺ) said: ‘They are equal in their burden (of sin).’” A similar report (as above) was narrated from Ibn Abu Kabshah, from his father, from the Prophet (ﷺ)}}
\hadithdefcmd{ibnmajah}{4229}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ شَرِيكٍ، عَنْ لَيْثٍ، عَنْ طَاوُسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ إِنَّمَا يُبْعَثُ النَّاسُ عَلَى نِيَّاتِهِمْ ‏"‏ ‏.‏\hadithno{4229}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“People will be resurrected (and judged) according to their intentions.”}}
\hadithdefcmd{ibnmajah}{4230}{حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، أَنْبَأَنَا زَكَرِيَّا بْنُ عَدِيٍّ، أَنْبَأَنَا شَرِيكٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ يُحْشَرُ النَّاسُ عَلَى نِيَّاتِهِمْ ‏"‏ ‏.‏\hadithno{4230}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“People will be gathered (on the Day of Resurrection) according to their intentions.”}}
\hadithdefcmd{ibnmajah}{4231}{حَدَّثَنَا أَبُو بِشْرٍ، ‏:‏ بَكْرُ بْنُ خَلَفٍ وَأَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي أَبِي، عَنْ أَبِي يَعْلَى، عَنِ الرَّبِيعِ بْنِ خُثَيْمٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏:‏ أَنَّهُ خَطَّ خَطًّا مُرَبَّعًا وَخَطًّا وَسَطَ الْخَطِّ الْمُرَبَّعِ وَخُطُوطًا إِلَى جَانِبِ الْخَطِّ الَّذِي وَسَطَ الْخَطِّ الْمُرَبَّعِ وَخَطًّا خَارِجًا مِنَ الْخَطِّ الْمُرَبَّعِ فَقَالَ ‏:‏ ‏"‏ أَتَدْرُونَ مَا هَذَا ‏"‏ ‏.‏ قَالُوا ‏:‏ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏:‏ ‏"‏ هَذَا الإِنْسَانُ الْخَطُّ الأَوْسَطُ وَهَذِهِ الْخُطُوطُ إِلَى جَنْبِهِ الأَعْرَاضُ تَنْهَشُهُ أَوْ تَنْهَسُهُ مِنْ كُلِّ مَكَانٍ فَإِنْ أَخْطَأَهُ هَذَا أَصَابَهُ هَذَا وَالْخَطُّ الْمُرَبَّعُ الأَجَلُ الْمُحِيطُ وَالْخَطُّ الْخَارِجُ الأَمَلُ ‏"‏ ‏.‏\hadithno{4231}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Prophet (ﷺ) drew a square, and a line in the middle of the square, and lines to the side of the line in the middle of the square, and a line outside the square, and he said:“Do you know what this is?” They said: “Allah and His Messenger know best.” He said: “Man is the line in the middle, and these lines to his side are the sicknesses and problems that assail him from all places. If one misses him, another will befall him. The square is his life span, at his neck; and the line outside it is (his) hope.”}}
\hadithdefcmd{ibnmajah}{4232}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏"‏ هَذَا ابْنُ آدَمَ وَهَذَا أَجَلُهُ عِنْدَ قَفَاهُ ‏"‏ ‏.‏ وَبَسَطَ يَدَهُ أَمَامَهُ ثُمَّ قَالَ ‏:‏ ‏"‏ وَثَمَّ أَمَلُهُ ‏"‏ ‏.‏\hadithno{4232}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik narrated the Messenger of Allah (ﷺ) said:“This is the son of Adam, and this is his life span at his neck,’ then he spread his hand in front of him and said: ‘And there is his hope.”}}
\hadithdefcmd{ibnmajah}{4233}{حَدَّثَنَا أَبُو مَرْوَانَ، ‏:‏ مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ قَلْبُ الشَّيْخِ شَابٌّ فِي اثْنَتَيْنِ ‏:‏ فِي حُبِّ الْحَيَاةِ وَكَثْرَةِ الْمَالِ ‏"‏ ‏.‏\hadithno{4233}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The heart of an old man is young in the love of two things: Love of life and much wealth.”}}
\hadithdefcmd{ibnmajah}{4234}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الضَّرِيرُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ يَهْرَمُ ابْنُ آدَمَ وَيَشِبُّ مِنْهُ اثْنَتَانِ ‏:‏ الْحِرْصُ عَلَى الْمَالِ وَالْحِرْصُ عَلَى الْعُمُرِ ‏"‏ ‏.‏\hadithno{4234}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:“The son of Adam grows old but two things remain young in him: His craving for wealth and his craving for a long life.”}}
\hadithdefcmd{ibnmajah}{4235}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ لَوْ أَنَّ لاِبْنِ آدَمَ وَادِيَيْنِ مِنْ مَالٍ لأَحَبَّ أَنْ يَكُونَ مَعَهُمَا ثَالِثٌ وَلاَ يَمْلأُ نَفْسَهُ إِلاَّ التُّرَابُ وَيَتُوبُ اللَّهُ عَلَى مَنْ تَابَ ‏"‏ ‏.‏\hadithno{4235}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“If the son of Adam had two valleys of wealth, he would love to have a third along with them. Nothing could satisfy him except dust. And Allah accepts the repentance of the one who repents.”}}
\hadithdefcmd{ibnmajah}{4236}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدٍ الْمُحَارِبِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ أَعْمَارُ أُمَّتِي مَا بَيْنَ السِّتِّينَ إِلَى السَّبْعِينَ وَأَقَلُّهُمْ مَنْ يَجُوزُ ذَلِكَ ‏"‏ ‏.‏\hadithno{4236}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The ages of (the people in) my nation will be between sixty and seventy, and few of them will exceed that.”}}
\hadithdefcmd{ibnmajah}{4237}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ ‏:‏ وَالَّذِي ذَهَبَ بِنَفْسِهِ ـ صلى الله عليه وسلم ـ مَا مَاتَ حَتَّى كَانَ أَكْثَرُ صَلاَتِهِ وَهُوَ جَالِسٌ وَكَانَ أَحَبَّ الأَعْمَالِ إِلَيْهِ، الْعَمَلُ الصَّالِحُ الَّذِي يَدُومُ عَلَيْهِ الْعَبْدُ وَإِنْ كَانَ يَسِيرًا ‏.‏\hadithno{4237}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{It was narrated that Umm Salamah said:“By the One Who took his (ﷺ) soul, he did not die until most of his prayers were offered sitting down. And the most beloved of deeds to him was a righteous deed which a person persists in doing, even if it is something small.”}}
\hadithdefcmd{ibnmajah}{4238}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ ‏:‏ كَانَتْ عِنْدِي امْرَأَةٌ فَدَخَلَ عَلَىَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏:‏ ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ قُلْتُ ‏:‏ فُلاَنَةُ ‏.‏ لاَ تَنَامُ - تَذْكُرُ مِنْ صَلاَحِهَا - فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏:‏ ‏"‏ مَهْ عَلَيْكُمْ بِمَا تُطِيقُونَ فَوَاللَّهِ لاَ يَمَلُّ اللَّهُ حَتَّى تَمَلُّوا ‏"‏ ‏.‏ قَالَتْ ‏:‏ وَكَانَ أَحَبَّ الدِّينِ إِلَيْهِ الَّذِي يَدُومُ عَلَيْهِ صَاحِبُهُ ‏.‏\hadithno{4238}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“There was a woman with me, and the Prophet (ﷺ) entered upon me and said: ‘Who is that?’ I said: ‘So-and-so; she does not sleep,’” – she mentioned her excessive praying. “The Prophet (ﷺ) said: ‘Keep quiet. You should do what you are able to, for by Allah, Allah does not get tired (of giving reward) but you get tired.’” She said: “The most beloved of religious deed to him was that in which a person persists.”}}
\hadithdefcmd{ibnmajah}{4239}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، عَنْ سُفْيَانَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ، عَنْ حَنْظَلَةَ الْكَاتِبِ التَّمِيمِيِّ الأُسَيِّدِيِّ، قَالَ ‏:‏ كُنَّا عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَكَرْنَا الْجَنَّةَ وَالنَّارَ حَتَّى كَأَنَّا رَأْىَ الْعَيْنِ فَقُمْتُ إِلَى أَهْلِي وَوَلَدِي فَضَحِكْتُ وَلَعِبْتُ ‏.‏ قَالَ ‏:‏ فَذَكَرْتُ الَّذِي كُنَّا فِيهِ فَخَرَجْتُ فَلَقِيتُ أَبَا بَكْرٍ فَقُلْتُ ‏:‏ نَافَقْتُ، نَافَقْتُ ‏.‏ فَقَالَ أَبُو بَكْرٍ ‏:‏ إِنَّا لَنَفْعَلُهُ ‏.‏ فَذَهَبَ حَنْظَلَةُ فَذَكَرَهُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏:‏ ‏ "‏ يَا حَنْظَلَةُ لَوْ كُنْتُمْ كَمَا تَكُونُونَ عِنْدِي لَصَافَحَتْكُمُ الْمَلاَئِكَةُ عَلَى فُرُشِكُمْ - أَوْ عَلَى طُرُقِكُمْ - يَا حَنْظَلَةُ سَاعَةٌ وَسَاعَةٌ ‏"‏ ‏.‏\hadithno{4239}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Hanzalah Tamimi Al-Usaiyidi, the scribe, said:“We were with the Messenger of Allah (ﷺ) and we spoke of Paradise and Hell until it was as if we could see them. Then I got up and went to my family and children, and I laughed and played (with them). Then I remembered how we had been, and I went out and met Abu Bakr, and said: ‘I have become a hypocrite!’ Abu Bakr said: ‘We all do that.’” So Hanzalah went and mentioned that to the Prophet (ﷺ), who said: “O Hanzalah, if you were (always) as you are with me, the angels would shake hands with you in your beds and in your streets. O Hanzalah, there is a time for this and a time for that.”}}
\hadithdefcmd{ibnmajah}{4240}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الأَعْرَجُ، سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ اكْلَفُوا مِنَ الْعَمَلِ مَا تُطِيقُونَ فَإِنَّ خَيْرَ الْعَمَلِ أَدْوَمُهُ وَإِنْ قَلَّ ‏"‏ ‏.‏\hadithno{4240}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Take on only as much as you can do of good deeds, for the best of deeds is that which is done consistently, even if it is little.”}}
\hadithdefcmd{ibnmajah}{4241}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ اللَّهِ الأَشْعَرِيُّ، عَنْ عِيسَى بْنِ جَارِيَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ ‏:‏ مَرَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى رَجُلٍ يُصَلِّي عَلَى صَخْرَةٍ فَأَتَى نَاحِيَةَ مَكَّةَ فَمَكَثَ مَلِيًّا ثُمَّ انْصَرَفَ فَوَجَدَ الرَّجُلَ يُصَلِّي عَلَى حَالِهِ فَقَامَ فَجَمَعَ يَدَيْهِ ثُمَّ قَالَ ‏:‏ ‏"‏ يَا أَيُّهَا النَّاسُ عَلَيْكُمْ بِالْقَصْدِ ‏"‏ ‏.‏ ثَلاَثًا ‏:‏ ‏"‏ فَإِنَّ اللَّهَ لاَ يَمَلُّ حَتَّى تَمَلُّوا ‏"‏ ‏.‏\hadithno{4241}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) passed by a man who was praying on a rock, and he went towards Makkah and stayed a while, then he left and found the man still praying as he had been. He stood up and clasped his hands, then said: “O people, you should observe moderation,” three times, “for Allah does not get tired (of giving reward) but you get tired.”}}
\hadithdefcmd{ibnmajah}{4242}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، وَأَبِي، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قُلْنَا ‏:‏ يَا رَسُولَ اللَّهِ أَنُؤَاخَذُ بِمَا كُنَّا نَفْعَلُ فِي الْجَاهِلِيَّةِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ مَنْ أَحْسَنَ فِي الإِسْلاَمِ لَمْ يُؤَاخَذْ بِمَا كَانَ فِي الْجَاهِلِيَّةِ وَمَنْ أَسَاءَ أُخِذَ بِالأَوَّلِ وَالآخِرِ ‏"‏ ‏.‏\hadithno{4242}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Abdullah said:“We said: ‘O Messenger of Allah, will we be taken to task for what we did in the Ignorance period?’ The Messenger of Allah (ﷺ) said: ‘Whoever does good in Islam (i.e., after becoming a Muslim) he will not be taken to task for what he did in the Ignorance period, but whoever does evil (i.e., after entering Islam) he will be taken to task for both the former and the latter.’”}}
\hadithdefcmd{ibnmajah}{4243}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سَعِيدُ بْنُ مُسْلِمِ بْنِ بَانَكَ، قَالَ سَمِعْتُ عَامِرَ بْنَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، يَقُولُ ‏:‏ حَدَّثَنِي عَوْفُ بْنُ الْحَارِثِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ يَا عَائِشَةُ إِيَّاكِ وَمُحَقَّرَاتِ الأَعْمَالِ فَإِنَّ لَهَا مِنَ اللَّهِ طَالِبًا ‏"‏ ‏.‏\hadithno{4243}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) said to me: ‘O ‘Aishah, beware of (evil) deeds that are regarded as insignificant, for they have a pursuer from Allah. (i.e. accountability).”}}
\hadithdefcmd{ibnmajah}{4244}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، وَالْوَلِيدُ بْنُ مُسْلِمٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏"‏ إِنَّ الْمُؤْمِنَ إِذَا أَذْنَبَ كَانَتْ نُكْتَةٌ سَوْدَاءُ فِي قَلْبِهِ فَإِنْ تَابَ وَنَزَعَ وَاسْتَغْفَرَ صُقِلَ قَلْبُهُ فَإِنْ زَادَ زَادَتْ فَذَلِكَ الرَّانُ الَّذِي ذَكَرَهُ اللَّهُ فِي كِتَابِهِ ‏\{كَلاَّ بَلْ رَانَ عَلَى قُلُوبِهِمْ مَا كَانُوا يَكْسِبُونَ\}‏ ‏"‏ ‏.‏\hadithno{4244}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When the believer commits sin, a black spot appears on his heart. If he repents and gives up that sin and seeks forgiveness, his heart will be polished. But if (the sin) increases, (the black spot) increases. That is the Ran that Allah mentions in His Book: “Nay! But on their hearts is the Ran (covering of sins and evil deeds) which they used to earn.” [83:]}}
\hadithdefcmd{ibnmajah}{4245}{حَدَّثَنَا عِيسَى بْنُ يُونُسَ الرَّمْلِيُّ، حَدَّثَنَا عُقْبَةُ بْنُ عَلْقَمَةَ بْنِ حُدَيْجٍ الْمَعَافِرِيُّ، عَنْ أَرْطَاةَ بْنِ الْمُنْذِرِ، عَنْ أَبِي عَامِرٍ الأَلْهَانِيِّ، عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏:‏ ‏"‏ لأَعْلَمَنَّ أَقْوَامًا مِنْ أُمَّتِي يَأْتُونَ يَوْمَ الْقِيَامَةِ بِحَسَنَاتٍ أَمْثَالِ جِبَالِ تِهَامَةَ بِيضًا فَيَجْعَلُهَا اللَّهُ عَزَّ وَجَلَّ هَبَاءً مَنْثُورًا ‏"‏ ‏.‏ قَالَ ثَوْبَانُ ‏:‏ يَا رَسُولَ اللَّهِ صِفْهُمْ لَنَا جَلِّهِمْ لَنَا أَنْ لاَ نَكُونَ مِنْهُمْ وَنَحْنُ لاَ نَعْلَمُ ‏.‏ قَالَ ‏:‏ ‏"‏ أَمَا إِنَّهُمْ إِخْوَانُكُمْ وَمِنْ جِلْدَتِكُمْ وَيَأْخُذُونَ مِنَ اللَّيْلِ كَمَا تَأْخُذُونَ وَلَكِنَّهُمْ أَقْوَامٌ إِذَا خَلَوْا بِمَحَارِمِ اللَّهِ انْتَهَكُوهَا ‏"‏ ‏.‏\hadithno{4245}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Thawban that the Prophet (ﷺ) said:“I certainly know people of my nation who will come on the Day of Resurrection with good deeds like the mountains of Tihamah, but Allah will make them like scattered dust.” Thawban said: “O Messenger of Allah, describe them to us and tell us more, so that we will not become of them unknowingly.” He said: “They are your brothers and from your race, worshipping at night as you do, but they will be people who, when they are alone, transgress the sacred limits of Allah.”}}
\hadithdefcmd{ibnmajah}{4246}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ أَبِيهِ، وَعَمِّهِ، عَنْ جَدِّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏:‏ سُئِلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏:‏ مَا أَكْثَرُ مَا يُدْخِلُ الْجَنَّةَ قَالَ ‏:‏ ‏"‏ التَّقْوَى وَحُسْنُ الْخُلُقِ ‏"‏ ‏.‏ وَسُئِلَ ‏:‏ مَا أَكْثَرُ مَا يُدْخِلُ النَّارَ قَالَ ‏:‏ ‏"‏ الأَجْوَفَانِ ‏:‏ الْفَمُ وَالْفَرْجُ ‏"‏ ‏.‏\hadithno{4246}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) was asked: ‘What most admits people to Paradise?’ He said: ‘Piety and good manners.’ And he was asked: ‘What most leads people to Hell?’ He said: ‘The two hollow ones: The mouth and the private part.’”}}
\hadithdefcmd{ibnmajah}{4247}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ أَفْرَحُ بِتَوْبَةِ أَحَدِكُمْ مِنْهُ بِضَالَّتِهِ إِذَا وَجَدَهَا ‏"‏ ‏.‏\hadithno{4247}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Allah rejoiced more over the repentance of anyone of you, then you rejoice over your lost animal when you find it.”}}
\hadithdefcmd{ibnmajah}{4248}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ الْمَدَنِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ لَوْ أَخْطَأْتُمْ حَتَّى تَبْلُغَ خَطَايَاكُمُ السَّمَاءَ ثُمَّ تُبْتُمْ لَتَابَ عَلَيْكُمْ ‏"‏ ‏.‏\hadithno{4248}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“If you were to commit sin until your sins reach the heaven, then you were to repent, your repentance would be accepted.”}}
\hadithdefcmd{ibnmajah}{4249}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ لَلَّهُ أَفْرَحُ بِتَوْبَةِ عَبْدِهِ مِنْ رَجُلٍ أَضَلَّ رَاحِلَتَهُ بِفَلاَةٍ مِنَ الأَرْضِ فَالْتَمَسَهَا حَتَّى إِذَا أَعْيَى تَسَجَّى بِثَوْبِهِ فَبَيْنَا هُوَ كَذَلِكَ إِذْ سَمِعَ وَجْبَةَ الرَّاحِلَةِ حَيْثُ فَقَدَهَا فَكَشَفَ الثَّوْبَ عَنْ وَجْهِهِ فَإِذَا هُوَ بِرَاحِلَتِهِ ‏"‏ ‏.‏\hadithno{4249}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“Allah rejoices more over the repentance of His slave, than a man who loses his mount in a barren land, and he searches for it until he gets tired and covers his face with his garment, and while he is like that, he heard the footsteps of his mount where he lost it, so he lifts the garment from his face and there is his mount.”}}
\hadithdefcmd{ibnmajah}{4250}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرَّقَاشِيُّ، حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، حَدَّثَنَا مَعْمَرٌ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ أَبِي عُبَيْدَةَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ التَّائِبُ مِنَ الذَّنْبِ كَمَنْ لاَ ذَنْبَ لَهُ ‏"‏ ‏.‏\hadithno{4250}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu ‘Ubadah bin ‘Abdullah, that his father said:“The Messenger of Allah (ﷺ) said: ‘The one who repents from sin is like one who did not sin.’”}}
\hadithdefcmd{ibnmajah}{4251}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا عَلِيُّ بْنُ مَسْعَدَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ كُلُّ بَنِي آدَمَ خَطَّاءٌ وَخَيْرُ الْخَطَّائِينَ التَّوَّابُونَ ‏"‏ ‏.‏\hadithno{4251}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:“Every son of Adam commits sin, and the best of those who commit sin are those who repent.’”}}
\hadithdefcmd{ibnmajah}{4252}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ زِيَادِ بْنِ أَبِي مَرْيَمَ، عَنِ ابْنِ مَعْقِلٍ، قَالَ ‏:‏ دَخَلْتُ مَعَ أَبِي عَلَى عَبْدِ اللَّهِ فَسَمِعْتُهُ يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏"‏ النَّدَمُ تَوْبَةٌ ‏"‏ ‏.‏ فَقَالَ لَهُ أَبِي ‏:‏ أَنْتَ سَمِعْتَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏:‏ ‏"‏ النَّدَمُ تَوْبَةٌ ‏"‏ ‏.‏ قَالَ ‏:‏ نَعَمْ ‏.‏\hadithno{4252}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Ma’qil said:“I entered with my father upon ‘Abdullah, and I heard him say: ‘The messenger of Allah (ﷺ) said: “Regret is repentance.” My father said: ‘Did you hear the Prophet (ﷺ) say: “Regret is repentance?” He said: ‘Yes.’”}}
\hadithdefcmd{ibnmajah}{4253}{حَدَّثَنَا رَاشِدُ بْنُ سَعِيدٍ الرَّمْلِيُّ، أَنْبَأَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ ابْنِ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ مَكْحُولٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَيَقْبَلُ تَوْبَةَ الْعَبْدِ مَا لَمْ يُغَرْغِرْ ‏"‏ ‏.‏\hadithno{4253}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Prophet (ﷺ) said:“Allah accepts the repentance of His slave so long as the death rattle has not yet reached his throat.”}}
\hadithdefcmd{ibnmajah}{4254}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، حَدَّثَنَا الْمُعْتَمِرُ، سَمِعْتُ أَبِي، حَدَّثَنَا أَبُو عُثْمَانَ، عَنِ ابْنِ مَسْعُودٍ، ‏:‏ أَنَّ رَجُلاً، أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَذَكَرَ أَنَّهُ أَصَابَ مِنِ امْرَأَةٍ قُبْلَةً فَجَعَلَ يَسْأَلُ عَنْ كَفَّارَتِهَا فَلَمْ يَقُلْ لَهُ شَيْئًا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ \{وَأَقِمِ الصَّلاَةَ طَرَفَىِ النَّهَارِ وَزُلَفًا مِنَ اللَّيْلِ إِنَّ الْحَسَنَاتِ يُذْهِبْنَ السَّيِّئَاتِ ذَلِكَ ذِكْرَى لِلذَّاكِرِينَ\}‏ فَقَالَ الرَّجُلُ ‏:‏ يَا رَسُولَ اللَّهِ أَلِي هَذِهِ فَقَالَ ‏:‏ ‏ "‏ هِيَ لِمَنْ عَمِلَ بِهَا مِنْ أُمَّتِي ‏"‏ ‏.‏\hadithno{4254}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Mas’ud that a man came to the Prophet (ﷺ) and said that he had kissed a woman, and he started to ask about expiation, but he (the Prophet (ﷺ)) did not say anything to him. Then Allah revealed the Verse:“And perform prayers at the two ends of the day and in some hours of the night. Verily, the good deeds remove the evil deeds. That is a reminder for the mindful.” [11:114] The man said: “O Messenger of Allah, is this (the Verse) just for me?” He said: “It is for whoever acts upon it among my nation.”}}
\hadithdefcmd{ibnmajah}{4255}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، قَالَ قَالَ الزُّهْرِيُّ ‏:‏ أَلاَ أُحَدِّثُكَ بِحَدِيثَيْنِ عَجِيبَيْنِ ‏:‏ أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ أَسْرَفَ رَجُلٌ عَلَى نَفْسِهِ فَلَمَّا حَضَرَهُ الْمَوْتُ أَوْصَى بَنِيهِ فَقَالَ ‏:‏ إِذَا أَنَا مِتُّ فَأَحْرِقُونِي ثُمَّ اسْحَقُونِي ثُمَّ ذَرُّونِي فِي الرِّيحِ فِي الْبَحْرِ فَوَاللَّهِ لَئِنْ قَدَرَ عَلَىَّ رَبِّي لَيُعَذِّبُنِي عَذَابًا مَا عَذَّبَهُ أَحَدًا ‏.‏ قَالَ ‏:‏ فَفَعَلُوا بِهِ ذَلِكَ فَقَالَ لِلأَرْضِ ‏:‏ أَدِّي مَا أَخَذْتِ ‏.‏ فَإِذَا هُوَ قَائِمٌ فَقَالَ لَهُ ‏:‏ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ قَالَ ‏:‏ خَشْيَتُكَ - أَوْ مَخَافَتُكَ - يَا رَبِّ ‏.‏ فَغَفَرَ لَهُ لِذَلِكَ ‏"‏ ‏.‏\hadithno{4255}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A man went to extremes in committing sins. When death came to him, he left instructions to his sons, saying: ‘When I die, burn me, then grind me into powder, then scatter me in the wind and in the sea, for by Allah, if my Lord has power over me, He will subject me to a punishment that He has never subjected anyone to.’ So they did that to him, then (Allah) said to the earth: ‘Return what you have taken,’ and there he was, standing. He said to him: ‘What made you do what you have done?’ He said: ‘Fear of You, O Lord.’ So He forgave him because of that (fear).”}}
\hadithdefcmd{ibnmajah}{4256}{قَالَ الزُّهْرِيُّ وَحَدَّثَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ دَخَلَتِ امْرَأَةٌ النَّارَ فِي هِرَّةٍ رَبَطَتْهَا فَلاَ هِيَ أَطْعَمَتْهَا وَلاَ هِيَ أَرْسَلَتْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ حَتَّى مَاتَتْ ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ ‏:‏ لِئَلاَّ يَتَّكِلَ رَجُلٌ وَلاَ يَيْأَسَ رَجُلٌ ‏.‏\hadithno{4256}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A woman entered Hell because of a cat which she tied up and did not feed, or let it loose to eat of the vermin of the earth, until it died.”}}
\hadithdefcmd{ibnmajah}{4257}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُوسَى بْنِ الْمُسَيَّبِ الثَّقَفِيِّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ يَا عِبَادِي كُلُّكُمْ مُذْنِبٌ إِلاَّ مَنْ عَافَيْتُ فَسَلُونِي الْمَغْفِرَةَ فَأَغْفِرَ لَكُمْ وَمَنْ عَلِمَ مِنْكُمْ أَنِّي ذُو قُدْرَةٍ عَلَى الْمَغْفِرَةِ فَاسْتَغْفَرَنِي بِقُدْرَتِي غَفَرْتُ لَهُ، وَكُلُّكُمْ ضَالٌّ إِلاَّ مَنْ هَدَيْتُ فَسَلُونِي الْهُدَى أَهْدِكُمْ، وَكُلُّكُمْ فَقِيرٌ إِلاَّ مَنْ أَغْنَيْتُ فَسَلُونِي أَرْزُقْكُمْ، وَلَوْ أَنَّ حَيَّكُمْ وَمَيِّتَكُمْ وَأَوَّلَكُمْ وَآخِرَكُمْ وَرَطْبَكُمْ وَيَابِسَكُمُ اجْتَمَعُوا فَكَانُوا عَلَى قَلْبِ أَتْقَى عَبْدٍ مِنْ عِبَادِي - لَمْ يَزِدْ فِي مُلْكِي جَنَاحُ بَعُوضَةٍ، وَلَوِ اجْتَمَعُوا فَكَانُوا عَلَى قَلْبِ أَشْقَى عَبْدٍ مِنْ عِبَادِي لَمْ يَنْقُصْ مِنْ مُلْكِي جَنَاحُ بَعُوضَةٍ وَلَوْ أَنَّ حَيَّكُمْ وَمَيِّتَكُمْ، وَأَوَّلَكُمْ وَآخِرَكُمْ وَرَطْبَكُمْ وَيَابِسَكُمُ اجْتَمَعُوا، فَسَأَلَ كُلُّ سَائِلٍ مِنْهُمْ مَا بَلَغَتْ أُمْنِيَّتُهُ - مَا نَقَصَ مِنْ مُلْكِي إِلاَّ كَمَا لَوْ أَنَّ أَحَدَكُمْ مَرَّ بِشَفَةِ الْبَحْرِ فَغَمَسَ فِيهَا إِبْرَةً ثُمَّ نَزَعَهَا، ذَلِكَ بِأَنِّي جَوَادٌ مَاجِدٌ عَطَائِي كَلاَمٌ إِذَا أَرَدْتُّ شَيْئًا فَإِنَّمَا أَقُولُ لَهُ ‏:‏ كُنْ فَيَكُونُ ‏"‏ ‏.‏\hadithno{4257}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Dharr that the Messenger of Allah (ﷺ) said:“Allah the Blessed and Exalted says: ‘O My slaves, all of you are sinners except those whom I have saved. So ask Me for forgiveness, I will forgive you. Whoever among you knows that I have the power to forgive and asks Me to forgive by My power, I will forgive him. All of you are astray except those whom I guide. Ask Me for guidance and I will guide you. All of you are poor except those whom I enrich (make independent of means). Ask of Me and I will grant you provision. Even if your living and your dead, your first and your last, your fresh and your dry, were all as pious as the most pious among My slaves, that would not increase my dominion as much as a gnat’s wing, and if they were to be as evil as the most evil among My slaves, that would not detract from My dominion as much as a gnat’s wing. Even if your living and your dead, your first and your last, your fresh and your dry, were to join together and each of them were to ask for all that he wishes for, that would only detract from My dominion as much as if one of you were to pass by the edge of the sea and dip a needle in it and withdraw it. That is because I am the Most Generous, Majestic. I give with a word; when I will something, all I do is say to it “Be!” – and it is.’”}}
\hadithdefcmd{ibnmajah}{4258}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ أَكْثِرُوا ذِكْرَ هَاذِمِ اللَّذَّاتِ ‏"‏ ‏.‏ يَعْنِي الْمَوْتَ ‏.‏\hadithno{4258}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Frequently remember the destroyer of pleasures,’ meaning death.”}}
\hadithdefcmd{ibnmajah}{4259}{حَدَّثَنَا الزُّبَيْرُ بْنُ بَكَّارٍ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا نَافِعُ بْنُ عَبْدِ اللَّهِ، عَنْ فَرْوَةَ بْنِ قَيْسٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَالَ ‏:‏ كُنْتُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَجَاءَهُ رَجُلٌ مِنَ الأَنْصَارِ فَسَلَّمَ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ ثُمَّ قَالَ ‏:‏ يَا رَسُولَ اللَّهِ أَىُّ الْمُؤْمِنِينَ أَفْضَلُ قَالَ ‏:‏ ‏"‏ أَحْسَنُهُمْ خُلُقًا ‏"‏ ‏.‏ قَالَ فَأَىُّ الْمُؤْمِنِينَ أَكْيَسُ قَالَ ‏:‏ ‏"‏ أَكْثَرُهُمْ لِلْمَوْتِ ذِكْرًا وَأَحْسَنُهُمْ لِمَا بَعْدَهُ اسْتِعْدَادًا أُولَئِكَ الأَكْيَاسُ ‏"‏ ‏.‏\hadithno{4259}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Umar said:“I was with the Messenger of Allah (ﷺ) and a man from among the Ansar came to him and greeted the Prophet (ﷺ) with Salam. Then he said: ‘O Messenger of Allah, which of the believers is best?’ He said: ‘He who has the best manners among them.’ He said: ‘Which of them is wisest?’ He said: ‘The one who remembers death the most and is best in preparing for it. Those are the wisest.’”}}
\hadithdefcmd{ibnmajah}{4260}{حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، حَدَّثَنِي ابْنُ أَبِي مَرْيَمَ، عَنْ ضَمْرَةَ بْنِ حَبِيبٍ، عَنْ أَبِي يَعْلَى، شَدَّادِ بْنِ أَوْسٍ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ الْكَيِّسُ مَنْ دَانَ نَفْسَهُ وَعَمِلَ لِمَا بَعْدَ الْمَوْتِ وَالْعَاجِزُ مَنْ أَتْبَعَ نَفْسَهُ هَوَاهَا ثُمَّ تَمَنَّى عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{4260}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Ya’la Shaddad bin Aws that the Messenger of Allah (ﷺ) said:“The wise man is the one who takes account of himself and strives for that which is after death. And the helpless man is the one who follows his own whims then indulges in wishful thinking about Allah.”}}
\hadithdefcmd{ibnmajah}{4261}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَكَمِ بْنِ أَبِي زِيَادٍ، حَدَّثَنَا سَيَّارٌ، حَدَّثَنَا جَعْفَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، ‏:‏ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ دَخَلَ عَلَى شَابٍّ وَهُوَ فِي الْمَوْتِ فَقَالَ ‏:‏ ‏"‏ كَيْفَ تَجِدُكَ ‏"‏ ‏.‏ قَالَ ‏:‏ أَرْجُو اللَّهَ يَا رَسُولَ اللَّهِ وَأَخَافُ ذُنُوبِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏"‏ لاَ يَجْتَمِعَانِ فِي قَلْبِ عَبْدٍ فِي مِثْلِ هَذَا الْمَوْطِنِ إِلاَّ أَعْطَاهُ اللَّهُ مَا يَرْجُو وَآمَنَهُ مِمَّا يَخَافُ ‏"‏ ‏.‏\hadithno{4261}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) entered upon a young man who was dying and said:“How do you feel?” He said: “I have hope in Allah, O Messenger of Allah, but I fear my sins.” The Messenger of Allah (ﷺ) said: “These two things (hope and fear) do not coexist in the heart of a person in a situation like this, but Allah will give him that which he hopes for and keep him safe from that which he fears.”}}
\hadithdefcmd{ibnmajah}{4262}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ الْمَيِّتُ تَحْضُرُهُ الْمَلاَئِكَةُ فَإِذَا كَانَ الرَّجُلُ صَالِحًا قَالُوا ‏:‏ اخْرُجِي أَيَّتُهَا النَّفْسُ الطَّيِّبَةُ كَانَتْ فِي الْجَسَدِ الطَّيِّبِ اخْرُجِي حَمِيدَةً وَأَبْشِرِي بِرَوْحٍ وَرَيْحَانٍ وَرَبٍّ غَيْرِ غَضْبَانَ فَلاَ يَزَالُ يُقَالُ لَهَا ذَلِكَ حَتَّى تَخْرُجَ ثُمَّ يُعْرَجُ بِهَا إِلَى السَّمَاءِ فَيُفْتَحُ لَهَا فَيُقَالُ ‏:‏ مَنْ هَذَا فَيَقُولُونَ ‏:‏ فُلاَنٌ ‏.‏ فَيُقَالُ ‏:‏ مَرْحَبًا بِالنَّفْسِ الطَّيِّبَةِ، كَانَتْ فِي الْجَسَدِ الطَّيِّبِ ادْخُلِي حَمِيدَةً، وَأَبْشِرِي بِرَوْحٍ وَرَيْحَانٍ وَرَبٍّ غَيْرِ غَضْبَانَ ‏.‏ فَلاَ يَزَالُ يُقَالُ لَهَا ذَلِكَ حَتَّى يُنْتَهَى بِهَا إِلَى السَّمَاءِ الَّتِي فِيهَا اللَّهُ عَزَّ وَجَلَّ وَإِذَا كَانَ الرَّجُلُ السُّوءُ قَالَ اخْرُجِي أَيَّتُهَا النَّفْسُ الْخَبِيثَةُ كَانَتْ فِي الْجَسَدِ الْخَبِيثِ اخْرُجِي ذَمِيمَةً وَأَبْشِرِي بِحَمِيمٍ وَغَسَّاقٍ ‏.‏ وَآخَرَ مِنْ شَكْلِهِ أَزْوَاجٌ ‏.‏ فَلاَ يَزَالُ يُقَالُ لَهَا ذَلِكَ حَتَّى تَخْرُجَ ثُمَّ يُعْرَجُ بِهَا إِلَى السَّمَاءِ فَلاَ يُفْتَحُ لَهَا فَيُقَالُ ‏:‏ مَنْ هَذَا فَيُقَالُ ‏:‏ فُلاَنٌ ‏.‏ فَيُقَالُ ‏:‏ لاَ مَرْحَبًا بِالنَّفْسِ الْخَبِيثَةِ كَانَتْ فِي الْجَسَدِ الْخَبِيثِ ارْجِعِي ذَمِيمَةً فَإِنَّهَا لاَ تُفْتَحُ لَكِ أَبْوَابُ السَّمَاءِ فَيُرْسَلُ بِهَا مِنَ السَّمَاءِ ثُمَّ تَصِيرُ إِلَى الْقَبْرِ ‏"‏ ‏\hadithno{4262}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Angels come to the dying person, and if the man was righteous, they say: ‘Come out, O good soul that was in a good body, come out praiseworthy and receive glad tidings of mercy and fragrance and a Lord Who is not angry.’ And this is repeated until it comes out, then it is taken up to heaven, and it is opened for it, and it is asked: ‘Who is this?’ They say: ‘So-and-so.’ It is said: ‘Welcome to the good soul that was in a good body. Enter praiseworthy and receive the glad tidings of mercy and fragrance and a Lord Who is not angry.’ And this is repeated until it is brought to the heaven above which is Allah. But if the man was evil, they say: ‘Come out O evil soul that was in an evil body. Come out blameworthy, and receive the tidings of boiling water and the discharge of dirty wounds,’ and other torments of similar kind, all together. And this is repeated until it comes out, then it is taken up to heaven and it is not opened for it. And it is asked: ‘Who is this?’ It is said: ‘So-and-so.’ And it is said: ‘No welcome to the evil soul that was in an evil body. Go back blameworthy, for the gates of heaven will not be opened to you.’ So it is sent back down from heaven, then it goes to the grave.”}}
\hadithdefcmd{ibnmajah}{4263}{حَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، وَعُمَرُ بْنُ شَبَّةَ بْنِ عَبِيدَةَ، قَالاَ حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، أَخْبَرَنِي إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ إِذَا كَانَ أَجَلُ أَحَدِكُمْ بِأَرْضٍ أَوْثَبَتْهُ إِلَيْهَا الْحَاجَةُ فَإِذَا بَلَغَ أَقْصَى أَثَرِهِ قَبَضَهُ اللَّهُ سُبْحَانَهُ فَتَقُولُ الأَرْضُ يَوْمَ الْقِيَامَةِ ‏:‏ رَبِّ هَذَا مَا اسْتَوْدَعْتَنِي ‏"‏ ‏.‏\hadithno{4263}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Prophet (ﷺ) said:“If the appointed time of death of anyone of you is in a certain land, some need will cause him to go there, then when he reaches the furthest point that it is decreed he will reach, Allah takes (his soul). And on the Day of Resurrection the earth will say: ‘My Lord, this is what You entrusted to me.’”}}
\hadithdefcmd{ibnmajah}{4264}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ أَبُو سَلَمَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ فَقِيلَ لَهُ ‏:‏ يَا رَسُولَ اللَّهِ كَرَاهِيَةُ لِقَاءِ اللَّهِ فِي كَرَاهِيَةِ لِقَاءِ الْمَوْتِ فَكُلُّنَا يَكْرَهُ الْمَوْتَ قَالَ ‏:‏ ‏"‏ لاَ إِنَّمَا ذَاكَ عِنْدَ مَوْتِهِ إِذَا بُشِّرَ بِرَحْمَةِ اللَّهِ وَمَغْفِرَتِهِ أَحَبَّ لِقَاءَ اللَّهِ فَأَحَبَّ اللَّهُ لِقَاءَهُ وَإِذَا بُشِّرَ بِعَذَابِ اللَّهِ كَرِهَ لِقَاءَ اللَّهِ وَكَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{4264}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:“Whoever loves to meet Allah, Allah loves to meet him, and whoever hates to meet Allah, Allah hates to meet him.” It was said to him: “O Messenger of Allah, does hating to meet Allah mean hating to meet death? For all of us hate death.” He said: “No. Rather that is only at the moment of death. But if he is given the glad tidings of the mercy and forgiveness of Allah, he loves to meet Allah and Allah loves to meet him; and if he is given the tidings of the punishment of Allah, he hates to meet Allah and Allah hates to meet him.”}}
\hadithdefcmd{ibnmajah}{4265}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ لاَ يَتَمَنَّى أَحَدُكُمُ الْمَوْتَ لِضُرٍّ نَزَلَ بِهِ فَإِنْ كَانَ لاَ بُدَّ مُتَمَنِّيًا الْمَوْتَ فَلْيَقُلِ ‏:‏ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏"‏ ‏.‏\hadithno{4265}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:“None of you should wish for death because of some harm that befalls him. If he must wish for death, let him say: ‘O Allah, keep me alive so long as living is good for me and cause me to die when death is good for me.’”}}
\hadithdefcmd{ibnmajah}{4266}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏ "‏ لَيْسَ شَىْءٌ مِنَ الإِنْسَانِ إِلاَّ يَبْلَى إِلاَّ عَظْمًا وَاحِدًا وَهُوَ عَجْبُ الذَّنَبِ وَمِنْهُ يُرَكَّبُ الْخَلْقُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4266}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There is no part of man that will not disintegrate, apart from a single bone at the base of the coccyx, from which he will be recreated on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{4267}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، حَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، عَنْ عَبْدِ اللَّهِ بْنِ بَحِيرٍ، عَنْ هَانِئٍ، - مَوْلَى عُثْمَانَ - قَالَ ‏:‏ كَانَ عُثْمَانُ بْنُ عَفَّانَ إِذَا وَقَفَ عَلَى قَبْرٍ يَبْكِي حَتَّى يَبُلَّ لِحْيَتَهُ فَقِيلَ لَهُ ‏:‏ تَذْكُرُ الْجَنَّةَ وَالنَّارَ وَلاَ تَبْكِي وَتَبْكِي مِنْ هَذَا قَالَ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏"‏ إِنَّ الْقَبْرَ أَوَّلُ مَنَازِلِ الآخِرَةِ فَإِنْ نَجَا مِنْهُ فَمَا بَعْدَهُ أَيْسَرُ مِنْهُ وَإِنْ لَمْ يَنْجُ مِنْهُ، فَمَا بَعْدَهُ أَشَدُّ مِنْهُ ‏"‏ ‏.‏ قَالَ وَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏:‏ ‏"‏ مَا رَأَيْتُ مَنْظَرًا قَطُّ إِلاَّ وَالْقَبْرُ أَفْظَعُ مِنْهُ ‏"‏ ‏.‏\hadithno{4267}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Hani’ the freed slave of ‘Uthman bin ‘Affan, said:“When ‘Uthman bin ‘Affan stood beside a grave, he would weep until his beard became wet. It was said to him: ‘You remember Paradise and Hell, and you do not weep, but you weep for this?’ He said: ‘The Messenger of Allah (ﷺ) said: “The grave is the first stage of the Hereafter. Whoever is delivered from it, what comes after it is easier. If he is not delivered from it, then what comes after it is harder.’” He said that the Messenger of Allah (ﷺ) said: “I have never seen any horrible scene but the grave is more horrible.”}}
\hadithdefcmd{ibnmajah}{4268}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ إِنَّ الْمَيِّتَ يَصِيرُ إِلَى الْقَبْرِ فَيُجْلَسُ الرَّجُلُ الصَّالِحُ فِي قَبْرِهِ غَيْرَ فَزِعٍ وَلاَ مَشْعُوفٍ ثُمَّ يُقَالُ لَهُ ‏:‏ فِيمَ كُنْتَ فَيَقُولُ ‏:‏ كُنْتُ فِي الإِسْلاَمِ ‏.‏ فَيُقَالُ لَهُ ‏:‏ مَا هَذَا الرَّجُلُ فَيَقُولُ ‏:‏ مُحَمَّدٌ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ جَاءَنَا بِالْبَيِّنَاتِ مِنْ عِنْدِ اللَّهِ فَصَدَّقْنَاهُ ‏.‏ فَيُقَالُ لَهُ ‏:‏ هَلْ رَأَيْتَ اللَّهَ فَيَقُولُ ‏:‏ مَا يَنْبَغِي لأَحَدٍ أَنْ يَرَى اللَّهَ ‏.‏ فَيُفْرَجُ لَهُ فُرْجَةٌ قِبَلَ النَّارِ فَيَنْظُرُ إِلَيْهَا يَحْطِمُ بَعْضُهَا بَعْضًا فَيُقَالُ لَهُ ‏:‏ انْظُرْ إِلَى مَا وَقَاكَ اللَّهُ ‏.‏ ثُمَّ يُفْرَجُ لَهُ فُرْجَةٌ قِبَلَ الْجَنَّةِ فَيَنْظُرُ إِلَى زَهْرَتِهَا وَمَا فِيهَا فَيُقَالُ لَهُ ‏:‏ هَذَا مَقْعَدُكَ ‏.‏ وَيُقَالُ لَهُ ‏:‏ عَلَى الْيَقِينِ كُنْتَ وَعَلَيْهِ مُتَّ وَعَلَيْهِ تُبْعَثُ إِنْ شَاءَ اللَّهُ ‏.‏ وَيُجْلَسُ الرَّجُلُ السُّوءُ فِي قَبْرِهِ فَزِعًا مَشْعُوفًا فَيُقَالُ لَهُ ‏:‏ فِيمَ كُنْتَ فَيَقُولُ ‏:‏ لاَ أَدْرِي ‏.‏ فَيُقَالُ لَهُ ‏:‏ مَا هَذَا الرَّجُلُ فَيَقُولُ ‏:‏ سَمِعْتُ النَّاسَ يَقُولُونَ قَوْلاً فَقُلْتُهُ ‏.‏ فَيُفْرَجُ لَهُ قِبَلَ الْجَنَّةِ فَيَنْظُرُ إِلَى زَهْرَتِهَا وَمَا فِيهَا فَيُقَالُ لَهُ ‏:‏ انْظُرْ إِلَى مَا صَرَفَ اللَّهُ عَنْكَ ‏.‏ ثُمَّ يُفْرَجُ لَهُ فُرْجَةٌ قِبَلَ النَّارِ فَيَنْظُرُ إِلَيْهَا يَحْطِمُ بَعْضُهَا بَعْضًا فَيُقَالُ لَهُ ‏:‏ هَذَا مَقْعَدُكَ عَلَى الشَّكِّ كُنْتَ وَعَلَيْهِ مُتَّ وَعَلَيْهِ تُبْعَثُ إِنْ شَاءَ اللَّهُ تَعَالَى ‏"‏ ‏.‏\hadithno{4268}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The dead person ends up in his grave, then the righteous man is made to sit up in his grave with no fear or panic. Then it is said to him: ‘What religion did you follow?’ He said: ‘I was in Islam.’ It is said to him: ‘Who is this man?’ He says: ‘Muhammad the Messenger of Allah (ﷺ). He brought us clear signs from Allah and we believed him.’ It is said to him: ‘Have you seen Allah?’ He says: ‘No one is able to see Allah.’ Then a window to Hell is opened for him, and he sees it, parts of it destroying others. Then it is said to him: ‘Look at what Allah has saved you from.’ Then a window to Paradise is opened to him, and he looks at its beauty and what is in it. It is said to him: ‘This is your place.’ And it is said to him: ‘You had certain faith and you died in that state, and in that state you will be resurrected if Allah wills.’ And the evil man is made to sit up in his grave with fear and panic. It is said to him: ‘What religion did you follow?’ He says: ‘I do not know.’ It is said to him: ‘Who is this man?’ He says: ‘I heard the people saying something and I said it too.’ Then a window to Paradise is opened to him, and he looks at its beauty and what is in it. It is said to him: ‘Look at what Allah has diverted away from you.’ Then a window to Hell is opened for him, and he sees it, parts of it destroying others, and it is said to him: ‘This is your place. You were doubtful; in this state you died and in this state you will be resurrected, if Allah wills.’”}}
\hadithdefcmd{ibnmajah}{4269}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏"‏ ‏\{يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ \}‏ قَالَ ‏:‏ نَزَلَتْ فِي عَذَابِ الْقَبْرِ يُقَالُ لَهُ ‏:‏ مَنْ رَبُّكَ فَيَقُولُ ‏:‏ رَبِّيَ اللَّهُ وَنَبِيِّي مُحَمَّدٌ فَذَلِكَ قَوْلُهُ ‏\{يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ\}‏ ‏"‏ ‏.‏\hadithno{4269}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Bara’ bin ‘Azib that the Prophet (ﷺ) said:“Allah will keep firm those who believe, with the word that stands firm.” [14:27] This has been revealed concerning the torment of the grave. It will be said to him: ‘Who is your Lord?’ He will say: ‘My Lord is Allah, and my Prophet is Muhammad.’ This is what Allah says: Allah will keep firm those who believe, with the word that stands firm in this world (i.e. they will keep on worshipping Allah Alone and none else), and in the Hereafter (i.e., at the time of questioning in the grave).’” [14:]}}
\hadithdefcmd{ibnmajah}{4270}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ إِذَا مَاتَ أَحَدُكُمْ عُرِضَ عَلَى مَقْعَدِهِ بِالْغَدَاةِ وَالْعَشِيِّ إِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَمِنْ أَهْلِ الْجَنَّةِ، وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ يُقَالُ هَذَا مَقْعَدُكَ حَتَّى تُبْعَثَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4270}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) said:“When anyone of you dies, he is shown his place morning and evening. If he is one of the people of Paradise, then he will be shown his seat in Paradise, and if he is one of the people of Hell, then he will be shown his seat in Hell. And it is said: ‘This is your place until you are raised on the Day of Resurrection.’”}}
\hadithdefcmd{ibnmajah}{4271}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، أَنْبَأَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبٍ الأَنْصَارِيِّ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَاهُ كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ إِنَّمَا نَسَمَةُ الْمُؤْمِنِ طَائِرٌ يَعْلُقُ فِي شَجَرِ الْجَنَّةِ حَتَّى يَرْجِعَ إِلَى جَسَدِهِ يَوْمَ يُبْعَثُ ‏"‏ ‏.‏\hadithno{4271}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Ka’b Al-Ansari that his father used to narrate that the Messenger of Allah (ﷺ) said:“The believer’s soul is a bird that eats from the trees of Paradise, until it will be returned to his body on the Day when he is resurrected.”}}
\hadithdefcmd{ibnmajah}{4272}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ حَفْصٍ الأُبُلِّيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏:‏ ‏ "‏ إِذَا أُدْخِلَ الْمَيِّتُ الْقَبْرَ مُثِّلَتِ الشَّمْسُ لَهُ عِنْدَ غُرُوبِهَا فَيَجْلِسُ يَمْسَحُ عَيْنَيْهِ وَيَقُولُ ‏:‏ دَعُونِي أُصَلِّي ‏"‏ ‏.‏\hadithno{4272}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) said:“When the deceased enters the grave, the sun is made to appear as if it is setting. He sits up, wipes his eyes and says: ‘Let me pray.’”}}
\hadithdefcmd{ibnmajah}{4273}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ حَجَّاجٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ صَاحِبَىِ الصُّورِ بِأَيْدِيهِمَا - أَوْ فِي أَيْدِيهِمَا - قَرْنَانِ يُلاَحِظَانِ النَّظَرَ مَتَى يُؤْمَرَانِ ‏"‏ ‏.‏\hadithno{4273}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“The two who are entrusted with the Trumpet have two horns in their hands, waiting until they will be commanded (to blow them).”}}
\hadithdefcmd{ibnmajah}{4274}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَجُلٌ مِنَ الْيَهُودِ بِسُوقِ الْمَدِينَةِ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْبَشَرِ ‏.‏ فَرَفَعَ رَجُلٌ مِنَ الأَنْصَارِ يَدَهُ فَلَطَمَهُ قَالَ تَقُولُ هَذَا وَفِينَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{وَنُفِخَ فِي الصُّورِ فَصَعِقَ مَنْ فِي السَّمَوَاتِ وَمَنْ فِي الأَرْضِ إِلاَّ مَنْ شَاءَ اللَّهُ ثُمَّ نُفِخَ فِيهِ أُخْرَى فَإِذَا هُمْ قِيَامٌ يَنْظُرُونَ\}‏ فَأَكُونُ أَوَّلَ مَنْ رَفَعَ رَأْسَهُ فَإِذَا أَنَا بِمُوسَى آخِذٌ بِقَائِمَةٍ مِنْ قَوَائِمِ الْعَرْشِ فَلاَ أَدْرِي أَرَفَعَ رَأْسَهُ قَبْلِي أَوْ كَانَ مِمَّنِ اسْتَثْنَى اللَّهُ عَزَّ وَجَلَّ ‏.‏ وَمَنْ قَالَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى فَقَدْ كَذَبَ ‏"‏ ‏.‏\hadithno{4274}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“A Jewish man said in the marketplace of Al-Madinah: ‘By the One Who chose Musa above all of mankind.’ An Ansari man raised his hand and slapped him. He said: ‘How dare you say this when the Messenger of Allah (ﷺ) is among us?’ Mention of that was made to the Messenger of Allah (ﷺ), and he said: ‘Allah says: “And the trumpet will be blown, and all who are in the heavens and all who are on the earth will swoon away, except him whom Allah wills. Then it will be blown a second time, and behold they will be standing, looking on (waiting).” [39:68] I will be the first one to raise his head, and I will see Musa holding on to one of the pillars of the Throne, and I do not know whether he will have raised his head before me, or he will be one of those whom Allah exempts. And whoever says that I am better than Yunus bin Matta, he is lying.”}}
\hadithdefcmd{ibnmajah}{4275}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي، عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ يَأْخُذُ الْجَبَّارُ سَمَوَاتِهِ وَأَرَضِيهِ بِيَدِهِ - وَقَبَضَ يَدَهُ فَجَعَلَ يَقْبِضُهَا وَيَبْسُطُهَا - ثُمَّ يَقُولُ أَنَا الْجَبَّارُ أَنَا الْمَلِكُ أَيْنَ الْجَبَّارُونَ أَيْنَ الْمُتَكَبِّرُونَ ‏"‏ ‏.‏ قَالَ وَيَتَمَايَلُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ حَتَّى نَظَرْتُ إِلَى الْمِنْبَرِ يَتَحَرَّكُ مِنْ أَسْفَلِ شَىْءٍ مِنْهُ حَتَّى إِنِّي لأَقُولُ أَسَاقِطٌ هُوَ بِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ\hadithno{4275}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“I heard the Messenger of Allah (ﷺ) say on the pulpit: ‘The Compeller (Al-Jabbar) will seize His heavens and His earths in His Hand’ – and he clenched his hand and started to open and close it – ‘Then He will say: “I am the Compeller, I am the King. Where are the tyrants? Where are the arrogant?” And the Messenger of Allah (ﷺ) was leaning to his right and his left, until I could see the pulpit shaking at the bottom, and I thought that it would fall along with the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{4276}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَاتِمِ بْنِ أَبِي صَغِيرَةَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ، قَالَ قَالَتْ عَائِشَةُ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ يُحْشَرُ النَّاسُ يَوْمَ الْقِيَامَةِ قَالَ ‏"‏ حُفَاةً عُرَاةً ‏"‏ ‏.‏ قُلْتُ وَالنِّسَاءُ قَالَ ‏"‏ وَالنِّسَاءُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ فَمَا يُسْتَحْيَى قَالَ ‏"‏ يَا عَائِشَةُ الأَمْرُ أَشَدُّ مِنْ أَنْ يَنْظُرَ بَعْضُهُمْ إِلَى بَعْضٍ ‏"‏ ‏.‏\hadithno{4276}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Qasim said:‘Aishah said: “I said: ‘O Messenger of Allah, how will the people be gathered on the Day of Resurrection?’ He said: ‘Barefoot and naked.’ I said: ‘And the women?’ He said: ‘And the women.’ I said: ‘O Messenger of Allah, will we not feel embarrassed?’ He said: ‘O ‘Aishah, the matter will be too serious for them to look at one another.’”}}
\hadithdefcmd{ibnmajah}{4277}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ عَلِيِّ بْنِ رِفَاعَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُعْرَضُ النَّاسُ يَوْمَ الْقِيَامَةِ ثَلاَثَ عَرَضَاتٍ فَأَمَّا عَرْضَتَانِ فَجِدَالٌ وَمَعَاذِيرُ وَأَمَّا الثَّالِثَةُ فَعِنْدَ ذَلِكَ تَطِيرُ الصُّحُفُ فِي الأَيْدِي فَآخِذٌ بِيَمِينِهِ وَآخِذٌ بِشِمَالِهِ ‏"‏ ‏.‏\hadithno{4277}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Musa Al-Ash’ari that the Messenger of Allah (ﷺ) said:“The people will be presented (before Allah) three times on the Day of Resurrection. The first two times will be for disputes and excuses, and the third time will be when the scrolls (of deeds) fly into their hands; some will take it in the right hand and some in the left.”}}
\hadithdefcmd{ibnmajah}{4278}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، وَأَبُو خَالِدٍ الأَحْمَرُ عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏\{يَوْمَ يَقُومُ النَّاسُ لِرَبِّ الْعَالَمِينَ\}‏ قَالَ ‏"‏ يَقُومُ أَحَدُهُمْ فِي رَشْحِهِ إِلَى أَنْصَافِ أُذُنَيْهِ ‏"‏ ‏.‏\hadithno{4278}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) said:“The Day when (all) mankind will stand before the Lord of all that exists.” [83:6] One of them will stand in his sweat up to halfway up his ears.”}}
\hadithdefcmd{ibnmajah}{4279}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ قَوْلِهِ ‏\{يَوْمَ تُبَدَّلُ الأَرْضُ غَيْرَ الأَرْضِ وَالسَّمَوَاتُ ‏\}‏ فَأَيْنَ تَكُونُ النَّاسُ يَوْمَئِذٍ قَالَ ‏"‏ عَلَى الصِّرَاطِ ‏"‏ ‏.‏\hadithno{4279}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“I asked the Messenger of Allah (ﷺ): “On the Day when the earth will be changed to another earth and so will be the heavens.” [14:48] – where will the people be on that Day?’ He said: ‘On the Sirat (the Bridge across Hell-fire).’”}}
\hadithdefcmd{ibnmajah}{4280}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ الْمُغِيرَةِ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ عَبْدٍ الْعُتْوَارِيِّ، أَحَدِ بَنِي لَيْثٍ - قَالَ - وَكَانَ فِي حَجْرِ أَبِي سَعِيدٍ قَالَ سَمِعْتُهُ - يَعْنِي أَبَا سَعِيدٍ، - يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ يُوضَعُ الصِّرَاطُ بَيْنَ ظَهْرَانَىْ جَهَنَّمَ عَلَى حَسَكٍ كَحَسَكِ السَّعْدَانِ ثُمَّ يَسْتَجِيزُ النَّاسُ فَنَاجٍ مُسَلَّمٌ وَمَخْدُوجٌ بِهِ ثُمَّ نَاجٍ وَمُحْتَبَسٌ بِهِ وَمَنْكُوسٌ فِيهَا ‏"‏ ‏.‏\hadithno{4280}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa’eed narrated that the Messenger of Allah (ﷺ) said:“The Sirat will be placed across Hell, on thorns like the thorns of Sa’dan plant.* Then the people will cross it. Some will pass over safe and sound, some will be detained, and some will fall in headfirst.”}}
\hadithdefcmd{ibnmajah}{4281}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، عَنْ أُمِّ مُبَشِّرٍ، عَنْ حَفْصَةَ، قَالَتْ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ إِنِّي لأَرْجُو أَلاَّ يَدْخُلَ النَّارَ أَحَدٌ إِنْ شَاءَ اللَّهُ تَعَالَى مِمَّنْ شَهِدَ بَدْرًا وَالْحُدَيْبِيَةَ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَلَيْسَ قَدْ قَالَ اللَّهُ ‏\{وَإِنْ مِنْكُمْ إِلاَّ وَارِدُهَا كَانَ عَلَى رَبِّكَ حَتْمًا مَقْضِيًّا\}‏ قَالَ ‏"‏ أَلَمْ تَسْمَعِيهِ يَقُولُ ‏\{ثُمَّ نُنَجِّي الَّذِينَ اتَّقَوْا وَنَذَرُ الظَّالِمِينَ فِيهَا جِثِيًّا\}‏ ‏.‏\hadithno{4281}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hafsah that the Prophet (ﷺ) said:“I hope that no one of those who witnessed (the battle of) Badr and (Treaty) Hudaybiyah will enter Hell, if Allah wills.” I said: “O Messenger of Allah, doesn’t Allah say “There is not one of you but will pass over it (Hell); this is with your Lord, a decree which must be accomplished?” [19:71] He said: “Have you not heard that He says: ‘Then We shall save those who use to fear Allah and were dutiful to Him. And We shall leave the wrongdoers therein (humbled) to their knees (in Hell)?’” [19:]}}
\hadithdefcmd{ibnmajah}{4282}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَرِدُونَ عَلَىَّ غُرًّا مُحَجَّلِينَ مِنَ الْوُضُوءِ سِيمَاءُ أُمَّتِي لَيْسَ لأَحَدٍ غَيْرِهَا ‏"‏ ‏.‏\hadithno{4282}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“You will come to me with radiant faces, hands and feet from the traces of ablution. This is the characteristic sign of my nation which does not belong to anyone else.”}}
\hadithdefcmd{ibnmajah}{4283}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي قُبَّةٍ فَقَالَ ‏"‏ أَتَرْضَوْنَ أَنْ تَكُونُوا رُبُعَ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ قُلْنَا بَلَى ‏.‏ قَالَ ‏"‏ أَتَرْضَوْنَ أَنْ تَكُونُوا ثُلُثَ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ قُلْنَا نَعَمْ ‏.‏ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَرْجُو أَنْ تَكُونُوا نِصْفَ أَهْلِ الْجَنَّةِ وَذَلِكَ أَنَّ الْجَنَّةَ لاَ يَدْخُلُهَا إِلاَّ نَفْسٌ مُسْلِمَةٌ وَمَا أَنْتُمْ فِي أَهْلِ الشِّرْكِ إِلاَّ كَالشَّعَرَةِ الْبَيْضَاءِ فِي جِلْدِ الثَّوْرِ الأَسْوَدِ أَوْ كَالشَّعَرَةِ السَّوْدَاءِ فِي جِلْدِ الثَّوْرِ الأَحْمَرِ ‏"‏ ‏.‏\hadithno{4283}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Abdullah said:“We were with the Messenger of Allah (ﷺ) in a tent, and he said: ‘Will it not please you to be one quarter of the people of Paradise?’ We said: ‘Yes.’ He said: ‘Will it not please you to be one third of the people of Paradise?’ We said: ‘Yes.’ He said: ‘By the One in Whose Hand is my soul, I hope that you will be half of the people of Paradise. For no one will enter Paradise but a Muslim soul, and among the people of polytheism you are like a white hair on the hide of a black bull, or like a black hair on the hide of a red bull.’”}}
\hadithdefcmd{ibnmajah}{4284}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَأَحْمَدُ بْنُ سِنَانٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ يَجِيءُ النَّبِيُّ يَوْمَ الْقِيَامَةِ وَمَعَهُ الرَّجُلُ وَيَجِيءُ النَّبِيُّ وَمَعَهُ الرَّجُلاَنِ وَيَجِيءُ النَّبِيُّ وَمَعَهُ الثَّلاَثَةُ وَأَكْثَرُ مِنْ ذَلِكَ وَأَقَلُّ فَيُقَالُ لَهُ هَلْ بَلَّغْتَ قَوْمَكَ فَيَقُولُ نَعَمْ ‏.‏ فَيُدْعَى قَوْمُهُ فَيُقَالُ هَلَ بَلَّغَكُمْ فَيَقُولُونَ لاَ ‏.‏ فَيُقَالُ مَنْ شَهِدَ لَكَ فَيَقُولُ مُحَمَّدٌ وَأُمَّتُهُ ‏.‏ فَتُدْعَى أُمَّةُ مُحَمَّدٍ فَيُقَالُ هَلْ بَلَّغَ هَذَا فَيَقُولُونَ نَعَمْ ‏.‏ فَيَقُولُ وَمَا عِلْمُكُمْ بِذَلِكَ فَيَقُولُونَ أَخْبَرَنَا نَبِيُّنَا بِذَلِكَ أَنَّ الرُّسُلَ قَدْ بَلَّغُوا فَصَدَّقْنَاهُ ‏.‏ قَالَ فَذَلِكُمْ قَوْلُهُ تَعَالَى ‏\{وَكَذَلِكَ جَعَلْنَاكُمْ أُمَّةً وَسَطًا لِتَكُونُوا شُهَدَاءَ عَلَى النَّاسِ وَيَكُونَ الرَّسُولُ عَلَيْكُمْ شَهِيدًا\}‏ ‏.‏\hadithno{4284}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“A Prophet will come accompanied by two men, and a Prophet will come accompanied by three, and (some will come) with more or less than that. It will be said to him: ‘Did you convey the message to your people?’ And he will say: ‘Yes.’ Then his people will be called and it will be said: ‘Did he convey the message to you?’ They will say: ‘No.’ Then it will be said: ‘Who will bear witness for you?’ He will say: ‘Muhammad and his nation.’ So the nation of Muhammad will be called and it will be said: ‘Did this man convey the message?’ They will say: ‘Yes.’ He will say: ‘How did you know that?’ They will say: ‘Our Prophet told us that the Messengers had conveyed the message, and we believed him.’ This is what Allah says: “Thus We have made you, a just (and the best) nation, that you be witnesses over mankind and the Messenger (Muhammad (ﷺ)) be a witness over you.’” [2:]}}
\hadithdefcmd{ibnmajah}{4285}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رِفَاعَةَ الْجُهَنِيِّ، قَالَ صَدَرْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ مَا مِنْ عَبْدٍ يُؤْمِنُ ثُمَّ يُسَدَّدُ إِلاَّ سُلِكَ بِهِ فِي الْجَنَّةِ وَأَرْجُو أَلاَّ يَدْخُلُوهَا حَتَّى تَبَوَّءُوا أَنْتُمْ وَمَنْ صَلَحَ مِنْ ذَرَارِيِّكُمْ مَسَاكِنَ فِي الْجَنَّةِ وَلَقَدْ وَعَدَنِي رَبِّي عَزَّ وَجَلَّ أَنْ يُدْخِلَ الْجَنَّةَ مِنْ أُمَّتِي سَبْعِينَ أَلْفًا بِغَيْرِ حِسَابٍ ‏"‏ ‏.‏\hadithno{4285}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Rifa’ah Al-Juhani said:“We came back (from a campaign) with the Messenger of Allah (ﷺ) and he said: ‘By the One in Whose Hand is the soul of Muhammad, there is no person who believes then stands firm, but he will be caused to enter Paradise. I hope that they will not enter it until you and those who are righteous among your offspring will enter it and take up your dwelling places therein. And my Lord has promised me that seventy thousand of my nation will enter Paradise without being brought to account.’”}}
\hadithdefcmd{ibnmajah}{4286}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ الأَلْهَانِيُّ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ الْبَاهِلِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ وَعَدَنِي رَبِّي سُبْحَانَهُ أَنْ يُدْخِلَ الْجَنَّةَ مِنْ أُمَّتِي سَبْعِينَ أَلْفًا لاَ حِسَابَ عَلَيْهِمْ وَلاَ عَذَابَ مَعَ كُلِّ أَلْفٍ سَبْعُونَ أَلْفًا وَثَلاَثُ حَثَيَاتٍ مِنْ حَثَيَاتِ رَبِّي عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4286}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Umamah Al-Bahili said:“I heard the Messenger of Allah (ﷺ) say: ‘My Lord has promised me that seventy thousand of my nation will enter Paradise without being brought to account or punished. With every thousand will be (another) seventy thousand, and three handfuls of my Lord, the Glorified.’”}}
\hadithdefcmd{ibnmajah}{4287}{حَدَّثَنَا عِيسَى بْنُ مُحَمَّدِ بْنِ النَّحَّاسِ الرَّمْلِيُّ، وَأَيُّوبُ بْنُ مُحَمَّدٍ الرَّقِّيُّ، قَالاَ حَدَّثَنَا ضَمْرَةُ بْنُ رَبِيعَةَ، عَنِ ابْنِ شَوْذَبٍ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نُكْمِلُ يَوْمَ الْقِيَامَةِ سَبْعِينَ أُمَّةً نَحْنُ آخِرُهَا وَخَيْرُهَا ‏"‏ ‏.‏\hadithno{4287}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Bahz bin Hakim, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) said: ‘On the Day of Resurrection, we will complete seventy nations, of whom we are the last and the best.’”}}
\hadithdefcmd{ibnmajah}{4288}{حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خِدَاشٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّكُمْ وَفَّيْتُمْ سَبْعِينَ أُمَّةً أَنْتُمْ خَيْرُهَا وَأَكْرَمُهَا عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{4288}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Bahz bin Hakim, from his father, that his grandfather said:“I heard the Messenger of Allah (ﷺ) say: ‘You complete seventy nations, of which you are the best and dearest to Allah.’”}}
\hadithdefcmd{ibnmajah}{4289}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِسْحَاقَ الْجَوْهَرِيُّ، حَدَّثَنَا حُسَيْنُ بْنُ حَفْصٍ الأَصْبَهَانِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَهْلُ الْجَنَّةِ عِشْرُونَ وَمِائَةُ صَفٍّ ثَمَانُونَ مِنْ هَذِهِ الأُمَّةِ وَأَرْبَعُونَ مِنْ سَائِرِ الأُمَمِ ‏"‏ ‏.‏\hadithno{4289}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sulaiman bin Buraidah, from his father, that the Prophet (ﷺ) said:“The people of Paradise are one hundred and twenty ranks, eighty from this nation and forty from all other nations.”}}
\hadithdefcmd{ibnmajah}{4290}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو سَلَمَةَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سَعِيدِ بْنِ إِيَاسٍ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ نَحْنُ آخِرُ الأُمَمِ وَأَوَّلُ مَنْ يُحَاسَبُ يُقَالُ أَيْنَ الأُمَّةُ الأُمِّيَّةُ وَنَبِيُّهَا فَنَحْنُ الآخِرُونَ الأَوَّلُونَ ‏"‏ ‏.‏\hadithno{4290}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said:“We are the last of the nations, and the first to be brought to account. It will be said: ‘Where is the unlettered nation and its Prophet?’ So we are the last and the first.”}}
\hadithdefcmd{ibnmajah}{4291}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ أَبِي الْمُسَاوِرِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا جَمَعَ اللَّهُ الْخَلاَئِقَ يَوْمَ الْقِيَامَةِ أُذِنَ لأُمَّةِ مُحَمَّدٍ بِالسُّجُودِ فَيَسْجُدُونَ لَهُ طَوِيلاً ثُمَّ يُقَالُ ارْفَعُوا رُءُوسَكُمْ قَدْ جَعَلْنَا عِدَّتَكُمْ فِدَاءَكُمْ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{4291}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Burdah that his father said:“The Messenger of Allah (ﷺ) said: ‘When Allah gathers all creatures on the Day of Resurrection, permission will be given to the nation of Muhammad to prostrate, so they will prostrate to Him for a long time. Then it will be said: “Raise your heads, for a certain number of you will go to Hell-fire and these will be your ransom from Hell.”}}
\hadithdefcmd{ibnmajah}{4292}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا كَثِيرُ بْنُ سُلَيْمٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ هَذِهِ أُمَّةٌ مَرْحُومَةٌ عَذَابُهَا بِأَيْدِيهَا فَإِذَا كَانَ يَوْمُ الْقِيَامَةِ دُفِعَ إِلَى كُلِّ رَجُلٍ مِنَ الْمُسْلِمِينَ رَجُلٌ مِنَ الْمُشْرِكِينَ فَيُقَالُ هَذَا فِدَاؤُكَ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{4292}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“This nation has been granted mercy (in the Hereafter) and its torment (in this world) is at the hands of one another. When the Day of Resurrection comes, each Muslim man will be given a man from among the idolaters and it will be said: ‘This is your ransom from the Fire.’”}}
\hadithdefcmd{ibnmajah}{4293}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ لِلَّهِ مِائَةَ رَحْمَةٍ قَسَمَ مِنْهَا رَحْمَةً بَيْنَ جَمِيعِ الْخَلاَئِقِ فَبِهَا يَتَرَاحَمُونَ وَبِهَا يَتَعَاطَفُونَ وَبِهَا تَعْطِفُ الْوَحْشُ عَلَى أَوْلاَدِهَا وَأَخَّرَ تِسْعَةً وَتِسْعِينَ رَحْمَةً يَرْحَمُ بِهَا عِبَادَهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4293}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Allah has one hundred (degrees of) mercy, of which He has shared one between all of creation, by virtue of which you show mercy and compassion towards one another and the wild animals show compassion towards their young. And He has kept back ninety-nine (degrees of) mercy by virtue of which He will show mercy to His slaves on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{4294}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَأَحْمَدُ بْنُ سِنَانٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَلَقَ اللَّهُ عَزَّ وَجَلَّ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ مِائَةَ رَحْمَةٍ فَجَعَلَ فِي الأَرْضِ مِنْهَا رَحْمَةً فَبِهَا تَعْطِفُ الْوَالِدَةُ عَلَى وَلَدِهَا وَالْبَهَائِمُ بَعْضُهَا عَلَى بَعْضٍ وَالطَّيْرُ وَأَخَّرَ تِسْعَةً وَتِسْعِينَ إِلَى يَوْمِ الْقِيَامَةٍ فَإِذَا كَانَ يَوْمُ الْقِيَامَةِ أَكْمَلَهَا اللَّهُ بِهَذِهِ الرَّحْمَةِ ‏"‏ ‏.‏\hadithno{4294}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“On the day when He created the heavens and the earth, Allah created one hundred (degrees of) mercy, of which He placed one on earth, by virtue of which mothers show compassion to their children and animals as well as the birds show compassion to one another. And He kept back ninety-nine (degrees of) mercy. When the Day of Resurrection comes, Allah will complete this mercy.”}}
\hadithdefcmd{ibnmajah}{4295}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَمَّا خَلَقَ الْخَلْقَ كَتَبَ بِيَدِهِ عَلَى نَفْسِهِ إِنَّ رَحْمَتِي تَغْلِبُ غَضَبِي ‏"‏ ‏.‏\hadithno{4295}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When Allah created the universe, He decreed for Himself: ‘My mercy prevails over My wrath.’”}}
\hadithdefcmd{ibnmajah}{4296}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ مَرَّ بِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَنَا عَلَى حِمَارٍ فَقَالَ ‏"‏ يَا مُعَاذُ هَلْ تَدْرِي مَا حَقُّ اللَّهِ عَلَى الْعِبَادِ وَمَا حَقُّ الْعِبَادِ عَلَى اللَّهِ ‏"‏ ‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ فَإِنَّ حَقَّ اللَّهِ عَلَى الْعِبَادِ أَنْ يَعْبُدُوهُ وَلاَ يُشْرِكُوا بِهِ شَيْئًا ‏.‏ وَحَقُّ الْعِبَادِ عَلَى اللَّهِ إِذَا فَعَلُوا ذَلِكَ أَنْ لاَ يُعَذِّبَهُمْ ‏"‏ ‏.‏\hadithno{4296}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mu’adh bin Jabal said:“The Messenger of Allah (ﷺ) passed by me when I was riding a donkey, and said: ‘O Mu’adh, do you know what Allah’s right over His slaves is and what His slaves’ right over Allah is?’ I said: ‘Allah and His Messenger know best.’ He said: ‘The right of Allah over His slaves is that they should worship Him and not associate anything with Him. And the right of the slaves over Allah, if they do that, is that He should not punish them.’”}}
\hadithdefcmd{ibnmajah}{4297}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَعْيَنَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ يَحْيَى الشَّيْبَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ حَفْصٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي بَعْضِ غَزَوَاتِهِ فَمَرَّ بِقَوْمٍ فَقَالَ مَنِ الْقَوْمُ فَقَالُوا نَحْنُ الْمُسْلِمُونَ ‏.‏ وَامْرَأَةٌ تَحْصِبُ تَنُّورَهَا وَمَعَهَا ابْنٌ لَهَا فَإِذَا ارْتَفَعَ وَهَجُ التَّنُّورِ تَنَحَّتْ بِهِ فَأَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَتْ أَنْتَ رَسُولُ اللَّهِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَتْ بِأَبِي أَنْتَ وَأُمِّي أَلَيْسَ اللَّهُ بِأَرْحَمِ الرَّاحِمِينَ قَالَ ‏"‏ بَلَى ‏"‏ ‏.‏ قَالَتْ أَوَلَيْسَ اللَّهُ بِأَرْحَمَ بِعِبَادِهِ مِنَ الأُمِّ بِوَلَدِهَا قَالَ ‏"‏ بَلَى ‏"‏ ‏.‏ قَالَتْ فَإِنَّ الأُمَّ لاَ تُلْقِي وَلَدَهَا فِي النَّارِ ‏.‏ فَأَكَبَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَبْكِي ثُمَّ رَفَعَ رَأْسَهُ إِلَيْهَا فَقَالَ ‏"‏ إِنَّ اللَّهَ لاَ يُعَذِّبُ مِنْ عِبَادِهِ إِلاَّ الْمَارِدَ الْمُتَمَرِّدَ الَّذِي يَتَمَرَّدُ عَلَى اللَّهِ وَأَبَى أَنْ يَقُولَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{4297}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“We were with the Messenger of Allah (ﷺ) on one of his campaigns. He passed by some people and said: ‘Who are these people?’ They said: ‘We are Muslims.’ There was a woman putting wood in her oven, and a son of hers was with her. When the flames got higher, she moved him away. She came to the Prophet (ﷺ) and said: ‘Are you the Messenger of Allah?’ He said: ‘Yes.’ She said: ‘May my father and mother be ransomed for you. Is not Allah the Most Merciful of those who show mercy?’ He said: ‘Yes indeed.’ She said: ‘Is not Allah more Merciful than a mother to her child?’ He said: ‘Yes indeed.’ She said: ‘A mother would not throw her child into the fire.’ The Messenger of Allah (ﷺ) lowered his head and wept. Then he looked up at her and said: ‘Allah does not punish any of His slaves except those who are defiant and rebellious, who rebel against Allah and refuse to say: La ilaha illallah.’”}}
\hadithdefcmd{ibnmajah}{4298}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا عَمْرُو بْنُ هَاشِمٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ يَدْخُلُ النَّارَ إِلاَّ شَقِيٌّ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَنِ الشَّقِيُّ قَالَ ‏"‏ مَنْ لَمْ يَعْمَلْ لِلَّهِ بِطَاعَةٍ وَلَمْ يَتْرُكْ لَهُ مَعْصِيَةً ‏"‏ ‏.‏\hadithno{4298}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: “No one will enter Hell except one who is doomed.” It was said: “O Messenger of Allah, who is the one who is doomed?” He said: “The one who never does any act of obedience (towards Allah) and who never omitted any act of sin.”}}
\hadithdefcmd{ibnmajah}{4299}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا سُهَيْلُ بْنُ عَبْدِ اللَّهِ، - أَخُو حَزْمٍ الْقُطَعِيِّ - حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَرَأَ - أَوْ تَلاَ - هَذِهِ الآيَةَ ‏\{هُوَ أَهْلُ التَّقْوَى وَأَهْلُ الْمَغْفِرَةِ\}‏ فَقَالَ ‏"‏ قَالَ اللَّهُ عَزَّ وَجَلَّ أَنَا أَهْلٌ أَنْ أُتَّقَى فَلاَ يُجْعَلَ مَعِي إِلَهٌ آخَرُ فَمَنِ اتَّقَى أَنْ يَجْعَلَ مَعِي إِلَهًا آخَرَ فَأَنَا أَهْلٌ أَنْ أَغْفِرَ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ الْقَطَّانُ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَصْرٍ، حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي حَزْمٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ فِي هَذِهِ الآيَةِ ‏\{هُوَ أَهْلُ التَّقْوَى وَأَهْلُ الْمَغْفِرَةِ \}‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ قَالَ رَبُّكُمْ أَنَا أَهْلٌ أَنْ أُتَّقَى فَلاَ يُشْرَكَ بِي غَيْرِي وَأَنَا أَهْلٌ لِمَنِ اتَّقَى أَنْ يُشْرِكَ بِي أَنْ أَغْفِرَ لَهُ ‏"‏ ‏.‏\hadithno{4299}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) recited this Verse:“He (Allah) is the One, deserving that mankind should be afraid of, and should be dutiful to Him, and should not take any Ilah (god) along with Him, and He is the One Who forgives (sins).” [74:56] Then he said: “Allah says: ‘I am the One Who deserves to be feared, so no other god should be appointed alongside Me. Whoever avoids appointing another god alongside Me, I am the One Who should forgive him.” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{4300}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي عَامِرُ بْنُ يَحْيَى، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُصَاحُ بِرَجُلٍ مِنْ أُمَّتِي يَوْمَ الْقِيَامَةِ عَلَى رُءُوسِ الْخَلاَئِقِ فَيُنْشَرُ لَهُ تِسْعَةٌ وَتِسْعُونَ سِجِلاًّ كُلُّ سِجِلٍّ مَدَّ الْبَصَرِ ثُمَّ يَقُولُ اللَّهُ عَزَّ وَجَلَّ هَلْ تُنْكِرُ مِنْ هَذَا شَيْئًا فَيَقُولُ لاَ يَا رَبِّ فَيَقُولُ أَظَلَمَتْكَ كَتَبَتِي الْحَافِظُونَ ثُمَّ يَقُولُ أَلَكَ عُذْرٌ أَلَكَ حَسَنَةٌ فَيُهَابُ الرَّجُلُ فَيَقُولُ لاَ ‏.‏ فَيَقُولُ بَلَى إِنَّ لَكَ عِنْدَنَا حَسَنَاتٍ وَإِنَّهُ لاَ ظُلْمَ عَلَيْكَ الْيَوْمَ فَتُخْرَجُ لَهُ بِطَاقَةٌ فِيهَا أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ قَالَ فَيَقُولُ يَا رَبِّ مَا هَذِهِ الْبِطَاقَةُ مَعَ هَذِهِ السِّجِلاَّتِ فَيَقُولُ إِنَّكَ لاَ تُظْلَمُ ‏.‏ فَتُوضَعُ السِّجِلاَّتُ فِي كِفَّةٍ وَالْبِطَاقَةُ فِي كِفَّةٍ فَطَاشَتِ السِّجِلاَّتُ وَثَقُلَتِ الْبِطَاقَةُ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى الْبِطَاقَةُ الرُّقْعَةُ وَأَهْلُ مِصْرَ يَقُولُونَ لِلرُّقْعَةِ بِطَاقَةً\hadithno{4300}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Abdullah bin ‘Amr narrated that the Messenger of Allah (ﷺ) said:“A man from my nation will be called before all of creation on the Day of Resurrection, and ninety-nine scrolls will be spread out for him, each one extending as far as the eye can see. Then Allah will say: “Do you deny anything of this?” He will say: “No, O Lord.” He will say: “Have My recording scribes been unfair to you?” Then He will say: “Apart from that, do you have any good deeds?” The man will be terrified and will say: “No.” (Allah) will say: “Indeed, you have good deeds with Us, and you will not be treated unjustly this Day.” Then a card will be brought out on which is written Ash-hadu an la ilaha illallah wa anna Muhammadan ‘abduhu wa rasuluhu (I bear witness that none has the right to be worshipped but Allah, and that Muhammad is His slave and Messenger). He will say: “O Lord, what is this card compared with these scrolls?” He will say: “You will not be treated unjustly.” Then the scrolls will be placed in one side of the Balance and the card in the other. The scrolls will go up (i.e., be light) and the card will go down (i.e., will weigh heavily).”}}
\hadithdefcmd{ibnmajah}{4301}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا زَكَرِيَّا، حَدَّثَنَا عَطِيَّةُ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ لِي حَوْضًا مَا بَيْنَ الْكَعْبَةِ وَبَيْتِ الْمَقْدِسِ أَبْيَضَ مِثْلَ اللَّبَنِ آنِيَتُهُ عَدَدُ النُّجُومِ وَإِنِّي لأَكْثَرُ الأَنْبِيَاءِ تَبَعًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4301}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) said:“I have a Cistern, (as large as the distance) between the Ka’bah and Baitul-Maqdis (Jerusalem). (It is) whiter than milk, and its vessels are the number of the stars. I will be the Prophet with the most followers on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{4302}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ أَبِي مَالِكٍ، سَعْدِ بْنِ طَارِقٍ عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ حَوْضِي لأَبْعَدُ مِنْ أَيْلَةَ إِلَى عَدَنَ وَالَّذِي نَفْسِي بِيَدِهِ لآنِيَتُهُ أَكْثَرُ مِنْ عَدَدِ النُّجُومِ وَلَهُوَ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ وَأَحْلَى مِنَ الْعَسَلِ وَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَذُودُ عَنْهُ الرِّجَالَ كَمَا يَذُودُ الرَّجُلُ الإِبِلَ الْغَرِيبَةَ عَنْ حَوْضِهِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ أَتَعْرِفُنَا قَالَ ‏"‏ نَعَمْ تَرِدُونَ عَلَىَّ غُرًّا مُحَجَّلِينَ مِنْ أَثَرِ الْوُضُوءِ لَيْسَتْ لأَحَدٍ غَيْرِكُمْ ‏"‏ ‏.‏\hadithno{4302}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hudhaifah that the Messenger of Allah (ﷺ) said:“My Cistern is wider than the distance between Ailah and ‘Aden. By the One in Whose Hand is my soul, its vessels are more numerous than the number of stars, and it is whiter than milk and sweeter than honey. By the One in Whose Hand is my soul, I will drive men away from it as a man drives strange camels away from his cistern.” It was said: “O Messenger of Allah, will you recognize us?” He said: “Yes, you will come to me with radiant faces, hands and feet, because of the traces of ablution, and this is not for anyone but you.”}}
\hadithdefcmd{ibnmajah}{4303}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُهَاجِرٍ، حَدَّثَنِي الْعَبَّاسُ بْنُ سَالِمٍ الدِّمَشْقِيُّ، نُبِّئْتُ عَنْ أَبِي سَلاَّمٍ الْحَبَشِيِّ، قَالَ بَعَثَ إِلَىَّ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ فَأَتَيْتُهُ عَلَى بَرِيدٍ فَلَمَّا قَدِمْتُ عَلَيْهِ قَالَ لَقَدْ شَقَقْنَا عَلَيْكَ يَا أَبَا سَلاَّمٍ فِي مَرْكَبِكَ ‏.‏ قَالَ أَجَلْ وَاللَّهِ يَا أَمِيرَ الْمُؤْمِنِينَ ‏.‏ قَالَ وَاللَّهِ مَا أَرَدْتُ الْمَشَقَّةَ عَلَيْكَ وَلَكِنْ حَدِيثٌ بَلَغَنِي أَنَّكَ تُحَدِّثُ بِهِ عَنْ ثَوْبَانَ مَوْلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْحَوْضِ فَأَحْبَبْتُ أَنْ تُشَافِهَنِي بِهِ ‏.‏ قَالَ فَقُلْتُ حَدَّثَنِي ثَوْبَانُ مَوْلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ حَوْضِي مَا بَيْنَ عَدَنَ إِلَى أَيْلَةَ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ وَأَحْلَى مِنَ الْعَسَلِ أَوَانِيهِ كَعَدَدِ نُجُومِ السَّمَاءِ مَنْ شَرِبَ مِنْهُ شَرْبَةً لَمْ يَظْمَأْ بَعْدَهَا أَبَدًا وَأَوَّلُ مَنْ يَرِدُهُ عَلَىَّ فُقَرَاءُ الْمُهَاجِرِينَ الدُّنْسُ ثِيَابًا وَالشُّعْثُ رُءُوسًا الَّذِينَ لاَ يَنْكِحُونَ الْمُنَعَّمَاتِ وَلاَ يُفْتَحُ لَهُمُ السُّدَدُ ‏"‏ ‏.‏ قَالَ فَبَكَى عُمَرُ حَتَّى اخْضَلَّتْ لِحْيَتُهُ ثُمَّ قَالَ لَكِنِّي قَدْ نَكَحْتُ الْمُنَعَّمَاتِ وَفُتِحَتْ لِيَ السُّدَدُ لاَ جَرَمَ أَنِّي لاَ أَغْسِلُ ثَوْبِي الَّذِي عَلَى جَسَدِي حَتَّى يَتَّسِخَ وَلاَ أَدْهُنُ رَأْسِي حَتَّى يَشْعَثَ ‏.‏\hadithno{4303}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sallam Al-Habashi said:“Umar bin ‘Abdul-‘Aziz sent for me and I came to him upon the riding animal prepared for swift mail delivery. When I came to him, he said: ‘We have caused you some trouble O Abu Sallam.’ He said: ‘Yes, by Allah, O Commander of the Believers!’ He said: ‘By Allah, we did not want to cause you any hardship, but there is a Hadith which I have heard that you narrate from Thawban, the freed slave of the Messenger of Allah (ﷺ), concerning the Cistern, and I wanted to hear it directly from you.’ He said: “I said: ‘Thawban, the freed slave of the Messenger of Allah (ﷺ), told me that the Messenger of Allah (ﷺ) said: “My Cistern is (wider than) the distance between Ailah and ‘Aden. It is whiter than milk and sweeter than honey, and its cups are as many as the stars in the sky. Whoever drinks from it will never feel thirst again. The first ones who come to drink from it will be the poor Muhajirin, with dirty clothes and disheveled hair, who do not marry refined women and for whom no doors are opened.” ‘Umar wept until his beard became wet, then he said: ‘But I have married refined women and doors have been opened for me. Certainly I will not wash the clothes that are on my body until they become dirt, and I will not comb my hair until it becomes disheveled.’”}}
\hadithdefcmd{ibnmajah}{4304}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبِي، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا بَيْنَ نَاحِيَتَىْ حَوْضِي كَمَا بَيْنَ صَنْعَاءَ وَالْمَدِينَةِ أَوْ كَمَا بَيْنَ الْمَدِينَةِ وَعَمَّانَ ‏"‏ ‏.‏\hadithno{4304}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:“The distance between the two ends of my Cistern is like the distance between San’a and Al-Madinah,’ or ‘between Al-Madinah and ‘Amman.’”}}
\hadithdefcmd{ibnmajah}{4305}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، قَالَ قَالَ أَنَسُ بْنُ مَالِكٍ قَالَ نَبِيُّ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُرَى فِيهِ أَبَارِيقُ الذَّهَبِ وَالْفِضَّةِ كَعَدَدِ نُجُومِ السَّمَاءِ ‏"‏ ‏.‏\hadithno{4305}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Anas bin Malik narrated that the Prophet (ﷺ) said:‘One can see in it (the Cistern) jugs of gold and silver, like the number of stars in the sky.”}}
\hadithdefcmd{ibnmajah}{4306}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ أَتَى الْمَقْبَرَةَ فَسَلَّمَ عَلَى الْمَقْبَرَةِ فَقَالَ ‏"‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ تَعَالَى بِكُمْ لاَحِقُونَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ وَدِدْتُ أَنَّا قَدْ رَأَيْنَا إِخْوَانَنَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَوَلَسْنَا إِخْوَانَكَ قَالَ ‏"‏ أَنْتُمْ أَصْحَابِي وَإِخْوَانِي الَّذِينَ يَأْتُونَ مِنْ بَعْدِي وَأَنَا فَرَطُكُمْ عَلَى الْحَوْضِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ تَعْرِفُ مَنْ لَمْ يَأْتِ مِنْ أُمَّتِكَ قَالَ ‏"‏ أَرَأَيْتُمْ لَوْ أَنَّ رَجُلاً لَهُ خَيْلٌ غُرٌّ مُحَجَّلَةٌ بَيْنَ ظَهْرَانَىْ خَيْلٍ دُهْمٍ بُهْمٍ أَلَمْ يَكُنْ يَعْرِفُهَا ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ فَإِنَّهُمْ يَأْتُونَ يَوْمَ الْقِيَامَةِ غُرًّا مُحَجَّلِينَ مِنْ آثَارِ الْوُضُوءِ ‏"‏ ‏.‏ قَالَ ‏"‏ أَنَا فَرَطُهُمْ عَلَى الْحَوْضِ ‏"‏ ‏.‏ ثُمَّ قَالَ أَلاَ لَيُذَادَنَّ رِجَالٌ عَنْ حَوْضِي كَمَا يُذَادُ الْبَعِيرُ الضَّالُّ فَأُنَادِيهِمْ أَلاَ هَلُمُّوا ‏.‏ فَيُقَالُ إِنَّهُمْ قَدْ بَدَّلُوا بَعْدَكَ وَلَمْ يَزَالُوا يَرْجِعُونَ عَلَى أَعْقَابِهِمْ ‏.‏ فَأَقُولُ أَلاَ سُحْقًا سُحْقًا ‏"‏ ‏.‏\hadithno{4306}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) came to a graveyard and greeted (its occupants) with Salam, then he said:“Peace be upon you, abode of believing people. We will join you soon, if Allah wills.” Then he said: “Would that we could see our brothers.” They said: “O Messenger of Allah, are we not your brothers?” He said: “You are my Companions. My brothers are those who will come after me. I will reach the Cistern ahead of you.” They said: “O Messenger of Allah, how will you recognize those of your nation who have not yet come?” He said: “If a man has a horse with a blaze on its forehead and white feet, don’t you think that he will recognize it among horses that are deep black in color?” They said: “Of course.” He said: “On the Day of Resurrection they will come with radiant faces, hands, and feet, because of the traces of ablution.” He said: “I will reach the Cistern ahead of you.” Then he said: “Men will be driven away from my Cistern just as stray camels are driven away. And I will call to them: ‘Come here!’ But it will be said: ‘They changed after you were gone, and they kept turning on their heels.’ So I will say: “Be off with you!”}}
\hadithdefcmd{ibnmajah}{4307}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لِكُلِّ نَبِيٍّ دَعْوَةٌ مُسْتَجَابَةٌ فَتَعَجَّلَ كُلُّ نَبِيٍّ دَعْوَتَهُ وَإِنِّي اخْتَبَأْتُ دَعْوَتِي شَفَاعَةً لأُمَّتِي فَهِيَ نَائِلَةٌ مَنْ مَاتَ مِنْهُمْ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا ‏"‏ ‏.‏\hadithno{4307}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Every Prophet had a prayer that was answered, and every Prophet offered this prayer in this world. But I am saving my prayer so that I can intercede for my nation, and it reaches every one of them who dies not associating anything with Allah.”}}
\hadithdefcmd{ibnmajah}{4308}{حَدَّثَنَا مُجَاهِدُ بْنُ مُوسَى، وَأَبُو إِسْحَاقَ الْهَرَوِيُّ إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حَاتِمٍ قَالاَ حَدَّثَنَا هُشَيْمٌ، أَنْبَأَنَا عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَنَا سَيِّدُ وَلَدِ آدَمَ وَلاَ فَخْرَ وَأَنَا أَوَّلُ مَنْ تَنْشَقُّ الأَرْضُ عَنْهُ يَوْمَ الْقِيَامَةِ وَلاَ فَخْرَ وَأَنَا أَوَّلُ شَافِعٍ وَأَوَّلُ مُشَفَّعٍ وَلاَ فَخْرَ وَلِوَاءُ الْحَمْدِ بِيَدِي يَوْمَ الْقِيَامَةِ وَلاَ فَخْرَ ‏"‏ ‏.‏\hadithno{4308}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“I am the leader of the sons of Adam, and it is no boast. I will be the first one for whom the earth will be split open on the Day of Resurrection, and it is no boast. I will be the first to intercede and the first whose intercession will be accepted, and it is no boast. The banner of praise will be in my hand on the Day of Resurrection, and it is no boast.”}}
\hadithdefcmd{ibnmajah}{4309}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، قَالاَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا سَعِيدُ بْنُ يَزِيدَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَمَّا أَهْلُ النَّارِ الَّذِينَ هُمْ أَهْلُهَا فَإِنَّهُمْ لاَ يَمُوتُونَ فِيهَا وَلاَ يَحْيَوْنَ وَلَكِنْ نَاسٌ أَصَابَتْهُمُ النَّارُ بِذُنُوبِهِمْ أَوْ بِخَطَايَاهُمْ فَأَمَاتَتْهُمْ إِمَاتَةً حَتَّى إِذَا كَانُوا فَحْمًا أُذِنَ لَهُمْ فِي الشَّفَاعَةِ فَجِيءَ بِهِمْ ضَبَائِرَ ضَبَائِرَ فَبُثُّوا عَلَى أَنْهَارِ الْجَنَّةِ فَقِيلَ يَا أَهْلَ الْجَنَّةِ أَفِيضُوا عَلَيْهِمْ فَيَنْبُتُونَ نَبَاتَ الْحِبَّةِ تَكُونُ فِي حَمِيلِ السَّيْلِ ‏"‏ ‏.‏ قَالَ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ كَأَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَدْ كَانَ فِي الْبَادِيَةِ ‏.‏\hadithno{4309}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“As for the people of Hell, who are its people (i.e., its permanent residents), they will neither die nor live therein. But there are some people who will be punished with fire because of their sins, whom it will kill, then when they have become like coal, permission will be granted for intercession for them. They will be brought, group by group, and scattered on the banks of the rivers of Paradise. It will be said: ‘O people of Paradise, pour water on them.’ Then they will grow like seeds carried by a flood (i.e., quickly).” A man among the people said: It is as if the Messenger of Allah (ﷺ) has been in the desert.”}}
\hadithdefcmd{ibnmajah}{4310}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ شَفَاعَتِي يَوْمَ الْقِيَامَةِ لأَهْلِ الْكَبَائِرِ مِنْ أُمَّتِي ‏"‏ ‏.‏\hadithno{4310}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:“I heard the Messenger of Allah (ﷺ) say: ‘My intercession on the Day of Resurrection will be for those among my nation who committed major sins.’”}}
\hadithdefcmd{ibnmajah}{4311}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَسَدٍ، حَدَّثَنَا أَبُو بَدْرٍ، حَدَّثَنَا زِيَادُ بْنُ خَيْثَمَةَ، عَنْ نُعَيْمِ بْنِ أَبِي هِنْدٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خُيِّرْتُ بَيْنَ الشَّفَاعَةِ وَبَيْنَ أَنْ يَدْخُلَ نِصْفُ أُمَّتِي الْجَنَّةَ فَاخْتَرْتُ الشَّفَاعَةَ لأَنَّهَا أَعَمُّ وَأَكْفَى أَتُرَوْنَهَا لِلْمُتَّقِينَ لاَ وَلَكِنَّهَا لِلْمُذْنِبِينَ الْخَطَّائِينَ الْمُتَلَوِّثِينَ ‏"‏ ‏.‏\hadithno{4311}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Musa Al-Ash’ari that the Messenger of Allah (ﷺ) said:“I was given the choice between being admitted to Paradise, and I chose intercession, because it is more general and more sufficient. Do you think it is for the pious? No, it is for the impure sinners.”}}
\hadithdefcmd{ibnmajah}{4312}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ يَجْتَمِعُ الْمُؤْمِنُونَ يَوْمَ الْقِيَامَةِ يُلْهَمُونَ - أَوْ يَهُمُّونَ شَكَّ سَعِيدٌ - فَيَقُولُونَ لَوْ تَشَفَّعْنَا إِلَى رَبِّنَا فَأَرَاحَنَا مِنْ مَكَانِنَا فَيَأْتُونَ آدَمَ فَيَقُولُونَ أَنْتَ آدَمُ أَبُو النَّاسِ خَلَقَكَ اللَّهُ بِيَدِهِ وَأَسْجَدَ لَكَ مَلاَئِكَتَهُ فَاشْفَعْ لَنَا عِنْدَ رَبِّكَ يُرِحْنَا مِنْ مَكَانِنَا هَذَا ‏.‏ فَيَقُولُ لَسْتُ هُنَاكُمْ - وَيَذْكُرُ وَيَشْكُو إِلَيْهِمْ ذَنْبَهُ الَّذِي أَصَابَ فَيَسْتَحْيِي مِنْ ذَلِكَ - وَلَكِنِ ائْتُوا نُوحًا فَإِنَّهُ أَوَّلُ رَسُولٍ بَعَثَهُ اللَّهُ إِلَى أَهْلِ الأَرْضِ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ - وَيَذْكُرُ سُؤَالَهُ رَبَّهُ مَا لَيْسَ لَهُ بِهِ عِلْمٌ وَيَسْتَحْيِي مِنْ ذَلِكَ - وَلَكِنِ ائْتُوا خَلِيلَ الرَّحْمَنِ إِبْرَاهِيمَ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ وَلَكِنِ ائْتُوا مُوسَى عَبْدًا كَلَّمَهُ اللَّهُ وَأَعْطَاهُ التَّوْرَاةَ ‏.‏ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ - وَيَذْكُرُ قَتْلَهُ النَّفْسَ بِغَيْرِ النَّفْسِ - وَلَكِنِ ائْتُوا عِيسَى عَبْدَ اللَّهِ وَرَسُولَهُ وَكَلِمَةَ اللَّهِ وَرُوحَهُ ‏.‏ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ وَلَكِنِ ائْتُوا مُحَمَّدًا عَبْدًا غَفَرَ اللَّهُ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ ‏.‏ قَالَ فَيَأْتُونِي فَأَنْطَلِقُ - قَالَ فَذَكَرَ هَذَا الْحَرْفَ عَنِ الْحَسَنِ ‏.‏ قَالَ فَأَمْشِي بَيْنَ السِّمَاطَيْنِ مِنَ الْمُؤْمِنِينَ ‏.‏ قَالَ ثُمَّ عَادَ إِلَى حَدِيثِ أَنَسٍ - قَالَ ‏"‏ فَأَسْتَأْذِنُ عَلَى رَبِّي فَيُؤْذَنُ لِي فَإِذَا رَأَيْتُهُ وَقَعْتُ سَاجِدًا فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي ثُمَّ يُقَالُ ارْفَعْ يَا مُحَمَّدُ وَقُلْ تُسْمَعْ وَسَلْ تُعْطَهْ وَاشْفَعْ تُشَفَّعْ فَأَحْمَدُهُ بِتَحْمِيدٍ يُعَلِّمُنِيهِ ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا فَيُدْخِلُهُمُ الْجَنَّةَ ثُمَّ أَعُودُ الثَّانِيَةَ فَإِذَا رَأَيْتُهُ وَقَعْتُ سَاجِدًا فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي ثُمَّ يُقَالُ لِي ارْفَعْ مُحَمَّدُ قُلْ تُسْمَعْ وَسَلْ تُعْطَهْ وَاشْفَعْ تُشَفَّعْ فَأَرْفَعُ رَأْسِي فَأَحْمَدُهُ بِتَحْمِيدٍ يُعَلِّمُنِيهِ ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا فَيُدْخِلُهُمُ الْجَنَّةَ ثُمَّ أَعُودُ الثَّالِثَةَ فَإِذَا رَأَيْتُ رَبِيِّ وَقَعْتُ سَاجِدًا فَيَدَعُنِي مَا شَاءَ اللَّهُ أَنْ يَدَعَنِي ثُمَّ يُقَالُ ارْفَعْ مُحَمَّدُ قُلْ تُسْمَعْ وَسَلْ تُعْطَهْ وَاشْفَعْ تُشَفَّعْ فَأَرْفَعُ رَأْسِي فَأَحْمَدُهُ بِتَحْمِيدٍ يُعَلِّمُنِيهِ ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا فَيُدْخِلُهُمُ الْجَنَّةَ ثُمَّ أَعُودُ الرَّابِعَةَ فَأَقُولُ يَا رَبِّ مَا بَقِيَ إِلاَّ مَنْ حَبَسَهُ الْقُرْآنُ ‏"‏ ‏.‏ يَقُولُ قَتَادَةُ عَلَى أَثَرِ هَذَا الْحَدِيثِ وَحَدَّثَنَا أَنَسُ بْنُ مَالِكٍ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ يَخْرُجُ مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَكَانَ فِي قَلْبِهِ مِثْقَالُ شَعِيرَةٍ مِنْ خَيْرٍ وَيَخْرُجُ مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَكَانَ فِي قَلْبِهِ مِثْقَالُ بُرَّةٍ مِنْ خَيْرٍ وَيَخْرُجُ مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَكَانَ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ مِنْ خَيْرٍ ‏"‏ ‏.‏\hadithno{4312}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“The believers will be gathered on the Day of Resurrection, inspired or worried.” – Sa’eed was not sure – “And they will say: ‘If we seek someone to intercede for us with our Lord, we may find relief from our situation.’ So they will go to Adam and will say: ‘You are Adam, the father of mankind. Allah created you with His Hand and His angels prostrated to you. Intercede for us with your Lord, that He might grant us relief from our situation.’ He will say: ‘I am not the one,’ and he will mention to them and complain of the sin that he committed. He will feel too shy to do that (and will say): ‘Rather go to Nuh, for he is the first Messenger whom Allah sent to the people of earth.’ So they will go to him, but he will say: ‘I am not the one,’ and he will mention of how he asked of Allah that of which he had no knowledge.* He will feel too shy to do that (and will say): ‘Rather go to the Close Friend of the Most Merciful, Ibrahim.’ So they will go to him and he will say: ‘I am not the one. Rather go to Musa, a slave to whom Allah spoke and to whom He gave the Torah.’ So they will go to him and he will say: ‘I am not the one,’ and he will mention how he killed a soul, not in retaliation for murder (and will say): ‘Rather go to ‘Isa, the slave of Allah and His Messenger, the Word of Allah and a spirit created by Him.’ So they will go to him, but he will say: ‘I am not the one. Rather go to Muhammad, a slave whose past and future sins Allah forgave.’ So they will come to me and I will go with them.” – There was a similar report from Hasan who added (the Prophet (ﷺ) said:) And I will walk between two rows of the believers.” Then he went back to the Hadith of Anas. – And he said: “And I will ask my Lord for permission and permission will be given to me. When I see Him I will fall down prostrating, and I will be left as long as Allah wills to leave me. Then it will be said: ‘Get up, O Muhammad. Speak, you will be heard; ask, you will be given; intercede, your intercession will be accepted.’ I will praise Him with praise that He will teach me, then I will intercede, and a limit will be set. Then they will be admitted to Paradise, and I will come back a second time. When I see Him I will fall down prostrating, and I will be left as long as Allah wills to leave me. Then it will be said: ‘Get up, O Muhammad. Speak, you will be heard; ask, you will be given; intercede, your intercession will be accepted.’ I will praise Him with praise that He will teach me, then I will intercede, and a limit will be set. Then they will be admitted to Paradise, and I will come back a third time. When I see Him I will fall down prostrating, and I will be left as long as Allah wills to leave me. Then it will be said: ‘Get up, O Muhammad. Speak, you will be heard; ask, you will be given; intercede, your intercession will be accepted.’ I will praise Him with praise that He will teach me, then I will intercede, and a limit will be set. Then they will be admitted to Paradise, and I will come back a fourth time and will say: ‘O Lord, there is no one left except those who are detained by the Qur’an.’” ** Qatadah (the Tabi'ee in the chain) would narrate after this hadith that Anas (ra) said "Those who said 'La illaha illa Allah' (there is no god except Allah) and had the weight of a grain of barley in good in his heart will come out of the Fire, and those who said 'La illaha illa Allah' and had a weight of a grain of wheat in good in his heart will come out of the Fire, and those who said 'La illaha illa Allah' and had a weight of a grain of dust in good in his heart will come out of the Fire}}
\hadithdefcmd{ibnmajah}{4313}{حَدَّثَنَا سَعِيدُ بْنُ مَرْوَانَ، حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا عَنْبَسَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عِلاَقِ بْنِ أَبِي مُسْلِمٍ، عَنْ أَبَانَ بْنِ عُثْمَانَ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَشْفَعُ يَوْمَ الْقِيَامَةِ ثَلاَثَةٌ الأَنْبِيَاءُ ثُمَّ الْعُلَمَاءُ ثُمَّ الشُّهَدَاءُ ‏"‏ ‏.‏\hadithno{4313}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Uthman bin ‘Affan that the Messenger of Allah (ﷺ) said:“Three will intercede on the Day of Resurrection: The Prophets, then the scholars, then the martyrs.”}}
\hadithdefcmd{ibnmajah}{4314}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الطُّفَيْلِ بْنِ أُبَىِّ بْنِ كَعْبٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا كَانَ يَوْمُ الْقِيَامَةِ كُنْتُ إِمَامَ النَّبِيِّينَ وَخَطِيبَهُمْ وَصَاحِبَ شَفَاعَتِهِمْ غَيْرَ فَخْرٍ ‏"‏ ‏.‏\hadithno{4314}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ubayy bin Ka’b, from his father, that the Messenger of Allah (ﷺ) said:“When the Day of Resurrection comes, I will be the leader of the Prophets and the one who addresses them, and the one among them who will agree to intercede, and it is no boast.”}}
\hadithdefcmd{ibnmajah}{4315}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا الْحُسَيْنُ بْنُ ذَكْوَانَ، عَنْ أَبِي رَجَاءٍ الْعُطَارِدِيِّ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَيَخْرُجَنَّ قَوْمٌ مِنَ النَّارِ بِشَفَاعَتِي يُسَمَّوْنَ الْجَهَنَّمِيِّينَ ‏"‏ ‏.‏\hadithno{4315}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from ‘Imran bin Husain that the Prophet (ﷺ) said:“Some people will be brought forth from Hell by my intercession, who will be called Al-Jahannamiyyin (those who came out of Hell).”}}
\hadithdefcmd{ibnmajah}{4316}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا خَالِدٌ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْجَذْعَاءِ، أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ لَيَدْخُلَنَّ الْجَنَّةَ بِشَفَاعَةِ رَجُلٍ مِنْ أُمَّتِي أَكْثَرُ مِنْ بَنِي تَمِيمٍ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ سِوَاكَ قَالَ ‏"‏ سِوَاىَ ‏"‏ ‏.‏ قُلْتُ أَنْتَ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ أَنَا سَمِعْتُهُ ‏.‏\hadithno{4316}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Abdullah bin Abi Jad’a’ that he heard the Prophet (ﷺ) say:“More than (the members of the tribe of) Banu Tamim will enter Paradise through the intercession of a man from among my nation.” They said: “O Messenger of Allah, besides you?” He said: “Besides me.”}}
\hadithdefcmd{ibnmajah}{4317}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا ابْنُ جَابِرٍ، قَالَ سَمِعْتُ سُلَيْمَ بْنَ عَامِرٍ، يَقُولُ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ الأَشْجَعِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَتَدْرُونَ مَا خَيَّرَنِي رَبِّيَ اللَّيْلَةَ ‏"‏ ‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ قَالَ ‏"‏ فَإِنَّهُ خَيَّرَنِي بَيْنَ أَنْ يَدْخُلَ نِصْفُ أُمَّتِي الْجَنَّةَ وَبَيْنَ الشَّفَاعَةِ فَاخْتَرْتُ الشَّفَاعَةَ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنَا مِنْ أَهْلِهَا ‏.‏ قَالَ ‏"‏ هِيَ لِكُلِّ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{4317}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Awf bin Malik Al-Ashja’i said:“The Messenger of Allah (ﷺ) said: ‘Do you know what choice my Lord gave me on this night?’ We said: ‘Allah and His Messenger know best.’ He said: ‘He gave me the choice between admitting half of my nation to Paradise and intercession, and I chose intercession.’ We said: ‘O Messenger of Allah, pray that we will be among its people (the people for whom you will intercede).’ He said: ‘It is for every Muslim.’”}}
\hadithdefcmd{ibnmajah}{4318}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَيَعْلَى، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ نُفَيْعٍ أَبِي دَاوُدَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ نَارَكُمْ هَذِهِ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنْ نَارِ جَهَنَّمَ وَلَوْلاَ أَنَّهَا أُطْفِئَتْ بِالْمَاءِ مَرَّتَيْنِ مَا انْتَفَعْتُمْ بِهَا وَإِنَّهَا لَتَدْعُو اللَّهَ عَزَّ وَجَلَّ أَنْ لاَ يُعِيدَهَا فِيهَا ‏"‏ ‏.‏\hadithno{4318}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“This fire of yours is one-seventieth part of the fire of Hell. Were it not that its heat has been reduced by water twice, you would not have been able to benefit from it. And it is praying to Allah, asking Allah not to return it (to its original level of heat).”}}
\hadithdefcmd{ibnmajah}{4319}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اشْتَكَتِ النَّارُ إِلَى رَبِّهَا فَقَالَتْ يَا رَبِّ أَكَلَ بَعْضِي بَعْضًا ‏.‏ فَجَعَلَ لَهَا نَفَسَيْنِ نَفَسٌ فِي الشِّتَاءِ وَنَفَسٌ فِي الصَّيْفِ فَشِدَّةُ مَا تَجِدُونَ مِنَ الْبَرْدِ مِنْ زَمْهَرِيرِهَا وَشِدَّةُ مَا تَجِدُونَ مِنَ الْحَرِّ مِنْ سَمُومِهَا ‏"‏ ‏.‏\hadithno{4319}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The Fire complained to its Lord and said: ‘O Lord, parts of me have consumed other parts.’ So He gave it two occasions to exhale, one in winter and one in summer. The intense cold that you feel (in winter) is part of its severe frost (Zamharir) and the intense heat that you feel in summer is part of its hot wind (Samum).”}}
\hadithdefcmd{ibnmajah}{4320}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا شَرِيكٌ، عَنْ عَاصِمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أُوقِدَتِ النَّارُ أَلْفَ سَنَةٍ فَابْيَضَّتْ ثُمَّ أُوقِدَتْ أَلْفَ سَنَةٍ فَاحْمَرَّتْ ثُمَّ أُوقِدَتْ أَلْفَ سَنَةٍ فَاسْوَدَّتْ فَهِيَ سَوْدَاءُ كَاللَّيْلِ الْمُظْلِمِ ‏"‏ ‏.‏\hadithno{4320}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The Hell-Fire was kindled for one thousand years and turned white. Then it was kindled for another thousand years and it turned red. Then it was kindled for another thousand years and it turned black. So it is black like the darkest night.”}}
\hadithdefcmd{ibnmajah}{4321}{حَدَّثَنَا الْخَلِيلُ بْنُ عَمْرٍو، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْحَرَّانِيُّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُؤْتَى يَوْمَ الْقِيَامَةِ بِأَنْعَمِ أَهْلِ الدُّنْيَا مِنَ الْكُفَّارِ فَيُقَالُ اغْمِسُوهُ فِي النَّارِ غَمْسَةً ‏.‏ فَيُغْمَسُ فِيهَا ثُمَّ يُقَالُ لَهُ أَىْ فُلاَنُ هَلْ أَصَابَكَ نَعِيمٌ قَطُّ فَيَقُولُ لاَ مَا أَصَابَنِي نَعِيمٌ قَطُّ ‏.‏ وَيُؤْتَى بِأَشَدِّ الْمُؤْمِنِينَ ضُرًّا وَبَلاَءً ‏.‏ فَيُقَالُ اغْمِسُوهُ غَمْسَةً فِي الْجَنَّةِ ‏.‏ فَيُغْمَسُ فِيهَا غَمْسَةً فَيُقَالُ لَهُ أَىْ فُلاَنُ هَلْ أَصَابَكَ ضُرٌّ قَطُّ أَوْ بَلاَءٌ فَيَقُولُ مَا أَصَابَنِي قَطُّ ضُرٌّ وَلاَ بَلاَءٌ ‏"‏ ‏.‏\hadithno{4321}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“On the Day of Resurrection the disbeliever who lived the most luxurious will be brought, and it will be said: ‘Dip him once in Hell.’ So he will be dipped in it, then it will be said to him: ‘O so- and-so, have you every enjoyed any pleasure?’ He will say: ‘No, I have never enjoyed any pleasure.’ Then the believer who suffered the most hardship and trouble will be brought and it will be said: ‘Dip him once in Paradise.’ So he will be dipped in it and it will be said to him: ‘O so-and-so, have you ever suffered any hardship or trouble?’ He will say: ‘I have never suffered any hardship or trouble.’”}}
\hadithdefcmd{ibnmajah}{4322}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا بَكْرُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عِيسَى بْنُ الْمُخْتَارِ، عَنْ مُحَمَّدِ بْنِ أَبِي لَيْلَى، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الْكَافِرَ لَيَعْظُمُ حَتَّى إِنَّ ضِرْسَهُ لأَعْظَمُ مِنْ أُحُدٍ وَفَضِيلَةُ جَسَدِهِ عَلَى ضِرْسِهِ كَفَضِيلَةِ جَسَدِ أَحَدِكُمْ عَلَى ضِرْسِهِ ‏"‏ ‏.‏\hadithno{4322}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) said:“The disbeliever will be made huge so much so that his molar will be bigger than (Mount) Uhud, and the size of his body in relation to his molar will be like the size of the body of anyone of you in relation to his molar.”}}
\hadithdefcmd{ibnmajah}{4323}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ قَيْسٍ، قَالَ كُنْتُ عِنْدَ أَبِي بُرْدَةَ ذَاتَ لَيْلَةٍ فَدَخَلَ عَلَيْنَا الْحَارِثُ بْنُ أُقَيْشٍ فَحَدَّثَنَا الْحَارِثُ، لَيْلَتَئِذٍ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ مِنْ أُمَّتِي مَنْ يَدْخُلُ الْجَنَّةَ بِشَفَاعَتِهِ أَكْثَرُ مِنْ مُضَرَ وَإِنَّ مِنْ أُمَّتِي مَنْ يَعْظُمُ لِلنَّارِ حَتَّى يَكُونَ أَحَدَ زَوَايَاهَا ‏"‏ ‏.‏\hadithno{4323}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Abdullah bin Qais said:“I was with Abu Burdah one night, and Harith bin Uqaish entered upon us. Harith told us that night that the Messenger of Allah (ﷺ) said: ‘Among my nation are some by whose intercession more (than the members of the tribe of) Mudar will enter Paradise, and among my nation are some who will be made huge for the Fire until they fill one of its corners.’”}}
\hadithdefcmd{ibnmajah}{4324}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنِ الأَعْمَشِ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُرْسَلُ الْبُكَاءُ عَلَى أَهْلِ النَّارِ فَيَبْكُونَ حَتَّى يَنْقَطِعَ الدُّمُوعُ ثُمَّ يَبْكُونَ الدَّمَ حَتَّى يَصِيرَ فِي وُجُوهِهِمْ كَهَيْئَةِ الأُخْدُودِ لَوْ أُرْسِلَتْ فِيهِ السُّفُنُ لَجَرَتْ ‏"‏ ‏.‏\hadithno{4324}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“The people of Hell will be made to weep and they will weep until they run out of tears. Then they will weep blood until something like trenches appear on their faces, and if ships were placed in them they would float.”}}
\hadithdefcmd{ibnmajah}{4325}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَرَأَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏\{يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ حَقَّ تُقَاتِهِ وَلاَ تَمُوتُنَّ إِلاَّ وَأَنْتُمْ مُسْلِمُونَ \}‏ ‏"‏ وَلَوْ أَنَّ قَطْرَةً مِنَ الزَّقُّومِ قُطِرَتْ فِي الأَرْضِ لأَفْسَدَتْ عَلَى أَهْلِ الدُّنْيَا مَعِيشَتَهُمْ فَكَيْفَ بِمَنْ لَيْسَ لَهُ طَعَامٌ غَيْرُهُ ‏"‏ ‏.‏\hadithno{4325}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) recited:“O you who believe! Have fear of Allah as is His due, and die not except as Muslims. [3:102] (Then he said): ‘If a drop of Zaqqum were to be dropped on the earth, it would ruin the livelihood of the people of this world, so how about those who have no food other than it (i.e. Zaqqum)?’”}}
\hadithdefcmd{ibnmajah}{4326}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَادَةَ الْوَاسِطِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ تَأْكُلُ النَّارُ ابْنَ آدَمَ إِلاَّ أَثَرَ السُّجُودِ حَرَّمَ اللَّهُ عَلَى النَّارِ أَنْ تَأْكُلَ أَثَرَ السُّجُودِ ‏"‏ ‏.‏\hadithno{4326}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The Fire will consume all of the son of Adam except the mark of prostration. Allah has forbidden the Fire to consume the mark of prostration.’”}}
\hadithdefcmd{ibnmajah}{4327}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُؤْتَى بِالْمَوْتِ يَوْمَ الْقِيَامَةِ فَيُوقَفُ عَلَى الصِّرَاطِ فَيُقَالُ يَا أَهْلَ الْجَنَّةِ ‏.‏ فَيَطَّلِعُونَ خَائِفِينَ وَجِلِينَ أَنْ يُخْرَجُوا مِنْ مَكَانِهِمُ الَّذِي هُمْ فِيهِ ثُمَّ يُقَالُ يَا أَهْلَ النَّارِ فَيَطَّلِعُونَ مُسْتَبْشِرِينَ فَرِحِينَ أَنْ يُخْرَجُوا مِنْ مَكَانِهِمُ الَّذِي هُمْ فِيهِ فَيُقَالُ هَلْ تَعْرِفُونَ هَذَا قَالُوا نَعَمْ هَذَا الْمَوْتُ ‏.‏ قَالَ فَيُؤْمَرُ بِهِ فَيُذْبَحُ عَلَى الصِّرَاطِ ثُمَّ يُقَالُ لِلْفَرِيقَيْنِ كِلاَهُمَا خُلُودٌ فِيمَا تَجِدُونَ لاَ مَوْتَ فِيهِ أَبَدًا ‏"‏ ‏.‏\hadithno{4327}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘Death will be brought on the Day of Resurrection and made to stand on the Sirat (the Bridge over Hell). It will be said: “O people of Paradise!” And they will look. Anxious and afraid lest they be brought out of the place they are in. Then it will be said: “O people of Hell!” and they will look, hoping that they will be brought out of the place they are in. Then it will be said: “Do you know what this is?” They will say: “Yes, this is Death.” Then the command will be given for it to be slaughtered on the Sirat, and it will be said to both groups: “It is eternal wherever you are, and there will never be any death therein.”}}
\hadithdefcmd{ibnmajah}{4328}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ أَعْدَدْتُ لِعِبَادِيَ الصَّالِحِينَ مَا لاَ عَيْنٌ رَأَتْ وَلاَ أُذُنٌ سَمِعَتْ وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَمِنْ بَلْهَ مَا قَدْ أَطْلَعَكُمُ اللَّهُ عَلَيْهِ اقْرَءُوا إِنْ شِئْتُمْ ‏\{فَلاَ تَعْلَمُ نَفْسٌ مَا أُخْفِيَ لَهُمْ مِنْ قُرَّةِ أَعْيُنٍ جَزَاءً بِمَا كَانُوا يَعْمَلُونَ \}‏ قَالَ وَكَانَ أَبُو هُرَيْرَةَ يَقْرَؤُهَا مِنْ قُرَّاتِ أَعْيُنٍ ‏.‏\hadithno{4328}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Allah says: ‘I have prepared for My righteous slaves that which no eye has seen, no ear has heard, and it has never crossed the mind of man.’”}}
\hadithdefcmd{ibnmajah}{4329}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ حَجَّاجٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ لَشِبْرٌ فِي الْجَنَّةِ خَيْرٌ مِنَ الأَرْضِ وَمَا عَلَيْهَا - الدُّنْيَا وَمَا فِيهَا ‏.‏\hadithno{4329}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) said:“A hand span in Paradise is better than the earth and everything on it.”}}
\hadithdefcmd{ibnmajah}{4330}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا زَكَرِيَّا بْنُ مَنْظُورٍ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَوْضِعُ سَوْطٍ فِي الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{4330}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sahl bin Sa’d that the Messenger of Allah (ﷺ) said:“A place the size of a whip in Paradise is better than this world and everything in it.”}}
\hadithdefcmd{ibnmajah}{4331}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْجَنَّةُ مِائَةُ دَرَجَةٍ كُلُّ دَرَجَةٍ مِنْهَا مَا بَيْنَ السَّمَاءِ وَالأَرْضِ وَإِنَّ أَعْلاَهَا الْفِرْدَوْسُ وَإِنَّ أَوْسَطَهَا الْفِرْدَوْسُ وَإِنَّ الْعَرْشَ عَلَى الْفِرْدَوْسِ مِنْهَا تُفَجَّرُ أَنْهَارُ الْجَنَّةِ فَإِذَا مَا سَأَلْتُمُ اللَّهَ فَسَلُوهُ الْفِرْدَوْسَ ‏"‏ ‏.‏\hadithno{4331}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Mu’adh bin Jabal said:“I heard the Messenger of Allah (ﷺ) say: ‘Paradise has one hundred grades, each of which is as big as the distance between heaven and earth. The highest of them is Firdaws and the best of them is Firdaws. The Throne is above Firdaws and from it spring forth the rivers of Paradise. If you ask of Allah, ask Him for Firdaws.’”}}
\hadithdefcmd{ibnmajah}{4332}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُهَاجِرٍ الأَنْصَارِيُّ، حَدَّثَنِي الضَّحَّاكُ الْمَعَافِرِيُّ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ كُرَيْبٍ، - مَوْلَى ابْنِ عَبَّاسٍ - قَالَ حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ذَاتَ يَوْمٍ لأَصْحَابِهِ ‏"‏ أَلاَ مُشَمِّرٌ لِلْجَنَّةِ فَإِنَّ الْجَنَّةَ لاَ خَطَرَ لَهَا هِيَ وَرَبِّ الْكَعْبَةِ نُورٌ يَتَلأْلأُ وَرَيْحَانَةٌ تَهْتَزُّ وَقَصْرٌ مَشِيدٌ وَنَهَرٌ مُطَّرِدٌ وَفَاكِهَةٌ كَثِيرَةٌ نَضِيجَةٌ وَزَوْجَةٌ حَسْنَاءُ جَمِيلَةٌ وَحُلَلٌ كَثِيرَةٌ فِي مَقَامٍ أَبَدًا فِي حَبْرَةٍ وَنَضْرَةٍ فِي دَارٍ عَالِيَةٍ سَلِيمَةٍ بَهِيَّةٍ ‏"‏ ‏.‏ قَالُوا نَحْنُ الْمُشَمِّرُونَ لَهَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ قُولُوا إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ الْجِهَادَ وَحَضَّ عَلَيْهِ ‏.‏\hadithno{4332}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Usamah bin Zaid said:“The Messenger of Allah (ﷺ) said one day to his Companions: ‘Who will strive hard with sincerity for Paradise? For there is nothing like Paradise. By the Lord of the Ka’bah, it is sparkling light, sweet basil waving in the breeze, a lofty palace, a flowing river, abundant ripe fruit, a beautiful wife and many fine garments, in a palace of eternal abode, in ease and luxury, in beautiful, strongly-built, lofty houses.’ They said: ‘We will strive heard for it, O Messenger of Allah.’ He said: ‘Say: In sha’ Allah (if Allah wills).’ Then he mentioned Jihad and encouraged them to engage in it.”}}
\hadithdefcmd{ibnmajah}{4333}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَوَّلُ زُمْرَةٍ تَدْخُلُ الْجَنَّةَ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ ثُمَّ الَّذِينَ يَلُونَهُمْ عَلَى ضَوْءِ أَشَدِّ كَوْكَبٍ دُرِّيٍّ فِي السَّمَاءِ إِضَاءَةً لاَ يَبُولُونَ وَلاَ يَتَغَوَّطُونَ وَلاَ يَمْتَخِطُونَ وَلاَ يَتْفِلُونَ أَمْشَاطُهُمُ الذَّهَبُ وَرَشْحُهُمُ الْمِسْكُ وَمَجَامِرُهُمُ الأَلُوَّةُ أَزْوَاجُهُمُ الْحُورُ الْعِينُ أَخْلاَقُهُمْ عَلَى خَلْقِ رَجُلٍ وَاحِدٍ عَلَى صُورَةِ أَبِيهِمْ آدَمَ سِتُّونَ ذِرَاعًا ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، مِثْلَ حَدِيثِ ابْنِ فُضَيْلٍ عَنْ عُمَارَةَ.‏\hadithno{4333}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The first group to enter Paradise will enter with (faces) like the moon in the night when it is full. Then those who follow them will be shining with a light brighter than the brightest star in the sky. They will not urinate or defecate, or blow their noses or spit. Their combs will be of gold, their sweat will be musk, their braziers (receptacle for holding live coals for burning incense) will be pearls and their wives will be houris. Their form will be that of a single man, the form of their father Adam, sixty forearm’s length tall.’” Another chain reports the same}}
\hadithdefcmd{ibnmajah}{4334}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ الْمُنْذِرِ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْكَوْثَرُ نَهَرٌ فِي الْجَنَّةِ حَافَتَاهُ مِنْ ذَهَبٍ مَجْرَاهُ عَلَى الْيَاقُوتِ وَالدُّرِّ تُرْبَتُهُ أَطْيَبُ مِنَ الْمِسْكِ وَمَاؤُهُ أَحْلَى مِنَ الْعَسَلِ وَأَشَدُّ بَيَاضًا مِنَ الثَّلْجِ ‏"‏ ‏.‏\hadithno{4334}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Kauthar is a river in Paradise whose banks are of gold and its bed is of rubies and pearls. Its soil is more fragrant than musk, its water is sweeter than honey and whiter than snow.”}}
\hadithdefcmd{ibnmajah}{4335}{حَدَّثَنَا أَبُو عُمَرَ الضَّرِيرُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُثْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ فِي الْجَنَّةِ شَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ سَنَةٍ لاَ يَقْطَعُهَا ‏"‏ ‏.‏ وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{وَظِلٍّ مَمْدُودٍ * وَمَاءٍ مَسْكُوبٍ ‏)‏ ‏.‏\hadithno{4335}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“In Paradise there is a tree under whose shade a rider could travel for one hundred years and never leave it.” "Recite, if you wish: 'And in shade long-extended (56:)}}
\hadithdefcmd{ibnmajah}{4336}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ حَبِيبِ بْنِ أَبِي الْعِشْرِينَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو الأَوْزَاعِيُّ، حَدَّثَنِي حَسَّانُ بْنُ عَطِيَّةَ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّهُ لَقِيَ أَبَا هُرَيْرَةَ فَقَالَ أَبُو هُرَيْرَةَ أَسْأَلُ اللَّهَ أَنْ يَجْمَعَ، بَيْنِي وَبَيْنَكَ فِي سُوقِ الْجَنَّةِ ‏.‏ قَالَ سَعِيدٌ أَوَفِيهَا سُوقٌ قَالَ نَعَمْ أَخْبَرَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّ أَهْلَ الْجَنَّةِ إِذَا دَخَلُوهَا نَزَلُوا فِيهَا بِفَضْلِ أَعْمَالِهِمْ فَيُؤْذَنُ لَهُمْ فِي مِقْدَارِ يَوْمِ الْجُمُعَةِ مِنْ أَيَّامِ الدُّنْيَا فَيَزُورُونَ اللَّهَ عَزَّ وَجَلَّ وَيُبْرِزُ لَهُمْ عَرْشَهُ وَيَتَبَدَّى لَهُمْ فِي رَوْضَةٍ مِنْ رِيَاضِ الْجَنَّةِ فَتُوضَعُ لَهُمْ مَنَابِرُ مِنْ نُورٍ وَمَنَابِرُ مِنْ لُؤْلُؤٍ وَمَنَابِرُ مِنْ يَاقُوتٍ وَمَنَابِرُ مِنْ زَبَرْجَدٍ وَمَنَابِرُ مِنْ ذَهَبٍ وَمَنَابِرُ مِنْ فِضَّةٍ وَيَجْلِسُ أَدْنَاهُمْ - وَمَا فِيهِمْ دَنِيءٌ - عَلَى كُثْبَانِ الْمِسْكِ وَالْكَافُورِ مَا يُرَوْنَ أَنَّ أَصْحَابَ الْكَرَاسِيِّ بِأَفْضَلَ مِنْهُمْ مَجْلِسًا ‏.‏ قَالَ أَبُو هُرَيْرَةَ قُلْتُ يَا رَسُولَ اللَّهِ هَلْ نَرَى رَبَّنَا قَالَ ‏"‏ نَعَمْ هَلْ تَتَمَارَوْنَ فِي رُؤْيَةِ الشَّمْسِ وَالْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏ ‏.‏ قُلْنَا لاَ ‏.‏ قَالَ ‏"‏ كَذَلِكَ لاَ تَتَمَارَوْنَ فِي رُؤْيَةِ رَبِّكُمْ عَزَّ وَجَلَّ وَلاَ يَبْقَى فِي ذَلِكَ الْمَجْلِسِ أَحَدٌ إِلاَّ حَاضَرَهُ اللَّهُ عَزَّ وَجَلَّ مُحَاضَرَةً حَتَّى إِنَّهُ يَقُولُ لِلرَّجُلِ مِنْكُمْ أَلاَ تَذْكُرُ يَا فُلاَنُ يَوْمَ عَمِلْتَ كَذَا وَكَذَا - يُذَكِّرُهُ بَعْضَ غَدَرَاتِهِ فِي الدُّنْيَا - فَيَقُولُ يَا رَبِّ أَفَلَمْ تَغْفِرْ لِي فَيَقُولُ بَلَى فَبِسَعَةِ مَغْفِرَتِي بَلَغْتَ مَنْزِلَتَكَ هَذِهِ ‏.‏ فَبَيْنَمَا هُمْ كَذَلِكَ غَشِيَتْهُمْ سَحَابَةٌ مِنْ فَوْقِهِمْ فَأَمْطَرَتْ عَلَيْهِمْ طِيبًا لَمْ يَجِدُوا مِثْلَ رِيحِهِ شَيْئًا قَطُّ ثُمَّ يَقُولُ قُومُوا إِلَى مَا أَعْدَدْتُ لَكُمْ مِنَ الْكَرَامَةِ فَخُذُوا مَا اشْتَهَيْتُمْ ‏.‏ قَالَ فَنَأْتِي سُوقًا قَدْ حُفَّتْ بِهِ الْمَلاَئِكَةُ فِيهِ مَا لَمْ تَنْظُرِ الْعُيُونُ إِلَى مِثْلِهِ وَلَمْ تَسْمَعِ الآذَانُ وَلَمْ يَخْطُرْ عَلَى الْقُلُوبِ ‏.‏ قَالَ فَيُحْمَلُ لَنَا مَا اشْتَهَيْنَا لَيْسَ يُبَاعُ فِيهِ شَىْءٌ وَلاَ يُشْتَرَى وَفِي ذَلِكَ السُّوقِ يَلْقَى أَهْلُ الْجَنَّةِ بَعْضُهُمْ بَعْضًا فَيُقْبِلُ الرَّجُلُ ذُو الْمَنْزِلَةِ الْمُرْتَفِعَةِ فَيَلْقَى مَنْ هُوَ دُونَهُ - وَمَا فِيهِمْ دَنِيءٌ - فَيَرُوعُهُ مَا يَرَى عَلَيْهِ مِنَ اللِّبَاسِ فَمَا يَنْقَضِي آخِرُ حَدِيثِهِ حَتَّى يَتَمَثَّلَ لَهُ عَلَيْهِ أَحْسَنُ مِنْهُ وَذَلِكَ أَنَّهُ لاَ يَنْبَغِي لأَحَدٍ أَنْ يَحْزَنَ فِيهَا ‏"‏ ‏.‏ قَالَ ‏"‏ ثُمَّ نَنْصَرِفُ إِلَى مَنَازِلِنَا فَيَتَلَقَّانَا أَزْوَاجُنَا فَيَقُلْنَ مَرْحَبًا وَأَهْلاً لَقَدْ جِئْتَ وَإِنَّ بِكَ مِنَ الْجَمَالِ وَالطِّيبِ أَفْضَلَ مِمَّا فَارَقْتَنَا عَلَيْهِ فَنَقُولُ إِنَّا جَالَسْنَا الْيَوْمَ رَبَّنَا الْجَبَّارَ عَزَّ وَجَلَّ وَيَحِقُّنَا أَنْ نَنْقَلِبَ بِمِثْلِ مَا انْقَلَبْنَا ‏"‏ ‏.‏\hadithno{4336}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sa’eed bin Al-Musayyab said that he met Abu Hurairah and Abu Hurairah said:“I supplicate Allah to bring you and I together in the marketplace of Paradise,” Sa’eed said: “Is there a marketplace there?” He said: “Yes. The Messenger of Allah (ﷺ) told me that when the people of Paradise enter it, they will take their places according to their deeds, and they will be given permission for a length of time equivalent to Friday on earth, when they will visit Allah. His Throne will be shown to them and He will appear to them in one of the gardens of Paradise. Chairs of light and chairs of pearls and chairs of rubies and chairs of chrysolite and chairs of gold and chairs of silver will be placed for them. Those who are of a lower status than them, and none of them will be regarded as insignificant, will sit on sandhills of musk and camphor, and they will not feel that those who are sitting on chairs are seated better than them.” Abu Hurairah said: “I said: ‘O Messenger of Allah, will we see our Lord?’ He said: ‘Yes. Do you dispute that you see the sun and the moon on the night when it is full?’ We said: ‘No.’ He said: ‘Likewise, you will not dispute that you see your Lord, the Glorified. There will be no one left in that gathering with whom Allah does not speak face to face, until He will say to a man among you: “Do you not remember, O so-and-so, the day you did such and such?” And He will remind him of some of his sins in this world. He will say: “O Lord, have You not forgiven me?” He will say: “Yes, it is by the vastness of My forgiveness that You have reached the position you are in.” While they are like that, a cloud will cover them from above and will rain down on them perfume the like of whose fragrance they have never smelled before. Then He will say: “Get up and go to the honor that has been prepared for you, and take whatever you desire.” So we will go to a marketplace surrounded by the angels, in which there will be such things as eyes have never seen, ears have never heard and it has not entered the heart of man. Whatever we desire will be carried for us. Nothing will be bought or sold therein. In that marketplace the people of Paradise will meet one another. A man of elevated status will meet those who are of lower status than him, but none shall be regarded as insignificant, and he will be dazzled by the clothes that he sees on him. He will not finish the last of his conversation before better clothes appear on him. That is because no one should be sad there.’” “He said: ‘Then we will go back to our homes where we will be met by our wives, and they will say: ‘Welcome. You have come looking more handsome and with a better fragrance than when you left us.’ And we will say: ‘Today we sat with our Lord, the Compeller, the Glorified, and we deserve to come back as we have come back.’”}}
\hadithdefcmd{ibnmajah}{4337}{حَدَّثَنَا هِشَامُ بْنُ خَالِدٍ الأَزْرَقُ أَبُو مَرْوَانَ الدِّمَشْقِيُّ، حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ بْنِ أَبِي مَالِكٍ، عَنْ أَبِيهِ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ أَحَدٍ يُدْخِلُهُ اللَّهُ الْجَنَّةَ إِلاَّ زَوَّجَهُ اللَّهُ عَزَّ وَجَلَّ ثِنْتَيْنِ وَسَبْعِينَ زَوْجَةً ثِنْتَيْنِ مِنَ الْحُورِ الْعِينِ وَسَبْعِينَ مِنْ مِيرَاثِهِ مِنْ أَهْلِ النَّارِ مَا مِنْهُنَّ وَاحِدَةٌ إِلاَّ وَلَهَا قُبُلٌ شَهِيٌّ وَلَهُ ذَكَرٌ لاَ يَنْثَنِي ‏"‏ ‏.‏ قَالَ هِشَامُ بْنُ خَالِدٍ مِنْ مِيرَاثِهِ مِنْ أَهْلِ النَّارِ يَعْنِي رِجَالاً دَخَلُوا النَّارَ فَوَرِثَ أَهْلُ الْجَنَّةِ نِسَاءَهُمْ كَمَا وُرِثَتِ امْرَأَةُ فِرْعَوْنَ ‏.‏\hadithno{4337}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that the Messenger of Allah (ﷺ) said:“There is no one whom Allah will admit to Paradise but Allah will marry him to seventy-two wives, two from houris and seventy from his inheritance from the people of Hell, all of whom will have desirable front passages and he will have a male member that never becomes flaccid (i.e., soft and limp).’”}}
\hadithdefcmd{ibnmajah}{4338}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ عَامِرٍ الأَحْوَلِ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُؤْمِنُ إِذَا اشْتَهَى الْوَلَدَ فِي الْجَنَّةِ كَانَ حَمْلُهُ وَوَضْعُهُ فِي سَاعَةٍ وَاحِدَةٍ كَمَا يَشْتَهِي ‏"‏ ‏.‏\hadithno{4338}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“When the believer wants a child in Paradise, he will be conceived and born and grown up, in a short while, according to his desire.”}}
\hadithdefcmd{ibnmajah}{4339}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي لأَعْلَمُ آخِرَ أَهْلِ النَّارِ خُرُوجًا مِنْهَا وَآخِرَ أَهْلِ الْجَنَّةِ دُخُولاً الْجَنَّةَ ‏.‏ رَجُلٌ يَخْرُجُ مِنَ النَّارِ حَبْوًا فَيُقَالُ لَهُ اذْهَبْ فَادْخُلِ الْجَنَّةَ ‏.‏ فَيَأْتِيهَا فَيُخَيَّلُ إِلَيْهِ أَنَّهَا مَلأَى فَيَرْجِعُ فَيَقُولُ يَا رَبِّ وَجَدْتُهَا مَلأَى ‏.‏ فَيَقُولُ اللَّهُ اذْهَبْ فَادْخُلِ الْجَنَّةَ ‏.‏ فَيَأْتِيهَا فَيُخَيَّلُ إِلَيْهِ أَنَّهَا مَلأَى فَيَرْجِعُ فَيَقُولُ يَا رَبِّ وَجَدْتُهَا مَلأَى ‏.‏ فَيَقُولُ اللَّهُ سُبْحَانَهُ اذْهَبْ فَادْخُلِ الْجَنَّةَ ‏.‏ فَيَأْتِيهَا فَيُخَيَّلُ إِلَيْهِ أَنَّهَا مَلأَى فَيَرْجِعُ فَيَقُولُ يَا رَبِّ إِنَّهَا مَلأَى ‏.‏ فَيَقُولُ اللَّهُ اذْهَبْ فَادْخُلِ الْجَنَّةَ ‏.‏ فَإِنَّ لَكَ مِثْلَ الدُّنْيَا وَعَشَرَةَ أَمْثَالِهَا - أَوْ إِنَّ لَكَ مِثْلَ عَشَرَةِ أَمْثَالِ الدُّنْيَا - فَيَقُولُ أَتَسْخَرُ بِي - أَوْ أَتَضْحَكُ بِي - وَأَنْتَ الْمَلِكُ ‏"‏ ‏.‏ قَالَ فَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ ‏.‏ فَكَانَ يُقَالُ هَذَا أَدْنَى أَهْلِ الْجَنَّةِ مَنْزِلَةً ‏.‏\hadithno{4339}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Messenger of Allah (ﷺ) said:“I know the last of the people of Hell who will be brought forth from it, and the last of the people of Paradise to be admitted to Paradise. (It is) a man who will emerge from Hell crawling, and it will be said to him: ‘Go and enter Paradise.’ He will come to it and it will be made to appear to him as if it is full.’ Allah will say: ‘Go and enter Paradise.’ He will come to it and it will appear to him as if it is full. So he will say: ‘O Lord, I found it full.’ Allah will say: ‘Go and enter Paradise.’ He will come to it and it will be made to appear to him as if it is full. So he will say: ‘O Lord, I found it full.’ Allah will say: ‘Go and enter Paradise, for you will have the like of the world and ten times more, or you will have ten times the like of the world.’ He will say: ‘Are You mocking me, or are You laughing at me, when You are the Sovereign?’” He said: "And I saw the Messenger of Allah (ﷺ) smiling so broadly that his molar teeth could be seen." And he used to say: "This is the lowest of the people of Paradise in status}}
\hadithdefcmd{ibnmajah}{4340}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ سَأَلَ الْجَنَّةَ ثَلاَثَ مَرَّاتٍ قَالَتِ الْجَنَّةُ اللَّهُمَّ أَدْخِلْهُ الْجَنَّةَ وَمَنِ اسْتَجَارَ مِنَ النَّارِ ثَلاَثَ مَرَّاتٍ قَالَتِ النَّارُ اللَّهُمَّ أَجِرْهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{4340}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Whoever asks for Paradise, three times, Paradise will say: “O Allah, admit him to Paradise.” And whoever asked to be saved from Hell, three times, Hell will say: “O Allah, save him from Hell.”}}
\hadithdefcmd{ibnmajah}{4341}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَحْمَدُ بْنُ سِنَانٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ لَهُ مَنْزِلاَنِ مَنْزِلٌ فِي الْجَنَّةِ وَمَنْزِلٌ فِي النَّارِ فَإِذَا مَاتَ فَدَخَلَ النَّارَ وَرِثَ أَهْلُ الْجَنَّةِ مَنْزِلَهُ فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{أُولَئِكَ هُمُ الْوَارِثُونَ \}‏ ‏"‏ ‏.‏\hadithno{4341}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There is no one among you who does not have two abodes: An abode in Paradise and an abode in Hell. If he dies and enters Hell, the people of Paradise inherit his abode. This is what Allah says: ‘These are indeed the inheritors.’” [23:]}}
