% Auto-generated chapter 23 for nasai
% Hadiths in this chapter: 184

\hadithdefcmd{nasai}{2435}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ الْمَوْصِلِيُّ، عَنِ الْمُعَافَى، عَنْ زَكَرِيَّا بْنِ إِسْحَاقَ الْمَكِّيِّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمُعَاذٍ حِينَ بَعَثَهُ إِلَى الْيَمَنِ ‏ "‏ إِنَّكَ تَأْتِي قَوْمًا أَهْلَ كِتَابٍ فَإِذَا جِئْتَهُمْ فَادْعُهُمْ إِلَى أَنْ يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ فَإِنْ هُمْ أَطَاعُوكَ بِذَلِكَ فَأَخْبِرْهُمْ أَنَّ اللَّهَ عَزَّ وَجَلَّ فَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي يَوْمٍ وَلَيْلَةٍ فَإِنْ هُمْ - يَعْنِي أَطَاعُوكَ بِذَلِكَ - فَأَخْبِرْهُمْ أَنَّ اللَّهَ عَزَّ وَجَلَّ فَرَضَ عَلَيْهِمْ صَدَقَةً تُؤْخَذُ مِنْ أَغْنِيَائِهِمْ فَتُرَدُّ عَلَى فُقَرَائِهِمْ فَإِنْ هُمْ أَطَاعُوكَ بِذَلِكَ فَاتَّقِ دَعْوَةَ الْمَظْلُومِ ‏"‏ ‏.‏\hadithno{2435}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said to Mu'adh when he sent him to Yemen: 'You are going to some of the People of the book. When you come to them, call them to testify that there is none worthy of worship except Allah and that Muhammad is the Messenger of Allah. If they obey you in that, then tell them that Allah, the Mighty and Sublime, has enjoined on them a charity (Zakah) to be taken from their rich and given to their poor. If they obey you in that, then beware of the supplication of the oppressed person}}
\hadithdefcmd{nasai}{2436}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ بَهْزَ بْنَ حَكِيمٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ مَا أَتَيْتُكَ حَتَّى حَلَفْتُ أَكْثَرَ مِنْ عَدَدِهِنَّ - لأَصَابِعِ يَدَيْهِ - أَنْ لاَ آتِيَكَ وَلاَ آتِيَ دِينَكَ وَإِنِّي كُنْتُ امْرَأً لاَ أَعْقِلُ شَيْئًا إِلاَّ مَا عَلَّمَنِي اللَّهُ عَزَّ وَجَلَّ وَرَسُولُهُ وَإِنِّي أَسْأَلُكَ بِوَحْىِ اللَّهِ بِمَا بَعَثَكَ رَبُّكَ إِلَيْنَا قَالَ ‏"‏ بِالإِسْلاَمِ ‏"‏ ‏.‏ قُلْتُ وَمَا آيَاتُ الإِسْلاَمِ قَالَ ‏"‏ أَنْ تَقُولَ أَسْلَمْتُ وَجْهِيَ إِلَى اللَّهِ وَتَخَلَّيْتُ وَتُقِيمَ الصَّلاَةَ وَتُؤْتِيَ الزَّكَاةَ ‏"‏ ‏.‏\hadithno{2436}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father, that his grandfather said:"I said: 'O Prophet of Allah, I did not come to you until I had sworn more than this many times" the number of fingers on his hands "that I would never come to you or follow your religion. I am a man who does not know anything except that which Allah, the Mighty and Sublime, and His Messenger teach me. I ask you by the Revelation of Allah, with what has your Lord sent your to us? He said: "With Islam.' I said: 'What are the signs of Islam?' He said: 'To say, I submit my face to Allah and give up Shirk, and to establish the Salah and to pay the Zakah}}
\hadithdefcmd{nasai}{2437}{أَخْبَرَنَا عِيسَى بْنُ مُسَاوِرٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبِ بْنِ شَابُورَ، عَنْ مُعَاوِيَةَ بْنِ سَلاَّمٍ، عَنْ أَخِيهِ، زَيْدِ بْنِ سَلاَّمٍ أَنَّهُ أَخْبَرَهُ عَنْ جَدِّهِ أَبِي سَلاَّمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، أَنَّ أَبَا مَالِكٍ الأَشْعَرِيَّ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِسْبَاغُ الْوُضُوءِ شَطْرُ الإِيمَانِ وَالْحَمْدُ لِلَّهِ تَمْلأُ الْمِيزَانَ وَالتَّسْبِيحُ وَالتَّكْبِيرُ يَمْلأُ السَّمَوَاتِ وَالأَرْضَ وَالصَّلاَةُ نُورٌ وَالزَّكَاةُ بُرْهَانٌ وَالصَّبْرُ ضِيَاءٌ وَالْقُرْآنُ حُجَّةٌ لَكَ أَوْ عَلَيْكَ ‏"‏ ‏.‏\hadithno{2437}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman bin Ghanm that Abu Malik Al-Ash'ari told him that the Messenger of Allah said:"Isbagh Al-Wudu is half of faith; Alhamdu lillah (praise be to Allah) fills the balance; the Tasbih and the Takbir fill the heavens and Earth; the Salah is light; the Zakah is a sign (of sincerity); patience is an illuminating torch; and the Qur'an is proof, either for you or against you}}
\hadithdefcmd{nasai}{2438}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، قَالَ أَنْبَأَنَا خَالِدٌ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ نُعَيْمٍ الْمُجْمِرِ أَبِي عَبْدِ اللَّهِ، قَالَ أَخْبَرَنِي صُهَيْبٌ، أَنَّهُ سَمِعَ مِنْ أَبِي هُرَيْرَةَ، وَمِنْ أَبِي سَعِيدٍ يَقُولاَنِ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَقَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ثُمَّ أَكَبَّ فَأَكَبَّ كُلُّ رَجُلٍ مِنَّا يَبْكِي لاَ نَدْرِي عَلَى مَاذَا حَلَفَ ثُمَّ رَفَعَ رَأْسَهُ فِي وَجْهِهِ الْبُشْرَى فَكَانَتْ أَحَبَّ إِلَيْنَا مِنْ حُمْرِ النَّعَمِ ثُمَّ قَالَ ‏"‏ مَا مِنْ عَبْدٍ يُصَلِّي الصَّلَوَاتِ الْخَمْسَ وَيَصُومُ رَمَضَانَ وَيُخْرِجُ الزَّكَاةَ وَيَجْتَنِبُ الْكَبَائِرَ السَّبْعَ إِلاَّ فُتِّحَتْ لَهُ أَبْوَابُ الْجَنَّةِ فَقِيلَ لَهُ ادْخُلْ بِسَلاَمٍ ‏"‏ ‏.‏\hadithno{2438}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Suhaib narrated that he heard Abu Hurairah and Abu Sa'eed say:"The Messenger of Allah addressed us one day and said: 'By the One in Whose hand is my sould' three times then he lowered his head, and each of us lowered his head, weeping, and we did not know what he had sworn that oath about. Then he raised his head with joy on his face, and that was dearer to us than red camels. Then he said: 'There is no one who offers the five (daily) prayers, fasts Ramadan, pays Zakah and avoid the seven major sins, but the gates of Paradise will be opened to him, and it will be said to him: Enter in peace}}
\hadithdefcmd{nasai}{2439}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ مِنْ شَىْءٍ مِنَ الأَشْيَاءِ فِي سَبِيلِ اللَّهِ دُعِيَ مِنْ أَبْوَابِ الْجَنَّةِ يَا عَبْدَ اللَّهِ هَذَا خَيْرٌ لَكَ وَلِلْجَنَّةِ أَبْوَابٌ فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ دُعِيَ مِنْ بَابِ الصَّلاَةِ وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ دُعِيَ مِنْ بَابِ الْجِهَادِ وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ دُعِيَ مِنْ بَابِ الصَّدَقَةِ وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ بَابِ الرَّيَّانِ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ هَلْ عَلَى مَنْ يُدْعَى مِنْ تِلْكَ الأَبْوَابِ مِنْ ضَرُورَةٍ فَهَلْ يُدْعَى مِنْهَا كُلِّهَا أَحَدٌ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَعَمْ وَإِنِّي أَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏ ‏.‏ يَعْنِي أَبَا بَكْرٍ ‏.‏\hadithno{2439}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah say" 'Whoever spends on a pair of things in the cause of Allah, he will be called from the gates of Paradise: O slave of Allah, this is good for you. Paradise had (several) gates. Whoever is one of the people of Salah, he will be called from the gate of prayer. Whoever is one of the people of Jihad, will be called from the gate of Jihad. Whoever is one of the people of charity will be called from the gate of charity. And whoever is one of the people of fasting will be called from the gate of Ar-Rayyan." Abu Bakr said: "Is there any need for anyone to be called from all of these gates? Will anyone be called from all of them, O Messenger of Allah?" He said: "Yes, and I hope that you will be among them}}
\hadithdefcmd{nasai}{2440}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، فِي حَدِيثِهِ عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ جِئْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ جَالِسٌ فِي ظِلِّ الْكَعْبَةِ فَلَمَّا رَآنِي مُقْبِلاً قَالَ ‏"‏ هُمُ الأَخْسَرُونَ وَرَبِّ الْكَعْبَةِ ‏"‏ ‏.‏ فَقُلْتُ مَا لِي لَعَلِّي أُنْزِلَ فِيَّ شَىْءٌ قُلْتُ مَنْ هُمْ فَدَاكَ أَبِي وَأُمِّي قَالَ ‏"‏ الأَكْثَرُونَ أَمْوَالاً إِلاَّ مَنْ قَالَ هَكَذَا وَهَكَذَا وَهَكَذَا حَتَّى بَيْنَ يَدَيْهِ وَعَنْ يَمِينِهِ وَعَنْ شِمَالِهِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَمُوتُ رَجُلٌ فَيَدَعُ إِبِلاً أَوْ بَقَرًا لَمْ يُؤَدِّ زَكَاتَهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَعْظَمَ مَا كَانَتْ وَأَسْمَنَهُ تَطَؤُهُ بِأَخْفَافِهَا وَتَنْطَحُهُ بِقُرُونِهَا كُلَّمَا نَفِدَتْ أُخْرَاهَا أُعِيدَتْ أُولاَهَا حَتَّى يُقْضَى بَيْنَ النَّاسِ ‏"‏ ‏.‏\hadithno{2440}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Dharr said:"I come to the Prophet while he was sitting in the shade of the Ka'bah. When he saw me coming he said: 'They are the losers, by the Lord of the Ka'bah!' I said: 'what's happening? Perhaps something has been revealed concerning me.' I said: 'Who are they, may my father said mother be ransomed for you?' He said: "those who have a lot of wealth, except one who does like this, and like this, and like this,' (motioning) in front of him, and to his right, and to his left. Then he said: 'By the One in Whose hand is my soul, no man dies leaving camels, or cattle, or sheep on which he did not pay the Zakah, but they will come on the Day of Resurrection as big and fat as they ever were, trampling him with their hooves and goring him with their horns. Every time the last of them runs over him, the first of them will come back, until judgment is passed among the people}}
\hadithdefcmd{nasai}{2441}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ جَامِعِ بْنِ أَبِي رَاشِدٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ رَجُلٍ لَهُ مَالٌ لاَ يُؤَدِّي حَقَّ مَالِهِ إِلاَّ جُعِلَ لَهُ طَوْقًا فِي عُنُقِهِ شُجَاعٌ أَقْرَعُ وَهُوَ يَفِرُّ مِنْهُ وَهُوَ يَتْبَعُهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ مِصْدَاقَهُ مِنْ كِتَابِ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَحْسَبَنَّ الَّذِينَ يَبْخَلُونَ بِمَا آتَاهُمُ اللَّهُ مِنْ فَضْلِهِ هُوَ خَيْرًا لَهُمْ بَلْ هُوَ شَرٌّ لَهُمْ سَيُطَوَّقُونَ مَا بَخِلُوا بِهِ يَوْمَ الْقِيَامَةِ ‏\}‏ الآيَةَ ‏.‏\hadithno{2441}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah said: 'There is no man who has wealth and does not pay the dues of his wealth, but a baldheaded Shuja'a will be made to encircle his neck, and he will run away from the Book of Allah: 'And let not those who covetously withhold of that which Allah has bestowed on them of His Bounty (wealth)' think that it is good for them (and so they do not pay the obligatory Zakah). Nay, it will be worse for them; the things which they covetously withheld, shall be tied toothier necks like a collar on the Day of Resurrection}}
\hadithdefcmd{nasai}{2442}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي عَمْرٍو الْغُدَانِيِّ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَيُّمَا رَجُلٍ كَانَتْ لَهُ إِبِلٌ لاَ يُعْطِي حَقَّهَا فِي نَجْدَتِهَا وَرِسْلِهَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا نَجْدَتُهَا وَرِسْلُهَا قَالَ ‏"‏ فِي عُسْرِهَا وَيُسْرِهَا فَإِنَّهَا تَأْتِي يَوْمَ الْقِيَامَةِ كَأَغَذِّ مَا كَانَتْ وَأَسْمَنِهِ وَآشَرِهِ يُبْطَحُ لَهَا بِقَاعٍ قَرْقَرٍ فَتَطَؤُهُ بِأَخْفَافِهَا إِذَا جَاءَتْ أُخْرَاهَا أُعِيدَتْ عَلَيْهِ أُولاَهَا فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ حَتَّى يُقْضَى بَيْنَ النَّاسِ فَيَرَى سَبِيلَهُ وَأَيُّمَا رَجُلٍ كَانَتْ لَهُ بَقَرٌ لاَ يُعْطِي حَقَّهَا فِي نَجْدَتِهَا وَرِسْلِهَا فَإِنَّهَا تَأْتِي يَوْمَ الْقِيَامَةِ أَغَذَّ مَا كَانَتْ وَأَسْمَنَهُ وَآشَرَهُ يُبْطَحُ لَهَا بِقَاعٍ قَرْقَرٍ فَتَنْطَحُهُ كُلُّ ذَاتِ قَرْنٍ بِقَرْنِهَا وَتَطَؤُهُ كُلُّ ذَاتِ ظِلْفٍ بِظِلْفِهَا إِذَا جَاوَزَتْهُ أُخْرَاهَا أُعِيدَتْ عَلَيْهِ أُولاَهَا فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ حَتَّى يُقْضَى بَيْنَ النَّاسِ فَيَرَى سَبِيلَهُ وَأَيُّمَا رَجُلٍ كَانَتْ لَهُ غَنَمٌ لاَ يُعْطِي حَقَّهَا فِي نَجْدَتِهَا وَرِسْلِهَا فَإِنَّهَا تَأْتِي يَوْمَ الْقِيَامَةِ كَأَغَذِّ مَا كَانَتْ وَأَكْثَرِهِ وَأَسْمَنِهِ وَآشَرِهِ ثُمَّ يُبْطَحُ لَهَا بِقَاعٍ قَرْقَرٍ فَتَطَؤُهُ كُلُّ ذَاتِ ظِلْفٍ بِظِلْفِهَا وَتَنْطَحُهُ كُلُّ ذَاتِ قَرْنٍ بِقَرْنِهَا لَيْسَ فِيهَا عَقْصَاءُ وَلاَ عَضْبَاءُ إِذَا جَاوَزَتْهُ أُخْرَاهَا أُعِيدَتْ عَلَيْهِ أُولاَهَا فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ حَتَّى يُقْضَى بَيْنَ النَّاسِ فَيَرَى سَبِيلَهُ ‏"‏ ‏.‏\hadithno{2442}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah say: 'Any man who has camels and does not pay what is due on them in its Najdah or its Risl mean?' He said: 'In times of hardship or in times of ease; they will come on the Day of Resurrection as energetic, fat and lively as they ever were. He will be laid face down in a flat arena for them and they will trample him with their hooves. When the last of them has passed, the first of them will return, on a day that is as long as fifty thousand years, until judgment is passed among the people, and he realizes his end. Any man who has cattle and does not pay what is due on them in drought or in plenty, they will come on the Day of Resurrection as energetic, fat and lively as they ever were. He will be laid face down in a flat arena for them, and they will trample him with their cloven hooves. When the last of them has passed the first of them will return, on a day that is as long as fifty thousand years, until judgment is passed among the people and he realizes his end. Any man who has sheep and does not pay what is due on them in drought or in plenty, they will come on the Day or Resurrection as energetic, fat and lively as they ever were. He will be laid face down in a flat arena for them and they will trample him with their cloven hooves, and each horned one will gore him with its horn, and there will be none among them with twisted or broken horns. When the last of them has passed, the first of them will return, on a day that is as long as fifty thousand years, until judgment is passed among the people, and he realizes his end}}
\hadithdefcmd{nasai}{2443}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاسْتُخْلِفَ أَبُو بَكْرٍ بَعْدَهُ وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ قَالَ عُمَرُ لأَبِي بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ رضى الله عنه لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ وَاللَّهِ لَوْ مَنَعُونِي عِقَالاً كَانُوا يُؤَدُّونَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهِ ‏.‏ قَالَ عُمَرُ رضى الله عنه فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ اللَّهَ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ فَعَرَفْتُ أَنَّهُ الْحَقُّ ‏.‏\hadithno{2443}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"When the Messenger of Allah died, and Abu Bakr became the Khalifah after him, and some of the 'Arabs reverted to disbelief. 'umar said to Abu Bakr: 'How can you fight the people when the Messenger of allah said: "I have been commanded to fight the people until they say La ilaha illallah (there is none worthy of worship but Allah). Whoever says La ilaha illah, his wealth and his life safe from me, unless he deserves a legal punishment justly, and his reckoning will be with Allah?"' Abu Bakr, may Allah be pleased with him, said: 'I will fight anyone who separates prayer and Zakah; Zakah is the compulsory right to be taken from wealth. By Allah, if they withhold from me a rope that they used to give to the Messenger of Allah, I will fight them for wiholding it.' 'Umar, may Allah be pleased with him, said: 'By Allah, it was as if I saw that Allah has opened the heart of Abu Bakr for fighting, and I knew that I was the truth}}
\hadithdefcmd{nasai}{2444}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا بَهْزُ بْنُ حَكِيمٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ فِي كُلِّ إِبِلٍ سَائِمَةٍ فِي كُلِّ أَرْبَعِينَ ابْنَةُ لَبُونٍ لاَ يُفَرَّقُ إِبِلٌ عَنْ حِسَابِهَا مَنْ أَعْطَاهَا مُؤْتَجِرًا فَلَهُ أَجْرُهَا وَمَنْ أَبَى فَإِنَّا آخِذُوهَا وَشَطْرَ إِبِلِهِ عَزْمَةٌ مِنْ عَزَمَاتِ رَبِّنَا لاَ يَحِلُّ لآلِ مُحَمَّدٍ صلى الله عليه وسلم مِنْهَا شَىْءٌ ‏"‏ ‏.‏\hadithno{2444}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim said:"My father told, me that my grandfather said: 'I heard the Prophet say: With regard to grazing camels, for every forty a Bint Labbun (a two-year old female camel). No differentiation is to be made between camels when calculating them. Whoever gives it seeking reward, he will be rewarded for it. Whoever refuses, we will take it, and half of his camels, as one of the rights of our Lord. And it is not permissible for the family of Muhammad to have any of them}}
\hadithdefcmd{nasai}{2445}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي عَمْرُو بْنُ يَحْيَى، ح وَأَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ سُفْيَانَ، وَشُعْبَةَ، وَمَالِكٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ وَلاَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلاَ فِيمَا دُونَ خَمْسَةِ أَوَاقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2445}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Messenger of Allah said:"No Sadaqah is due on less than five Awsuq,[1] and no Sadaqah is due on less than five Dhawd (head of camel), and no Sadaqah is due on less than five Awaq}}
\hadithdefcmd{nasai}{2446}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ ذَوْدٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوَاقٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2446}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Saeed Al-Khudri that the Messenger of Allah said:"No Sadaqah is due on less than five Dhawd (head of camel), and no Sadaqah is due on less than five Awaq, and no Sadaqah is due on less than five Awsuq}}
\hadithdefcmd{nasai}{2447}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا الْمُظَفَّرُ بْنُ مُدْرِكٍ أَبُو كَامِلٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، قَالَ أَخَذْتُ هَذَا الْكِتَابَ مِنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَنَسِ بْنِ مَالِكٍ عَنْ أَنَسِ بْنِ مَالِكٍ أَنَّ أَبَا بَكْرٍ كَتَبَ لَهُمْ إِنَّ هَذِهِ فَرَائِضُ الصَّدَقَةِ الَّتِي فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمُسْلِمِينَ الَّتِي أَمَرَ اللَّهُ عَزَّ وَجَلَّ بِهَا رَسُولَهُ صلى الله عليه وسلم فَمَنْ سُئِلَهَا مِنَ الْمُسْلِمِينَ عَلَى وَجْهِهَا فَلْيُعْطِ وَمَنْ سُئِلَ فَوْقَ ذَلِكَ فَلاَ يُعْطِ فِيمَا دُونَ خَمْسٍ وَعِشْرِينَ مِنَ الإِبِلِ فِي كُلِّ خَمْسِ ذَوْدٍ شَاةٌ فَإِذَا بَلَغَتْ خَمْسًا وَعِشْرِينَ فَفِيهَا بِنْتُ مَخَاضٍ إِلَى خَمْسٍ وَثَلاَثِينَ فَإِنْ لَمْ تَكُنْ بِنْتُ مَخَاضٍ فَابْنُ لَبُونٍ ذَكَرٌ فَإِذَا بَلَغَتْ سِتًّا وَثَلاَثِينَ فَفِيهَا بِنْتُ لَبُونٍ إِلَى خَمْسٍ وَأَرْبَعِينَ فَإِذَا بَلَغَتْ سِتَّةً وَأَرْبَعِينَ فَفِيهَا حِقَّةٌ طَرُوقَةُ الْفَحْلِ إِلَى سِتِّينَ فَإِذَا بَلَغَتْ إِحْدَى وَسِتِّينَ فَفِيهَا جَذَعَةٌ إِلَى خَمْسٍ وَسَبْعِينَ فَإِذَا بَلَغَتْ سِتًّا وَسَبْعِينَ فَفِيهَا بِنْتَا لَبُونٍ إِلَى تِسْعِينَ فَإِذَا بَلَغَتْ إِحْدَى وَتِسْعِينَ فَفِيهَا حِقَّتَانِ طَرُوقَتَا الْفَحْلِ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ عَلَى عِشْرِينَ وَمِائَةٍ فَفِي كُلِّ أَرْبَعِينَ بِنْتُ لَبُونٍ وَفِي كُلِّ خَمْسِينَ حِقَّةٌ فَإِذَا تَبَايَنَ أَسْنَانُ الإِبِلِ فِي فَرَائِضِ الصَّدَقَاتِ فَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْجَذَعَةِ وَلَيْسَتْ عِنْدَهُ جَذَعَةٌ وَعِنْدَهُ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ الْحِقَّةُ وَيَجْعَلُ مَعَهَا شَاتَيْنِ إِنِ اسْتَيْسَرَتَا لَهُ أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَتْ عِنْدَهُ حِقَّةٌ وَعِنْدَهُ جَذَعَةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ إِنِ اسْتَيْسَرَتَا لَهُ وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَتْ عِنْدَهُ وَعِنْدَهُ بِنْتُ لَبُونٍ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيَجْعَلُ مَعَهَا شَاتَيْنِ إِنِ اسْتَيْسَرَتَا لَهُ أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ ابْنَةِ لَبُونٍ وَلَيْسَتْ عِنْدَهُ إِلاَّ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ ابْنَةِ لَبُونٍ وَلَيْسَتْ عِنْدَهُ بِنْتُ لَبُونٍ وَعِنْدَهُ بِنْتُ مَخَاضٍ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيَجْعَلُ مَعَهَا شَاتَيْنِ إِنِ اسْتَيْسَرَتَا لَهُ أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ ابْنَةِ مَخَاضٍ وَلَيْسَ عِنْدَهُ إِلاَّ ابْنُ لَبُونٍ ذَكَرٌ فَإِنَّهُ يُقْبَلُ مِنْهُ وَلَيْسَ مَعَهُ شَىْءٌ وَمَنْ لَمْ يَكُنْ عِنْدَهُ إِلاَّ أَرْبَعٌ مِنَ الإِبِلِ فَلَيْسَ فِيهَا شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا وَفِي صَدَقَةِ الْغَنَمِ فِي سَائِمَتِهَا إِذَا كَانَتْ أَرْبَعِينَ فَفِيهَا شَاةٌ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ وَاحِدَةٌ فَفِيهَا شَاتَانِ إِلَى مِائَتَيْنِ فَإِذَا زَادَتْ وَاحِدَةٌ فَفِيهَا ثَلاَثُ شِيَاهٍ إِلَى ثَلاَثِمِائَةٍ فَإِذَا زَادَتْ فَفِي كُلِّ مِائَةٍ شَاةٌ وَلاَ يُؤْخَذُ فِي الصَّدَقَةِ هَرِمَةٌ وَلاَ ذَاتُ عَوَارٍ وَلاَ تَيْسُ الْغَنَمِ إِلاَّ أَنْ يَشَاءَ الْمُصَّدِّقُ وَلاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ خَشْيَةَ الصَّدَقَةِ وَمَا كَانَ مِنْ خَلِيطَيْنِ فَإِنَّهُمَا يَتَرَاجَعَانِ بَيْنَهُمَا بِالسَّوِيَّةِ فَإِذَا كَانَتْ سَائِمَةُ الرَّجُلِ نَاقِصَةً مِنْ أَرْبَعِينَ شَاةٌ وَاحِدَةٌ فَلَيْسَ فِيهَا شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا وَفِي الرِّقَةِ رُبُعُ الْعُشْرِ فَإِنْ لَمْ تَكُنْ إِلاَّ تِسْعِينَ وَمِائَةَ دِرْهَمٍ فَلَيْسَ فِيهَا شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا ‏"‏ ‏.‏\hadithno{2447}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that Abu Bakar wrote to them:"This is the obligation of Sadaqah which the Messenger of Allah enjoined upon the Muslims, as Allah , the Mighty and Sublime, commanded the Messenger of Allah .Whoever is asked for it in the manner explained (in the letter of Abu Bakar), let him give it, and whoever is asked for more than that, let him not give it. When there are less than twenty-five camels, for every five camels, one sheep (is to be given). If the number reaches twenty five, then a Bint Makhad (a one-year old she-camel) is due, up to thirty-five. If a Bint Makhad is not available, then a Bin Labun (a two-year old male camel). If the number reaches thirty-six, then a Bint Labun (a two-yer-old she-camel) is due, up to forty-five. If the number reaches forty-six, then a Hiqqqah (a three-year-old she-camel) that has been bred from a stallion camel is due, up to sixty. If the number reaches sixty-one, then a Jadhah (a four-year-old she-camel) is due, up to seventy-six, then two Bint Labuns (two-year-old she-camels0 are due, up to ninety. If the number reaches ninety-one, then two Hiqqahs (three-year-old she-camels) that have been bred from stallion camels are due, up to one hundred and twenty. If there are more than one hundred and twenty, then for every forty a Bint Labun, and for every fifty a Hiqqah. In the event that a person does not have a camel of the age specified according to the Hiaqah regulations, then if a person owes a Jadhah as Sadaqah but he does not have a Jadhah, then a Hiqqah should be accepted from him, and he should give two sheep along with it if they are available, or twenty Dirhams, If he owes a Hiqqah as Sadaqah and he does not have Hiqqah but he has a Jadhah, then if should be accepted from him, and the Zakah collector should give him twenty Dirhams, or two sheep if they are available. If a person owes a Hiqqah as Sadaqah and he does not have one, but he has a Bint Labun, it should be accepted from him, and he should give two sheep along with it if they are available, or twenty Dirhams. If a person owes a Bint Labun as Sadaqah but he only has a Hiqaah, then it should be accepted from him and the Zakah collector should give him twenty Dirhams, or two sheep. If a person owes a Bint Labun as Sadaqah but he only has a Bint Makhad, then it should be accepted from him, and he should be accepted from him, and he should give two sheep along with it if they are available, or twenty Dirhams. If a person owes a Bint Makhad as Sadaqah but he only has a Bint Labun, a male; it should be accepted from him, and he does not have to give anything else along with it. If a person has only four camels he does not have to give anything unless their owner wants to. With regard to the Sadaqah on grazing sheep, if there are forty, then one sheep is due upon them, up to one hundred and twenty. If there is one more, then two sheep are due, up to two hundred. If there is one more, then three sheep are due, up to three hundred. If there are more than that, then for every hundred, one sheep is due. No feeble, defective or male sheep should be taken as Sadaqah unless the Zakah collector wishes. Do not combine separate flocks or separate combined flocks for fear of Sadaqah. Each partner (who has a share in a combined flock) should pay the Sadaqah in proportion to his shares. If a man's flock is one less than forty sheep, then nothing is due from them, unless their owner wishes. With regard to silver, one-quarter of one-tenth, and if there are only one hundred and ninety Dirhams, no Zakah is due unless the owner wishes}}
\hadithdefcmd{nasai}{2448}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، مِمَّا حَدَّثَهُ عَبْدُ الرَّحْمَنِ الأَعْرَجُ، مِمَّا ذَكَرَ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ بِهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَأْتِي الإِبِلُ عَلَى رَبِّهَا عَلَى خَيْرِ مَا كَانَتْ إِذَا هِيَ لَمْ يُعْطِ فِيهَا حَقَّهَا تَطَؤُهُ بِأَخْفَافِهَا وَتَأْتِي الْغَنَمُ عَلَى رَبِّهَا عَلَى خَيْرِ مَا كَانَتْ إِذَا لَمْ يُعْطِ فِيهَا حَقَّهَا تَطَؤُهُ بِأَظْلاَفِهَا وَتَنْطَحُهُ بِقُرُونِهَا - قَالَ - وَمِنْ حَقِّهَا أَنْ تُحْلَبَ عَلَى الْمَاءِ أَلاَ لاَ يَأْتِيَنَّ أَحَدُكُمْ يَوْمَ الْقِيَامَةِ بِبَعِيرٍ يَحْمِلُهُ عَلَى رَقَبَتِهِ لَهُ رُغَاءٌ فَيَقُولُ يَا مُحَمَّدُ ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ بَلَّغْتُ ‏.‏ أَلاَ لاَ يَأْتِيَنَّ أَحَدُكُمْ يَوْمَ الْقِيَامَةِ بِشَاةٍ يَحْمِلُهَا عَلَى رَقَبَتِهِ لَهَا يُعَارٌ فَيَقُولُ يَا مُحَمَّدُ ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ بَلَّغْتُ - قَالَ - وَيَكُونُ كَنْزُ أَحَدِهِمْ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ يَفِرُّ مِنْهُ صَاحِبُهُ وَيَطْلُبُهُ أَنَا كَنْزُكَ فَلاَ يَزَالُ حَتَّى يُلْقِمَهُ أُصْبُعَهُ ‏"‏ ‏.‏\hadithno{2448}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: '(On the Day of Resurrection) camels will come to their owner in the best state of health that they ever had (in this world) and if he did not pay what was due on them, they will trample him with their hooves. Sheep willcome to their owner in the best state of health that they ever had (in this world) and if he did not pay what was due on them, they will trample him with their cloven hooves and gore him with their horns. And among their rights are that they should be milked with water in the front of them. I do not want any one of you to come on the Day of Resurrection with a groaning camel on his neck, saying , O Muhammad, and I will say: I cannot do anything for you, I conveyed the message. I do not want any one of you to come on the Day of Resurrection with a bleating sheep on his neck, saying, "O Muhammad," and I will say: "I cannot do anything for you, I conveyed the message." And on the Day of Resurrection the hoarded treasure of one of you will be a blad-headed Shujaa[1]from which its owner will flee, but it will chase him (saying), I am your hoarded treasure, and it will keep (chasing him) until he gives it his finger to swallow}}
\hadithdefcmd{nasai}{2449}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ بَهْزَ بْنَ حَكِيمٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ فِي كُلِّ إِبِلٍ سَائِمَةٍ مِنْ كُلِّ أَرْبَعِينَ ابْنَةُ لَبُونٍ لاَ تُفَرَّقُ إِبِلٌ عَنْ حِسَابِهَا مَنْ أَعْطَاهَا مُؤْتَجِرًا لَهُ أَجْرُهَا وَمَنْ مَنَعَهَا فَإِنَّا آخِذُوهَا وَشَطْرَ إِبِلِهِ عَزْمَةً مِنْ عَزَمَاتِ رَبِّنَا لاَ يَحِلُّ لآلِ مُحَمَّدٍ صلى الله عليه وسلم مِنْهَا شَىْءٌ ‏"‏ ‏.‏\hadithno{2449}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Bahz bin Hakim narrated from his father that his grandfather said:"I heard the Messenger of Allah say: 'With regard to grazing camels, for every forty a Bint Labun. No differentiation is to be made between camels when calculating them. Whoever gives it seeking reward will be rewarded for it. Whoever refuses, we will take it and half of his camels, as one of the rights of our Lord. And it is not permissible for the family of Muhammad to have any of them}}
\hadithdefcmd{nasai}{2450}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا مُفَضَّلٌ، - وَهُوَ ابْنُ مُهَلْهَلٍ - عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ مُعَاذٍ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَهُ إِلَى الْيَمَنِ وَأَمَرَهُ أَنْ يَأْخُذَ مِنْ كُلِّ حَالِمٍ دِينَارًا أَوْ عِدْلَهُ مَعَافِرَ وَمِنَ الْبَقَرِ مِنْ ثَلاَثِينَ تَبِيعًا أَوْ تَبِيعَةً وَمِنْ كُلِّ أَرْبَعِينَ مُسِنَّةً ‏"‏ ‏.‏\hadithno{2450}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muadh:That the Messenger of Allah sent him to Yemen, and he commanded him to take a Dinar, or its equivalent in Maafr,[1] from each person who had reached the age of puberty. And with regard to cattle, from every thirty a male or female Tabi '(two-year-old). And from every forty a Musinnah (three-year-old). (Daif)}}
\hadithdefcmd{nasai}{2451}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَعْلَى، - وَهُوَ ابْنُ عُبَيْدٍ - قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، وَالأَعْمَشُ، عَنْ إِبْرَاهِيمَ، قَالاَ قَالَ مُعَاذٌ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَمَنِ فَأَمَرَنِي أَنْ آخُذَ مِنْ كُلِّ أَرْبَعِينَ بَقَرَةً ثَنِيَّةً وَمِنْ كُلِّ ثَلاَثِينَ تَبِيعًا وَمِنْ كُلِّ حَالِمٍ دِينَارًا أَوْ عِدْلَهُ مَعَافِرَ ‏.‏\hadithno{2451}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Muadh said:"The Messenger of Allah sent me to Yemen, and he commanded me to take from every forty cows, a cow in its third year, and from every thirty, a Tabi '(two-year-old), and from every person who had reached the age of puberty a Dinar or is equivalent in Maafir." (Daif)}}
\hadithdefcmd{nasai}{2452}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ مُعَاذٍ، قَالَ لَمَّا بَعَثَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَمَنِ أَمَرَهُ أَنْ يَأْخُذَ مِنْ كُلِّ ثَلاَثِينَ مِنَ الْبَقَرِ تَبِيعًا أَوْ تَبِيعَةً وَمِنْ كُلِّ أَرْبَعِينَ مُسِنَّةً وَمِنْ كُلِّ حَالِمٍ دِينَارًا أَوْ عِدْلَهُ مَعَافِرَ ‏.‏\hadithno{2452}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mu'adh said:That when the Messenger of Allah sent him to Yemen, he commanded him to take from every thirty, cattle a male or female Tabi'(two-year-old), and from every forty, a Musinnah (three-year-old), and from every person who had reached the age of puberty a Dinar or is equivalent in Ma'afir. (Da 'if)}}
\hadithdefcmd{nasai}{2453}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الطُّوسِيُّ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي سُلَيْمَانُ الأَعْمَشُ، عَنْ أَبِي وَائِلِ بْنِ سَلَمَةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ بَعَثَنِي إِلَى الْيَمَنِ أَنْ لاَ آخُذَ مِنَ الْبَقَرِ شَيْئًا حَتَّى تَبْلُغَ ثَلاَثِينَ فَإِذَا بَلَغَتْ ثَلاَثِينَ فَفِيهَا عِجْلٌ تَابِعٌ جَذَعٌ أَوْ جَذَعَةٌ حَتَّى تَبْلُغَ أَرْبَعِينَ فَإِذَا بَلَغَتْ أَرْبَعِينَ فَفِيهَا بَقَرَةٌ مُسِنَّةٌ ‏.‏\hadithno{2453}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Muadh to Yemen:The Messenger of Allah commanded me not to take any cattle until the number had reached thirty. If the number reached thirty, then a Jadh'ah calf in its second year, either male or female, was due on them, until the number reached forty. If the number reached forty. If the number reached forty, then a Musinnah was due on them." (Daif)}}
\hadithdefcmd{nasai}{2454}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، عَنِ ابْنِ فُضَيْلٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ صَاحِبِ إِبِلٍ وَلاَ بَقَرٍ وَلاَ غَنَمٍ لاَ يُؤَدِّي حَقَّهَا إِلاَّ وُقِفَ لَهَا يَوْمَ الْقِيَامَةِ بِقَاعٍ قَرْقَرٍ تَطَؤُهُ ذَاتُ الأَظْلاَفِ بِأَظْلاَفِهَا وَتَنْطَحُهُ ذَاتُ الْقُرُونِ بِقُرُونِهَا لَيْسَ فِيهَا يَوْمَئِذٍ جَمَّاءُ وَلاَ مَكْسُورَةُ الْقَرْنِ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ وَمَاذَا حَقُّهَا قَالَ ‏"‏ إِطْرَاقُ فَحْلِهَا وَإِعَارَةُ دَلْوِهَا وَحَمْلٌ عَلَيْهَا فِي سَبِيلِ اللَّهِ وَلاَ صَاحِبِ مَالٍ لاَ يُؤَدِّي حَقَّهُ إِلاَّ يُخَيَّلُ لَهُ يَوْمَ الْقِيَامَةِ شُجَاعٌ أَقْرَعُ يَفِرُّ مِنْهُ صَاحِبُهُ وَهُوَ يَتْبَعُهُ يَقُولُ لَهُ هَذَا كَنْزُكَ الَّذِي كُنْتَ تَبْخَلُ بِهِ فَإِذَا رَأَى أَنَّهُ لاَ بُدَّ لَهُ مِنْهُ أَدْخَلَ يَدَهُ فِي فِيهِ فَجَعَلَ يَقْضَمُهَا كَمَا يَقْضَمُ الْفَحْلُ ‏"‏ ‏.‏\hadithno{2454}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Abdullah said:"The Messenger of Allah said: 'There is no owner of camels or cattle or sheep who does not give what is due on them, but he will be made to stand for them on the Day of Resurrection in a flat arena, and those with hooves will trample him with their hooves, and those with horns will gore him with their horns. And on that day there will be none that are hornless or have broken horns.' We said: 'O Messenger of Allah, what is due on them?' He said: Lending males for breeding, lending their buckets, and giving them to people to ride in the cause of Allah. And there is no owner of wealth who does not give what is due on it but a bald-headed Shujaa[1]will appear to him on the Day of Resurrection; its owner will flee from it and it will chase him and say to him: This is your treasure which you used to hoard. When he realizes that he cannot escape it he will put his hand in its mouth and it will start to bite it as a stallion bites}}
\hadithdefcmd{nasai}{2455}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ النَّسَائِيُّ، قَالَ أَنْبَأَنَا شُرَيْحُ بْنُ النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَنَسِ بْنِ مَالِكٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ أَبَا بَكْرٍ، رضى الله عنه كَتَبَ لَهُ أَنَّ هَذِهِ فَرَائِضُ الصَّدَقَةِ الَّتِي فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمُسْلِمِينَ الَّتِي أَمَرَ اللَّهُ بِهَا رَسُولَهُ صلى الله عليه وسلم فَمَنْ سُئِلَهَا مِنَ الْمُسْلِمِينَ عَلَى وَجْهِهَا فَلْيُعْطِهَا وَمَنْ سُئِلَ فَوْقَهَا فَلاَ يُعْطِهِ فِيمَا دُونَ خَمْسٍ وَعِشْرِينَ مِنَ الإِبِلِ فِي خَمْسِ ذَوْدٍ شَاةٌ فَإِذَا بَلَغَتْ خَمْسًا وَعِشْرِينَ فَفِيهَا بِنْتُ مَخَاضٍ إِلَى خَمْسٍ وَثَلاَثِينَ فَإِنْ لَمْ تَكُنِ ابْنَةُ مَخَاضٍ فَابْنُ لَبُونٍ ذَكَرٌ فَإِذَا بَلَغَتْ سِتَّةً وَثَلاَثِينَ فَفِيهَا بِنْتُ لَبُونِ إِلَى خَمْسٍ وَأَرْبَعِينَ فَإِذَا بَلَغَتْ سِتَّةً وَأَرْبَعِينَ فَفِيهَا حِقَّةٌ طَرُوقَةُ الْفَحْلِ إِلَى سِتِّينَ فَإِذَا بَلَغَتْ إِحْدَى وَسِتِّينَ فَفِيهَا جَذَعَةٌ إِلَى خَمْسَةٍ وَسَبْعِينَ فَإِذَا بَلَغَتْ سِتَّةً وَسَبْعِينَ فَفِيهَا ابْنَتَا لَبُونٍ إِلَى تِسْعِينَ فَإِذَا بَلَغَتْ إِحْدَى وَتِسْعِينَ فَفِيهَا حِقَّتَانِ طَرُوقَتَا الْفَحْلِ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ عَلَى عِشْرِينَ وَمِائَةٍ فَفِي كُلِّ أَرْبَعِينَ ابْنَةُ لَبُونٍ وَفِي كُلِّ خَمْسِينَ حِقَّةٌ فَإِذَا تَبَايَنَ أَسْنَانُ الإِبِلِ فِي فَرَائِضِ الصَّدَقَاتِ فَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْجَذَعَةِ وَلَيْسَتْ عِنْدَهُ جَذَعَةٌ وَعِنْدَهُ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ الْحِقَّةُ وَيَجْعَلُ مَعَهَا شَاتَيْنِ إِنِ اسْتَيْسَرَتَا لَهُ أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَتْ عِنْدَهُ إِلاَّ جَذَعَةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيُعْطِيهِ الْمُصَّدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَتْ عِنْدَهُ وَعِنْدَهُ ابْنَةُ لَبُونٍ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيَجْعَلُ مَعَهَا شَاتَيْنِ إِنِ اسْتَيْسَرَتَا لَهُ أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ بِنْتِ لَبُونٍ وَلَيْسَتْ عِنْدَهُ إِلاَّ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيُعْطِيهِ الْمُصَّدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ بِنْتِ لَبُونٍ وَعِنْدَهُ بِنْتُ مَخَاضٍ فَإِنَّهَا تُقْبَلُ مِنْهُ وَيَجْعَلُ مَعَهَا شَاتَيْنِ إِنِ اسْتَيْسَرَتَا لَهُ أَوْ عِشْرِينَ دِرْهَمًا وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ ابْنَةِ مَخَاضٍ وَلَيْسَتْ عِنْدَهُ إِلاَّ ابْنُ لَبُونٍ ذَكَرٌ فَإِنَّهُ يُقْبَلُ مِنْهُ وَلَيْسَ مَعَهُ شَىْءٌ وَمَنْ لَمْ يَكُنْ عِنْدَهُ إِلاَّ أَرْبَعَةٌ مِنَ الإِبِلِ فَلَيْسَ فِيهَا شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا وَفِي صَدَقَةِ الْغَنَمِ فِي سَائِمَتِهَا إِذَا كَانَتْ أَرْبَعِينَ فَفِيهَا شَاةٌ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ وَاحِدَةٌ فَفِيهَا شَاتَانِ إِلَى مِائَتَيْنِ فَإِذَا زَادَتْ وَاحِدَةٌ فَفِيهَا ثَلاَثُ شِيَاهٍ إِلَى ثَلاَثِمِائَةٍ فَإِذَا زَادَتْ وَاحِدَةٌ فَفِي كُلِّ مِائَةٍ شَاةٌ وَلاَ تُؤْخَذُ فِي الصَّدَقَةِ هَرِمَةٌ وَلاَ ذَاتُ عَوَارٍ وَلاَ تَيْسُ الْغَنَمِ إِلاَّ أَنْ يَشَاءَ الْمُصَّدِّقُ وَلاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ خَشْيَةَ الصَّدَقَةِ وَمَا كَانَ مِنْ خَلِيطَيْنِ فَإِنَّهُمَا يَتَرَاجَعَانِ بَيْنَهُمَا بِالسَّوِيَّةِ وَإِذَا كَانَتْ سَائِمَةُ الرَّجُلِ نَاقِصَةً مِنْ أَرْبَعِينَ شَاةٌ وَاحِدَةٌ فَلَيْسَ فِيهَا شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا وَفِي الرِّقَةِ رُبُعُ الْعُشْرِ فَإِنْ لَمْ يَكُنِ الْمَالُ إِلاَّ تِسْعِينَ وَمِائَةً فَلَيْسَ فِيهِ شَىْءٌ إِلاَّ أَنْ يَشَاءَ رَبُّهَا ‏.‏\hadithno{2455}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that Abu Bakar, may Allah be pleased with him, wrote to him:"This is the obligation of Sadaqah which the Messenger of Allah enjoined upon the Muslims, as Allah commanded the Messenger of Allah Whoever is asked for it in the manner explained (in the letter of Abu Bakar), let him give it, and whoever is asked for more than that, let him not give it. When there are less than twenty-five camels, for every five camels, one sheep (is to be given). If the number reaches twenty-five, then a Bint Makhad (a one-year-old she-camel) is due, up to thirty-five. If a Bint Makhad (a one-year-old male camel). If the number reaches thirty-six, then a Bint Labun (a two-year-old she-camel) is due, up to forty five. If the number reaches forty-six, then a Hiqqah (a three year old she-camel) that was bred by a stallion camel is due, up to sixty. If the number reaches sixty-one, then a Jadh'ah (a four-year-old she-camel) is due, up to seventy-five. If the number reaches seventy-six, then two Bint Labun are due, up to ninety. If the number reaches ninety-one, then two Hiqqahs that have been bred by stallion camels are due, up to one hundred and twenty. If there are more than one hundred and twenty, then for every forty a Bint Labun and for every fifty a Hiqqah. In the event that a person does not have a camel of the age specified according to the Sadaqah regulation, then if a person owes a Jadh'ah but he has a Hiqqah, then the Hiqqah should be accepted from him and he should give two sheep along with it if they are available, or twenty Dirhams. If a person owes a Hiqqah as Sadaqah but he only has a Jadh'ah, then it shold be accepted from him, and the Zakah collector should give him twenty Dirhams or two sheep. If a person owes a Hiqqah and does not have one but he has a Bint Labun, it should be accepted from him, and he should give two sheep along with it, if they are available, or twenty Dirhams. If a person owes a Bint Labun as Sadaqah but he only has a Hiqqah, it should be accepted from him, and the Zakah collector should give him twenty Dirhams or two sheep. If a person owes a Bint Labun as Sadaqah and he does not have a Bint Labun, but he has a Bint Makhad. It should be accepted from him, and he should give two sheep along with it, if they are available, or twenty Dirhams. If a person owes a Bint Makhad as Sadaqah but he only has a Bint Labun, a male, it shold be accepted from him and nothing else (need be given) with it. If a person has only four camels, then nothing is due on them, unless their owner wishes (to give something). With regard to the Sadaqah of grazing sheep, if there are forty then one sheep is due, up to one hundred and twenty. If there is one more than that, then two sheep are due, up to two hundred. If there is one more than that, then three sheep are due, up to three hundred. If there is one more than that, then for every hundred one sheep is due, and no decrepit or defecting sheep or male sheep should be taken as Sadaqah unless the Zakah collector wishes. Do not combine separate flocks or separate combined flocks for fear of Sadaqah, Each partner (who has a share in a combined flock) shold pay Sadaqah in proportion to his shares. If a man's flock is one less than forty sheep, then nothing is due from them unless their owner wishes. With regard to silver, one-quarter of one-tenth, and if there are only one hundred and ninety, nothing is due unless the owner wishes}}
\hadithdefcmd{nasai}{2456}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ صَاحِبِ إِبِلٍ وَلاَ بَقَرٍ وَلاَ غَنَمٍ لاَ يُؤَدِّي زَكَاتَهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَعْظَمَ مَا كَانَتْ وَأَسْمَنَهُ تَنْطَحُهُ بِقُرُونِهَا وَتَطَؤُهُ بِأَخْفَافِهَا كُلَّمَا نَفَذَتْ أُخْرَاهَا أَعَادَتْ عَلَيْهِ أُولاَهَا حَتَّى يُقْضَى بَيْنَ النَّاسِ ‏"‏ ‏.‏\hadithno{2456}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah said: There is no owner of camels, cattle or sheep who does not give Zakah on them, but they will come on the Day of Resurrection as big and fast as they ever were, and will gore him with their horns and trample him with their hooves. Every time the last of them has run over him the first of them will come back to him, until judgment is passed among the people}}
\hadithdefcmd{nasai}{2457}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ هُشَيْمٍ، عَنْ هِلاَلِ بْنِ خَبَّابٍ، عَنْ مَيْسَرَةَ أَبِي صَالِحٍ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ أَتَانَا مُصَدِّقُ النَّبِيِّ صلى الله عليه وسلم فَأَتَيْتُهُ فَجَلَسْتُ إِلَيْهِ فَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ فِي عَهْدِي أَنْ لاَ نَأْخُذَ رَاضِعَ لَبَنٍ وَلاَ نَجْمَعَ بَيْنَ مُتَفَرِّقٍ وَلاَ نُفَرِّقَ بَيْنَ مُجْتَمِعٍ ‏"‏ ‏.‏ فَأَتَاهُ رَجُلٌ بِنَاقَةٍ كَوْمَاءَ فَقَالَ ‏"‏ خُذْهَا ‏"‏ ‏.‏ فَأَبَى\hadithno{2457}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Suwaid bin Ghafalah said:"The Zakah collector of the prophet came to us, and I went to him, sat with him, and heard him say: In my contract it says that we should not take any sucking young, nor combine what is separate, nor separate what is combined.' A man brought a she-camel with a big hump to him and said: 'Take it, but he refused." (Daif)}}
\hadithdefcmd{nasai}{2458}{أَخْبَرَنَا هَارُونُ بْنُ زَيْدِ بْنِ يَزِيدَ، - يَعْنِي ابْنَ أَبِي الزَّرْقَاءِ - قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ سَاعِيًا فَأَتَى رَجُلاً فَأَتَاهُ فَصِيلاً مَخْلُولاً فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بَعَثْنَا مُصَدِّقَ اللَّهِ وَرَسُولِهِ وَإِنَّ فُلاَنًا أَعْطَاهُ فَصِيلاً مَخْلُولاً اللَّهُمَّ لاَ تُبَارِكْ فِيهِ وَلاَ فِي إِبِلِهِ ‏"‏ ‏.‏ فَبَلَغَ ذَلِكَ الرَّجُلَ فَجَاءَ بِنَاقَةٍ حَسْنَاءَ فَقَالَ أَتُوبُ إِلَى اللَّهِ عَزَّ وَجَلَّ وَإِلَى نَبِيِّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَارِكْ فِيهِ وَفِي إِبِلِهِ ‏"‏ ‏.‏\hadithno{2458}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from wa'il bin Hujr that:the Prophet sent a collector and he came to a man who brought him a slim, recently-weaned camel. The Prophet said: "We sent to Zakah collector of Allah and His Messenger, and so-and-so gave him a slim, recently-weaned camel. O Allah, do not bless him nor his camels!" News of that reached the man, so he came with a beautiful she-camel and said: "I repent to Allah and to His Prophet. " The Prophet said: "O Allah, bless him and his camels!" (Daif)}}
\hadithdefcmd{nasai}{2459}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ عَمْرُو بْنُ مُرَّةَ أَخْبَرَنِي قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَاهُ قَوْمٌ بِصَدَقَتِهِمْ قَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ فُلاَنٍ ‏"‏ ‏.‏ فَأَتَاهُ أَبِي بِصَدَقَتِهِ فَقَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ أَبِي أَوْفَى ‏"‏ ‏.‏\hadithno{2459}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin Abi Awfa said:"When people brought their Zakah to him, the Messenger of Allah would say: 'O Allah, send salah upon the family of so-and-so,' My father brought his Sadaqah to him and he said: 'O Allah, send Salah upon the family of Abu Awfa}}
\hadithdefcmd{nasai}{2460}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ أَبِي إِسْمَاعِيلَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هِلاَلٍ، قَالَ قَالَ جَرِيرٌ أَتَى النَّبِيَّ صلى الله عليه وسلم نَاسٌ مِنَ الأَعْرَابِ فَقَالُوا يَا رَسُولَ اللَّهِ يَأْتِينَا نَاسٌ مِنْ مُصَدِّقِيكَ يَظْلِمُونَ ‏.‏ قَالَ ‏"‏ أَرْضُوا مُصَدِّقِيكُمْ ‏"‏ ‏.‏ قَالُوا وَإِنْ ظَلَمَ قَالَ ‏"‏ أَرْضُوا مُصَدِّقِيكُمْ ‏"‏ ‏.‏ ثُمَّ قَالُوا وَإِنْ ظَلَمَ قَالَ ‏"‏ أَرْضُوا مُصَدِّقِيكُمْ ‏"‏ ‏.‏ قَالَ جَرِيرٌ فَمَا صَدَرَ عَنِّي مُصَدِّقٌ مُنْذُ سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ وَهُوَ رَاضٍ ‏.‏\hadithno{2460}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdur-Rahman bin Hilal said:"Jarir said: 'Some Bedouin people came to the Prephet and said: O Messenger of Allah, some of your Zakah collectors come to us and they are unfair. He said: Keep your Zakah collectors happy. They said: Even if they are unfair? He said: Keep your Zakah collectors happy. Then they said: Even if they are unfair. He said: Keep your Zakah collectors happy. Jarir said: No Zakah collector left me, since I heard this from the Messenger of Allah but he was pleased with me}}
\hadithdefcmd{nasai}{2461}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - هُوَ ابْنُ عُلَيَّةَ - قَالَ أَنْبَأَنَا دَاوُدُ، عَنِ الشَّعْبِيِّ، قَالَ قَالَ جَرِيرٌ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَاكُمُ الْمُصَدِّقُ فَلْيَصْدُرْ وَهُوَ عَنْكُمْ رَاضٍ ‏"‏ ‏.‏\hadithno{2461}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ash-Shabbi said:"Jarir said: 'The Messenger of Allah said: When the Zakah collector comes to you, let him leave happy with you}}
\hadithdefcmd{nasai}{2462}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، عَنْ عَمْرِو بْنِ أَبِي سُفْيَانَ، عَنْ مُسْلِمِ بْنِ ثَفِنَةَ، قَالَ اسْتَعْمَلَ ابْنُ عَلْقَمَةَ أَبِي عَلَى عِرَافَةِ قَوْمِهِ وَأَمَرَهُ أَنْ يُصَدِّقَهُمْ، فَبَعَثَنِي أَبِي إِلَى طَائِفَةٍ مِنْهُمْ لآتِيَهُ بِصَدَقَتِهِمْ فَخَرَجْتُ حَتَّى أَتَيْتُ عَلَى شَيْخٍ كَبِيرٍ يُقَالُ لَهُ سَعْرٌ فَقُلْتُ إِنَّ أَبِي بَعَثَنِي إِلَيْكَ لِتُؤَدِّيَ صَدَقَةَ غَنَمِكَ ‏.‏ قَالَ ابْنَ أَخِي وَأَىُّ نَحْوٍ تَأْخُذُونَ قُلْتُ نَخْتَارُ حَتَّى إِنَّا لَنَشْبُرُ ضُرُوعَ الْغَنَمِ ‏.‏ قَالَ ابْنَ أَخِي فَإِنِّي أُحَدِّثُكَ أَنِّي كُنْتُ فِي شِعْبٍ مِنْ هَذِهِ الشِّعَابِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَنَمٍ لِي فَجَاءَنِي رَجُلاَنِ عَلَى بَعِيرٍ فَقَالاَ إِنَّا رَسُولاَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَيْكَ لِتُؤَدِّيَ صَدَقَةَ غَنَمِكَ ‏.‏ قَالَ قُلْتُ وَمَا عَلَىَّ فِيهَا قَالاَ شَاةٌ ‏.‏ فَأَعْمِدُ إِلَى شَاةٍ قَدْ عَرَفْتُ مَكَانَهَا مُمْتَلِئَةً مَحْضًا وَشَحْمًا فَأَخْرَجْتُهَا إِلَيْهِمَا فَقَالَ هَذِهِ الشَّافِعُ ‏.‏ وَالشَّافِعُ الْحَائِلُ وَقَدْ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَأْخُذَ شَافِعًا قَالَ فَأَعْمِدُ إِلَى عَنَاقٍ مُعْتَاطٍ - وَالْمُعْتَاطُ الَّتِي لَمْ تَلِدْ وَلَدًا وَقَدْ حَانَ وِلاَدُهَا - فَأَخْرَجْتُهَا إِلَيْهِمَا فَقَالاَ نَاوِلْنَاهَا فَرَفَعْتُهَا إِلَيْهِمَا فَجَعَلاَهَا مَعَهُمَا عَلَى بَعِيرِهِمَا ثُمَّ انْطَلَقَا ‏.‏\hadithno{2462}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Muslim bin Thafihan said:"Ibn 'Alqamah appointed my father to be in charge of his people, and he commanded him to collect their Sadaqah. My father sent me to a group of them to bring their Sadaqah to him. I set out and came to an old man who was called Sa'r. I said: My father has sent me to collect the Sadaqah of your sheep. 'He said: O son of my brother, how will you decode what you want to take?' I said" 'We choose, and we even measure the sheep's udders.' He said: O son of my brother, I tell you that I was in one of these mountain passes at the time of the Messenger of Allah with some sheep of mine. Two men came on a camel and said: We are the messengers of the Messengers of Allah, we come to take the Sadaqah of your sheep. I said: What do I have to give? They said: A sheep. So I went to a sheep that I knew was filled with milk and was fat, and brought it out to them. He said: This is a Shafi - a sheep that has a child or is pregnant - and the Messenger of Allah forbade us to take a Shafi'. So I went to a Mu'tat she-goat - a Mutat is one that has not given birth before, but has reached the age where it could produce young- and brought it out to them. They said: We will take it. So I lifted it up to them, and they took it with them on their camel and left."' (Daif)}}
\hadithdefcmd{nasai}{2463}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا رَوْحٌ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، قَالَ حَدَّثَنِي عَمْرُو بْنُ أَبِي سُفْيَانَ، قَالَ حَدَّثَنِي مُسْلِمُ بْنُ ثَفِنَةَ، أَنَّ ابْنَ عَلْقَمَةَ، اسْتَعْمَلَ أَبَاهُ عَلَى صَدَقَةِ قَوْمِهِ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{2463}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muslim bin Thafinah narrated that:Ibn 'Alqamah appointed his father to collect the Zakah of his people - and he quoted the same Hadith}}
\hadithdefcmd{nasai}{2464}{أَخْبَرَنِي عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، مِمَّا حَدَّثَهُ عَبْدُ الرَّحْمَنِ الأَعْرَجُ، مِمَّا ذَكَرَ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ قَالَ وَقَالَ عُمَرُ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَدَقَةٍ فَقِيلَ مَنَعَ ابْنُ جَمِيلٍ وَخَالِدُ بْنُ الْوَلِيدِ وَعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يَنْقِمُ ابْنُ جَمِيلٍ إِلاَّ أَنَّهُ كَانَ فَقِيرًا فَأَغْنَاهُ اللَّهُ وَأَمَّا خَالِدُ بْنُ الْوَلِيدِ فَإِنَّكُمْ تَظْلِمُونَ خَالِدًا قَدِ احْتَبَسَ أَدْرَاعَهُ وَأَعْتُدَهُ فِي سَبِيلِ اللَّهِ وَأَمَّا الْعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ عَمُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهِيَ عَلَيْهِ صَدَقَةٌ وَمِثْلُهَا مَعَهَا ‏"‏ ‏.‏\hadithno{2464}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurariah said:"Umar said: 'The Messenger of Allah enjoined Sadaqah and it was said that Ibn Jamil, Khalid bin Al-Walid and 'Abbas bin 'Abdul-Muttalib had withheld some. The Messenger of Allah said: What is the matter with Ibn Jamil? Was he not poor then Allah made him rich? As for Khalid bin Al-Walid, you are being unfair to Khalid, for he is saving his shields and weapons for the sake of Allah. As for Al-Abbas bin 'Abdul-Muttalib, the paternal uncle of the Messenger of Allah, it is and obligatory charity for him and he has to pay as much again}}
\hadithdefcmd{nasai}{2465}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ مُوسَى، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَدَقَةٍ مِثْلَهُ سَوَاءً ‏.‏\hadithno{2465}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah enjoined giving Sadaqah;"and he narrated something similar}}
\hadithdefcmd{nasai}{2466}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ بْنِ هِلاَلٍ الثَّقَفِيِّ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ كِدْتُ أُقْتَلُ بَعْدَكَ فِي عَنَاقٍ أَوْ شَاةٍ مِنَ الصَّدَقَةِ ‏.‏ فَقَالَ ‏ "‏ لَوْلاَ أَنَّهَا تُعْطَى فُقَرَاءَ الْمُهَاجِرِينَ مَا أَخَذْتُهَا ‏"‏ ‏.‏\hadithno{2466}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Hilal Ath-Thaqafi said:"A man came to the Prophet and said: 'I feared that I might be killed after you are gone for the sake of a goat or sheep of the Sadaqah.' He said: 'Were it not that it will be given to the poor Muhajirin I would not have taken it."' (Daif)}}
\hadithdefcmd{nasai}{2467}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، وَسُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي عَبْدِهِ وَلاَ فَرَسِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2467}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurariah said:"The Messenger of Allah said: 'The Muslim does not have to pay Sadaqah on his slave or his horse}}
\hadithdefcmd{nasai}{2468}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ حَرْبٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا مُحْرِزُ بْنُ الْوَضَّاحِ، عَنْ إِسْمَاعِيلَ، - وَهُوَ ابْنُ أُمَيَّةَ - عَنْ مَكْحُولٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ زَكَاةَ عَلَى الرَّجُلِ الْمُسْلِمِ فِي عَبْدِهِ وَلاَ فَرَسِهِ ‏"‏ ‏.‏\hadithno{2468}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'A Muslim man does not have to pay Zakah on his slave or his horse}}
\hadithdefcmd{nasai}{2469}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَيُّوبُ بْنُ مُوسَى، عَنْ مَكْحُولٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، يَرْفَعُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي عَبْدِهِ وَلاَ فِي فَرَسِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2469}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah and attributed to the Prophet:"The Muslim does not have to pay Sadaqah on his slave or his horse}}
\hadithdefcmd{nasai}{2470}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ خُثَيْمٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى الْمَرْءِ فِي فَرَسِهِ وَلاَ فِي مَمْلُوكِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2470}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"A person does not have to pay Sadaqah on his horse or his slave}}
\hadithdefcmd{nasai}{2471}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي عَبْدِهِ وَلاَ فِي فَرَسِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2471}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"The Muslim does not have to pay Sadaqah on his slave or his horse}}
\hadithdefcmd{nasai}{2472}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ خُثَيْمِ بْنِ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ صَدَقَةٌ فِي غُلاَمِهِ وَلاَ فِي فَرَسِهِ ‏"‏ ‏.‏\hadithno{2472}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"The Muslim does not have to pay Sadaqah on his slave or his horse}}
\hadithdefcmd{nasai}{2473}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، عَنْ حَمَّادٍ، قَالَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوَاقٍ صَدَقَةٌ وَلاَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوْسُقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2473}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Saeed Al-Khudri said:"The Messenger of Allah said: 'No Sadaqah is due on anything less than five Awaq, no Sadaqah is due on less than five Dhawh (head of camel), and no Sadaqah is due on less than five Awsuq."[1] 2476. It was narrated from Abu Sa 'eed Al-Khudri that the Messenger of Allah said: "No Sadaqah is due on lessthan five Awsuq of dates, no Sadaqah is due on less than five Awaq of silver, and no Sadaqah is due on less than five Dhawd (head) of camels}}
\hadithdefcmd{nasai}{2474}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ الْمَازِنِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ أَوْسُقٍ مِنَ التَّمْرِ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ مِنَ الْوَرِقِ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ مِنَ الإِبِلِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2474}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Sa 'eed Al-Khudri that the Messenger of Allah said:"No Sadaqah is due on lessthan five Awsuq of dates, no Sadaqah is due on less than five Awaq of silver, and no Sadaqah is due on less than five Dhawd (head) of camels}}
\hadithdefcmd{nasai}{2475}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، وَعَبَّادِ بْنِ تَمِيمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ صَدَقَةَ فِيمَا دُونَ خَمْسِ أَوْسَاقٍ مِنَ التَّمْرِ وَلاَ فِيمَا دُونَ خَمْسِ أَوَاقٍ مِنَ الْوَرِقِ صَدَقَةٌ وَلاَ فِيمَا دُونَ خَمْسِ ذَوْدٍ مِنَ الإِبِلِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2475}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa 'eed Al-Khudri that he heard the Messenger of Allah say:"No Sadaqah is due on less than five Awsaq[2] of dates, no Sadaqah is due on less than five Awaq of silver, and no Sadagah is due on less than five Dhawd (head) of camels}}
\hadithdefcmd{nasai}{2476}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الطُّوسِيُّ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا ابْنُ إِسْحَاقَ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ يَحْيَى بْنِ حَبَّانَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، - وَكَانَا ثِقَةً - عَنْ يَحْيَى بْنِ عُمَارَةَ بْنِ أَبِي حَسَنٍ، وَعَبَّادِ بْنِ تَمِيمٍ، - وَكَانَا ثِقَةً - عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ مِنَ الْوَرِقِ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسٍ مِنَ الإِبِلِ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2476}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa 'eed Al-Khudri said:"I heard the Messenger of Allah say: "No Sadaqah is due on less than five Awsaq of silver, no Sadaqah is due on less than five Dhawd (head) of camels, and no Sadaqah is due on less than five Awsuq of dates}}
\hadithdefcmd{nasai}{2477}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ عَفَوْتُ عَنِ الْخَيْلِ وَالرَّقِيقِ فَأَدُّوا زَكَاةَ أَمْوَالِكُمْ مِنْ كُلِّ مِائَتَيْنِ خَمْسَةً ‏"‏ ‏.‏\hadithno{2477}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali, may Allah e pleased with him, said:"The Messenger of Allah said: 'I have exempted you from (having to pay Zakah on) horses and slaves. Pay the Zakah on your wealth, for every two hundred (Dirhams), five}}
\hadithdefcmd{nasai}{2478}{أَخْبَرَنَا حُسَيْنُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا ابْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ عَفَوْتُ عَنِ الْخَيْلِ وَالرَّقِيقِ وَلَيْسَ فِيمَا دُونَ مِائَتَيْنِ زَكَاةٌ ‏"‏ ‏.‏\hadithno{2478}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali, may Allah be pleased with him, said:"The Messenger of Allah said: 'I have exempted you from (having to pay Zakah on) houses and slaves, and there is no Zakah on less than two hundred (Dirhams)}}
\hadithdefcmd{nasai}{2479}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ حُسَيْنٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ امْرَأَةً، مِنْ أَهْلِ الْيَمَنِ أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَبِنْتٌ لَهَا فِي يَدِ ابْنَتِهَا مَسَكَتَانِ غَلِيِظَتَانِ مِنْ ذَهَبٍ فَقَالَ ‏"‏ أَتُؤَدِّينَ زَكَاةَ هَذَا ‏"‏ ‏.‏ قَالَتْ لاَ ‏.‏ قَالَ ‏"‏ أَيَسُرُّكِ أَنْ يُسَوِّرَكِ اللَّهُ عَزَّ وَجَلَّ بِهِمَا يَوْمَ الْقِيَامَةِ سِوَارَيْنِ مِنْ نَارٍ ‏"‏ ‏.‏ قَالَ فَخَلَعَتْهُمَا فَأَلْقَتْهُمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ هُمَا لِلَّهِ وَلِرَسُولِهِ صلى الله عليه وسلم ‏.‏\hadithno{2479}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu 'aib, from his father, from his grandfather, that:a woman from among the people of Yemen came to the Messenger of Allah with a daughter of hers, and on the daughter's hand were two thick bangles of gold. He said: "Do you pay Zakah on these? She said: "No." He said: "Would it please you if Allah were to put two bangles of fire on you on the Day of Resurrection? " So she took them of and gave them to the Messenger of Allah and said: "They are for Allah and His Messenger}}
\hadithdefcmd{nasai}{2480}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ حُسَيْنًا، قَالَ حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، قَالَ جَاءَتِ امْرَأَةٌ وَمَعَهَا بِنْتٌ لَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي يَدِ ابْنَتِهَا مَسَكَتَانِ نَحْوَهُ مُرْسَلٌ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ خَالِدٌ أَثْبَتُ مِنَ الْمُعْتَمِرِ ‏.‏\hadithno{2480}\hadithgrade{Abu Ghuddah: Hasan Lighairihi; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Amr bin Shu 'aib said:"A woman came to the Messenger of Allah with a daughter of hers, and on her daughter's arm were two bangles" - a similar report, in Mursal form}}
\hadithdefcmd{nasai}{2481}{أَخْبَرَنَا الْفَضْلُ بْنُ سَهْلٍ، قَالَ حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الَّذِي لاَ يُؤَدِّي زَكَاةَ مَالِهِ يُخَيَّلُ إِلَيْهِ مَالُهُ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ لَهُ زَبِيبَتَانِ - قَالَ - فَيَلْتَزِمُهُ أَوْ يُطَوِّقُهُ - قَالَ - يَقُولُ أَنَا كَنْزُكَ أَنَا كَنْزُكَ ‏"‏ ‏.‏\hadithno{2481}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: The one who does not pay Zakah on his wealth, his wealth will appear to him on the Day of Resurrection like a bald-headed Shuja 'a [2] with two dots above its eyes. It will hold onto him or encircle him and will say: I am your hoarded treasure, I am your hoarded treasure}}
\hadithdefcmd{nasai}{2482}{أَخْبَرَنَا الْفَضْلُ بْنُ سَهْلٍ، قَالَ حَدَّثَنَا حَسَنُ بْنُ مُوسَى الأَشْيَبُ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ الْمَدَنِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ آتَاهُ اللَّهُ عَزَّ وَجَلَّ مَالاً فَلَمْ يُؤَدِّ زَكَاتَهُ مُثِّلَ لَهُ مَالُهُ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ لَهُ زَبِيبَتَانِ يَأْخُذُ بِلِهْزِمَتَيْهِ يَوْمَ الْقِيَامَةِ فَيَقُولُ أَنَا مَالُكَ أَنَا كَنْزُكَ ‏"‏ ‏.‏ ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏\{‏ وَلاَ يَحْسَبَنَّ الَّذِينَ يَبْخَلُونَ بِمَا آتَاهُمُ اللَّهُ مِنْ فَضْلِهِ ‏\}‏ الآيَةَ ‏.‏\hadithno{2482}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"If Allah gives a person wealth and he does not pay Zakah on it, his wealth will appear to him on the Day of Resurrection as a bald-heated Shuja'a with two dots above its eyes. It will take hold of the corners of his mouth on the Day of Resurrection and will say: 'I am your wealth, I am your hoarded treasure.' The he recited this verse: 'And let not those who covetously withhold of that which Allah has bestowed on them of His Bounty (wealth) and think that it is good for them (and so they do not pay the obligatory Zakah)}}
\hadithdefcmd{nasai}{2483}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسَاقٍ مِنْ حَبٍّ أَوْ تَمْرٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2483}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated the Abu Sa'eed Al-Khudri said:"The Messenger of Allah said: There is no Sadaqah on less than five Awsaq of grains or dates}}
\hadithdefcmd{nasai}{2484}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا رَوْحُ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنِي عَمْرُو بْنُ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ فِي الْبُرِّ وَالتَّمْرِ زَكَاةٌ حَتَّى تَبْلُغَ خَمْسَةَ أَوْسُقٍ وَلاَ يَحِلُّ فِي الْوَرِقِ زَكَاةٌ حَتَّى تَبْلُغَ خَمْسَةَ أَوَاقٍ وَلاَ يَحِلُّ فِي إِبِلٍ زَكَاةٌ حَتَّى تَبْلُغَ خَمْسَ ذَوْدٍ ‏"‏ ‏.‏\hadithno{2484}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Messenger of Allah said:"No Zakah is due on wheat or dates unless the amount reaches five Awsuq. No Zakah is due on silver unless the amount reaches five Awaq. No Zakah is due on camels until the number reaches five Dhawd}}
\hadithdefcmd{nasai}{2485}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِي حَبٍّ وَلاَ تَمْرٍ صَدَقَةٌ حَتَّى يَبْلُغَ خَمْسَةَ أَوْسُقٍ وَلاَ فِيمَا دُونَ خَمْسِ ذَوْدٍ وَلاَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2485}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Prophet said:"No Sadaqah is due on grains or dates unless the amount reaches five Awauq, nor on less than five Dhawd, nor on less than five Awaq}}
\hadithdefcmd{nasai}{2486}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا إِدْرِيسُ الأَوْدِيُّ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2486}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed said:The Messenger of Allah said: "No Sadaqah is due on less than five Awaq}}
\hadithdefcmd{nasai}{2487}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدَةَ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَعُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ وَلاَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2487}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al\_khudri that the Prophet said:"No sadaqah is due on less than five Awaq, no Sadaqah is due on less than five Dhawd, no Sadaqah is due on less than five Awsuq}}
\hadithdefcmd{nasai}{2488}{أَخْبَرَنَا هَارُونُ بْنُ سَعِيدِ بْنِ الْهَيْثَمِ أَبُو جَعْفَرٍ الأَيْلِيُّ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِيمَا سَقَتِ السَّمَاءُ وَالأَنْهَارُ وَالْعُيُونُ أَوْ كَانَ بَعْلاً الْعُشْرُ وَمَا سُقِيَ بِالسَّوَانِي وَالنَّضْحِ نِصْفُ الْعُشْرِ ‏"‏ ‏.‏\hadithno{2488}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Salim, from his father, that the Messenger of Allah said:"For whatever is irrigated by the sky, rivers and springs, or draws up water from deep roots, one-tenth. For whatever is irrigated by animals and artificial means, one half of one-tenth}}
\hadithdefcmd{nasai}{2489}{أَخْبَرَنِي عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، وَأَحْمَدُ بْنُ عَمْرٍو، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، أَنَّ أَبَا الزُّبَيْرِ، حَدَّثَهُ أَنَّهُ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِيمَا سَقَتِ السَّمَاءُ وَالأَنْهَارُ وَالْعُيُونُ الْعُشْرُ وَفِيمَا سُقِيَ بِالسَّانِيَةِ نِصْفُ الْعُشْرِ ‏"‏ ‏.‏\hadithno{2489}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir bin 'Abdullah said:"The Messenger of Allah said:'For that which is watered by the sky, rivers and springs, one-tenth. For whatever is irrigated by animals, one-half of one-tenth}}
\hadithdefcmd{nasai}{2490}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي بَكْرٍ، - وَهُوَ ابْنُ عَيَّاشٍ - عَنْ عَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنْ مُعَاذٍ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَمَنِ فَأَمَرَنِي أَنْ آخُذَ مِمَّا سَقَتِ السَّمَاءُ الْعُشْرَ وَفِيمَا سُقِيَ بِالدَّوَالِي نِصْفَ الْعُشْرِ ‏.‏\hadithno{2490}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Mu'adh said:"The Messenger of Allah sent me to Yemen and he commanded me to take one-tenth of whatever is irrigated by the sky, and half of one-tenth of whatever is irrigated by means of buckets}}
\hadithdefcmd{nasai}{2491}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ خُبَيْبَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَسْعُودِ بْنِ نِيَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثَمَةَ، قَالَ أَتَانَا وَنَحْنُ فِي السُّوقِ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا خَرَصْتُمْ فَخُذُوا وَدَعُوا الثُّلُثَ فَإِنْ لَمْ تَأْخُذُوا أَوْ تَدَعُوا الثُّلُثَ - شَكَّ شُعْبَةُ - فَدَعُوا الرُّبُعَ ‏"‏ ‏.‏\hadithno{2491}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman bin Mas'ud bin Niyar:"Sahl bin Abi Hathmah came to us when we were in the market and said: "The Messenger of Allah said: When you have estimated, take two-thirds (of the portion you have estimated as Zakah) and leave one-third, and if you do not take (two-thirds) or leave one-third. (One of the reporters) Shu 'bah doubted - leave one quarter}}
\hadithdefcmd{nasai}{2492}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنِي عَبْدُ الْجَلِيلِ بْنُ حُمَيْدٍ الْيَحْصَبِيُّ، أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ قَالَ حَدَّثَنِي أَبُو أُمَامَةَ بْنُ سَهْلِ بْنِ حُنَيْفٍ، فِي الآيَةِ الَّتِي قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَيَمَّمُوا الْخَبِيثَ مِنْهُ تُنْفِقُونَ ‏\}‏ قَالَ هُوَ الْجُعْرُورُ وَلَوْنُ حُبَيْقٍ فَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُؤْخَذَ فِي الصَّدَقَةِ الرُّذَالَةُ ‏.‏\hadithno{2492}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Umamah bin Sahl bin Hunaif said:concerning the Verse in which Allah, the Mighty and Subline, says: And do not aim at that which is bad to spend from it." [2] This refers to had quality dates. The Messenger of Allah forbade taking bad quality dates as Sadaqah}}
\hadithdefcmd{nasai}{2493}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا يَحْيَى، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنِي صَالِحُ بْنُ أَبِي عَرِيبٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ الْحَضْرَمِيِّ، عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَبِيَدِهِ عَصًا وَقَدْ عَلَّقَ رَجُلٌ قِنْوَ حَشَفٍ فَجَعَلَ يَطْعَنُ فِي ذَلِكَ الْقِنْوِ فَقَالَ ‏ "‏ لَوْ شَاءَ رَبُّ هَذِهِ الصَّدَقَةِ تَصَدَّقَ بِأَطْيَبَ مِنْ هَذَا إِنَّ رَبَّ هَذِهِ الصَّدَقَةِ يَأْكُلُ حَشَفًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2493}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Awf bin Malik said:"The Messenger of Allah came out with a stick in his hand, and a man had hung up a bunch of dry and bad dates. He started hitting that bunch of dates and said: 'I wish that the one who gave this Sadaqah had given something better than this, for the one who gave these dry, bad dates will eat dry, bad dates on the Day of Resurrection}}
\hadithdefcmd{nasai}{2494}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ اللُّقَطَةِ فَقَالَ ‏ "‏ مَا كَانَ فِي طَرِيقٍ مَأْتِيٍّ أَوْ فِي قَرْيَةٍ عَامِرَةٍ فَعَرِّفْهَا سَنَةً فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ فَلَكَ وَمَا لَمْ يَكُنْ فِي طَرِيقٍ مَأْتِيٍّ وَلاَ فِي قَرْيَةٍ عَامِرَةٍ فَفِيهِ وَفِي الرِّكَازِ الْخُمْسُ ‏"‏ ‏.‏\hadithno{2494}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"The Messenger of Allah was asked about Al-Luqath.[2] He said: "That which is found on a much-traveled road or in an inhabited village, announce it for a year. If its owner comes (and takes it, well and good), otherwise it is yours. That which was not found on a much-traveled road or in an inhabited village is subject to the Khuns, as is Rikaz}}
\hadithdefcmd{nasai}{2495}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَأَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَجْمَاءُ جَرْحُهَا جُبَارٌ وَالْبِئْرُ جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَفِي الرِّكَازِ الْخُمْسُ ‏"‏ ‏.‏\hadithno{2495}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"The injuries caused by the beast are without liability, [2] and wells are without liability, and mines are without liability, and the Khumus is due on Rikaz}}
\hadithdefcmd{nasai}{2496}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدٍ، وَعُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2496}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah:A similar report was narrated from Abu Hurairah from the Messenger of Allah}}
\hadithdefcmd{nasai}{2497}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ جَرْحُ الْعَجْمَاءِ جُبَارٌ وَالْبِئْرُ جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَفِي الرِّكَازِ الْخُمْسُ ‏"‏ ‏.‏\hadithno{2497}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"The injuries caused by the best are without liability, and wells are without liability, and mines are without liability, and the Khumus is due on Rikaz}}
\hadithdefcmd{nasai}{2498}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، أَنْبَأَنَا مَنْصُورٌ، وَهِشَامٌ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبِئْرُ جُبَارٌ وَالْعَجْمَاءُ جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَفِي الرِّكَازِ الْخُمْسُ ‏"‏ ‏.‏\hadithno{2498}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:The Messenger of Allah said: "The injuries caused by the well are without liability, [1] and beasts are without liability, and mines are without liability, and the Khumus is due on Rikaz}}
\hadithdefcmd{nasai}{2499}{أَخْبَرَنِي الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، عَنْ مُوسَى بْنِ أَعْيَنَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ هِلاَلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِعُشُورِ نَحْلٍ لَهُ وَسَأَلَهُ أَنْ يَحْمِيَ لَهُ وَادِيًا يُقَالُ لَهُ سَلَبَةُ فَحَمَى لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَلِكَ الْوَادِيَ فَلَمَّا وَلِيَ عُمَرُ بْنُ الْخَطَّابِ كَتَبَ سُفْيَانُ بْنُ وَهْبٍ إِلَى عُمَرَ بْنِ الْخَطَّابِ يَسْأَلُهُ فَكَتَبَ عُمَرُ إِنْ أَدَّى إِلَيْكَ مَا كَانَ يُؤَدِّي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ عُشْرِ نَحْلِهِ فَاحْمِ لَهُ سَلَبَةَ ذَلِكَ وَإِلاَّ فَإِنَّمَا هُوَ ذُبَابُ غَيْثٍ يَأْكُلُهُ مَنْ شَاءَ ‏.‏\hadithno{2499}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father that his grandfather said:"Hilal came to the Messenger of Allah with one-tenth of the honey and asked him to protect a valley for him that was called Salabah. 'The Messenger of Allah protected that valley for him. When 'Umar bin Al-Khattab became the Khalifah, sufyan bin Wahb wrote the 'Umar and asked him (about that), and Umar wrote: 'If the gives me what he used to give to the Messenger of Allah, one-tenth of his honey, I will protect Salahab for him, otherwise they are just bees and anyone who wants to may eat of it}}
\hadithdefcmd{nasai}{2500}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، عَنْ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ رَمَضَانَ عَلَى الْحُرِّ وَالْعَبْدِ وَالذَّكَرِ وَالأُنْثَى صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ فَعَدَلَ النَّاسُ بِهِ نِصْفَ صَاعٍ مِنْ بُرٍّ ‏.‏\hadithno{2500}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah enjoined Zakah of Ramadan upon the free and the slave, male and female, a Sa[1] of dates or a Sa of barley, so the people considered that equivalent to half a Sa of wheat}}
\hadithdefcmd{nasai}{2501}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَدَقَةَ الْفِطْرِ عَلَى الذَّكَرِ وَالأُنْثَى وَالْحُرِّ وَالْمَمْلُوكِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ ‏.‏ قَالَ فَعَدَلَ النَّاسُ إِلَى نِصْفِ صَاعٍ مِنْ بُرٍّ ‏.‏\hadithno{2501}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah enjoined Sadaqatul Fitr upon male and female, free and slave; a Sa of dates or a Sa of barley." He said: "The people considered that equivalent to half a Sa of wheat}}
\hadithdefcmd{nasai}{2502}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ رَمَضَانَ عَلَى كُلِّ صَغِيرٍ وَكَبِيرٍ حُرٍّ وَعَبْدٍ وَذَكَرٍ وَأُنْثَى صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ ‏.‏\hadithno{2502}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah enjoined the Zakah of Ramadan on everyone, young and old, free and slave, male and female, a Sa of dates or a Sa of barley}}
\hadithdefcmd{nasai}{2503}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَضَ زَكَاةَ الْفِطْرِ مِنْ رَمَضَانَ عَلَى النَّاسِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ عَلَى كُلِّ حُرٍّ أَوْ عَبْدٍ ذَكَرٍ أَوْ أُنْثَى مِنَ الْمُسْلِمِينَ ‏.‏\hadithno{2503}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah enjoined Zakatul-Fitr at the end of Ramadan upon the people; a Sa' of dates or a Sa' of barley, upon everyone, free or slave, male or female, of the Muslims}}
\hadithdefcmd{nasai}{2504}{أَخْبَرَنَا يَحْيَى بْنُ مُحَمَّدِ بْنِ السَّكَنِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَهْضَمٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عُمَرَ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ الْفِطْرِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ عَلَى الْحُرِّ وَالْعَبْدِ وَالذَّكَرِ وَالأُنْثَى وَالصَّغِيرِ وَالْكَبِيرِ مِنَ الْمُسْلِمِينَ وَأَمَرَ بِهَا أَنْ تُؤَدَّى قَبْلَ خُرُوجِ النَّاسِ إِلَى الصَّلاَةِ ‏.‏\hadithno{2504}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah enjoined Zakatul-Fitr, a Sa' of dates or a Sa of barley, upon the free person and the slave, male and female, young and old, among the Muslims. He commanded that it be given before the people went out to the ('fd) prayer}}
\hadithdefcmd{nasai}{2505}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عِيسَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَدَقَةَ الْفِطْرِ عَلَى الصَّغِيرِ وَالْكَبِيرِ وَالذَّكَرِ وَالأُنْثَى وَالْحُرِّ وَالْعَبْدِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ ‏.‏\hadithno{2505}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah enjoined Sadaqatul Fitr upon young and old, male and female, free and slave; a Sa' of dates or a Sa' of barley}}
\hadithdefcmd{nasai}{2506}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ قَيْسِ بْنِ سَعْدِ بْنِ عُبَادَةَ، قَالَ كُنَّا نَصُومُ عَاشُورَاءَ وَنُؤَدِّي زَكَاةَ الْفِطْرِ فَلَمَّا نَزَلَ رَمَضَانُ وَنَزَلَتِ الزَّكَاةُ لَمْ نُؤْمَرْ بِهِ وَلَمْ نُنْهَ عَنْهُ وَكُنَّا نَفْعَلُهُ ‏.‏\hadithno{2506}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qais bin Sa'd bin 'Ubadah Said:"We used to fast on 'Ashura and give Zakatul-Fitr, and when the command to fast in Ramadan was revealed, and the command to give Zakah was revealed, we were neither commanded to give it, nor told not to do so, and we used to do it}}
\hadithdefcmd{nasai}{2507}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ أَبِي عَمَّارٍ الْهَمْدَانِيِّ، عَنْ قَيْسِ بْنِ سَعْدٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَدَقَةِ الْفِطْرِ قَبْلَ أَنْ تَنْزِلَ الزَّكَاةُ فَلَمَّا نَزَلَتِ الزَّكَاةُ لَمْ يَأْمُرْنَا وَلَمْ يَنْهَنَا وَنَحْنُ نَفْعَلُهُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَبُو عَمَّارٍ اسْمُهُ عَرِيبُ بْنُ حُمَيْدٍ وَعَمْرُو بْنُ شُرَحْبِيلَ يُكَنَّى أَبَا مَيْسَرَةَ وَسَلَمَةُ بْنُ كُهَيْلٍ خَالَفَ الْحَكَمَ فِي إِسْنَادِهِ وَالْحَكَمُ أَثْبَتُ مِنْ سَلَمَةَ بْنِ كُهَيْلٍ ‏.‏\hadithno{2507}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qais bin Sa'd said:"The Messenger of Allah commanded us to give Sadaqatul Fitr before the command to give Zakah was revealed. When the command to give Zakah was revealed, he neither told us to do it, not told us not to do it, and we used to do it." (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: Abu 'Ammar's name is 'Arib bin Humaid, and 'Amr bin Shurabbil's Kunyah is Abu Maisarah, and Salamah bin Kuhail contradicted Al-Hakam in his chain, and Al-Hakam is more reliable than Salamah bin Kuhail}}
\hadithdefcmd{nasai}{2508}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا حُمَيْدٌ، عَنِ الْحَسَنِ، قَالَ قَالَ ابْنُ عَبَّاسٍ وَهُوَ أَمِيرُ الْبَصْرَةِ فِي آخِرِ الشَّهْرِ أَخْرِجُوا زَكَاةَ صَوْمِكُمْ ‏.‏ فَنَظَرَ النَّاسُ بَعْضُهُمْ إِلَى بَعْضٍ فَقَالَ مَنْ هَا هُنَا مِنْ أَهْلِ الْمَدِينَةِ قُومُوا فَعَلِّمُوا إِخْوَانَكُمْ فَإِنَّهُمْ لاَ يَعْلَمُونَ إِنَّ هَذِهِ الزَّكَاةَ فَرَضَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى كُلِّ ذَكَرٍ وَأُنْثَى حُرٍّ وَمَمْلُوكٍ صَاعًا مِنْ شَعِيرٍ أَوْ تَمْرٍ أَوْ نِصْفَ صَاعٍ مِنْ قَمْحٍ ‏.‏ فَقَامُوا ‏.‏ خَالَفَهُ هِشَامٌ فَقَالَ عَنْ مُحَمَّدِ بْنِ سِيرِينَ ‏.‏\hadithno{2508}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{When he was the governor of Al-Basrah, at the end of the month, Ibn 'Abbas said:"Give Zakah of your fast." The people looked at one another, so he said: "Whoever is here from the people of Al-Madinah, get up and teach your brothers, for they do lnot know that this Zakah was enjoined by the Messenger of Allah upon every male and female, free and slave, a Sa' of barley or dates, or half a Sa' of wheat. "So they got up. (Da'if) Hisham contradicted him, he said: "From Muhammad bin Sirin}}
\hadithdefcmd{nasai}{2509}{أَخْبَرَنَا عَلِيُّ بْنُ مَيْمُونٍ، عَنْ مَخْلَدٍ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ذَكَرَ فِي صَدَقَةِ الْفِطْرِ قَالَ صَاعًا مِنْ بُرٍّ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ سُلْتٍ ‏.‏\hadithno{2509}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that:Ibn 'Abbas said concerning Sadaqatul-Fitr. "A Sa' of wheat, or a Sa' of dates, or Sa of barley, or a Sa' of rye." (Sahih Mawquf)}}
\hadithdefcmd{nasai}{2510}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي رَجَاءٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَخْطُبُ عَلَى مِنْبَرِكُمْ - يَعْنِي مِنْبَرَ الْبَصْرَةِ - يَقُولُ صَدَقَةُ الْفِطْرِ صَاعٌ مِنْ طَعَامٍ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا أَثْبَتُ الثَّلاَثَةِ ‏.‏\hadithno{2510}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Raja' said:I heard Ibn 'Abbas deliver a Khutbah from your Minbar - meaning the Minbar in Al-Basrah - saying: 'Sadaqatul Fitr is a Sa' of food." (Sahih) Abu 'Abdur-Rahman (An-Nasa'i) said: This is the most reliable of the three}}
\hadithdefcmd{nasai}{2511}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ حَرْبٍ، قَالَ حَدَّثَنَا مُحْرِزُ بْنُ الْوَضَّاحِ، عَنْ إِسْمَاعِيلَ، - وَهُوَ ابْنُ أُمَيَّةَ - عَنِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي ذُبَابٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَرْحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَدَقَةَ الْفِطْرِ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ أَقِطٍ ‏.‏\hadithno{2511}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah enjoined Sadaqatul Fitr, a Sa' of barley or a Sa of dates or a Sa' of cottage cheese}}
\hadithdefcmd{nasai}{2512}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَرْحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ كُنَّا نُخْرِجُ زَكَاةَ الْفِطْرِ إِذْ كَانَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَاعًا مِنْ طَعَامٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ زَبِيبٍ أَوْ صَاعًا مِنْ أَقِطٍ ‏.‏\hadithno{2512}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"We used to pay Zakaul Fitr when the Messenger of Allah was among us; a Sa' of food, or a Sa' of barley, or a Sa' of dates, or a Sa' of raisins, or a Sa of cottage cheese}}
\hadithdefcmd{nasai}{2513}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ، قَالَ كُنَّا نُخْرِجُ صَدَقَةَ الْفِطْرِ إِذْ كَانَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَاعًا مِنْ طَعَامٍ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ أَقِطٍ فَلَمْ نَزَلْ كَذَلِكَ حَتَّى قَدِمَ مُعَاوِيَةُ مِنَ الشَّامِ وَكَانَ فِيمَا عَلَّمَ النَّاسَ أَنَّهُ قَالَ مَا أَرَى مُدَّيْنِ مِنْ سَمْرَاءِ الشَّامِ إِلاَّ تَعْدِلُ صَاعًا مِنْ هَذَا ‏.‏ قَالَ فَأَخَذَ النَّاسُ بِذَلِكَ ‏.‏\hadithno{2513}\hadithgrade{Abu Ghuddah: -; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed said:"We used to pay Salaqatul Fitr when the Messenger of Allah was among us; a Sa' of food, or a Sa' of dates, or a Sa' of barley, or a Sa' of cottage cheese. We continued to do so until Mu'awiyah came from Ash-Sham and one of the things that he taught the people was when he said: I think that two Mudds of wheat from Ash-Sham are equivalent to a Sa' of this, So the people took to that}}
\hadithdefcmd{nasai}{2514}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، قَالَ سَمِعْتُ عِيَاضَ بْنَ عَبْدِ اللَّهِ، يُخْبِرُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ لَمْ نُخْرِجْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ زَبِيبٍ أَوْ صَاعًا مِنْ دَقِيقٍ أَوْ صَاعًا مِنْ أَقِطٍ أَوْ صَاعًا مِنْ سُلْتٍ - ثُمَّ شَكَّ سُفْيَانُ - فَقَالَ دَقِيقٍ أَوْ سُلْتٍ ‏.‏\hadithno{2514}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:" At the time of the Messenger of Allah we did not give anything except a Sa' of dates, or a Sa' of barley, or a Sa' of raisins, or a Sa' of flour, or a Sa' of cottage cheese, or a Sa' of rye." Then (one of the narrators) Sufyan was uncertain and said: "Flour or rye}}
\hadithdefcmd{nasai}{2515}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنِ الْحَسَنِ، أَنَّ ابْنَ عَبَّاسٍ، خَطَبَ بِالْبَصْرَةِ فَقَالَ أَدُّوا زَكَاةَ صَوْمِكُمْ ‏.‏ فَجَعَلَ النَّاسُ يَنْظُرُ بَعْضُهُمْ إِلَى بَعْضٍ فَقَالَ مَنْ هَا هُنَا مِنْ أَهْلِ الْمَدِينَةِ قُومُوا إِلَى إِخْوَانِكُمْ فَعَلِّمُوهُمْ فَإِنَّهُمْ لاَ يَعْلَمُونَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَضَ صَدَقَةَ الْفِطْرِ عَلَى الصَّغِيرِ وَالْكَبِيرِ وَالْحُرِّ وَالْعَبْدِ وَالذَّكَرِ وَالأُنْثَى نِصْفَ صَاعِ بُرٍّ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ شَعِيرٍ ‏.‏ قَالَ الْحَسَنُ فَقَالَ عَلِيٌّ أَمَّا إِذَا أَوْسَعَ اللَّهُ فَأَوْسِعُوا أَعْطُوا صَاعًا مِنْ بُرٍّ أَوْ غَيْرِهِ ‏.‏\hadithno{2515}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Hasan that Ibn 'Abbas delivered a Khutbah in Al-Basrah and said:"Give Zakah of your fast." The people started looking at one another. So he said: "Whoever is here of the people of Al-Madinah, get up and teach your brothers, for they do not know that the Messenger of Allah has enjoined Salaqatul Fitr upon young and old, free and slave, male and female; half a Sa' of wheat or a Sa' of dates or barely." Al\_Hasan said: 'If Allah has given you more, then give more generously of wheat or something else}}
\hadithdefcmd{nasai}{2516}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّاسُ يُخْرِجُونَ عَنْ صَدَقَةِ الْفِطْرِ، فِي عَهْدِ النَّبِيِّ صلى الله عليه وسلم صَاعًا مِنْ شَعِيرٍ أَوْ تَمْرٍ أَوْ سُلْتٍ أَوْ زَبِيبٍ ‏.‏\hadithno{2516}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"At the time of the Messenger of Allah, the people used to give as Sadaqatul Fitr a Sa' of barely or dates or rye or raising}}
\hadithdefcmd{nasai}{2517}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، قَالَ حَدَّثَنَا عِيَاضٌ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نُخْرِجُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم صَاعًا مِنْ شَعِيرٍ أَوْ تَمْرٍ أَوْ زَبِيبٍ أَوْ أَقِطٍ فَلَمْ نَزَلْ كَذَلِكَ حَتَّى كَانَ فِي عَهْدِ مُعَاوِيَةَ قَالَ مَا أَرَى مُدَّيْنِ مِنْ سَمْرَاءِ الشَّامِ إِلاَّ تَعْدِلُ صَاعًا مِنْ شَعِيرٍ ‏.‏\hadithno{2517}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa' eed Al-Khudri said:"At the time of the Messenger of Allah, we used to give a Sa' of barley, or dates, or raisins, or cottage cheese, and we continued to do so until the time of Mu'awiyah, when he said: 'I think that two Mudds of wheat from Ash-Sham are equivalent to a Sa' of barley}}
\hadithdefcmd{nasai}{2518}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَزِيدَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُثْمَانَ، أَنَّ عِيَاضَ بْنَ عَبْدِ اللَّهِ بْنِ سَعْدٍ، حَدَّثَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ قَالَ كُنَّا نُخْرِجُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ أَقِطٍ لاَ نُخْرِجُ غَيْرَهُ ‏.‏\hadithno{2518}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"At the time of the Messenger of Allah we used to give a Sa' of dates, or a Sa' of barley, or a Sa' of cottage cheese, and we did not give anything else}}
\hadithdefcmd{nasai}{2519}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا الْقَاسِمُ، - وَهُوَ ابْنُ مَالِكٍ - عَنِ الْجُعَيْدِ، سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، قَالَ كَانَ الصَّاعُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مُدًّا وَثُلُثًا بِمُدِّكُمُ الْيَوْمَ وَقَدْ زِيدَ فِيهِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَحَدَّثَنِيهِ زِيَادُ بْنُ أَيُّوبَ ‏.‏\hadithno{2519}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Ju'aid:"I heard As-Sa'ib bin Yazid say: 'During the time of Allah's messenger, the Sa' was equal to a Mudd and third of the Mudd you use today, and the Sa' of today has become large."' (Sahih) Abu 'Abdur-Rahman (An-Nasa'i) said: And Ziyad bin Ayyub narrated it to me}}
\hadithdefcmd{nasai}{2520}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حَنْظَلَةَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمِكْيَالُ مِكْيَالُ أَهْلِ الْمَدِينَةِ وَالْوَزْنُ وَزْنُ أَهْلِ مَكَّةَ ‏"‏ ‏.‏\hadithno{2520}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet (ﷺ) said:"The measure (to be used) is the measure of the people of Al-Madinah, and the weight (to be used) is the weight of the people of Makkah}}
\hadithdefcmd{nasai}{2521}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْدَانَ بْنِ عِيسَى، قَالَ حَدَّثَنَا الْحَسَنُ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُوسَى، ح قَالَ وَأَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا الْفُضَيْلُ، قَالَ حَدَّثَنَا مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِصَدَقَةِ الْفِطْرِ أَنْ تُؤَدَّى قَبْلَ خُرُوجِ النَّاسِ إِلَى الصَّلاَةِ ‏.‏ قَالَ ابْنُ بَزِيعٍ بِزَكَاةِ الْفِطْرِ ‏.‏\hadithno{2521}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah enjoined that Sadaqatul Fitr should be given before the people go out to pray. (One of the narratorsP: Ibn Bazi'said: "Zakatul-Fitr)}}
\hadithdefcmd{nasai}{2522}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، - وَكَانَ ثِقَةً - عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ مُعَاذَ بْنَ جَبَلٍ إِلَى الْيَمَنِ فَقَالَ ‏ "‏ إِنَّكَ تَأْتِي قَوْمًا أَهْلَ كِتَابٍ فَادْعُهُمْ إِلَى شَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ فَإِنْ هُمْ أَطَاعُوكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ عَزَّ وَجَلَّ افْتَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ فَإِنْ هُمْ أَطَاعُوكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ عَزَّ وَجَلَّ قَدِ افْتَرَضَ عَلَيْهِمْ صَدَقَةً فِي أَمْوَالِهِمْ تُؤْخَذُ مِنْ أَغْنِيَائِهِمْ فَتُوضَعُ فِي فُقَرَائِهِمْ فَإِنْ هُمْ أَطَاعُوكَ لِذَلِكَ فَإِيَّاكَ وَكَرَائِمَ أَمْوَالِهِمْ وَاتَّقِ دَعْوَةَ الْمَظْلُومِ فَإِنَّهَا لَيْسَ بَيْنَهَا وَبَيْنَ اللَّهِ عَزَّ وَجَلَّ حِجَابٌ ‏"‏ ‏.‏\hadithno{2522}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet sent Mu'adh bin Jabal to Yemen and said:"You are going to some people from among the people of the Book. Call them to bear witness that there is none worthy of worship except Allah and that I am the Messenger of Allah. If they obey you in that, then teach them that Allah has enjoined upon them five prayers every day and night. If they obey you in that, then teach them that Allah has enjoined upon them Sadaqah (Zakah) from their wealth, to be taken from their rich and given to their poor. If they obey you in that, then do not touch the most precious of their wealth, and fear the supplication of the one who has been wronged, for there is no barrier between it and Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{2523}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، مِمَّا حَدَّثَهُ عَبْدُ الرَّحْمَنِ الأَعْرَجُ، مِمَّا ذَكَرَ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ بِهِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ قَالَ رَجُلٌ لأَتَصَدَّقَنَّ بِصَدَقَةٍ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدِ سَارِقٍ فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ عَلَى سَارِقٍ فَقَالَ اللَّهُمَّ لَكَ الْحَمْدُ عَلَى سَارِقٍ لأَتَصَدَّقَنَّ بِصَدَقَةٍ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدِ زَانِيَةٍ فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ اللَّيْلَةَ عَلَى زَانِيَةٍ فَقَالَ اللَّهُمَّ لَكَ الْحَمْدُ عَلَى زَانِيَةٍ لأَتَصَدَّقَنَّ بِصَدَقَةٍ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدِ غَنِيٍّ فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ عَلَى غَنِيٍّ قَالَ اللَّهُمَّ لَكَ الْحَمْدُ عَلَى زَانِيَةٍ وَعَلَى سَارِقٍ وَعَلَى غَنِيٍّ فَأُتِيَ فَقِيلَ لَهُ أَمَّا صَدَقَتُكَ فَقَدْ تُقُبِّلَتْ أَمَّا الزَّانِيَةُ فَلَعَلَّهَا أَنْ تَسْتَعِفَّ بِهِ مِنْ زِنَاهَا وَلَعَلَّ السَّارِقَ أَنْ يَسْتَعِفَّ بِهِ عَنْ سَرِقَتِهِ وَلَعَلَّ الْغَنِيَّ أَنْ يَعْتَبِرَ فَيُنْفِقَ مِمَّا أَعْطَاهُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2523}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"A man said" 'I am going to give some charity.' So he went out with his charity and put it in the hand of a thief. The next morning they started talking about how charity had been given to a thief. Then he said: 'O Allah, to You be praise for the thief. I am going to give some charity.' So he went out with his charity and put it in the hand of a prostitute. The next morning they started talking about how charity had been given to a prostitute. He said: 'O Allah, to You be praise for the prostitute. I am going to give some charity. So he went out with his charity and put it in the hand of a rich man. The next morning they started talking about how charity had been given to a rich man. He said: 'O Allah, th You be praise for the prostitute, the thief and the rich man. 'Then the message came to him: As for your charity, it is accepted. As for the prostitute, perhaps it will keep her from committing Zina. As for the thief, perhaps it will stop him from stealing. And as for the rich man, perhaps he will learn a lesson, and will spend from that which Allah, the Mighty and Sublime, has given him}}
\hadithdefcmd{nasai}{2524}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ الذَّارِعُ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا شُعْبَةُ، ‏.‏ قَالَ وَأَنْبَأَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، - وَهُوَ ابْنُ الْمُفَضَّلِ - قَالَ حَدَّثَنَا شُعْبَةُ، - وَاللَّفْظُ لِبِشْرٍ - عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ لاَ يَقْبَلُ صَلاَةً بِغَيْرِ طُهُورٍ وَلاَ صَدَقَةً مِنْ غُلُولٍ ‏"‏ ‏.‏\hadithno{2524}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Al-Malib that his father said:"I heard the Messenger of Allah say: 'Allah, the Mighty and Sublime, does not accept prayer without purification or charity from Ghulul}}
\hadithdefcmd{nasai}{2525}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَصَدَّقَ أَحَدٌ بِصَدَقَةٍ مِنْ طَيِّبٍ وَلاَ يَقْبَلُ اللَّهُ عَزَّ وَجَلَّ إِلاَّ الطَّيِّبَ إِلاَّ أَخَذَهَا الرَّحْمَنُ عَزَّ وَجَلَّ بِيَمِينِهِ وَإِنْ كَانَتْ تَمْرَةً فَتَرْبُو فِي كَفِّ الرَّحْمَنِ حَتَّى تَكُونَ أَعْظَمَ مِنَ الْجَبَلِ كَمَا يُرَبِّي أَحَدُكُمْ فَلُوَّهُ أَوْ فَصِيلَهُ ‏"‏ ‏.‏\hadithno{2525}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Huraiarh said:"The Messenger of Allah said: None gives charity from (wealth earned from) a good source - and Allah does not accept anything but that which is good - but the Most Merciful takes it in His right hand, even if it is a date, and it tended in the hand of the Most Merciful until it becomes grater than a mountain, just as one of you tends his foal or camel calf."' (Shih)}}
\hadithdefcmd{nasai}{2526}{أَخْبَرَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْحَكَمِ، عَنْ حَجَّاجٍ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عُثْمَانُ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَلِيٍّ الأَزْدِيِّ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ حُبْشِيٍّ الْخَثْعَمِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏"‏ إِيمَانٌ لاَ شَكَّ فِيهِ وَجِهَادٌ لاَ غُلُولَ فِيهِ وَحَجَّةٌ مَبْرُورَةٌ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الصَّلاَةِ أَفْضَلُ قَالَ ‏"‏ طُولُ الْقُنُوتِ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏"‏ جَهْدُ الْمُقِلِّ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الْهِجْرَةِ أَفْضَلُ قَالَ ‏"‏ مَنْ هَجَرَ مَا حَرَّمَ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الْجِهَادِ أَفْضَلُ قَالَ ‏"‏ مَنْ جَاهَدَ الْمُشْرِكِينَ بِمَالِهِ وَنَفْسِهِ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الْقَتْلِ أَشْرَفُ قَالَ ‏"‏ مَنْ أُهْرِيقَ دَمُهُ وَعُقِرَ جَوَادُهُ ‏"‏ ‏.‏\hadithno{2526}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abudullah bin Hubshi Al-Khath 'ami that the Prophet was asked:"Which deed is best?" He said: "Faith in which there is no doubt, Jihad in which there is no stealing of the spoils of war, and Hjijatun Mabrurah."[1] It was said: "Which prayer is best? He said:"That in which there is ling Qunut (standing)." It was said: "Which charity is best?" He said: "The poor's night." It was said: "Which Hijrah (emigration) is best?" He said: "One who shuns (Hahara) that which Allah has forbidden." It was said: "One who strives against the idolaters with his life and his wealth. "It was said: "Which death is best?" He said: "One who sheds his blood while his horse's feet are cut with swords}}
\hadithdefcmd{nasai}{2527}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، وَالْقَعْقَاعِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ سَبَقَ دِرْهَمٌ مِائَةَ أَلْفِ دِرْهَمٍ ‏"‏ ‏.‏ قَالُوا وَكَيْفَ قَالَ ‏"‏ كَانَ لِرَجُلٍ دِرْهَمَانِ تَصَدَّقَ بِأَحَدِهِمَا وَانْطَلَقَ رَجُلٌ إِلَى عُرْضِ مَالِهِ فَأَخَذَ مِنْهُ مِائَةَ أَلْفِ دِرْهَمٍ فَتَصَدَّقَ بِهَا ‏"‏ ‏.‏\hadithno{2527}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"A Dirham surpassed a hundred thousand Dirhams." They said: "How?" He said: "A man had two Dirhams and gave one in charity, and another man went part of his wealth and took out a hundred thousand Dirhams and gave them in charity}}
\hadithdefcmd{nasai}{2528}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، قَالَ حَدَّثَنَا ابْنُ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَبَقَ دِرْهَمٌ مِائَةَ أَلْفٍ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَكَيْفَ قَالَ ‏"‏ رَجُلٌ لَهُ دِرْهَمَانِ فَأَخَذَ أَحَدَهُمَا فَتَصَدَّقَ بِهِ وَرَجُلٌ لَهُ مَالٌ كَثِيرٌ فَأَخَذَ مِنْ عُرْضِ مَالِهِ مِائَةَ أَلْفٍ فَتَصَدَّقَ بِهَا ‏"‏ ‏.‏\hadithno{2528}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'A Dirham was better than a hundred thousand Dirhams.' They said: 'O Messenger of Allah, how?' He said: 'A man had two Dirhams and gave one in charity, and another man went to part of his wealth and took out a hundred thousand Dirhams and gave them in charity}}
\hadithdefcmd{nasai}{2529}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ، عَنْ مَنْصُورٍ، عَنْ شَقِيقٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا بِالصَّدَقَةِ فَمَا يَجِدُ أَحَدُنَا شَيْئًا يَتَصَدَّقُ بِهِ حَتَّى يَنْطَلِقَ إِلَى السُّوقِ فَيَحْمِلَ عَلَى ظَهْرِهِ فَيَجِيءَ بِالْمُدِّ فَيُعْطِيَهُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِنِّي لأَعْرِفُ الْيَوْمَ رَجُلاً لَهُ مِائَةُ أَلْفٍ مَا كَانَ لَهُ يَوْمَئِذٍ دِرْهَمٌ ‏.‏\hadithno{2529}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Mas'ud said:"The Messenger of Allah used to tell us to give in charity, and one of us could not find anything to give until he went to the market place and hired himself out to carry loads for people. Then he would bring a Mudd and give it to the Messenger of Allah. I know a man who has a hundred thousand now, but on that day he had (only) one Dirham}}
\hadithdefcmd{nasai}{2530}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ لَمَّا أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالصَّدَقَةِ فَتَصَدَّقَ أَبُو عَقِيلٍ بِنِصْفِ صَاعٍ وَجَاءَ إِنْسَانٌ بِشَىْءٍ أَكْثَرَ مِنْهُ فَقَالَ الْمُنَافِقُونَ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَغَنِيٌّ عَنْ صَدَقَةِ هَذَا وَمَا فَعَلَ هَذَا الآخَرُ إِلاَّ رِيَاءً فَنَزَلَتِ ‏\{‏ الَّذِينَ يَلْمِزُونَ الْمُطَّوِّعِينَ مِنَ الْمُؤْمِنِينَ فِي الصَّدَقَاتِ وَالَّذِينَ لاَ يَجِدُونَ إِلاَّ جُهْدَهُمْ ‏\}‏ ‏.‏\hadithno{2530}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Mas 'ud said:"When the Messenger of Allah commanded us to give in charity, Abu 'Aqil give half a Sa', and another man brought much more than that. The hypocrites said: 'Allah has no need of the charity of the former, and the latter only did it to show off. Then the following was revealed: 'Those who defame such of the believers who give charity voluntarily, and such who could not find to give charity except what is available to them}}
\hadithdefcmd{nasai}{2531}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدٌ، وَعُرْوَةُ، سَمِعَا حَكِيمَ بْنَ حِزَامٍ، يَقُولُ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ قَالَ ‏ "‏ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ فَمَنْ أَخَذَهُ بِطِيبِ نَفْسٍ بُورِكَ لَهُ فِيهِ وَمَنْ أَخَذَهُ بِإِشْرَافِ نَفْسٍ لَمْ يُبَارَكْ لَهُ فِيهِ وَكَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏ ‏.‏\hadithno{2531}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'eed and 'Urwah narrated that they heard Hakim bin Hizam say:"I asked the Messenger of Allah and he gave me, then I asked him and he gave me, then I asked him and he gave me. Then he said: "This wealth is attractive and sweet. Whoever takes it without insisting, it will be blessed for him, and whoever takes it with avarice, it will not be blessed for him. He is like one who eats and is not satisfied. And the upper hand is better than the lower hand}}
\hadithdefcmd{nasai}{2532}{أَخْبَرَنَا يُوسُفُ بْنُ عِيسَى، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زِيَادِ بْنِ أَبِي الْجَعْدِ - عَنْ جَامِعِ بْنِ شَدَّادٍ، عَنْ طَارِقٍ الْمُحَارِبِيِّ، قَالَ قَدِمْنَا الْمَدِينَةَ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ عَلَى الْمِنْبَرِ يَخْطُبُ النَّاسَ وَهُوَ يَقُولُ ‏ "‏ يَدُ الْمُعْطِي الْعُلْيَا وَابْدَأْ بِمَنْ تَعُولُ أُمَّكَ وَأَبَاكَ وَأُخْتَكَ وَأَخَاكَ ثُمَّ أَدْنَاكَ أَدْنَاكَ ‏"‏ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{2532}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Tariq Al-Muharibi said:"We came to Al-Madinah and the Messenger of Allah was standing on the Minbar addressing the people and saying: 'The hand which gives is the upper hand. Start with those for whom you are responsible; your mother, your father, your sister, your brother, then the next closest, and the next closet}}
\hadithdefcmd{nasai}{2533}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ يَذْكُرُ الصَّدَقَةَ وَالتَّعَفُّفَ عَنِ الْمَسْأَلَةِ ‏ "‏ الْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى وَالْيَدُ الْعُلْيَا الْمُنْفِقَةُ وَالْيَدُ السُّفْلَى السَّائِلَةُ ‏"‏ ‏.‏\hadithno{2533}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:the Messenger of Allah said, when mentioning charity and those who refrain from asking. "The upper hand is better than the lower hand; the upper hand is that which gives and the lower hand is that which asks}}
\hadithdefcmd{nasai}{2534}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرٌ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ الصَّدَقَةِ مَا كَانَ عَنْ ظَهْرِ غِنًى وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى وَابْدَأْ بِمَنْ تَعُولُ ‏"‏ ‏.‏\hadithno{2534}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"The best of charity is that which is given when you are self-sufficient, and the upper hand is better than the lower hand, and start with those for whom you are responsible}}
\hadithdefcmd{nasai}{2535}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقُوا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ عِنْدِي دِينَارٌ ‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهِ عَلَى نَفْسِكَ ‏"‏ ‏.‏ قَالَ عِنْدِي آخَرُ ‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهِ عَلَى زَوْجَتِكَ ‏"‏ ‏.‏ قَالَ عِنْدِي آخَرُ ‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهِ عَلَى وَلَدِكَ ‏"‏ ‏.‏ قَالَ عِنْدِي آخَرُ ‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهِ عَلَى خَادِمِكَ ‏"‏ ‏.‏ قَالَ عِنْدِي آخَرُ ‏.‏ قَالَ ‏"‏ أَنْتَ أَبْصَرُ ‏"‏ ‏.‏\hadithno{2535}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Give charity.' A man said: 'O Messenger of Allah, I have a Dinar.' He said: 'Spend it on yourself.' He said: 'I have another.' He said: 'Spend it on your wife.' He said: 'I have another.' He said: 'Spend it on your son.' He said: 'I have another.' He said: 'Spend it on your servant.' He said: 'I have another.' He said: 'You know best (what to do with it)}}
\hadithdefcmd{nasai}{2536}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ عَجْلاَنَ، عَنْ عِيَاضٍ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ يَوْمَ الْجُمُعَةِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ فَقَالَ ‏"‏ صَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏ ثُمَّ جَاءَ الْجُمُعَةَ الثَّانِيَةَ وَالنَّبِيُّ صلى الله عليه وسلم يَخْطُبُ فَقَالَ ‏"‏ صَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏ ثُمَّ جَاءَ الْجُمُعَةَ الثَّالِثَةَ فَقَالَ ‏"‏ صَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ تَصَدَّقُوا ‏"‏ ‏.‏ فَتَصَدَّقُوا فَأَعْطَاهُ ثَوْبَيْنِ ثُمَّ قَالَ ‏"‏ تَصَدَّقُوا ‏"‏ ‏.‏ فَطَرَحَ أَحَدَ ثَوْبَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَمْ تَرَوْا إِلَى هَذَا إِنَّهُ دَخَلَ الْمَسْجِدَ بِهَيْئَةٍ بَذَّةٍ فَرَجَوْتُ أَنْ تَفْطُنُوا لَهُ فَتَصَدَّقُوا عَلَيْهِ فَلَمْ تَفْعَلُوا فَقُلْتُ تَصَدَّقُوا ‏.‏ فَتَصَدَّقْتُمْ فَأَعْطَيْتُهُ ثَوْبَيْنِ ثُمَّ قُلْتُ تَصَدَّقُوا ‏.‏ فَطَرَحَ أَحَدَ ثَوْبَيْهِ خُذْ ثَوْبَكَ ‏"‏ ‏.‏ وَانْتَهَرَهُ ‏.‏\hadithno{2536}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed that:a man entered the Msjid on a Friday when the Messenger of Allah was delivering the Khutbah, and he said: "Pray two Rak'ahs." Then he came on the following Friday, when the Prophet was delivering the Khutbah and he said: "Pray two Rak'ahs." Then he came on the third Friday, when the Prophet was delivering Khutbah and he said: "Pray two Rak'ahs." Then he said: "Give in charity." So they gave in charity, and he gave him (that man) two garments. Then he said: "Give in charity" and (that man) threw one of his two garments. The Messenger of Allah said: "Have you not seen this man? He entered the Masjid in scruffy clothes and I hoped that you would notice him, and give charity to him, but you did not do that, So I said, 'Give in charity.' You gave in charity, and I gave him two garments, then I said; 'Give in charity' and he threw one of his two garments. Take your garment." And he rebuked him}}
\hadithdefcmd{nasai}{2537}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَاتِمٌ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، قَالَ سَمِعْتُ عُمَيْرًا، مَوْلَى آبِي اللَّحْمِ قَالَ أَمَرَنِي مَوْلاَىَ أَنْ أُقَدِّدَ، لَحْمًا فَجَاءَ مِسْكِينٌ فَأَطْعَمْتُهُ مِنْهُ فَعَلِمَ بِذَلِكَ مَوْلاَىَ فَضَرَبَنِي فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَدَعَاهُ فَقَالَ ‏"‏ لِمَ ضَرَبْتَهُ ‏"‏ ‏.‏ فَقَالَ يُطْعِمُ طَعَامِي بِغَيْرِ أَنْ آمُرَهُ وَقَالَ مَرَّةً أُخْرَى بِغَيْرِ أَمْرِي قَالَ ‏"‏ الأَجْرُ بَيْنَكُمَا ‏"‏ ‏.‏\hadithno{2537}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated:'Umair, the freed slave of commanded me to cut up some meat, then a poor man came so I gave him some. When my master fund out about that, he beat me, so I went to the Messenger of Allah and he came to him and said: 'Do not beat him.' He said: 'He gave away my food without me telling him to.' He said: 'The reward will be shared between you both}}
\hadithdefcmd{nasai}{2538}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي ابْنُ أَبِي بُرْدَةَ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ عَلَى كُلِّ مُسْلِمٍ صَدَقَةٌ ‏"‏ ‏.‏ قِيلَ أَرَأَيْتَ إِنْ لَمْ يَجِدْهَا قَالَ ‏"‏ يَعْتَمِلُ بِيَدِهِ فَيَنْفَعُ نَفْسَهُ وَيَتَصَدَّقُ ‏"‏ ‏.‏ قِيلَ أَرَأَيْتَ إِنْ لَمْ يَفْعَلْ قَالَ ‏"‏ يُعِينُ ذَا الْحَاجَةِ الْمَلْهُوفَ ‏"‏ ‏.‏ قِيلَ فَإِنْ لَمْ يَفْعَلْ قَالَ ‏"‏ يَأْمُرُ بِالْخَيْرِ ‏"‏ ‏.‏ قِيلَ أَرَأَيْتَ إِنْ لَمْ يَفْعَلْ قَالَ ‏"‏ يُمْسِكُ عَنِ الشَّرِّ فَإِنَّهَا صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2538}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa that the Prophet said:"Every Muslim must give charity." It was said: "What if he cannot find (anything to give)? "He said: "Let him work with his hands and benefit himself and give in charity." It was said: "What if he cannot do that?" He said: "Let him help someone who is in desperate need." It was said: "What if he cannot do that?" He said: "Let him enjoin good." It was said: "What if he cannot do that? He said: "Let him refrain from doing evil, for that is an act of charity}}
\hadithdefcmd{nasai}{2539}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يُحَدِّثُ عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَصَدَّقَتِ الْمَرْأَةُ مِنْ بَيْتِ زَوْجِهَا كَانَ لَهَا أَجْرٌ وَلِلزَّوْجِ مِثْلُ ذَلِكَ وَلِلْخَازِنِ مِثْلُ ذَلِكَ وَلاَ يَنْقُصُ كُلُّ وَاحِدٍ مِنْهُمَا مِنْ أَجْرِ صَاحِبِهِ شَيْئًا لِلزَّوْجِ بِمَا كَسَبَ وَلَهَا بِمَا أَنْفَقَتْ ‏"‏ ‏.‏\hadithno{2539}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"When a woman give charity from her husband's house, she will have a reward, and her husband will have a similar reward, and the storekeeper will have a similar reward, without the reward of any of them detracting from the reward of the others in the slightest. The husband will be rewarded for what he earned and she will be rewarded for what she spent}}
\hadithdefcmd{nasai}{2540}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ أَبَاهُ، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ لَمَّا فَتَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ قَامَ خَطِيبًا فَقَالَ فِي خُطْبَتِهِ ‏ "‏ لاَ يَجُوزُ لاِمْرَأَةٍ عَطِيَّةٌ إِلاَّ بِإِذْنِ زَوْجِهَا ‏"‏ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{2540}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"When the Messenger of Allah conquered Makkah, he stood up to address the people and said in his Khutbah; 'It is not permissible for a woman to give anything without her husband's permission."' (He narrated it) in abridged from}}
\hadithdefcmd{nasai}{2541}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا أَبُو عَوَانَةَ، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ أَزْوَاجَ، النَّبِيِّ صلى الله عليه وسلم اجْتَمَعْنَ عِنْدَهُ فَقُلْنَ أَيَّتُنَا بِكَ أَسْرَعُ لُحُوقًا فَقَالَ ‏ "‏ أَطْوَلُكُنَّ يَدًا ‏"‏ ‏.‏ فَأَخَذْنَ قَصَبَةً فَجَعَلْنَ يَذْرَعْنَهَا فَكَانَتْ سَوْدَةُ أَسْرَعَهُنَّ بِهِ لُحُوقًا فَكَانَتْ أَطْوَلَهُنَّ يَدًا فَكَانَ ذَلِكَ مِنْ كَثْرَةِ الصَّدَقَةِ ‏.‏\hadithno{2541}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah, may Allah be pleased with her, that the wives of the Prophet "gathered around him and said:"Which of us will be the first to following you (in death)?" He said: "The one of you who has the longest arms." They took a stick and started to measure their arms. But Sawdah was the first one to follow him. She was the one who had the longest arms, because she used to give in charity a great deal}}
\hadithdefcmd{nasai}{2542}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏ "‏ أَنْ تَصَدَّقَ وَأَنْتَ صَحِيحٌ شَحِيحٌ تَأْمُلُ الْعَيْشَ وَتَخْشَى الْفَقْرَ ‏"‏ ‏.‏\hadithno{2542}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"A man said: 'O Messenger of Allah, which kind of charity is best? He said: 'Giving charity when you are in good health, and feeling stingy, hoping for a long life and fearing poverty}}
\hadithdefcmd{nasai}{2543}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ سَمِعْتُ مُوسَى بْنَ طَلْحَةَ، أَنَّ حَكِيمَ بْنَ حِزَامٍ، حَدَّثَهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصَّدَقَةِ مَا كَانَ عَنْ ظَهْرِ غِنًى وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى وَابْدَأْ بِمَنْ تَعُولُ ‏"‏ ‏.‏\hadithno{2543}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Hakim bin Hizam said:"The Messenger of Allah said: "The best kind of charity is that which is given when you are rich, and the upper hand is better than the lower hand, and start with those for whom you are responsible}}
\hadithdefcmd{nasai}{2544}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، عَنِ ابْنِ وَهْبٍ، قَالَ أَنْبَأَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ الصَّدَقَةِ مَا كَانَ عَنْ ظَهْرِ غِنًى وَابْدَأْ بِمَنْ تَعُولُ ‏"‏ ‏.‏\hadithno{2544}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: "The best of charity is that which is given when you are self-sufficient, and start with those for whom you are responsible}}
\hadithdefcmd{nasai}{2545}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَزِيدَ الأَنْصَارِيَّ، يُحَدِّثُ عَنْ أَبِي مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَنْفَقَ الرَّجُلُ عَلَى أَهْلِهِ وَهُوَ يَحْتَسِبُهَا كَانَتْ لَهُ صَدَقَةً ‏"‏ ‏.‏\hadithno{2545}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Mas'ud that the Prophet said:"When a man spends on his family, seeking reward for that, that is an act of charity on his part}}
\hadithdefcmd{nasai}{2546}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَعْتَقَ رَجُلٌ مِنْ بَنِي عُذْرَةَ عَبْدًا لَهُ عَنْ دُبُرٍ، فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَلَكَ مَالٌ غَيْرُهُ ‏"‏ ‏.‏ قَالَ لاَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَشْتَرِيهِ مِنِّي ‏"‏ ‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ الْعَدَوِيُّ بِثَمَانِمِائَةِ دِرْهَمٍ فَجَاءَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَفَعَهَا إِلَيْهِ ثُمَّ قَالَ ‏"‏ ابْدَأْ بِنَفْسِكَ فَتَصَدَّقْ عَلَيْهَا فَإِنْ فَضَلَ شَىْءٌ فَلأَهْلِكَ فَإِنْ فَضَلَ شَىْءٌ عَنْ أَهْلِكَ فَلِذِي قَرَابَتِكَ فَإِنْ فَضَلَ عَنْ ذِي قَرَابَتِكَ شَىْءٌ فَهَكَذَا وَهَكَذَا يَقُولُ بَيْنَ يَدَيْكَ وَعَنْ يَمِينِكَ وَعَنْ شِمَالِكَ ‏"‏ ‏.‏\hadithno{2546}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Jabir said:"A man from Banu 'Udhrah declared that a slave of his would become free after he died. News of that reached the Messenger of Allah and he said: 'Do you have any property besides him?' He said: 'No.' The Messenger of Allah said: 'Who will buy him from me?' Nu'aim bin 'Abdullah Al-Adawi bought him for eight hundred Dirhams. The Messenger of Allah brought it (the money) and gave it to him, then he said: 'Start with yourself and if there is anything left, give it to our family. If there is anything left after your family (has been taken care of), then give it to your relatives. If there is anything left after your relatives (have been taken care of), then (give it) to such and such, saying: 'In front of you and to your right and to your left."' (Shih)}}
\hadithdefcmd{nasai}{2547}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ طَاوُسٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، ثُمَّ قَالَ حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مَثَلَ الْمُنْفِقِ الْمُتَصَدِّقِ وَالْبَخِيلِ كَمَثَلِ رَجُلَيْنِ عَلَيْهِمَا جُبَّتَانِ أَوْ جُنَّتَانِ مِنْ حَدِيدٍ مِنْ لَدُنْ ثُدِيِّهِمَا إِلَى تَرَاقِيهِمَا فَإِذَا أَرَادَ الْمُنْفِقُ أَنْ يُنْفِقَ اتَّسَعَتْ عَلَيْهِ الدِّرْعُ أَوْ مَرَّتْ حَتَّى تُجِنَّ بَنَانَهُ وَتَعْفُوَ أَثَرَهُ وَإِذَا أَرَادَ الْبَخِيلُ أَنْ يُنْفِقَ قَلَصَتْ وَلَزِمَتْ كُلُّ حَلْقَةٍ مَوْضِعَهَا حَتَّى أَخَذَتْهُ بِتَرْقُوَتِهِ أَوْ بِرَقَبَتِهِ ‏"‏ ‏.‏ يَقُولُ أَبُو هُرَيْرَةَ أَشْهَدُ أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُوَسِّعُهَا فَلاَ تَتَّسِعُ ‏.‏ قَالَ طَاوُسٌ سَمِعْتُ أَبَا هُرَيْرَةَ يُشِيرُ بِيَدِهِ وَهُوَ يُوَسِّعُهَا وَلاَ تَتَوَسَّعُ ‏.‏\hadithno{2547}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: "The parable of the one who spends and give in charity, and the one who is miserly, is that of two men wearing coats of mail, with their hands pressed closely to their breasts and their collarbones. When the one who spends wants to give charity, the (coat of mail) expends so much that it covers his fingertips and obliterates his traces. But when the miser wants to give, the (coat of mail) contracts and every ring grips the place where it is, and his hands are tied up to his collarbone."' Abu Hurairah says: 'I swear that he saw the Messenger trying to expand it but it did not." Tawus said: "I heard Abu Hurairah said: "I heard Abu Hurairah illustrating with his hand trying to expand it but it did not." (Sahaih)}}
\hadithdefcmd{nasai}{2548}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَثَلُ الْبَخِيلِ وَالْمُتَصَدِّقِ مَثَلُ رَجُلَيْنِ عَلَيْهِمَا جُنَّتَانِ مِنْ حَدِيدٍ قَدِ اضْطَرَّتْ أَيْدِيَهُمَا إِلَى تَرَاقِيهِمَا فَكُلَّمَا هَمَّ الْمُتَصَدِّقُ بِصَدَقَةٍ اتَّسَعَتْ عَلَيْهِ حَتَّى تُعَفِّيَ أَثَرَهُ وَكُلَّمَا هَمَّ الْبَخِيلُ بِصَدَقَةٍ تَقَبَّضَتْ كُلُّ حَلْقَةٍ إِلَى صَاحِبَتِهَا وَتَقَلَّصَتْ عَلَيْهِ وَانْضَمَّتْ يَدَاهُ إِلَى تَرَاقِيهِ ‏"‏ ‏.‏ وَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ فَيَجْتَهِدُ أَنْ يُوَسِّعَهَا فَلاَ تَتَّسِعُ ‏"‏ ‏.‏\hadithno{2548}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"The parable of the miser and the one who gives in charity is that of two men wearing coats of mail with their hands tied to their collarbones. Every time the one who gives thinks of giving in charity, the (coat of mail) expands until it obliterates his traces, and every time the miser thinks of giving charity, every circle (of the coat of mail) contracts and sticks to him, and his hand is tied up to his collarbones." I heard the Messenger of Allah say: "He tries to expand it, but he cannot}}
\hadithdefcmd{nasai}{2549}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ أُمَيَّةَ بْنِ هِنْدٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، قَالَ كُنَّا يَوْمًا فِي الْمَسْجِدِ جُلُوسًا وَنَفَرٌ مِنَ الْمُهَاجِرِينَ وَالأَنْصَارِ فَأَرْسَلْنَا رَجُلاً إِلَى عَائِشَةَ لِيَسْتَأْذِنَ فَدَخَلْنَا عَلَيْهَا قَالَتْ دَخَلَ عَلَىَّ سَائِلٌ مَرَّةً وَعِنْدِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَمَرْتُ لَهُ بِشَىْءٍ ثُمَّ دَعَوْتُ بِهِ فَنَظَرْتُ إِلَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا تُرِيدِينَ أَنْ لاَ يَدْخُلَ بَيْتَكِ شَىْءٌ وَلاَ يَخْرُجَ إِلاَّ بِعِلْمِكِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ مَهْلاً يَا عَائِشَةُ لاَ تُحْصِي فَيُحْصِيَ اللَّهُ عَزَّ وَجَلَّ عَلَيْكِ ‏"‏ ‏.‏\hadithno{2549}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Umamah bin Sahl bin Hunaif said:"One day we were sitting in the Masjid with a group of the Muhajirin and Ansar, We sent a man to 'Aishah to ask permission to come to her. She said: 'A beggar came in to me one day when the Messenger of Allah was present, and I ordered that he be given something, then I called for it and looked at it. The Messenger of Allah said: Do you want that nothing should enter or leave your house without your knowledge? I said: 'Yes.' He said: "Don't be hasty, O 'Aishah. Do not count what you give, otherwise Allah will count what He gives to you}}
\hadithdefcmd{nasai}{2550}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ لاَ تُحْصِي فَيُحْصِيَ اللَّهُ عَزَّ وَجَلَّ عَلَيْكِ ‏"‏ ‏.‏\hadithno{2550}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Asma' bint Abi Bakr that the Prophet said to her:"Do not count what you give, otherwise Allah, the Mighty and Sublime, will count what He gives to you}}
\hadithdefcmd{nasai}{2551}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، عَنْ حَجَّاجٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا جَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا نَبِيَّ اللَّهِ لَيْسَ لِي شَىْءٌ إِلاَّ مَا أَدْخَلَ عَلَىَّ الزُّبَيْرُ فَهَلْ عَلَىَّ جُنَاحٌ فِي أَنْ أَرْضَخَ مِمَّا يُدْخِلُ عَلَىَّ فَقَالَ ‏ "‏ ارْضَخِي مَا اسْتَطَعْتِ وَلاَ تُوكِي فَيُوكِيَ اللَّهُ عَزَّ وَجَلَّ عَلَيْكِ ‏"‏ ‏.‏\hadithno{2551}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Asma' bint Abi Bakr that she came to the Prophet and said:"O Prophet of Allah, I do not have anything but that which Az-Zubair brings to me. Is there any sin on me if I give a small amount of that which he brings to me?" He said: Give whatever you can, and do not withhold what you have, lest Allah withhold provision from you}}
\hadithdefcmd{nasai}{2552}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، عَنْ خَالِدٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْمُحِلِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اتَّقُوا النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ ‏"‏ ‏.‏\hadithno{2552}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Adiyy bin Hatim that the Prophet said:"Protect yourselves from the Fire, even with half a date}}
\hadithdefcmd{nasai}{2553}{أَنْبَأَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، أَنَّ عَمْرَو بْنَ مُرَّةَ، حَدَّثَهُمْ عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّارَ فَأَشَاحَ بِوَجْهِهِ وَتَعَوَّذَ مِنْهَا ذَكَرَ شُعْبَةُ أَنَّهُ فَعَلَهُ ثَلاَثَ مَرَّاتٍ - ثُمَّ قَالَ ‏ "‏ اتَّقُوا النَّارَ وَلَوْ بِشِقِّ التَّمْرَةِ فَإِنْ لَمْ تَجِدُوا فَبِكَلِمَةٍ طَيِّبَةٍ ‏"‏ ‏.‏\hadithno{2553}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"The Messenger of Allah mentioned the Fire, and he turned his face away (as if seeing it), and sought refuge with Allah from it." (One of the narrators) Shu'bah said: "He did that three times, then he said: 'Protect yourselves from the Fire even with half a date, and if you cannot find that, then with a good word}}
\hadithdefcmd{nasai}{2554}{أَخْبَرَنَا أَزْهَرُ بْنُ جَمِيلٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ وَذَكَرَ عَوْنُ بْنُ أَبِي جُحَيْفَةَ قَالَ سَمِعْتُ الْمُنْذِرَ بْنَ جَرِيرٍ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي صَدْرِ النَّهَارِ فَجَاءَ قَوْمٌ عُرَاةً حُفَاةً مُتَقَلِّدِي السُّيُوفِ عَامَّتُهُمْ مِنْ مُضَرَ بَلْ كُلُّهُمْ مِنْ مُضَرَ فَتَغَيَّرَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم لِمَا رَأَى بِهِمْ مِنَ الْفَاقَةِ فَدَخَلَ ثُمَّ خَرَجَ فَأَمَرَ بِلاَلاً فَأَذَّنَ فَأَقَامَ الصَّلاَةَ فَصَلَّى ثُمَّ خَطَبَ فَقَالَ ‏"‏ ‏\{‏ يَا أَيُّهَا النَّاسُ اتَّقُوا رَبَّكُمُ الَّذِي خَلَقَكُمْ مِنْ نَفْسٍ وَاحِدَةٍ وَخَلَقَ مِنْهَا زَوْجَهَا وَبَثَّ مِنْهُمَا رِجَالاً كَثِيرًا وَنِسَاءً وَاتَّقُوا اللَّهَ الَّذِي تَسَاءَلُونَ بِهِ وَالأَرْحَامَ إِنَّ اللَّهَ كَانَ عَلَيْكُمْ رَقِيبًا ‏\}‏ وَ ‏\{‏ اتَّقُوا اللَّهَ وَلْتَنْظُرْ نَفْسٌ مَا قَدَّمَتْ لِغَدٍ ‏\}‏ تَصَدَّقَ رَجُلٌ مِنْ دِينَارِهِ مِنْ دِرْهَمِهِ مِنْ ثَوْبِهِ مِنْ صَاعِ بُرِّهِ مِنْ صَاعِ تَمْرِهِ - حَتَّى قَالَ - وَلَوْ بِشِقِّ تَمْرَةٍ ‏"‏ ‏.‏ فَجَاءَ رَجُلٌ مِنَ الأَنْصَارِ بِصُرَّةٍ كَادَتْ كَفُّهُ تُعْجِزُ عَنْهَا بَلْ قَدْ عَجَزَتْ ثُمَّ تَتَابَعَ النَّاسُ حَتَّى رَأَيْتُ كَوْمَيْنِ مِنْ طَعَامٍ وَثِيَابٍ حَتَّى رَأَيْتُ وَجْهَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَتَهَلَّلُ كَأَنَّهُ مُذْهَبَةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ سَنَّ فِي الإِسْلاَمِ سُنَّةً حَسَنَةً فَلَهُ أَجْرُهَا وَأَجْرُ مَنْ عَمِلَ بِهَا مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أُجُورِهِمْ شَيْئًا وَمَنْ سَنَّ فِي الإِسْلاَمِ سُنَّةً سَيِّئَةً فَعَلَيْهِ وِزْرُهَا وَوِزْرُ مَنْ عَمِلَ بِهَا مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أَوْزَارِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{2554}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Al-Mundhir bin Jarir narrated that his father said:"While we were with the Messenger of Allah in the early hours of the morning, some people came who were naked and barefoot, with their swords hung (around their necks). Most of them, may all of them, belonged to the tribe of Mudar. The face of the Messenger of Allah changed when he saw them in poverty. He went in (to his house) then he came out and ordered Bilah to call the Adhan and then the Iqamah. He (the Prophet) prayed, tjem je addressed te,, (reciting the Verses): 'O mankind! Be dutiful to your Lord, Who created you from a single person (Adam), and from him(Adam) He created his wife [Hawwa (Eve)], and from them both He created many men and women: and fear Allah through Whom you demand (your mutual right), and (do not cut the relations of) the wombs (kinship). Surely, Allah is Ever and All-Watcher over you.' [1] and: 'Fear Allah and keep your duty to Him. And let every person look to what he has sent forth for the morrow,' [2] Then they gave in charity, some giving a Dinar, others a Dirham, or a garment, or a Sa' of wheat or, a Sa' of dates, until he said: 'Even half a date.' A man from among the Ansar came with a bag of money which his hands could hardly lift. The people followed one another (in giving charity) until I saw two heaps of food and clothing, and I saw the face of the Messenger of Allah shining like gold (with joy). The Messenger of Allah said: 'Whoever sets a good precedent in Islam, he will have the reward for that, and the reward of those who acted in accordance with it, without that detracting from their reward in the slightest. And whoever sets an evil precedent in Islam, he will have a burden of sin for that, and the burden of those who acted in accordance with it, without that detracting from their burden in the slightest}}
\hadithdefcmd{nasai}{2555}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، عَنْ حَارِثَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَصَدَّقُوا فَإِنَّهُ سَيَأْتِي عَلَيْكُمْ زَمَانٌ يَمْشِي الرَّجُلُ بِصَدَقَتِهِ فَيَقُولُ الَّذِي يُعْطَاهَا لَوْ جِئْتَ بِهَا بِالأَمْسِ قَبِلْتُهَا فَأَمَّا الْيَوْمَ فَلاَ ‏"‏ ‏.‏\hadithno{2555}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Harithah said:"I heard the Messenger of Allah (ﷺ) say: 'Give charity, for there will come a time when a man will walk about with his charity, and the one to whom he wants to give it will say: If you had brought it yesterday I would have accepted it, but today (I have no need of it)}}
\hadithdefcmd{nasai}{2556}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ أَخْبَرَنِي أَبُو بُرْدَةَ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اشْفَعُوا تُشَفَّعُوا وَيَقْضِي اللَّهُ عَزَّ وَجَلَّ عَلَى لِسَانِ نَبِيِّهِ مَا شَاءَ ‏"‏ ‏.‏\hadithno{2556}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa that the Prophet said:"Intercede and your intercession may be accepted, and Allah, the Mighty and Sublime, decrees on the lips of His Prophet whatsoever He will}}
\hadithdefcmd{nasai}{2557}{أَخْبَرَنَا هَارُونُ بْنُ سَعِيدٍ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ ابْنِ مُنَبِّهٍ، عَنْ أَخِيهِ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الرَّجُلَ لَيَسْأَلُنِي الشَّىْءَ فَأَمْنَعُهُ حَتَّى تَشْفَعُوا فِيهِ فَتُؤْجَرُوا ‏"‏ ‏.‏ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اشْفَعُوا تُؤْجَرُوا ‏"‏ ‏.‏\hadithno{2557}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mu'awiyah bin Sufyan that the Messenger of Allah said:"A man may come and ask for something, and I refuse until you intercede, so that you will be rewarded." And the Messenger of Allah said: "Intercede and you will be rewarded}}
\hadithdefcmd{nasai}{2558}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيُّ، عَنِ ابْنِ جَابِرٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنَ الْغَيْرَةِ مَا يُحِبُّ اللَّهُ عَزَّ وَجَلَّ وَمِنْهَا مَا يُبْغِضُ اللَّهُ عَزَّ وَجَلَّ وَمِنَ الْخُيَلاَءِ مَا يُحِبُّ اللَّهُ عَزَّ وَجَلَّ وَمِنْهَا مَا يُبْغِضُ اللَّهُ عَزَّ وَجَلَّ فَأَمَّا الْغَيْرَةُ الَّتِي يُحِبُّ اللَّهُ عَزَّ وَجَلَّ فَالْغَيْرَةُ فِي الرِّيبَةِ وَأَمَّا الْغَيْرَةُ الَّتِي يُبْغِضُ اللَّهُ عَزَّ وَجَلَّ فَالْغَيْرَةُ فِي غَيْرِ رِيبَةٍ وَالاِخْتِيَالُ الَّذِي يُحِبُّ اللَّهُ عَزَّ وَجَلَّ اخْتِيَالُ الرَّجُلِ بِنَفْسِهِ عِنْدَ الْقِتَالِ وَعِنْدَ الصَّدَقَةِ وَالاِخْتِيَالِ الَّذِي يُبْغِضُ اللَّهُ عَزَّ وَجَلَّ الْخُيَلاَءُ فِي الْبَاطِلِ ‏"‏ ‏.‏\hadithno{2558}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Jabir, from his father, that the Messenger of Allah said:"There is a kind of protective Jealousy that Allah, the Mighty and Sublime, loves anda kind that Allah, the Mighty and Sublime, hates, and a kind of pride that Allah, the Mighty and Sublime, loves and a kind that Allah, the Mighty and Sublime, hates, As for the protective jealousy that Allah, the Mighty and Sublime, loves, it is protective jealousy when there are grounds for suspicion. As for the protective jealousy that Allah, the Mighty and Sublime, hates, it is protective jealousy when there are no grounds for suspicion. As for the pride that Allah, the Mighty and Sublime, loves, it is when a man feels proud of himself when fighting and when giving charity. And as for the kind of pride that Allah, the Mighty and Sublime, hates, it is pride in doing wrong}}
\hadithdefcmd{nasai}{2559}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُوا وَتَصَدَّقُوا وَالْبَسُوا فِي غَيْرِ إِسْرَافٍ وَلاَ مَخِيلَةٍ ‏"‏ ‏.‏\hadithno{2559}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"Eat, give charity and clothe yourselves, without being extravagant, and without showing off}}
\hadithdefcmd{nasai}{2560}{أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ الْهَيْثَمِ بْنِ عُثْمَانَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ بُرَيْدِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمُؤْمِنُ لِلْمُؤْمِنِ كَالْبُنْيَانِ يَشُدُّ بَعْضُهُ بَعْضًا ‏"‏ ‏.‏ وَقَالَ ‏"‏ الْخَازِنُ الأَمِينُ الَّذِي يُعْطِي مَا أُمِرَ بِهِ طَيِّبًا بِهَا نَفْسُهُ أَحَدُ الْمُتَصَدِّقَيْنِ ‏"‏ ‏.‏\hadithno{2560}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah said: 'The believers are like a building they support one another.' And he said: "The trustworthy storekeeper who gives that which he has been commanded to give, and is happy with what he is doing, is one of the two giving charity}}
\hadithdefcmd{nasai}{2561}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ كَثِيرِ بْنِ مُرَّةَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْجَاهِرُ بِالْقُرْآنِ كَالْجَاهِرِ بِالصَّدَقَةِ وَالْمُسِرُّ بِالْقُرْآنِ كَالْمُسِرِّ بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{2561}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that the Messenger of Allah said:"The one who recites the Qur'an loudly is like one who gives charity openly, and the one who recites the Qur'an quietly is like one who gives charity in secret}}
\hadithdefcmd{nasai}{2562}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا عُمَرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَسَارٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يَنْظُرُ اللَّهُ عَزَّ وَجَلَّ إِلَيْهِمْ يَوْمَ الْقِيَامَةِ الْعَاقُّ لِوَالِدَيْهِ وَالْمَرْأَةُ الْمُتَرَجِّلَةُ وَالدَّيُّوثُ وَثَلاَثَةٌ لاَ يَدْخُلُونَ الْجَنَّةَ الْعَاقُّ لِوَالِدَيْهِ وَالْمُدْمِنُ عَلَى الْخَمْرِ وَالْمَنَّانُ بِمَا أَعْطَى ‏"‏ ‏.‏\hadithno{2562}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Salim bin 'Abdullah that his father said:"The Messenger of Allah said: "There are three at whom Allah will not look on the Day of Resurrection: The one who disobeys his parents, the woman who imitates men in her outward appearance, and the cuckold. And there are three who will not enter Paradise: The one who disobeys his parents, the drunkard, and the one who reminds people of what he has given them}}
\hadithdefcmd{nasai}{2563}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ الْمُدْرِكِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ وَلاَ يَنْظُرُ إِلَيْهِمْ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ ‏"‏ ‏.‏ فَقَرَأَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ أَبُو ذَرٍّ خَابُوا وَخَسِرُوا خَابُوا وَخَسِرُوا ‏.‏ قَالَ ‏"‏ الْمُسْبِلُ إِزَارَهُ وَالْمُنَفِّقُ سِلْعَتَهُ بِالْحَلِفِ الْكَاذِبِ وَالْمَنَّانُ عَطَاءَهُ ‏"‏ ‏.‏\hadithno{2563}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Dharr that the Prophet said:"There are three to whom Allah will not speak on the Day of Resurrection, or look at them, or sanctify them, and theirs will be a painful torment." The Messenger of Allah repeated and Abu Dharr said: "May they be lost and doomed." He said: "The one who lets his garment hang beneath his ankles, a vendor who tries to sell his product by means of false oaths, and the one who reminds people of what he has given them}}
\hadithdefcmd{nasai}{2564}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، قَالَ سَمِعْتُ سُلَيْمَانَ، - وَهُوَ الأَعْمَشُ - عَنْ سُلَيْمَانَ بْنِ مُسْهِرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ وَلاَ يَنْظُرُ إِلَيْهِمْ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ الْمَنَّانُ بِمَا أَعْطَى وَالْمُسْبِلُ إِزَارَهُ وَالْمُنَفِّقُ سِلْعَتَهُ بِالْحَلِفِ الْكَاذِبِ ‏"‏ ‏.‏\hadithno{2564}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah said: "There are three to whom of Allah will not speak on the Day of Resurrection or look at them or purify them, and theirs will be a painful torment: the one who reminds people of what he has given them, the one who lets his garment hang beneath his ankles, and a vendor who tries to sell his product by means of false oaths}}
\hadithdefcmd{nasai}{2565}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، ح وَأَنْبَأَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ بُجَيْدٍ الأَنْصَارِيِّ، عَنْ جَدَّتِهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رُدُّوا السَّائِلَ وَلَوْ بِظِلْفٍ ‏"‏ ‏.‏ فِي حَدِيثِ هَارُونَ مُحْرَقٍ ‏.‏\hadithno{2565}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Bujaid Al-Ansari from his grandmother that the Messenger of Allah said:"Respond to the one who asks even with a sheep's foot." According to the narration of Harun: "With a sheep's burned foot}}
\hadithdefcmd{nasai}{2566}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ بَهْزَ بْنَ حَكِيمٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَأْتِي رَجُلٌ مَوْلاَهُ يَسْأَلُهُ مِنْ فَضْلٍ عِنْدَهُ فَيَمْنَعُهُ إِيَّاهُ إِلاَّ دُعِيَ لَهُ يَوْمَ الْقِيَامَةِ شُجَاعٌ أَقْرَعُ يَتَلَمَّظُ فَضْلَهُ الَّذِي مَنَعَ ‏"‏ ‏.‏\hadithno{2566}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father that his grandfather said:"No man comes to his Mawla and asks him for something from the surplus of what he has, and he withholds it from him, but on the Day of Resurrection a bald-headed Shuja'a [1] will be called to him and will be licking the surplus that he withheld}}
\hadithdefcmd{nasai}{2567}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اسْتَعَاذَ بِاللَّهِ فَأَعِيذُوهُ وَمَنْ سَأَلَكُمْ بِاللَّهِ فَأَعْطُوهُ وَمَنِ اسْتَجَارَ بِاللَّهِ فَأَجِيرُوهُ وَمَنْ آتَى إِلَيْكُمْ مَعْرُوفًا فَكَافِئُوهُ فَإِنْ لَمْ تَجِدُوا فَادْعُوا لَهُ حَتَّى تَعْلَمُوا أَنْ قَدْ كَافَأْتُمُوهُ ‏"‏ ‏.‏\hadithno{2567}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'Whoever seeks refuge with (the name of) Allah, grant him refuge; whoever asks of you in (the name of) Allah, give him; whoever seeks protection with (the name of Allah, give him protection. Whoever does you a favor, then reciprocate, and if you cannot, then supplicate for him until you think that you have repaid him)}}
\hadithdefcmd{nasai}{2568}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ بَهْزَ بْنَ حَكِيمٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ مَا أَتَيْتُكَ حَتَّى حَلَفْتُ أَكْثَرَ مِنْ عَدَدِهِنَّ - لأَصَابِعِ يَدَيْهِ - أَلاَّ آتِيَكَ وَلاَ آتِيَ دِينَكَ وَإِنِّي كُنْتُ امْرَأً لاَ أَعْقِلُ شَيْئًا إِلاَّ مَا عَلَّمَنِي اللَّهُ وَرَسُولُهُ وَإِنِّي أَسْأَلُكَ بِوَجْهِ اللَّهِ عَزَّ وَجَلَّ بِمَا بَعَثَكَ رَبُّكَ إِلَيْنَا قَالَ ‏"‏ بِالإِسْلاَمِ ‏"‏ ‏.‏ قَالَ قُلْتُ وَمَا آيَاتُ الإِسْلاَمِ قَالَ ‏"‏ أَنْ تَقُولَ أَسْلَمْتُ وَجْهِيَ إِلَى اللَّهِ عَزَّ وَجَلَّ وَتَخَلَّيْتُ وَتُقِيمَ الصَّلاَةَ وَتُؤْتِيَ الزَّكَاةَ كُلُّ مُسْلِمٍ عَلَى مُسْلِمٍ مُحَرَّمٌ أَخَوَانِ نَصِيرَانِ لاَ يَقْبَلُ اللَّهُ عَزَّ وَجَلَّ مِنْ مُشْرِكٍ بَعْدَ مَا أَسْلَمَ عَمَلاً أَوْ يُفَارِقَ الْمُشْرِكِينَ إِلَى الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{2568}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Bahz bin Hakim narrated from his father that his grandfather said:"I said: 'O Prophet of Allah! I did not come to you until I had sworn more that this many times' - the number of fingers on his hands - 'that I would never come to you or follow your religion. I am a man who does not know anything except that which Allah and His Messenger teach me. I ask you by the face of Allah, the Mighty and Sublime, with what has your Lord sent you to us? He said: 'With Islam.' I said: What are the signs of Islam? He said; To say: I submit my face to Allah and give up Shirk, and, to establish the Salah and to pay Zakah. Each Muslim is sacred and inviolable to his fellow Muslim; they support one another. Allah does not accept my deed from an idolater after he becomes a Muslim, until he departs from the idolaters and joins the Muslims}}
\hadithdefcmd{nasai}{2569}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، قَالَ أَنْبَأَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ خَالِدٍ الْقَارِظِيِّ، عَنْ إِسْمَاعِيلَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ النَّاسِ مَنْزِلاً ‏"‏ ‏.‏ قُلْنَا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ رَجُلٌ آخِذٌ بِرَأْسِ فَرَسِهِ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ حَتَّى يَمُوتَ أَوْ يُقْتَلَ وَأُخْبِرُكُمْ بِالَّذِي يَلِيهِ ‏"‏ ‏.‏ قُلْنَا نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ رَجُلٌ مُعْتَزِلٌ فِي شِعْبٍ يُقِيمُ الصَّلاَةَ وَيُؤْتِي الزَّكَاةَ وَيَعْتَزِلُ شُرُورَ النَّاسِ وَأُخْبِرُكُمْ بِشَرِّ النَّاسِ ‏"‏ ‏.‏ قُلْنَا نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ الَّذِي يُسْأَلُ بِاللَّهِ عَزَّ وَجَلَّ وَلاَ يُعْطِي بِهِ ‏"‏ ‏.‏\hadithno{2569}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah said:"Shall I not tell you of the best of the people in status?" We said: "Yes. O Messenger of Allah!" He said: "A man who rides his horse in the cause of Allah, the Mighty and Sublime, until he dies or is killed. Shall I not tell you of the one who comes after him (in status)?" We said: "Yes, O Messenger of Allah!" He said; "A man who withdraws to a mountain pass and establishes Salah, and pays Zakah, and keeps away from the evil of people. Shall I not tell you of the worst of people?" We said: "Yes, O Messenger of Allah!" He said: "The one who asks for the sake of Allah, the Mighty and Sublime, but does not give (when he is asked) for His sake}}
\hadithdefcmd{nasai}{2570}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ سَمِعْتُ رِبْعِيًّا، يُحَدِّثُ عَنْ زَيْدِ بْنِ ظَبْيَانَ، رَفَعَهُ إِلَى أَبِي ذَرٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ يُحِبُّهُمُ اللَّهُ عَزَّ وَجَلَّ وَثَلاَثَةٌ يُبْغِضُهُمُ اللَّهُ عَزَّ وَجَلَّ أَمَّا الَّذِينَ يُحِبُّهُمُ اللَّهُ عَزَّ وَجَلَّ فَرَجُلٌ أَتَى قَوْمًا فَسَأَلَهُمْ بِاللَّهِ عَزَّ وَجَلَّ وَلَمْ يَسْأَلْهُمْ بِقَرَابَةٍ بَيْنَهُ وَبَيْنَهُمْ فَمَنَعُوهُ فَتَخَلَّفَهُ رَجُلٌ بِأَعْقَابِهِمْ فَأَعْطَاهُ سِرًّا لاَ يَعْلَمُ بِعَطِيَّتِهِ إِلاَّ اللَّهُ عَزَّ وَجَلَّ وَالَّذِي أَعْطَاهُ وَقَوْمٌ سَارُوا لَيْلَتَهُمْ حَتَّى إِذَا كَانَ النَّوْمُ أَحَبَّ إِلَيْهِمْ مِمَّا يُعْدَلُ بِهِ نَزَلُوا فَوَضَعُوا رُءُوسَهُمْ فَقَامَ يَتَمَلَّقُنِي وَيَتْلُو آيَاتِي وَرَجُلٌ كَانَ فِي سَرِيَّةٍ فَلَقُوا الْعَدُوَّ فَهُزِمُوا فَأَقْبَلَ بِصَدْرِهِ حَتَّى يُقْتَلَ أَوْ يَفْتَحَ اللَّهُ لَهُ وَالثَّلاَثَةُ الَّذِينَ يُبْغِضُهُمُ اللَّهُ عَزَّ وَجَلَّ الشَّيْخُ الزَّانِي وَالْفَقِيرُ الْمُخْتَالُ وَالْغَنِيُّ الظَّلُومُ ‏"‏ ‏.‏\hadithno{2570}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zaid bin Zibyan, and attributed to Abu Dharr, that the Prophet said:"There are three whom Allah, the Mighty and Sublime, loves, and three whom Allah, the Mighty and Sublime, hates. As for those whom Allah, the Mighty and Sublime, loves: A man who comes to some people and asks (to be given something) for the sake of Allah, the Mighty and Sublime, and not for the sake of their relationship, but they do not give him. So one man stayed behind and gave to him in secret, and no one knew of his giving except Allah, the Mighty and Sublime, and the one to whom he gave it. People who travel all night until sleep becomes dearer to them than anything that may be equivalent to it, so they lay down their heads (and slept). Then a man among them got up and started praying to Me and beseeching Me, reciting MY Ayat. And a man who was on a campaign and met the enemy and they fled, but he went forward (pursuing them) until he was killed or Allah, the Mighty and Sublime, granted victory to him. And three whom Allah hates are the old man who commits Zina, the poor man who shows off, and the rich man who is unjust}}
\hadithdefcmd{nasai}{2571}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ الْمِسْكِينُ الَّذِي تَرُدُّهُ التَّمْرَةُ وَالتَّمْرَتَانِ وَاللُّقْمَةُ وَاللُّقْمَتَانِ إِنَّ الْمِسْكِينَ الْمُتَعَفِّفُ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏ لاَ يَسْأَلُونَ النَّاسَ إِلْحَافًا ‏\}‏ ‏"‏ ‏.‏\hadithno{2571}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the messenger of Allah said:"The poor man (Miskin) is not the one who leaves if you give him a date or two, or a morsel or two. Rather the poor man is the one who refrains from asking. Recite if you wish: "They do not beg of people at all}}
\hadithdefcmd{nasai}{2572}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ الْمِسْكِينُ بِهَذَا الطَّوَّافِ الَّذِي يَطُوفُ عَلَى النَّاسِ تَرُدُّهُ اللُّقْمَةُ وَاللُّقْمَتَانِ وَالتَّمْرَةُ وَالتَّمْرَتَانِ ‏"‏ ‏.‏ قَالُوا فَمَا الْمِسْكِينُ قَالَ ‏"‏ الَّذِي لاَ يَجِدُ غِنًى يُغْنِيهِ وَلاَ يُفْطَنُ لَهُ فَيُتَصَدَّقَ عَلَيْهِ وَلاَ يَقُومُ فَيَسْأَلَ النَّاسَ ‏"‏ ‏.‏\hadithno{2572}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"The poor man (Miskin) is not the one who goes around asking people and they send him away with a morsel or two, of a date or two. "They said: "Then what does poor (Mishkin) mean?" He said: "The one who does not possess independence of means and no one notices him to give charity to him, and he does not stand and ask of people}}
\hadithdefcmd{nasai}{2573}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ الْمِسْكِينُ الَّذِي تَرُدُّهُ الأُكْلَةُ وَالأُكْلَتَانِ وَالتَّمْرَةُ وَالتَّمْرَتَانِ ‏"‏ ‏.‏ قَالُوا فَمَا الْمِسْكِينُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الَّذِي لاَ يَجِدُ غِنًى وَلاَ يَعْلَمُ النَّاسُ حَاجَتَهُ فَيُتَصَدَّقَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2573}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"The poor man (Miskin) is not the one who leaves if you give him a morsel or two, or a date or two." They said: "Then who is the Miskin, O Messenger of Allah?" He said: "The one who does not possess independence of means, and the people do not know of his need, so that they could give him charity}}
\hadithdefcmd{nasai}{2574}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بُجَيْدٍ، عَنْ جَدَّتِهِ أُمِّ بُجَيْدٍ، وَكَانَتْ، مِمَّنْ بَايَعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَّهَا قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ الْمِسْكِينَ لَيَقُومُ عَلَى بَابِي فَمَا أَجِدُ لَهُ شَيْئًا أُعْطِيهِ إِيَّاهُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ لَمْ تَجِدِي شَيْئًا تُعْطِينَهُ إِيَّاهُ إِلاَّ ظِلْفًا مُحْرَقًا فَادْفَعِيهِ إِلَيْهِ ‏"‏ ‏.‏\hadithno{2574}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin Bujaid that his grandmother Umm Bujaid -who was one of those who gave the oath of allegiance to the Messenger of Allah - said to the Messenger of Allah:" The poor man stands at my door, and I cannot find anything to give him. " The Messenger of Allah said to her: "If you cannot find anything to give to him except a sheep's burned foot, then give it to him}}
\hadithdefcmd{nasai}{2575}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ الشَّيْخُ الزَّانِي وَالْعَائِلُ الْمَزْهُوُّ وَالإِمَامُ الْكَذَّابُ ‏"‏ ‏.‏\hadithno{2575}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: "There are three to whom Allah, it Mighty and Sublime, with not speak on the Day of Resurrection: An old man who commits adultery, a poor man who is arrogant, and an Imam who tells lies}}
\hadithdefcmd{nasai}{2576}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا عَارِمٌ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَرْبَعَةٌ يُبْغِضُهُمُ اللَّهُ عَزَّ وَجَلَّ الْبَيَّاعُ الْحَلاَّفُ وَالْفَقِيرُ الْمُخْتَالُ وَالشَّيْخُ الزَّانِي وَالإِمَامُ الْجَائِرُ ‏"‏ ‏.‏\hadithno{2576}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"There are four whom Allah, the Mighty and Sublime, hates: The vendor who sells his wares by means of false oaths, the poor man who shows off, the old man who commits Zina and the Imam who is unjust}}
\hadithdefcmd{nasai}{2577}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ السَّاعِي عَلَى الأَرْمَلَةِ وَالْمِسْكِينِ كَالْمُجَاهِدِ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2577}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: "The one who strives to sponsor a widow or a poor person is like the one who strives in Jihad in the cause of Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{2578}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَعَثَ عَلِيٌّ وَهُوَ بِالْيَمَنِ بِذُهَيْبَةٍ بِتُرْبَتِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَسَمَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَرْبَعَةِ نَفَرٍ الأَقْرَعِ بْنِ حَابِسٍ الْحَنْظَلِيِّ وَعُيَيْنَةَ بْنِ بَدْرٍ الْفَزَارِيِّ وَعَلْقَمَةَ بْنِ عُلاَثَةَ الْعَامِرِيِّ ثُمَّ أَحَدِ بَنِي كِلاَبٍ وَزَيْدٍ الطَّائِيِّ ثُمَّ أَحَدِ بَنِي نَبْهَانَ فَغَضِبَتْ قُرَيْشٌ وَقَالَ مَرَّةً أُخْرَى صَنَادِيدُ قُرَيْشٍ فَقَالُوا تُعْطِي صَنَادِيدَ نَجْدٍ وَتَدَعُنَا ‏.‏ قَالَ ‏"‏ إِنَّمَا فَعَلْتُ ذَلِكَ لأَتَأَلَّفَهُمْ ‏"‏ ‏.‏ فَجَاءَ رَجُلٌ كَثُّ اللِّحْيَةِ مُشْرِفُ الْوَجْنَتَيْنِ غَائِرُ الْعَيْنَيْنِ نَاتِئُ الْجَبِينِ مَحْلُوقُ الرَّأْسِ فَقَالَ اتَّقِ اللَّهَ يَا مُحَمَّدُ ‏.‏ قَالَ ‏"‏ فَمَنْ يُطِعِ اللَّهَ عَزَّ وَجَلَّ إِنْ عَصَيْتُهُ أَيَأْمَنُنِي عَلَى أَهْلِ الأَرْضِ وَلاَ تَأْمَنُونِي ‏"‏ ‏.‏ ثُمَّ أَدْبَرَ الرَّجُلُ فَاسْتَأْذَنَ رَجُلٌ مِنَ الْقَوْمِ فِي قَتْلِهِ يَرَوْنَ أَنَّهُ خَالِدُ بْنُ الْوَلِيدِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ ضِئْضِئِ هَذَا قَوْمًا يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَنَاجِرَهُمْ يَقْتُلُونَ أَهْلَ الإِسْلاَمِ وَيَدَعُونَ أَهْلَ الأَوْثَانِ يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ لَئِنْ أَدْرَكْتُهُمْ لأَقْتُلَنَّهُمْ قَتْلَ عَادٍ ‏"‏ ‏.‏\hadithno{2578}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"When he was in Yemen, Ali sent a piece of gold that was still mixed with sediment to the Messenger of Allah, and the Messenger of Allah distributed it among four people: Al-Aqra' bin Habis Al-Hanzali, 'Uyaynah bin Badr Al-Fazari, 'Alqamah bin 'Ulathah Al- 'Amiri, who was from Banu Kilab and Zaid Al-Ta'I who was from Banu Nabhan. The Quraish" - he said one time: became angry and said: 'You give to the chiefs of Najdand that, so as to soften their hearts toward Islam.' Then a man with a thick beard, prominent cheeks, and a shaven head came and said: 'Fear Allah. O Muhammad! He said: 'Who would obey Allah if I disobeyed Him? (Is it fair that) He has entrusted me with all the people of the Earth but you do not trust me?' Then the man went away, and a man from among the people, whom they (the narrators) think was Khalid bin Al-Walid, asked for permission to kill him. The Messenger of Allah said: 'Among the offspring of this man will be some people who will recite the Qur'an but it will not go any further than their throats. They will kill the Muslims but leave the idol worshippers alone, and they will passes through Islam as an arrow passes through the body of the target. If I live to see them. I will kill them all, as the people of 'Ad were killed}}
\hadithdefcmd{nasai}{2579}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، عَنْ حَمَّادٍ، عَنْ هَارُونَ بْنِ رِئَابٍ، قَالَ حَدَّثَنِي كِنَانَةُ بْنُ نُعَيْمٍ، ح وَأَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ هَارُونَ، عَنْ كِنَانَةَ بْنِ نُعَيْمٍ، عَنْ قَبِيصَةَ بْنِ مُخَارِقٍ، قَالَ تَحَمَّلْتُ حَمَالَةً فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَسَأَلْتُهُ فِيهَا فَقَالَ ‏ "‏ إِنَّ الْمَسْأَلَةَ لاَ تَحِلُّ إِلاَّ لِثَلاَثَةٍ رَجُلٍ تَحَمَّلَ بِحَمَالَةٍ بَيْنَ قَوْمٍ فَسَأَلَ فِيهَا حَتَّى يُؤَدِّيَهَا ثُمَّ يُمْسِكَ ‏"‏ ‏.‏\hadithno{2579}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Qubaisah bin Mukhariq said:"I undertook a financial responsibility. [1] Then I came to the Prophet and asked him (for help) concerning that. He said: 'Asking (for money) is not permissible except for three: A man who undertakes a financial responsibility between people; he may ask for help with that until the matter is settled, then he should refrain (from asking)}}
\hadithdefcmd{nasai}{2580}{أَخْبَرَنَا مُحَمَّدُ بْنُ النَّضْرِ بْنِ مُسَاوِرٍ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ هَارُونَ بْنِ رِئَابٍ، قَالَ حَدَّثَنِي كِنَانَةُ بْنُ نُعَيْمٍ، عَنْ قَبِيصَةَ بْنِ مُخَارِقٍ، قَالَ تَحَمَّلْتُ حَمَالَةً فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَسْأَلُهُ فِيهَا فَقَالَ ‏"‏ أَقِمْ يَا قَبِيصَةُ حَتَّى تَأْتِيَنَا الصَّدَقَةُ فَنَأْمُرَ لَكَ ‏"‏ ‏.‏ قَالَ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا قَبِيصَةُ إِنَّ الصَّدَقَةَ لاَ تَحِلُّ إِلاَّ لأَحَدِ ثَلاَثَةٍ رَجُلٍ تَحَمَّلَ حَمَالَةً فَحَلَّتْ لَهُ الْمَسْأَلَةُ حَتَّى يُصِيبَ قِوَامًا مِنْ عَيْشٍ أَوْ سِدَادًا مِنْ عَيْشٍ وَرَجُلٍ أَصَابَتْهُ جَائِحَةٌ فَاجْتَاحَتْ مَالَهُ فَحَلَّتْ لَهُ الْمَسْأَلَةُ حَتَّى يُصِيبَهَا ثُمَّ يُمْسِكَ وَرَجُلٍ أَصَابَتْهُ فَاقَةٌ حَتَّى يَشْهَدَ ثَلاَثَةٌ مِنْ ذَوِي الْحِجَا مِنْ قَوْمِهِ قَدْ أَصَابَتْ فُلاَنًا فَاقَةٌ فَحَلَّتْ لَهُ الْمَسْأَلَةُ حَتَّى يُصِيبَ قِوَامًا مِنْ عَيْشٍ أَوْ سِدَادًا مِنْ عَيْشٍ فَمَا سِوَى هَذَا مِنَ الْمَسْأَلَةِ يَا قَبِيصَةُ سُحْتٌ يَأْكُلُهَا صَاحِبُهَا سُحْتًا ‏"‏ ‏.‏\hadithno{2580}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qubaisah bin Mukhariq said:"I undertook a financial responsibility, then I came to the Prophet and asked him (for help) concerning that. He said: 'Hold on, o Qubaisah! When we get some charity we will give you some.' Then the Messenger of Allah said: 'O Qubaisah, charity is not permissible except for one of three: A man who undertakes a financial responsibility, so it is permissible for him to be given charity until he finds means to make him independent and to suffice him; a man who was stricken by calamity and his wealth was destroyed, so it is permissible for him to ask for help until he has enough to keep him going, them he should refrain from asking; and a man who is stricken with poverty and three wise men from among his own people testily that so-and-so is in desperate need, then it is permissible for him to ask for help until he finds means to make him independent and to suffice him. Asking for help in cases other than these, O Qubaisah, is unlawful, and the one who takes it is consuming it unlawfully}}
\hadithdefcmd{nasai}{2581}{أَخْبَرَنِي زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، قَالَ أَخْبَرَنِي هِشَامٌ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي هِلاَلٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَجَلَسْنَا حَوْلَهُ فَقَالَ ‏"‏ إِنَّمَا أَخَافُ عَلَيْكُمْ مِنْ بَعْدِي مَا يُفْتَحُ لَكُمْ مِنْ زَهْرَةٍ ‏"‏ ‏.‏ وَذَكَرَ الدُّنْيَا وَزِينَتَهَا فَقَالَ رَجُلٌ أَوَيَأْتِي الْخَيْرُ بِالشَّرِّ فَسَكَتَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقِيلَ لَهُ مَا شَأْنُكَ تُكَلِّمُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَلاَ يُكَلِّمُكَ ‏.‏ قَالَ وَرَأَيْنَا أَنَّهُ يُنْزَلُ عَلَيْهِ فَأَفَاقَ يَمْسَحُ الرُّحَضَاءَ وَقَالَ ‏"‏ أُشَاهِدُ السَّائِلَ إِنَّهُ لاَ يَأْتِي الْخَيْرُ بِالشَّرِّ وَإِنَّ مِمَّا يُنْبِتُ الرَّبِيعُ يَقْتُلُ أَوْ يُلِمُّ إِلاَّ آكِلَةُ الْخَضِرِ فَإِنَّهَا أَكَلَتْ حَتَّى إِذَا امْتَدَّتْ خَاصِرَتَاهَا اسْتَقْبَلَتْ عَيْنَ الشَّمْسِ فَثَلَطَتْ ثُمَّ بَالَتْ ثُمَّ رَتَعَتْ وَإِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ وَنِعْمَ صَاحِبُ الْمُسْلِمِ هُوَ إِنْ أَعْطَى مِنْهُ الْيَتِيمَ وَالْمِسْكِينَ وَابْنَ السَّبِيلِ وَإِنَّ الَّذِي يَأْخُذُهُ بِغَيْرِ حَقِّهِ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ وَيَكُونُ عَلَيْهِ شَهِيدًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2581}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah sat on the Minbar, and we sat around him. He said: 'What I fear most for you after I am gone is the (worldly) delights that will come to you.' And he spoke of this world and its attractions. A man said: 'Can good bring forth evil? 'The Messenger of Allah remained silent and it was said to him (that man): 'What is the matter with you? You speak to the Messenger of Allah when he does not speak to you? We noticed that he was receiving Revelation. Then he recovered and wiped off his sweat and said: I know what the questioner meant: he means that good never brings forth evil. But some of that which grows in the spring kills the animals or makes them sick, unless they eat Al-Khadir (kind of plant): if they eat their fill or it then turn to face the sun and then defecate and urinate and start to graze again. This wealth is fresh and sweet. Blessed is the wealth of a Muslim from which he gives to a Muslim from which he gives to orphans, the poor and wayfarers. The one who takes it unlawfully is like the one who eats but is never satisfied, and who eats but is never satisfied, and it will be a witness against him on the Day of Resurrection}}
\hadithdefcmd{nasai}{2582}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ الرَّائِحِ، عَنْ سَلْمَانَ بْنِ عَامِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الصَّدَقَةَ عَلَى الْمِسْكِينِ صَدَقَةٌ وَعَلَى ذِي الرَّحِمِ اثْنَتَانِ صَدَقَةٌ وَصِلَةٌ ‏"‏ ‏.‏\hadithno{2582}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Salman bin 'Amir that the Prophet said:"Giving charity to a poor person is charity, and (giving) to a relative is two things, charity and upholding the ties of kinship}}
\hadithdefcmd{nasai}{2583}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلنِّسَاءِ ‏"‏ تَصَدَّقْنَ وَلَوْ مِنَ حُلِيِّكُنَّ ‏"‏ ‏.‏ قَالَتْ وَكَانَ عَبْدُ اللَّهِ خَفِيفَ ذَاتِ الْيَدِ فَقَالَتْ لَهُ أَيَسَعُنِي أَنْ أَضَعَ صَدَقَتِي فِيكَ وَفِي بَنِي أَخٍ لِي يَتَامَى فَقَالَ عَبْدُ اللَّهِ سَلِي عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَإِذَا عَلَى بَابِهِ امْرَأَةٌ مِنَ الأَنْصَارِ يُقَالُ لَهَا زَيْنَبُ تَسْأَلُ عَمَّا أَسْأَلُ عَنْهُ فَخَرَجَ إِلَيْنَا بِلاَلٌ فَقُلْنَا لَهُ انْطَلِقْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَلْهُ عَنْ ذَلِكَ وَلاَ تُخْبِرْهُ مَنْ نَحْنُ ‏.‏ فَانْطَلَقَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ هُمَا ‏"‏ ‏.‏ قَالَ زَيْنَبُ ‏.‏ قَالَ ‏"‏ أَىُّ الزَّيَانِبِ ‏"‏ ‏.‏ قَالَ زَيْنَبُ امْرَأَةُ عَبْدِ اللَّهِ وَزَيْنَبُ الأَنْصَارِيَّةُ قَالَ ‏"‏ نَعَمْ لَهُمَا أَجْرَانِ أَجْرُ الْقَرَابَةِ وَأَجْرُ الصَّدَقَةِ ‏"‏ ‏.‏\hadithno{2583}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Zainab, the wife of 'Abdullah, said:"The Messenger of Allah said to women: 'Give charity, even from women: 'Give charity, even from your jewelry. 'Abdullah was not a wealthy man and she said to him: 'Can I spend my charity on you and on my brother's children who are orphans? 'Abdullah said: 'Ask the Messenger of Allah about that.' She said: So I went to the Messenger of Allah, and at his door I found a woman from among the Ansar who was also called Zainab, and she was asking about the same matter as I was. Bilal came out to us and we said to him: Go to the Messenger of Allah and ask him about that, but do not tell him who we are. He went to the Messenger of Allah and he said:' Who are they?' He said: Zainab.' He said: 'Which Zainab?" He said: 'Zainab Al-Ansariyyah.' Abdullah and Zainab Al-Ansariyyah.' He said: 'Yes, they will have two rewards, the reward for upholding the ties of kinship and the reward dfor giving charity}}
\hadithdefcmd{nasai}{2584}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ أَزْهَرَ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَحْتَزِمَ أَحَدُكُمْ حُزْمَةَ حَطَبٍ عَلَى ظَهْرِهِ فَيَبِيعَهَا خَيْرٌ مِنْ أَنْ يَسْأَلَ رَجُلاً فَيُعْطِيَهُ أَوْ يَمْنَعَهُ ‏"‏ ‏.‏\hadithno{2584}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'if one of you were to carry a bundle of firewood on his back and sell it, that would be better than asking a man who may or may not give him something}}
\hadithdefcmd{nasai}{2585}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، قَالَ سَمِعْتُ حَمْزَةَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يَزَالُ الرَّجُلُ يَسْأَلُ حَتَّى يَأْتِيَ يَوْمَ الْقِيَامَةِ لَيْسَ فِي وَجْهِهِ مُزْعَةٌ مِنْ لَحْمٍ ‏"‏ ‏.‏\hadithno{2585}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin 'Amr said:"The Messenger of Allah said: ' A man will keep on asking until on the Day of Resurrection he will come without even a shared of skin on his face}}
\hadithdefcmd{nasai}{2586}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُثْمَانَ بْنِ أَبِي صَفْوَانَ الثَّقَفِيُّ، قَالَ حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ بِسْطَامِ بْنِ مُسْلِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ خَلِيفَةَ، عَنْ عَائِذِ بْنِ عَمْرٍو، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ فَأَعْطَاهُ فَلَمَّا وَضَعَ رِجْلَهُ عَلَى أُسْكُفَّةِ الْبَابِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ تَعْلَمُونَ مَا فِي الْمَسْأَلَةِ مَا مَشَى أَحَدٌ إِلَى أَحَدٍ يَسْأَلُهُ شَيْئًا ‏"‏ ‏.‏\hadithno{2586}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'A'idh bin 'Amr that:a man came to the prophet and asked him and he gave him, and when he placed his foot on the threshold the Messenger of Allah said: "If you knew how bad begging is, no one would go to anyone else and ask him for anything}}
\hadithdefcmd{nasai}{2587}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ مُسْلِمِ بْنِ مَخْشِيٍّ، عَنِ ابْنِ الْفِرَاسِيِّ، أَنَّ الْفِرَاسِيَّ، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَسْأَلُ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ لاَ وَإِنْ كُنْتَ سَائِلاً لاَ بُدَّ فَاسْأَلِ الصَّالِحِينَ ‏"‏ ‏.‏\hadithno{2587}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Al-Firasi that Al-Firasi said to the Messenger of Allah:"Shall I ask people (for help), O Messenger of Allah?" He said: "No, but if you have no alternative but to ask, then ask the righteous}}
\hadithdefcmd{nasai}{2588}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ نَاسًا، مِنَ الأَنْصَارِ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَاهُمْ ثُمَّ سَأَلُوهُ فَأَعْطَاهُمْ حَتَّى إِذَا نَفِدَ مَا عِنْدَهُ قَالَ ‏ "‏ مَا يَكُونُ عِنْدِي مِنْ خَيْرٍ فَلَنْ أَدَّخِرَهُ عَنْكُمْ وَمَنْ يَسْتَعْفِفْ يُعِفَّهُ اللَّهُ عَزَّ وَجَلَّ وَمَنْ يَصْبِرْ يُصَبِّرْهُ اللَّهُ وَمَا أُعْطِيَ أَحَدٌ عَطَاءً هُوَ خَيْرٌ وَأَوْسَعُ مِنَ الصَّبْرِ ‏"‏ ‏.‏\hadithno{2588}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:some of the Ansar asked the Messenger of Allah (for help) and he gave them (something). Then they asked him and he gave them, then when he had ran out he said: "Whatever I have of good, I will never keep it from you, but whoever wants to refrain from asking, Allah, the Mighty and Sublime, will help him to do so, and whoever wants to be patient, Allah will help him to be patient. None is ever given anything better and more far-reaching than patience}}
\hadithdefcmd{nasai}{2589}{أَخْبَرَنَا عَلِيُّ بْنُ شُعَيْبٍ، قَالَ أَنْبَأَنَا مَعْنٌ، قَالَ أَنْبَأَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَنْ يَأْخُذَ أَحَدُكُمْ حَبْلَهُ فَيَحْتَطِبَ عَلَى ظَهْرِهِ خَيْرٌ لَهُ مِنْ أَنْ يَأْتِيَ رَجُلاً أَعْطَاهُ اللَّهُ عَزَّ وَجَلَّ مِنْ فَضْلِهِ فَيَسْأَلَهُ أَعْطَاهُ أَوْ مَنَعَهُ ‏"‏ ‏.‏\hadithno{2589}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"By the One in Whose hand is my soul, if one of you were to take a rope and gather firewood on his back that would be better for him than coming to a man to whom Allah, the Mighty and Sublime, has given of His bounty and asking him (for help). Which he may or may not give}}
\hadithdefcmd{nasai}{2590}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنِي مُحَمَّدُ بْنُ قَيْسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ مُعَاوِيَةَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَضْمَنْ لِي وَاحِدَةً وَلَهُ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ يَحْيَى هَا هُنَا كَلِمَةٌ مَعْنَاهَا أَنْ لاَ يَسْأَلَ النَّاسَ شَيْئًا ‏.‏\hadithno{2590}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Thawban said:"The Messenger of Allah said: 'Whoever can promise me one thing. Paradise will be his." (One of the narrators) Yahya said: "Here a statement which means: That he will not ask the people for anything}}
\hadithdefcmd{nasai}{2591}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ حَمْزَةَ - قَالَ حَدَّثَنِي الأَوْزَاعِيُّ، عَنْ هَارُونَ بْنِ رِئَابٍ، أَنَّهُ حَدَّثَهُ عَنْ أَبِي بَكْرٍ، عَنْ قَبِيصَةَ بْنِ مُخَارِقٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَصْلُحُ الْمَسْأَلَةُ إِلاَّ لِثَلاَثَةٍ رَجُلٍ أَصَابَتْ مَالَهُ جَائِحَةٌ فَيَسْأَلُ حَتَّى يُصِيبَ سِدَادًا مِنْ عَيْشٍ ثُمَّ يُمْسِكَ وَرَجُلٍ تَحَمَّلَ حَمَالَةً فَيَسْأَلُ حَتَّى يُؤَدِّيَ إِلَيْهِمْ حَمَالَتَهُمْ ثُمَّ يُمْسِكَ عَنِ الْمَسْأَلَةِ وَرَجُلٍ يَحْلِفُ ثَلاَثَةُ نَفَرٍ مِنْ قَوْمِهِ مِنْ ذَوِي الْحِجَا بِاللَّهِ لَقَدْ حَلَّتِ الْمَسْأَلَةُ لِفُلاَنٍ فَيَسْأَلُ حَتَّى يُصِيبَ قِوَامًا مِنْ مَعِيشَةٍ ثُمَّ يُمْسِكَ عَنِ الْمَسْأَلَةِ فَمَا سِوَى ذَلِكَ سُحْتٌ ‏"‏ ‏.‏\hadithno{2591}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qabisah bin Mukhariq said:"I heard the Messenger of Allah says: 'It is not right to ask (for help) except in three cases: A man whose wealth has been destroyed by some calamity, so he asks until he gets enough to keep him going, then he refrains from asking: a man who undertakes a financial responsibility, and asks for help until he pays off whatever needs to be paid; and a man concerning whom three wise men from his own people swear by Allah that it is permissible for so-an-so to ask for help, so he asks until he has enough to be independent of means, then he refrains from asking. Apart from that. (asking) is unlawful}}
\hadithdefcmd{nasai}{2592}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ سَأَلَ وَلَهُ مَا يُغْنِيهِ جَاءَتْ خُمُوشًا أَوْ كُدُوحًا فِي وَجْهِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَاذَا يُغْنِيهِ أَوْ مَاذَا أَغْنَاهُ قَالَ ‏"‏ خَمْسُونَ دِرْهَمًا أَوْ حِسَابُهَا مِنَ الذَّهَبِ ‏"‏ ‏.‏ قَالَ يَحْيَى قَالَ سُفْيَانُ وَسَمِعْتُ زُبَيْدًا يُحَدِّثُ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ ‏.‏\hadithno{2592}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"The Messenger of Allah said: 'Whoever asks when he has enough to make him independent of means will have lacerations on his face on the Day of Resurrection.' It was said: 'O Messenger of Allah, what would make him independent of means?' He said: 'Fifty Dirhams or its equivalent of gold}}
\hadithdefcmd{nasai}{2593}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ أَخِيهِ، عَنْ مُعَاوِيَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُلْحِفُوا فِي الْمَسْأَلَةِ وَلاَ يَسْأَلْنِي أَحَدٌ مِنْكُمْ شَيْئًا وَأَنَا لَهُ كَارِهٌ فَيُبَارَكُ لَهُ فِيمَا أَعْطَيْتُهُ ‏"‏ ‏.‏\hadithno{2593}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Mu'awiyah that the Messenger of Allah said:"Do not be demanding when asking. If one of you asks me for anything and I give it reluctantly, there will be no blessing in it}}
\hadithdefcmd{nasai}{2594}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ، عَنْ دَاوُدَ بْنِ شَابُورَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَأَلَ وَلَهُ أَرْبَعُونَ دِرْهَمًا فَهُوَ الْمُلْحِفُ ‏"‏ ‏.‏\hadithno{2594}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"The Messenger of Allah said: 'Whoever asks when he has forty Dirhams I being too demanding when asking}}
\hadithdefcmd{nasai}{2595}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي الرِّجَالِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، قَالَ سَرَّحَتْنِي أُمِّي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُهُ وَقَعَدْتُ فَاسْتَقْبَلَنِي وَقَالَ ‏ "‏ مَنِ اسْتَغْنَى أَغْنَاهُ اللَّهُ عَزَّ وَجَلَّ وَمَنِ اسْتَعَفَّ أَعَفَّهُ اللَّهُ عَزَّ وَجَلَّ وَمَنِ اسْتَكْفَى كَفَاهُ اللَّهُ عَزَّ وَجَلَّ وَمَنْ سَأَلَ وَلَهُ قِيمَةُ أُوقِيَّةٍ فَقَدْ أَلْحَفَ ‏"‏ ‏.‏ فَقُلْتُ نَاقَتِي الْيَاقُوتَةُ خَيْرٌ مِنْ أُوقِيَّةٍ فَرَجَعْتُ وَلَمْ أَسْأَلْهُ ‏.‏\hadithno{2595}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman bin Abu Sa'eed Al-Khudri that his father said:"My mother sent me to the Messenger of Allah, and I came to him and sat down. He turned to me and said: 'Whoever wants to be independent of means, Allah, the Mighty and Sublime, will make him independent. Whoever wants to refrain from asking, Allah, the Mighty and Sublime, will help him to refrain. Whoever wants to be content with his lot, Allah, the Mighty and Sublime, Allah, the Mighty and Sublime, will suffice him. Whoever asks when he has something worth one Uqiyah, then he is being too demanding. 'I said: 'My she-camel Al-Yaqutah is worth more than and Uqiyah,' so I came back and did not ask him for anything}}
\hadithdefcmd{nasai}{2596}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ أَنْبَأَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رَجُلٍ، مِنْ بَنِي أَسَدٍ قَالَ نَزَلْتُ أَنَا وَأَهْلِي، بِبَقِيعِ الْغَرْقَدِ فَقَالَتْ لِي أَهْلِي اذْهَبْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَلْهُ لَنَا شَيْئًا نَأْكُلْهُ ‏.‏ فَذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَجَدْتُ عِنْدَهُ رَجُلاً يَسْأَلُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ أَجِدُ مَا أُعْطِيكَ ‏"‏ ‏.‏ فَوَلَّى الرَّجُلُ عَنْهُ وَهُوَ مُغْضَبٌ وَهُوَ يَقُولُ لَعَمْرِي إِنَّكَ لَتُعْطِي مَنْ شِئْتَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَيَغْضَبُ عَلَىَّ أَنْ لاَ أَجِدَ مَا أُعْطِيهِ مَنْ سَأَلَ مِنْكُمْ وَلَهُ أُوقِيَّةٌ أَوْ عِدْلُهَا فَقَدْ سَأَلَ إِلْحَافًا ‏"‏ ‏.‏ قَالَ الأَسَدِيُّ فَقُلْتُ لَلَقْحَةٌ لَنَا خَيْرٌ مِنْ أُوقِيَّةٍ - وَالأُوقِيَّةُ أَرْبَعُونَ دِرْهَمًا - فَرَجَعْتُ وَلَمْ أَسْأَلْهُ فَقَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ شَعِيرٌ وَزَبِيبٌ فَقَسَّمَ لَنَا مِنْهُ حَتَّى أَغْنَانَا اللَّهُ عَزَّ وَجَلَّ ‏.‏\hadithno{2596}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ata'bin Yasar that a man from Banu Asad said:"My wife and I stopped at Baqi Al-Gharqad, and my wife said to me: 'Go to the Messenger of Allah and ask him to give us something to eat. ' So I went to the Messenger of Allah and found a man with him asking him (for something), and the Messenger of Allah was saying: 'I do not have anything to give to you.' The man turned away angrily, saying: 'You only give to those you want. 'The Messenger of Allah said: 'He is angry with me because I did not have anything to give him. Whoever asks of you and he has an Uqiyah or its equivalent, then he has been too demanding in asking."' Al-Asadi said: I said: 'Our milch-camel is worth more than an Uqiyah, 'and an Uqiyah is forty Dirhams. "So I went back and did not ask him for anything. Then the Messenger of Allah got some barley and raisins after that, and he gave us a share of them, until Allah, the Mighty and Sublime, made us independent of means}}
\hadithdefcmd{nasai}{2597}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ سَالِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحِلُّ الصَّدَقَةُ لِغَنِيٍّ وَلاَ لِذِي مِرَّةٍ سَوِيٍّ ‏"‏ ‏.‏\hadithno{2597}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'It is not permissible to give charity to a rich man (or one who is independent of means) or to one who is strong and healthy}}
\hadithdefcmd{nasai}{2598}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَدِيِّ بْنِ الْخِيَارِ، ‏.‏ أَنَّ رَجُلَيْنِ، حَدَّثَاهُ أَنَّهُمَا، أَتَيَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْأَلاَنِهِ مِنَ الصَّدَقَةِ فَقَلَّبَ فِيهِمَا الْبَصَرَ - وَقَالَ مُحَمَّدٌ بَصَرَهُ - فَرَآهُمَا جَلْدَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ شِئْتُمَا وَلاَ حَظَّ فِيهَا لِغَنِيٍّ وَلاَ لِقَوِيٍّ مُكْتَسِبٍ ‏"‏ ‏.‏\hadithno{2598}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ubaidullah bin 'Adiyy bin Al-Khiyar narrated that:two men told him, that they came to the Messenger of Allah asking him for charity. He looked from one to the other and he saw that they were strong. The Messenger of Allah said: "If you want, I will give you, but no rich man or one who is strong and able to earn has a share of it}}
\hadithdefcmd{nasai}{2599}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ زَيْدِ بْنِ عُقْبَةَ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَسَائِلَ كُدُوحٌ يَكْدَحُ بِهَا الرَّجُلُ وَجْهَهُ فَمَنْ شَاءَ كَدَحَ وَجْهَهُ وَمَنْ شَاءَ تَرَكَ إِلاَّ أَنْ يَسْأَلَ الرَّجُلُ ذَا سُلْطَانٍ أَوْ شَيْئًا لاَ يَجِدُ مِنْهُ بُدًّا ‏"‏ ‏.‏\hadithno{2599}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Samurah bin Jundab said:"The Messenger of Allah said: "Every time a man begs, it will turn into lacerations on his face (on the Day of Resurrection). So whoever wants his face to be lacerated (let him ask), and whoever does not want that (let him not ask): except in the case of a man who asks a Sultan, or he asks when he can find no alternative}}
\hadithdefcmd{nasai}{2600}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ زَيْدِ بْنِ عُقْبَةَ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَسْأَلَةُ كَدٌّ يَكُدُّ بِهَا الرَّجُلُ وَجْهَهُ إِلاَّ أَنْ يَسْأَلَ الرَّجُلُ سُلْطَانًا أَوْ فِي أَمْرٍ لاَ بُدَّ مِنْهُ ‏"‏ ‏.‏\hadithno{2600}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Samurah bin Jundab said:"The Messenger of Allah said: 'Begging will be but lacerations on a man's face (on the Day of Resurrection). Unless he asks a man in authority or when he has no alternative}}
\hadithdefcmd{nasai}{2601}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ بْنِ عَبْدِ الْجَبَّارِ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا حَكِيمُ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ فَمَنْ أَخَذَهُ بِطِيبِ نَفْسٍ بُورِكَ لَهُ فِيهِ وَمَنْ أَخَذَهُ بِإِشْرَافِ نَفْسٍ لَمْ يُبَارَكْ لَهُ فِيهِ وَكَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏ ‏.‏\hadithno{2601}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Kakim bin Hizam said:"I asked the Messenger of Allah and he gave me, then I asked him and he gave me, then I asked him and he gave me. Then he said: This wealth is attractive and sweet. Whoever takes it without insisting, it will be blessed for him, and whoever takes it with avarice, it will not be blessed for him. He is like one who eats and is not satisfied. And the upper hand is better than the lower hand}}
\hadithdefcmd{nasai}{2602}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مِسْكِينُ بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا حَكِيمُ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ مَنْ أَخَذَهُ بِسَخَاوَةِ نَفْسٍ بُورِكَ لَهُ فِيهِ وَمَنْ أَخَذَهُ بِإِشْرَافِ النَّفْسِ لَمْ يُبَارَكْ لَهُ فِيهِ وَكَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏ ‏.‏\hadithno{2602}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hakim bin Hizam said:"I asked the Messenger of Allah and he gave me, then I asked him and he gave me, then I asked him and he gave me. Then he said: 'O Kahim! This wealth is attractive and sweet. Whoever takes it without being greedy, it will be blessed for him, and whoever takes it with avarice, it will not be blessed for him. He is like one who eats and is not satisfied. And the upper hand is better than the lower hand}}
\hadithdefcmd{nasai}{2603}{أَخْبَرَنِي الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ حَكِيمَ بْنَ حِزَامٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا حَكِيمُ إِنَّ هَذَا الْمَالَ حُلْوَةٌ فَمَنْ أَخَذَهُ بِسَخَاوَةِ نَفْسٍ بُورِكَ لَهُ فِيهِ وَمَنْ أَخَذَهُ بِإِشْرَافِ نَفْسٍ لَمْ يُبَارَكْ لَهُ فِيهِ وَكَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏ ‏.‏ قَالَ حَكِيمٌ فَقُلْتُ يَا رَسُولَ اللَّهِ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ أَرْزَأُ أَحَدًا بَعْدَكَ حَتَّى أُفَارِقَ الدُّنْيَا بِشَىْءٍ ‏.‏\hadithno{2603}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Kahim bin Hizamsaid:"I asked the Messenger of Allah and he gave me, then I asked him and he gave me. The he said: 'O Hakim, this wealth is attractive and sweet. Whoever takes it without being greedy, it will be blessed for him, and whoever takes it with avarice, it will be blessed for him. He is like one who eats and is not satisfied. And the upper hand is better than the lower hand.' I said: 'O Messenger of Allah! By the One Who sent you with the truth, I will never ask anyone for anything after you, until I depart this world}}
\hadithdefcmd{nasai}{2604}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنِ ابْنِ السَّاعِدِيِّ الْمَالِكِيِّ، قَالَ اسْتَعْمَلَنِي عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه عَلَى الصَّدَقَةِ فَلَمَّا فَرَغْتُ مِنْهَا فَأَدَّيْتُهَا إِلَيْهِ أَمَرَ لِي بِعُمَالَةٍ فَقُلْتُ لَهُ إِنَّمَا عَمِلْتُ لِلَّهِ عَزَّ وَجَلَّ وَأَجْرِي عَلَى اللَّهِ عَزَّ وَجَلَّ ‏.‏ فَقَالَ خُذْ مَا أَعْطَيْتُكَ فَإِنِّي قَدْ عَمِلْتُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ مِثْلَ قَوْلِكَ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُعْطِيتَ شَيْئًا مِنْ غَيْرِ أَنْ تَسْأَلَ فَكُلْ وَتَصَدَّقْ ‏"‏ ‏.‏\hadithno{2604}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn As-Sa'idi Al-Maliki said:"Umar bin Al-Khattab, may Allah be pleased with him, appointed me in charge of the Sadaqah. When I finished collecting it and handed it over to him, he ordered that I be given some payment. I said to him: 'I only did for the sake of Allah, the Mighty and Sublime, and my reward will be with Allah, the Mighty and Sublime.' He said: 'Take what I have given you: I did the same take during the time of the Messenger of Allah, and I said what you have said, but the Messenger of Allah said to me: "If you are given something without asking for it, then keep (some) and give (some) in charity}}
\hadithdefcmd{nasai}{2605}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو عُبَيْدِ اللَّهِ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ حُوَيْطِبِ بْنِ عَبْدِ الْعُزَّى، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ السَّعْدِيِّ، أَنَّهُ قَدِمَ عَلَى عُمَرَ بْنِ الْخَطَّابِ رضى الله عنه مِنَ الشَّامِ فَقَالَ أَلَمْ أُخْبَرْ أَنَّكَ تَعْمَلُ عَلَى عَمَلٍ مِنْ أَعْمَالِ الْمُسْلِمِينَ فَتُعْطَى عَلَيْهِ عُمَالَةً فَلاَ تَقْبَلُهَا قَالَ أَجَلْ إِنَّ لِي أَفْرَاسًا وَأَعْبُدًا وَأَنَا بِخَيْرٍ وَأُرِيدُ أَنْ يَكُونَ عَمَلِي صَدَقَةً عَلَى الْمُسْلِمِينَ فَقَالَ عُمَرُ رضى الله عنه إِنِّي أَرَدْتُ الَّذِي أَرَدْتَ وَكَانَ النَّبِيُّ صلى الله عليه وسلم يُعْطِينِي الْمَالَ فَأَقُولُ أَعْطِهِ مَنْ هُوَ أَفْقَرُ إِلَيْهِ مِنِّي وَإِنَّهُ أَعْطَانِي مَرَّةً مَالاً فَقُلْتُ لَهُ أَعْطِهِ مَنْ هُوَ أَحْوَجُ إِلَيْهِ مِنِّي ‏.‏ فَقَالَ ‏ "‏ مَا آتَاكَ اللَّهُ عَزَّ وَجَلَّ مِنْ هَذَا الْمَالِ مِنْ غَيْرِ مَسْأَلَةٍ وَلاَ إِشْرَافٍ فَخُذْهُ فَتَمَوَّلْهُ أَوْ تَصَدَّقْ بِهِ وَمَا لاَ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏ ‏.‏\hadithno{2605}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdullah bin As-Sa'di narrated that he came to 'Umar bin Al-Khattab, may Allah be pleased with him, from Ash-Sham, and he said:"I heard that you have been doing some work for the Muslims, and you are given payment for that, but you do not accept it. "I said: "Yes (that is so); I have horses and slaves and am well-off, and I wanted my work to be an act of charity toward the Muslims." 'Umar, may Allah be pleased with him, said: "I wanted the same thing as you. The Prophet used to give me money, and I would say: 'Give it to someone who is more in need of it than I am. Once he gave me money and I said: 'Give it to someone who us more in need of it that I am, and he said: 'Whatever Allah, the Mighty and Sublime, gives you of this wealth without you asking for it or hoping or it, take it and keep it, or give it in charity, and whatever. He does not give you then do not hope for it or wish for it}}
\hadithdefcmd{nasai}{2606}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، أَنَّ حُوَيْطِبَ بْنَ عَبْدِ الْعُزَّى، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ السَّعْدِيِّ أَخْبَرَهُ أَنَّهُ، قَدِمَ عَلَى عُمَرَ بْنِ الْخَطَّابِ فِي خِلاَفَتِهِ فَقَالَ لَهُ عُمَرُ أَلَمْ أُحَدَّثْ أَنَّكَ تَلِي مِنْ أَعْمَالِ النَّاسِ أَعْمَالاً فَإِذَا أُعْطِيتَ الْعُمَالَةَ رَدَدْتَهَا فَقُلْتُ بَلَى ‏.‏ فَقَالَ عُمَرُ رضى الله عنه فَمَا تُرِيدُ إِلَى ذَلِكَ فَقُلْتُ لِي أَفْرَاسٌ وَأَعْبُدٌ وَأَنَا بِخَيْرٍ وَأُرِيدُ أَنْ يَكُونَ عَمَلِي صَدَقَةً عَلَى الْمُسْلِمِينَ ‏.‏ فَقَالَ لَهُ عُمَرُ فَلاَ تَفْعَلْ فَإِنِّي كُنْتُ أَرَدْتُ مِثْلَ الَّذِي أَرَدْتَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْطِينِي الْعَطَاءَ فَأَقُولُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذْهُ فَتَمَوَّلْهُ أَوْ تَصَدَّقْ بِهِ مَا جَاءَكَ مِنْ هَذَا الْمَالِ وَأَنْتَ غَيْرُ مُشْرِفٍ وَلاَ سَائِلٍ فَخُذْهُ وَمَا لاَ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏ ‏.‏\hadithno{2606}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin As-Sa'di narrated that he came to 'Umar bin Al-Khattab during his Caliphate and 'Umar said to him:"I heard that you do some jobs for the people but when payment is given to you, you refuse it." I said: "(that is so)." 'Umar, may Allah be pleased with him, said: "Why do you do that? I said: "I have horses and slaves and am well off, and I wanted my work to be an act of charity toward the Muslims." 'Umar said to him: "Do not do that. I used to want the same thing as you. The Messenger of Allah used to give me payment and I would say, 'Give it to someone who is more in need of it that I am.' But the Messenger of Allah said: "Take it and keep it or give it in charity. Whatever comes to you of this wealth when you are not hoping for it and not asking for it, take it, and whatever does not, then do not wish for it}}
\hadithdefcmd{nasai}{2607}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، عَنِ الْحَكَمِ بْنِ نَافِعٍ، قَالَ أَنْبَأَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي السَّائِبُ بْنُ يَزِيدَ، أَنَّ حُوَيْطِبَ بْنَ عَبْدِ الْعُزَّى، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ السَّعْدِيِّ أَخْبَرَهُ أَنَّهُ، قَدِمَ عَلَى عُمَرَ بْنِ الْخَطَّابِ فِي خِلاَفَتِهِ فَقَالَ عُمَرُ أَلَمْ أُخْبَرْ أَنَّكَ، تَلِي مِنْ أَعْمَالِ النَّاسِ أَعْمَالاً فَإِذَا أُعْطِيتَ الْعُمَالَةَ كَرِهْتَهَا قَالَ فَقُلْتُ بَلَى ‏.‏ قَالَ فَمَا تُرِيدُ إِلَى ذَلِكَ فَقُلْتُ إِنَّ لِي أَفْرَاسًا وَأَعْبُدًا وَأَنَا بِخَيْرٍ وَأُرِيدُ أَنْ يَكُونَ عَمَلِي صَدَقَةً عَلَى الْمُسْلِمِينَ فَقَالَ عُمَرُ فَلاَ تَفْعَلْ فَإِنِّي كُنْتُ أَرَدْتُ الَّذِي أَرَدْتَ فَكَانَ النَّبِيُّ صلى الله عليه وسلم يُعْطِينِي الْعَطَاءَ فَأَقُولُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي حَتَّى أَعْطَانِي مَرَّةً مَالاً فَقُلْتُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خُذْهُ فَتَمَوَّلْهُ وَتَصَدَّقْ بِهِ فَمَا جَاءَكَ مِنْ هَذَا الْمَالِ وَأَنْتَ غَيْرُ مُشْرِفٍ وَلاَ سَائِلٍ فَخُذْهُ وَمَا لاَ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏ ‏.‏\hadithno{2607}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdullah bin As-Sa'di narrated that he came to 'Umar bin Al-Khattab during his Caliphate and 'Umar said to him:"I heard that you do some jobs for the people but when payment is given to you, you do not like it." I said: "Yes (that is so)." He said: "Why do you do that? I said: "I have horses and slaves and well off, and I wanted my work to be an act of charity toward the Muslims." 'Umar said to him: "Do not do that. I used to want the same thing as you. The Messenger of Allah used to give me payment and I would say, 'Give it to someone who is more in need of it than I am' until, on one occasion, the Prophet gave me payment and I said: 'Give it to someone who is more in said: "Take it and keep it or give it in charity. Wealth when you are not hoping for it and not asking for it, take it, and whatever does not, then do not wish for it}}
\hadithdefcmd{nasai}{2608}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، قَالَ أَنْبَأَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ سَمِعْتُ عُمَرَ، رضى الله عنه يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعْطِينِي الْعَطَاءَ فَأَقُولُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي حَتَّى أَعْطَانِي مَرَّةً مَالاً فَقُلْتُ لَهُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي ‏.‏ فَقَالَ ‏ "‏ خُذْهُ فَتَمَوَّلْهُ وَتَصَدَّقْ بِهِ وَمَا جَاءَكَ مِنْ هَذَا الْمَالِ وَأَنْتَ غَيْرُ مُشْرِفٍ وَلاَ سَائِلٍ فَخُذْهُ وَمَا لاَ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏ ‏.‏\hadithno{2608}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Umar said:"I heard 'Umar, may Allah be pleased with him, say: The Prophet used to give me payment and I would say: Give it to someone who is more, in need of it than I am, until one day he gave me some money and I said to him: Give it to someone who is more in need of it than I am. He said: Take it and keep it or give it in charity. Whatever comes to you of this wealth when you are not hoping for it and not asking for it, take it, and whatever does not, then do not wish for it}}
\hadithdefcmd{nasai}{2609}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ الْهَاشِمِيِّ، أَنَّ عَبْدَ الْمُطَّلِبِ بْنَ رَبِيعَةَ بْنِ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ، أَخْبَرَهُ أَنَّ أَبَاهُ رَبِيعَةَ بْنَ الْحَارِثِ قَالَ لِعَبْدِ الْمُطَّلِبِ بْنِ رَبِيعَةَ بْنِ الْحَارِثِ وَالْفَضْلِ بْنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ ائْتِيَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُولاَ لَهُ اسْتَعْمِلْنَا يَا رَسُولَ اللَّهِ عَلَى الصَّدَقَاتِ ‏.‏ فَأَتَى عَلِيُّ بْنُ أَبِي طَالِبٍ وَنَحْنُ عَلَى تِلْكَ الْحَالِ فَقَالَ لَهُمَا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لاَ يَسْتَعْمِلُ مِنْكُمْ أَحَدًا عَلَى الصَّدَقَةِ قَالَ عَبْدُ الْمُطَّلِبِ فَانْطَلَقْتُ أَنَا وَالْفَضْلُ حَتَّى أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لَنَا ‏ "‏ إِنَّ هَذِهِ الصَّدَقَةَ إِنَّمَا هِيَ أَوْسَاخُ النَّاسِ وَإِنَّهَا لاَ تَحِلُّ لِمُحَمَّدٍ وَلاَ لآلِ مُحَمَّدٍ صلى الله عليه وسلم ‏"‏ ‏.‏\hadithno{2609}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Rabiah binAl-Harith said to 'Abdul-Muttalib bin Rabi'ah bin Al-Harith and Al-Fadl bin 'Abbas bin 'Abdul-Muttalib:"Go to the Messenger of Allah and say to him: 'O Messenger of Allah, appoint us to collect the Sadaqat!' 'Ali bin Abi Talib came along when we were like that, and he said to them: "The Messenger of Allah will not appoint any of you to collect the Sadaqah."' 'Abdul-Muttalib said: "So I went with Al-Fadl until we came to the Messenger of Allah and he said to us: "This Zakah is the dirt of the people, and it is not permissible for Muhammad or for the family of Muhammad}}
\hadithdefcmd{nasai}{2610}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ قُلْتُ لأَبِي إِيَاسٍ مُعَاوِيَةَ بْنِ قُرَّةَ أَسَمِعْتَ أَنَسَ بْنَ مَالِكٍ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ابْنُ أُخْتِ الْقَوْمِ مِنْ أَنْفُسِهِمْ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{2610}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Shu'bah said:"I said to Abu Iyas Mu'awiyah bin Qurrah: 'Did you hear Ans bin Malik say: The Messenger of Allah said: The son of the daughter of a people is one of them? He said: 'Yes}}
\hadithdefcmd{nasai}{2611}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ابْنُ أُخْتِ الْقَوْمِ مِنْهُمْ ‏"‏ ‏.‏\hadithno{2611}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah said:"The son of the daughter of a people is one of them}}
\hadithdefcmd{nasai}{2612}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا الْحَكَمُ، عَنِ ابْنِ أَبِي رَافِعٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً مِنْ بَنِي مَخْزُومٍ عَلَى الصَّدَقَةِ فَأَرَادَ أَبُو رَافِعٍ أَنْ يَتْبَعَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الصَّدَقَةَ لاَ تَحِلُّ لَنَا وَإِنَّ مَوْلَى الْقَوْمِ مِنْهُمْ ‏"‏ ‏.‏\hadithno{2612}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ihn Abi Rafi, from his father, that:the Messenger of Allah appointed a man from Banu Makhzum to collect Sadaqah. Abu Rafi wanted to go with him, but the Messenger of Allah said: "The Sadaqah is not permissible for us, and the freed slave of a people is one of them}}
\hadithdefcmd{nasai}{2613}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ وَاصِلٍ، قَالَ حَدَّثَنَا بَهْزُ بْنُ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أُتِيَ بِشَىْءٍ سَأَلَ عَنْهُ ‏ "‏ أَهَدِيَّةٌ أَمْ صَدَقَةٌ ‏"‏ ‏.‏ فَإِنْ قِيلَ صَدَقَةٌ لَمْ يَأْكُلْ وَإِنْ قِيلَ هَدِيَّةٌ بَسَطَ يَدَهُ ‏.‏\hadithno{2613}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father that his grandfather said:"If something was brought to him, the prophet would ask whether it was a gift or charity. If it was said that if was charity, he would not eat, and if it was said that it was a gift, he would stretch forth his hand}}
\hadithdefcmd{nasai}{2614}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا الْحَكَمُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ، بَرِيرَةَ فَتَعْتِقَهَا وَأَنَّهُمُ اشْتَرَطُوا وَلاَءَهَا فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ اشْتَرِيهَا وَاعْتِقِيهَا فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ وَخُيِّرَتْ حِينَ أُعْتِقَتْ وَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلَحْمٍ فَقِيلَ هَذَا مِمَّا تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ ‏.‏ فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏ وَكَانَ زَوْجُهَا حُرًّا ‏.‏\hadithno{2614}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that:she wanted to buy Barirah and set her free, but they stipulated that her loyally as a freed slave (wala') should be to them. She mentioned that to the Messenger of Allah and he said: "Buy her and set her fee, and loyally is due to the one who frees the slave." She was given the choice when she was freed. Some meat was brought to the Messenger of Allah and it was said: "This is something that is given in charity to Barirah." He said: "It is charity for her and gift for us." And her husband was a free man}}
\hadithdefcmd{nasai}{2615}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ، يَقُولُ حَمَلْتُ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ فَأَضَاعَهُ الَّذِي كَانَ عِنْدَهُ وَأَرَدْتُ أَنْ أَبْتَاعَهُ مِنْهُ وَظَنَنْتُ أَنَّهُ بَائِعُهُ بِرُخْصٍ فَسَأَلْتُ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَشْتَرِهِ وَإِنْ أَعْطَاكَهُ بِدِرْهَمٍ فَإِنَّ الْعَائِدَ فِي صَدَقَتِهِ كَالْكَلْبِ يَعُودُ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{2615}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Zaid bin Aslam that his father said:"I heard 'Umar say: 'I gave a horse to someone to ride in the cause of Allah, the Mighty and Sublime, and the one who kept it neglected it. I wanted to buy it back from him, and I thought that he would sell it at a cheap price. I asked the Messenger for Allah about that and he said: Do not buy it, even if he gives it to you for a Dirham. The one who takes back his charity is like the dog that goes back to its own vomit}}
\hadithdefcmd{nasai}{2616}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ عُمَرَ، أَنَّهُ حَمَلَ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ فَرَآهَا تُبَاعُ فَأَرَادَ شِرَاءَهَا فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَعْرِضْ فِي صَدَقَتِكَ ‏"‏ ‏.‏\hadithno{2616}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Umar that:he gave someone a horse to ride in the cause of Allah, then he saw it offered for sale and wanted to buy it. The Prophet said to him: "Do not think of buying back what you have given in charity}}
\hadithdefcmd{nasai}{2617}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ أَنْبَأَنَا حُجَيْنٌ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُحَدِّثُ أَنَّ عُمَرَ، تَصَدَّقَ بِفَرَسٍ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ فَوَجَدَهَا تُبَاعُ بَعْدَ ذَلِكَ فَأَرَادَ أَنْ يَشْتَرِيَهُ ثُمَّ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَأْمَرَهُ فِي ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏ ‏.‏\hadithno{2617}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim bin 'Abdullah that 'Abdullah bin 'Umar used to narrate that:'Umar give a house in charity for the sake of Allah, the Mighty and Sublime, and he found it being offered for sale after that. He wanted to buy it, then he went to the Messenger of Allah and asked him about that. The Messenger of Allah said: "Do not take back what you have given in charity}}
\hadithdefcmd{nasai}{2618}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا بِشْرٌ، وَيَزِيدُ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ عَتَّابَ بْنَ أَسِيدٍ أَنْ يَخْرِصَ الْعِنَبَ فَتُؤَدَّى زَكَاتُهُ زَبِيبًا كَمَا تُؤَدَّى زَكَاةُ النَّخْلِ تَمْرًا ‏.‏\hadithno{2618}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa'eed bin Al-Musayyab:That the Messenger of Allah told 'Attab bin Usaid to estimate the (harvest of) grapes, and to pay Zakah in raisins, just as the Zakah on date palms is given in died dates}}
