% Auto-generated chapter 11 for abudawud
% Hadiths in this chapter: 325

\hadithdefcmd{abudawud}{1721}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ الْمَعْنَى، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سِنَانٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ الأَقْرَعَ بْنَ حَابِسٍ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ الْحَجُّ فِي كُلِّ سَنَةٍ أَوْ مَرَّةً وَاحِدَةً قَالَ ‏ "‏ بَلْ مَرَّةً وَاحِدَةً فَمَنْ زَادَ فَهُوَ تَطَوُّعٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هُوَ أَبُو سِنَانٍ الدُّؤَلِيُّ كَذَا قَالَ عَبْدُ الْجَلِيلِ بْنُ حُمَيْدٍ وَسُلَيْمَانُ بْنُ كَثِيرٍ جَمِيعًا عَنِ الزُّهْرِيِّ وَقَالَ عُقَيْلٌ عَنْ سِنَانٍ ‏.‏\hadithno{1721}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aqra' ibn Habib: Ibn Abbas said: Aqra' ibn Habis asked the Prophet (ﷺ) saying: Messenger of Allah hajj is to be performed annually or only once? He replied: Only once, and if anyone performs it more often, he performs a supererogatory act. Abu Dawud said: The narrator Abu Sinan is Abu Sinan al-Du'wail. The same has been reported by both 'Abd al-Jalil bin Humaid and Sulaiman bin Kathir from al-Zuhri. The narrator 'Uqail reported the name "Sinan}}
\hadithdefcmd{abudawud}{1722}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنٍ لأَبِي، وَاقِدٍ اللَّيْثِيِّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لأَزْوَاجِهِ فِي حَجَّةِ الْوَدَاعِ ‏ "‏ هَذِهِ ثُمَّ ظُهُورُ الْحُصْرِ ‏"‏ ‏.‏\hadithno{1722}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Waqid al-Laythi: I heard the Messenger of Allah (ﷺ) saying to his wives during the Farewell Pilgrimage: This (is the pilgrimage for you); afterwards stick to the surface of the mats (i.e. should stay at home)}}
\hadithdefcmd{abudawud}{1723}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ مُسْلِمَةٍ تُسَافِرُ مَسِيرَةَ لَيْلَةٍ إِلاَّ وَمَعَهَا رَجُلٌ ذُو حُرْمَةٍ مِنْهَا ‏"‏ ‏.‏\hadithno{1723}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1339)}\hadithtrans{Abu Huraira reported :The Messenger of Allah (SWAS) as saying : A muslim woman must not make a journey of a night unless she is accompanied by a man who is within the prohibited degrees}}
\hadithdefcmd{abudawud}{1724}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، وَالنُّفَيْلِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنِي مَالِكٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، - قَالَ الْحَسَنُ فِي حَدِيثِهِ عَنْ أَبِيهِ، ثُمَّ اتَّفَقُوا - عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُسَافِرَ يَوْمًا وَلَيْلَةً ‏"‏ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَمْ يَذْكُرِ الْقَعْنَبِيُّ وَالنُّفَيْلِيُّ عَنْ أَبِيهِ رَوَاهُ ابْنُ وَهْبٍ وَعُثْمَانُ بْنُ عُمَرَ عَنْ مَالِكٍ كَمَا قَالَ الْقَعْنَبِيُّ ‏.‏\hadithno{1724}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1339)}\hadithtrans{Abu Hurairah reported the Prophet (SWAS) as saying :A woman who believes in Allah and the last Day must not make a journey of a day and a night. He then narrated the rest of the tradition to the same effect (as above). The narrator al-Nufaili said : Malik narrated us. Abu Dawud said : The narrators al-Nufail and al\_Qa’nabi did not mention the words “from his father”. Ibn Wahb and ‘Uthman bin ‘Umr narrated from Malik the same words as narrated by al-Qa’nabi (i.e. omitted the words “from his father”)}}
\hadithdefcmd{abudawud}{1725}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، عَنْ جَرِيرٍ، عَنْ سُهَيْلٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ إِلاَّ أَنَّهُ قَالَ ‏ "‏ بَرِيدًا ‏"‏ ‏.‏\hadithno{1725}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported the Messenger of Allah (SWAS) as saying :He then reported the same tradition as mentioned above but he mentioned (in this version) the word “mail post”}}
\hadithdefcmd{abudawud}{1726}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَهَنَّادٌ، أَنَّ أَبَا مُعَاوِيَةَ، وَوَكِيعًا، حَدَّثَاهُمْ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُسَافِرَ سَفَرًا فَوْقَ ثَلاَثَةِ أَيَّامٍ فَصَاعِدًا إِلاَّ وَمَعَهَا أَبُوهَا أَوْ أَخُوهَا أَوْ زَوْجُهَا أَوِ ابْنُهَا أَوْ ذُو مَحْرَمٍ مِنْهَا ‏"‏ ‏.‏\hadithno{1726}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1340)}\hadithtrans{Abu Sa’id reported The Apostel of Allah (SWAS) as saying:A woman who believes in Allah and the Last Day must not make a journey of more than three days unless she is accompanied by her father or her brother, or her husband or her son or her relative who is within the prohibited degree}}
\hadithdefcmd{abudawud}{1727}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُسَافِرُ الْمَرْأَةُ ثَلاَثًا إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ ‏"‏ ‏.‏\hadithno{1727}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1087) Sahih Muslim (1338)}\hadithtrans{Ibn `Umr reported the Prophet (SWAS) as saying :A woman must not make a journey of three days unless she is accompanied by a man who is within the prohibited degree}}
\hadithdefcmd{abudawud}{1728}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يُرْدِفُ مَوْلاَةً لَهُ يُقَالُ لَهَا صَفِيَّةُ تُسَافِرُ مَعَهُ إِلَى مَكَّةَ ‏.‏\hadithno{1728}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Nafi` said :Ibn `Umr used to seat his slave girl called Safiyyah behind him(on the Camel) and thus she travelled to Makkah in his company}}
\hadithdefcmd{abudawud}{1729}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي سُلَيْمَانَ بْنَ حَيَّانَ الأَحْمَرَ - عَنِ ابْنِ جُرَيْجٍ، عَنْ عُمَرَ بْنِ عَطَاءٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ صَرُورَةَ فِي الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{1729}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Islam does not allow for failure to perform the hajj}}
\hadithdefcmd{abudawud}{1730}{حَدَّثَنَا أَحْمَدُ بْنُ الْفُرَاتِ، - يَعْنِي أَبَا مَسْعُودٍ الرَّازِيَّ - وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْمُخَرِّمِيُّ - وَهَذَا لَفْظُهُ - قَالاَ حَدَّثَنَا شَبَابَةُ، عَنْ وَرْقَاءَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانُوا يَحُجُّونَ وَلاَ يَتَزَوَّدُونَ - قَالَ أَبُو مَسْعُودٍ كَانَ أَهْلُ الْيَمَنِ أَوْ نَاسٌ مِنْ أَهْلِ الْيَمَنِ يَحُجُّونَ وَلاَ يَتَزَوَّدُونَ - وَيَقُولُونَ نَحْنُ الْمُتَوَكِّلُونَ فَأَنْزَلَ اللَّهُ سُبْحَانَهُ ‏\{‏ وَتَزَوَّدُوا فَإِنَّ خَيْرَ الزَّادِ التَّقْوَى ‏\}‏ الآيَةَ ‏.‏\hadithno{1730}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1523)}\hadithtrans{Ibn `Abbas said :People used to perform Hajj and not bring provisions with them. Abu Mas’ud said the inhabitants of Yemen or people of Yemen used to perform Hajj and not bring provisions with them. They would declare we put our trust in Allah. So Allah most high sent down “ and bring provisions, but the best provision is piety”}}
\hadithdefcmd{abudawud}{1731}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا جَرِيرٌ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ قَرَأَ هَذِهِ الآيَةَ ‏\{‏ لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَبْتَغُوا فَضْلاً مِنْ رَبِّكُمْ ‏\}‏ قَالَ كَانُوا لاَ يَتَّجِرُونَ بِمِنًى فَأُمِرُوا بِالتِّجَارَةِ إِذَا أَفَاضُوا مِنْ عَرَفَاتٍ ‏.‏\hadithno{1731}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: Ibn Abbas recited this verse: 'It is no sin for you that you seek the bounty of your Lord', and said: The people would not trade in Mina (during the hajj), so they were commanded to trade when they proceeded from Arafat}}
\hadithdefcmd{abudawud}{1732}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، مُحَمَّدُ بْنُ خَازِمٍ عَنِ الأَعْمَشِ، عَنِ الْحَسَنِ بْنِ عَمْرٍو، عَنْ مِهْرَانَ أَبِي صَفْوَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَرَادَ الْحَجَّ فَلْيَتَعَجَّلْ ‏"‏ ‏.‏\hadithno{1732}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: He who intends to perform hajj should hasten to do so}}
\hadithdefcmd{abudawud}{1733}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الْعَلاَءُ بْنُ الْمُسَيَّبِ، حَدَّثَنَا أَبُو أُمَامَةَ التَّيْمِيُّ، قَالَ كُنْتُ رَجُلاً أُكْرِي فِي هَذَا الْوَجْهِ وَكَانَ نَاسٌ يَقُولُونَ لِي إِنَّهُ لَيْسَ لَكَ حَجٌّ فَلَقِيتُ ابْنَ عُمَرَ فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنِّي رَجُلٌ أُكْرِي فِي هَذَا الْوَجْهِ وَإِنَّ نَاسًا يَقُولُونَ لِي إِنَّهُ لَيْسَ لَكَ حَجٌّ فَقَالَ ابْنُ عُمَرَ أَلَيْسَ تُحْرِمُ وَتُلَبِّي وَتَطُوفُ بِالْبَيْتِ وَتُفِيضُ مِنْ عَرَفَاتٍ وَتَرْمِي الْجِمَارَ قَالَ قُلْتُ بَلَى ‏.‏ قَالَ فَإِنَّ لَكَ حَجًّا جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَأَلَهُ عَنْ مِثْلِ مَا سَأَلْتَنِي عَنْهُ فَسَكَتَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يُجِبْهُ حَتَّى نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَبْتَغُوا فَضْلاً مِنْ رَبِّكُمْ ‏\}‏ فَأَرْسَلَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَرَأَ عَلَيْهِ هَذِهِ الآيَةَ وَقَالَ ‏"‏ لَكَ حَجٌّ ‏"‏ ‏.‏\hadithno{1733}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{AbuUmamah at-Taymi said:I was a man who used to give (riding-beasts) on hire for this purpose (for travelling during the pilgrimage) and the people would tell (me): Your hajj is not valid. So I met Ibn Umar and told him: AbuAbdurRahman, I am a man who gives (riding-beast) on hire for this purpose (i.e. for hajj), and the people tell me: Your hajj is not valid. Ibn Umar replied: Do you not put on ihram (the pilgrim dress), call the talbiyah (labbayk), circumambulate the Ka'bah, return from Arafat and lapidate jamrahs? I said: Why not? Then he said: Your hajj is valid. a man came to the Prophet (ﷺ) and asked him the same question you have asked me. The Messenger of Allah (ﷺ) kept silence and did not answer him till this verse came down: "It is no sin for you that you seek the bounty of your Lord." The Messenger of Allah (ﷺ) sent for him and recited this verse to him and said: Your hajj is valid}}
\hadithdefcmd{abudawud}{1734}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ النَّاسَ، فِي أَوَّلِ الْحَجِّ كَانُوا يَتَبَايَعُونَ بِمِنًى وَعَرَفَةَ وَسُوقِ ذِي الْمَجَازِ وَمَوَاسِمِ الْحَجِّ فَخَافُوا الْبَيْعَ وَهُمْ حُرُمٌ فَأَنْزَلَ اللَّهُ سُبْحَانَهُ ‏\{‏ لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَبْتَغُوا فَضْلاً مِنْ رَبِّكُمْ ‏\}‏ فِي مَوَاسِمِ الْحَجِّ ‏.‏ قَالَ فَحَدَّثَنِي عُبَيْدُ بْنُ عُمَيْرٍ أَنَّهُ كَانَ يَقْرَأُهَا فِي الْمُصْحَفِ ‏.‏\hadithno{1734}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The people used to trade, in the beginning, at Mina, Arafat, the market place of Dhul-Majaz, and during the season of hajj. But (later on) they became afraid of trading while they were putting on ihram. So Allah, glory be to Him, sent down this verse: "It is no sin for you that you seek the bounty of your Lord during the seasons of hajj." Ubayd ibn Umayr told me that he (Ibn Abbas) used to recite this verse in his codex}}
\hadithdefcmd{abudawud}{1735}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، - قَالَ أَحْمَدُ بْنُ صَالِحٍ كَلاَمًا مَعْنَاهُ أَنَّهُ مَوْلَى ابْنِ عَبَّاسٍ - عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ النَّاسَ، فِي أَوَّلِ مَا كَانَ الْحَجُّ كَانُوا يَبِيعُونَ فَذَكَرَ مَعْنَاهُ إِلَى قَوْلِهِ مَوَاسِمِ الْحَجِّ ‏.‏\hadithno{1735}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abd Allah bin `Abbas said :In the beginning when Hajj was prescribed, people used to trade during Hajj. The narrator then narrated the rest of the tradition upto the words, `season of Hajj’}}
\hadithdefcmd{abudawud}{1736}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالرَّوْحَاءِ فَلَقِيَ رَكْبًا فَسَلَّمَ عَلَيْهِمْ فَقَالَ ‏"‏ مَنِ الْقَوْمُ ‏"‏ ‏.‏ فَقَالُوا الْمُسْلِمُونَ ‏.‏ فَقَالُوا فَمَنْ أَنْتُمْ قَالُوا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَفَزِعَتِ امْرَأَةٌ فَأَخَذَتْ بِعَضُدِ صَبِيٍّ فَأَخْرَجَتْهُ مِنْ مِحَفَّتِهَا فَقَالَتْ يَا رَسُولَ اللَّهِ هَلْ لِهَذَا حَجٌّ قَالَ ‏"‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{1736}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1336)}\hadithtrans{Ibn `Abbas said the Messenger of Allah (SWAS) was at al-Rawha. There he met some riders. He saluted them and asked who they were. They replied that they were Muslims. They asked who are you. They (the companions) replied he is the Messenger of Allah (SWAS). A woman became upset :she took her child by his arm and lifted him from her litter at the camel. She said Messenger of Allah (SWAS) can this (child) be credited with having performed Hajj. He replied Yes, and you will have a reward}}
\hadithdefcmd{abudawud}{1737}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ وَقَّتَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ وَلأَهْلِ الشَّامِ الْجُحْفَةَ وَلأَهْلِ نَجْدٍ قَرْنًا وَبَلَغَنِي أَنَّهُ وَقَّتَ لأَهْلِ الْيَمَنِ يَلَمْلَمَ ‏.‏\hadithno{1737}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1525) Sahih Muslim (1182)}\hadithtrans{Ibn Umar said :The Messenger of Allah (SWAS) appointed the following places for putting on Ihram : Dhul al-Hulaifah for the people of Madina, al-Juhfah for the people of Syria and al-Qarn for the people of Najd and have been told that appointed Yalamlam for the people of Yemen}}
\hadithdefcmd{abudawud}{1738}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، وَعَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، قَالاَ وَقَّتَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ أَحَدُهُمَا وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ ‏.‏ وَقَالَ أَحَدُهُمَا أَلَمْلَمَ قَالَ ‏ "‏ فَهُنَّ لَهُمْ وَلِمَنْ أَتَى عَلَيْهِنَّ مِنْ غَيْرِ أَهْلِهِنَّ مِمَّنْ كَانَ يُرِيدُ الْحَجَّ وَالْعُمْرَةَ وَمَنْ كَانَ دُونَ ذَلِكَ ‏.‏ - قَالَ ابْنُ طَاوُسٍ - مِنْ حَيْثُ أَنْشَأَ قَالَ وَكَذَلِكَ حَتَّى أَهْلُ مَكَّةَ يُهِلُّونَ مِنْهَا ‏"‏ ‏.‏\hadithno{1738}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1526) Sahih Muslim (1181)}\hadithtrans{Ibn `Abbas and Tawus reported :The Messenger of Allah (SWAS) appointed places for putting on Ihram and narrated the rest of the tradition to the same effect (as mentioned above). One of them said and Yalamlam for the people of Yemen. The other narrator said Alamlam. These (places for Ihram) are appointed for these regions and for people of other regions who come to them intending to perform Hajj and `Umrah. The place where those who live nearer to Makkah should put on Ihram from where they start and so on up to the inhabitants of Makkah itself who put on Ihram in it. This is the version of Ibn Tawus}}
\hadithdefcmd{abudawud}{1739}{حَدَّثَنَا هِشَامُ بْنُ بَهْرَامَ الْمَدَائِنِيُّ، حَدَّثَنَا الْمُعَافَى بْنُ عِمْرَانَ، عَنْ أَفْلَحَ، - يَعْنِي ابْنَ حُمَيْدٍ - عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْعِرَاقِ ذَاتَ عِرْقٍ ‏.‏\hadithno{1739}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) appointed Dhat Irq as the place for putting on ihram for the people of Iraq}}
\hadithdefcmd{abudawud}{1740}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ وَقَّتَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ الْمَشْرِقِ الْعَقِيقَ ‏.‏\hadithno{1740}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) appointed al-Aqiq as the place for putting on ihram for the people of East}}
\hadithdefcmd{abudawud}{1741}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يُحَنَّسَ، عَنْ يَحْيَى بْنِ أَبِي سُفْيَانَ الأَخْنَسِيِّ، عَنْ جَدَّتِهِ، حُكَيْمَةَ عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ أَهَلَّ بِحَجَّةٍ أَوْ عُمْرَةٍ مِنَ الْمَسْجِدِ الأَقْصَى إِلَى الْمَسْجِدِ الْحَرَامِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ ‏"‏ ‏.‏ أَوْ ‏"‏ وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏ شَكَّ عَبْدُ اللَّهِ أَيَّتَهُمَا قَالَ ‏.‏ قَالَ أَبُو دَاوُدَ يَرْحَمُ اللَّهُ وَكِيعًا أَحْرَمَ مِنْ بَيْتِ الْمَقْدِسِ يَعْنِي إِلَى مَكَّةَ ‏.‏\hadithno{1741}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: She heard the Messenger of Allah (ﷺ) say: If anyone puts on ihram for hajj or umrah from the Aqsa mosque to the sacred mosque , his former and latter sins will be forgiven, or he will be guaranteed Paradise. The narrator Abdullah doubted which of these words he said. Abu Dawud said: May Allah have mercy on Waki'. He put on ihram from Jerusalem (Aqsa mosque), that is, to Mecca}}
\hadithdefcmd{abudawud}{1742}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ أَبِي الْحَجَّاجِ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عُتْبَةُ بْنُ عَبْدِ الْمَلِكِ السَّهْمِيُّ، حَدَّثَنِي زُرَارَةُ بْنُ كُرَيْمٍ، أَنَّ الْحَارِثَ بْنَ عَمْرٍو السَّهْمِيَّ، حَدَّثَهُ قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ بِمِنًى أَوْ بِعَرَفَاتٍ وَقَدْ أَطَافَ بِهِ النَّاسُ قَالَ فَتَجِيءُ الأَعْرَابُ فَإِذَا رَأَوْا وَجْهَهُ قَالُوا هَذَا وَجْهٌ مُبَارَكٌ ‏.‏ قَالَ وَوَقَّتَ ذَاتَ عِرْقٍ لأَهْلِ الْعِرَاقِ ‏.‏\hadithno{1742}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Harith ibn Amr as-Sahmi: I came to the Messenger of Allah (ﷺ) when he was at Mina, or at Arafat. He was surrounded by the people. When the bedouins came and saw his face, they would say: This is a blessed face. He said: He (the Prophet) appointed Dhat Irq as the place of putting on ihram for the people of Iraq}}
\hadithdefcmd{abudawud}{1743}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ نُفِسَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ بِمُحَمَّدِ بْنِ أَبِي بَكْرٍ بِالشَّجَرَةِ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا بَكْرٍ أَنْ تَغْتَسِلَ فَتُهِلَّ ‏.‏\hadithno{1743}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1209)}\hadithtrans{Aishah said:Asma daughther of 'Umais gave birth to Muhammad bin Abi Bakr at Shajarah. The Messenger of Allah (ﷺ) commanded Abu Bakr to ask her to take a bath and wear ihram}}
\hadithdefcmd{abudawud}{1744}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَإِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ أَبُو مَعْمَرٍ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ شُجَاعٍ، عَنْ خُصَيْفٍ، عَنْ عِكْرِمَةَ، وَمُجَاهِدٍ، وَعَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ الْحَائِضُ وَالنُّفَسَاءُ إِذَا أَتَتَا عَلَى الْوَقْتِ تَغْتَسِلاَنِ وَتُحْرِمَانِ وَتَقْضِيَانِ الْمَنَاسِكَ كُلَّهَا غَيْرَ الطَّوَافِ بِالْبَيْتِ ‏"‏ ‏.‏ قَالَ أَبُو مَعْمَرٍ فِي حَدِيثِهِ حَتَّى تَطْهُرَ وَلَمْ يَذْكُرِ ابْنُ عِيسَى عِكْرِمَةَ وَمُجَاهِدًا قَالَ عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ وَلَمْ يَقُلِ ابْنُ عِيسَى ‏"‏ كُلَّهَا ‏"‏ ‏.‏ قَالَ ‏"‏ الْمَنَاسِكَ إِلاَّ الطَّوَافَ بِالْبَيْتِ ‏"‏ ‏.‏\hadithno{1744}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: A menstruating woman and the one who delivered a child should take a bath, put on ihram and perform all the rites of hajj except circumambulation of the House (Ka'bah) when they came to the place of wearing ihram. Abu Ma'mar said in his version: "till she is purified". The narrator Ibn Isa did not mention the names of Ikrimah and Mujahid, but he said: from Ata on the authority of Ibn Abbas. Ibn Isa also did not mention the word "all (rites of hajj)." He said in his version: All the rites of hajj except circumambulation of the House (the Ka'bah)}}
\hadithdefcmd{abudawud}{1745}{حَدَّثَنَا الْقَعْنَبِيُّ، وَأَحْمَدُ بْنُ يُونُسَ، قَالاَ حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم لإِحْرَامِهِ قَبْلَ أَنْ يُحْرِمَ وَلإِحْلاَلِهِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ ‏.‏\hadithno{1745}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1539) Sahih Muslim (1189)}\hadithtrans{A’ishah said ; I used to perfume the Messenger of Allah (SWAS) preparatory to his entering the sacred state before he put on Ihram, and preparatory to putting off Ihram before he made the circuits round the House (the Ka’bah)}}
\hadithdefcmd{abudawud}{1746}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الْمِسْكِ فِي مَفْرِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏\hadithno{1746}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1190)}\hadithtrans{A’ishah (may Allah be pleased with her) said :I still seem to see the glistening of the perfume where the hair was parted on the head of the Messenger of Allah (SWAS) while he was wearing Ihram}}
\hadithdefcmd{abudawud}{1747}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ - عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يُهِلُّ مُلَبِّدًا ‏.‏\hadithno{1747}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1540) Sahih Muslim (1184)}\hadithtrans{Ibn `Umar said that he heard the Prophet (SWAS) say with hair matted that he raised his voice in the talbiyah}}
\hadithdefcmd{abudawud}{1748}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَبَّدَ رَأْسَهُ بِالْعَسَلِ ‏.‏\hadithno{1748}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn `Umar said :The Prophet (SWAS) matted his hair with honey}}
\hadithdefcmd{abudawud}{1749}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمِنْهَالِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنِ ابْنِ إِسْحَاقَ، - الْمَعْنَى - قَالَ قَالَ عَبْدُ اللَّهِ - يَعْنِي ابْنَ أَبِي نَجِيحٍ - حَدَّثَنِي مُجَاهِدٌ عَنِ ابْنِ عَبَّاسٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهْدَى عَامَ الْحُدَيْبِيَةِ فِي هَدَايَا رَسُولِ اللَّهِ صلى الله عليه وسلم جَمَلاً كَانَ لأَبِي جَهْلٍ فِي رَأْسِهِ بُرَةُ فِضَّةٍ ‏.‏ قَالَ ابْنُ مِنْهَالٍ بُرَةٌ مِنْ ذَهَبٍ زَادَ النُّفَيْلِيُّ يَغِيظُ بِذَلِكَ الْمُشْرِكِينَ ‏.‏\hadithno{1749}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: In the year of al-Hudaybiyyah, the Messenger of Allah (ﷺ) included among his sacrificial animals a camel with a silver nose-ring (Ibn Minhal's version has gold) which had belonged to AbuJahl (the version of an-Nufayli added) "thereby enraging the polytheists}}
\hadithdefcmd{abudawud}{1750}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَحَرَ عَنْ آلِ مُحَمَّدٍ فِي حَجَّةِ الْوَدَاعِ بَقَرَةً وَاحِدَةً ‏.‏\hadithno{1750}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) sacrificed a cow for his wives at the Farewell Pilgrimage}}
\hadithdefcmd{abudawud}{1751}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، وَمُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، قَالاَ حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَبَحَ عَمَّنِ اعْتَمَرَ مِنْ نِسَائِهِ بَقَرَةً بَيْنَهُنَّ ‏.‏\hadithno{1751}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurayrah: The Messenger of Allah (ﷺ) sacrificed a cow for his wives who had performed umrah}}
\hadithdefcmd{abudawud}{1752}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، وَحَفْصُ بْنُ عُمَرَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، - قَالَ أَبُو الْوَلِيدِ - قَالَ سَمِعْتُ أَبَا حَسَّانَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الظُّهْرَ بِذِي الْحُلَيْفَةِ ثُمَّ دَعَا بِبَدَنَةٍ فَأَشْعَرَهَا مِنْ صَفْحَةِ سَنَامِهَا الأَيْمَنِ ثُمَّ سَلَتَ عَنْهَا الدَّمَ وَقَلَّدَهَا بِنَعْلَيْنِ ثُمَّ أُتِيَ بِرَاحِلَتِهِ فَلَمَّا قَعَدَ عَلَيْهَا وَاسْتَوَتْ بِهِ عَلَى الْبَيْدَاءِ أَهَلَّ بِالْحَجِّ ‏.‏\hadithno{1752}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1243)}\hadithtrans{Ibn `Abbas said :The Messenger of Allah (SWAS) offered the noon prayer at Dhu al-Hulaifah. He then sent for a camel and made incision in the right side of its hump ; he then took out the blood by pressing it and tied two shoes in its neck. He then rode on his mount (camel) and reached al-Baida, he raised his voice for the talbiyah for performing Hajj}}
\hadithdefcmd{abudawud}{1753}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، بِهَذَا الْحَدِيثِ بِمَعْنَى أَبِي الْوَلِيدِ قَالَ ثُمَّ سَلَتَ الدَّمَ بِيَدِهِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ هَمَّامٌ قَالَ سَلَتَ الدَّمَ عَنْهَا بِإِصْبَعِهِ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا مِنْ سُنَنِ أَهْلِ الْبَصْرَةِ الَّذِي تَفَرَّدُوا بِهِ ‏.‏\hadithno{1753}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by Shu’bah through a different chain of narrators similar to that reported by Abu al-Walid. This version adds he then took out the blood by pressing it with his hand. Abu Dawud said :Hammam’s version has the words “He took out the blood by pressing with his fingers”. Abu Dawud said this tradition has been narrated by the people of Basrah who alone are its transmitters}}
\hadithdefcmd{abudawud}{1754}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَمَرْوَانَ، أَنَّهُمَا قَالاَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ فَلَمَّا كَانَ بِذِي الْحُلَيْفَةِ قَلَّدَ الْهَدْىَ وَأَشْعَرَهُ وَأَحْرَمَ ‏.‏\hadithno{1754}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Miswar bin Makhramah and al-Marwan said the Messenger of Allah (SWAS) proceeded in the year of al-Hudaibiyyah (to Makkah). When he reached Dhu al-Hulaifah, he tied (garlanded) something in the neck of the sacrificial camel (which He took along with him), and made incision in its hump and put on Ihram}}
\hadithdefcmd{abudawud}{1755}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهْدَى غَنَمًا مُقَلَّدَةً ‏.‏\hadithno{1755}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1701) Sahih Muslim (1321)}\hadithtrans{Ai’shah said :The Messenger of Allah (SWAS) once brought sheep (or goats) for sacrifice to the house (at the Ka’bah) and garlanded them}}
\hadithdefcmd{abudawud}{1756}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، - قَالَ أَبُو دَاوُدَ أَبُو عَبْدِ الرَّحِيمِ خَالِدُ بْنُ أَبِي يَزِيدَ خَالُ مُحَمَّدِ بْنِ سَلَمَةَ رَوَى عَنْهُ، حَجَّاجُ بْنُ مُحَمَّدٍ - عَنْ جَهْمِ بْنِ الْجَارُودِ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ أَهْدَى عُمَرُ بْنُ الْخَطَّابِ نَجِيبًا فَأُعْطِيَ بِهَا ثَلاَثَمِائَةِ دِينَارٍ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَهْدَيْتُ نَجِيبًا فَأُعْطِيتُ بِهَا ثَلاَثَمِائَةِ دِينَارٍ أَفَأَبِيعُهَا وَأَشْتَرِي بِثَمَنِهَا بُدْنًا قَالَ ‏ "‏ لاَ انْحَرْهَا إِيَّاهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا لأَنَّهُ كَانَ أَشْعَرَهَا ‏.‏\hadithno{1756}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: Umar ibn al-Khattab named a bukhti camel for sacrifice (at hajj). He was offered three hundred dinars for it (as its price). He came to the Prophet (ﷺ) and said: Messenger of Allah, I named a bukhti camel for sacrifice and I was offered for it three hundred dinars. May I sell it and purchase another one for its price? No, sacrifice it. Abu Dawud said: This was due to the fact that 'Umar had made an incision in hump}}
\hadithdefcmd{abudawud}{1757}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا أَفْلَحُ بْنُ حُمَيْدٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ فَتَلْتُ قَلاَئِدَ بُدْنِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ ثُمَّ أَشْعَرَهَا وَقَلَّدَهَا ثُمَّ بَعَثَ بِهَا إِلَى الْبَيْتِ وَأَقَامَ بِالْمَدِينَةِ فَمَا حَرُمَ عَلَيْهِ شَىْءٌ كَانَ لَهُ حِلاًّ ‏.‏\hadithno{1757}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1699) Sahih Muslim (1321)}\hadithtrans{Ai’shah said :I twisted the garlands of the sacrificial animals of the Messenger of Allah (SWAS) with my own hands, after which he made incision in their humps and garlanded them, and sent them as offerings to the house (Kabah), but he himself stayed back at Madinah and nothing which had been lawful for him had been forbidden}}
\hadithdefcmd{abudawud}{1758}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الرَّمْلِيُّ الْهَمْدَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، أَنَّ اللَّيْثَ بْنَ سَعْدٍ، حَدَّثَهُمْ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُهْدِي مِنَ الْمَدِينَةِ فَأَفْتِلُ قَلاَئِدَ هَدْيِهِ ثُمَّ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُ الْمُحْرِمُ ‏.‏\hadithno{1758}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1698) Sahih Muslim (1321)}\hadithtrans{Ai’shah said:The Messenger of Allah (SWAS) would send the sacrificial animals as offerings (to Makkah) from Madinah. I would twist the garlands of the sacrificial animals ; thereafter he would not abstain from anything from which a pilgrim putting on Ihram abstains}}
\hadithdefcmd{abudawud}{1759}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، وَعَنْ إِبْرَاهِيمَ، - زَعَمَ أَنَّهُ سَمِعَهُ مِنْهُمَا، جَمِيعًا وَلَمْ يَحْفَظْ حَدِيثَ هَذَا مِنْ حَدِيثِ هَذَا وَلاَ حَدِيثَ هَذَا مِنْ حَدِيثِ هَذَا - قَالاَ قَالَتْ أُمُّ الْمُؤْمِنِينَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْهَدْىِ فَأَنَا فَتَلْتُ قَلاَئِدَهَا بِيَدِي مِنْ عِهْنٍ كَانَ عِنْدَنَا ثُمَّ أَصْبَحَ فِينَا حَلاَلاً يَأْتِي مَا يَأْتِي الرَّجُلُ مِنْ أَهْلِهِ ‏.‏\hadithno{1759}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1699) Sahih Muslim (1321)}\hadithtrans{Ai’shah said:The Messenger of Allah (SWAS) sent sacrificial camels as offering (to the Ka’bah) and I twisted with my own hands their garlands of coloured wool that we had with us. Next morning he came free from restrictions, having intercourse (with his wife) as a man not wearing Ihram does with his wife}}
\hadithdefcmd{abudawud}{1760}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً ‏.‏ فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ قَالَ إِنَّهَا بَدَنَةٌ ‏.‏ فَقَالَ ‏"‏ ارْكَبْهَا وَيْلَكَ ‏"‏ ‏.‏ فِي الثَّانِيَةِ أَوْ فِي الثَّالِثَةِ ‏.‏\hadithno{1760}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1689) Sahih Muslim (1322)}\hadithtrans{Abu Hurairah said:The Messenger of Allah (SWAS)saw a man driving the sacrificial camel. He said ride on it. He said this is a sacrificial camel. He again said ride on it, bother you, either the second or the third time he spoke}}
\hadithdefcmd{abudawud}{1761}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ عَنْ رُكُوبِ الْهَدْىِ، فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ ارْكَبْهَا بِالْمَعْرُوفِ إِذَا أُلْجِئْتَ إِلَيْهَا حَتَّى تَجِدَ ظَهْرًا ‏"‏ ‏.‏\hadithno{1761}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1324)}\hadithtrans{Abu al-Zubair said:I asked Jabir bin `Abdallah about riding on the sacrificial camels. He said I heard The Messenger of Allah (SWAS) saying ride on them gently when you have nothing else till you find a mount}}
\hadithdefcmd{abudawud}{1762}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ نَاجِيَةَ الأَسْلَمِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ مَعَهُ بِهَدْىٍ فَقَالَ ‏ "‏ إِنْ عَطِبَ مِنْهَا شَىْءٌ فَانْحَرْهُ ثُمَّ اصْبَغْ نَعْلَهُ فِي دَمِهِ ثُمَّ خَلِّ بَيْنَهُ وَبَيْنَ النَّاسِ ‏"‏ ‏.‏\hadithno{1762}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Najiyah al-Aslami: The Messenger of Allah (ﷺ) sent sacrificial camels with him (as offering to the Ka'bah). He then said: If any one of them becomes fatigued, slaughter it, dip its shoes in its blood, and leave it for the people (to eat)}}
\hadithdefcmd{abudawud}{1763}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادٌ، ح حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، - وَهَذَا حَدِيثُ مُسَدَّدٍ - عَنْ أَبِي التَّيَّاحِ، عَنْ مُوسَى بْنِ سَلَمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم فُلاَنًا الأَسْلَمِيَّ وَبَعَثَ مَعَهُ بِثَمَانَ عَشْرَةَ بَدَنَةً فَقَالَ أَرَأَيْتَ إِنْ أُزْحِفَ عَلَىَّ مِنْهَا شَىْءٌ قَالَ ‏"‏ تَنْحَرُهَا ثُمَّ تَصْبُغُ نَعْلَهَا فِي دَمِهَا ثُمَّ اضْرِبْهَا عَلَى صَفْحَتِهَا وَلاَ تَأْكُلْ مِنْهَا أَنْتَ وَلاَ أَحَدٌ مِنْ أَصْحَابِكَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ مِنْ أَهْلِ رُفْقَتِكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الَّذِي تَفَرَّدَ بِهِ مِنْ هَذَا الْحَدِيثِ قَوْلُهُ ‏"‏ وَلاَ تَأْكُلْ مِنْهَا أَنْتَ وَلاَ أَحَدٌ مِنْ أَهْلِ رُفْقَتِكَ ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِ عَبْدِ الْوَارِثِ ‏"‏ ثُمَّ اجْعَلْهُ عَلَى صَفْحَتِهَا ‏"‏ ‏.‏ مَكَانَ ‏"‏ اضْرِبْهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَبَا سَلَمَةَ يَقُولُ إِذَا أَقَمْتَ الإِسْنَادَ وَالْمَعْنَى كَفَاكَ ‏.‏\hadithno{1763}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1325)}\hadithtrans{Ibn Abbas said:The Messenger of Allah (SWAS) sent a man of al-Aslam tribe and sent with him eighteen sacrificial camels (as offering to Makkah). What do you think if any one of them becomes fatigued. He replied : You should sacrifice it then dye its shoe with its blood, then mark with it on its neck. But you or any of your companions should not eat out of it. Abu Dawud said: The following words of this tradition are not supported by any other tradition “You should not eat of it yourself nor any of your companions”. The version of `Abdal Warith has the words “then hang it in its neck” instead of the words “mark or strike with it”. Abu Dawud said I heard Abu Salamah say if the chain of narrators and the meaning are correct, it is sufficient for you}}
\hadithdefcmd{abudawud}{1764}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدٌ، وَيَعْلَى، ابْنَا عُبَيْدٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ لَمَّا نَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بُدْنَهُ فَنَحَرَ ثَلاَثِينَ بِيَدِهِ وَأَمَرَنِي فَنَحَرْتُ سَائِرَهَا ‏.‏\hadithno{1764}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: When the Messenger of Allah (ﷺ) sacrificed the camels, he sacrificed thirty of them with his own hand, and then commanded me (to sacrifice them), so I sacrificed the rest of them}}
\hadithdefcmd{abudawud}{1765}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، ح وَحَدَّثَنَا مُسَدَّدٌ، أَخْبَرَنَا عِيسَى، - وَهَذَا لَفْظُ إِبْرَاهِيمَ - عَنْ ثَوْرٍ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ لُحَىٍّ، عَنْ عَبْدِ اللَّهِ بْنِ قُرْطٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَعْظَمَ الأَيَّامِ عِنْدَ اللَّهِ تَبَارَكَ وَتَعَالَى يَوْمُ النَّحْرِ ثُمَّ يَوْمُ الْقَرِّ ‏"‏ ‏.‏ قَالَ عِيسَى قَالَ ثَوْرٌ وَهُوَ الْيَوْمُ الثَّانِي ‏.‏ قَالَ وَقُرِّبَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم بَدَنَاتٌ خَمْسٌ أَوْ سِتٌّ فَطَفِقْنَ يَزْدَلِفْنَ إِلَيْهِ بِأَيَّتِهِنَّ يَبْدَأُ فَلَمَّا وَجَبَتْ جُنُوبُهَا - قَالَ فَتَكَلَّمَ بِكَلِمَةٍ خَفِيَّةٍ لَمْ أَفْهَمْهَا فَقُلْتُ مَا قَالَ - قَالَ ‏"‏ مَنْ شَاءَ اقْتَطَعَ ‏"‏ ‏.‏\hadithno{1765}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Qurt: The Prophet (ﷺ) said: The greatest day in Allah's sight is the day of sacrifice and next the day of resting which Isa said on the authority of Thawr is the second day. Five or six sacrificial camels were brought to the Messenger of Allah (ﷺ) and they began to draw near to see which he would sacrifice first. When they fell down dead, he said something in a low voice, which I could not catch. So I asked: What did he say? He was told that he had said: Anyone who wants can cut off a piece}}
\hadithdefcmd{abudawud}{1766}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَرْمَلَةَ بْنِ عِمْرَانَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ الأَزْدِيِّ، قَالَ سَمِعْتُ غَرَفَةَ بْنَ الْحَارِثِ الْكِنْدِيَّ، قَالَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ وَأُتِيَ بِالْبُدْنِ فَقَالَ ‏"‏ ادْعُوا لِي أَبَا حَسَنٍ ‏"‏ ‏.‏ فَدُعِيَ لَهُ عَلِيٌّ - رضى الله عنه - فَقَالَ لَهُ ‏"‏ خُذْ بِأَسْفَلِ الْحَرْبَةِ ‏"‏ ‏.‏ وَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَعْلاَهَا ثُمَّ طَعَنَ بِهَا فِي الْبُدْنِ فَلَمَّا فَرَغَ رَكِبَ بَغْلَتَهُ وَأَرْدَفَ عَلِيًّا رضى الله عنه ‏.‏\hadithno{1766}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Arfah ibn al-Harith al-Kandi: I was present with the Messenger of Allah (ﷺ) at the Farewell Pilgrimage. When the sacrificial camels were brought to him, he said: Call AbulHasan (Ali) to me. Ali was then called for and he (the Prophet) said to him: Catch hold of the lower end of the lance, and the Messenger of Allah (ﷺ) himself caught hold of the upper end. He then pierced the camels with it. When he finished slaughtering, he rode on his mule and mounted Ali behind him}}
\hadithdefcmd{abudawud}{1767}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، وَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ سَابِطٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَصْحَابَهُ كَانُوا يَنْحَرُونَ الْبَدَنَةَ مَعْقُولَةَ الْيُسْرَى قَائِمَةً عَلَى مَا بَقِيَ مِنْ قَوَائِمِهَا ‏.‏\hadithno{1767}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Abd al Rahman bin Thabit said:The Prophet (SWAS) and his companions used to sacrifice the camel with its left leg tied and it remained standing on the rest of his legs}}
\hadithdefcmd{abudawud}{1768}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يُونُسُ، أَخْبَرَنِي زِيَادُ بْنُ جُبَيْرٍ، قَالَ كُنْتُ مَعَ ابْنِ عُمَرَ بِمِنًى فَمَرَّ بِرَجُلٍ وَهُوَ يَنْحَرُ بَدَنَتَهُ وَهِيَ بَارِكَةٌ فَقَالَ ابْعَثْهَا قِيَامًا مُقَيَّدَةً سُنَّةَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏\hadithno{1768}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1713) Sahih Muslim (1320)}\hadithtrans{Ziyad bin Jubair said :I was present with Ibn `Umar at Minah. He passed a man who was sacrificing his camel while it was sitting. He said make it stand and tie its leg ; thus follow the practice (sunnah) of Muhammad (SWAS)}}
\hadithdefcmd{abudawud}{1769}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا سُفْيَانُ، - يَعْنِي ابْنَ عُيَيْنَةَ - عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَقُومَ عَلَى بُدْنِهِ وَأَقْسِمَ جُلُودَهَا وَجِلاَلَهَا وَأَمَرَنِي أَنْ لاَ أُعْطِيَ الْجَزَّارَ مِنْهَا شَيْئًا وَقَالَ ‏ "‏ نَحْنُ نُعْطِيهِ مِنْ عِنْدِنَا ‏"‏ ‏.‏\hadithno{1769}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1716) Sahih Muslim (1317)}\hadithtrans{Ali said :The Messenger of Allah (SWAS) commanded me to take charge of (his) sacrificial camels and to distribute the skins and saddle clothes (after sacrifice) as sadaqah. He commanded me not to give anything from it to the butcher. He said we used to give it (the wages) to the butcher ourselves}}
\hadithdefcmd{abudawud}{1770}{حَدَّثَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي خُصَيْفُ بْنُ عَبْدِ الرَّحْمَنِ الْجَزَرِيُّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ عَبَّاسٍ يَا أَبَا الْعَبَّاسِ عَجِبْتُ لاِخْتِلاَفِ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي إِهْلاَلِ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ أَوْجَبَ ‏.‏ فَقَالَ إِنِّي لأَعْلَمُ النَّاسِ بِذَلِكَ إِنَّهَا إِنَّمَا كَانَتْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَجَّةٌ وَاحِدَةٌ فَمِنْ هُنَاكَ اخْتَلَفُوا خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَاجًّا فَلَمَّا صَلَّى فِي مَسْجِدِهِ بِذِي الْحُلَيْفَةِ رَكْعَتَيْهِ أَوْجَبَ فِي مَجْلِسِهِ فَأَهَلَّ بِالْحَجِّ حِينَ فَرَغَ مِنْ رَكْعَتَيْهِ فَسَمِعَ ذَلِكَ مِنْهُ أَقْوَامٌ فَحَفِظْتُهُ عَنْهُ ثُمَّ رَكِبَ فَلَمَّا اسْتَقَلَّتْ بِهِ نَاقَتُهُ أَهَلَّ وَأَدْرَكَ ذَلِكَ مِنْهُ أَقْوَامٌ وَذَلِكَ أَنَّ النَّاسَ إِنَّمَا كَانُوا يَأْتُونَ أَرْسَالاً فَسَمِعُوهُ حِينَ اسْتَقَلَّتْ بِهِ نَاقَتُهُ يُهِلُّ فَقَالُوا إِنَّمَا أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ اسْتَقَلَّتْ بِهِ نَاقَتُهُ ثُمَّ مَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا عَلاَ عَلَى شَرَفِ الْبَيْدَاءِ أَهَلَّ وَأَدْرَكَ ذَلِكَ مِنْهُ أَقْوَامٌ فَقَالُوا إِنَّمَا أَهَلَّ حِينَ عَلاَ عَلَى شَرَفِ الْبَيْدَاءِ وَايْمُ اللَّهِ لَقَدْ أَوْجَبَ فِي مُصَلاَّهُ وَأَهَلَّ حِينَ اسْتَقَلَّتْ بِهِ نَاقَتُهُ وَأَهَلَّ حِينَ عَلاَ عَلَى شَرَفِ الْبَيْدَاءِ ‏.‏ قَالَ سَعِيدٌ فَمَنْ أَخَذَ بِقَوْلِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ أَهَلَّ فِي مُصَلاَّهُ إِذَا فَرَغَ مِنْ رَكْعَتَيْهِ ‏.‏\hadithno{1770}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: Sa'id ibn Jubayr said: I said to Abdullah ibn Abbas: AbulAbbas, I am surprised to see the difference of opinion amongst the companions of the Apostle (ﷺ) about the wearing of ihram by the Messenger of Allah (ﷺ) when he made it obligatory. He replied: I am aware of it more than the people. The Messenger of Allah (ﷺ) performed only one hajj. Hence the people differed among themselves. The Messenger of Allah (ﷺ) came out (from Medina) with the intention of performing hajj. When he offered two rak'ahs of prayer in the mosque at Dhul-Hulayfah, he made it obligatory by wearing it. At the same meeting, he raised his voice in the talbiyah for hajj, when he finished his two rak'ahs. Some people heard it and I retained it from him. He then rode (on the she-camel), and when it (the she-camel) stood up, with him on its back, he raised his voice in the talbiyah and some people heard it at that moment. This is because the people were coming in groups, so they heard him raising his voice calling the talbiyah when his she-camel stood up with him on its back, and they thought that the Messenger of Allah (ﷺ) had raised his voice in the talbiyah when his she-camel stood up with him on its back. The Messenger of Allah (ﷺ) proceeded further; when he ascended the height of al-Bayda' he raised his voice in the talbiyah. Some people heard it at that moment. They thought that he had raised his voice in the talbiyah when he ascended the height of al-Bayda'. I swear by Allah, he raised his voice in the talbiyah at the place where he prayed, and he raised his voice in the talbiyah when his she-camel stood up with him on its back, and he raised his voice in the talbiyah when he ascended the height of al-Bayda'. Sa'id (ibn Jubayr) said; He who follows the view of Ibn Abbas raises his voice in talbiyah (and ihram) at the place of is prayer after he finishes two rak'ahs of his prayer}}
\hadithdefcmd{abudawud}{1771}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّهُ قَالَ بَيْدَاؤُكُمْ هَذِهِ الَّتِي تَكْذِبُونَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهَا مَا أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ مِنْ عِنْدِ الْمَسْجِدِ يَعْنِي مَسْجِدَ ذِي الْحُلَيْفَةِ ‏.‏\hadithno{1771}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1541) Sahih Muslim (1186)}\hadithtrans{Ibn `Umar said this is your al-Baida’ about which you ascribe falsehood to the Messenger of Allah (SWAS). He did not raise his voice in talbiyah but from the masjid, i.e. the mosque of Dhu al-Hulaifah}}
\hadithdefcmd{abudawud}{1772}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ يَا أَبَا عَبْدِ الرَّحْمَنِ رَأَيْتُكَ تَصْنَعُ أَرْبَعًا لَمْ أَرَ أَحَدًا مِنْ أَصْحَابِكَ يَصْنَعُهَا ‏.‏ قَالَ مَا هُنَّ يَا ابْنَ جُرَيْجٍ قَالَ رَأَيْتُكَ لاَ تَمَسُّ مِنَ الأَرْكَانِ إِلاَّ الْيَمَانِيَيْنِ وَرَأَيْتُكَ تَلْبَسُ النِّعَالَ السِّبْتِيَّةَ وَرَأَيْتُكَ تَصْبُغُ بِالصُّفْرَةِ وَرَأَيْتُكَ إِذَا كُنْتَ بِمَكَّةَ أَهَلَّ النَّاسُ إِذَا رَأَوُا الْهِلاَلَ وَلَمْ تُهِلَّ أَنْتَ حَتَّى كَانَ يَوْمُ التَّرْوِيَةِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ أَمَّا الأَرْكَانُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمَسُّ إِلاَّ الْيَمَانِيَيْنِ وَأَمَّا النِّعَالُ السِّبْتِيَّةُ فِإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْبَسُ النِّعَالَ الَّتِي لَيْسَ فِيهَا شَعْرٌ وَيَتَوَضَّأُ فِيهَا فَأَنَا أُحِبُّ أَنْ أَلْبَسَهَا وَأَمَّا الصُّفْرَةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْبُغُ بِهَا فَأَنَا أُحِبُّ أَنْ أَصْبُغَ بِهَا وَأَمَّا الإِهْلاَلُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ حَتَّى تَنْبَعِثَ بِهِ رَاحِلَتُهُ ‏.‏\hadithno{1772}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (166) Sahih Muslim (1187)}\hadithtrans{Ubayd ibn Jurayj said to Abdullah ibn Umar:AbuAbdurRahman, I saw you doing things which I did not see being done by your companions. He asked: What are they, Ibn Jurayj? He replied: I saw you touching only the two Yamani corners; and I saw you wearing shoes having no hair; I saw you dyeing in yellow colour; and I saw you wearing ihram on the eighth of Dhul-Hijjah, whereas the people had worn ihram when they sighted the moon. Abdullah ibn Umar replied: As regards the corners, I have not seen the Messenger of Allah (ﷺ) touching anything (in the Ka'bah) but the two Yamani corners. As for the tanned leather shoes, I have seen the Messenger of Allah (ﷺ) wearing tanned leather shoes, and he would wear them after ablution. Therefore I like to wear them. As regards wearing yellow, I have seen the Messenger of Allah (ﷺ) wearing yellow, so I like to wear with it. As regards shouting the talbiyah, I have seen the Messenger of Allah (ﷺ) raising his voice in talbiyah when his she-camel stood up with him on its back}}
\hadithdefcmd{abudawud}{1773}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ أَنَسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ بِالْمَدِينَةِ أَرْبَعًا وَصَلَّى الْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ ثُمَّ بَاتَ بِذِي الْحُلَيْفَةِ حَتَّى أَصْبَحَ فَلَمَّا رَكِبَ رَاحِلَتَهُ وَاسْتَوَتْ بِهِ أَهَلَّ ‏.‏\hadithno{1773}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1546) Sahih Muslim (690)}\hadithtrans{Anas said :Messenger of Allah (SWAS) prayed four rak’ahs at Madinah and prayed two rak’ahs of afternoon prayer at Dhu-al Hulaifah. He then passed the night at Dhu-al Hulaifah till the morning came. When he rode on his mount and it stood up on its back, he raised his voice in talbiyah}}
\hadithdefcmd{abudawud}{1774}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ ثُمَّ رَكِبَ رَاحِلَتَهُ فَلَمَّا عَلاَ عَلَى جَبَلِ الْبَيْدَاءِ أَهَلَّ ‏.‏\hadithno{1774}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) offered the noon prayer, and then rode on his mount. When he came to the hill of al-Bayda', he raised his voice in talbiyah}}
\hadithdefcmd{abudawud}{1775}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبٌ، - يَعْنِي ابْنَ جَرِيرٍ - قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ مُحَمَّدَ بْنَ إِسْحَاقَ، يُحَدِّثُ عَنْ أَبِي الزِّنَادِ، عَنْ عَائِشَةَ بِنْتِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَتْ قَالَ سَعْدُ بْنُ أَبِي وَقَّاصٍ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِذَا أَخَذَ طَرِيقَ الْفُرْعِ أَهَلَّ إِذَا اسْتَقَلَّتْ بِهِ رَاحِلَتُهُ وَإِذَا أَخَذَ طَرِيقَ أُحُدٍ أَهَلَّ إِذَا أَشْرَفَ عَلَى جَبَلِ الْبَيْدَاءِ ‏.‏\hadithno{1775}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd ibn Abi Waqqas: When the Prophet of Allah (peace be upon him0 undertook his journey by the way of al-Far', he shouted talbiyah when his mount stood up with him on its back. But when he travelled by the way of Uhud, he raised his voice in Talbiyah when he ascended the hill of al-Bayda)}}
\hadithdefcmd{abudawud}{1776}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ هِلاَلِ بْنِ خَبَّابٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ ضُبَاعَةَ بِنْتَ الزُّبَيْرِ بْنِ عَبْدِ الْمُطَّلِبِ، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ الْحَجَّ أَأَشْتَرِطُ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَتْ فَكَيْفَ أَقُولُ قَالَ ‏"‏ قُولِي لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ وَمَحِلِّي مِنَ الأَرْضِ حَيْثُ حَبَسْتَنِي ‏"‏ ‏.‏\hadithno{1776}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn `Abbas said:Duba`ah, daughter of al-Zubair bin `Abd al-Muttalib, came to the Messenger of Allah(SWAS) and said Messenger of Allah (SWAS) I want to perform Hajj; may I make a provision? He said Yes. She asked how should I say? He replied : Say “ Labbaik Allahumma Labbaik (I am at Thy service, Oh Allah, I am at Thy service). The place where I took off Ihram will be where Thou restrainest me.”}}
\hadithdefcmd{abudawud}{1777}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفْرَدَ الْحَجَّ ‏.‏\hadithno{1777}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1211)}\hadithtrans{Ai’shah said :The Messenger of Allah (SWAS) performed Hajj exclusively (without performing `Umrah in the beginning)}}
\hadithdefcmd{abudawud}{1778}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ سَلَمَةَ، ح وَحَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُوَافِينَ هِلاَلَ ذِي الْحِجَّةِ فَلَمَّا كَانَ بِذِي الْحُلَيْفَةِ قَالَ ‏"‏ مَنْ شَاءَ أَنْ يُهِلَّ بِحَجٍّ فَلْيُهِلَّ وَمَنْ شَاءَ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهِلَّ بِعُمْرَةٍ ‏"‏ ‏.‏ قَالَ مُوسَى فِي حَدِيثِ وُهَيْبٍ ‏"‏ فَإِنِّي لَوْلاَ أَنِّي أَهْدَيْتُ لأَهْلَلْتُ بِعُمْرَةٍ ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏"‏ وَأَمَّا أَنَا فَأُهِلُّ بِالْحَجِّ فَإِنَّ مَعِيَ الْهَدْىَ ‏"‏ ‏.‏ ثُمَّ اتَّفَقُوا فَكُنْتُ فِيمَنْ أَهَلَّ بِعُمْرَةٍ فَلَمَّا كَانَ فِي بَعْضِ الطَّرِيقِ حِضْتُ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ مَا يُبْكِيكِ ‏"‏ ‏.‏ قُلْتُ وَدِدْتُ أَنِّي لَمْ أَكُنْ خَرَجْتُ الْعَامَ ‏.‏ قَالَ ‏"‏ ارْفُضِي عُمْرَتَكِ وَانْقُضِي رَأْسَكِ وَامْتَشِطِي ‏"‏ ‏.‏ قَالَ مُوسَى ‏"‏ وَأَهِلِّي بِالْحَجِّ ‏"‏ ‏.‏ وَقَالَ سُلَيْمَانُ ‏"‏ وَاصْنَعِي مَا يَصْنَعُ الْمُسْلِمُونَ فِي حَجِّهِمْ ‏"‏ ‏.‏ فَلَمَّا كَانَ لَيْلَةُ الصَّدَرِ أَمَرَ - يَعْنِي رَسُولَ اللَّهِ صلى الله عليه وسلم - عَبْدَ الرَّحْمَنِ فَذَهَبَ بِهَا إِلَى التَّنْعِيمِ ‏.‏ زَادَ مُوسَى فَأَهَلَّتْ بِعُمْرَةٍ مَكَانَ عُمْرَتِهَا وَطَافَتْ بِالْبَيْتِ فَقَضَى اللَّهُ عُمْرَتَهَا وَحَجَّهَا ‏.‏ قَالَ هِشَامٌ وَلَمْ يَكُنْ فِي شَىْءٍ مِنْ ذَلِكَ هَدْىٌ ‏.‏ قَالَ أَبُو دَاوُدَ زَادَ مُوسَى فِي حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ فَلَمَّا كَانَتْ لَيْلَةُ الْبَطْحَاءِ طَهُرَتْ عَائِشَةُ رضى الله عنها ‏.‏\hadithno{1778}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ai’shah said :We went out along with The Messenger of Allah (SWAS) when the moon of the month of Dhu al-Hijja was going to appear shortly. When he reached Dhu al-Hulaifah he said : Anyone who wants to perform Hajj should raise his voice in Talbiyah for Hajj (after wearing Ihram); and he who wants to perform `Umrah should raise his voice in talbiyah for an `Umrah. The narrator Musa in the version of Wuhaib reported him (the Prophet) as saying if there were no sacrificial animals with me, I would raise my voice in talbiyah for an `Umrah. But according to the version of Hammad bin Salamah, he said as for myself, I shall raise my voice in talbiyah for Hajj because I have sacrificial animal with me. The agreed version goes I (Ai’shah) was one of those persons who wore Ihram for an ‘Umrah. But on my way (to Makkah) I menstruated. The Messenger of Allah (SWAS) entered upon me while I was weeping. He asked why are you weeping? I wished I would not come out (for Hajj) this year. He said give up your `Umrah; untie your hair and comb. The version of Musa said and raise your voice in talbiyah for Hajj (after wearing Ihram). Sulaiman’s version goes and do as all the Muslims do during their Hajj. When the night for performing the obligatory circumambulation (tawaf al-Ziyarah) came, the Messenger of Allah (SWAS) commanded `Abd al-Rahman. He took her to al-Tan’im (instead of the words “her ‘Umrah”). She went round the Ka’bah. Allah thus completed both her ‘Umrah and Hajj. Hisham said : No sacrificial animal was offered during all this time. In the version of Hammad bin Salamah, the narrator Musa added when the night of al-Batha came Ai’ shah was purified}}
\hadithdefcmd{abudawud}{1779}{حَدَّثَنَا الْقَعْنَبِيُّ عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ فَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِحَجٍّ وَعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِالْحَجِّ وَأَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ فَأَمَّا مَنْ أَهَلَّ بِالْحَجِّ أَوْ جَمَعَ الْحَجَّ وَالْعُمْرَةَ فَلَمْ يَحِلُّوا حَتَّى كَانَ يَوْمُ النَّحْرِ ‏.‏\hadithno{1779}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1562) Sahih Muslim (1211)}\hadithtrans{Ai’shah wife the Prophet (SWAS) narrated we went out with the Messenger of Allah (SWAS) at the farewell pilgrimage. Some of us had put on Ihram for `Umrah and some both for Hajj and `Umrah, when the Messenger of Allah (SWAS) had put on Ihram for Hajj only.He who had put on Ihram for 'Umrah, put off Ihram after performing `Umrah and he who had worn Ihram both for Hajj and `Umrah or only for Hajj did not take it off till the tenth (of the month)}}
\hadithdefcmd{abudawud}{1780}{حَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، عَنْ أَبِي الأَسْوَدِ، بِإِسْنَادِهِ مِثْلَهُ زَادَ فَأَمَّا مَنْ أَهَلَّ بِعُمْرَةٍ فَأَحَلَّ ‏.‏\hadithno{1780}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1562) Sahih Muslim (1211)}\hadithtrans{The aforesaid tradition has also been narrated by Abu al-Aswad through a different chain of narrators. This version adds he who raises his voice in talbiyah for `Umrah (and wearing Ihram for it) should put off Ihram after performing `Umrah}}
\hadithdefcmd{abudawud}{1781}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ فَأَهْلَلْنَا بِعُمْرَةٍ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُهِلَّ بِالْحَجِّ مَعَ الْعُمْرَةِ ثُمَّ لاَ يَحِلُّ حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ ‏.‏ فَقَدِمْتُ مَكَّةَ وَأَنَا حَائِضٌ وَلَمْ أَطُفْ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَشَكَوْتُ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْقُضِي رَأْسَكِ وَامْتَشِطِي وَأَهِلِّي بِالْحَجِّ وَدَعِي الْعُمْرَةَ ‏"‏ ‏.‏ قَالَتْ فَفَعَلْتُ فَلَمَّا قَضَيْنَا الْحَجَّ أَرْسَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ إِلَى التَّنْعِيمِ فَاعْتَمَرْتُ فَقَالَ ‏"‏ هَذِهِ مَكَانَ عُمْرَتِكِ ‏"‏ ‏.‏ قَالَتْ فَطَافَ الَّذِينَ أَهَلُّوا بِالْعُمْرَةِ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ حَلُّوا ثُمَّ طَافُوا طَوَافًا آخَرَ بَعْدَ أَنْ رَجَعُوا مِنْ مِنًى لِحَجِّهِمْ وَأَمَّا الَّذِينَ كَانُوا جَمَعُوا الْحَجَّ وَالْعُمْرَةَ فَإِنَّمَا طَافُوا طَوَافًا وَاحِدًا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ إِبْرَاهِيمُ بْنُ سَعْدٍ وَمَعْمَرٌ عَنِ ابْنِ شِهَابٍ نَحْوَهُ لَمْ يَذْكُرُوا طَوَافَ الَّذِينَ أَهَلُّوا بِعُمْرَةٍ وَطَوَافَ الَّذِينَ جَمَعُوا الْحَجَّ وَالْعُمْرَةَ ‏.‏\hadithno{1781}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1556) Sahih Muslim (1211)}\hadithtrans{Ai’shah the wife of the Prophet (SWAS) said :We went out with the Messenger of Allah (SWAS) at the farewell pilgrimage and raised the voice in talbiyah for an ‘Umrah. The Apostel of Allah (SWAS) said those who have brought the sacrificial animals with them should raise their voices in talbiyah for Hajj along with an ‘Umrah and they should not put off their Ihram till they do so after performing them both. I came to Makkah while I was menstruating and I did not go round the House (the Ka’bah) or run between al-Safa and al-Marwah. I complained about this to the Messenger of Allah (SWAS) he said: Undo your hair, comb it and raise your voice in talbiyah for Hajj and let `Umrah go. She said I did so. When we performed Hajj, the Messenger of Allah (SWAS) sent me along with `Abd al-Rahman bin Abu Bakr to al-Ta’nim and I performed `Umrah. He said, this is `Umrah in place of the one you had missed. She said those who had raised their voices in talbiyah for `Umrah put off Ihram after circumambulating the House (the Ka’bah) and after running between al-Safa and al-Marwa. Then they performed another circumambulation for their Hajj after they returned from Mina but those who combined Hajj and `Umrah performed only one circumambulation}}
\hadithdefcmd{abudawud}{1782}{حَدَّثَنَا أَبُو سَلَمَةَ، مُوسَى بْنُ إِسْمَاعِيلَ حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ لَبَّيْنَا بِالْحَجِّ حَتَّى إِذَا كُنَّا بِسَرِفَ حِضْتُ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ مَا يُبْكِيكِ يَا عَائِشَةُ ‏"‏ ‏.‏ فَقُلْتُ حِضْتُ لَيْتَنِي لَمْ أَكُنْ حَجَجْتُ ‏.‏ فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ إِنَّمَا ذَلِكَ شَىْءٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ ‏"‏ ‏.‏ فَقَالَ ‏"‏ انْسُكِي الْمَنَاسِكَ كُلَّهَا غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ ‏"‏ ‏.‏ فَلَمَّا دَخَلْنَا مَكَّةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ شَاءَ أَنْ يَجْعَلَهَا عُمْرَةً فَلْيَجْعَلْهَا عُمْرَةً إِلاَّ مَنْ كَانَ مَعَهُ الْهَدْىُ ‏"‏ ‏.‏ قَالَتْ وَذَبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نِسَائِهِ الْبَقَرَ يَوْمَ النَّحْرِ فَلَمَّا كَانَتْ لَيْلَةُ الْبَطْحَاءِ وَطَهُرَتْ عَائِشَةُ قَالَتْ يَا رَسُولَ اللَّهِ أَتَرْجِعُ صَوَاحِبِي بِحَجٍّ وَعُمْرَةٍ وَأَرْجِعُ أَنَا بِالْحَجِّ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ فَذَهَبَ بِهَا إِلَى التَّنْعِيمِ فَلَبَّتْ بِالْعُمْرَةِ ‏.‏\hadithno{1782}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1211)}\hadithtrans{Ai’shah said :We raised our voices in talbiyah for Hajj. When we reached Sarif, I menstruated. The Messenger of Allah (SWAS) came upon me while I was weeping. He asked, why are your weeping, Ai’shah? I replied, I menstruated. Would that I had not come out for performing Hajj. He said : Glory be to Allah, this is a thing prescribed by Allah on the daughters of Adam. He said perform all the rites of Hajj but do not go round the House (the Ka’bah). When we entered Makkah, the Messenger of Allah (SWAS) said he who desires to make (his Hajj) an `Umrah may do so, except those who have sacrificial animals with them. The Messenger of Allah (SWAS) sacrificed a cow on behalf of his wives on the day of sacrifice. When the night of al-Batha came, and Ai’shah was purified she said to the Messenger of Allah (SWAS) my fellow female pilgrims will return after performing Hajj and `Umrah and I shall return after performing only Hajj? He therefore, ordered `Abd al-Rahman bin Abu Bakr who took her to al-Ta’nim. She uttered there talbiyah for `Umrah}}
\hadithdefcmd{abudawud}{1783}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ نَرَى إِلاَّ أَنَّهُ الْحَجُّ فَلَمَّا قَدِمْنَا تَطَوَّفْنَا بِالْبَيْتِ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ أَنْ يُحِلَّ فَأَحَلَّ مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ ‏.‏\hadithno{1783}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1561) Sahih Muslim (1211)}\hadithtrans{A’ishah said “We went out with the Messenger of Allah(ﷺ) and we thought it nothing but a Hajj. When we came, we circumambulated the House (the Ka’bah). The Messenger of Allah(ﷺ) then commanded those who did not bring the sacrificial animals with them to take off their ihram. Therefore those who did not bring the sacrificial animals with them took off their ihram}}
\hadithdefcmd{abudawud}{1784}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ لَمَا سُقْتُ الْهَدْىَ ‏"‏ ‏.‏ قَالَ مُحَمَّدٌ أَحْسِبُهُ قَالَ ‏"‏ وَلَحَلَلْتُ مَعَ الَّذِينَ أَحَلُّوا مِنَ الْعُمْرَةِ ‏"‏ ‏.‏ قَالَ أَرَادَ أَنْ يَكُونَ أَمْرُ النَّاسِ وَاحِدًا ‏.‏\hadithno{1784}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{A’ishah reported the Apostle of Allaah(ﷺ) as saying “If I had known beforehand about my affair what I have come to know later, I would not have brought the sacrificial animals with me. The narrator Muhammad(bin Yahya) said “ I think he(’Uthman bin ‘Umar) said and I would have taken off my ihram with those who have put their ihram after performing ‘Umrah. He said “By this he intended that all the people might have performed equal rites(of Hajj)}}
\hadithdefcmd{abudawud}{1785}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَقْبَلْنَا مُهِلِّينَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ مُفْرَدًا وَأَقْبَلَتْ عَائِشَةُ مُهِلَّةً بِعُمْرَةٍ حَتَّى إِذَا كَانَتْ بِسَرِفَ عَرَكَتْ حَتَّى إِذَا قَدِمْنَا طُفْنَا بِالْكَعْبَةِ وَبِالصَّفَا وَالْمَرْوَةِ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُحِلَّ مِنَّا مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ قَالَ فَقُلْنَا حِلُّ مَاذَا فَقَالَ ‏"‏ الْحِلُّ كُلُّهُ ‏"‏ ‏.‏ فَوَاقَعْنَا النِّسَاءَ وَتَطَيَّبْنَا بِالطِّيبِ وَلَبِسْنَا ثِيَابَنَا وَلَيْسَ بَيْنَنَا وَبَيْنَ عَرَفَةَ إِلاَّ أَرْبَعُ لَيَالٍ ثُمَّ أَهْلَلْنَا يَوْمَ التَّرْوِيَةِ ثُمَّ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عَائِشَةَ فَوَجَدَهَا تَبْكِي فَقَالَ ‏"‏ مَا شَأْنُكِ ‏"‏ ‏.‏ قَالَتْ شَأْنِي أَنِّي قَدْ حِضْتُ وَقَدْ حَلَّ النَّاسُ وَلَمْ أَحْلِلْ وَلَمْ أَطُفْ بِالْبَيْتِ وَالنَّاسُ يَذْهَبُونَ إِلَى الْحَجِّ الآنَ ‏.‏ فَقَالَ ‏"‏ إِنَّ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ فَاغْتَسِلِي ثُمَّ أَهِلِّي بِالْحَجِّ ‏"‏ ‏.‏ فَفَعَلَتْ ‏.‏ وَوَقَفَتِ الْمَوَاقِفَ حَتَّى إِذَا طَهُرَتْ طَافَتْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ قَالَ ‏"‏ قَدْ حَلَلْتِ مِنْ حَجِّكِ وَعُمْرَتِكِ جَمِيعًا ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أَجِدُ فِي نَفْسِي أَنِّي لَمْ أَطُفْ بِالْبَيْتِ حِينَ حَجَجْتُ ‏.‏ قَالَ ‏"‏ فَاذْهَبْ بِهَا يَا عَبْدَ الرَّحْمَنِ فَأَعْمِرْهَا مِنَ التَّنْعِيمِ ‏"‏ ‏.‏ وَذَلِكَ لَيْلَةَ الْحَصْبَةِ ‏.‏\hadithno{1785}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1213)}\hadithtrans{Jabir said “We went out along with the Messenger of Allah(ﷺ) raising our voices in talbiyah for Hakk alone(Ifrad) while A’ishah raised her voice in talbiyah for an ‘Umrah. When she reached Sarif, she menstruated. When we came to (Makkah) we circumambulated the Ka’bah and ran between al Safa’ and al Marwah. The Messenger of Allah(ﷺ) then commanded us that those who had not brought sacrificial animals withthem should put off their ihram (after ‘Umrah). We asked “Which acts are lawful(and which not)? He replied All acts are lawful (that are permissible usually). We had therefore intercourse with our wives, used perfumes, put on our clothes. There remained only four days to perform Hajj at ‘Arafah. We then raised our voice in talbiyah (wearing Ihram for Hajj) on the eighth of Dhu al Hijjah. The Messenger of Allah(ﷺ) entered upon A’ishah and found her weeping. He said What is the matter with you? My problem is that I have menstruated, while the people have put on their ihram but I have not done so, nor did I go round the House(the Ka’bah). Now the people are proceeding for Hajj. He said This is a thing destined by Allah to the daughters of Adam. Take a bath, then raise your voice in talbiyah for Hajj(i.e, wear ihram for Hajj). She took a abtah and performed all the rites of the Hajj(lit. she stayed at all those places where the pilgrims stay). When she was purified, she circumambulated the House (the Ka’bah), and ran between al Safa’ and al Marwah. He (the Prophet) said “Now you have performed both your Hajj and your ‘Umrah. She said Messenger of Allah, I have some misgiving in my mind that I did not go round the Ka’bah when I performed Hajj (in the beginning). He said ‘Abd al Rahman (her brother), take her and have her perform ‘Umrah from Al Tan’im. This happened on the night of Al Hasbah(i.e., the fourteenth of Dhu Al Hijjah)}}
\hadithdefcmd{abudawud}{1786}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى عَائِشَةَ بِبَعْضِ هَذِهِ الْقِصَّةِ قَالَ عِنْدَ قَوْلِهِ ‏"‏ وَأَهِلِّي بِالْحَجِّ ‏"‏ ‏.‏ ‏"‏ ثُمَّ حُجِّي وَاصْنَعِي مَا يَصْنَعُ الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ وَلاَ تُصَلِّي ‏"‏ ‏.‏\hadithno{1786}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1213)}\hadithtrans{The aforesaid tradition has also been transmitted by Jabir through a different chain of narrators. This version has The Prophet(ﷺ) said “Raise your voice in talbiyah for Hajj and then perform Hajj, and do so all the pilgrims do, except that you should not circumambulate the Hose(the Ka’bah) and should not pray}}
\hadithdefcmd{abudawud}{1787}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدٍ، أَخْبَرَنِي أَبِي، حَدَّثَنِي الأَوْزَاعِيُّ، حَدَّثَنِي مَنْ، سَمِعَ عَطَاءَ بْنَ أَبِي رَبَاحٍ، حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، قَالَ أَهْلَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ خَالِصًا لاَ يُخَالِطُهُ شَىْءٌ فَقَدِمْنَا مَكَّةَ لأَرْبَعِ لَيَالٍ خَلَوْنَ مِنْ ذِي الْحِجَّةِ فَطُفْنَا وَسَعَيْنَا ثُمَّ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَحِلَّ وَقَالَ ‏"‏ لَوْلاَ هَدْيِي لَحَلَلْتُ ‏"‏ ‏.‏ ثُمَّ قَامَ سُرَاقَةُ بْنُ مَالِكٍ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ مُتْعَتَنَا هَذِهِ أَلِعَامِنَا هَذَا أَمْ لِلأَبَدِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَلْ هِيَ لِلأَبَدِ ‏"‏ ‏.‏ قَالَ الأَوْزَاعِيُّ سَمِعْتُ عَطَاءَ بْنَ أَبِي رَبَاحٍ يُحَدِّثُ بِهَذَا فَلَمْ أَحْفَظْهُ حَتَّى لَقِيتُ ابْنَ جُرَيْجٍ فَأَثْبَتَهُ لِي ‏.‏\hadithno{1787}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7367) Sahih Muslim (1216)}\hadithtrans{Jabir bin Abdullah said “We raised our voices in talbiyah along with the Apostle of Allaah(ﷺ) exclusively for Hajj, not combining anything with it. When we came to Makkah four days of Dhu al Hijjah had already passed. We the circumambulated (the Ka’bah) and ran between Al Safa’ and Al Marwah . The Apostle of Allaah(ﷺ) then commanded us to put off ihram. He said if I had not brought the sacrificial animals, I would have taken off Ihram. Suraqah bin Malik then stood up and said Apostle of Allaah , what do you think, have you provided this facility to us for this year alone or forever? The Apostle of Allaah said No, this forever and forever. Al Awza’l said I heard Ata bin Abi Rabah narrating this tradition, but I did not memorize it till I met Ibn Juraij who confirmed it for me}}
\hadithdefcmd{abudawud}{1788}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ لأَرْبَعِ لَيَالٍ خَلَوْنَ مِنْ ذِي الْحِجَّةِ فَلَمَّا طَافُوا بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اجْعَلُوهَا عُمْرَةً إِلاَّ مَنْ كَانَ مَعَهُ الْهَدْىُ ‏"‏ ‏.‏ فَلَمَّا كَانَ يَوْمُ التَّرْوِيَةِ أَهَلُّوا بِالْحَجِّ فَلَمَّا كَانَ يَوْمُ النَّحْرِ قَدِمُوا فَطَافُوا بِالْبَيْتِ وَلَمْ يَطُوفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏\hadithno{1788}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir said The Apostle of Allaah(ﷺ) and his companions came to Makkah on the fourth of Dhu Al Hijjah. When they circumambulated the Ka’bah and ran between al Safa’ and al Marwah the Apostle of Allaah(ﷺ) said Change this (Hajj) into ‘Umrah, except those who have brought the sacrificial animals with them. When the eighth of Dhul Al Hijjah came, they raised their voices in talbiyah for Hall. When the tenth of Dhul Al Hijjah came, they circumambulated the Ka’bah, but did not run between al Safa’ and Al Marwah}}
\hadithdefcmd{abudawud}{1789}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا حَبِيبٌ، - يَعْنِي الْمُعَلِّمَ - عَنْ عَطَاءٍ، حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهَلَّ هُوَ وَأَصْحَابُهُ بِالْحَجِّ وَلَيْسَ مَعَ أَحَدٍ مِنْهُمْ يَوْمَئِذٍ هَدْىٌ إِلاَّ النَّبِيَّ صلى الله عليه وسلم وَطَلْحَةَ وَكَانَ عَلِيٌّ - رضى الله عنه - قَدِمَ مِنَ الْيَمَنِ وَمَعَهُ الْهَدْىُ فَقَالَ أَهْلَلْتُ بِمَا أَهَلَّ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ أَصْحَابَهُ أَنْ يَجْعَلُوهَا عُمْرَةً يَطُوفُوا ثُمَّ يُقَصِّرُوا وَيَحِلُّوا إِلاَّ مَنْ كَانَ مَعَهُ الْهَدْىُ فَقَالُوا أَنَنْطَلِقُ إِلَى مِنًى وَذُكُورُنَا تَقْطُرُ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَوْ أَنِّي اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا أَهْدَيْتُ وَلَوْلاَ أَنَّ مَعِيَ الْهَدْىَ لأَحْلَلْتُ ‏"‏ ‏.‏\hadithno{1789}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1651)}\hadithtrans{Jabir bin Abdullah said The Apostle of Allaah(ﷺ) and his companions raised their voices in talbiyah for Hajj. No one of them had brought the sacrificial animals with them except the Prophet(ﷺ) and Talhah. Ali (may Allaah be pleased with him) had returned from Yemen and had brought sacrificial animals with him. He said I raised my voice in talbiyah for which the Apostle of Allaah (ﷺ) raised his voice. The Prophet (ﷺ) commanded his companions to change it into ‘Umrah and clip their hair after running (between Al Safa’ and Al Marwah), and then take off their ihram except those who brought the sacrificial animals with them. They remarked should we go to Mina with our penises dripping with prostatic fluid? These remarks reached the Apostle of Allaah(ﷺ). Thereupon he said “had I known before hand about my affair what I have come to know later, I would not have brought sacrificial animals. Had I not brought sacrificial animals with me, I would have put off my ihram. “}}
\hadithdefcmd{abudawud}{1790}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرٍ، حَدَّثَهُمْ عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ هَذِهِ عُمْرَةٌ اسْتَمْتَعْنَا بِهَا فَمَنْ لَمْ يَكُنْ عِنْدَهُ هَدْىٌ فَلْيَحِلَّ الْحِلَّ كُلَّهُ وَقَدْ دَخَلَتِ الْعُمْرَةُ فِي الْحَجِّ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا مُنْكَرٌ إِنَّمَا هُوَ قَوْلُ ابْنِ عَبَّاسٍ ‏.‏\hadithno{1790}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1241)}\hadithtrans{Ibn ‘Abbas reported the Prophet (ﷺ) as saying This is an ‘Umrah from which we have benefitted. Anyone who has brought sacrificial animal with him should take off ihram totally. ‘Umrah has been included in Hajj till the Day of Judgment. Abu Dawud said This is a munkar (uncommon) tradition. This is in fact the statement of Ibn ‘Abbas himself}}
\hadithdefcmd{abudawud}{1791}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنِي أَبِي، حَدَّثَنَا النَّهَّاسُ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَهَلَّ الرَّجُلُ بِالْحَجِّ ثُمَّ قَدِمَ مَكَّةَ فَطَافَ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ فَقَدْ حَلَّ وَهِيَ عُمْرَةٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ جُرَيْجٍ عَنْ رَجُلٍ عَنْ عَطَاءٍ دَخَلَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم مُهِلِّينَ بِالْحَجِّ خَالِصًا فَجَعَلَهَا النَّبِيُّ صلى الله عليه وسلم عُمْرَةً ‏.‏\hadithno{1791}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas reported the Prophet(ﷺ) as saying If a man raises his voice in talbiya for Hajj, then he comes to Makkah, goes round the House(the Ka’bah) and runs between Al Safa’ and Al Marwah he may take off his ihram. That will be considered as ihram for ‘Umrah. Abu Dawud said Ibn Juraij narrated from a man on the authority of ‘Ata that the companions of the Prophet (ﷺ) entered Makkah raising their voices in talbiyah for Hajj alone, but the Prophet (ﷺ) changed it to ‘Umrah}}
\hadithdefcmd{abudawud}{1792}{حَدَّثَنَا الْحَسَنُ بْنُ شَوْكَرٍ، وَأَحْمَدُ بْنُ مَنِيعٍ، قَالاَ حَدَّثَنَا هُشَيْمٌ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، - قَالَ ابْنُ مَنِيعٍ أَخْبَرَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ الْمَعْنَى، - عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَهَلَّ النَّبِيُّ صلى الله عليه وسلم بِالْحَجِّ فَلَمَّا قَدِمَ طَافَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ - وَقَالَ ابْنُ شَوْكَرٍ وَلَمْ يُقَصِّرْ ثُمَّ اتَّفَقَا - وَلَمْ يَحِلَّ مِنْ أَجْلِ الْهَدْىِ وَأَمَرَ مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ أَنْ يَطُوفَ وَأَنْ يَسْعَى وَيُقَصِّرَ ثُمَّ يَحِلَّ ‏.‏ زَادَ ابْنُ مَنِيعٍ فِي حَدِيثِهِ أَوْ يَحْلِقَ ثُمَّ يَحِلَّ ‏.‏\hadithno{1792}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) raised his voice in talbiyah for hajj. When he came (to Mecca) he went round the House (the Ka'bah) and ran between as-Safa and al-Marwah. The narrator Ibn Shawkar said: He did not clip his hair, nor did he take off his ihram due to sacrificial animals. But he commanded those who did not bring sacrificial animals with them to go round the Ka'bah, to run between as-Safa and al-Marwah, to clip their hair, and then put off their ihram. The narrator Ibn Mani' added: Or shave their heads, then take off their ihram}}
\hadithdefcmd{abudawud}{1793}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ، أَخْبَرَنِي أَبُو عِيسَى الْخُرَاسَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ الْقَاسِمِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَجُلاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَتَى عُمَرَ بْنَ الْخَطَّابِ - رَضِيَ اللَّهُ عَنْهُ - فَشَهِدَ عِنْدَهُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ الَّذِي قُبِضَ فِيهِ يَنْهَى عَنِ الْعُمْرَةِ قَبْلَ الْحَجِّ ‏.‏\hadithno{1793}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sa'id ibn al-Musayyab: A man from the Companions of the Prophet (ﷺ) came to Umar ibn al-Khattab (may Allah be pleased with him). He bore witness before him that when he (the Prophet) was suffering from a disease of which he died he heard the Messenger of Allah (ﷺ) prohibiting performing of umrah before hajj}}
\hadithdefcmd{abudawud}{1794}{حَدَّثَنَا مُوسَى أَبُو سَلَمَةَ، حَدَّثَنَا حَمَّادٌ، عَنْ قَتَادَةَ، عَنْ أَبِي شَيْخٍ الْهُنَائِيِّ، خَيْوَانَ بْنِ خَلْدَةَ مِمَّنْ قَرَأَ عَلَى أَبِي مُوسَى الأَشْعَرِيِّ مِنْ أَهْلِ الْبَصْرَةِ أَنَّ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ قَالَ لأَصْحَابِ النَّبِيِّ صلى الله عليه وسلم هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كَذَا وَكَذَا وَعَنْ رُكُوبِ جُلُودِ النُّمُورِ قَالُوا نَعَمْ ‏.‏ قَالَ فَتَعْلَمُونَ أَنَّهُ نَهَى أَنْ يُقْرَنَ بَيْنَ الْحَجِّ وَالْعُمْرَةِ فَقَالُوا أَمَّا هَذَا فَلاَ ‏.‏ فَقَالَ أَمَا إِنَّهَا مَعَهُنَّ وَلَكِنَّكُمْ نَسِيتُمْ ‏.‏\hadithno{1794}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'awiyah ibn AbuSufyan: Mu'awiyah said to the Companions of the Prophet (ﷺ): Do you know that the Messenger of Allah (ﷺ) prohibited from doing so and so (and he prohibited from) riding on the skins of leopards? They said: Yes. He again said: You know that he prohibited combining hajj and umrah. They replied: This we do not (know). He said: This was prohibited along with other things, but you forgot}}
\hadithdefcmd{abudawud}{1795}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، وَعَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، وَحُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُمْ سَمِعُوهُ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُلَبِّي بِالْحَجِّ وَالْعُمْرَةِ جَمِيعًا يَقُولُ ‏ "‏ لَبَّيْكَ عُمْرَةً وَحَجًّا لَبَّيْكَ عُمْرَةً وَحَجًّا ‏"‏ ‏.‏\hadithno{1795}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1251)}\hadithtrans{Anas bin Malik said I heard the Apostle of Allaah(ﷺ) uttering talbiyah(labbaik) aloud for both Hajj and ‘Umrah. He was saying in a loud voice “Labbaik for ‘Umrah and Hajj, labbaik for ‘Umrah and Hajj”}}
\hadithdefcmd{abudawud}{1796}{حَدَّثَنَا أَبُو سَلَمَةَ، مُوسَى بْنُ إِسْمَاعِيلَ حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَاتَ بِهَا - يَعْنِي بِذِي الْحُلَيْفَةِ - حَتَّى أَصْبَحَ ثُمَّ رَكِبَ حَتَّى إِذَا اسْتَوَتْ بِهِ عَلَى الْبَيْدَاءِ حَمِدَ اللَّهَ وَسَبَّحَ وَكَبَّرَ ثُمَّ أَهَلَّ بِحَجٍّ وَعُمْرَةٍ وَأَهَلَّ النَّاسُ بِهِمَا فَلَمَّا قَدِمْنَا أَمَرَ النَّاسَ فَحَلُّوا حَتَّى إِذَا كَانَ يَوْمُ التَّرْوِيَةِ أَهَلُّوا بِالْحَجِّ وَنَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَبْعَ بَدَنَاتٍ بِيَدِهِ قِيَامًا ‏.‏ قَالَ أَبُو دَاوُدَ الَّذِي تَفَرَّدَ بِهِ - يَعْنِي أَنَسًا - مِنْ هَذَا الْحَدِيثِ أَنَّهُ بَدَأَ بِالْحَمْدِ وَالتَّسْبِيحِ وَالتَّكْبِيرِ ثُمَّ أَهَلَّ بِالْحَجِّ ‏.‏\hadithno{1796}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1551)}\hadithtrans{Anas said The Prophet(ﷺ) passed the night at Dhu al Hulaifah till the morning came. He then rode (on his she Camel) which stood up with him on her back. When he reached al Baida, he praied Allaah, glorified Him and expressed His greatness. He then raised his voice in talbiyah for Hajj and ‘Umrah. The people too raised their voices in talbiyah for both of them. When we came (to Makkah), he ordered the people to take off their ihram and they did so. When the eight of Dhu Al Hijjah came, they again raised their voices in talbiyah for Hajj (i.e., wore ihram for Hajj). The Apostle of Allaah(ﷺ) sacrificed seven Camels standing with his own hand. Abu Dawud said The version narrated by Anas alone has the words. He began with the praise, glorification and exaltation of Allaah, then he raised his voice in talbiyah for Hajj}}
\hadithdefcmd{abudawud}{1797}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا يُونُسُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كُنْتُ مَعَ عَلِيٍّ حِينَ أَمَّرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْيَمَنِ قَالَ فَأَصَبْتُ مَعَهُ أَوَاقِيَ فَلَمَّا قَدِمَ عَلِيٌّ مِنَ الْيَمَنِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَجَدَ فَاطِمَةَ - رضى الله عنها - قَدْ لَبِسَتْ ثِيَابًا صَبِيغًا وَقَدْ نَضَحَتِ الْبَيْتَ بِنَضُوحٍ فَقَالَتْ مَا لَكَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَمَرَ أَصْحَابَهُ فَأَحَلُّوا قَالَ قُلْتُ لَهَا إِنِّي أَهْلَلْتُ بِإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ لِي ‏"‏ كَيْفَ صَنَعْتَ ‏"‏ ‏.‏ فَقَالَ قُلْتُ أَهْلَلْتُ بِإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ فَإِنِّي قَدْ سُقْتُ الْهَدْىَ وَقَرَنْتُ ‏"‏ ‏.‏ قَالَ فَقَالَ لِي ‏"‏ انْحَرْ مِنَ الْبُدْنِ سَبْعًا وَسِتِّينَ أَوْ سِتًّا وَسِتِّينَ وَأَمْسِكْ لِنَفْسِكَ ثَلاَثًا وَثَلاَثِينَ أَوْ أَرْبَعًا وَثَلاَثِينَ وَأَمْسِكْ لِي مِنْ كُلِّ بَدَنَةٍ مِنْهَا بَضْعَةً ‏"‏ ‏.‏\hadithno{1797}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Bara' ibn Azib: I was with Ali (may Allah be pleased with him) when the Messenger of Allah (ﷺ) appointed him to be the governor of the Yemen. I collected some ounces of gold during my stay with him. When Ali returned from the Yemen to the Messenger of Allah (ﷺ) he said: I found that Fatimah had put on coloured clothes and the smell of the perfume she had used was pervading the house. (He expressed his amazement at the use of coloured clothes and perfume.) She said: What is wrong with you? The Messenger of Allah (ﷺ) has ordered his companions to put off their ihram and they did so. Ali said: I said to her: I raised my voice in talbiyah for which the Prophet (ﷺ) raised his voice (i.e. I wore ihram for qiran). Then I came to the Prophet (ﷺ). He asked (me): How did you do? I replied: I raised my voice in talbiyah, for which the Prophet (ﷺ) raised his voice. He said: I have brought the sacrificial animals with me and combined umrah and hajj. He said to me: Sacrifice sixty-seven or sixty-six camels (for me) and withhold for yourself thirty-three or thirty-four, and withhold a piece (of flesh) for me from every camel}}
\hadithdefcmd{abudawud}{1798}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ الصُّبَىُّ بْنُ مَعْبَدٍ أَهْلَلْتُ بِهِمَا مَعًا ‏.‏ فَقَالَ عُمَرُ هُدِيتَ لِسُنَّةِ نَبِيِّكَ صلى الله عليه وسلم ‏.‏\hadithno{1798}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umar ibn al-Khattab: As-Subayy ibn Ma'bad said: I raised my voice in talbiyah for both of them (i.e. umrah and hajj). Thereupon Umar said: You were guided to the practice (sunnah) of your Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1799}{حَدَّثَنَا مُحَمَّدُ بْنُ قُدَامَةَ بْنِ أَعْيَنَ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ الصُّبَىُّ بْنُ مَعْبَدٍ كُنْتُ رَجُلاً أَعْرَابِيًّا نَصْرَانِيًّا فَأَسْلَمْتُ فَأَتَيْتُ رَجُلاً مِنْ عَشِيرَتِي يُقَالُ لَهُ هُذَيْمُ بْنُ ثُرْمُلَةَ فَقُلْتُ لَهُ يَا هَنَاهُ إِنِّي حَرِيصٌ عَلَى الْجِهَادِ وَإِنِّي وَجَدْتُ الْحَجَّ وَالْعُمْرَةَ مَكْتُوبَيْنِ عَلَىَّ فَكَيْفَ لِي بِأَنْ أَجْمَعَهُمَا قَالَ اجْمَعْهُمَا وَاذْبَحْ مَا اسْتَيْسَرَ مِنَ الْهَدْىِ ‏.‏ فَأَهْلَلْتُ بِهِمَا مَعًا فَلَمَّا أَتَيْتُ الْعُذَيْبَ لَقِيَنِي سَلْمَانُ بْنُ رَبِيعَةَ وَزَيْدُ بْنُ صُوحَانَ وَأَنَا أُهِلُّ بِهِمَا جَمِيعًا فَقَالَ أَحَدُهُمَا لِلآخَرِ مَا هَذَا بِأَفْقَهَ مِنْ بَعِيرِهِ ‏.‏ قَالَ فَكَأَنَّمَا أُلْقِيَ عَلَىَّ جَبَلٌ حَتَّى أَتَيْتُ عُمَرَ بْنَ الْخَطَّابِ فَقُلْتُ لَهُ يَا أَمِيرَ الْمُؤْمِنِينَ إِنِّي كُنْتُ رَجُلاً أَعْرَابِيًّا نَصْرَانِيًّا وَإِنِّي أَسْلَمْتُ وَأَنَا حَرِيصٌ عَلَى الْجِهَادِ وَإِنِّي وَجَدْتُ الْحَجَّ وَالْعُمْرَةَ مَكْتُوبَيْنِ عَلَىَّ فَأَتَيْتُ رَجُلاً مِنْ قَوْمِي فَقَالَ لِي اجْمَعْهُمَا وَاذْبَحْ مَا اسْتَيْسَرَ مِنَ الْهَدْىِ وَإِنِّي أَهْلَلْتُ بِهِمَا مَعًا ‏.‏ فَقَالَ لِي عُمَرُ رضى الله عنه هُدِيتَ لِسُنَّةِ نَبِيِّكَ صلى الله عليه وسلم ‏.‏\hadithno{1799}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated As-Subayy ibn Ma'bad: I was a Christian Bedouin; then I embraced Islam. I came to a man of my tribe, who was called Hudhaym ibn Thurmulah. I said to him. O brother, I am eager to wage war in the cause of Allah (i.e. jihad), and I find that both hajj and umrah are due from me. How can I combine them? He said: Combine them and sacrifice the animal made easily available for you. I, therefore, raised my voice in talbiyah for both of them (i.e. umrah and hajj). When I reached al-Udhayb, Salman ibn Rabi'ah and Zayd ibn Suhan met me while I was raising my voice in talbiyah for both of them. One of them said to the other: This (man) does not have any more understanding than his camel. Thereupon it was as if a mountain fell on me. I came to Umar ibn al-Khattab (may Allah be pleased with him) and said to him: Commander of the Faithful, I was a Christian Bedouin, and I have embraced Islam. I am eager to wage war in the cause of Allah (jihad), and I found that both hajj and umrah were due from me. I came to a man of my tribe who said to me: Combine both of them and sacrifice the animal easily available for you. I have raised my voice in talbiyah for both of them. Umar thereupon said to me: You have been guided to the practice (sunnah) of your Prophet) (ﷺ)}}
\hadithdefcmd{abudawud}{1800}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مِسْكِينٌ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَتَانِي اللَّيْلَةَ آتٍ مِنْ عِنْدِ رَبِّي عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَ وَهُوَ بِالْعَقِيقِ ‏"‏ وَقَالَ صَلِّ فِي هَذَا الْوَادِي الْمُبَارَكِ وَقَالَ عُمْرَةٌ فِي حَجَّةٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الْوَلِيدُ بْنُ مُسْلِمٍ وَعُمَرُ بْنُ عَبْدِ الْوَاحِدِ فِي هَذَا الْحَدِيثِ عَنِ الأَوْزَاعِيِّ ‏"‏ وَقُلْ عُمْرَةٌ فِي حَجَّةٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا رَوَاهُ عَلِيُّ بْنُ الْمُبَارَكِ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ فِي هَذَا الْحَدِيثِ وَقَالَ ‏"‏ وَقُلْ عُمْرَةٌ فِي حَجَّةٍ ‏"‏ ‏.‏\hadithno{1800}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1534)}\hadithtrans{Umar bin Al Khattab heard the Apostle of Allaah(ﷺ) say Someone came to me at night from Allaah the Exalted. The narrator said When he was staying at ‘Aqiq said Pray in his blessed valley. Then he said ‘Umrah has been included in Hajj. Abu Dawud said Al Walid bin Musilm and ‘Umar bin Abd Al Wahid narrated in this version from Al Auza’I the words “And say An ‘Umrah included in Hajj”. Abu Dawud said Ali bin Al Mubarak has also narrated similarly from Yahya bin said Abi Kathir in this version “And say An ‘Umrah included in Hajj”}}
\hadithdefcmd{abudawud}{1801}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ، حَدَّثَنِي الرَّبِيعُ بْنُ سَبْرَةَ، عَنْ أَبِيهِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِعُسْفَانَ قَالَ لَهُ سُرَاقَةُ بْنُ مَالِكٍ الْمُدْلِجِيُّ يَا رَسُولَ اللَّهِ اقْضِ لَنَا قَضَاءَ قَوْمٍ كَأَنَّمَا وُلِدُوا الْيَوْمَ ‏.‏ فَقَالَ ‏ "‏ إِنَّ اللَّهَ تَعَالَى قَدْ أَدْخَلَ عَلَيْكُمْ فِي حَجِّكُمْ هَذَا عُمْرَةً فَإِذَا قَدِمْتُمْ فَمَنْ تَطَوَّفَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ فَقَدْ حَلَّ إِلاَّ مَنْ كَانَ مَعَهُ هَدْىٌ ‏"‏ ‏.‏\hadithno{1801}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Saburah: Ar-Rabi' ibn Saburah said on the authority of his father (Saburah): We went out along with the Messenger of Allah (ﷺ) till we reached Usfan, Suraqah ibn Malik al-Mudlaji said to him: Messenger of Allah, explain to us like the people as if they were born today. He said: Allah, the Exalted, has included this umrah in your hajj. When you come (to Mecca), and he who goes round the House (the Ka'bah), and runs between as-Safa and al-Marwah, is allowed to take off ihram except he who has brought the sacrificial animals with him}}
\hadithdefcmd{abudawud}{1802}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، عَنِ ابْنِ جُرَيْجٍ، ح حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ، حَدَّثَنَا يَحْيَى، - الْمَعْنَى - عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، أَخْبَرَهُ قَالَ قَصَّرْتُ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِشْقَصٍ عَلَى الْمَرْوَةِ ‏.‏ أَوْ رَأَيْتُهُ يُقَصَّرُ عَنْهُ عَلَى الْمَرْوَةِ بِمِشْقَصٍ ‏.‏ قَالَ ابْنُ خَلاَّدٍ إِنَّ مُعَاوِيَةَ لَمْ يَذْكُرْ أَخْبَرَهُ ‏.‏\hadithno{1802}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1730) Sahih Muslim (1246)}\hadithtrans{Ibn ‘Abbas said that Mu’awiyah reported to him I clipped some hair of the Prophet’s(ﷺ) head with a broad iron arrowhead at Al Marwah; or (he said) I saw him that the hair of his head was clipped with a broad iron arrowhead at Al Marwah. The narrator Ibn Khallad said in his version “Mu’awiyah said” and not the word “reported”}}
\hadithdefcmd{abudawud}{1803}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَمَخْلَدُ بْنُ خَالِدٍ، وَمُحَمَّدُ بْنُ يَحْيَى، - الْمَعْنَى - قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ مُعَاوِيَةَ، قَالَ لَهُ أَمَا عَلِمْتَ أَنِّي قَصَّرْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِشْقَصِ أَعْرَابِيٍّ عَلَى الْمَرْوَةِ - زَادَ الْحَسَنُ فِي حَدِيثِهِ - لِحَجَّتِهِ ‏.‏\hadithno{1803}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Abbas said that Mu'awiyah told him:do you not know that I clipped the hair of the head of the Messenger of Allah (ﷺ) with a broad iron arrowhead at al-Marwah? Al-Hasan added in his version: "during his hajj}}
\hadithdefcmd{abudawud}{1804}{حَدَّثَنَا ابْنُ مُعَاذٍ، أَخْبَرَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُسْلِمٍ الْقُرِّيِّ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ أَهَلَّ النَّبِيُّ صلى الله عليه وسلم بِعُمْرَةٍ وَأَهَلَّ أَصْحَابُهُ بِحَجٍّ ‏.‏\hadithno{1804}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1238)}\hadithtrans{Ibn ‘Abbas said The Prophet(ﷺ) raised his voice in talbiyah for ‘Umrah and his companions for Hajj}}
\hadithdefcmd{abudawud}{1805}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، ‏\{‏ عَنْ جَدِّي، ‏\}‏ عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ تَمَتَّعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ بِالْعُمْرَةِ إِلَى الْحَجِّ فَأَهْدَى وَسَاقَ مَعَهُ الْهَدْىَ مِنْ ذِي الْحُلَيْفَةِ وَبَدَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَهَلَّ بِالْعُمْرَةِ ثُمَّ أَهَلَّ بِالْحَجِّ وَتَمَتَّعَ النَّاسُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْعُمْرَةِ إِلَى الْحَجِّ فَكَانَ مِنَ النَّاسِ مَنْ أَهْدَى وَسَاقَ الْهَدْىَ وَمِنْهُمْ مَنْ لَمْ يُهْدِ فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ قَالَ لِلنَّاسِ ‏ "‏ مَنْ كَانَ مِنْكُمْ أَهْدَى فَإِنَّهُ لاَ يَحِلُّ لَهُ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى يَقْضِيَ حَجَّهُ وَمَنْ لَمْ يَكُنْ مِنْكُمْ أَهْدَى فَلْيَطُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ وَلْيُقَصِّرْ وَلْيَحْلِلْ ثُمَّ لْيُهِلَّ بِالْحَجِّ وَلْيُهْدِ فَمَنْ لَمْ يَجِدْ هَدْيًا فَلْيَصُمْ ثَلاَثَةَ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةً إِذَا رَجَعَ إِلَى أَهْلِهِ ‏"‏ ‏.‏ وَطَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ قَدِمَ مَكَّةَ فَاسْتَلَمَ الرُّكْنَ أَوَّلَ شَىْءٍ ثُمَّ خَبَّ ثَلاَثَةَ أَطْوَافٍ مِنَ السَّبْعِ وَمَشَى أَرْبَعَةَ أَطْوَافٍ ثُمَّ رَكَعَ حِينَ قَضَى طَوَافَهُ بِالْبَيْتِ عِنْدَ الْمَقَامِ رَكْعَتَيْنِ ثُمَّ سَلَّمَ فَانْصَرَفَ فَأَتَى الصَّفَا فَطَافَ بِالصَّفَا وَالْمَرْوَةِ سَبْعَةَ أَطْوَافٍ ثُمَّ لَمْ يَحْلِلْ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى قَضَى حَجَّهُ وَنَحَرَ هَدْيَهُ يَوْمَ النَّحْرِ وَأَفَاضَ فَطَافَ بِالْبَيْتِ ثُمَّ حَلَّ مِنْ كُلِّ شَىْءٍ حَرُمَ مِنْهُ وَفَعَلَ النَّاسُ مِثْلَ مَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ أَهْدَى وَسَاقَ الْهَدْىَ مِنَ النَّاسِ ‏.‏\hadithno{1805}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1691) Sahih Muslim (1227)}\hadithtrans{‘Abd Allah bin Umar said At the Farewell Pilgrimage the Apostle of Allaah(ﷺ) put on ihram first for ‘Umrah and afterwards for Hajj and drove the sacrificial animals along with him from Dhu Al Hulaifah. The Apostle of Allaah(ﷺ) first raised his voice in talbiyah for ‘Umrah and afterwards he did so for Hajj; and the people along with the Apostle of Allaah(ﷺ) did it first for ‘Umrah and afterwards for Hajj. Some of the people had brought sacrificial animals and others had not, so when the Apostle of Allaah(ﷺ) came to Makkah , he said to the people. Those of you who have brought sacrificial animals must not treat as lawful anything which has become unlawful for you till you complete your Hajj; but those of you who have not brought sacrificial animals should go round the House(Ka’bah) and run between Al Safa’ and Al Marwah, clip their hair, put off ihram, and afterwards raise their voice in talbiyah for Hajj and bring sacrificial animals. Those who cannot get sacrificial animals should fast three days during Hajj and seven days when they return to their families. The Apostle of Allaah(ﷺ) then performed circumambulation when he came to Makkah first touching the corner then running during three circuits out of seven and walking during four and when he had finished his circumambulation of the House (Ka’bah) he prayed two rak’ahs at Maqam Ibrahim, then giving the salutation and departing he went to Al Safa’ and ran seven times between Al Safa’ and Al Marwah. After that he did not treat anything as lawful which had become unlawful for him till he had completed his Hajj, sacrificed his animals on the day of sacrifice, went quickly and performed the circumambulation of the House(the Ka’bah), after which all that had been unlawful became lawful for him. Those people who had brought sacrificial animals did as the Apostle of Allaah(ﷺ) did}}
\hadithdefcmd{abudawud}{1806}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ حَفْصَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ مَا شَأْنُ النَّاسِ قَدْ حَلُّوا وَلَمْ تَحْلِلْ أَنْتَ مِنْ عُمْرَتِكَ فَقَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي وَقَلَّدْتُ هَدْيِي فَلاَ أَحِلُّ حَتَّى أَنْحَرَ الْهَدْىَ ‏"‏ ‏.‏\hadithno{1806}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1566) Sahih Muslim (1229)}\hadithtrans{Hafsah, wife of the Prophet (ﷺ) said Apostle of Allaah(ﷺ), how is it that the people have put off their ihram and you did not put off your ihram after your ‘Umrah. He said I have matted my hair and garlanded my sacrificial animal, so I shall not put off my ihram till I sacrifice my sacrificial animals}}
\hadithdefcmd{abudawud}{1807}{حَدَّثَنَا هَنَّادٌ، - يَعْنِي ابْنَ السَّرِيِّ - عَنِ ابْنِ أَبِي زَائِدَةَ، أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ سَلِيمِ بْنِ الأَسْوَدِ، أَنَّ أَبَا ذَرٍّ، كَانَ يَقُولُ فِيمَنْ حَجَّ ثُمَّ فَسَخَهَا بِعُمْرَةٍ لَمْ يَكُنْ ذَلِكَ إِلاَّ لِلرَّكْبِ الَّذِينَ كَانُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1807}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Abu Dharr used to say about a person who makes the intention of Hajj but he repeal it for the ‘Umrah (that will not be valid). This cancellation of hajj for ‘Umrah was specially meant for the people who accompanied the Apostle of Allaah(ﷺ)}}
\hadithdefcmd{abudawud}{1808}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - أَخْبَرَنِي رَبِيعَةُ بْنُ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْحَارِثِ بْنِ بِلاَلِ بْنِ الْحَارِثِ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ فَسْخُ الْحَجِّ لَنَا خَاصَّةً أَوْ لِمَنْ بَعْدَنَا قَالَ ‏ "‏ بَلْ لَكُمْ خَاصَّةً ‏"‏ ‏.‏\hadithno{1808}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Bilal ibn al-Harith al-Muzani: I asked: Messenger of Allah, is the (command of) cancelling hajj meant exclusively for us, or for others too? He replied: No, this is meant exclusively for you}}
\hadithdefcmd{abudawud}{1809}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كَانَ الْفَضْلُ بْنُ عَبَّاسٍ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَتْهُ امْرَأَةٌ مِنْ خَثْعَمَ تَسْتَفْتِيهِ فَجَعَلَ الْفَضْلُ يَنْظُرُ إِلَيْهَا وَتَنْظُرُ إِلَيْهِ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْرِفُ وَجْهَ الْفَضْلِ إِلَى الشِّقِّ الآخَرِ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ عَلَى عِبَادِهِ فِي الْحَجِّ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَطِيعُ أَنْ يَثْبُتَ عَلَى الرَّاحِلَةِ أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ وَذَلِكَ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{1809}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1513) Sahih Muslim (1334)}\hadithtrans{‘Abd Allah bin Abbas said Al Fadl bin Abbas was riding the Camel behind the Apostle of Allaah(ﷺ). A woman of the tribe of Khath’am came seeking his (the Prophet’s) decision (about a problem relating to Hajj). Al Fadl began to look at her and she too began to look at him. The Apostle of Allaah(ﷺ) would turn the face of Fadl to the other side. She said Apostle of Allaah(ﷺ) Allaah’s commandment that His servants should perform Hajj has come when my father is an old man and is unable to sit firmly on a Camel. May I perform Hajj on his behalf? He said yes, That was at the Farewell Pilgrimage}}
\hadithdefcmd{abudawud}{1810}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، - بِمَعْنَاهُ - قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ أَبِي رَزِينٍ، - قَالَ حَفْصٌ فِي حَدِيثِهِ رَجُلٌ مِنْ بَنِي عَامِرٍ - أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبِي شَيْخٌ كَبِيرٌ لاَ يَسْتَطِيعُ الْحَجَّ وَلاَ الْعُمْرَةَ وَلاَ الظَّعْنَ ‏.‏ قَالَ ‏ "‏ احْجُجْ عَنْ أَبِيكَ وَاعْتَمِرْ ‏"‏ ‏.‏\hadithno{1810}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuRazin: A man of Banu Amir said: Messenger of Allah, my father is very old, he cannot perform hajj and umrah himself nor can be ride on a mount. He said: Perform hajj and umrah on behalf of your father}}
\hadithdefcmd{abudawud}{1811}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ الطَّالْقَانِيُّ، وَهَنَّادُ بْنُ السَّرِيِّ، - الْمَعْنَى وَاحِدٌ - قَالَ إِسْحَاقُ - حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَمِعَ رَجُلاً يَقُولُ لَبَّيْكَ عَنْ شُبْرُمَةَ ‏.‏ قَالَ ‏"‏ مَنْ شُبْرُمَةَ ‏"‏ ‏.‏ قَالَ أَخٌ لِي أَوْ قَرِيبٌ لِي ‏.‏ قَالَ ‏"‏ حَجَجْتَ عَنْ نَفْسِكَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ حُجَّ عَنْ نَفْسِكَ ثُمَّ حُجَّ عَنْ شُبْرُمَةَ ‏"‏ ‏.‏\hadithno{1811}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) heard a man say: Labbayk (always ready to obey) on behalf of Shubrumah. He asked: Who is Shubrumah? He replied: A brother or relative of mine. He asked: Have you performed hajj on your own behalf? He said: No. He said: perform hajj on your own behalf, then perform it on behalf of Shubrumah}}
\hadithdefcmd{abudawud}{1812}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ تَلْبِيَةَ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَزِيدُ فِي تَلْبِيَتِهِ ‏"‏ لَبَّيْكَ لَبَّيْكَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ بِيَدَيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏"‏ ‏.‏\hadithno{1812}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1549) Sahih Muslim (1184)}\hadithtrans{Ibn ‘Umar said Talbiyah uttered by the Apostle of Allaah(ﷺ) was Labbaik(always ready to obey), O Allaah labbaik, labbaik; Thou hast no partner, praise and grace are Thine, and the Dominion, Thou hast no partner. The narrator said ‘Abd Allaah bin ‘Umar used to add to his talbiyah Labbaik, labbaik, labbaik wa sa’daik(give me blessing after blessing) and good is Thy hands, desire and actions are directed towards Thee}}
\hadithdefcmd{abudawud}{1813}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا جَعْفَرٌ، حَدَّثَنَا أَبِي، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ التَّلْبِيَةَ مِثْلَ حَدِيثِ ابْنِ عُمَرَ قَالَ وَالنَّاسُ يَزِيدُونَ ‏ "‏ ذَا الْمَعَارِجِ ‏"‏ ‏.‏ وَنَحْوَهُ مِنَ الْكَلاَمِ وَالنَّبِيُّ صلى الله عليه وسلم يَسْمَعُ فَلاَ يَقُولُ لَهُمْ شَيْئًا ‏.‏\hadithno{1813}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) raised his voice in talbiyah; he then mentioned the wordings of talbiyah like the tradition narrated by Ibn Umar. The people used to add the words dhal-ma'arij (the Possessor of ladders) and similar other words (to talbiyah) while the Prophet (ﷺ) heard them utter these words, but he did not say anything to them}}
\hadithdefcmd{abudawud}{1814}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ خَلاَّدِ بْنِ السَّائِبِ الأَنْصَارِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَتَانِي جِبْرِيلُ صلى الله عليه وسلم فَأَمَرَنِي أَنْ آمُرَ أَصْحَابِي وَمَنْ مَعِي أَنْ يَرْفَعُوا أَصْوَاتَهُمْ بِالإِهْلاَلِ - أَوْ قَالَ - بِالتَّلْبِيَةِ ‏"‏ ‏.‏ يُرِيدُ أَحَدَهُمَا ‏.‏\hadithno{1814}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated as-Sa'ib al-Ansari: Khalid ibn as-Sa'ib al-Ansari on his father's authority reported the Messenger of Allah (ﷺ) as saying: Gabriel came to me and commanded me to order my Companions to raise their voices in talbiyah}}
\hadithdefcmd{abudawud}{1815}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَبَّى حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ ‏.‏\hadithno{1815}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1685) Sahih Muslim (1280)}\hadithtrans{Al Fadl bin Abbas said The Apostle of Allaah(ﷺ) uttered talbiyah till he threw pebbles at Jamrat Al ‘Aqbah}}
\hadithdefcmd{abudawud}{1816}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ غَدَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ مِنًى إِلَى عَرَفَاتٍ مِنَّا الْمُلَبِّي وَمِنَّا الْمُكَبِّرُ ‏.‏\hadithno{1816}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1284)}\hadithtrans{‘Abd Allah bin Umar said We proceeded along with the Apostle of Allaah(ﷺ) from Mina to ‘Arafat, some of us were uttering talbiyah and the others were shouting “Allaah is most great.”}}
\hadithdefcmd{abudawud}{1817}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا هُشَيْمٌ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُلَبِّي الْمُعْتَمِرُ حَتَّى يَسْتَلِمَ الْحَجَرَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ وَهَمَّامٌ عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ مَوْقُوفًا ‏.‏\hadithno{1817}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: A person who performs umrah should shout talbiyah till he touches the Black Stone. Abu Dawud said: This tradition has been transmitted by 'Abd al-Malik b. Abi Sulaiman and Hammam from 'Ata on the authority of Ibn 'Abbas as his own statement (i.e. the tradition was not attributed to the Prophet)}}
\hadithdefcmd{abudawud}{1818}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، أَخْبَرَنَا ابْنُ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حُجَّاجًا حَتَّى إِذَا كُنَّا بِالْعَرْجِ نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَزَلْنَا فَجَلَسَتْ عَائِشَةُ - رضى الله عنها - إِلَى جَنْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَجَلَسْتُ إِلَى جَنْبِ أَبِي وَكَانَتْ زِمَالَةُ أَبِي بَكْرٍ وَزِمَالَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاحِدَةً مَعَ غُلاَمٍ لأَبِي بَكْرٍ فَجَلَسَ أَبُو بَكْرٍ يَنْتَظِرُ أَنْ يَطْلُعَ عَلَيْهِ فَطَلَعَ وَلَيْسَ مَعَهُ بَعِيرُهُ قَالَ أَيْنَ بَعِيرُكَ قَالَ أَضْلَلْتُهُ الْبَارِحَةَ ‏.‏ قَالَ فَقَالَ أَبُو بَكْرٍ بَعِيرٌ وَاحِدٌ تُضِلُّهُ قَالَ فَطَفِقَ يَضْرِبُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَتَبَسَّمُ وَيَقُولُ ‏"‏ انْظُرُوا إِلَى هَذَا الْمُحْرِمِ مَا يَصْنَعُ ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي رِزْمَةَ فَمَا يَزِيدُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَنْ يَقُولَ ‏"‏ انْظُرُوا إِلَى هَذَا الْمُحْرِمِ مَا يَصْنَعُ ‏"‏ ‏.‏ وَيَتَبَسَّمُ ‏.‏\hadithno{1818}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Asma' bint AbuBakr: We came out for performing hajj along with the Messenger of Allah (ﷺ). When we reached al-Araj, the Messenger of Allah (ﷺ) alighted and we also alighted. Aisha sat beside the Messenger of Allah (ﷺ) and I sat beside my father (AbuBakr). The equipment and personal effects of AbuBakr and of the Messenger of Allah (ﷺ) were placed with AbuBakr's slave on a camel. AbuBakr was sitting and waiting for his arrival. He arrived but he had no camel with him. He asked: Where is your camel? He replied: I lost it last night. AbuBakr said: There was only one camel, even that you have lost. He then began to beat him while the Messenger of Allah (ﷺ) was smiling and saying: Look at this man who is in the sacred state (putting on ihram), what is he doing? Ibn AbuRizmah said: The Messenger of Allah (ﷺ) spoke nothing except the words: Look at this man who is in the sacred state (wearing ihram), what is he doing? He was smiling (when he uttered these words)}}
\hadithdefcmd{abudawud}{1819}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، قَالَ سَمِعْتُ عَطَاءً، أَخْبَرَنَا صَفْوَانُ بْنُ يَعْلَى بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ بِالْجِعْرَانَةِ وَعَلَيْهِ أَثَرُ خَلُوقٍ - أَوْ قَالَ صُفْرَةٍ - وَعَلَيْهِ جُبَّةٌ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ تَأْمُرُنِي أَنْ أَصْنَعَ فِي عُمْرَتِي فَأَنْزَلَ اللَّهُ تَبَارَكَ وَتَعَالَى عَلَى النَّبِيِّ صلى الله عليه وسلم الْوَحْىَ فَلَمَّا سُرِّيَ عَنْهُ قَالَ ‏"‏ أَيْنَ السَّائِلُ عَنِ الْعُمْرَةِ ‏"‏ ‏.‏ قَالَ ‏"‏ اغْسِلْ عَنْكَ أَثَرَ الْخَلُوقِ - أَوْ قَالَ أَثَرَ الصُّفْرَةِ - وَاخْلَعِ الْجُبَّةَ عَنْكَ وَاصْنَعْ فِي عُمْرَتِكَ مَا صَنَعْتَ فِي حَجَّتِكَ ‏"‏ ‏.‏\hadithno{1819}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1789) Sahih Muslim (1180)}\hadithtrans{Narrated Ya'la ibn Umayyah: A man came to the Prophet (ﷺ) when he was at al-Ji'ranah. He was wearing perfume or the mark of saffron was on him and he was wearing a tunic. He said: Messenger of Allah, what do you command me to do while performing my Umrah. In the meantime, Allah, the Exalted, sent a revelation to the Prophet (ﷺ). When he (the Prophet) came to himself gradually, he asked: Where is the man who asking about umrah? (When the man came) he (the Prophet) said: Wash the perfume which is on you, or he said: (Wash) the mark of saffron (the narrator is doubtful), take off the tunic, then do in your umrah as you do in your hajj}}
\hadithdefcmd{abudawud}{1820}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ عَطَاءٍ، عَنْ يَعْلَى بْنِ أُمَيَّةَ، وَهُشَيْمٌ، عَنِ الْحَجَّاجِ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، بِهَذِهِ الْقِصَّةِ قَالَ فِيهِ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اخْلَعْ جُبَّتَكَ ‏"‏ ‏.‏ فَخَلَعَهَا مِنْ رَأْسِهِ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{1820}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Daif}\hadithtrans{This tradition has also been narrated by Ya’la bin Umayyah through a different chain of narrators. This version adds The Prophet (ﷺ) said to him “Take off your tunic”. He then took it off from his head. The narrator then narrated the rest of the tradition}}
\hadithdefcmd{abudawud}{1821}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ الرَّمْلِيُّ، قَالَ حَدَّثَنِي اللَّيْثُ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنِ ابْنِ يَعْلَى ابْنِ مُنْيَةَ، عَنْ أَبِيهِ، بِهَذَا الْخَبَرِ قَالَ فِيهِ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَنْزِعَهَا نَزْعًا وَيَغْتَسِلَ مَرَّتَيْنِ أَوْ ثَلاَثًا ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{1821}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{This tradition has also been transmitted by Ya’la bin Umayyah through a different chain of narrators. This version adds The Apostle of Allaah(ﷺ) commanded him to take it off (the tunic) and to take a bath twice or thrice. The narrator then transmitted the rest of the tradition}}
\hadithdefcmd{abudawud}{1822}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ قَيْسَ بْنَ سَعْدٍ، يُحَدِّثُ عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم بِالْجِعْرَانَةِ وَقَدْ أَحْرَمَ بِعُمْرَةٍ وَعَلَيْهِ جُبَّةٌ وَهُوَ مُصَفِّرٌ لِحْيَتَهُ وَرَأْسَهُ وَسَاقَ هَذَا الْحَدِيثَ ‏.‏\hadithno{1822}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1180)}\hadithtrans{It is narrated by Ya’la bin Umayyah that a man came to Prophet (ﷺ) at Ji’ranah, putting on ihram for ‘Umrah. He had a cloak on him and his beard and head had been dyed}}
\hadithdefcmd{abudawud}{1823}{حَدَّثَنَا مُسَدَّدٌ، وَأَحْمَدُ بْنُ حَنْبَلٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا يَتْرُكُ الْمُحْرِمُ مِنَ الثِّيَابِ فَقَالَ ‏ "‏ لاَ يَلْبَسُ الْقَمِيصَ وَلاَ الْبُرْنُسَ وَلاَ السَّرَاوِيلَ وَلاَ الْعِمَامَةَ وَلاَ ثَوْبًا مَسَّهُ وَرْسٌ وَلاَ زَعْفَرَانٌ وَلاَ الْخُفَّيْنِ إِلاَّ لِمَنْ لَمْ يَجِدِ النَّعْلَيْنِ فَمَنْ لَمْ يَجِدِ النَّعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ وَلْيَقْطَعْهُمَا حَتَّى يَكُونَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{1823}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5806) Sahih Muslim (1177)}\hadithtrans{‘Abd Allaah bin Umar said A man asked the Apostle of Allaah(ﷺ) What clothing one should put on if one intend to put on ihram? He said He should not wear shirts, turbans, trousers, garments with head coverings and clothing which has any dye of waras or saffron; one should not put on shoes unless one cannot get sandals. If one cannot get sandals, one should wear the shoes, in which case one must cut them to come below the ankles}}
\hadithdefcmd{abudawud}{1824}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏\hadithno{1824}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1542) Sahih Muslim (1177)}\hadithtrans{The aforesaid tradition has also been transmitted by Ibn ‘Umar from the Prophet (ﷺ) to the same effect}}
\hadithdefcmd{abudawud}{1825}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ زَادَ ‏"‏ وَلاَ تَنْتَقِبُ الْمَرْأَةُ الْحَرَامُ وَلاَ تَلْبَسُ الْقُفَّازَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَدْ رَوَى هَذَا الْحَدِيثَ حَاتِمُ بْنُ إِسْمَاعِيلَ وَيَحْيَى بْنُ أَيُّوبَ عَنْ مُوسَى بْنِ عُقْبَةَ عَنْ نَافِعٍ عَلَى مَا قَالَ اللَّيْثُ وَرَوَاهُ مُوسَى بْنُ طَارِقٍ عَنْ مُوسَى بْنِ عُقْبَةَ مَوْقُوفًا عَلَى ابْنِ عُمَرَ وَكَذَلِكَ رَوَاهُ عُبَيْدُ اللَّهِ بْنُ عُمَرَ وَمَالِكٌ وَأَيُّوبُ مَوْقُوفًا وَإِبْرَاهِيمُ بْنُ سَعِيدٍ الْمَدِينِيُّ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ الْمُحْرِمَةُ لاَ تَنْتَقِبُ وَلاَ تَلْبَسُ الْقُفَّازَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ إِبْرَاهِيمُ بْنُ سَعِيدٍ الْمَدِينِيُّ شَيْخٌ مِنْ أَهْلِ الْمَدِينَةِ لَيْسَ لَهُ كَبِيرُ حَدِيثٍ ‏.‏\hadithno{1825}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1838)}\hadithtrans{This tradition has also been transmitted through a different chain of narrators by Ibn ‘Umar to the same effect. This version adds “A woman in the sacred state(while wearing ihram) should not be veiled or wear gloves. Abu Dawud said This tradition has also been transmitted by Hatim bin Isma’il and Yahya bin Ayyub from Musa bin ‘Uqbah from ‘Nafi as reported by al Laith. This has also been narrated by Musa bin Tariq from Musa bin ‘Uqbah as a statement of Ibn ‘Umar(not of the Prophet). Similarly, this tradition has also been transmitted by ‘Ubaid Allah bin Umar, Malik and Ayyub as a statement of Ibn ‘Umar (not of the Prophet). Ibrahim bin Sa’id al Madini narrated this tradition from Nafi’ on the authority of Ibn ‘Umar from the Prophet (ﷺ) A woman in the sacred state (wearing ihram) must not be veiled or wear gloves. Abu Dawud said Ibrahim bin Sa’id al Madini is a traditionist of Madina. Not many traditions have been narrated by him}}
\hadithdefcmd{abudawud}{1826}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْمَدِينِيُّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُحْرِمَةُ لاَ تَنْتَقِبُ وَلاَ تَلْبَسُ الْقُفَّازَيْنِ ‏"‏ ‏.‏\hadithno{1826}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn ‘Umar reported that the Prophet(ﷺ) as saying A woman in the sacred state (wearing ihram) must not be veiled or wear gloves}}
\hadithdefcmd{abudawud}{1827}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ فَإِنَّ نَافِعًا مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ حَدَّثَنِي عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى النِّسَاءَ فِي إِحْرَامِهِنَّ عَنِ الْقُفَّازَيْنِ وَالنِّقَابِ وَمَا مَسَّ الْوَرْسُ وَالزَّعْفَرَانُ مِنَ الثِّيَابِ وَلْتَلْبَسْ بَعْدَ ذَلِكَ مَا أَحَبَّتْ مِنْ أَلْوَانِ الثِّيَابِ مُعَصْفَرًا أَوْ خَزًّا أَوْ حُلِيًّا أَوْ سَرَاوِيلَ أَوْ قَمِيصًا أَوْ خُفًّا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ عَنِ ابْنِ إِسْحَاقَ عَنْ نَافِعٍ عَبْدَةُ بْنُ سُلَيْمَانَ وَمُحَمَّدُ بْنُ سَلَمَةَ إِلَى قَوْلِهِ وَمَا مَسَّ الْوَرْسُ وَالزَّعْفَرَانُ مِنَ الثِّيَابِ ‏.‏ وَلَمْ يَذْكُرَا مَا بَعْدَهُ ‏.‏\hadithno{1827}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Abd Allaah bin Umar said that he heard the Apostle of Allaah(ﷺ) prohibiting women in the sacred state (wearing ihram) to wear gloves, veil(their faces) and to wear clothes with dye of waras or saffron on them. But afterwards they can wear any kind of clothing they like dyed yellow or silk or jewelry or trousers or shirts or shoes. Abu Dawud said ‘Abdah and Muhammad bin Ishaq narrated this tradition from Muhammad bin Ishaq up to the words “And to wear clothes with dye of waras or saffron on them”. They did not mention the words after them}}
\hadithdefcmd{abudawud}{1828}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ وَجَدَ الْقُرَّ فَقَالَ أَلْقِ عَلَىَّ ثَوْبًا يَا نَافِعُ ‏.‏ فَأَلْقَيْتُ عَلَيْهِ بُرْنُسًا فَقَالَ تُلْقِي عَلَىَّ هَذَا وَقَدْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَلْبَسَهُ الْمُحْرِمُ\hadithno{1828}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi' said Ibn ‘Umar felt cold and said Throw a garment over me, ‘Nafi. I threw a hooded cloak over him. Thereupon he said Are you throwing this over me when the Apostle of Allaah(ﷺ) has forbidden those who are in sacred state to wear it?}}
\hadithdefcmd{abudawud}{1829}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ السَّرَاوِيلُ لِمَنْ لاَ يَجِدُ الإِزَارَ وَالْخُفُّ لِمَنْ لاَ يَجِدُ النَّعْلَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حَدِيثُ أَهْلِ مَكَّةَ وَمَرْجِعُهُ إِلَى الْبَصْرَةِ إِلَى جَابِرِ بْنِ زَيْدٍ وَالَّذِي تَفَرَّدَ بِهِ مِنْهُ ذِكْرُ السَّرَاوِيلِ وَلَمْ يَذْكُرِ الْقَطْعَ فِي الْخُفِّ ‏.‏\hadithno{1829}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1841) Sahih Muslim (1178)}\hadithtrans{Ibn ‘Abbas said I heard the Apostle of Allaah(ﷺ) say When one who is wearing ihram cannot get a lower garment(loin cloth) he may ear trousers and when he cannot get sandals he may wear shoes. Abu Dawud said This is the tradition narrated by the narrators of Makkah. Its narrator from Basrah is Jabir bin Zaid. He mentioned only trousers and omitted the mention of cutting of the shoes}}
\hadithdefcmd{abudawud}{1830}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْجُنَيْدِ الدَّامَغَانِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ أَخْبَرَنِي عُمَرُ بْنُ سُوَيْدٍ الثَّقَفِيُّ، قَالَ حَدَّثَتْنِي عَائِشَةُ بِنْتُ طَلْحَةَ، أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، - رضى الله عنها - حَدَّثَتْهَا قَالَتْ كُنَّا نَخْرُجُ مَعَ النَّبِيِّ صلى الله عليه وسلم إِلَى مَكَّةَ فَنُضَمِّدُ جِبَاهَنَا بِالسُّكِّ الْمُطَيَّبِ عِنْدَ الإِحْرَامِ فَإِذَا عَرِقَتْ إِحْدَانَا سَالَ عَلَى وَجْهِهَا فَيَرَاهُ النَّبِيُّ صلى الله عليه وسلم فَلاَ يَنْهَاهَا ‏.‏\hadithno{1830}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin:We were proceeding to Mecca along with the Prophet (ﷺ). We pasted on our foreheads the perfume known as sukk at the time of wearing ihram. When one of us perspired, it (the perfume) came down on her face. The Prophet (ﷺ) saw it but did not forbid it}}
\hadithdefcmd{abudawud}{1831}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ ذَكَرْتُ لاِبْنِ شِهَابٍ فَقَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ، - يَعْنِي ابْنَ عُمَرَ - كَانَ يَصْنَعُ ذَلِكَ - يَعْنِي يَقْطَعُ الْخُفَّيْنِ لِلْمَرْأَةِ الْمُحْرِمَةِ - ثُمَّ حَدَّثَتْهُ صَفِيَّةُ بِنْتُ أَبِي عُبَيْدٍ أَنَّ عَائِشَةَ حَدَّثَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ كَانَ رَخَّصَ لِلنِّسَاءِ فِي الْخُفَّيْنِ فَتَرَكَ ذَلِكَ ‏.‏\hadithno{1831}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Salim ibn Abdullah said: Abdullah ibn Umar used to do so, that is to say, he would cut the shoes of a woman who put on ihram; then Safiyyah, daughter of AbuUbayd, reported to him that Aisha (may Allah be pleased with her) narrated to her that the Messenger of Allah (ﷺ) gave licence to women in respect of the shoes (i.e. women are not required to cut the shoes). He, therefore, abandoned it}}
\hadithdefcmd{abudawud}{1832}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ لَمَّا صَالَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَهْلَ الْحُدَيْبِيَةِ صَالَحَهُمْ عَلَى أَنْ لاَ يَدْخُلُوهَا إِلاَّ بِجُلْبَانِ السِّلاَحِ فَسَأَلْتُهُ مَا جُلْبَانُ السِّلاَحِ قَالَ الْقِرَابُ بِمَا فِيهِ ‏.‏\hadithno{1832}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2298) Sahih Muslim (1783)}\hadithtrans{Al Bara’ (bin Azib) said When the Apostle of Allaah(ﷺ) concluded the treaty with the people of Al Hudaibiyyah, they stipulated that they (the Muslims) would not enter (Makkah) except with the bag of armament (julban al-silah). I asked what is julban al-silah? He replied:The bag with its contents}}
\hadithdefcmd{abudawud}{1833}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ الرُّكْبَانُ يَمُرُّونَ بِنَا وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُحْرِمَاتٌ فَإِذَا حَاذَوْا بِنَا سَدَلَتْ إِحْدَانَا جِلْبَابَهَا مِنْ رَأْسِهَا إِلَى وَجْهِهَا فَإِذَا جَاوَزُونَا كَشَفْنَاهُ ‏.‏\hadithno{1833}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Riders would pass us when we accompanied the Messenger of Allah (ﷺ) while we were in the sacred state (wearing ihram). When they came by us, one of us would let down her outer garment from her head over her face, and when they had passed on, we would uncover our faces}}
\hadithdefcmd{abudawud}{1834}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ يَحْيَى بْنِ حُصَيْنٍ، عَنْ أُمِّ الْحُصَيْنِ، حَدَّثَتْهُ قَالَتْ، حَجَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم حَجَّةَ الْوَدَاعِ فَرَأَيْتُ أُسَامَةَ وَبِلاَلاً وَأَحَدُهُمَا آخِذٌ بِخِطَامِ نَاقَةِ النَّبِيِّ صلى الله عليه وسلم وَالآخَرُ رَافِعٌ ثَوْبَهُ لِيَسْتُرَهُ مِنَ الْحَرِّ حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ ‏.‏\hadithno{1834}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1298)}\hadithtrans{Umm al Hussain said We performed the Farewell Pilgrimage along with the Prophet(ﷺ) . I saw Usamah and Bilal one of them holding the halter of the she-Camel of the Prophet(ﷺ), while the other raising his garment and sheltering from the heat till he had thrown pebbles at the jamrah of the ‘Aqabah}}
\hadithdefcmd{abudawud}{1835}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، وَطَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{1835}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1835) Sahih Muslim (1202)}\hadithtrans{Ibn ‘Abbas said The Prophet(ﷺ) had himself cupped when he was in the sacred state(wearing ihram)}}
\hadithdefcmd{abudawud}{1836}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ فِي رَأْسِهِ مِنْ دَاءٍ كَانَ بِهِ ‏.‏\hadithno{1836}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5700)}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) had himself cupped in his head when he was in the sacred state (wearing ihram due to a disease from which he was suffering)}}
\hadithdefcmd{abudawud}{1837}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ عَلَى ظَهْرِ الْقَدَمِ مِنْ وَجَعٍ كَانَ بِهِ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ قَالَ ابْنُ أَبِي عَرُوبَةَ أَرْسَلَهُ يَعْنِي عَنْ قَتَادَةَ ‏.‏\hadithno{1837}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Messenger of Allah (ﷺ) had himself cupped on the surface of his foot because of a pain in it while he was in the sacred state (wearing ihram). Abu Dawud said: I heard Ahmad say: "Ibn Abi 'Arubah narrated it in Mursal form". Meaning from Qatadah}}
\hadithdefcmd{abudawud}{1838}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نُبَيْهِ بْنِ وَهْبٍ، قَالَ اشْتَكَى عُمَرُ بْنُ عُبَيْدِ اللَّهِ بْنِ مَعْمَرٍ عَيْنَيْهِ فَأَرْسَلَ إِلَى أَبَانَ بْنِ عُثْمَانَ - قَالَ سُفْيَانُ وَهُوَ أَمِيرُ الْمَوْسِمِ - مَا يَصْنَعُ بِهِمَا قَالَ اضْمِدْهُمَا بِالصَّبِرِ فَإِنِّي سَمِعْتُ عُثْمَانَ - رضى الله عنه - يُحَدِّثُ ذَلِكَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1838}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1204)}\hadithtrans{Nubaih bin Wahb said ‘Umar bin ‘Ubaid Allah bin Ma’mar had a complaint in his eyes. He sent (someone) to Aban bin ‘Uthman - the narrator Sufyan said that he was the chief of pilgrims during the season of Hajj – asking him what he should do with them. He said Apply aloes to them, for I heard ‘Uthaman narrating this on the authority of the Apostle of Allaah(ﷺ)}}
\hadithdefcmd{abudawud}{1839}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، بِهَذَا الْحَدِيثِ ‏.‏\hadithno{1839}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by Nubaih bin Wahb through a different chain of narrators}}
\hadithdefcmd{abudawud}{1840}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، اخْتَلَفَا بِالأَبْوَاءِ فَقَالَ ابْنُ عَبَّاسٍ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ وَقَالَ الْمِسْوَرُ لاَ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ فَأَرْسَلَهُ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ إِلَى أَبِي أَيُّوبَ الأَنْصَارِيِّ فَوَجَدَهُ يَغْتَسِلُ بَيْنَ الْقَرْنَيْنِ وَهُوَ يُسْتَرُ بِثَوْبٍ قَالَ فَسَلَّمْتُ عَلَيْهِ ��َقَالَ مَنْ هَذَا قُلْتُ أَنَا عَبْدُ اللَّهِ بْنُ حُنَيْنٍ أَرْسَلَنِي إِلَيْكَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ أَسْأَلُكَ كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْسِلُ رَأْسَهُ وَهُوَ مُحْرِمٌ قَالَ فَوَضَعَ أَبُو أَيُّوبَ يَدَهُ عَلَى الثَّوْبِ فَطَأْطَأَهُ حَتَّى بَدَا لِي رَأْسُهُ ثُمَّ قَالَ لإِنْسَانٍ يَصُبُّ عَلَيْهِ اصْبُبْ ‏.‏ قَالَ فَصَبَّ عَلَى رَأْسِهِ ثُمَّ حَرَّكَ أَبُو أَيُّوبَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ ثُمَّ قَالَ هَكَذَا رَأَيْتُهُ يَفْعَلُ صلى الله عليه وسلم ‏.‏\hadithno{1840}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1840) Sahih Muslim (1205)}\hadithtrans{‘Abd Allah bin Hunain said ‘Abd Allah bin Abbas and Miswar bin Makhramah differed amongst themselves (on the question of washing the head in the sacred state) at al Abwa. ‘Ibn Abbas said A pilgrim in the sacred state (while wearing ihram) can wash his head. Al Miswar said A pilgrim in the sacred state(wearing ihram) cannot wash his head. ‘Abd Allah bin Abbas then sent him (‘Abd Allah bin Hunain) to Abu Ayyub Al Ansari. He found him taking a bath between two woods erected at the edge of the well and he was hiding himself with a cloth (curtain). He (the narrator) said I saluted him. He asked Who is this? I said I am ‘Abd Allah bin Hunain. ‘Abd Allah bin Abbas has sent me to you asking you how the Apostle of Allaah(ﷺ) used to wash his head while he was wearing ihram. Abu Ayyub then put his hand on the cloth and removed it till his head appeared to me. He then said to a person who was pouring water on him:Pour water. He poured water on his head and Abu Ayyub moved his head with his hands. He carried his hands forward and backward. He then said I saw him doing similarly}}
\hadithdefcmd{abudawud}{1841}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، أَخِي بَنِي عَبْدِ الدَّارِ أَنَّ عُمَرَ بْنَ عُبَيْدِ اللَّهِ، أَرْسَلَ إِلَى أَبَانَ بْنِ عُثْمَانَ بْنِ عَفَّانَ يَسْأَلُهُ وَأَبَانُ يَوْمَئِذٍ أَمِيرُ الْحَاجِّ وَهُمَا مُحْرِمَانِ إِنِّي أَرَدْتُ أَنْ أُنْكِحَ طَلْحَةَ بْنَ عُمَرَ ابْنَةَ شَيْبَةَ بْنِ جُبَيْرٍ فَأَرَدْتُ أَنْ تَحْضُرَ ذَلِكَ ‏.‏ فَأَنْكَرَ ذَلِكَ عَلَيْهِ أَبَانُ وَقَالَ إِنِّي سَمِعْتُ أَبِي عُثْمَانَ بْنَ عَفَّانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْكِحُ الْمُحْرِمُ وَلاَ يُنْكَحُ ‏"‏ ‏.‏\hadithno{1841}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1409)}\hadithtrans{Nubaih bin Wahb brother of Banu Abd Al Dar said ‘Umar bin Ubaid Allah sent someone to Aban bin Uthman bin Affan asking him (to participate in the marriage ceremony). Aban in those days was the chief of the pilgrims and both were in the sacred state (wearing ihram). I want to give the daughter of Shaibah bin Jubair to Talhah bin Umar in marriage. I wish that you may attend it. Aban refused and said I heard my father ‘Uthman bin Affan narrating a tradition from the Apostle of Allaah(ﷺ) as saying A pilgrim may not marry and give someone in marriage in the sacred state(while wearing ihram)}}
\hadithdefcmd{abudawud}{1842}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرٍ، حَدَّثَهُمْ حَدَّثَنَا سَعِيدٌ، عَنْ مَطَرٍ، وَيَعْلَى بْنِ حَكِيمٍ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، عَنْ أَبَانَ بْنِ عُثْمَانَ، عَنْ عُثْمَانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ مِثْلَهُ زَادَ ‏ "‏ وَلاَ يَخْطُبُ ‏"‏ ‏.‏\hadithno{1842}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by Aban bin ‘Uthman on the authority of ‘Uthman from the Apostle of Allaah(ﷺ) in a similar manner. This version adds “And he should not make a betrothal”}}
\hadithdefcmd{abudawud}{1843}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ يَزِيدَ بْنِ الأَصَمِّ ابْنِ أَخِي، مَيْمُونَةَ عَنْ مَيْمُونَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ حَلاَلاَنِ بِسَرِفَ ‏.‏\hadithno{1843}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1411)}\hadithtrans{Yazid bin Al Asamm, Maimunah’s nephew said on Maimunah’s authority The Apostle of Allaah(ﷺ) married me when we were not in the sacred state at Sarif}}
\hadithdefcmd{abudawud}{1844}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{1844}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4258)}\hadithtrans{Ibn ‘Abbas said The Prophet(ﷺ) married Maimunah while he was in the sacred state(wearing ihram)}}
\hadithdefcmd{abudawud}{1845}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ رَجُلٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ وَهِمَ ابْنُ عَبَّاسٍ فِي تَزْوِيجِ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{1845}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sa’id bin Al Musayyib said There is a misunderstanding on the part of Ibn ‘Abbas about the marriage (of the Prophet) with Maimunah while he was in the sacred state}}
\hadithdefcmd{abudawud}{1846}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَمَّا يَقْتُلُ الْمُحْرِمُ مِنَ الدَّوَابِّ فَقَالَ ‏ "‏ خَمْسٌ لاَ جُنَاحَ فِي قَتْلِهِنَّ عَلَى مَنْ قَتَلَهُنَّ فِي الْحِلِّ وَالْحَرَمِ الْعَقْرَبُ وَالْفَأْرَةُ وَالْحِدَأَةُ وَالْغُرَابُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{1846}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1199)}\hadithtrans{Ibn ‘Umar said The Prophet (ﷺ) was asked as to which of the creatures could be killed by a pilgrim in the sacred state. He said there are five creatures which it is not a sin for anyone to kill, outside or inside the sacred area. The Scorpion, the Crow, the Rat, the Kite and the biting Dog}}
\hadithdefcmd{abudawud}{1847}{حَدَّثَنَا عَلِيُّ بْنُ بَحْرٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنِي مُحَمَّدُ بْنُ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ قَتْلُهُنَّ حَلاَلٌ فِي الْحَرَمِ الْحَيَّةُ وَالْعَقْرَبُ وَالْحِدَأَةُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{1847}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying There are five(creatures) the killing of which is lawful in the sacred territory. The Snake, the Scorpion, the Kite, the Rat and the biting Dog}}
\hadithdefcmd{abudawud}{1848}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي نُعْمٍ الْبَجَلِيُّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَمَّا يَقْتُلُ الْمُحْرِمُ قَالَ ‏ "‏ الْحَيَّةُ وَالْعَقْرَبُ وَالْفُوَيْسِقَةُ وَيَرْمِي الْغُرَابَ وَلاَ يَقْتُلُهُ وَالْكَلْبُ الْعَقُورُ وَالْحِدَأَةُ وَالسَّبُعُ الْعَادِي ‏"‏ ‏.‏\hadithno{1848}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) was asked which of the creatures a pilgrim in sacred state could kill. He replied: The snake, the scorpion, the rat; he should drive away the pied crow, but should not kill it; the biting dog, the kite, and any wild animal which attacks (man)}}
\hadithdefcmd{abudawud}{1849}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أَبِيهِ، وَكَانَ الْحَارِثُ، خَلِيفَةَ عُثْمَانَ عَلَى الطَّائِفِ فَصَنَعَ لِعُثْمَانَ طَعَامًا فِيهِ مِنَ الْحَجَلِ وَالْبَعَاقِيبِ وَلَحْمِ الْوَحْشِ قَالَ فَبَعَثَ إِلَى عَلِيِّ بْنِ أَبِي طَالِبٍ فَجَاءَهُ الرَّسُولُ وَهُوَ يَخْبِطُ لأَبَاعِرَ لَهُ فَجَاءَهُ وَهُوَ يَنْفُضُ الْخَبَطَ عَنْ يَدِهِ فَقَالُوا لَهُ كُلْ ‏.‏ فَقَالَ أَطْعِمُوهُ قَوْمًا حَلاَلاً فَإِنَّا حُرُمٌ ‏.‏ فَقَالَ عَلِيٌّ رضى الله عنه أَنْشُدُ اللَّهَ مَنْ كَانَ هَا هُنَا مِنْ أَشْجَعَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهْدَى إِلَيْهِ رَجُلٌ حِمَارَ وَحْشٍ وَهُوَ مُحْرِمٌ فَأَبَى أَنْ يَأْكُلَهُ قَالُوا نَعَمْ ‏.‏\hadithno{1849}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah ibn al-Harith reported on the authority of his father al-Harith:(My father) al-Harith was the governor of at-Ta'if under the caliph Uthman. He prepared food for Uthman which contained birds and the flesh of wild ass. He sent it to Ali (may Allah be pleased with him). When the Messenger came to him he was beating leaves for camels and shaking them off with his hand. He said to him: Eat it. He replied: Give it to the people who are not in sacred state; we are wearing ihram. I adjure the people of Ashja' who are present here. Do you know that a man presented a wild ass to the Messenger of Allah (ﷺ) while he was in ihram? But he refused to eat from it. They said: Yes}}
\hadithdefcmd{abudawud}{1850}{حَدَّثَنَا أَبُو سَلَمَةَ، مُوسَى بْنُ إِسْمَاعِيلَ حَدَّثَنَا حَمَّادٌ، عَنْ قَيْسٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ يَا زَيْدُ بْنَ أَرْقَمَ هَلْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُهْدِيَ إِلَيْهِ عُضْوُ صَيْدٍ فَلَمْ يَقْبَلْهُ وَقَالَ ‏ "‏ إِنَّا حُرُمٌ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{1850}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn ‘Abbas said Zaid bin ‘Arqam do you know that the limb of a game was presented to the Apostle of Allaah(ﷺ) but he did not accept it. He said “We are wearing ihram”. He replied, Yes}}
\hadithdefcmd{abudawud}{1851}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي الإِسْكَنْدَرَانِيَّ الْقَارِيَّ - عَنْ عَمْرٍو، عَنِ الْمُطَّلِبِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ صَيْدُ الْبَرِّ لَكُمْ حَلاَلٌ مَا لَمْ تَصِيدُوهُ أَوْ يُصَدْ لَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ إِذَا تَنَازَعَ الْخَبَرَانِ عَنِ النَّبِيِّ صلى الله عليه وسلم يُنْظَرُ بِمَا أَخَذَ بِهِ أَصْحَابُهُ ‏.‏\hadithno{1851}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: I heard the Messenger of Allah (ﷺ) say: The game of the land is lawful for you (when you are wearing ihram) as long as you do not hunt it or have it hunted on your behalf. Abu Dawud said: When two traditions from the Prophet (ﷺ) conflict, one should see which of them was followed by his Companions}}
\hadithdefcmd{abudawud}{1852}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ التَّيْمِيِّ عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ الأَنْصَارِيِّ عَنْ أَبِي قَتَادَةَ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِبَعْضِ طَرِيقِ مَكَّةَ تَخَلَّفَ مَعَ أَصْحَابٍ لَهُ مُحْرِمِينَ وَهُوَ غَيْرُ مُحْرِمٍ فَرَأَى حِمَارًا وَحْشِيًّا فَاسْتَوَى عَلَى فَرَسِهِ قَالَ فَسَأَلَ أَصْحَابَهُ أَنْ يُنَاوِلُوهُ سَوْطَهُ فَأَبَوْا فَسَأَلَهُمْ رُمْحَهُ فَأَبَوْا فَأَخَذَهُ ثُمَّ شَدَّ عَلَى الْحِمَارِ فَقَتَلَهُ فَأَكَلَ مِنْهُ بَعْضُ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبَى بَعْضُهُمْ فَلَمَّا أَدْرَكُوا رَسُولَ اللَّهِ صلى الله عليه وسلم سَأَلُوهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّمَا هِيَ طُعْمَةٌ أَطْعَمَكُمُوهَا اللَّهُ تَعَالَى ‏"‏ ‏.‏\hadithno{1852}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2914) Sahih Muslim (1196)}\hadithtrans{Abu Qatadah said that he accompanied the Apostle of Allaah(ﷺ) and he stayed behind on the way to Makkah with some of his companions who were wearing ihram, although he was not. When he saw a wild ass he mounted his horse and asked them to hand him his whip, but they refused. He then asked them to hand him his lance. When they refused, he took it, chased the while ass and killed it. Some of the Companions of the Apostle of Allaah(ﷺ) ate it and some refused (to eat). When they met the Apostle of Allaah(ﷺ) they asked him about it. He said that was the food that Allaah provided you for eating}}
\hadithdefcmd{abudawud}{1853}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا حَمَّادٌ، عَنْ مَيْمُونِ بْنِ جَابَانَ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْجَرَادُ مِنْ صَيْدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{1853}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying “Locusts are counted along with what is caught in the sea (i.e., the game of the sea).”}}
\hadithdefcmd{abudawud}{1854}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ حَبِيبٍ الْمُعَلِّمِ، عَنْ أَبِي الْمُهَزِّمِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَصَبْنَا صِرْمًا مِنْ جَرَادٍ فَكَانَ رَجُلٌ مِنَّا يَضْرِبُهُ بِسَوْطِهِ وَهُوَ مُحْرِمٌ فَقِيلَ لَهُ إِنَّ هَذَا لاَ يَصْلُحُ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّمَا هُوَ مِنْ صَيْدِ الْبَحْرِ ‏"‏ ‏.‏ سَمِعْتُ أَبَا دَاوُدَ يَقُولُ أَبُو الْمُهَزِّمِ ضَعِيفٌ وَالْحَدِيثَانِ جَمِيعًا وَهَمٌ ‏.‏\hadithno{1854}\hadithgrade{Al-Albani: Very Daif; Muhammad Muhyi Al-Din Abdul Hamid: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said, We found a swarm of Locusts. A man who was wearing ihram began to strike it with his whip. He was told that his action was not valid. The fact was mentioned to the Prophet (ﷺ); He said “That is counted along with the game of the sea.” I heard Abu Dawud say “The narrator Abu Al Muhzim is weak. Both these traditions are based on misunderstanding}}
\hadithdefcmd{abudawud}{1855}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مَيْمُونِ بْنِ جَابَانَ، عَنْ أَبِي رَافِعٍ، عَنْ كَعْبٍ، قَالَ الْجَرَادُ مِنْ صَيْدِ الْبَحْرِ ‏.‏\hadithno{1855}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ka’ab said “Locusts are counted along with the game of the sea.”}}
\hadithdefcmd{abudawud}{1856}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ الطَّحَّانِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِهِ زَمَنَ الْحُدَيْبِيَةِ فَقَالَ ‏"‏ قَدْ آذَاكَ هَوَامُّ رَأْسِكَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ احْلِقْ ثُمَّ اذْبَحْ شَاةً نُسُكًا أَوْ صُمْ ثَلاَثَةَ أَيَّامٍ أَوْ أَطْعِمْ ثَلاَثَةَ آصُعٍ مِنْ تَمْرٍ عَلَى سِتَّةِ مَسَاكِينَ ‏"‏ ‏.‏\hadithno{1856}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1814) Sahih Muslim (1201)}\hadithtrans{Ka’ab bin ‘Ujrah said that the Apostle of Allaah(ﷺ) came upon him (during their stay) at Al Hudaibiyyah. He asked do the insects of your head (lice) annoy you? He said Yes. The Prophet (ﷺ) said Shave your head, then sacrifice a sheep as offering or fast three days or give three sa’s of dates to six poor people}}
\hadithdefcmd{abudawud}{1857}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ إِنْ شِئْتَ فَانْسُكْ نَسِيكَةً وَإِنْ شِئْتَ فَصُمْ ثَلاَثَةَ أَيَّامٍ وَإِنْ شِئْتَ فَأَطْعِمْ ثَلاَثَةَ آصُعٍ مِنْ تَمْرٍ لِسِتَّةِ مَسَاكِينَ ‏"‏ ‏.‏\hadithno{1857}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ka’ab bin ‘Ujrah said that the Apostle of Allaah(ﷺ) said to him, If you like sacrifice an animal or if you like fast three days or if you like give three sa’s of dates to six poor people}}
\hadithdefcmd{abudawud}{1858}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، - وَهَذَا لَفْظُ ابْنِ الْمُثَنَّى - عَنْ دَاوُدَ، عَنْ عَامِرٍ، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِهِ زَمَنَ الْحُدَيْبِيَةِ فَذَكَرَ الْقِصَّةَ فَقَالَ ‏"‏ أَمَعَكَ دَمٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَصُمْ ثَلاَثَةَ أَيَّامٍ أَوْ تَصَدَّقْ بِثَلاَثَةِ آصُعٍ مِنْ تَمْرٍ عَلَى سِتَّةِ مَسَاكِينَ بَيْنَ كُلِّ مِسْكِينَيْنِ صَاعٌ ‏"‏ ‏.‏\hadithno{1858}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ka'b ibn Ujrah: The Messenger of Allah (ﷺ) came upon him (during their stay) at al-Hudaybiyyah. He then narrated the rest of the tradition. This version adds: "He asked: Do you have a sacrificial animal? He replied: No. He then said: Fast three days or give three sa's of dates to six poor people, giving one sa' to every two persons}}
\hadithdefcmd{abudawud}{1859}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ أَخْبَرَهُ عَنْ كَعْبِ بْنِ عُجْرَةَ، - وَكَانَ قَدْ أَصَابَهُ فِي رَأْسِهِ أَذًى فَحَلَقَ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يُهْدِيَ هَدْيًا بَقَرَةً ‏.‏\hadithno{1859}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{A man from the Ansar said on the authority of Ka'b ibn Ujrah that he was feeling pain in his head (due to lice); so he shaved his head. The Prophet (ﷺ) ordered him to sacrifice a cow as offering}}
\hadithdefcmd{abudawud}{1860}{حَدَّثَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنِي أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي أَبَانُ، - يَعْنِي ابْنَ صَالِحٍ - عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ أَصَابَنِي هَوَامُّ فِي رَأْسِي وَأَنَا مَعَ، رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ حَتَّى تَخَوَّفْتُ عَلَى بَصَرِي فَأَنْزَلَ اللَّهُ سُبْحَانَهُ وَتَعَالَى ‏\{‏ فَمَنْ كَانَ مِنْكُمْ مَرِيضًا أَوْ بِهِ أَذًى مِنْ رَأْسِهِ ‏\}‏ الآيَةَ فَدَعَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لِي ‏"‏ احْلِقْ رَأْسَكَ وَصُمْ ثَلاَثَةَ أَيَّامٍ أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ فَرَقًا مِنْ زَبِيبٍ أَوِ انْسُكْ شَاةً ‏"‏ ‏.‏ فَحَلَقْتُ رَأْسِي ثُمَّ نَسَكْتُ ‏.‏\hadithno{1860}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Ka’b bin ‘Ujrah said I had lice in my head when I accompanied the Apostle of Allaah(ﷺ) in the year of Al Hudaibiyyah so much so that I feared about my eyesight. So Allaah, the exalted revealed these verses about me. “And whoever among you is sick or hath an aliment of the head.” The Apostle of Allaah(ﷺ) called me and said “Shave your head and fast three days or give a faraq of raisins to six poor men or sacrifice a goat. So, I shaved my head and sacrificed}}
\hadithdefcmd{abudawud}{1861}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ الْكَرِيمِ بْنِ مَالِكٍ الْجَزَرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، فِي هَذِهِ الْقِصَّةِ زَادَ ‏ "‏ أَىَّ ذَلِكَ فَعَلْتَ أَجْزَأَ عَنْكَ ‏"‏ ‏.‏\hadithno{1861}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was reported from 'Abdul-Karim bin Malik Al-Jazari, from 'Abdur-Rahman bin Abi Laila, from Ka'b bin Ujrah, regarding this incident (as narrated in on previous hadith), and he added:"Whichever of these you do, it will suffice}}
\hadithdefcmd{abudawud}{1862}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ حَجَّاجٍ الصَّوَّافِ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، قَالَ سَمِعْتُ الْحَجَّاجَ بْنَ عَمْرٍو الأَنْصَارِيَّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كُسِرَ أَوْ عَرِجَ فَقَدْ حَلَّ وَعَلَيْهِ الْحَجُّ مِنْ قَابِلٍ ‏"‏ ‏.‏ قَالَ عِكْرِمَةُ سَأَلْتُ ابْنَ عَبَّاسٍ وَأَبَا هُرَيْرَةَ عَنْ ذَلِكَ فَقَالاَ صَدَقَ ‏.‏\hadithno{1862}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al Hajjaj bin ‘Amr Al Ansari reported the Apostle of Allaah(ﷺ) as saying “ If anyone breaks (a bone or leg) or becomes lame, he has come out of the sacred state and must perform Hajj the following year.” ‘Ikrimah said I asked Ibn ‘Abbas and Abu Hurairah about this. They replied He spoke the truth}}
\hadithdefcmd{abudawud}{1863}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، وَسَلَمَةُ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، عَنِ الْحَجَّاجِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كُسِرَ أَوْ عَرِجَ أَوْ مَرِضَ ‏"‏ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏ قَالَ سَلَمَةُ بْنُ شَبِيبٍ قَالَ أَنَا مَعْمَرٌ ‏.‏\hadithno{1863}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated al-Hajjaj ibn Amr: The Prophet (ﷺ) said: If anyone breaks (a leg) or becomes lame or falls ill. He then narrated the tradition to the same effect. The narrator Salamah ibn Shabib said: Ma'mar narrated (this tradition) to us}}
\hadithdefcmd{abudawud}{1864}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ سَمِعْتُ أَبَا حَاضِرٍ الْحِمْيَرِيَّ، يُحَدِّثُ أَبِي مَيْمُونَ بْنَ مِهْرَانَ قَالَ خَرَجْتُ مُعْتَمِرًا عَامَ حَاصَرَ أَهْلُ الشَّأْمِ ابْنَ الزُّبَيْرِ بِمَكَّةَ وَبَعَثَ مَعِي رِجَالٌ مِنْ قَوْمِي بِهَدْىٍ فَلَمَّا انْتَهَيْنَا إِلَى أَهْلِ الشَّأْمِ مَنَعُونَا أَنْ نَدْخُلَ الْحَرَمَ فَنَحَرْتُ الْهَدْىَ مَكَانِي ثُمَّ أَحْلَلْتُ ثُمَّ رَجَعْتُ فَلَمَّا كَانَ مِنَ الْعَامِ الْمُقْبِلِ خَرَجْتُ لأَقْضِيَ عُمْرَتِي فَأَتَيْتُ ابْنَ عَبَّاسٍ فَسَأَلْتُهُ فَقَالَ أَبْدِلِ الْهَدْىَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أَصْحَابَهُ أَنْ يُبْدِلُوا الْهَدْىَ الَّذِي نَحَرُوا عَامَ الْحُدَيْبِيَةِ فِي عُمْرَةِ الْقَضَاءِ ‏.‏\hadithno{1864}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Maymun ibn Mahran said:I came out to perform umrah in the year when the people of Syria besieged Ibn az-Zubayr at Mecca. Some people of my tribe sent sacrificial animals with me as an offering. When we reached the people of Syria, they stopped us from entering the sacred territory. I, therefore, sacrificed the animals at the same spot. I then took off ihram and returned. Next year I came out to make an atonement for my umrah. I came to Ibn Abbas and asked him (about it). He said: Bring a new sacrificial animal, for the Messenger of Allah (ﷺ) ordered his companions to bring fresh sacrificial animals for the umrah of atonement in lieu of the animals they had sacrificed in the year of al-Hudaybiyyah}}
\hadithdefcmd{abudawud}{1865}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ إِذَا قَدِمَ مَكَّةَ بَاتَ بِذِي طُوًى حَتَّى يُصْبِحَ وَيَغْتَسِلَ ثُمَّ يَدْخُلُ مَكَّةَ نَهَارًا وَيَذْكُرُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ فَعَلَهُ ‏.‏\hadithno{1865}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Nafi’ said It was Ibn ‘Umar’s habit that whenever he came to Makkah he spent the night at Dhu Tuwa in the morning he would take a bath and enter Makkah in the daytime. He used to say the Prophet (ﷺ) had done so}}
\hadithdefcmd{abudawud}{1866}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْبَرْمَكِيُّ، حَدَّثَنَا مَعْنٌ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا مُسَدَّدٌ، وَابْنُ، حَنْبَلٍ عَنْ يَحْيَى، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، جَمِيعًا عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدْخُلُ مَكَّةَ مِنَ الثَّنِيَّةِ الْعُلْيَا - قَالاَ عَنْ يَحْيَى إِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدْخُلُ مَكَّةَ مِنْ كَدَاءَ مِنْ ثَنِيَّةِ الْبَطْحَاءِ - وَيَخْرُجُ مِنَ الثَّنِيَّةِ السُّفْلَى ‏.‏ زَادَ الْبَرْمَكِيُّ يَعْنِي ثَنِيَّتَىْ مَكَّةَ وَحَدِيثُ مُسَدَّدٍ أَتَمُّ ‏.‏\hadithno{1866}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1575) Sahih Muslim (1257)}\hadithtrans{Ibn ‘Umar said The Prophet (ﷺ) used to enter Makkah from the upper hillock. The version of Yahya goes:The Prophet (ﷺ) used to enter Makkah from Kuda’ from the hillock of Batha’. He would come out from the lower hillock. Al Barmaki added “that is the two hillocks of Makkah”. The version of Musaddad is more complete}}
\hadithdefcmd{abudawud}{1867}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَخْرُجُ مِنْ طَرِيقِ الشَّجَرَةِ وَيَدْخُلُ مِنْ طَرِيقِ الْمُعَرَّسِ ‏.‏\hadithno{1867}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn ‘Umar said The Messenger of Allah (ﷺ) used to come out from (Medina) by the way of Al Shajarah and enter (Makkah) by the way of Al Mu’arras}}
\hadithdefcmd{abudawud}{1868}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ مِنْ كَدَاءَ مِنْ أَعْلَى مَكَّةَ وَدَخَلَ فِي الْعُمْرَةِ مِنْ كُدًى قَالَ وَكَانَ عُرْوَةُ يَدْخُلُ مِنْهُمَا جَمِيعًا وَكَانَ أَكْثَرُ مَا كَانَ يَدْخُلُ مِنْ كُدًى وَكَانَ أَقْرَبَهُمَا إِلَى مَنْزِلِهِ ‏.‏\hadithno{1868}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1578) Sahih Muslim (1258)}\hadithtrans{A’ishah said The Apostle of Allaah (ﷺ) entered Makkah from the side of Kuda’ the upper end of Makkah in the year of conquest (of Makkah) and he entered from the side of Kida’ when he performed ‘Umrah. ‘Urwah used to enter (Makkah) from both sides, but he often entered from the side of Kuda’ as it was nearer to his house}}
\hadithdefcmd{abudawud}{1869}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ مَكَّةَ دَخَلَ مِنْ أَعْلاَهَا وَخَرَجَ مِنْ أَسْفَلِهَا ‏.‏\hadithno{1869}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1577) Sahih Muslim (1258)}\hadithtrans{A’ishah said When the Prophet (ﷺ) entered Makkah he entered from the side of the upper end and he came out from the side of the lower end}}
\hadithdefcmd{abudawud}{1870}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرٍ، حَدَّثَهُمْ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا قَزَعَةَ، يُحَدِّثُ عَنِ الْمُهَاجِرِ الْمَكِّيِّ، قَالَ سُئِلَ جَابِرُ بْنُ عَبْدِ اللَّهِ عَنِ الرَّجُلِ، يَرَى الْبَيْتَ يَرْفَعُ يَدَيْهِ فَقَالَ مَا كُنْتُ أَرَى أَحَدًا يَفْعَلُ هَذَا إِلاَّ الْيَهُودَ وَقَدْ حَجَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يَكُنْ يَفْعَلُهُ ‏.‏\hadithno{1870}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: was asked about a man who looks at the House (the Ka'bah) and raises his hands (for prayer). He replied: I did not find anyone doing this except the Jews. We performed hajj along with the Messenger of Allah (ﷺ), but he did not do so}}
\hadithdefcmd{abudawud}{1871}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا سَلاَّمُ بْنُ مِسْكِينٍ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ الأَنْصَارِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا دَخَلَ مَكَّةَ طَافَ بِالْبَيْتِ وَصَلَّى رَكْعَتَيْنِ خَلْفَ الْمَقَامِ يَعْنِي يَوْمَ الْفَتْحِ ‏.‏\hadithno{1871}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim (1780)}\hadithtrans{Abu Hurairah said When the Prophet(ﷺ) entered Makkah he circumambulated the House(the Ka’bah) and offered two rak’ahs of prayer behind the station. That is, he did so on the day of the Conquest (of Makkah)}}
\hadithdefcmd{abudawud}{1872}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، وَهَاشِمٌ، - يَعْنِي ابْنَ الْقَاسِمِ - قَالاَ حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ مَكَّةَ فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْحَجَرِ فَاسْتَلَمَهُ ثُمَّ طَافَ بِالْبَيْتِ ثُمَّ أَتَى الصَّفَا فَعَلاَهُ حَيْثُ يَنْظُرُ إِلَى الْبَيْتِ فَرَفَعَ يَدَيْهِ فَجَعَلَ يَذْكُرُ اللَّهَ مَا شَاءَ أَنْ يَذْكُرَهُ وَيَدْعُوهُ قَالَ وَالأَنْصَارُ تَحْتَهُ قَالَ هَاشِمٌ فَدَعَا وَحَمِدَ اللَّهَ وَدَعَا بِمَا شَاءَ أَنْ يَدْعُوَ ‏.‏\hadithno{1872}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim (1780)}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) came an entered Mecca, and after the Messenger of Allah (ﷺ) had gone forward to the Stone, and touched it, he went round the House (the Ka'bah). He then went to as-Safa and mounted it so that he could look at the House. Then he raised his hands began to make mention of Allah as much as he wished and make supplication. The narrator said: The Ansar were beneath him. The narrator Hashim said: He prayed and praised Allah and asked Him for what he wished to ask}}
\hadithdefcmd{abudawud}{1873}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَابِسِ بْنِ رَبِيعَةَ، عَنْ عُمَرَ، أَنَّهُ جَاءَ إِلَى الْحَجَرِ فَقَبَّلَهُ فَقَالَ إِنِّي أَعْلَمُ أَنَّكَ حَجَرٌ لاَ تَنْفَعُ وَلاَ تَضُرُّ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقَبِّلُكَ مَا قَبَّلْتُكَ ‏.‏\hadithno{1873}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1597) Sahih Muslim (1270)}\hadithtrans{Abis bin Rabi’ah said on the authority of ‘Umar He(‘Umar) came to the (Black) Stone and said “ I know for sure that you are a stone which can neither benefit nor injure and had I not seen the Apostle of Allaah(ﷺ) kissing you, I would not have kissed you.”}}
\hadithdefcmd{abudawud}{1874}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْسَحُ مِنَ الْبَيْتِ إِلاَّ الرُّكْنَيْنِ الْيَمَانِيَيْنِ ‏.‏\hadithno{1874}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1609) Sahih Muslim (1267)}\hadithtrans{Ibn ‘Umar said I have not seen the Apostle of Allaah(ﷺ) touching anything in the House (the Ka’bah) but the two Yamani corners}}
\hadithdefcmd{abudawud}{1875}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ أُخْبِرَ بِقَوْلِ، عَائِشَةَ رضى الله عنها إِنَّ الْحَجَرَ بَعْضُهُ مِنَ الْبَيْتِ ‏.‏ فَقَالَ ابْنُ عُمَرَ وَاللَّهِ إِنِّي لأَظُنُّ عَائِشَةَ إِنْ كَانَتْ سَمِعَتْ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنِّي لأَظُنُّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَتْرُكِ اسْتِلاَمَهُمَا إِلاَّ أَنَّهُمَا لَيْسَا عَلَى قَوَاعِدِ الْبَيْتِ وَلاَ طَافَ النَّاسُ وَرَاءَ الْحِجْرِ إِلاَّ لِذَلِكَ ‏.‏\hadithno{1875}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Umar was informed about the statement of Aisha that a part of al-Hijr is included in the magnitude of the Ka'bah. Ibn Umar said:By Allah, I think that she must have heard it from the Messenger of Allah (ﷺ). I think that the Messenger of Allah (ﷺ) had not given up touching both of them but for the reason that they were not on the foundation of the House (the Ka'bah), nor did the people circumambulate (the House) beyond al-Hijr for this reason}}
\hadithdefcmd{abudawud}{1876}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَدَعُ أَنْ يَسْتَلِمَ الرُّكْنَ الْيَمَانِيَ وَالْحَجَرَ فِي كُلِّ طَوْفَةٍ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَفْعَلُهُ ‏.‏\hadithno{1876}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Umar said The Apostle of Allaah(ﷺ) did not give up touching the Yamani corner and the (Black) Stone in each of his circumambulations. Ibn ‘Umar used to do so}}
\hadithdefcmd{abudawud}{1877}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ - عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ فِي حَجَّةِ الْوَدَاعِ عَلَى بَعِيرٍ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ ‏.‏\hadithno{1877}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1607) Sahih Muslim (1272)}\hadithtrans{Ibn ‘Abbas said The Apostle of Allaah(ﷺ) performed the circumambulation at the Farewell Pilgrimage on a Camel and touched the corner(Black Stone) with a crooked stick}}
\hadithdefcmd{abudawud}{1878}{حَدَّثَنَا مُصَرِّفُ بْنُ عَمْرٍو الْيَامِيُّ، حَدَّثَنَا يُونُسُ، - يَعْنِي ابْنَ بُكَيْرٍ - حَدَّثَنَا ابْنُ إِسْحَاقَ، حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، قَالَتْ لَمَّا اطْمَأَنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ عَامَ الْفَتْحِ طَافَ عَلَى بَعِيرٍ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ فِي يَدِهِ ‏.‏ قَالَتْ وَأَنَا أَنْظُرُ إِلَيْهِ ‏.‏\hadithno{1878}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Safiyyah, daughter of Shaybah: When the Messenger of Allah (ﷺ) had some rest at Mecca in the year of its Conquest, he performed circumambulation on a camel and touched the corner (black Stone) with a crooked stick in his hand. She said: I was looking at him}}
\hadithdefcmd{abudawud}{1879}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ رَافِعٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ مَعْرُوفٍ، - يَعْنِي ابْنَ خَرَّبُوذَ الْمَكِّيَّ - حَدَّثَنَا أَبُو الطُّفَيْلِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَطُوفُ بِالْبَيْتِ عَلَى رَاحِلَتِهِ يَسْتَلِمُ الرُّكْنَ بِمِحْجَنِهِ ثُمَّ يُقَبِّلُهُ زَادَ مُحَمَّدُ بْنُ رَافِعٍ ثُمَّ خَرَجَ إِلَى الصَّفَا وَالْمَرْوَةِ فَطَافَ سَبْعًا عَلَى رَاحِلَتِهِ ‏.‏\hadithno{1879}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1265)}\hadithtrans{Abu Al Tufail reported on the authority of Ibn ‘Abbas who said I saw the Prophet (ﷺ) circumambulating the Ka’bah on his Camel, touching the corner (Black Stone) with a crooked stick and kissing it (the crooked stick). The narrator Muhammad bin Rafi’ added “he then went o Al Safa and Al Marwah and ran seven times on his Camel}}
\hadithdefcmd{abudawud}{1880}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ طَافَ النَّبِيُّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ عَلَى رَاحِلَتِهِ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ لِيَرَاهُ النَّاسُ وَلِيُشْرِفَ وَلِيَسْأَلُوهُ فَإِنَّ النَّاسَ غَشُوهُ ‏.‏\hadithno{1880}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1273)}\hadithtrans{Jabir bin ‘Abd Allah said The Prophet(ﷺ) performed the circumambulation of the House(the Ka’bah) on his Camel at the Farewell Pilgrimage and ran between Al Safa’ and Al Marwah, so that the people could see him, remain well informed about him and ask him questions(about Hajj) for the people surrounded him}}
\hadithdefcmd{abudawud}{1881}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدِمَ مَكَّةَ وَهُوَ يَشْتَكِي فَطَافَ عَلَى رَاحِلَتِهِ كُلَّمَا أَتَى عَلَى الرُّكْنِ اسْتَلَمَ الرُّكْنَ بِمِحْجَنٍ فَلَمَّا فَرَغَ مِنْ طَوَافِهِ أَنَاخَ فَصَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{1881}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas said When the Apostle of Allaah(ﷺ) came to Makkah he was ill. So, he performed the circumambulation on his Camel. He touched the corner (Black Stone) with a crooked stick as often as he came to it. When he finished the circumambulation, he made his Camel kneel down and offered two rak’ahs of prayer}}
\hadithdefcmd{abudawud}{1882}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ شَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِّي أَشْتَكِي فَقَالَ ‏"‏ طُوفِي مِنْ وَرَاءِ النَّاسِ وَأَنْتِ رَاكِبَةٌ ‏"‏ ‏.‏ قَالَتْ فَطُفْتُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حِينَئِذٍ يُصَلِّي إِلَى جَنْبِ الْبَيْتِ وَهُوَ يَقْرَأُ بِـ ‏\{‏ الطُّورِ * وَكِتَابٍ مَسْطُورٍ ‏\}‏ ‏.‏\hadithno{1882}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (464) Sahih Muslim (1276)}\hadithtrans{Umm Salamah said I complained to the Apostle of Allaah(ﷺ) that I was ill. He said “Perform the circumambulation riding behind the people”. She said “I performed circumambulation and the Apostle of Allaah(ﷺ) was praying towards the side of the House(the Ka’bah) and reciting “by al Tur and a Book inscribed”.”}}
\hadithdefcmd{abudawud}{1883}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ يَعْلَى، عَنْ يَعْلَى، قَالَ طَافَ النَّبِيُّ صلى الله عليه وسلم مُضْطَبِعًا بِبُرْدٍ أَخْضَرَ ‏.‏\hadithno{1883}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ya'la: The Messenger of Allah (ﷺ) went round the House (the Ka'bah) wearing a green Yamani mantle under his right armpit with the end over his left shoulder}}
\hadithdefcmd{abudawud}{1884}{حَدَّثَنَا أَبُو سَلَمَةَ، مُوسَى حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَصْحَابَهُ اعْتَمَرُوا مِنَ الْجِعْرَانَةِ فَرَمَلُوا بِالْبَيْتِ وَجَعَلُوا أَرْدِيَتَهُمْ تَحْتَ آبَاطِهِمْ قَدْ قَذَفُوهَا عَلَى عَوَاتِقِهِمُ الْيُسْرَى ‏.‏\hadithno{1884}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) and his Companions performed umrah from al-Ji'ranah. They went quickly round the House (the Ka'bah) moving their shoulders) proudly. They put their upper garments under their armpits and threw the ends over their left shoulders}}
\hadithdefcmd{abudawud}{1885}{حَدَّثَنَا أَبُو سَلَمَةَ، مُوسَى بْنُ إِسْمَاعِيلَ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَبُو عَاصِمٍ الْغَنَوِيُّ، عَنْ أَبِي الطُّفَيْلِ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ يَزْعُمُ قَوْمُكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ رَمَلَ بِالْبَيْتِ وَأَنَّ ذَلِكَ سُنَّةٌ ‏.‏ قَالَ صَدَقُوا وَكَذَبُوا ‏.‏ قُلْتُ وَمَا صَدَقُوا وَمَا كَذَبُوا قَالَ صَدَقُوا قَدْ رَمَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَذَبُوا لَيْسَ بِسُنَّةٍ إِنَّ قُرَيْشًا قَالَتْ زَمَنَ الْحُدَيْبِيَةِ دَعُوا مُحَمَّدًا وَأَصْحَابَهُ حَتَّى يَمُوتُوا مَوْتَ النَّغَفِ ‏.‏ فَلَمَّا صَالَحُوهُ عَلَى أَنْ يَجِيئُوا مِنَ الْعَاِمِ الْمُقْبِلِ فَيُقِيمُوا بِمَكَّةَ ثَلاَثَةَ أَيَّامٍ فَقَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمُشْرِكُونَ مِنْ قِبَلِ قُعَيْقِعَانَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏ "‏ ارْمُلُوا بِالْبَيْتِ ثَلاَثًا ‏"‏ ‏.‏ وَلَيْسَ بِسُنَّةٍ ‏.‏ قُلْتُ يَزْعُمُ قَوْمُكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ عَلَى بَعِيرِهِ وَأَنَّ ذَلِكَ سُنَّةٌ فَقَالَ صَدَقُوا وَكَذَبُوا ‏.‏ قُلْتُ مَا صَدَقُوا وَمَا كَذَبُوا قَالَ صَدَقُوا قَدْ طَافَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الصَّفَا وَالْمَرْوَةِ عَلَى بَعِيرِهِ وَكَذَبُوا لَيْسَ بِسُنَّةٍ كَانَ النَّاسُ لاَ يُدْفَعُونَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ يُصْرَفُونَ عَنْهُ فَطَافَ عَلَى بَعِيرٍ لِيَسْمَعُوا كَلاَمَهُ وَلِيَرَوْا مَكَانَهُ وَلاَ تَنَالَهُ أَيْدِيهِمْ ‏.‏\hadithno{1885}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Al Tufail said I said to Ibn ‘Abbas Your people think that the Apostle of Allaah(ﷺ) walked proudly with swift strides while going round the Ka’bah and that it is sunnah (practice of the Prophet). He said “They spoke the truth (in part) and told a lie (in part).” I asked “What truth did they speak and what lie did they tell?” He said “They spoke the truth that the Apostle of Allaah(ﷺ) walked proudly while going round the Ka’bah but they told a lie, this is no sunnah. The Quraish asserted during the days of Al Hudaibiyyah “Forsake Muhammad and his Companions till they die the death of a Camel which dies of bacteria in its nose. When they concluded a treaty with him agreeing upon the fact that they (the Prophet and his Companions) would come (to Makkah) next year and stay at Makkah three days, the Apostle of Allaah(ﷺ) said to the Companions “Walk proudly (moving shoulders) while going round the Ka’bah in first three circuits. (Ibn ‘Abbas said) But this is not sunnah. I said “Your people think that the Apostle of Allaah(ﷺ) ran between Al Safa and Al Marwah on a Camel and that is sunnah.” He said “They spoke the truth (in part) and told a lie (in part). I asked “What truth did they speak and what lie did they tell? He said “they spoke the truth that the Apostle of Allaah(ﷺ) ran between Al Safa and Al Marwah on a Camel. They told a lie that it is a sunnah. As the people did not move from around the Apostle of Allaah(ﷺ) and did not separate themselves from him he did the sa’i on a Camel so that they may listen to him and see his position and their hands might not reach him}}
\hadithdefcmd{abudawud}{1886}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّهُ حَدَّثَ عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ وَقَدْ وَهَنَتْهُمْ حُمَّى يَثْرِبَ فَقَالَ الْمُشْرِكُونَ إِنَّهُ يَقْدَمُ عَلَيْكُمْ قَوْمٌ قَدْ وَهَنَتْهُمُ الْحُمَّى وَلَقُوا مِنْهَا شَرًّا فَأَطْلَعَ اللَّهُ سُبْحَانَهُ نَبِيَّهُ صلى الله عليه وسلم عَلَى مَا قَالُوهُ فَأَمَرَهُمْ أَنْ يَرْمُلُوا الأَشْوَاطَ الثَّلاَثَةَ وَأَنْ يَمْشُوا بَيْنَ الرُّكْنَيْنِ فَلَمَّا رَأَوْهُمْ رَمَلُوا قَالُوا هَؤُلاَءِ الَّذِينَ ذَكَرْتُمْ أَنَّ الْحُمَّى قَدْ وَهَنَتْهُمْ هَؤُلاَءِ أَجْلَدُ مِنَّا ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَلَمْ يَأْمُرْهُمْ أَنْ يَرْمُلُوا الأَشْوَاطَ إِلاَّ إِبْقَاءً عَلَيْهِمْ ‏.‏\hadithno{1886}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1602) Sahih Muslim (1266)}\hadithtrans{Ibn ‘Abbas said The Apostle of Allaah(ﷺ) came to Makkah while the fever of Yathrib (Medina) had weakened them. Thereupon the disbelievers said “The people whom the fever has weakened and who suffer misery at Medina are coming to you.” Allaah, the exalted, informed the Prophet (ﷺ) of what they had said. He, therefore, ordered them to perform ramal (walk proudly with swift pace) in first three circuits and walk ordinarily between the two corners (Yamani Corner and the Black Stone). When they saw them the believers walking proudly, they said” These are the people about whom you mentioned that the fever had weakened them, but they are more vigorous than us.” Ibn ‘Abbas said “He did not order them to walk proudly in all circuits (of the circumambulation) out of mercy upon them.”}}
\hadithdefcmd{abudawud}{1887}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ فِيمَ الرَّمَلاَنُ الْيَوْمَ وَالْكَشْفُ عَنِ الْمَنَاكِبِ، وَقَدْ أَطَّأَ اللَّهُ الإِسْلاَمَ وَنَفَى الْكُفْرَ وَأَهْلَهُ مَعَ ذَلِكَ لاَ نَدَعُ شَيْئًا كُنَّا نَفْعَلُهُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1887}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aslam said:I heard Umar ibn al-Khattab say: What is the need of walking proudly (ramal) and moving the shoulders (while going round the Ka'bah)? Allah has now strengthened Islam and obliterated disbelief and the infidels. In spite of that we shall not forsake anything that we used to do during the time of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{1888}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا جُعِلَ الطَّوَافُ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ وَرَمْىُ الْجِمَارِ لإِقَامَةِ ذِكْرِ اللَّهِ ‏"‏ ‏.‏\hadithno{1888}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: Going round the House (the Ka'bah), running between as-Safa and lapidation of the pillars are meant for the remembrance of Allah}}
\hadithdefcmd{abudawud}{1889}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنِ ابْنِ خُثَيْمٍ، عَنْ أَبِي الطُّفَيْلِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اضْطَبَعَ فَاسْتَلَمَ وَكَبَّرَ ثُمَّ رَمَلَ ثَلاَثَةَ أَطْوَافٍ وَكَانُوا إِذَا بَلَغُوا الرُّكْنَ الْيَمَانِيَ وَتَغَيَّبُوا مِنْ قُرَيْشٍ مَشَوْا ثُمَّ يَطْلُعُونَ عَلَيْهِمْ يَرْمُلُونَ تَقُولُ قُرَيْشٌ كَأَنَّهُمُ الْغِزْلاَنُ قَالَ ابْنُ عَبَّاسٍ فَكَانَتْ سُنَّةً ‏.‏\hadithno{1889}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) wore the mantle under his right armpit with the end over his left shoulder, and touched the corner (Black Stone), then uttered "Allah is most great" and walked proudly in three circuits of circumambulation. When they (the Companions) reached the Yamani corner, and disappeared from the eyes of the Quraysh, they walked as usual; When they appeared before them, they walked proudly with rapid strides. Thereupon the Quraysh said: They look to be the deer (that are jumping). Ibn Abbas said: Hence this became the sunnah (model behaviour of the Prophet)}}
\hadithdefcmd{abudawud}{1890}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ أَبِي الطُّفَيْلِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَصْحَابَهُ اعْتَمَرُوا مِنَ الْجِعْرَانَةِ فَرَمَلُوا بِالْبَيْتِ ثَلاَثًا وَمَشَوْا أَرْبَعًا ‏.‏\hadithno{1890}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) and his Companions performed umrah from al-Ji'ranah and walked proudly with rapid strides round the House (the Ka'bah) in three circuits and walked as usual in four circuits}}
\hadithdefcmd{abudawud}{1891}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا سُلَيْمُ بْنُ أَخْضَرَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، رَمَلَ مِنَ الْحَجَرِ إِلَى الْحَجَرِ وَذَكَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ ذَلِكَ ‏.‏\hadithno{1891}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1262)}\hadithtrans{Nafi’ said Ibn ‘Umar walked proudly (ramal) from the corner (Black Stone) to the corner (Black Stone) and mentioned that the Apostle of Allaah (ﷺ) had done so}}
\hadithdefcmd{abudawud}{1892}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ يَحْيَى بْنِ عُبَيْدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ مَا بَيْنَ الرُّكْنَيْنِ ‏\{‏ رَبَّنَا آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنَا عَذَابَ النَّارِ ‏\}‏ ‏.‏\hadithno{1892}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn as-Sa'ib: I heard the Messenger of Allah (ﷺ) say between the two corners: O Allah, bring us a blessing in this world and a blessing in the next and guard us from punishment of Hell}}
\hadithdefcmd{abudawud}{1893}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا طَافَ فِي الْحَجِّ وَالْعُمْرَةِ أَوَّلَ مَا يَقْدَمُ فَإِنَّهُ يَسْعَى ثَلاَثَةَ أَطْوَافٍ وَيَمْشِي أَرْبَعًا ثُمَّ يُصَلِّي سَجْدَتَيْنِ ‏.‏\hadithno{1893}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1616) Sahih Muslim (1261)}\hadithtrans{Ibn ‘Umar said When the Apostle of Allaah(ﷺ) observed the circumambulation at hajj and ‘Umrah on his arrival, he ran three circuits and walked four, then he made two prostrations}}
\hadithdefcmd{abudawud}{1894}{حَدَّثَنَا ابْنُ السَّرْحِ، وَالْفَضْلُ بْنُ يَعْقُوبَ، - وَهَذَا لَفْظُهُ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَاهْ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَمْنَعُوا أَحَدًا يَطُوفُ بِهَذَا الْبَيْتِ وَيُصَلِّي أَىَّ سَاعَةٍ شَاءَ مِنْ لَيْلٍ أَوْ نَهَارٍ ‏"‏ ‏.‏ قَالَ الْفَضْلُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَا بَنِي عَبْدِ مَنَافٍ لاَ تَمْنَعُوا أَحَدًا ‏"‏ ‏.‏\hadithno{1894}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jubayr ibn Mut'im: The Prophet (ﷺ) said: Do not prevent anyone from going round this House (the Ka'bah) and from praying any moment he desires by day or by night. The narrator Fadl (ibn Ya'qub) said: The Messenger of Allah (ﷺ) said: Banu Abdu Munaf, do not stop anyone}}
\hadithdefcmd{abudawud}{1895}{حَدَّثَنَا ابْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ لَمْ يَطُفِ النَّبِيُّ صلى الله عليه وسلم وَلاَ أَصْحَابُهُ بَيْنَ الصَّفَا وَالْمَرْوَةِ إِلاَّ طَوَافًا وَاحِدًا طَوَافَهُ الأَوَّلَ ‏.‏\hadithno{1895}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1215)}\hadithtrans{Jabir bin ‘Abdallah said “Neither the Prophet (ﷺ) nor his Companions ran between Al Safa’ and Al Marwah except once and that was his first running.”}}
\hadithdefcmd{abudawud}{1896}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَصْحَابَ، رَسُولِ اللَّهِ صلى الله عليه وسلم الَّذِينَ كَانُوا مَعَهُ لَمْ يَطُوفُوا حَتَّى رَمَوُا الْجَمْرَةَ ‏.‏\hadithno{1896}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Companions of the Messenger of Allah (ﷺ) who accompanied him did not go round the Ka'bah till they threw pebbles at the Jamrah (pillar at Mina)}}
\hadithdefcmd{abudawud}{1897}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ الْمُؤَذِّنُ، أَخْبَرَنِي الشَّافِعِيُّ، عَنِ ابْنِ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ طَوَافُكِ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ يَكْفِيكِ لِحَجَّتِكِ وَعُمْرَتِكِ ‏"‏ ‏.‏ قَالَ الشَّافِعِيُّ كَانَ سُفْيَانُ رُبَّمَا قَالَ عَنْ عَطَاءٍ عَنْ عَائِشَةَ ‏.‏ وَرُبَّمَا قَالَ عَنْ عَطَاءٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِعَائِشَةَ رضى الله عنها ‏.‏\hadithno{1897}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Ata said The Prophet (ﷺ) said to A’ishah Your observance of circumambulation of the Ka’bah and your running between Al Safa’ and al Marwah (only once) are sufficient for your Hajj and your ‘Umrah. Al Shafi’i said The narrator Sufyan has transmitted this tradition from ‘Ata on the authority of A’ishah and also narrated it on the authority of ‘Ata stating that the Prophet (ﷺ) said to A’ishah(may Allah be pleased with her)}}
\hadithdefcmd{abudawud}{1898}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ صَفْوَانَ، قَالَ لَمَّا فَتَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ قُلْتُ لأَلْبَسَنَّ ثِيَابِي - وَكَانَتْ دَارِي عَلَى الطَّرِيقِ - فَلأَنْظُرَنَّ كَيْفَ يَصْنَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَانْطَلَقْتُ فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم قَدْ خَرَجَ مِنَ الْكَعْبَةِ هُوَ وَأَصْحَابُهُ وَقَدِ اسْتَلَمُوا الْبَيْتَ مِنَ الْبَابِ إِلَى الْحَطِيمِ وَقَدْ وَضَعُوا خُدُودَهُمْ عَلَى الْبَيْتِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَسْطَهُمْ ‏.‏\hadithno{1898}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbdurRahman ibn Safwan: When the Messenger of Allah (ﷺ) conquered Mecca, I said (to myself): I shall put on my clothes, and my house lay on the way, I shall watch how the Messenger of Allah (ﷺ) behaves. So I went out. I saw that the Prophet (ﷺ) and his Companions had come out from the Ka'bah and embraced the House (the Ka'bah) from its entrance (al-Bab) to al-Hatim. They placed their cheek on the House (the Ka'bah) while the Messenger of Allah (ﷺ) was amongst them}}
\hadithdefcmd{abudawud}{1899}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الْمُثَنَّى بْنُ الصَّبَّاحِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، قَالَ طُفْتُ مَعَ عَبْدِ اللَّهِ فَلَمَّا جِئْنَا دُبَرَ الْكَعْبَةِ قُلْتُ أَلاَ تَتَعَوَّذُ ‏.‏ قَالَ نَعُوذُ بِاللَّهِ مِنَ النَّارِ ‏.‏ ثُمَّ مَضَى حَتَّى اسْتَلَمَ الْحَجَرَ وَأَقَامَ بَيْنَ الرُّكْنِ وَالْبَابِ فَوَضَعَ صَدْرَهُ وَوَجْهَهُ وَذِرَاعَيْهِ وَكَفَّيْهِ هَكَذَا وَبَسَطَهُمَا بَسْطًا ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ ‏.‏\hadithno{1899}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Amr b. Shu'aib reported on the authority of his father:I went round the Ka'bah along with Abdullah ibn Amr. When we came behind the Ka'bah I asked: Do you not seek refuge? He uttered the words: I seek refuge in Allah from the Hell-fire. He then went (farther) and touched the Black Stone, and stood between the corner (Black Stone) and the entrance of the Ka'bah. He then placed his breast, his face, his hands and his palms in this manner, and he spread them, and said: I saw the apostle of Allah (ﷺ) doing like this}}
\hadithdefcmd{abudawud}{1900}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا السَّائِبُ بْنُ عُمَرَ الْمَخْزُومِيُّ، حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُودُ ابْنَ عَبَّاسٍ فَيُقِيمُهُ عِنْدَ الشُّقَّةِ الثَّالِثَةِ مِمَّا يَلِي الرُّكْنَ الَّذِي يَلِي الْحَجَرَ مِمَّا يَلِي الْبَابَ فَيَقُولُ لَهُ ابْنُ عَبَّاسٍ أُنْبِئْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي هَا هُنَا فَيَقُولُ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ فَيَقُومُ فَيُصَلِّي ‏.‏\hadithno{1900}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah ibn as-Sa'ib reported on the authority of his father as-Sa'ib that he used to lead Ibn Abbas (when he become blind) and make him stand in the third corner that was adjacent to the corner (Black Stone) near the entrance of the Ka'bah. Ibn Abbas used to say:Has it been reported to you that the Messenger of Allah (ﷺ) would pray in this place. He would reply: Yes. He then used to stand (there) and pray}}
\hadithdefcmd{abudawud}{1901}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، ح وَحَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ قُلْتُ لِعَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَأَنَا يَوْمَئِذٍ حَدِيثُ السِّنِّ أَرَأَيْتِ قَوْلَ اللَّهِ تَعَالَى ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ ‏\}‏ فَمَا أَرَى عَلَى أَحَدٍ شَيْئًا أَنْ لاَ يَطَّوَّفَ بِهِمَا ‏.‏ قَالَتْ عَائِشَةُ كَلاَّ لَوْ كَانَ كَمَا تَقُولُ كَانَتْ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا إِنَّمَا أُنْزِلَتْ هَذِهِ الآيَةُ فِي الأَنْصَارِ كَانُوا يُهِلُّونَ لِمَنَاةَ وَكَانَتْ مَنَاةُ حَذْوَ قُدَيْدٍ وَكَانُوا يَتَحَرَّجُونَ أَنْ يَطُوفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ فَلَمَّا جَاءَ الإِسْلاَمُ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ ‏\}‏ ‏.‏\hadithno{1901}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1790) Sahih Muslim (1277)}\hadithtrans{‘Urwa bin Al Zubair said I said to A’ishah, wife of the Prophet(ﷺ) while I was a boy. What do you think about the pronouncement of Allaah, the Exalted “Lo! (The Mountains) Al Safa’ and Al Marwah are among the indications of Allaah. “I think there is no harm for anyone if he does not run between them. A’ishah(may Allah be pleased with her) said Nay, had it been so as you said, it would have been thus. It is no sin on him not to go around them. This verse was revealed about the Ansaar, they used to perform hajj for Manat. Manat was erected in front of Qudaid. Hence they used to avoid going around Al Safa and Al Marwah. When Islam came, they asked the Apostle of Allaah(ﷺ) about it. Allaah, the Exalted therefore revealed the verse “Lo! (The Mountains) Al Safa’ and Al Marwah are among the indications of Allaah}}
\hadithdefcmd{abudawud}{1902}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اعْتَمَرَ فَطَافَ بِالْبَيْتِ وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ وَمَعَهُ مَنْ يَسْتُرُهُ مِنَ النَّاسِ فَقِيلَ لِعَبْدِ اللَّهِ أَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْكَعْبَةَ قَالَ لاَ ‏.‏\hadithno{1902}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1600) Sahih Muslim (1332)}\hadithtrans{‘Abd Allaah bin Abi Aufa said the Apostle of Allaah(ﷺ) performed ‘Umrah and went round the House(the Ka’bah) and prayed behind the station (Maqam Ibrahim) two rak’ahs and he was accompanied by so many people that he was hidden by them. ‘Abd Allaah bin Abi Aufa was asked Did the Apostle of Allaah(ﷺ) enter the Ka’bah ? He replied “No”}}
\hadithdefcmd{abudawud}{1903}{حَدَّثَنَا تَمِيمُ بْنُ الْمُنْتَصِرِ، أَخْبَرَنَا إِسْحَاقُ بْنُ يُوسُفَ، أَخْبَرَنَا شَرِيكٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، بِهَذَا الْحَدِيثِ زَادَ ثُمَّ أَتَى الصَّفَا وَالْمَرْوَةَ فَسَعَى بَيْنَهُمَا سَبْعًا ثُمَّ حَلَقَ رَأْسَهُ ‏.‏\hadithno{1903}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Isma’il bin Abi Khalid said I heard ‘Abd Allaah bin Abi Aufa narrated this tradition. His version added “He then came to Al Safa’ and Al Marwah and ran between them seven times and then shaved his head}}
\hadithdefcmd{abudawud}{1904}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ كَثِيرِ بْنِ جُمْهَانَ، أَنَّ رَجُلاً، قَالَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ بَيْنَ الصَّفَا وَالْمَرْوَةِ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنِّي أَرَاكَ تَمْشِي وَالنَّاسُ يَسْعَوْنَ قَالَ إِنْ أَمْشِ فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْشِي وَإِنْ أَسْعَ فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْعَى وَأَنَا شَيْخٌ كَبِيرٌ ‏.‏\hadithno{1904}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Kathir ibn Jamhan said:A man asked Abdullah ibn Umar between as-Safa and al-Marwah: AbdurRahman, I see you walking while the people are running (between as-Safa and al-Marwah)? He replied: If I walk, I saw the Messenger of Allah (ﷺ) running. I am too old}}
\hadithdefcmd{abudawud}{1905}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، وَسُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيَّانِ، - وَرُبَّمَا زَادَ بَعْضُهُمْ عَلَى بَعْضٍ الْكَلِمَةَ وَالشَّىْءَ - قَالُوا حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ عَنْ أَبِيهِ قَالَ دَخَلْنَا عَلَى جَابِرِ بْنِ عَبْدِ اللَّهِ فَلَمَّا انْتَهَيْنَا إِلَيْهِ سَأَلَ عَنِ الْقَوْمِ حَتَّى انْتَهَى إِلَىَّ فَقُلْتُ أَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ حُسَيْنٍ ‏.‏ فَأَهْوَى بِيَدِهِ إِلَى رَأْسِي فَنَزَعَ زِرِّي الأَعْلَى ثُمَّ نَزَعَ زِرِّي الأَسْفَلَ ثُمَّ وَضَعَ كَفَّهُ بَيْنَ ثَدْيَىَّ وَأَنَا يَوْمَئِذٍ غُلاَمٌ شَابٌّ ‏.‏ فَقَالَ مَرْحَبًا بِكَ وَأَهْلاً يَا ابْنَ أَخِي سَلْ عَمَّا شِئْتَ ‏.‏ فَسَأَلْتُهُ وَهُوَ أَعْمَى وَجَاءَ وَقْتُ الصَّلاَةِ فَقَامَ فِي نِسَاجَةٍ مُلْتَحِفًا بِهَا يَعْنِي ثَوْبًا مُلَفَّقًا كُلَّمَا وَضَعَهَا عَلَى مَنْكِبِهِ رَجَعَ طَرَفَاهَا إِلَيْهِ مِنْ صِغَرِهَا فَصَلَّى بِنَا وَرِدَاؤُهُ إِلَى جَنْبِهِ عَلَى الْمِشْجَبِ ‏.‏ فَقُلْتُ أَخْبِرْنِي عَنْ حَجَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ بِيَدِهِ فَعَقَدَ تِسْعًا ‏.‏ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَكَثَ تِسْعَ سِنِينَ لَمْ يَحُجَّ ثُمَّ أُذِّنَ فِي النَّاسِ فِي الْعَاشِرَةِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَاجٌّ فَقَدِمَ الْمَدِينَةَ بَشَرٌ كَثِيرٌ كُلُّهُمْ يَلْتَمِسُ أَنْ يَأْتَمَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَيَعْمَلَ بِمِثْلِ عَمَلِهِ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَخَرَجْنَا مَعَهُ حَتَّى أَتَيْنَا ذَا الْحُلَيْفَةِ فَوَلَدَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ أَصْنَعُ قَالَ ‏"‏ اغْتَسِلِي وَاسْتَذْفِرِي بِثَوْبٍ وَأَحْرِمِي ‏"‏ ‏.‏ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ ثُمَّ رَكِبَ الْقَصْوَاءَ حَتَّى إِذَا اسْتَوَتْ بِهِ نَاقَتُهُ عَلَى الْبَيْدَاءِ ‏.‏ قَالَ جَابِرٌ نَظَرْتُ إِلَى مَدِّ بَصَرِي مِنْ بَيْنِ يَدَيْهِ مِنْ رَاكِبٍ وَمَاشٍ وَعَنْ يَمِينِهِ مِثْلَ ذَلِكَ وَعَنْ يَسَارِهِ مِثْلَ ذَلِكَ وَمِنْ خَلْفِهِ مِثْلَ ذَلِكَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا وَعَلَيْهِ يَنْزِلُ الْقُرْآنُ وَهُوَ يَعْلَمُ تَأْوِيلَهُ فَمَا عَمِلَ بِهِ مِنْ شَىْءٍ عَمِلْنَا بِهِ فَأَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالتَّوْحِيدِ ‏"‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ وَأَهَلَّ النَّاسُ بِهَذَا الَّذِي يُهِلُّونَ بِهِ فَلَمْ يَرُدَّ عَلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا مِنْهُ وَلَزِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم تَلْبِيَتَهُ ‏.‏ قَالَ جَابِرٌ لَسْنَا نَنْوِي إِلاَّ الْحَجَّ لَسْنَا نَعْرِفُ الْعُمْرَةَ حَتَّى إِذَا أَتَيْنَا الْبَيْتَ مَعَهُ اسْتَلَمَ الرُّكْنَ فَرَمَلَ ثَلاَثًا وَمَشَى أَرْبَعًا ثُمَّ تَقَدَّمَ إِلَى مَقَامِ إِبْرَاهِيمَ فَقَرَأَ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏\}‏ فَجَعَلَ الْمَقَامَ بَيْنَهُ وَبَيْنَ الْبَيْتِ قَالَ فَكَانَ أَبِي يَقُولُ قَالَ ابْنُ نُفَيْلٍ وَعُثْمَانُ وَلاَ أَعْلَمُهُ ذَكَرَهُ إِلاَّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ سُلَيْمَانُ وَلاَ أَعْلَمُهُ إِلاَّ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الرَّكْعَتَيْنِ بِـ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ وَبِـ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏\}‏ ثُمَّ رَجَعَ إِلَى الْبَيْتِ فَاسْتَلَمَ الرُّكْنَ ثُمَّ خَرَجَ مِنَ الْبَابِ إِلَى الصَّفَا فَلَمَّا دَنَا مِنَ الصَّفَا قَرَأَ ‏\{‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ ‏\}‏ ‏"‏ نَبْدَأُ بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏ فَبَدَأَ بِالصَّفَا فَرَقِيَ عَلَيْهِ حَتَّى رَأَى الْبَيْتَ فَكَبَّرَ اللَّهَ وَوَحَّدَهُ وَقَالَ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ أَنْجَزَ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏ ‏.‏ ثُمَّ دَعَا بَيْنَ ذَلِكَ وَقَالَ مِثْلَ هَذَا ثَلاَثَ مَرَّاتٍ ثُمَّ نَزَلَ إِلَى الْمَرْوَةِ حَتَّى إِذَا انْصَبَّتْ قَدَمَاهُ رَمَلَ فِي بَطْنِ الْوَادِي حَتَّى إِذَا صَعِدَ مَشَى حَتَّى أَتَى الْمَرْوَةَ فَصَنَعَ عَلَى الْمَرْوَةِ مِثْلَ مَا صَنَعَ عَلَى الصَّفَا حَتَّى إِذَا كَانَ آخِرُ الطَّوَافِ عَلَى الْمَرْوَةِ قَالَ ‏"‏ إِنِّي لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ لَمْ أَسُقِ الْهَدْىَ وَلَجَعَلْتُهَا عُمْرَةً فَمَنْ كَانَ مِنْكُمْ لَيْسَ مَعَهُ هَدْىٌ فَلْيَحْلِلْ وَلْيَجْعَلْهَا عُمْرَةً ‏"‏ ‏.‏ فَحَلَّ النَّاسُ كُلُّهُمْ وَقَصَّرُوا إِلاَّ النَّبِيَّ صلى الله عليه وسلم وَمَنْ كَانَ مَعَهُ هَدْىٌ فَقَامَ سُرَاقَةُ بْنُ جُعْشُمٍ فَقَالَ يَا رَسُولَ اللَّهِ أَلِعَامِنَا هَذَا أَمْ لِلأَبَدِ فَشَبَّكَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَصَابِعَهُ فِي الأُخْرَى ثُمَّ قَالَ ‏"‏ دَخَلَتِ الْعُمْرَةُ فِي الْحَجِّ ‏"‏ ‏.‏ هَكَذَا مَرَّتَيْنِ ‏"‏ لاَ بَلْ لأَبَدِ أَبَدٍ لاَ بَلْ لأَبَدِ أَبَدٍ ‏"‏ ‏.‏ قَالَ وَقَدِمَ عَلِيٌّ - رضى الله عنه - مِنَ الْيَمَنِ بِبُدْنِ النَّبِيِّ صلى الله عليه وسلم فَوَجَدَ فَاطِمَةَ - رضى الله عنها - مِمَّنْ حَلَّ وَلَبِسَتْ ثِيَابًا صَبِيغًا وَاكْتَحَلَتْ فَأَنْكَرَ عَلِيٌّ ذَلِكَ عَلَيْهَا وَقَالَ مَنْ أَمَرَكِ بِهَذَا فَقَالَتْ أَبِي ‏.‏ فَكَانَ عَلِيٌّ يَقُولُ بِالْعِرَاقِ ذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مُحَرِّشًا عَلَى فَاطِمَةَ فِي الأَمْرِ الَّذِي صَنَعَتْهُ مُسْتَفْتِيًا لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي الَّذِي ذَكَرَتْ عَنْهُ فَأَخْبَرْتُهُ أَنِّي أَنْكَرْتُ ذَلِكَ عَلَيْهَا فَقَالَتْ إِنَّ أَبِي أَمَرَنِي بِهَذَا ‏.‏ فَقَالَ ‏"‏ صَدَقَتْ صَدَقَتْ مَاذَا قُلْتَ حِينَ فَرَضْتَ الْحَجَّ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُمَّ إِنِّي أُهِلُّ بِمَا أَهَلَّ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ فَإِنَّ مَعِيَ الْهَدْىَ فَلاَ تَحْلِلْ ‏"‏ ‏.‏ قَالَ وَكَانَ جَمَاعَةُ الْهَدْىِ الَّذِي قَدِمَ بِهِ عَلِيٌّ مِنَ الْيَمَنِ وَالَّذِي أَتَى بِهِ النَّبِيُّ صلى الله عليه وسلم مِنَ الْمَدِينَةِ مِائَةً فَحَلَّ النَّاسُ كُلُّهُمْ وَقَصَّرُوا إِلاَّ النَّبِيَّ صلى الله عليه وسلم وَمَنْ كَانَ مَعَهُ هَدْىٌ قَالَ فَلَمَّا كَانَ يَوْمُ التَّرْوِيَةِ وَوَجَّهُوا إِلَى مِنًى أَهَلُّوا بِالْحَجِّ فَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى بِمِنًى الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ وَالصُّبْحَ ثُمَّ مَكَثَ قَلِيلاً حَتَّى طَلَعَتِ الشَّمْسُ وَأَمَرَ بِقُبَّةٍ لَهُ مِنْ شَعَرٍ فَضُرِبَتْ بِنَمِرَةَ فَسَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ تَشُكُّ قُرَيْشٌ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَاقِفٌ عِنْدَ الْمَشْعَرِ الْحَرَامِ بِالْمُزْدَلِفَةِ كَمَا كَانَتْ قُرَيْشٌ تَصْنَعُ فِي الْجَاهِلِيَّةِ فَأَجَازَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَتَى عَرَفَةَ فَوَجَدَ الْقُبَّةَ قَدْ ضُرِبَتْ لَهُ بِنَمِرَةَ فَنَزَلَ بِهَا حَتَّى إِذَا زَاغَتِ الشَّمْسُ أَمَرَ بِالْقَصْوَاءِ فَرُحِلَتْ لَهُ فَرَكِبَ حَتَّى أَتَى بَطْنَ الْوَادِي فَخَطَبَ النَّاسَ فَقَالَ ‏"‏ إِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ عَلَيْكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا أَلاَ إِنَّ كُلَّ شَىْءٍ مِنْ أَمْرِ الْجَاهِلِيَّةِ تَحْتَ قَدَمَىَّ مَوْضُوعٌ وَدِمَاءُ الْجَاهِلِيَّةِ مَوْضُوعَةٌ وَأَوَّلُ دَمٍ أَضَعُهُ دِمَاؤُنَا دَمُ ‏"‏ ‏.‏ قَالَ عُثْمَانُ ‏"‏ دَمُ ابْنِ رَبِيعَةَ ‏"‏ ‏.‏ وَقَالَ سُلَيْمَانُ ‏"‏ دَمُ رَبِيعَةَ بْنِ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ ‏"‏ ‏.‏ وَقَالَ بَعْضُ هَؤُلاَءِ كَانَ مُسْتَرْضَعًا فِي بَنِي سَعْدٍ فَقَتَلَتْهُ هُذَيْلٌ ‏"‏ وَرِبَا الْجَاهِلِيَّةِ مَوْضُوعٌ وَأَوَّلُ رِبًا أَضَعُهُ رِبَانَا رِبَا عَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ فَإِنَّهُ مَوْضُوعٌ كُلُّهُ اتَّقُوا اللَّهَ فِي النِّسَاءِ فَإِنَّكُمْ أَخَذْتُمُوهُنَّ بِأَمَانَةِ اللَّهِ وَاسْتَحْلَلْتُمْ فُرُوجَهُنَّ بِكَلِمَةِ اللَّهِ وَإِنَّ لَكُمْ عَلَيْهِنَّ أَنْ لاَ يُوطِئْنَ فُرُشَكُمْ أَحَدًا تَكْرَهُونَهُ فَإِنْ فَعَلْنَ فَاضْرِبُوهُنَّ ضَرْبًا غَيْرَ مُبَرِّحٍ وَلَهُنَّ عَلَيْكُمْ رِزْقُهُنَّ وَكِسْوَتُهُنَّ بِالْمَعْرُوفِ وَإِنِّي قَدْ تَرَكْتُ فِيكُمْ مَا لَنْ تَضِلُّوا بَعْدَهُ إِنِ اعْتَصَمْتُمْ بِهِ كِتَابَ اللَّهِ وَأَنْتُمْ مَسْئُولُونَ عَنِّي فَمَا أَنْتُمْ قَائِلُونَ ‏"‏ ‏.‏ قَالُوا نَشْهَدُ أَنَّكَ قَدْ بَلَّغْتَ وَأَدَّيْتَ وَنَصَحْتَ ‏.‏ ثُمَّ قَالَ بِأُصْبُعِهِ السَّبَّابَةِ يَرْفَعُهَا إِلَى السَّمَاءِ وَيَنْكِبُهَا إِلَى النَّاسِ ‏"‏ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏ ثُمَّ أَذَّنَ بِلاَلٌ ثُمَّ أَقَامَ فَصَلَّى الظُّهْرَ ثُمَّ أَقَامَ فَصَلَّى الْعَصْرَ وَلَمْ يُصَلِّ بَيْنَهُمَا شَيْئًا ثُمَّ رَكِبَ الْقَصْوَاءَ حَتَّى أَتَى الْمَوْقِفَ فَجَعَلَ بَطْنَ نَاقَتِهِ الْقَصْوَاءَ إِلَى الصَّخَرَاتِ وَجَعَلَ حَبْلَ الْمُشَاةِ بَيْنَ يَدَيْهِ فَاسْتَقْبَلَ الْقِبْلَةَ فَلَمْ يَزَلْ وَاقِفًا حَتَّى غَرَبَتِ الشَّمْسُ وَذَهَبَتِ الصُّفْرَةُ قَلِيلاً حِينَ غَابَ الْقُرْصُ وَأَرْدَفَ أُسَامَةَ خَلْفَهُ فَدَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ شَنَقَ لِلْقَصْوَاءِ الزِّمَامَ حَتَّى إِنَّ رَأْسَهَا لَيُصِيبُ مَوْرِكَ رَحْلِهِ وَهُوَ يَقُولُ بِيَدِهِ الْيُمْنَى ‏"‏ السَّكِينَةَ أَيُّهَا النَّاسُ السَّكِينَةَ أَيُّهَا النَّاسُ ‏"‏ ‏.‏ كُلَّمَا أَتَى حَبْلاً مِنَ الْحِبَالِ أَرْخَى لَهَا قَلِيلاً حَتَّى تَصْعَدَ حَتَّى أَتَى الْمُزْدَلِفَةَ فَجَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِأَذَانٍ وَاحِدٍ وَإِقَامَتَيْنِ - قَالَ عُثْمَانُ وَلَمْ يُسَبِّحْ بَيْنَهُمَا شَيْئًا ثُمَّ اتَّفَقُوا - ثُمَّ اضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى طَلَعَ الْفَجْرُ فَصَلَّى الْفَجْرَ حِينَ تَبَيَّنَ لَهُ الصُّبْحُ - قَالَ سُلَيْمَانُ بِنِدَاءٍ وَإِقَامَةٍ ثُمَّ اتَّفَقُوا - ثُمَّ رَكِبَ الْقَصْوَاءَ حَتَّى أَتَى الْمَشْعَرَ الْحَرَامَ فَرَقِيَ عَلَيْهِ قَالَ عُثْمَانُ وَسُلَيْمَانُ فَاسْتَقْبَلَ الْقِبْلَةَ فَحَمِدَ اللَّهَ وَكَبَّرَهُ وَهَلَّلَهُ زَادَ عُثْمَانُ وَوَحَّدَهُ فَلَمْ يَزَلْ وَاقِفًا حَتَّى أَسْفَرَ جِدًّا ثُمَّ دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ وَأَرْدَفَ الْفَضْلَ بْنَ عَبَّاسٍ وَكَانَ رَجُلاً حَسَنَ الشَّعْرِ أَبْيَضَ وَسِيمًا فَلَمَّا دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَرَّ الظُّعُنُ يَجْرِينَ فَطَفِقَ الْفَضْلُ يَنْظُرُ إِلَيْهِنَّ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ عَلَى وَجْهِ الْفَضْلِ وَصَرَفَ الْفَضْلُ وَجْهَهُ إِلَى الشِّقِّ الآخَرِ وَحَوَّلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ إِلَى الشِّقِّ الآخَرِ وَصَرَفَ الْفَضْلُ وَجْهَهُ إِلَى الشِّقِّ الآخَرِ يَنْظُرُ حَتَّى أَتَى مُحَسِّرًا فَحَرَّكَ قَلِيلاً ثُمَّ سَلَكَ الطَّرِيقَ الْوُسْطَى الَّذِي يُخْرِجُكَ إِلَى الْجَمْرَةِ الْكُبْرَى حَتَّى أَتَى الْجَمْرَةَ الَّتِي عِنْدَ الشَّجَرَةِ فَرَمَاهَا بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ مِنْهَا بِمِثْلِ حَصَى الْخَذْفِ فَرَمَى مِنْ بَطْنِ الْوَادِي ثُمَّ انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمَنْحَرِ فَنَحَرَ بِيَدِهِ ثَلاَثًا وَسِتِّينَ وَأَمَرَ عَلِيًّا فَنَحَرَ مَا غَبَرَ - يَقُولُ مَا بَقِيَ - وَأَشْرَكَهُ فِي هَدْيِهِ ثُمَّ أَمَرَ مِنْ كُلِّ بَدَنَةٍ بِبَضْعَةٍ فَجُعِلَتْ فِي قِدْرٍ فَطُبِخَتْ فَأَكَلاَ مِنْ لَحْمِهَا وَشَرِبَا مِنْ مَرَقِهَا قَالَ سُلَيْمَانُ ثُمَّ رَكِبَ ثُمَّ أَفَاضَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْبَيْتِ فَصَلَّى بِمَكَّةَ الظُّهْرَ ثُمَّ أَتَى بَنِي عَبْدِ الْمُطَّلِبِ وَهُمْ يَسْقُونَ عَلَى زَمْزَمَ فَقَالَ ‏"‏ انْزِعُوا بَنِي عَبْدِ الْمُطَّلِبِ فَلَوْلاَ أَنْ يَغْلِبَكُمُ النَّاسُ عَلَى سِقَايَتِكُمْ لَنَزَعْتُ مَعَكُمْ ‏"‏ ‏.‏ فَنَاوَلُوهُ دَلْوًا فَشَرِبَ مِنْهُ ‏.‏\hadithno{1905}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1218)}\hadithtrans{Ja’far bin Muhammad reported on the authority of his father “We entered upon Jabir bin ‘Abd Allaah. When we reached him, he asked about the people (who had come to visit him). When my turn came I said “I am Muhammad bin Ali bin Hussain. He patted my head with his hand and undid my upper then lower buttons. He then placed his hand between my nipples and in those days I was a young boy.” He then said “welcome to you my nephew, ask what you like. I questioned him he was blind. The time of prayer came and he stood wrapped in a mantle. Whenever he placed it on his shoulders its ends fell due to its shortness. He led us in prayer while his mantle was placed on a rack by his side. I said “tell me about the Hajj of the Apostle of Allaah(ﷺ).”He signed with his hand and folded his fingers indicating nine. He then said Apostle of Allaah(ﷺ) remained nine years (at Madeenah ) during which he did not perform Hajj, then made a public announcement in the tenth year to the effect that the Apostle of Allaah(ﷺ) was about to (go to) perform Hajj. A large number of people came to Madeenah everyone desiring to follow him and act like him. The Apostle of Allaah(ﷺ) went out and we too went out with him till we reached Dhu Al Hulaifah. Asma’ daughter of ‘Umais gave birth to Muhammad bin Abi Bakr. She sent message to Apostle of Allaah(ﷺ) asking him What should I do?He replied “take a bath, bandage your private parts with a cloth and put on ihram.” The Apostle of Allaah(ﷺ) then prayed (in the masjid) and mounted Al Qaswa’ and his she Camel stood erect with him on its back. Jabir said “I saw (a large number of) people on mounts and on foot in front of him and a similar number on his right side and a similar number on his left side and a similar number behind him. The Apostle of Allaah(ﷺ) was among us, the Qur’an was being revealed to him and he knew its interpretation. Whatever he did, we did it. The Apostle of Allaah(ﷺ) then raised his voice declaring Allaah’s unity and saying “Labbaik ( I am at thy service), O Allaah, labbaik, labbaik, Thou hast no partner praise and grace are Thine and the Dominion. Thou hast no partner. The people too raised their voices in talbiyah which they used to utter. But the Apostle of Allaah(ﷺ) did not forbid them anything. The Apostle of Allaah(ﷺ) continued his talbiyah. Jabir said “We did not express our intention of performing anything but Hajj, being unaware of ‘Umrah (at that season), but when we came with him to the House (the Ka’bah), he touched the corner (and made seven circuits) walking quickly with pride in three of them and walking ordinarily in four. Then going forward to the station of Abraham he recited “And take the station of Abraham as a place of prayer.” (While praying two rak’ahs) he kept the station between him and the House. The narrator said My father said that Ibn Nufail and ‘Uthman said I do not know that he (Jabir) narrated it from anyone except the Prophet (ﷺ). The narrator Sulaiman said I do not know but he (Jabir) said “The Apostle of Allaah(ﷺ) used to recite in the two rak’ahs “Say, He is Allaah, one” and “Say O infidels”. He then returned to the House (the ka’bah) and touched the corner after which he went out by the gate to Al Safa’. When he reached near Al Safa’ he recited “Al Safa’ and Al Marwah are among the indications of Allaah” and he added “We begin with what Allaah began with”. He then began with Al Safa’ and mounting it till he could see the House (the Ka’bah) he declared the greatness of Allaah and proclaimed his Unity. He then said “there is no god but Allaah alone, Who alone has fulfilled His promise, helped His servant and routed the confederates. He then made supplication in the course of that saying such words three times. He then descended and walked towards Al Marwah and when his feet came down into the bottom of the valley, he ran, and when he began to ascend he walked till he reached Al Marwah. He did at al Marwah as he had done at Al Safa’ and when he came to Al Marwah for the last time, he said “If I had known before what I have come to know afterwards regarding this matter of mine, I would not have brought sacrificial animals but made it an ‘Umrah, so if any of you has no sacrificial animals, he may take off ihram and treat it as an ‘Umrah. All the people then took off ihram and clipped their hair except the Prophet (ﷺ) and those who had brought sacrificial animals. Suraqah (bin Malik) bin Ju’sham then got up and asked Apostle of Allaah(ﷺ)does this apply to the present year or does it apply for ever? The Apostle of Allaah(ﷺ) interwined his fingers and said “The ‘Umarh has been incorporated in Hajj. Adding ‘No’, but forever and ever. ‘Ali came from Yemen with the sacrificial animals of the Apostle of Allaah(ﷺ) and found Fathima among one of those who had taken off their ihram. She said put on colored clothes and stained her eyes with collyrium. ‘Ali disliked (this action of her) and asked Who commanded you for this? She said “My father”. Jabir said ‘Ali said at Iraq I went to Apostle of Allaah(ﷺ) to complain against Fathima for what she had done and to ask the opinion of Apostle of Allaah(ﷺ) about which she mentioned to me. I informed him that I disliked her action and that thereupon she said to me “My father commanded me to do this.” He said “She spoke the truth, she spoke the truth.” What did you say when you put on ihram for Hajj? I said O Allaah, I put on ihram for the same purpose for which Apostle of Allaah(ﷺ) has put it on. He said I have sacrificial animals with me, so do not take off ihram. He (Jabir) said “The total of those sacrificial animals brought by ‘Ali from Yemen and of those brought by the Prophet (ﷺ) from Madeenah was one hundred.” Then all the people except the Prophet (ﷺ) and those who had with them the sacrificial animals took off ihram and clipped their hair. When the 8th of Dhu Al Hijjah (Yaum Al Tarwiyah) came, they went towards Mina having pit on ihram for Hajj and the Apostle of Allaah(ﷺ) rode and prayed at Mina the noon, afternoon, sunset, night and dawn prayers. After that he waited a little till the sun rose and gave orders for a tent of hair to be set up at Namrah. The Apostle of Allaah(ﷺ) then sent out and the Quraish did not doubt that he would halt at Al Mash ‘ar Al Haram at Al Muzdalifah, as the Quraish used to do in the pre Islamic period but he passed on till he came to ‘Arafah and found that the tent had been setup at Namrah. There he dismounted and when the sun had passed the meridian he ordered Al Qaswa’ to be brought and when it was saddled for him, he went down to the bottom of the valley and addressed the people saying “Your lives and your property must be respected by one another like the sacredness of this day of yours in the month of yours in this town of yours. Lo! Everything pertaining to the pre Islamic period has been put under my feet and claims for blood vengeance belonging to the pre Islamic period have been abolished. The first of those murdered among us whose blood vengeance I permit is the blood vengeance of ours (according to the version of the narrator ‘Uthman, the blood vengeance of the son of Rabi’ah and according to the version of the narrator Sulaiman the blood vengeance of the son of Rabi’ah bin Al Harith bin ‘Abd Al Muttalib). Some (scholars) said “he was suckled among Banu Sa’d(i.e., he was brought up among Bani Sa’d) and then killed by Hudhail. The usury of the pre Islamic period is abolished and the first of usury I abolish is our usury, the usury of ‘Abbas bin ‘Abd Al Muttalib for it is all abolished. Fear Allaah regarding women for you have got them under Allah’s security and have the right to intercourse with them by Allaah’s word. It is a duty from you on them not to allow anyone whom you dislike to lie on your beds but if they do beat them, but not severely. You are responsible for providing them with food and clothing in a fitting manner. I have left among you something by which if you hold to it you will never again go astray, that is Allaah’s Book. You will be asked about me, so what will you say? They replied “We testify that you have conveyed and fulfilled the message and given counsel. Then raising his forefinger towards the sky and pointing it at the people, he said “O Allaah! Be witness, O Allaah! Be witness, O Allaah! Be witness! Bilal then uttered the call to prayer and the iqamah and he prayed the noon prayer, he then uttered the iqamah and he prayed the afternoon prayer, engaging in no prayer between the two. He then mounted (his she Camel) al Qaswa’ and came to the place of standing , making his she Camel Al Qaswa‘ turn its back to the rocks and having the path taken by those who went on foot in front of him and he faced the qiblah. He remained standing till sunset when the yellow light had somewhat gone and the disc of the sun had disappeared. He took Usamah up behind him and picked the reins of Al Qaswa’ severely so much so that its head was touching the front part of the saddle. Pointing with is right hand he was saying “Calmness, O People! Calmness, O people. Whenever he came over a mound (of sand) he let loose its reins a little so that it could ascend. He then came to Al Muzdalifah where he combined the sunset and night prayers, with one adhan and two iqamahs. The narrator ‘Uthamn said He did not offer supererogatory prayers between them. The narrators are then agreed upon the version He then lay down till dawn and prayed the dawn prayer when the morning light was clear. The narrator Sulaiman said with one adhan and one iqamah. The narrators are then agreed upon the version He then mounted Al Qaswa’ and came to Al Mash’ar Al Haram and ascended it. The narrators ‘Uthaman and Sulaiman said He faced the qiblah praised Allaah, declared His greatness, His uniqueness. ‘Uthamn added in his version and His Unity and kept standing till the day was very clear. The Apostle of Allaah(ﷺ) then went quickly before the sun rose , taking Al Fadl bin ‘Abbas behind him. He was a man having beautiful hair, white and handsome color. When the Apostle of Allaah(ﷺ) went quickly, the women in the howdas also began to pass him quickly. Al Fadl began to look at them. The Apostle of Allaah(ﷺ) placed his hand on the face of Al Fadl , but Al fadl turned his face towards the other side. The Apostle of Allaah(ﷺ) also turned away his hand to the other side. Al Fadl also turned his face to the other side looking at them till he came to (the Valley of) Muhassir. He urged the Camel a little and following a middle road which comes out at the greatest jamrah, he came to the jamrah which is beside the tree and he threw seven small pebbles at this (jamrah) saying “Allah is most great” each time he threw a pebble like bean seeds. He threw them from the bottom of the valley. The Apostle of Allaah(ﷺ) then went to the place of the sacrifice and sacrificed sixty three Camels with his own hand. He then commanded ‘Ali who sacrificed the remainder and he shared him and his sacrificial animals. After that he ordered that a piece of flesh from each Camel should be put in a pot and when it was cooked the two of them ate some of it and drank some of its broth. The narrator Sulaiman said the he mounted afterwards the Apostle of Allaah(ﷺ) went quickly to the House (the Ka’bah) and prayed the noon prayer at Makkah. He came to Banu ‘Abd Al Muttalib who were supplying water at Zamzam and said draw water Banu ‘Abd Al Muttalib were it not that people would take from you the right to draw water, I would draw it along with you. So they handed him a bucket and he drank from it}}
\hadithdefcmd{abudawud}{1906}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا سُلَيْمَانُ يَعْنِي ابْنَ بِلاَلٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، - الْمَعْنَى وَاحِدٌ - عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ وَالْعَصْرَ بِأَذَانٍ وَاحِدٍ بِعَرَفَةَ وَلَمْ يُسَبِّحْ بَيْنَهُمَا وَإِقَامَتَيْنِ وَصَلَّى الْمَغْرِبَ وَالْعِشَاءَ بِجَمْعٍ بِأَذَانٍ وَاحِدٍ وَإِقَامَتَيْنِ وَلَمْ يُسَبِّحْ بَيْنَهُمَا ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا الْحَدِيثُ أَسْنَدَهُ حَاتِمُ بْنُ إِسْمَاعِيلَ فِي الْحَدِيثِ الطَّوِيلِ وَوَافَقَ حَاتِمَ بْنَ إِسْمَاعِيلَ عَلَى إِسْنَادِهِ مُحَمَّدُ بْنُ عَلِيٍّ الْجُعْفِيُّ عَنْ جَعْفَرٍ عَنْ أَبِيهِ عَنْ جَابِرٍ إِلاَّ أَنَّهُ قَالَ فَصَلَّى الْمَغْرِبَ وَالْعَتَمَةَ بِأَذَانٍ وَإِقَامَةٍ ‏.‏\hadithno{1906}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ja’far bin Muhammad reported on the authority of his father The Prophet (ﷺ) prayed the noon and the afternoon prayers with one adhan and two iqamahs at ‘Arafah and he did not offer supererogatory prayers between them. He prayed the sunset and night prayers at Al Muzdalifah with one adhan and two iqamahs and he did not offer supererogatory prayers between them. Abu Dawud said This tradition has been narrated by Hatim bin Isma’il as a part of the lengthy tradition. Muhammad bin ‘Ali Al Ju’fi narrated it from Ja’far from his father on the authority of Jabir, like the tradition transmitted by Hatim bin Isma’il. But this version has He offered the sunset and night prayers with one adhan and one iqamah}}
\hadithdefcmd{abudawud}{1907}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا جَعْفَرٌ، حَدَّثَنَا أَبِي، عَنْ جَابِرٍ، قَالَ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَدْ نَحَرْتُ هَا هُنَا وَمِنًى كُلُّهَا مَنْحَرٌ ‏"‏ ‏.‏ وَوَقَفَ بِعَرَفَةَ فَقَالَ ‏"‏ قَدْ وَقَفْتُ هَا هُنَا وَعَرَفَةُ كُلُّهَا مَوْقِفٌ ‏"‏ ‏.‏ وَوَقَفَ فِي الْمُزْدَلِفَةِ فَقَالَ ‏"‏ قَدْ وَقَفْتُ هَا هُنَا وَمُزْدَلِفَةُ كُلُّهَا مَوْقِفٌ ‏"‏ ‏.‏\hadithno{1907}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1218)}\hadithtrans{Jabir said then the Prophet (ﷺ) said “I sacrificed here and the whole of Mina is the place of sacrifice”. He stationed at ‘Arafah and said “I stationed here and the whole of ‘Arafah is the place of station”. He stationed at Al Muzadalifah and said “I stationed here and the whole of Al Muzadalifah is the place of station.”}}
\hadithdefcmd{abudawud}{1908}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ جَعْفَرٍ، بِإِسْنَادِهِ زَادَ ‏ "‏ فَانْحَرُوا فِي رِحَالِكُمْ ‏"‏ ‏.‏\hadithno{1908}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1218)}\hadithtrans{The aforesaid tradition has also been transmitted by Hafs bin Ghiyath from Ja’far with the same chain of narrators. But this version adds “Sacrifice in your dwellings.”}}
\hadithdefcmd{abudawud}{1909}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ جَعْفَرٍ، حَدَّثَنِي أَبِي، عَنْ جَابِرٍ، فَذَكَرَ هَذَا الْحَدِيثَ وَأَدْرَجَ فِي الْحَدِيثِ عِنْدَ قَوْلِهِ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏\}‏ قَالَ فَقَرَأَ فِيهَا بِالتَّوْحِيدِ وَ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏\}‏ وَقَالَ فِيهِ قَالَ عَلِيٌّ - رضى الله عنه - بِالْكُوفَةِ قَالَ أَبِي هَذَا الْحَرْفُ لَمْ يَذْكُرْهُ جَابِرٌ فَذَهَبْتُ مُحَرِّشًا ‏.‏ وَذَكَرَ قِصَّةَ فَاطِمَةَ رضى الله عنها ‏.‏\hadithno{1909}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition has also been transmitted by Jabir through a different chain of narrators. He narrated this tradition and added the words “he recited in two rak’ahs the surah relating to Unity of Allaah” and “Say, O disbelievers” to the Qur’anic verse “And take the station of Abraham as a place of prayer. “. This version has ‘Ali said in Kufah. The narrator said “My father said Jabir did not say these words. I went to complain (against Fatimah). He then narrated the story of Fatimah.”}}
\hadithdefcmd{abudawud}{1910}{حَدَّثَنَا هَنَّادٌ، عَنْ أَبِي مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ قُرَيْشٌ وَمَنْ دَانَ دِينَهَا يَقِفُونَ بِالْمُزْدَلِفَةِ وَكَانُوا يُسَمَّوْنَ الْحُمْسَ وَكَانَ سَائِرُ الْعَرَبِ يَقِفُونَ بِعَرَفَةَ قَالَتْ فَلَمَّا جَاءَ الإِسْلاَمُ أَمَرَ اللَّهُ تَعَالَى نَبِيَّهُ صلى الله عليه وسلم أَنْ يَأْتِيَ عَرَفَاتٍ فَيَقِفَ بِهَا ثُمَّ يُفِيضَ مِنْهَا فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏ ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ ‏\}‏ ‏.‏\hadithno{1910}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4520) Sahih Muslim (1219)}\hadithtrans{A’ishah said “Quraish and those who followed their religion used to station at Al Muzdalifah and they were called Al Hums and the rest of Arabs used to station at ‘Arafah. When Islam came, Allaah the most High commanded His Prophet (ﷺ) to go to ‘Arafah and station there then go quickly from it. That is in accordance with the words of Him Who is exalted “Then go quickly from where the people went quickly.”}}
\hadithdefcmd{abudawud}{1911}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الأَحْوَصُ بْنُ جَوَّابٍ الضَّبِّيُّ، حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ يَوْمَ التَّرْوِيَةِ وَالْفَجْرَ يَوْمَ عَرَفَةَ بِمِنًى ‏.‏\hadithno{1911}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) offered the noon prayer on the 8th of Dhul-Hijjah (Yawm at-Tarwiyah) and dawn prayer on the 9th of Dhul-Hijjah (Yawm al-Arafah) in Mina}}
\hadithdefcmd{abudawud}{1912}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ قُلْتُ أَخْبِرْنِي بِشَىْءٍ، عَقَلْتَهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَيْنَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ يَوْمَ التَّرْوِيَةِ فَقَالَ بِمِنًى ‏.‏ قُلْتُ فَأَيْنَ صَلَّى الْعَصْرَ يَوْمَ النَّفْرِ قَالَ بِالأَبْطَحِ ثُمَّ قَالَ افْعَلْ كَمَا يَفْعَلُ أُمَرَاؤُكَ ‏.‏\hadithno{1912}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1763) Sahih Muslim (1309)}\hadithtrans{‘Abd Al ‘Aziz bin Rufai’ said I asked Anas bin Malik saying “Tell me something you knew about the Apostle of Allaah(ﷺ) viz where he offered the noon prayer on Yawm Al Tarwiyah(8th of Dhu Al Hijjah). He replied, In Mina I asked Where did he pray the afternoon prayer on Yaum Al Nafr(12th or 13th of Dhu Al Hijjah). He replied In al-Abtah he then said “Do as your commanders do.”}}
\hadithdefcmd{abudawud}{1913}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ غَدَا رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ مِنًى حِينَ صَلَّى الصُّبْحَ صَبِيحَةَ يَوْمِ عَرَفَةَ حَتَّى أَتَى عَرَفَةَ فَنَزَلَ بِنَمِرَةَ وَهِيَ مَنْزِلُ الإِمَامِ الَّذِي يَنْزِلُ بِهِ بِعَرَفَةَ حَتَّى إِذَا كَانَ عِنْدَ صَلاَةِ الظُّهْرِ رَاحَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُهَجِّرًا فَجَمَعَ بَيْنَ الظُّهْرِ وَالْعَصْرِ ثُمَّ خَطَبَ النَّاسَ ثُمَّ رَاحَ فَوَقَفَ عَلَى الْمَوْقِفِ مِنْ عَرَفَةَ ‏.‏\hadithno{1913}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Umar said the Apostle of Allaah(ﷺ) proceeded from Mina when he offered the dawn prayer on Yaum Al ‘Arafah (9th of Dhu Al Hijjah) in the morning till he came to ‘Arafah and he descended at Namrah. This is the place where the imam (prayer leader at ‘Arafah) takes his place. When the time of the noon prayer came, the Apostle of Allaah(ﷺ) proceeded earlier and combined the noon and afternoon prayers. He then addressed the people (i.e., recited the sermon) and proceeded. He stationed at a place of stationing in ‘Arafah}}
\hadithdefcmd{abudawud}{1914}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنْ سَعِيدِ بْنِ حَسَّانَ، عَنِ ابْنِ عُمَرَ، قَالَ لَمَّا أَنْ قَتَلَ الْحَجَّاجُ ابْنَ الزُّبَيْرِ، أَرْسَلَ إِلَى ابْنِ عُمَرَ أَيَّةُ سَاعَةٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرُوحُ فِي هَذَا الْيَوْمِ قَالَ إِذَا كَانَ ذَلِكَ رُحْنَا ‏.‏ فَلَمَّا أَرَادَ ابْنُ عُمَرَ أَنْ يَرُوحَ قَالُوا لَمْ تَزِغِ الشَّمْسُ ‏.‏ قَالَ أَزَاغَتْ قَالُوا لَمْ تَزِغْ - أَوْ زَاغَتْ - قَالَ فَلَمَّا قَالُوا قَدْ زَاغَتِ ‏.‏ ارْتَحَلَ ‏.‏\hadithno{1914}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: When al-Hajjaj killed Ibn Zubayr, he sent a message to Ibn Umar asking him: At which moment the Messenger of Allah (ﷺ) used to proceed (to Arafat) this day? He replied: When it happens so, we shall proceed. When Ibn Umar intended to proceed, the people said: The sun did not decline. He (Ibn Umar) asked: Did it decline? They replied: It did not decline. When they said that the sun had declined, he proceeded}}
\hadithdefcmd{abudawud}{1915}{حَدَّثَنَا هَنَّادٌ، عَنِ ابْنِ أَبِي زَائِدَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ رَجُلٍ، مِنْ بَنِي ضَمْرَةَ عَنْ أَبِيهِ، أَوْ عَمِّهِ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ بِعَرَفَةَ ‏.‏\hadithno{1915}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A man from banu Damrah reported on the authority of his father or his uncle “ I saw the Apostle of Allaah(ﷺ) on the pulpit in ‘Arafah.”}}
\hadithdefcmd{abudawud}{1916}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ سَلَمَةَ بْنِ نُبَيْطٍ، عَنْ رَجُلٍ، مِنَ الْحَىِّ عَنْ أَبِيهِ، نُبَيْطٍ أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم وَاقِفًا بِعَرَفَةَ عَلَى بَعِيرٍ أَحْمَرَ يَخْطُبُ ‏.‏\hadithno{1916}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Nubayt: Nubayt had seen the Prophet (ﷺ) in Arafat}}
\hadithdefcmd{abudawud}{1917}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ عَبْدِ الْمَجِيدِ، قَالَ حَدَّثَنِي الْعَدَّاءُ بْنُ خَالِدِ بْنِ هَوْذَةَ، - قَالَ هَنَّادٌ عَنْ عَبْدِ الْمَجِيدِ أَبِي عَمْرٍو، - قَالَ حَدَّثَنِي خَالِدُ بْنُ الْعَدَّاءِ بْنِ هَوْذَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ النَّاسَ يَوْمَ عَرَفَةَ عَلَى بَعِيرٍ قَائِمٌ فِي الرِّكَابَيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ الْعَلاَءِ عَنْ وَكِيعٍ كَمَا قَالَ هَنَّادٌ ‏.‏\hadithno{1917}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Adda' ibn Khalid ibn Hudhah said:I saw the Messenger of Allah (ﷺ) on 9 Dhul-Hijjah on a camel standing at the stirrups. Abu Dawud said: Ibn al-'Ala has reported this tradition from Waki' as narrated by Hammad}}
\hadithdefcmd{abudawud}{1918}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الْمَجِيدِ أَبُو عَمْرٍو، عَنِ الْعَدَّاءِ، بِمَعْنَاهُ ‏.‏\hadithno{1918}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{This tradition has also been transmitted by Al ‘Adda bin Khalid through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{1919}{حَدَّثَنَا ابْنُ نُفَيْلٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، - يَعْنِي ابْنَ دِينَارٍ - عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، عَنْ يَزِيدَ بْنِ شَيْبَانَ، قَالَ أَتَانَا ابْنُ مِرْبَعٍ الأَنْصَارِيُّ وَنَحْنُ بِعَرَفَةَ فِي مَكَانٍ يُبَاعِدُهُ عَمْرٌو عَنِ الإِمَامِ فَقَالَ أَمَا إِنِّي رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَيْكُمْ يَقُولُ لَكُمْ ‏ "‏ قِفُوا عَلَى مَشَاعِرِكُمْ فَإِنَّكُمْ عَلَى إِرْثٍ مِنْ إِرْثِ أَبِيكُمْ إِبْرَاهِيمَ ‏"‏ ‏.‏\hadithno{1919}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Yazid ibn Shayban said:We were in a place of stationing at Arafat which Amr (ibn Abdullah) thought was very far away from where the imam was stationing, when Ibn Mirba' al-Ansari came to us and told (us): I am a messenger for you from the Messenger of Allah (ﷺ). He tells you: Station where you are performing your devotions for you are an heir to the heritage of Abraham}}
\hadithdefcmd{abudawud}{1920}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا وَهْبُ بْنُ بَيَانٍ، حَدَّثَنَا عَبِيدَةُ، حَدَّثَنَا سُلَيْمَانُ الأَعْمَشُ، - الْمَعْنَى - عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَفَاضَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَةَ وَعَلَيْهِ السَّكِينَةُ وَرَدِيفُهُ أُسَامَةُ وَقَالَ ‏"‏ أَيُّهَا النَّاسُ عَلَيْكُمْ بِالسَّكِينَةِ فَإِنَّ الْبِرَّ لَيْسَ بِإِيجَافِ الْخَيْلِ وَالإِبِلِ ‏"‏ ‏.‏ قَالَ فَمَا رَأَيْتُهَا رَافِعَةً يَدَيْهَا عَادِيَةً حَتَّى أَتَى جَمْعًا ‏.‏ زَادَ وَهْبٌ ثُمَّ أَرْدَفَ الْفَضْلَ بْنَ الْعَبَّاسِ ‏.‏ وَقَالَ ‏"‏ أَيُّهَا النَّاسُ إِنَّ الْبِرَّ لَيْسَ بِإِيجَافِ الْخَيْلِ وَالإِبِلِ فَعَلَيْكُمْ بِالسَّكِينَةِ ‏"‏ ‏.‏ قَالَ فَمَا رَأَيْتُهَا رَافِعَةً يَدَيْهَا حَتَّى أَتَى مِنًى ‏.‏\hadithno{1920}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas said The Apostle of Allaah(ﷺ) returned from ‘Arafah preserving a quiet demeanor and he took Usamah up behind him (on the Camel). He said “O people preserve a quiet demeanor for piety does not consist in exciting the Horses and the Camels (i.e., in driving them quickly).” He (Ibn ‘Abbas) said “Thereafter I did not see them raising their hands running quickly till he came to Al Muzdalifah.” The narrator Wahb added He took Al Fadl bin ‘Abbas up behind him (on the Camel) and said O people piety does not consist in exciting the Horses and the Camels (i.e., in driving them quickly), you must preserve a quiet demeanor”. He (Ibn ‘Abbas) said “Thereafter I did not see them raising their hands till he came to Mina.”}}
\hadithdefcmd{abudawud}{1921}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، - وَهَذَا لَفْظُ حَدِيثِ زُهَيْرٍ - حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُقْبَةَ، أَخْبَرَنِي كُرَيْبٌ، أَنَّهُ سَأَلَ أُسَامَةَ بْنَ زَيْدٍ قُلْتُ أَخْبِرْنِي كَيْفَ، فَعَلْتُمْ - أَوْ صَنَعْتُمْ - عَشِيَّةَ رَدِفْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ جِئْنَا الشِّعْبَ الَّذِي يُنِيخُ النَّاسُ فِيهِ لِلْمُعَرَّسِ فَأَنَاخَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاقَتَهُ ثُمَّ بَالَ - وَمَا قَالَ زُهَيْرٌ أَهْرَاقَ الْمَاءَ - ثُمَّ دَعَا بِالْوَضُوءِ فَتَوَضَّأَ وُضُوءًا لَيْسَ بِالْبَالِغِ جِدًّا قُلْتُ يَا رَسُولَ اللَّهِ الصَّلاَةَ ‏.‏ قَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ قَالَ فَرَكِبَ حَتَّى قَدِمْنَا الْمُزْدَلِفَةَ فَأَقَامَ الْمَغْرِبَ ثُمَّ أَنَاخَ النَّاسُ فِي مَنَازِلِهِمْ وَلَمْ يَحِلُّوا حَتَّى أَقَامَ الْعِشَاءَ وَصَلَّى ثُمَّ حَلَّ النَّاسُ ‏.‏ زَادَ مُحَمَّدٌ فِي حَدِيثِهِ قَالَ قُلْتُ كَيْفَ فَعَلْتُمْ حِينَ أَصْبَحْتُمْ قَالَ رَدِفَهُ الْفَضْلُ وَانْطَلَقْتُ أَنَا فِي سُبَّاقِ قُرَيْشٍ عَلَى رِجْلَىَّ ‏.‏\hadithno{1921}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1280)}\hadithtrans{Ibrahim bin ’Uqabah said “Kuraib told me that he asked Umamah bin Zaid saying tell me how you did in the evening when you rode behind the Apostle of Allaah(ﷺ). He said “We came to the valley where the people make their Camels kneel down to take rest at night.” The Apostle of Allaah(ﷺ) made his she Camel kneel down and he then urinated. He then called for water for ablution and performed the ablution but he did not perform minutely (but performed lightly). I asked Apostle of Allaah(ﷺ), prayer? He replied “Prayer ahead of you”. He then mounted (the Camel) till we came to Al Muzadalifah. There iqamah for the sunset prayer was called. The people then made their Camels kneel down at their places. The Camels were not unloaded as yet, iqamah for the night prayers was called and he prayed. The people then unloaded the Camels. The narrator Muhammad added in his version of the tradition How did you do when the morning came? He replied Al Fadl rode behind him and I walked on foot among the people of the Quraish who went ahead}}
\hadithdefcmd{abudawud}{1922}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَيَّاشٍ، عَنْ زَيْدِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيٍّ، قَالَ ثُمَّ أَرْدَفَ أُسَامَةَ فَجَعَلَ يُعْنِقُ عَلَى نَاقَتِهِ وَالنَّاسُ يَضْرِبُونَ الإِبِلَ يَمِينًا وَشِمَالاً لاَ يَلْتَفِتُ إِلَيْهِمْ وَيَقُولُ ‏ "‏ السَّكِينَةَ أَيُّهَا النَّاسُ ‏"‏ ‏.‏ وَدَفَعَ حِينَ غَابَتِ الشَّمْسُ ‏.‏\hadithno{1922}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet then took up Usamah behind him (on the camel), and drove the camel at a quick pace. The people were beating their camels right and left, but he did not pay attention to them; he was saying: O people, preserve a quiet demeanour. He proceeded (from Arafat) when the sun had set}}
\hadithdefcmd{abudawud}{1923}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ سُئِلَ أُسَامَةُ بْنُ زَيْدٍ وَأَنَا جَالِسٌ، كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسِيرُ فِي حَجَّةِ الْوَدَاعِ حِينَ دَفَعَ قَالَ كَانَ يَسِيرُ الْعَنَقَ فَإِذَا وَجَدَ فَجْوَةً نَصَّ ‏.‏ قَالَ هِشَامٌ النَّصُّ فَوْقَ الْعَنَقِ ‏.‏\hadithno{1923}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1666) Sahih Muslim (1286)}\hadithtrans{Hisham bin ‘Urwah reported on the authority of his father Usamah bin Zaid was asked when I was sitting along with him, how did the Apostle of Allaah(ﷺ) travel during the Farewell Pilgrimage when he proceeded from ‘Arafah to Al Muzdalifah? He replied he was travelling at a quick pace and when he found an opening he urged on his Camel. Hisham said “Nass(running or urging on the Camel) is above ‘anaq(going at a quick pace).”}}
\hadithdefcmd{abudawud}{1924}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ عَنْ أُسَامَةَ، قَالَ كُنْتُ رِدْفَ النَّبِيِّ صلى الله عليه وسلم فَلَمَّا وَقَعَتِ الشَّمْسُ دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1924}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Usamah said:I rode behind the Prophet(ﷺ) When the sun set Apostle of Allaah(ﷺ) returned from ‘Arafah (to Al Muzdalifah)}}
\hadithdefcmd{abudawud}{1925}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ سَمِعَهُ يَقُولُ دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَةَ حَتَّى إِذَا كَانَ بِالشِّعْبِ نَزَلَ فَبَالَ فَتَوَضَّأَ وَلَمْ يُسْبِغِ الْوُضُوءَ قُلْتُ لَهُ الصَّلاَةَ ‏.‏ فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ فَرَكِبَ فَلَمَّا جَاءَ الْمُزْدَلِفَةَ نَزَلَ فَتَوَضَّأَ فَأَسْبَغَ الْوُضُوءَ ثُمَّ أُقِيمَتِ الصَّلاَةُ فَصَلَّى الْمَغْرِبَ ثُمَّ أَنَاخَ كُلُّ إِنْسَانٍ بَعِيرَهُ فِي مَنْزِلِهِ ثُمَّ أُقِيمَتِ الْعِشَاءُ فَصَلاَّهَا وَلَمْ يُصَلِّ بَيْنَهُمَا شَيْئًا ‏.‏\hadithno{1925}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan Sahih Bukhari (1672) Sahih Muslim (1280 After  1285)}\hadithtrans{Usamah bin Zaid said:The Apostle of Allaah(ﷺ) returned from ‘Arafah. When he came to the mountain path , he alighted, urinated and performed the ablution, but he did not perform it completely. I said to him Prayer? He said “The prayer will be offered ahead of you.” He then mounted. When he reached Al Muzdalifah he alighted performed the ablution, performed it well. Thereafter iqamah for the prayer was called and he offered the sunset prayer. Then everyone made his Camel kneel down at his place. Iqamah was then called for night prayer and he offered it but he did not pray between them}}
\hadithdefcmd{abudawud}{1926}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ جَمِيعًا ‏.‏\hadithno{1926}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (703 After  1287)}\hadithtrans{‘Abd Allah bin ‘Umar said The apostle of Allaah(ﷺ) combined the sunset and the night prayers at Al Muzdalifah}}
\hadithdefcmd{abudawud}{1927}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، بِإِسْنَادِهِ وَمَعْنَاهُ وَقَالَ بِإِقَامَةٍ إِقَامَةٍ جَمَعَ بَيْنَهُمَا ‏.‏ قَالَ أَحْمَدُ قَالَ وَكِيعٌ صَلَّى كُلَّ صَلاَةٍ بِإِقَامَةٍ ‏.‏\hadithno{1927}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1673)}\hadithtrans{The aforesaid tradition has been transmitted by Al Zuhri through a different chain of narrators. This version adds “Each prayer with an iqamah”. Ahmad reported on the authority of Waki’ “he offered each prayer with a single iqamah.”}}
\hadithdefcmd{abudawud}{1928}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، ح وَحَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، - الْمَعْنَى - أَخْبَرَنَا عُثْمَانُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، بِإِسْنَادِ ابْنِ حَنْبَلٍ عَنْ حَمَّادٍ، وَمَعْنَاهُ، قَالَ بِإِقَامَةٍ وَاحِدَةٍ لِكُلِّ صَلاَةٍ وَلَمْ يُنَادِ فِي الأُولَى وَلَمْ يُسَبِّحْ عَلَى أَثَرِ وَاحِدَةٍ مِنْهُمَا ‏.‏ قَالَ مَخْلَدٌ لَمْ يُنَادِ فِي وَاحِدَةٍ مِنْهُمَا ‏.‏\hadithno{1928}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted to the same effect by by Al Zuhri with a different chain of narrators beginning with Ibn Hanbal on the authority of Hammad. This version adds “With an iqamah for every prayer, he did not call adhan for the first prayer and he did not offer supererogatory prayer after any of them. The narrator Makhlad said “He did not call adhan for any of them.”}}
\hadithdefcmd{abudawud}{1929}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ، قَالَ صَلَّيْتُ مَعَ ابْنِ عُمَرَ الْمَغْرِبَ ثَلاَثًا وَالْعِشَاءَ رَكْعَتَيْنِ فَقَالَ لَهُ مَالِكُ بْنُ الْحَارِثِ مَا هَذِهِ الصَّلاَةُ قَالَ صَلَّيْتُهُمَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي هَذَا الْمَكَانِ بِإِقَامَةٍ وَاحِدَةٍ ‏.‏\hadithno{1929}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah ibn Malik said:I offered three rak'ahs of the sunset prayer and two rak'ahs of the night prayer along with Ibn Umar. Thereupon Malik ibn al-Harith said: What is this prayer? He said: I offered these prayers along with the Messenger of Allah (ﷺ) in this place with a single iqamah}}
\hadithdefcmd{abudawud}{1930}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا إِسْحَاقُ، - يَعْنِي ابْنَ يُوسُفَ - عَنْ شَرِيكٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَعَبْدِ اللَّهِ بْنِ مَالِكٍ، قَالاَ صَلَّيْنَا مَعَ ابْنِ عُمَرَ بِالْمُزْدَلِفَةِ الْمَغْرِبَ وَالْعِشَاءَ بِإِقَامَةٍ وَاحِدَةٍ فَذَكَرَ مَعْنَى حَدِيثِ ابْنِ كَثِيرٍ ‏.‏\hadithno{1930}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1288)}\hadithtrans{Sa’id bin Jubair and ‘Abd Allah bin Malik said “We offered the sunset and the night prayers at Al Muzdalifah along with ibn ‘Umar with one iqamah.” The narrator then narrated the rest of the tradition as reported by Ibn Kathir}}
\hadithdefcmd{abudawud}{1931}{حَدَّثَنَا ابْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ إِسْمَاعِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ أَفَضْنَا مَعَ ابْنِ عُمَرَ فَلَمَّا بَلَغْنَا جَمْعًا صَلَّى بِنَا الْمَغْرِبَ وَالْعِشَاءَ بِإِقَامَةٍ وَاحِدَةٍ ثَلاَثًا وَاثْنَتَيْنِ فَلَمَّا انْصَرَفَ قَالَ لَنَا ابْنُ عُمَرَ هَكَذَا صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي هَذَا الْمَكَانِ ‏.‏\hadithno{1931}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1288)}\hadithtrans{Sa’id bin Jubair said “We returned along with Ibn ‘Umar and when we reached Al Muzdalifah he led us in the sunset and night prayers with one iqamah and three rak’ahs of the sunset prayer and two rak’ahs of the night prayer. When he finished the prayer Ibn ‘Umar said to us The Messenger of Allah (ﷺ) led us in prayer in this way at this place.”}}
\hadithdefcmd{abudawud}{1932}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي سَلَمَةُ بْنُ كُهَيْلٍ، قَالَ رَأَيْتُ سَعِيدَ بْنَ جُبَيْرٍ أَقَامَ بِجَمْعٍ فَصَلَّى الْمَغْرِبَ ثَلاَثًا ثُمَّ صَلَّى الْعِشَاءَ رَكْعَتَيْنِ ثُمَّ قَالَ شَهِدْتُ ابْنَ عُمَرَ صَنَعَ فِي هَذَا الْمَكَانِ مِثْلَ هَذَا وَقَالَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَنَعَ مِثْلَ هَذَا فِي هَذَا الْمَكَانِ ‏.‏\hadithno{1932}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1288)}\hadithtrans{Salamah bin Kuhail said “I saw Sa’id bin Jubair he called the iqamah at Al Muzdalifah and offered three ra’kahs of the sunset prayer and two ra’kahs of the night prayer. He then said “I attended Ibn ‘Umar.” He did like this in this place and he (Ibn ‘Umar) said “I attended the Apostle of Allaah(ﷺ)”. He did in a similar way in this place}}
\hadithdefcmd{abudawud}{1933}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا أَشْعَثُ بْنُ سُلَيْمٍ، عَنْ أَبِيهِ، قَالَ أَقْبَلْتُ مَعَ ابْنِ عُمَرَ مِنْ عَرَفَاتٍ إِلَى الْمُزْدَلِفَةِ فَلَمْ يَكُنْ يَفْتُرُ مِنَ التَّكْبِيرِ وَالتَّهْلِيلِ حَتَّى أَتَيْنَا الْمُزْدَلِفَةَ فَأَذَّنَ وَأَقَامَ أَوْ أَمَرَ إِنْسَانًا فَأَذَّنَ وَأَقَامَ فَصَلَّى بِنَا الْمَغْرِبَ ثَلاَثَ رَكَعَاتٍ ثُمَّ الْتَفَتَ إِلَيْنَا فَقَالَ الصَّلاَةُ فَصَلَّى بِنَا الْعِشَاءَ رَكْعَتَيْنِ ثُمَّ دَعَا بِعَشَائِهِ ‏.‏ قَالَ وَأَخْبَرَنِي عِلاَجُ بْنُ عَمْرٍو بِمِثْلِ حَدِيثِ أَبِي عَنِ ابْنِ عُمَرَ قَالَ فَقِيلَ لاِبْنِ عُمَرَ فِي ذَلِكَ فَقَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم هَكَذَا ‏.‏\hadithno{1933}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ash’ath bin Sulaim reported on the authority of his father “I proceeded along with Ibn ‘Umar from ‘Arafah towards Al Muzdalifah.” He was not tiring of uttering “Allaah is most great” and “There is no god but Allaah”, till we came to Al Muzdalifah. He uttered the adhan and the iqamah or ordered some person who called the adhan and the iqamah. He then led us the three rak’ahs of the sunset prayers and turned to us and said (Another) prayer. Thereafter he led us in the two rak’ahs of the night prayer. Then he called for his dinner. He (Ash’ath) said ‘Ilaj bin ‘Amr reported a tradition like that of my father on the authority of Ibn ‘Umar. Ibn ‘Umar was asked about it. He said “I prayed along with the Apostle of Allaah(ﷺ) in a similar manner.”}}
\hadithdefcmd{abudawud}{1934}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ عَبْدَ الْوَاحِدِ بْنَ زِيَادٍ، وَأَبَا، عَوَانَةَ وَأَبَا مُعَاوِيَةَ حَدَّثُوهُمْ عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى صَلاَةً إِلاَّ لِوَقْتِهَا إِلاَّ بِجَمْعٍ فَإِنَّهُ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ وَصَلَّى صَلاَةَ الصُّبْحِ مِنَ الْغَدِ قَبْلَ وَقْتِهَا ‏.‏\hadithno{1934}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1682) Sahih Muslim (1289)}\hadithtrans{Ibn Mas’ud said “ I never saw the Apostle of Allaah(ﷺ) observe a prayer out of its proper time except(two prayers) at Al Muzdalifah. He combined the sunset and night prayers at Al Muzdalifah and he offered the dawn prayer that day before its proper time}}
\hadithdefcmd{abudawud}{1935}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَيَّاشٍ، عَنْ زَيْدِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيٍّ، قَالَ فَلَمَّا أَصْبَحَ - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - وَوَقَفَ عَلَى قُزَحَ فَقَالَ ‏ "‏ هَذَا قُزَحُ وَهُوَ الْمَوْقِفُ وَجَمْعٌ كُلُّهَا مَوْقِفٌ وَنَحَرْتُ هَا هُنَا وَمِنًى كُلُّهَا مَنْحَرٌ فَانْحَرُوا فِي رِحَالِكُمْ ‏"‏ ‏.‏\hadithno{1935}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: When the morning came, the Prophet (ﷺ) stood at the mountain Quzah and said: This is Quzah, and this is a place of stationing, and the whole of al-Muzdalifah is a place of stationing. I sacrificed the animals here, and the whole of Mina is a place of sacrifice. So sacrifice in your dwellings}}
\hadithdefcmd{abudawud}{1936}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ وَقَفْتُ هَا هُنَا بِعَرَفَةَ وَعَرَفَةُ كُلُّهَا مَوْقِفٌ وَوَقَفْتُ هَا هُنَا بِجَمْعٍ وَجَمْعٌ كُلُّهَا مَوْقِفٌ وَنَحَرْتُ هَا هُنَا وَمِنًى كُلُّهَا مَنْحَرٌ فَانْحَرُوا فِي رِحَالِكُمْ ‏"‏ ‏.‏\hadithno{1936}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir reported the Prophet (ﷺ) as saying “I halted here in ‘Arafah and the whole of ‘Arafah is a place of halting. I halted here in Al Muzdalifah and the whole of Al Muzdalifah is a place of halting. I sacrificed the animals here and the whole of Mina is a place of sacrifice. So sacrifice in your dwellings}}
\hadithdefcmd{abudawud}{1937}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عَطَاءٍ، قَالَ حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ عَرَفَةَ مَوْقِفٌ وَكُلُّ مِنًى مَنْحَرٌ وَكُلُّ الْمُزْدَلِفَةِ مَوْقِفٌ وَكُلُّ فِجَاجِ مَكَّةَ طَرِيقٌ وَمَنْحَرٌ ‏"‏ ‏.‏\hadithno{1937}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Jabir bin ‘Abdallah reported the Apostle of Allaah (ﷺ) as saying “The whole of ‘Arafah is a place of halting, the whole of Mina is a place of sacrifice, the whole of Al Muzdalifah is a place of halting and all the passes of Makkah are a thoroughfare and a place of sacrifice}}
\hadithdefcmd{abudawud}{1938}{حَدَّثَنَا ابْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ كَانَ أَهْلُ الْجَاهِلِيَّةِ لاَ يُفِيضُونَ حَتَّى يَرَوُا الشَّمْسَ عَلَى ثَبِيرٍ فَخَالَفَهُمُ النَّبِيُّ صلى الله عليه وسلم فَدَفَعَ قَبْلَ طُلُوعِ الشَّمْسِ ‏.‏\hadithno{1938}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3838)}\hadithtrans{Narrated Umar ibn al-Khattab: The Arabs in the pre-Islamic period did not return from al-Muzdalifah till they saw sunlight at the mountain Thabir. The Prophet (ﷺ) opposed them and returned before the sunrise}}
\hadithdefcmd{abudawud}{1939}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ أَنَا مِمَّنْ، قَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْمُزْدَلِفَةِ فِي ضَعَفَةِ أَهْلِهِ ‏.‏\hadithno{1939}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1678) Sahih Muslim (1293)}\hadithtrans{Ibn ‘Abbas said I was among the weak members of his family whom the Apostle of Allaah(ﷺ) sent ahead on the night of Al Muzdalifah}}
\hadithdefcmd{abudawud}{1940}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، قَالَ حَدَّثَنِي سَلَمَةُ بْنُ كُهَيْلٍ، عَنِ الْحَسَنِ الْعُرَنِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْمُزْدَلِفَةِ أُغَيْلِمَةَ بَنِي عَبْدِ الْمُطَّلِبِ عَلَى حُمُرَاتٍ فَجَعَلَ يَلْطَحُ أَفْخَاذَنَا وَيَقُولُ ‏ "‏ أُبَيْنِيَّ لاَ تَرْمُوا الْجَمْرَةَ حَتَّى تَطْلُعَ الشَّمْسُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ اللَّطْحُ الضَّرْبُ اللَّيِّنُ ‏.‏\hadithno{1940}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) sent ahead some boys from Banu AbdulMuttalib on donkeys on the night of al-Muzdalifah. He began to pat our thighs (out of love) and said: O young! boys do not throw pebbles at the jamrah till the sun rises. Abu Dawud said: The Arabic word al-lath means to strike softly}}
\hadithdefcmd{abudawud}{1941}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْوَلِيدُ بْنُ عُقْبَةَ، حَدَّثَنَا حَمْزَةُ الزَّيَّاتُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَدِّمُ ضُعَفَاءَ أَهْلِهِ بِغَلَسٍ وَيَأْمُرُهُمْ يَعْنِي لاَ يَرْمُونَ الْجَمْرَةَ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏\hadithno{1941}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) used to send ahead the weak members of his family in darkness (to Mina), and command them not to throw pebbles at jamrahs until the sun rose}}
\hadithdefcmd{abudawud}{1942}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ، - يَعْنِي ابْنَ عُثْمَانَ - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ أَرْسَلَ النَّبِيُّ صلى الله عليه وسلم بِأُمِّ سَلَمَةَ لَيْلَةَ النَّحْرِ فَرَمَتِ الْجَمْرَةَ قَبْلَ الْفَجْرِ ثُمَّ مَضَتْ فَأَفَاضَتْ وَكَانَ ذَلِكَ الْيَوْمُ الْيَوْمَ الَّذِي يَكُونُ رَسُولُ اللَّهِ صلى الله عليه وسلم - تَعْنِي - عِنْدَهَا ‏.‏\hadithno{1942}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) sent Umm Salamah on the night before the day of sacrifice and she threw pebbles at the jamrah before dawn. She hastened (to Mecca) and performed the circumambulation. That day was the one the Messenger of Allah (ﷺ) spent with her}}
\hadithdefcmd{abudawud}{1943}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَخْبَرَنِي مُخْبِرٌ، عَنْ أَسْمَاءَ، أَنَّهَا رَمَتِ الْجَمْرَةَ قُلْتُ إِنَّا رَمَيْنَا الْجَمْرَةَ بِلَيْلٍ ‏.‏ قَالَتْ إِنَّا كُنَّا نَصْنَعُ هَذَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1943}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ata' said:A reporter reported to me about Asma' that she threw pebbles at the jamrah at night. I said: We threw pebbles (at the jamrah) at night. She said: We used to do so in the lifetime of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{1944}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَفَاضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ السَّكِينَةُ وَأَمَرَهُمْ أَنْ يَرْمُوا بِمِثْلِ حَصَى الْخَذْفِ وَأَوْضَعَ فِي وَادِي مُحَسِّرٍ ‏.‏\hadithno{1944}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) hastened from al-Muzdalifah with a quite demeanour and ordered them (the people) to throw small pebbles and he hastened in the valley (wadi) of Muhassir}}
\hadithdefcmd{abudawud}{1945}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا هِشَامٌ، - يَعْنِي ابْنَ الْغَازِ - حَدَّثَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَفَ يَوْمَ النَّحْرِ بَيْنَ الْجَمَرَاتِ فِي الْحَجَّةِ الَّتِي حَجَّ فَقَالَ ‏"‏ أَىُّ يَوْمٍ هَذَا ‏"‏ ‏.‏ قَالُوا يَوْمُ النَّحْرِ ‏.‏ قَالَ ‏"‏ هَذَا يَوْمُ الْحَجِّ الأَكْبَرِ ‏"‏ ‏.‏\hadithno{1945}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) halted on the day of sacrifice between the jamrahs (pillars at Mina) during hajj which he performed. He asked: Which is this day? They replied: This is the day of sacrifice. He said: This is the day of greater hajj}}
\hadithdefcmd{abudawud}{1946}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، أَنَّ الْحَكَمَ بْنَ نَافِعٍ، حَدَّثَهُمْ حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ بَعَثَنِي أَبُو بَكْرٍ فِيمَنْ يُؤَذِّنُ يَوْمَ النَّحْرِ بِمِنًى أَنْ لاَ يَحُجَّ بَعْدَ الْعَامِ مُشْرِكٌ وَلاَ يَطُوفَ بِالْبَيْتِ عُرْيَانٌ وَيَوْمُ الْحَجِّ الأَكْبَرِ يَوْمُ النَّحْرِ وَالْحَجُّ الأَكْبَرُ الْحَجُّ ‏.‏\hadithno{1946}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3177) Sahih Muslim (1347)}\hadithtrans{Narrated Abu Hurairah:Abu Bakr sent me among those who proclaim at Mina that no polytheist should perform Hajj after this year and no naked person should go round the House (the Ka'bah), and that the day of greater Hajj is the day of sacrifice, and the greater Hajj is the Hajj}}
\hadithdefcmd{abudawud}{1947}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ فِي حَجَّتِهِ فَقَالَ ‏ "‏ إِنَّ الزَّمَانَ قَدِ اسْتَدَارَ كَهَيْئَتِهِ يَوْمَ خَلَقَ اللَّهُ السَّمَوَاتِ وَالأَرْضَ السَّنَةُ اثْنَا عَشَرَ شَهْرًا مِنْهَا أَرْبَعَةٌ حُرُمٌ ثَلاَثٌ مُتَوَالِيَاتٌ ذُو الْقَعْدَةِ وَ ذُو الْحِجَّةِ وَالْمُحَرَّمُ وَرَجَبُ مُضَرَ الَّذِي بَيْنَ جُمَادَى وَشَعْبَانَ ‏"‏ ‏.‏\hadithno{1947}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (4406) Sahih Muslim (1679)}\hadithtrans{Narrated AbuBakrah: The Prophet (ﷺ) gave a sermon during his hajj and said: Time has completed a cycle and assumed the form of the day when Allah created the heavens and the earth. The year contains twelve months of which four are sacred, three of them consecutive, viz. Dhul-Qa'dah, Dhul-Hijjah and Muharram and also Rajab of Mudar which comes between Jumadah and Sha'ban}}
\hadithdefcmd{abudawud}{1948}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنُ فَيَّاضٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ السَّخْتِيَانِيُّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ سَمَّاهُ ابْنُ عَوْنٍ فَقَالَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ عَنْ أَبِي بَكْرَةَ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{1948}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4406) Sahih Muslim (1679)}\hadithtrans{The aforesaid tradition has also been transmitted by Abu Bakrah through a different chain of narrators. Abu Dawud said:Ibn 'Awn has mentioned his ('Abu Bakrah's) name and narrated this tradition: From 'Abd al-Rahman b. Abi Bakrah on the authority of Abu Bakrah}}
\hadithdefcmd{abudawud}{1949}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي بُكَيْرُ بْنُ عَطَاءٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي يَعْمَرَ الدِّيلِيِّ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ بِعَرَفَةَ فَجَاءَ نَاسٌ - أَوْ نَفَرٌ - مِنْ أَهْلِ نَجْدٍ فَأَمَرُوا رَجُلاً فَنَادَى رَسُولَ اللَّهِ صلى الله عليه وسلم كَيْفَ الْحَجُّ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً فَنَادَى ‏"‏ الْحَجُّ الْحَجُّ يَوْمُ عَرَفَةَ مَنْ جَاءَ قَبْلَ صَلاَةِ الصُّبْحِ مِنْ لَيْلَةِ جَمْعٍ فَتَمَّ حَجُّهُ أَيَّامُ مِنًى ثَلاَثَةٌ فَمَنْ تَعَجَّلَ فِي يَوْمَيْنِ فَلاَ إِثْمَ عَلَيْهِ وَمَنْ تَأَخَّرَ فَلاَ إِثْمَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ ثُمَّ أَرْدَفَ رَجُلاً خَلْفَهُ فَجَعَلَ يُنَادِي بِذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ مِهْرَانُ عَنْ سُفْيَانَ قَالَ ‏"‏ الْحَجُّ الْحَجُّ ‏"‏ ‏.‏ مَرَّتَيْنِ وَرَوَاهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ عَنْ سُفْيَانَ قَالَ ‏"‏ الْحَجُّ ‏"‏ ‏.‏ مَرَّةً ‏.‏\hadithno{1949}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbdurRahman Ya'mar ad-Dayli: I came to the Holy Prophet (ﷺ) when he was in Arafat. Some people or a group of people came from Najd. They commanded someone (to ask the Prophet about hajj). So he called the Messenger of Allah (ﷺ), saying: How is the hajj done? He (the Prophet) ordered a man (to reply). He shouted loudly: The hajj, the hajj is on the day of Arafah. If anyone comes over there before the dawn prayer on the night of al-Muzdalifah, his hajj will be complete. The period of halting at Mina is three days. Then whoever hastens (his departure) by two days, it is no sin for him, and whoever delays it there is no sin for him. The narrator said: He (the Prophet) then put a man behind him on the camel. He began to proclaim this loudly. Abu Dawud said: This tradition has been narrated by Mahran from Sufyan in a similar way. This version adds: The Hajj, the Hajj, twice. The version narrated by Yaya b. Sa'id al-Qattan has the words: The Hajj only once}}
\hadithdefcmd{abudawud}{1950}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، حَدَّثَنَا عَامِرٌ، أَخْبَرَنِي عُرْوَةُ بْنُ مُضَرِّسٍ الطَّائِيُّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِالْمَوْقِفِ - يَعْنِي بِجَمْعٍ قُلْتُ جِئْتُ يَا رَسُولَ اللَّهِ مِنْ جَبَلِ طَيِّئٍ أَكْلَلْتُ مَطِيَّتِي وَأَتْعَبْتُ نَفْسِي وَاللَّهِ مَا تَرَكْتُ مِنْ جَبَلٍ إِلاَّ وَقَفْتُ عَلَيْهِ فَهَلْ لِي مِنْ حَجٍّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَدْرَكَ مَعَنَا هَذِهِ الصَّلاَةَ وَأَتَى عَرَفَاتٍ قَبْلَ ذَلِكَ لَيْلاً أَوْ نَهَارًا فَقَدْ تَمَّ حَجُّهُ وَقَضَى تَفَثَهُ ‏"‏ ‏.‏\hadithno{1950}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Urwah ibn Mudarris at-Ta'i: I came to the Messenger of Allah (ﷺ) at the place of halting, that is, al-Muzdalifah. I said: I have come from the mountains of Tayy. I fatigued my mount and fatigued myself. By Allah, I found no hill (on my way) but I halted there. Have I completed my hajj? The Messenger of Allah (ﷺ) said: Anyone who offers this prayer along with us and comes over to Arafat before it by night or day will complete his hajj and he may wash away the dirt (of his body)}}
\hadithdefcmd{abudawud}{1951}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُعَاذٍ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ خَطَبَ النَّبِيُّ صلى الله عليه وسلم النَّاسَ بِمِنًى وَنَزَّلَهُمْ مَنَازِلَهُمْ فَقَالَ ‏"‏ لِيَنْزِلِ الْمُهَاجِرُونَ هَا هُنَا ‏"‏ ‏.‏ وَأَشَارَ إِلَى مَيْمَنَةِ الْقِبْلَةِ ‏"‏ وَالأَنْصَارُ هَا هُنَا ‏"‏ ‏.‏ وَأَشَارَ إِلَى مَيْسَرَةِ الْقِبْلَةِ ‏"‏ ثُمَّ لْيَنْزِلِ النَّاسُ حَوْلَهُمْ ‏"‏ ‏.‏\hadithno{1951}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{AbdurRahman ibn Mu'adh said that he heard a man from the Companions of the Prophet (ﷺ) say:The Prophet (ﷺ) addressed the people at Mina and he made them stay in their dwellings. He then said: The Muhajirun (Emigrants) should stay here, and he made a sign to the right side of the qiblah, and the Ansar (the Helpers) here, and he made a sign to the left side of the qiblah; the people should stay around them}}
\hadithdefcmd{abudawud}{1952}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ إِبْرَاهِيمَ بْنِ نَافِعٍ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ أَبِيهِ، عَنْ رَجُلَيْنِ، مِنْ بَنِي بَكْرٍ قَالاَ رَأَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ بَيْنَ أَوْسَطِ أَيَّامِ التَّشْرِيقِ وَنَحْنُ عِنْدَ رَاحِلَتِهِ وَهِيَ خُطْبَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي خَطَبَ بِمِنًى ‏.‏\hadithno{1952}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn AbuNajih reported from his father on the authority of two men from Banu Bakr who said:We saw the Messenger of Allah (ﷺ) addressing (the people) in the middle of the tashriq days when we were staying near his mount. This is the address of the Messenger of Allah (ﷺ) which he gave at Mina}}
\hadithdefcmd{abudawud}{1953}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا رَبِيعَةُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ حِصْنٍ، حَدَّثَتْنِي جَدَّتِي، سَرَّاءُ بِنْتُ نَبْهَانَ - وَكَانَتْ رَبَّةَ بَيْتٍ فِي الْجَاهِلِيَّةِ - قَالَتْ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الرُّءُوسِ فَقَالَ ‏"‏ أَىُّ يَوْمٍ هَذَا ‏"‏ ‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ قَالَ ‏"‏ أَلَيْسَ أَوْسَطَ أَيَّامِ التَّشْرِيقِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ قَالَ عَمُّ أَبِي حُرَّةَ الرَّقَاشِيِّ إِنَّهُ خَطَبَ أَوْسَطَ أَيَّامِ التَّشْرِيقِ ‏.‏\hadithno{1953}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sarra' daughter of Nabhan: She was mistress of a temple in pre-Islamic days. She said: The prophet (ﷺ) addressed us on the second day of sacrifice (yawm ar-ru'us) and said: Which is this day? We said: Allah and His Apostle are better aware. He said: Is this not the middle of the tashriq days?}}
\hadithdefcmd{abudawud}{1954}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، حَدَّثَنَا عِكْرِمَةُ، حَدَّثَنِي الْهِرْمَاسُ بْنُ زِيَادٍ الْبَاهِلِيُّ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ النَّاسَ عَلَى نَاقَتِهِ الْعَضْبَاءِ يَوْمَ الأَضْحَى بِمِنًى ‏.‏\hadithno{1954}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Harmas ibn Ziyad al-Bahili: I saw the Prophet (ﷺ) addressing the people on his she-camel al-Adba', on the day of sacrifice at Mina}}
\hadithdefcmd{abudawud}{1955}{حَدَّثَنَا مُؤَمَّلٌ، - يَعْنِي ابْنَ الْفَضْلِ - الْحَرَّانِيُّ - حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا ابْنُ جَابِرٍ، حَدَّثَنَا سُلَيْمُ بْنُ عَامِرٍ الْكَلاَعِيُّ، سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ سَمِعْتُ خُطْبَةَ، رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِنًى يَوْمَ النَّحْرِ ‏.‏\hadithno{1955}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Umamah:I heard the address of the Messenger of Allah (ﷺ) at Mina on the day of sacrifice}}
\hadithdefcmd{abudawud}{1956}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الرَّحِيمِ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ، عَنْ هِلاَلِ بْنِ عَامِرٍ الْمُزَنِيِّ، حَدَّثَنِي رَافِعُ بْنُ عَمْرٍو الْمُزَنِيُّ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ النَّاسَ بِمِنًى حِينَ ارْتَفَعَ الضُّحَى عَلَى بَغْلَةٍ شَهْبَاءَ وَعَلِيٌّ - رضى الله عنه - يُعَبِّرُ عَنْهُ وَالنَّاسُ بَيْنَ قَاعِدٍ وَقَائِمٍ ‏.‏\hadithno{1956}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Rafi' ibn Amr al-Muzani: I saw the Messenger of Allah (ﷺ) addressing the people at Mina (on the day of sacrifice) when the sun rose high (i.e. in the forenoon) on a white mule, and Ali (Allah be pleased with him) was interpreting on his behalf; some people were standing and some sitting}}
\hadithdefcmd{abudawud}{1957}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُعَاذٍ التَّيْمِيِّ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ بِمِنًى فَفُتِحَتْ أَسْمَاعُنَا حَتَّى كُنَّا نَسْمَعُ مَا يَقُولُ وَنَحْنُ فِي مَنَازِلِنَا فَطَفِقَ يُعَلِّمُهُمْ مَنَاسِكَهُمْ حَتَّى بَلَغَ الْجِمَارَ فَوَضَعَ أُصْبُعَيْهِ السَّبَّابَتَيْنِ فِي أُذُنَيْهِ ثُمَّ قَالَ ‏ "‏ بِحَصَى الْخَذْفِ ‏"‏ ‏.‏ ثُمَّ أَمَرَ الْمُهَاجِرِينَ فَنَزَلُوا فِي مُقَدَّمِ الْمَسْجِدِ وَأَمَرَ الأَنْصَارَ فَنَزَلُوا مِنْ وَرَاءِ الْمَسْجِدِ ثُمَّ نَزَلَ النَّاسُ بَعْدَ ذَلِكَ ‏.‏\hadithno{1957}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbdurRahman ibn Mu'adh at-Taymi: The Messenger of Allah (ﷺ) addressed us when we were at Mina. Our ears were open and we were listening to what he was saying, while we were in our dwellings. He began to teach them the rites of hajj till he reached the injunction of throwing pebbles at the Jamrahs (pillars at Mina). He put his forefingers in his ears and said: (Throw small pebbles. He then commanded the Emigrants (Muhajirun) to station themselves. They stationed themselves before the mosque. He then commanded the Helpers (Ansar) to encamp. They encamped behind the mosque. Thereafter the people encamped}}
\hadithdefcmd{abudawud}{1958}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ خَلاَّدٍ الْبَاهِلِيُّ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي حَرِيزٌ، أَوْ أَبُو حَرِيزٍ - الشَّكُّ مِنْ يَحْيَى - أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ فَرُّوخَ، يَسْأَلُ ابْنَ عُمَرَ قَالَ إِنَّا نَتَبَايَعُ بِأَمْوَالِ النَّاسِ فَيَأْتِي أَحَدُنَا مَكَّةَ فَيَبِيتُ عَلَى الْمَالِ فَقَالَ أَمَّا رَسُولُ اللَّهِ صلى الله عليه وسلم فَبَاتَ بِمِنًى وَظَلَّ ‏.‏\hadithno{1958}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Jurayj asked Ibn Umar:We sell the property of the people; so one of us goes to Mecca and passes the night there with the property (during the stay at Mina). He said: The Messenger of Allah (ﷺ) used to pass night and day at Mina}}
\hadithdefcmd{abudawud}{1959}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اسْتَأْذَنَ الْعَبَّاسُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيتَ بِمَكَّةَ لَيَالِيَ مِنًى مِنْ أَجْلِ سِقَايَتِهِ فَأَذِنَ لَهُ ‏.‏\hadithno{1959}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1745) Sahih Muslim (1315)}\hadithtrans{Narrated Ibn 'Umar:Al-'Abbas sought permission from the Messenger of Allah (ﷺ) to pass the night at Mecca during the period of his stay at Mina for distributing water among the people. He gave him permission}}
\hadithdefcmd{abudawud}{1960}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ أَبَا مُعَاوِيَةَ، وَحَفْصَ بْنَ غِيَاثٍ، حَدَّثَاهُ - وَحَدِيثُ أَبِي مُعَاوِيَةَ، أَتَمُّ - عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ صَلَّى عُثْمَانُ بِمِنًى أَرْبَعًا فَقَالَ عَبْدُ اللَّهِ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم رَكْعَتَيْنِ وَمَعَ أَبِي بَكْرٍ رَكْعَتَيْنِ وَمَعَ عُمَرَ رَكْعَتَيْنِ زَادَ عَنْ حَفْصٍ وَمَعَ عُثْمَانَ صَدْرًا مِنْ إِمَارَتِهِ ثُمَّ أَتَمَّهَا ‏.‏ زَادَ مِنْ هَا هُنَا عَنْ أَبِي مُعَاوِيَةَ ثُمَّ تَفَرَّقَتْ بِكُمُ الطُّرُقُ فَلَوَدِدْتُ أَنَّ لِي مِنْ أَرْبَعِ رَكَعَاتٍ رَكْعَتَيْنِ مُتَقَبَّلَتَيْنِ ‏.‏ قَالَ الأَعْمَشُ فَحَدَّثَنِي مُعَاوِيَةُ بْنُ قُرَّةَ عَنْ أَشْيَاخِهِ أَنَّ عَبْدَ اللَّهِ صَلَّى أَرْبَعًا قَالَ فَقِيلَ لَهُ عِبْتَ عَلَى عُثْمَانَ ثُمَّ صَلَّيْتَ أَرْبَعًا قَالَ الْخِلاَفُ شَرٌّ ‏.‏\hadithno{1960}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1084) Sahih Muslim (695)}\hadithtrans{Narrated 'Abd al-Rahman b. Zaid: 'Uthman prayed four rak'ahs at Mina. 'Abd Allah (b. Mas'ud) said: I prayed two rak'ahs along with the Prophet (ﷺ) and two rak'ahs along with 'Umar. The version of Hafs added: And along with 'Uthman during the early period of his caliphate. He ('Uthman) began to offer complete prayer (i.e. four rak'ahs) later on. The version of Abu Mu'awiyah added: Then your modes of action varied. I would like to pray two rak'ahs acceptable to Allah instead of four rak'ahs. Al-A'mash said: Mu'awiyah b. Qurrah reported to me from his teachers: 'Abd Allah (b. Mas'ud) once prayed four rak'ahs. He was told: You criticized 'Uthman but you yourself prayed four ? He replied: Dissension is evil}}
\hadithdefcmd{abudawud}{1961}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، أَنَّ عُثْمَانَ، إِنَّمَا صَلَّى بِمِنًى أَرْبَعًا لأَنَّهُ أَجْمَعَ عَلَى الإِقَامَةِ بَعْدَ الْحَجِّ ‏.‏\hadithno{1961}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Az-Zuhri: Uthman prayed four rak'ahs at Mina because he resolved to stay there after hajj}}
\hadithdefcmd{abudawud}{1962}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنِ الْمُغِيرَةِ، عَنْ إِبْرَاهِيمَ، قَالَ إِنَّ عُثْمَانَ صَلَّى أَرْبَعًا لأَنَّهُ اتَّخَذَهَا وَطَنًا ‏.‏\hadithno{1962}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibrahim: Uthman prayed four rak'ahs (at Mina) for he made it his home (for settlement)}}
\hadithdefcmd{abudawud}{1963}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ لَمَّا اتَّخَذَ عُثْمَانُ الأَمْوَالَ بِالطَّائِفِ وَأَرَادَ أَنْ يُقِيمَ بِهَا صَلَّى أَرْبَعًا قَالَ ثُمَّ أَخَذَ بِهِ الأَئِمَّةُ بَعْدَهُ ‏.‏\hadithno{1963}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Az-Zuhri: When Uthman placed his property at at-Ta'if and intended to settle there, he prayed four rak'ahs. The rulers after him followed the same practice}}
\hadithdefcmd{abudawud}{1964}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنِ الزُّهْرِيِّ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، أَتَمَّ الصَّلاَةَ بِمِنًى مِنْ أَجْلِ الأَعْرَابِ لأَنَّهُمْ كَثُرُوا عَامَئِذٍ فَصَلَّى بِالنَّاسِ أَرْبَعًا لِيُعْلِمَهُمْ أَنَّ الصَّلاَةَ أَرْبَعٌ ‏.‏\hadithno{1964}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Az-Zuhri: Uthman offered complete prayer at Mina for the sake of bedouins who attended (hajj) in large numbers that year. He led the people four rak'ahs in prayer in order to teach them that the prayer (i.e. noon or afternoon prayer) essentially contained four rak'ahs}}
\hadithdefcmd{abudawud}{1965}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، حَدَّثَنِي حَارِثَةُ بْنُ وَهْبٍ الْخُزَاعِيُّ، - وَكَانَتْ أُمُّهُ تَحْتَ عُمَرَ فَوَلَدَتْ لَهُ عُبَيْدَ اللَّهِ بْنَ عُمَرَ - قَالَ صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِنًى وَالنَّاسُ أَكْثَرُ مَا كَانُوا فَصَلَّى بِنَا رَكْعَتَيْنِ فِي حَجَّةِ الْوَدَاعِ ‏.‏ قَالَ أَبُو دَاوُدَ حَارِثَةُ مِنْ خُزَاعَةَ وَدَارُهُمْ بِمَكَّةَ ‏.‏\hadithno{1965}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (1083) Sahih Muslim (696)}\hadithtrans{Narrated Harithah ibn Wahb al-Khuza'i,: I prayed along with the Messenger of Allah (ﷺ) at Mina and the people gathered there in large numbers. He led us two rak'ahs in prayer in the Farewell Pilgrimage. Abu Dawud said: Harithah belonged to the tribe of Khuza'ah, and they had their houses in Mecca}}
\hadithdefcmd{abudawud}{1966}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مَهْدِيٍّ، حَدَّثَنِي عَلِيُّ بْنُ مُسْهِرٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، أَخْبَرَنَا سُلَيْمَانُ بْنُ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أُمِّهِ، قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْمِي الْجَمْرَةَ مِنْ بَطْنِ الْوَادِي وَهُوَ رَاكِبٌ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ وَرَجُلٌ مِنْ خَلْفِهِ يَسْتُرُهُ فَسَأَلْتُ عَنِ الرَّجُلِ فَقَالُوا الْفَضْلُ بْنُ الْعَبَّاسِ وَازْدَحَمَ النَّاسُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَيُّهَا النَّاسُ لاَ يَقْتُلْ بَعْضُكُمْ بَعْضًا وَإِذَا رَمَيْتُمُ الْجَمْرَةَ فَارْمُوا بِمِثْلِ حَصَى الْخَذْفِ ‏"‏ ‏.‏\hadithno{1966}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sulaiman b. 'Amr b. al-Ahwas:On the authority of his mother: I saw the Messenger of Allah (ﷺ) throwing pebbles at the jamrah from the botton of wadi (valley) while he was riding (on a camel). He was uttering the takbir (Allah is most great) with each pebble. A man behind him was shading him. I asked about the man. They (the people) said: He is al-Fadl b. al-'Abbas. The people crowded. The Prophet (ﷺ) said: 'O people, do not kill each other ; when you throw pebbled at the jamrah, throw small pebbles}}
\hadithdefcmd{abudawud}{1967}{حَدَّثَنَا أَبُو ثَوْرٍ، إِبْرَاهِيمُ بْنُ خَالِدٍ وَوَهْبُ بْنُ بَيَانٍ قَالاَ حَدَّثَنَا عَبِيدَةُ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أُمِّهِ، قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ جَمْرَةِ الْعَقَبَةِ رَاكِبًا وَرَأَيْتُ بَيْنَ أَصَابِعِهِ حَجَرًا فَرَمَى وَرَمَى النَّاسُ ‏.‏\hadithno{1967}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Sulaiman b. 'Amr b. Ahwas reported on the authority of his mother:I saw the Messenger of Allah (ﷺ) near the Jamrat al-Aqabah (the third or last pillar) riding (on a camel) and I saw a pebble between his fingers. He threw the pebbles and the people also threw (stones at the Jamrah)}}
\hadithdefcmd{abudawud}{1968}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، بِإِسْنَادِهِ فِي مِثْلِ هَذَا الْحَدِيثِ زَادَ وَلَمْ يَقُمْ عِنْدَهَا ‏.‏\hadithno{1968}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition (No 1963) has also been transmitted by Yazid ibn AbuZiyad with a different chain of narrators. This version adds the words:He (the Prophet) did not stand near it (the jamrah)}}
\hadithdefcmd{abudawud}{1969}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ عُمَرَ - عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يَأْتِي الْجِمَارَ فِي الأَيَّامِ الثَّلاَثَةِ بَعْدَ يَوْمِ النَّحْرِ مَاشِيًا ذَاهِبًا وَرَاجِعًا وَيُخْبِرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{1969}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Nafi' reported on the authority of Ibn Umar. He (ibn Umar) used to come (to Mina) and threw pebbles three days after the day of sacrifice walking when arriving and returning (both ways). He reported that the Prophet (ﷺ) used to do so}}
\hadithdefcmd{abudawud}{1970}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْمِي عَلَى رَاحِلَتِهِ يَوْمَ النَّحْرِ يَقُولُ ‏ "‏ لِتَأْخُذُوا مَنَاسِكَكُمْ فَإِنِّي لاَ أَدْرِي لَعَلِّي لاَ أَحُجُّ بَعْدَ حَجَّتِي هَذِهِ ‏"‏ ‏.‏\hadithno{1970}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1297)}\hadithtrans{Narrated Jabir bin ‘Abdullah :I saw the Messenger of Allah (ﷺ) throwing pebbles on the day of sacrifice while on his riding beast and saying: Learn your rites, for I do not know whether I am likely to perform Hajj after this occasion}}
\hadithdefcmd{abudawud}{1971}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْمِي عَلَى رَاحِلَتِهِ يَوْمَ النَّحْرِ ضُحًى فَأَمَّا بَعْدَ ذَلِكَ فَبَعْدَ زَوَالِ الشَّمْسِ ‏.‏\hadithno{1971}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1299)}\hadithtrans{Narrated Jabir :I saw the Messenger of Allah (ﷺ) throwing pebbles on the day of sacrifice while on his riding beast in the forenoon, and next when the sun had passed the meridian}}
\hadithdefcmd{abudawud}{1972}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ مِسْعَرٍ، عَنْ وَبَرَةَ، قَالَ سَأَلْتُ ابْنَ عُمَرَ مَتَى أَرْمِي الْجِمَارَ قَالَ إِذَا رَمَى إِمَامُكَ فَارْمِ ‏.‏ فَأَعَدْتُ عَلَيْهِ الْمَسْأَلَةَ فَقَالَ كُنَّا نَتَحَيَّنُ زَوَالَ الشَّمْسِ فَإِذَا زَالَتِ الشَّمْسُ رَمَيْنَا ‏.‏\hadithno{1972}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1746)}\hadithtrans{Narrated Wabrah:I asked Ibn 'Umar: When should I throw pebbles at the jamrah? He replied: When your imam (leader at Hajj) throws pebbles, at that time you should throw them. I repeated the question to him. Thereupon he said: We used to wait for the time when the sun passes the meridian. When the sun declined, we threw the pebbles}}
\hadithdefcmd{abudawud}{1973}{حَدَّثَنَا عَلِيُّ بْنُ بَحْرٍ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَفَاضَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ آخِرِ يَوْمِهِ حِينَ صَلَّى الظُّهْرَ ثُمَّ رَجَعَ إِلَى مِنًى فَمَكَثَ بِهَا لَيَالِيَ أَيَّامِ التَّشْرِيقِ يَرْمِي الْجَمْرَةَ إِذَا زَالَتِ الشَّمْسُ كُلَّ جَمْرَةٍ بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ وَيَقِفُ عِنْدَ الأُولَى وَالثَّانِيَةِ فَيُطِيلُ الْقِيَامَ وَيَتَضَرَّعُ وَيَرْمِي الثَّالِثَةَ وَلاَ يَقِفُ عِنْدَهَا ‏.‏\hadithno{1973}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) performed the obligatory circumambulation of the Ka'bah at the end of the day of sacrifice after he had offered the noon prayer. He hen returned to Mina and stayed there during the tashriq days and he threw pebbles at the jamrahs when the sun declined. He threw seven pebbles at each of the jamrahs, uttering the takbir (Allah is most great) at the time of the throwing the pebble. He stood at the first and the second jamrah, and prolonged his standing there, making supplications with humilation. He threw pebbles at the third jamrah but did not stand there}}
\hadithdefcmd{abudawud}{1974}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ لَمَّا انْتَهَى إِلَى الْجَمْرَةِ الْكُبْرَى جَعَلَ الْبَيْتَ عَنْ يَسَارِهِ وَمِنًى عَنْ يَمِينِهِ وَرَمَى الْجَمْرَةَ بِسَبْعِ حَصَيَاتٍ وَقَالَ هَكَذَا رَمَى الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏\hadithno{1974}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (1748) Sahih Muslim (1296)}\hadithtrans{Narrated 'Abd al-Rahman b. Yazid:On the authority of Ibn Mas'ud: When Ibn Mas'ud came to the largest jamrah, he stood with the House (the Ka'bah) on his left and Mina on his right, and he thew seven pebbles at the jamrah. Then he said: Thus he did throw to whom Surat al-Baqarah was sent down}}
\hadithdefcmd{abudawud}{1975}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ أَبِي الْبَدَّاحِ بْنِ عَاصِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ لِرِعَاءِ الإِبِلِ فِي الْبَيْتُوتَةِ يَرْمُونَ يَوْمَ النَّحْرِ ثُمَّ يَرْمُونَ الْغَدَ وَمِنْ بَعْدِ الْغَدِ بِيَوْمَيْنِ وَيَرْمُونَ يَوْمَ النَّفْرِ ‏.‏\hadithno{1975}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu al-Baddah b. 'Asim: On the authority of his father 'Asim: The Messenger of Allah (ﷺ) gave permission to the herdsmen of the camels not to pass night at Mina and asked them to throw pebbles on the day of sacrifice, and to throw pebbles at the jamrahs the next day and the following two days, and on the day of their return}}
\hadithdefcmd{abudawud}{1976}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ، وَمُحَمَّدِ، ابْنَىْ أَبِي بَكْرٍ عَنْ أَبِيهِمَا، عَنْ أَبِي الْبَدَّاحِ بْنِ عَدِيٍّ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ لِلرِّعَاءِ أَنْ يَرْمُوا يَوْمًا وَيَدَعُوا يَوْمًا ‏.‏\hadithno{1976}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu al-Baddah b. 'Asim b. Adi: On the authority of his father: The Messenger of Allah (ﷺ) permitted the herdsmen of the camel to lapidate the the jamrahs one day and omit one day}}
\hadithdefcmd{abudawud}{1977}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا مِجْلَزٍ، يَقُولُ سَأَلْتُ ابْنَ عَبَّاسٍ عَنْ شَىْءٍ، مِنْ أَمْرِ الْجِمَارِ فَقَالَ مَا أَدْرِي أَرَمَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسِتٍّ أَوْ بِسَبْعٍ ‏.‏\hadithno{1977}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{AbuMijlaz said:I asked Ibn Abbas about a thing concerning the throwing of stones at the jamrahs. He said: I do not know whether the Messenger of Allah (ﷺ) threw six or seven pebbles}}
\hadithdefcmd{abudawud}{1978}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الْحَجَّاجُ، عَنِ الزُّهْرِيِّ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَمَى أَحَدُكُمْ جَمْرَةَ الْعَقَبَةِ فَقَدْ حَلَّ لَهُ كُلُّ شَىْءٍ إِلاَّ النِّسَاءَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حَدِيثٌ ضَعِيفٌ الْحَجَّاجُ لَمْ يَرَ الزُّهْرِيَّ وَلَمْ يَسْمَعْ مِنْهُ ‏.‏\hadithno{1978}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: When one of you throws pebbles at the last jamrah (Jamrat al-Aqabah), everything becomes lawful for him except women (sexual intercourse). Abu Dawud said: This is a weak tradition. The narrator al-Hajjaj neither saw al-Zuhri nor heard tradition from him}}
\hadithdefcmd{abudawud}{1979}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اللَّهُمَّ ارْحَمِ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَالْمُقَصِّرِينَ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ ارْحَمِ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَالْمُقَصِّرِينَ ‏.‏ قَالَ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏ ‏.‏\hadithno{1979}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1727) Sahih Muslim (1301)}\hadithtrans{Narrated 'Abd Allah b. 'Umar:That the Messenger of Allah (ﷺ) said: O Allah, have mercy on those who have themselves shaved. The people said: Messenger of Allah, and those who have clipped their hair. He again said: O Allah, have mercy on those who have themselves shaved. The people said: Messenger of Allah, those who have clipped their hair. He said: and those who clip their hair}}
\hadithdefcmd{abudawud}{1980}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي الإِسْكَنْدَرَانِيَّ - عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَلَقَ رَأْسَهُ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{1980}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4410) Sahih Muslim (1304)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) had his head shaved at the Farewell Pilgrimage}}
\hadithdefcmd{abudawud}{1981}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا حَفْصٌ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَى جَمْرَةَ الْعَقَبَةِ يَوْمَ النَّحْرِ ثُمَّ رَجَعَ إِلَى مَنْزِلِهِ بِمِنًى فَدَعَا بِذِبْحٍ فَذُبِحَ ثُمَّ دَعَا بِالْحَلاَّقِ فَأَخَذَ بِشِقِّ رَأْسِهِ الأَيْمَنِ فَحَلَقَهُ فَجَعَلَ يَقْسِمُ بَيْنَ مَنْ يَلِيهِ الشَّعْرَةَ وَالشَّعْرَتَيْنِ ثُمَّ أَخَذَ بِشِقِّ رَأْسِهِ الأَيْسَرِ فَحَلَقَهُ ثُمَّ قَالَ ‏ "‏ هَا هُنَا أَبُو طَلْحَةَ ‏"‏ ‏.‏ فَدَفَعَهُ إِلَى أَبِي طَلْحَةَ ‏.‏\hadithno{1981}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1305)}\hadithtrans{Narrated Anas bin Malik:The Messenger of Allah (ﷺ) threw pebbles at the last jamrah (Jamrat al-'Aqabah) on the day of sacrifice. He then returned to his lodging at Mina. He called for a sacrificial animal which he slaughtered. He then called for a barber. He held the right side of his head and shaved it. He then began to distribute among those who were around him one or two hair each. He then held the left side of his head and shaved it. Again he said: Is Abu Talhah here ? He then gave it (the hair shaved off) to Abu Talhah}}
\hadithdefcmd{abudawud}{1982}{حَدَّثَنَا عُبَيْدُ بْنُ هِشَامٍ أَبُو نُعَيْمٍ الْحَلَبِيُّ، وَعَمْرُو بْنُ عُثْمَانَ الْمَعْنَى، - قَالاَ - حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ حَسَّانَ، بِإِسْنَادِهِ بِهَذَا قَالَ فِيهِ قَالَ لِلْحَالِقِ ‏ "‏ ابْدَأْ بِشِقِّي الأَيْمَنِ فَاحْلِقْهُ ‏"‏ ‏.‏\hadithno{1982}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by Hisham n. Hassan through a different chain of narrators. This version adds:He said to the barber: Start with the right side and shave it}}
\hadithdefcmd{abudawud}{1983}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَخْبَرَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُسْأَلُ يَوْمَ مِنًى فَيَقُولُ ‏"‏ لاَ حَرَجَ ‏"‏ ‏.‏ فَسَأَلَهُ رَجُلٌ فَقَالَ إِنِّي حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ ‏.‏ قَالَ ‏"‏ اذْبَحْ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ إِنِّي أَمْسَيْتُ وَلَمْ أَرْمِ ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{1983}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1735)}\hadithtrans{Narrated Ibn 'Abbas:The Prophet (ﷺ) was asked (about rites of Hajj) on the day of stay at Mina. He said: No harm. A man asked him: I got myself shaved before I slaughtered. He said: Slaughter, there is no harm. He again asked: The evening came but I did not throw stones at the jamrah. He replied: Throw stones now ; there is no harm}}
\hadithdefcmd{abudawud}{1984}{حَدَّثَنَا مُحَمَّدُ بْنُ الْحَسَنِ الْعَتَكِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ بَلَغَنِي عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ بْنِ عُثْمَانَ، قَالَتْ أَخْبَرَتْنِي أُمُّ عُثْمَانَ بِنْتُ أَبِي سُفْيَانَ، أَنَّ ابْنَ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى النِّسَاءِ حَلْقٌ إِنَّمَا عَلَى النِّسَاءِ التَّقْصِيرُ ‏"‏ ‏.‏\hadithno{1984}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Shaving is not a duty laid on women; only clipping the hair is incumbent on them}}
\hadithdefcmd{abudawud}{1985}{حَدَّثَنَا أَبُو يَعْقُوبَ الْبَغْدَادِيُّ، ثِقَةٌ حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جُبَيْرِ بْنِ شَيْبَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، قَالَتْ أَخْبَرَتْنِي أُمُّ عُثْمَانَ بِنْتُ أَبِي سُفْيَانَ، أَنَّ ابْنَ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى النِّسَاءِ الْحَلْقُ إِنَّمَا عَلَى النِّسَاءِ التَّقْصِيرُ ‏"‏ ‏.‏\hadithno{1985}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Shaving is not a duty laid on women; only clipping the hair is incumbent on them}}
\hadithdefcmd{abudawud}{1986}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، وَيَحْيَى بْنُ زَكَرِيَّا، عَنِ ابْنِ جُرَيْجٍ، عَنْ عِكْرِمَةَ بْنِ خَالِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ أَنْ يَحُجَّ ‏.‏\hadithno{1986}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1774)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) performed 'Umrah before performing Hajj}}
\hadithdefcmd{abudawud}{1987}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ أَبِي زَائِدَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، وَمُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ وَاللَّهِ مَا أَعْمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَائِشَةَ فِي ذِي الْحِجَّةِ إِلاَّ لِيَقْطَعَ بِذَلِكَ أَمْرَ أَهْلِ الشِّرْكِ فَإِنَّ هَذَا الْحَىَّ مِنْ قُرَيْشٍ وَمَنْ دَانَ دِينَهُمْ كَانُوا يَقُولُونَ إِذَا عَفَا الْوَبَرْ وَبَرَأَ الدَّبَرْ وَدَخَلَ صَفَرْ فَقَدْ حَلَّتِ الْعُمْرَةُ لِمَنِ اعْتَمَرْ ‏.‏ فَكَانُوا يُحَرِّمُونَ الْعُمْرَةَ حَتَّى يَنْسَلِخَ ذُو الْحِجَّةِ وَالْمُحَرَّمُ ‏.‏\hadithno{1987}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: By Allah, the Messenger of Allah (ﷺ) did not make Aisha perform umrah during Dhul-Hijjah but to discontinue the practice of the idolaters (in Arabia before Islam), for this clan of Quraysh and those who followed them used to say: When the fur of the camel abounds, and the wounds on the back of the camels are recovered and the month of Safar begins, umrah becomes lawful for one who performs umrah. They considered performing umrah unlawful till the months of Dhul-Hijjah and al-Muharram passed away}}
\hadithdefcmd{abudawud}{1988}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، أَخْبَرَنِي رَسُولُ مَرْوَانَ الَّذِي أَرْسَلَ إِلَى أُمِّ مَعْقِلٍ قَالَتْ كَانَ أَبُو مَعْقِلٍ حَاجًّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا قَدِمَ قَالَتْ أُمُّ مَعْقِلٍ قَدْ عَلِمْتَ أَنَّ عَلَىَّ حَجَّةً فَانْطَلَقَا يَمْشِيَانِ حَتَّى دَخَلاَ عَلَيْهِ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ عَلَىَّ حَجَّةً وَإِنَّ لأَبِي مَعْقِلٍ بَكْرًا ‏.‏ قَالَ أَبُو مَعْقِلٍ صَدَقَتْ جَعَلْتُهُ فِي سَبِيلِ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْطِهَا فَلْتَحُجَّ عَلَيْهِ فَإِنَّهُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ فَأَعْطَاهَا الْبَكْرَ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ قَدْ كَبِرْتُ وَسَقِمْتُ فَهَلْ مِنْ عَمَلٍ يُجْزِئُ عَنِّي مِنْ حَجَّتِي قَالَ ‏"‏ عُمْرَةٌ فِي رَمَضَانَ تُجْزِئُ حَجَّةً ‏"‏ ‏.‏\hadithno{1988}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{AbuBakr ibn AbdurRahman said:The messenger of Marwan whom he sent to Umm Ma'qil reported to me. She said: AbuMa'qil accompanied the Messenger of Allah (ﷺ) during hajj. When he came (to her) she said: You know that hajj is incumbent on me. They walked until they visited him (i.e. the Prophet) and she asked (him): Messenger of Allah, hajj is due from me, and AbuMa'qil has a camel. AbuMa'qil said: She spoke the truth, I have dedicated it to the cause of Allah. The Messenger of Allah (ﷺ) said: Give it to her, that is in the cause of Allah. So he gave the camel to her. She then said: Messenger of Allah, I am a woman who has become aged and ill. Is there any action which would be sufficient for me as my hajj? He replied: umrah performed during Ramadan is sufficient as hajj}}
\hadithdefcmd{abudawud}{1989}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ الْوَهْبِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ عِيسَى بْنِ مَعْقِلِ ابْنِ أُمِّ مَعْقِلٍ الأَسَدِيِّ، - أَسَدُ خُزَيْمَةَ - حَدَّثَنِي يُوسُفُ بْنُ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، عَنْ جَدَّتِهِ أُمِّ مَعْقِلٍ، قَالَتْ لَمَّا حَجَّ رَسُولُ اللَّهِ صلى الله عليه وسلم حَجَّةَ الْوَدَاعِ وَكَانَ لَنَا جَمَلٌ فَجَعَلَهُ أَبُو مَعْقِلٍ فِي سَبِيلِ اللَّهِ وَأَصَابَنَا مَرَضٌ وَهَلَكَ أَبُو مَعْقِلٍ وَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا فَرَغَ مِنْ حَجِّهِ جِئْتُهُ فَقَالَ ‏"‏ يَا أُمَّ مَعْقِلٍ مَا مَنَعَكِ أَنْ تَخْرُجِي مَعَنَا ‏"‏ ‏.‏ قَالَتْ لَقَدْ تَهَيَّأْنَا فَهَلَكَ أَبُو مَعْقِلٍ وَكَانَ لَنَا جَمَلٌ هُوَ الَّذِي نَحُجُّ عَلَيْهِ فَأَوْصَى بِهِ أَبُو مَعْقِلٍ فِي سَبِيلِ اللَّهِ ‏.‏ قَالَ ‏"‏ فَهَلاَّ خَرَجْتِ عَلَيْهِ فَإِنَّ الْحَجَّ فِي سَبِيلِ اللَّهِ فَأَمَّا إِذْ فَاتَتْكِ هَذِهِ الْحَجَّةُ مَعَنَا فَاعْتَمِرِي فِي رَمَضَانَ فَإِنَّهَا كَحَجَّةٍ ‏"‏ ‏.‏ فَكَانَتْ تَقُولُ الْحَجُّ حَجَّةٌ وَالْعُمْرَةُ عُمْرَةٌ وَقَدْ قَالَ هَذَا لِي رَسُولُ اللَّهِ صلى الله عليه وسلم مَا أَدْرِي أَلِيَ خَاصَّةً ‏.‏\hadithno{1989}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Ma'qil: When the Messenger of Allah (ﷺ) performed the Farewell Pilgrimage, and we had a camel, AbuMa'qil dedicated it to the cause of Allah. Then we suffered from a disease, and AbuMa'qil died. The Prophet (ﷺ) went out (for hajj). When he finished the hajj, I came to him. He said (to me): Umm Ma'qil, what prevented you from coming out for hajj along with us? She said: We resolved (to do so), but AbuMa'qil died. We had a camel on which we could perform hajj, but AbuMa'qil had bequeathed it to the cause of Allah. He said: Why did you not go out (for hajj) upon it, for hajj is in the cause of Allah? If you miss this hajj along with us, perform umrah during Ramadan, for it is like hajj. She used to say: hajj is hajj, and umrah is umrah. The Messenger of Allah (ﷺ) said it to me: I do not know whether it was peculiar to me}}
\hadithdefcmd{abudawud}{1990}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَامِرٍ الأَحْوَلِ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْحَجَّ فَقَالَتِ امْرَأَةٌ لِزَوْجِهَا أَحِجَّنِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى جَمَلِكَ ‏.‏ فَقَالَ مَا عِنْدِي مَا أُحِجُّكِ عَلَيْهِ ‏.‏ قَالَتْ أَحِجَّنِي عَلَى جَمَلِكَ فُلاَنٍ ‏.‏ قَالَ ذَاكَ حَبِيسٌ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏.‏ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ امْرَأَتِي تَقْرَأُ عَلَيْكَ السَّلاَمَ وَرَحْمَةَ اللَّهِ وَإِنَّهَا سَأَلَتْنِي الْحَجَّ مَعَكَ قَالَتْ أَحِجَّنِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقُلْتُ مَا عِنْدِي مَا أُحِجُّكِ عَلَيْهِ ‏.‏ فَقَالَتْ أَحِجَّنِي عَلَى جَمَلِكَ فُلاَنٍ ‏.‏ فَقُلْتُ ذَاكَ حَبِيسٌ فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ ‏"‏ أَمَا إِنَّكَ لَوْ أَحْجَجْتَهَا عَلَيْهِ كَانَ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ وَإِنَّهَا أَمَرَتْنِي أَنْ أَسْأَلَكَ مَا يَعْدِلُ حَجَّةً مَعَكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَقْرِئْهَا السَّلاَمَ وَرَحْمَةَ اللَّهِ وَبَرَكَاتِهِ وَأَخْبِرْهَا أَنَّهَا تَعْدِلُ حَجَّةً مَعِي ‏"‏ ‏.‏ يَعْنِي عُمْرَةً فِي رَمَضَانَ ‏.‏\hadithno{1990}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah Ibn Abbas: The Messenger of Allah (ﷺ) intended to perform hajj. A woman said to her husband: Let me perform hajj along with the Messenger of Allah (ﷺ). He said: I have nothing on which I can let you perform hajj. She said: You may perform hajj on your such-and-such camel. He said: That is dedicated to the cause of Allah, the Exalted. He then came to the Messenger of Allah (ﷺ) and said: My wife has conveyed her greetings and the blessings of Allah to you. She has asked about performing hajj along with you. She said (to me): Let me perform hajj with the Messenger of Allah (ﷺ). I said (to her): I have nothing upon which I can let you perform hajj. She said: Let me perform hajj on your such-and-such camel. I said: That is dedicated to the cause of Allah, The Exalted. He replied: If you let her perform hajj on it, that would be in the cause of Allah. He said: She has also requested me to ask you: What is that action which is equivalent to performing hajj with you? The Messenger of Allah (ﷺ) said: Convey my greetings, the mercy of Allah and His blessings to her and tell her that umrah during Ramadan is equivalent to performing hajj along with me}}
\hadithdefcmd{abudawud}{1991}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اعْتَمَرَ عُمْرَتَيْنِ عُمْرَةً فِي ذِي الْقَعْدَةِ وَعُمْرَةً فِي شَوَّالٍ ‏.‏\hadithno{1991}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) performed two umrahs: one umrah in Dhul-Qa'dah, and the other in Shawwal}}
\hadithdefcmd{abudawud}{1992}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ مُجَاهِدٍ، قَالَ سُئِلَ ابْنُ عُمَرَ كَمِ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ مَرَّتَيْنِ ‏.‏ فَقَالَتْ عَائِشَةُ لَقَدْ عَلِمَ ابْنُ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدِ اعْتَمَرَ ثَلاَثًا سِوَى الَّتِي قَرَنَهَا بِحَجَّةِ الْوَدَاعِ ‏.‏\hadithno{1992}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Mujahid said:Ibn 'Umar was asked: How many times did the Messenger of Allah (ﷺ) perform 'Umrah ? He said: Twice. 'Aishah said: Ibn 'Umar knew that the Messenger of Allah (ﷺ) performed three 'Umrahs in addition to the one he combined with the Farewell Pilgrimage}}
\hadithdefcmd{abudawud}{1993}{حَدَّثَنَا النُّفَيْلِيُّ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرْبَعَ عُمَرٍ عُمْرَةَ الْحُدَيْبِيَةِ وَالثَّانِيَةَ حِينَ تَوَاطَئُوا عَلَى عُمْرَةٍ مِنْ قَابِلٍ وَالثَّالِثَةَ مِنَ الْجِعْرَانَةِ وَالرَّابِعَةَ الَّتِي قَرَنَ مَعَ حَجَّتِهِ ‏.‏\hadithno{1993}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) performed four umrahs, viz. umrah al-Hudaybiyyah; the second is the one when they (the Companions) were agreed upon performing umrah next year; the third is umrah performed from al-Ji'ranah; the fourth is the one which he combined with his hajj}}
\hadithdefcmd{abudawud}{1994}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، وَهُدْبَةُ بْنُ خَالِدٍ، قَالاَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اعْتَمَرَ أَرْبَعَ عُمَرٍ كُلُّهُنَّ فِي ذِي الْقَعْدَةِ إِلاَّ الَّتِي مَعَ حَجَّتِهِ - قَالَ أَبُو دَاوُدَ أَتْقَنْتُ مِنْ هَا هُنَا مِنْ هُدْبَةَ وَسَمِعْتُهُ مِنْ أَبِي الْوَلِيدِ وَلَمْ أَضْبِطْهُ - عُمْرَةً زَمَنَ الْحُدَيْبِيَةِ أَوْ مِنَ الْحُدَيْبِيَةِ وَعُمْرَةَ الْقَضَاءِ فِي ذِي الْقَعْدَةِ وَعُمْرَةً مِنَ الْجِعْرَانَةِ حَيْثُ قَسَمَ غَنَائِمَ حُنَيْنٍ فِي ذِي الْقَعْدَةِ وَعُمْرَةً مَعَ حَجَّتِهِ ‏.‏\hadithno{1994}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1778) Sahih Muslim (1253)}\hadithtrans{Narrated Anas: The Messenger of Allah (ﷺ) performed four 'Umrahs all in Dhu al-Qa'dah except the one which he performed along with Hajj. Abu Dawud said: From here the narrator Hudbah (b. Khalid) became certain. I heard it from Abu al-Walid , but I did nor retain: An 'Umrah, during the treaty of al-Hudaibiyyah, or from al-Hudaibiyyah ; and 'Umrat al-Qada' in Dhu al-Qa'dah, and an 'Umrah from al-Ji'ranah where he (the Prophet) distributed the booty of Hunain in Dhu al-Qa'dah, and an 'Umrah along with his Hajj}}
\hadithdefcmd{abudawud}{1995}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ حَفْصَةَ بِنْتِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهَا، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِعَبْدِ الرَّحْمَنِ ‏ "‏ يَا عَبْدَ الرَّحْمَنِ أَرْدِفْ أُخْتَكَ عَائِشَةَ فَأَعْمِرْهَا مِنَ التَّنْعِيمِ فَإِذَا هَبَطْتَ بِهَا مِنَ الأَكَمَةِ فَلْتُحْرِمْ فَإِنَّهَا عُمْرَةٌ مُتَقَبَّلَةٌ ‏"‏ ‏.‏\hadithno{1995}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hafsah, daughter of AbdurRahman ibn AbuBakr, reported on the authority of her father:The Messenger of Allah (ﷺ) said to AbdurRahman: AbdurRahman, put your sister Aisha on the back of the camel behind you and make her perform umrah from at-Tan'im. When you come down from the hillock (in at-Tan'im), she must wear (ihram for umrah), for this is an umrah accepted (by Allah)}}
\hadithdefcmd{abudawud}{1996}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سَعِيدُ بْنُ مُزَاحِمِ بْنِ أَبِي مُزَاحِمٍ، حَدَّثَنِي أَبِي مُزَاحِمٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عَبْدِ اللَّهِ بْنِ أَسِيدٍ، عَنْ مُحَرِّشٍ الْكَعْبِيِّ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم الْجِعْرَانَةَ فَجَاءَ إِلَى الْمَسْجِدِ فَرَكَعَ مَا شَاءَ اللَّهُ ثُمَّ أَحْرَمَ ثُمَّ اسْتَوَى عَلَى رَاحِلَتِهِ فَاسْتَقْبَلَ بَطْنَ سَرِفَ حَتَّى لَقِيَ طَرِيقَ الْمَدِينَةِ فَأَصْبَحَ بِمَكَّةَ كَبَائِتٍ ‏.‏\hadithno{1996}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Muharrish al-Ka'bi: The Prophet (ﷺ) entered al-Ji'ranah. He came to the mosque (there) and prayed as long as Allah desired; he then wore ihram. Then he rode his camel and faced Batn Sarif till he reached the way which leads to Medina. He returned from Mecca (at night to al-Ji'ranah) as if he had passed the night at Mecca}}
\hadithdefcmd{abudawud}{1997}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ أَبَانَ بْنِ صَالِحٍ، وَعَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقَامَ فِي عُمْرَةِ الْقَضَاءِ ثَلاَثًا ‏.‏\hadithno{1997}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) stayed (at Mecca) for three days during umrah for atonement ('Umrat al-Qada)}}
\hadithdefcmd{abudawud}{1998}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَفَاضَ يَوْمَ النَّحْرِ ثُمَّ صَلَّى الظُّهْرَ بِمِنًى يَعْنِي رَاجِعًا ‏.‏\hadithno{1998}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1308)}\hadithtrans{Narrated Ibn 'Umar:The Prophet (ﷺ) performed the obligatory circumambulation (Tawaf al-Ziyarah) on the day of the sacrifice ; he then offered the noon prayer at Mina when he returned}}
\hadithdefcmd{abudawud}{1999}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَيَحْيَى بْنُ مَعِينٍ، - الْمَعْنَى وَاحِدٌ - قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنَا أَبُو عُبَيْدَةَ بْنُ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، عَنْ أَبِيهِ، وَعَنْ أُمِّهِ، زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، - يُحَدِّثَانِهِ جَمِيعًا ذَاكَ عَنْهَا - قَالَتْ كَانَتْ لَيْلَتِي الَّتِي يَصِيرُ إِلَىَّ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَسَاءَ يَوْمِ النَّحْرِ فَصَارَ إِلَىَّ وَدَخَلَ عَلَىَّ وَهْبُ بْنُ زَمْعَةَ وَمَعَهُ رَجُلٌ مِنْ آلِ أَبِي أُمَيَّةَ مُتَقَمِّصَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِوَهْبٍ ‏"‏ هَلْ أَفَضْتَ أَبَا عَبْدِ اللَّهِ ‏"‏ ‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ صلى الله عليه وسلم ‏"‏ انْزِعْ عَنْكَ الْقَمِيصَ ‏"‏ ‏.‏ قَالَ فَنَزَعَهُ مِنْ رَأْسِهِ وَنَزَعَ صَاحِبُهُ قَمِيصَهُ مِنْ رَأْسِهِ ثُمَّ قَالَ وَلِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنَّ هَذَا يَوْمٌ رُخِّصَ لَكُمْ إِذَا أَنْتُمْ رَمَيْتُمُ الْجَمْرَةَ أَنْ تَحِلُّوا ‏"‏ ‏.‏ يَعْنِي مِنْ كُلِّ مَا حَرُمْتُمْ مِنْهُ إِلاَّ النِّسَاءَ ‏"‏ فَإِذَا أَمْسَيْتُمْ قَبْلَ أَنْ تَطُوفُوا هَذَا الْبَيْتَ صِرْتُمْ حُرُمًا كَهَيْئَتِكُمْ قَبْلَ أَنْ تَرْمُوا الْجَمْرَةَ حَتَّى تَطُوفُوا بِهِ ‏"‏ ‏.‏\hadithno{1999}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The night which the Messenger of Allah (ﷺ) passed with me was the one that followed the day of sacrifice. He came to me and Wahb ibn Zam'ah also visited me. A man belonging to the lineage of AbuUmayyah accompanied him. Both of them were wearing shirts. The Messenger of Allah (ﷺ) said to Wahb: Did you perform the obligatory circumambulation (Tawaf az-Ziyarah), AbuAbdullah? He said: No, by Allah Messenger of Allah. He (the Prophet) said: Take off your shirt. He then took it off over his head, and his companion too took his shirt off over his head. He then asked: And why (this), Messenger of Allah? He replied: On this day you have been allowed to take off ihram when you have thrown the stones at the jamrahs, that is, everything prohibited during the state of ihram is lawful except intercourse with a woman. If the evening comes before you go round this House (the Ka'bah) you will remain in the sacred state (i.e. ihram), just like the state in which you were before you threw stones at the jamrahs, until you perform the circumambulation of it (i.e. the Ka'bah)}}
\hadithdefcmd{abudawud}{2000}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَائِشَةَ، وَابْنِ، عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَخَّرَ طَوَافَ يَوْمِ النَّحْرِ إِلَى اللَّيْلِ ‏.‏\hadithno{2000}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin ; Abdullah Ibn Abbas: The Prophet (ﷺ) postponed the circumambulation on the day of sacrifice till the night}}
\hadithdefcmd{abudawud}{2001}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي ابْنُ جُرَيْجٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَرْمُلْ فِي السَّبْعِ الَّذِي أَفَاضَ فِيهِ ‏.‏\hadithno{2001}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) did not walk quickly (ramal) in the seven rounds of the last circumambulation (Tawaf al-Ifadah)}}
\hadithdefcmd{abudawud}{2002}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّاسُ يَنْصَرِفُونَ فِي كُلِّ وَجْهٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَنْفِرَنَّ أَحَدٌ حَتَّى يَكُونَ آخِرُ عَهْدِهِ الطَّوَافَ بِالْبَيْتِ ‏"‏ ‏.‏\hadithno{2002}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1327)}\hadithtrans{Narrated Ibn 'Abbas:The people used to go out (from Mecca after Hajj) by all sides. The Prophet (ﷺ) said: No one should leave (Mecca) until he performs the last circumambulation of the House (the Ka'bah)}}
\hadithdefcmd{abudawud}{2003}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ صَفِيَّةَ بِنْتَ حُيَىٍّ فَقِيلَ إِنَّهَا قَدْ حَاضَتْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَعَلَّهَا حَابِسَتُنَا ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ أَفَاضَتْ ‏.‏ فَقَالَ ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏\hadithno{2003}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) mentioned about Safiyyah, daughter of Huyayy. He was told that she had menstruated. The Messenger of Allah (ﷺ) said: She may probably detain us. They (the people) said: She has performed the obligatory circumambulation (Tawaf al-Ziyarah). He said: If so, there is no need (of staying any longer)}}
\hadithdefcmd{abudawud}{2004}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ الْحَارِثِ بْنِ عَبْدِ اللَّهِ بْنِ أَوْسٍ، قَالَ أَتَيْتُ عُمَرَ بْنَ الْخَطَّابِ فَسَأَلْتُهُ عَنِ الْمَرْأَةِ، تَطُوفُ بِالْبَيْتِ يَوْمَ النَّحْرِ ثُمَّ تَحِيضُ قَالَ لِيَكُنْ آخِرُ عَهْدِهَا بِالْبَيْتِ ‏.‏ قَالَ فَقَالَ الْحَارِثُ كَذَلِكَ أَفْتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَقَالَ عُمَرُ أَرِبْتَ عَنْ يَدَيْكَ سَأَلْتَنِي عَنْ شَىْءٍ سَأَلْتَ عَنْهُ رَسُولَ اللَّهِ صلى الله عليه وسلم لِكَيْمَا أُخَالِفَ ‏.‏\hadithno{2004}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Harith ibn Abdullah ibn Aws said:I came to Umar ibn al-Khattab and asked him about a woman who has performed the (obligatory) circumambulation on the day of sacrifice, and then she menstruates. He said: She must perform the last circumambulation of the House (the Ka'bah). Al-Harith said: The Messenger of Allah (ﷺ) told me the same thing. Umar said: May your hands fall down! You asked me about a thing that you had asked the Messenger of Allah (ﷺ) so that I might oppose him}}
\hadithdefcmd{abudawud}{2005}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ أَفْلَحَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ أَحْرَمْتُ مِنَ التَّنْعِيمِ بِعُمْرَةٍ فَدَخَلْتُ فَقَضَيْتُ عُمْرَتِي وَانْتَظَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِالأَبْطَحِ حَتَّى فَرَغْتُ وَأَمَرَ النَّاسَ بِالرَّحِيلِ ‏.‏ قَالَتْ وَأَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْتَ فَطَافَ بِهِ ثُمَّ خَرَجَ ‏.‏\hadithno{2005}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (1560) Sahih Muslim (1211)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I put on ihram for umrah at at-Tan'im and I entered (Mecca) and performed my umrah as an atonement. The Messenger of Allah (ﷺ) waited for me at al-Abtah till I finished it. He commanded the people to depart. The Messenger of Allah (ﷺ) came to the House (the Ka'bah), went round it and went out (i.e. left for Medina)}}
\hadithdefcmd{abudawud}{2006}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ، - يَعْنِي الْحَنَفِيَّ - حَدَّثَنَا أَفْلَحُ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْتُ مَعَهُ - تَعْنِي مَعَ النَّبِيِّ صلى الله عليه وسلم - فِي النَّفْرِ الآخِرِ فَنَزَلَ الْمُحَصَّبَ - قَالَ أَبُو دَاوُدَ وَلَمْ يَذْكُرِ ابْنُ بَشَّارٍ قِصَّةَ بَعْثِهَا إِلَى التَّنْعِيمِ فِي هَذَا الْحَدِيثِ - قَالَتْ ثُمَّ جِئْتُهُ بِسَحَرٍ فَأَذَّنَ فِي أَصْحَابِهِ بِالرَّحِيلِ فَارْتَحَلَ فَمَرَّ بِالْبَيْتِ قَبْلَ صَلاَةِ الصُّبْحِ فَطَافَ بِهِ حِينَ خَرَجَ ثُمَّ انْصَرَفَ مُتَوَجِّهًا إِلَى الْمَدِينَةِ ‏.‏\hadithno{2006}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1560) Sahih Muslim (1211)}\hadithtrans{Narrated 'Aishah: I went out along with the Prophet (ﷺ) during his last march, and he alighted at al-Muhassab. Abu Dawud said: Ibn Bashshar did not mention that she was sent to al-Tan'im in this tradition. She said: I then came to him in the morning. He announced to his companions for departure, and he himself departed. He passed the house (the Ka'bah) before the dawn prayer, and went round it when he proceeded. He then went away facing Medina}}
\hadithdefcmd{abudawud}{2007}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ طَارِقٍ، أَخْبَرَهُ عَنْ أُمِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا جَازَ مَكَانًا مِنْ دَارِ يَعْلَى - نَسِيَهُ عُبَيْدُ اللَّهِ - اسْتَقْبَلَ الْبَيْتَ فَدَعَا ‏.‏\hadithno{2007}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbdurRahman ibn Tariq: AbdurRahman reported on the authority of his mother: When the Messenger of Allah (ﷺ) passed any place from the house of Ya'la,--the narrator Ubaydullah forgot its name--he faced the House (the Ka'bah) and supplicated}}
\hadithdefcmd{abudawud}{2008}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّمَا نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُحَصَّبَ لِيَكُونَ أَسْمَحَ لِخُرُوجِهِ وَلَيْسَ بِسُنَّةٍ فَمَنْ شَاءَ نَزَلَهُ وَمَنْ شَاءَ لَمْ يَنْزِلْهُ ‏.‏\hadithno{2008}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) alighted at al-Muhassab so that it might be easier for him to proceed (to Medina). It is not a sunnah (i.e. a rite of Hajj). Anyone who desires may alight there, and anyone who does not want may not alight}}
\hadithdefcmd{abudawud}{2009}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ الْمَعْنَى، ح وَحَدَّثَنَا مُسَدَّدٌ، قَالُوا حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا صَالِحُ بْنُ كَيْسَانَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ قَالَ أَبُو رَافِعٍ لَمْ يَأْمُرْنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَنْزِلَهُ وَلَكِنْ ضَرَبْتُ قُبَّتَهُ فَنَزَلَهُ ‏.‏ قَالَ مُسَدَّدٌ وَكَانَ عَلَى ثَقَلِ النَّبِيِّ صلى الله عليه وسلم وَقَالَ عُثْمَانُ يَعْنِي فِي الأَبْطَحِ ‏.‏\hadithno{2009}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1313)}\hadithtrans{Abu Rafi’ said The Apostle of Allaah(ﷺ) did not command me to align there. But when I pitched his tent there, he alighted. The narrator Musaddad said “He (Abu Rafi’) kept watch over the luggage of the Prophet(ﷺ). The narrator ‘Uthman said That is in Al Abtah}}
\hadithdefcmd{abudawud}{2010}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَيْنَ تَنْزِلُ غَدًا فِي حَجَّتِهِ قَالَ ‏"‏ هَلْ تَرَكَ لَنَا عَقِيلٌ مَنْزِلاً ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ نَحْنُ نَازِلُونَ بِخَيْفِ بَنِي كِنَانَةَ حَيْثُ قَاسَمَتْ قُرَيْشٌ عَلَى الْكُفْرِ ‏"‏ ‏.‏ يَعْنِي الْمُحَصَّبَ وَذَلِكَ أَنَّ بَنِي كِنَانَةَ حَالَفَتْ قُرَيْشًا عَلَى بَنِي هَاشِمٍ أَنْ لاَ يُنَاكِحُوهُمْ وَلاَ يُبَايِعُوهُمْ وَلاَ يُئْوُوهُمْ ‏.‏ قَالَ الزُّهْرِيُّ وَالْخَيْفُ الْوَادِي ‏.‏\hadithno{2010}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3058) Sahih Muslim (1351)}\hadithtrans{Usamah bin Zaid said I asked Apostle of Allaah(ﷺ) where will you encamp tomorrow? (This is asked on the occasion of his Hajj). He replied “Did ‘Aqil leave any house for us?” He again said “We shall encamp in the valley (Khaif) of Banu Kinanah where the Quraish took an oath upon disbelief, that is, Al Muhassab.” The oath was that Banu Kinanah concluded a pact with the Quraish against Banu Hashim “they would have no marital relationship with them, nor would give them accommodation nor would have any commercial ties with them.” Al Zuhri said Al Khaif means valley}}
\hadithdefcmd{abudawud}{2011}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا عُمَرُ، حَدَّثَنَا أَبُو عَمْرٍو، - يَعْنِي الأَوْزَاعِيَّ - عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ حِينَ أَرَادَ أَنْ يَنْفِرَ مِنْ مِنًى ‏ "‏ نَحْنُ نَازِلُونَ غَدًا ‏"‏ ‏.‏ فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرْ أَوَّلَهُ وَلاَ ذَكَرَ الْخَيْفُ الْوَادِي ‏.‏\hadithno{2011}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1590) Sahih Muslim (1314)}\hadithtrans{Abu Hurairah said “Apostle of Allaah(ﷺ) said when intended to march from Mina we shall encamp tomorrow. The narrator then narrated something similar (as a previous tradition but he did not mention the opening words, nor did he mention the words “Al Khaif, Al Wadi(Khaif means Valley).”}}
\hadithdefcmd{abudawud}{2012}{حَدَّثَنَا مُوسَى أَبُو سَلَمَةَ، حَدَّثَنَا حَمَّادٌ، عَنْ حُمَيْدٍ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، وَأَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يَهْجَعُ هَجْعَةً بِالْبَطْحَاءِ ثُمَّ يَدْخُلُ مَكَّةَ وَيَزْعُمُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{2012}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Nafi’ said “Ibn ‘Umar used to nap for a short while at Batha’ (i.e, Al Muhassab) and then enter Makkah.” He thought that Apostle of Allaah(ﷺ) used to do so}}
\hadithdefcmd{abudawud}{2013}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا حُمَيْدٌ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، وَأَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ بِالْبَطْحَاءِ ثُمَّ هَجَعَ هَجْعَةً ثُمَّ دَخَلَ مَكَّةَ وَكَانَ ابْنُ عُمَرَ يَفْعَلُهُ ‏.‏\hadithno{2013}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn ‘Umar said “The Prophet(ﷺ) offered noon, afternoon, evening and night prayers at Al Batha(i.e, Al Muhassab). He then napped for a short while and then entered Makkah. Ibn ‘Umar also used to do so}}
\hadithdefcmd{abudawud}{2014}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عِيسَى بْنِ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ قَالَ وَقَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ بِمِنًى يَسْأَلُونَهُ فَجَاءَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي لَمْ أَشْعُرْ فَحَلَقْتُ قَبْلَ أَنْ أَذْبَحَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اذْبَحْ وَلاَ حَرَجَ ‏"‏ ‏.‏ وَجَاءَ رَجُلٌ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ لَمْ أَشْعُرْ فَنَحَرْتُ قَبْلَ أَنْ أَرْمِيَ ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ فَمَا سُئِلَ يَوْمَئِذٍ عَنْ شَىْءٍ قُدِّمَ أَوْ أُخِّرَ إِلاَّ قَالَ ‏"‏ اصْنَعْ وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{2014}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (83) Sahih Muslim (1306)}\hadithtrans{‘Abd Allaah bin ‘Amr bin Al ‘As said “The Apostle of Allaah(ﷺ) stopped during the Farewell Pilgrimage at Mina, as the people were to ask him(about the rites of Hajj). A man came and said Apostle of Allaah being ignorant, I shaved before sacrificing. The Apostle of Allaah(ﷺ) replied “Sacrifice, for no harm will come.” Another man came and said “Apostle of Allaah(ﷺ), being ignorant, I sacrificed before throwing the pebbles.” He replied “Throw them for no harm will come.” He (the Prophet) was not asked about anything which had been done before or after its proper time without saying “Do it, for no harm will come.”}}
\hadithdefcmd{abudawud}{2015}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الشَّيْبَانِيِّ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ أُسَامَةَ بْنِ شَرِيكٍ، قَالَ خَرَجْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم حَاجًّا فَكَانَ النَّاسُ يَأْتُونَهُ فَمَنْ قَالَ يَا رَسُولَ اللَّهِ سَعَيْتُ قَبْلَ أَنْ أَطُوفَ أَوْ قَدَّمْتُ شَيْئًا أَوْ أَخَّرْتُ شَيْئًا ‏.‏ فَكَانَ يَقُولُ ‏ "‏ لاَ حَرَجَ لاَ حَرَجَ إِلاَّ عَلَى رَجُلٍ اقْتَرَضَ عِرْضَ رَجُلٍ مُسْلِمٍ وَهُوَ ظَالِمٌ فَذَلِكَ الَّذِي حَرِجَ وَهَلَكَ ‏"‏ ‏.‏\hadithno{2015}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Usamah bin Sharik said “I went out with the Prophet (ﷺ) to perform Hajj, and the people were coming to him. One would say “Apostle of Allaah(ﷺ) I ran between Al Safa’ and Al Marwah before going round the Ka’bah or I did something before the its proper time or did something after its proper time. He would reply “No harm will come; no harm will come except to one who defames a Muslim acting wrongfully. That is the one who will be in trouble and will perish}}
\hadithdefcmd{abudawud}{2016}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنِي كَثِيرُ بْنُ كَثِيرِ بْنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ، عَنْ بَعْضِ، أَهْلِي عَنْ جَدِّهِ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يُصَلِّي مِمَّا يَلِي بَابَ بَنِي سَهْمٍ وَالنَّاسُ يَمُرُّونَ بَيْنَ يَدَيْهِ وَلَيْسَ بَيْنَهُمَا سُتْرَةٌ ‏.‏ قَالَ سُفْيَانُ لَيْسَ بَيْنَهُ وَبَيْنَ الْكَعْبَةِ سُتْرَةٌ ‏.‏ قَالَ سُفْيَانُ كَانَ ابْنُ جُرَيْجٍ أَخْبَرَنَا عَنْهُ قَالَ أَخْبَرَنَا كَثِيرٌ عَنْ أَبِيهِ قَالَ فَسَأَلْتُهُ فَقَالَ لَيْسَ مِنْ أَبِي سَمِعْتُهُ وَلَكِنْ مِنْ بَعْضِ أَهْلِي عَنْ جَدِّي ‏.‏\hadithno{2016}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Kathir b. Kathir b. al-Muttalib b. Abi Wida'ah From his people on the authority of his grandfather:He saw that the Prophet (ﷺ) was praying at the place adjacent to the gate of Banu Sahm and the people were passing before him, and there was no covering (sutrah) between them. The narrator Sufyan said: There was no covering between him and the Ka'bah. Sufyan said: Ibn Juraij reported us stating that Kathir reported on the authority of his father saying: I did not hear my father say, but I heard some of my people on the authority of my grandfather}}
\hadithdefcmd{abudawud}{2017}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى، - يَعْنِي ابْنَ أَبِي كَثِيرٍ - عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا فَتَحَ اللَّهُ تَعَالَى عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَكَّةَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهِمْ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ حَبَسَ عَنْ مَكَّةَ الْفِيلَ وَسَلَّطَ عَلَيْهَا رَسُولَهُ وَالْمُؤْمِنِينَ وَإِنَّمَا أُحِلَّتْ لِي سَاعَةً مِنَ النَّهَارِ ثُمَّ هِيَ حَرَامٌ إِلَى يَوْمِ الْقِيَامَةِ لاَ يُعْضَدُ شَجَرُهَا وَلاَ يُنَفَّرُ صَيْدُهَا وَلاَ تَحِلُّ لُقَطَتُهَا إِلاَّ لِمُنْشِدٍ ‏"‏ ‏.‏ فَقَامَ عَبَّاسٌ أَوْ قَالَ قَالَ الْعَبَّاسُ يَا رَسُولَ اللَّهِ إِلاَّ الإِذْخِرَ فَإِنَّهُ لِقُبُورِنَا وَبُيُوتِنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَزَادَنَا فِيهِ ابْنُ الْمُصَفَّى عَنِ الْوَلِيدِ فَقَامَ أَبُو شَاهٍ - رَجُلٌ مِنْ أَهْلِ الْيَمَنِ - فَقَالَ يَا رَسُولَ اللَّهِ اكْتُبُوا لِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏ ‏.‏ قُلْتُ لِلأَوْزَاعِيِّ مَا قَوْلُهُ ‏"‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏ ‏.‏ قَالَ هَذِهِ الْخُطْبَةَ الَّتِي سَمِعَهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2017}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2434) Sahih Muslim (1355)}\hadithtrans{Abu Hurairah said “When Allah, the Exalted, granted the conquest of Makkah to his Apostle, the Prophet(ﷺ) stood among them(the people) and praised Allaah and extolled Him. He then said, Verily Allaah stopped the Elephant from Makkah, and gave His Apostle and the believers sway upon it and it has been made lawful for me only for one hour on one day then it will remain sacred till the Day of Resurrection. Its trees are not to be cut, its game is not to be molested and the things dropped there are to be picked up only by one who publicly announces it. ‘Abbas or Al ‘Abbas suggested “Apostle of Allaah(ﷺ) except the rush(idhkir) for it is useful for our graves and our houses. The Apostle of Allaah(ﷺ) said “Except the rush.” Abu Dawud said “Ibn Al Musaffa added on the authority of Al Walid Abu Shah a man from the people of the Yemen stood and said “Give me in writing, Apostle of Allaah(ﷺ)”. The Apostle of Allaah(ﷺ) said “Give in writing to Abu Shah. I said to Al Awza’i “What does the statement mean? Give Abu Shah in writing?” He said “This was an address which he heard from the Apostle of Allaah(ﷺ).”}}
\hadithdefcmd{abudawud}{2018}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، فِي هَذِهِ الْقِصَّةِ قَالَ ‏ "‏ وَلاَ يُخْتَلَى خَلاَهَا ‏"‏ ‏.‏\hadithno{2018}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1834) Sahih Muslim (1353)}\hadithtrans{The version of Ibn ‘Abbas added “Its fresh herbage is not to be cut.”}}
\hadithdefcmd{abudawud}{2019}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَلاَ نَبْنِي لَكَ بِمِنًى بَيْتًا أَوْ بِنَاءً يُظِلُّكَ مِنَ الشَّمْسِ فَقَالَ ‏ "‏ لاَ إِنَّمَا هُوَ مُنَاخُ مَنْ سَبَقَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{2019}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I said: Messenger of Allah, should we not build a house or a building which shades you from the sun? He replied: No, it is a place for the one who reaches there earlier}}
\hadithdefcmd{abudawud}{2020}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ جَعْفَرِ بْنِ يَحْيَى بْنِ ثَوْبَانَ، أَخْبَرَنِي عُمَارَةُ بْنُ ثَوْبَانَ، حَدَّثَنِي مُوسَى بْنُ بَاذَانَ، قَالَ أَتَيْتُ يَعْلَى بْنَ أُمَيَّةَ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ احْتِكَارُ الطَّعَامِ فِي الْحَرَمِ إِلْحَادٌ فِيهِ ‏"‏ ‏.‏\hadithno{2020}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ya'la ibn Umayyah: The Prophet (ﷺ) said: Hoarding up food (to sell it at a high price) in the sacred territory is a deviation (from right to wrong)}}
\hadithdefcmd{abudawud}{2021}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا خَالِدٌ، عَنْ حُمَيْدٍ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ مَا بَالُ أَهْلِ هَذَا الْبَيْتِ يَسْقُونَ النَّبِيذَ وَبَنُو عَمِّهِمْ يَسْقُونَ اللَّبَنَ وَالْعَسَلَ وَالسَّوِيقَ أَبُخْلٌ بِهِمْ أَمْ حَاجَةٌ فَقَالَ ابْنُ عَبَّاسٍ مَا بِنَا مِنْ بُخْلٍ وَلاَ بِنَا مِنْ حَاجَةٍ وَلَكِنْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رَاحِلَتِهِ وَخَلْفَهُ أُسَامَةُ بْنُ زَيْدٍ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَرَابٍ فَأُتِيَ بِنَبِيذٍ فَشَرِبَ مِنْهُ وَدَفَعَ فَضْلَهُ إِلَى أُسَامَةَ بْنِ زَيْدٍ فَشَرِبَ مِنْهُ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحْسَنْتُمْ وَأَجْمَلْتُمْ كَذَلِكَ فَافْعَلُوا ‏"‏ ‏.‏ فَنَحْنُ هَكَذَا لاَ نُرِيدُ أَنْ نُغَيِّرَ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2021}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1316)}\hadithtrans{Bakr bin ‘Abd Allah said “A man said to Ibn ‘Abbas “What about the people of this House? They supply Nabidh to the public while their cousins provide milk, honey and mush (sawiq). Is this due to their niggardliness or need? Ibn ‘Abbas replied “This is due neither to our niggardliness nor to our need, but the Apostle of Allaah(ﷺ) (once) entered upon us on his riding beast and ‘Usamah bin Zaid was sitting behind him. The Apostle of Allaah(ﷺ) called for drink. Nabidh was brought to him and he drank from it and gave its left over to Usamah bin Zaid who drank from it. The Apostle of Allaah (ﷺ) then said “You have done a good and handsome deed and do it in a similar way . It is due to this we are doing so, we do not want to change what the Apostle of Allaah (ﷺ)had said}}
\hadithdefcmd{abudawud}{2022}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، أَنَّهُ سَمِعَ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَسْأَلُ السَّائِبَ بْنَ يَزِيدَ هَلْ سَمِعْتَ فِي الإِقَامَةِ، بِمَكَّةَ شَيْئًا قَالَ أَخْبَرَنِي ابْنُ الْحَضْرَمِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لِلْمُهَاجِرِينَ إِقَامَةٌ بَعْدَ الصَّدَرِ ثَلاَثًا ‏"‏ ‏.‏\hadithno{2022}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3933) Sahih Muslim (1352)}\hadithtrans{Umar bin ‘Abd Al ‘Aziz asked Al Sa’ib bin Yazid “Did you hear anything relating to staying at Makkah(after the completion of the rites of Hajj)? He said “Ibn Al Hadrami told me that he heard the Apostle of Allaah(ﷺ) say “The Muhajirun(Immigrants) are allowed to stay at the Ka’bah (Makkah) for three days after the obligatory circumambulation (Tawaf Al Ziyarah or Sadr)”}}
\hadithdefcmd{abudawud}{2023}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْكَعْبَةَ هُوَ وَأُسَامَةُ بْنُ زَيْدٍ وَعُثْمَانُ بْنُ طَلْحَةَ الْحَجَبِيُّ وَبِلاَلٌ فَأَغْلَقَهَا عَلَيْهِ فَمَكَثَ فِيهَا قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَسَأَلْتُ بِلاَلاً حِينَ خَرَجَ مَاذَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ جَعَلَ عَمُودًا عَنْ يَسَارِهِ وَعَمُودَيْنِ عَنْ يَمِينِهِ وَثَلاَثَةَ أَعْمِدَةٍ وَرَاءَهُ - وَكَانَ الْبَيْتُ يَوْمَئِذٍ عَلَى سِتَّةِ أَعْمِدَةٍ - ثُمَّ صَلَّى ‏.‏\hadithno{2023}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (505) Sahih Muslim (1329)}\hadithtrans{‘Abd Allaah bin Umar said “The Apostle of Allaah(ﷺ) entered the Ka’bah and along with him entered Usamah bin Zaid, Uthman bin Talhah Al Hajabi and Bilal. He then closed the door and stayed there. ‘Abd Allah bin ‘Umar said “I asked Bilal when he came out What did the Apostle of Allaah(ﷺ) do (there)? He replied “He stood with a pillar on his left, two pillars on his right, and three pillars behind him. At that time the House (the Ka’bah) stood on six pillars. He then prayed}}
\hadithdefcmd{abudawud}{2024}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ إِسْحَاقَ الأَذْرَمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكٍ، بِهَذَا الْحَدِيثِ لَمْ يَذْكُرِ السَّوَارِيَ قَالَ ثُمَّ صَلَّى وَبَيْنَهُ وَبَيْنَ الْقِبْلَةِ ثَلاَثَةُ أَذْرُعٍ ‏.‏\hadithno{2024}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by Malik through a different chain of narrators. He (‘Abd Al Rahman bin Mahdi) did not mention the words “pillars”. This version adds “He then prayed and there was a distance of three cubits between him and the qiblah.”}}
\hadithdefcmd{abudawud}{2025}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ الْقَعْنَبِيِّ ‏.‏ قَالَ وَنَسِيتُ أَنْ أَسْأَلَهُ كَمْ صَلَّى ‏.‏\hadithno{2025}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by Ibn ‘Umar through a different chain of narrators like the one narrated by Al Qa’nabi . This version has “ I forgot to ask the number of rak’ahs he offered}}
\hadithdefcmd{abudawud}{2026}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ صَفْوَانَ، قَالَ قُلْتُ لِعُمَرَ بْنِ الْخَطَّابِ كَيْفَ صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ دَخَلَ الْكَعْبَةَ قَالَ صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{2026}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{‘Abd Al Rahman bin Safwan said “I asked ‘Umar bin Al Khattab How did the Apostle of Allaah(ﷺ) do when he entered the Ka’bah? He said “He offered two rak’ahs of prayer.”}}
\hadithdefcmd{abudawud}{2027}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ أَبِي الْحَجَّاجِ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا قَدِمَ مَكَّةَ أَبَى أَنْ يَدْخُلَ الْبَيْتَ وَفِيهِ الآلِهَةُ فَأَمَرَ بِهَا فَأُخْرِجَتْ قَالَ فَأَخْرَجَ صُورَةَ إِبْرَاهِيمَ وَإِسْمَاعِيلَ وَفِي أَيْدِيهِمَا الأَزْلاَمُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَاتَلَهُمُ اللَّهُ وَاللَّهِ لَقَدْ عَلِمُوا مَا اسْتَقْسَمَا بِهَا قَطُّ ‏"‏ ‏.‏ قَالَ ثُمَّ دَخَلَ الْبَيْتَ فَكَبَّرَ فِي نَوَاحِيهِ وَفِي زَوَايَاهُ ثُمَّ خَرَجَ وَلَمْ يُصَلِّ فِيهِ ‏.‏\hadithno{2027}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1601)}\hadithtrans{‘Abbas said “When the Prophet (ﷺ) came to Makkah he refused to enter the House (the Ka’bah) for there were idols in it. He ordered to take them out and they were taken out. The statues of Abraham and Isma’il were taken out and they had arrows in their hands. Apostle of Allaah(ﷺ) said “May Allaah destroy them! By Allaah, they knew that they never cast lots by arrow. He then entered the House(the Ka’bah) and uttered the takbir (Allaah is most great) in all its sides and corners. He then came out and did not pray}}
\hadithdefcmd{abudawud}{2028}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ عَلْقَمَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كُنْتُ أُحِبُّ أَنْ أَدْخُلَ الْبَيْتَ فَأُصَلِّيَ فِيهِ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِي فَأَدْخَلَنِي فِي الْحِجْرِ فَقَالَ ‏ "‏ صَلِّي فِي الْحِجْرِ إِذَا أَرَدْتِ دُخُولَ الْبَيْتِ فَإِنَّمَا هُوَ قِطْعَةٌ مِنَ الْبَيْتِ فَإِنَّ قَوْمَكِ اقْتَصَرُوا حِينَ بَنَوُا الْكَعْبَةَ فَأَخْرَجُوهُ مِنَ الْبَيْتِ ‏"‏ ‏.‏\hadithno{2028}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I liked to enter the House (the Ka'bah) and pray therein. The Messenger of Allah (ﷺ) caught me by hand and admitted me to al-Hijr. He then said: Pray in al-Hijr when you intend to enter the House (the Ka'bah), for it is a part of the House (the Ka'bah). Your people shortened it when they built the Ka'bah, and they took it out of the House}}
\hadithdefcmd{abudawud}{2029}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ إِسْمَاعِيلَ بْنِ عَبْدِ الْمَلِكِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ مِنْ عِنْدِهَا وَهُوَ مَسْرُورٌ ثُمَّ رَجَعَ إِلَىَّ وَهُوَ كَئِيبٌ فَقَالَ ‏ "‏ إِنِّي دَخَلْتُ الْكَعْبَةَ وَلَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا دَخَلْتُهَا إِنِّي أَخَافُ أَنْ أَكُونَ قَدْ شَقَقْتُ عَلَى أُمَّتِي ‏"‏ ‏.‏\hadithno{2029}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) went out from me, while he was happy, but he returned to me while he was sad. He said: I entered the Ka'bah, I know beforehand about my affair what I have come to know later I would not have entered it. I am afraid I have put my community to hardship}}
\hadithdefcmd{abudawud}{2030}{حَدَّثَنَا ابْنُ السَّرْحِ، وَسَعِيدُ بْنُ مَنْصُورٍ، وَمُسَدَّدٌ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ الْحَجَبِيِّ، حَدَّثَنِي خَالِي، عَنْ أُمِّي، صَفِيَّةَ بِنْتِ شَيْبَةَ قَالَتْ سَمِعْتُ الأَسْلَمِيَّةَ، تَقُولُ قُلْتُ لِعُثْمَانَ مَا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ دَعَاكَ قَالَ ‏ "‏ إِنِّي نَسِيتُ أَنْ آمُرَكَ أَنْ تُخَمِّرَ الْقَرْنَيْنِ فَإِنَّهُ لَيْسَ يَنْبَغِي أَنْ يَكُونَ فِي الْبَيْتِ شَىْءٌ يَشْغَلُ الْمُصَلِّيَ ‏"‏ ‏.‏ قَالَ ابْنُ السَّرْحِ خَالِي مُسَافِعُ بْنُ شَيْبَةَ ‏.‏\hadithno{2030}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{(Al-Aslamiyyah said:I said to Uthman ibn Talhah al-Hajabi): What did the Messenger of Allah (ﷺ) say to you when he called you? He said: (The Prophet said:) I forgot to order you to cover the two horns (of the lamb), for it is not advisable that there should be anything in the House (the Ka'bah) which diverts the attention of the man at prayer. Ibn as-Sarh said: The name of my maternal uncle is Musafi' ibn Shaybah}}
\hadithdefcmd{abudawud}{2031}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدٍ الْمُحَارِبِيُّ، عَنِ الشَّيْبَانِيِّ، عَنْ وَاصِلٍ الأَحْدَبِ، عَنْ شَقِيقٍ، عَنْ شَيْبَةَ، - يَعْنِي ابْنَ عُثْمَانَ - قَالَ قَعَدَ عُمَرُ بْنُ الْخَطَّابِ - رضى الله عنه - فِي مَقْعَدِكَ الَّذِي أَنْتَ فِيهِ فَقَالَ لاَ أَخْرُجُ حَتَّى أَقْسِمَ مَالَ الْكَعْبَةِ ‏.‏ قَالَ قُلْتُ مَا أَنْتَ بِفَاعِلٍ ‏.‏ قَالَ بَلَى لأَفْعَلَنَّ ‏.‏ قَالَ قُلْتُ مَا أَنْتَ بِفَاعِلٍ ‏.‏ قَالَ لِمَ قُلْتُ لأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ رَأَى مَكَانَهُ وَأَبُو بَكْرٍ - رضى الله عنه - وَهُمَا أَحْوَجُ مِنْكَ إِلَى الْمَالِ فَلَمْ يُخْرِجَاهُ ‏.‏ فَقَامَ فَخَرَجَ ‏.‏\hadithno{2031}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Shaibah bin ‘Uthman said “‘Umar bin Al Khattab was sitting in the place where you are sitting. He said I shall not go out until I distribute the property of The Ka’bah. I said “You will not do it.” He asked “Why?” I said “For the Apostle of Allaah(ﷺ) and Abu Bakr had seen its place and they were more in need of the property than you, but they did not take it out. He (‘Umar) stood up and went out.”}}
\hadithdefcmd{abudawud}{2032}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ إِنْسَانٍ الطَّائِفِيِّ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الزُّبَيْرِ، قَالَ لَمَّا أَقْبَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ لِيَّةَ حَتَّى إِذَا كُنَّا عِنْدَ السِّدْرَةِ وَقَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي طَرَفِ الْقَرْنِ الأَسْوَدِ حَذْوَهَا فَاسْتَقْبَلَ نَخِبًا بِبَصَرِهِ وَقَالَ مَرَّةً وَادِيَهُ وَوَقَفَ حَتَّى اتَّقَفَ النَّاسُ كُلُّهُمْ ثُمَّ قَالَ ‏ "‏ إِنَّ صَيْدَ وَجٍّ وَعِضَاهَهُ حَرَامٌ مُحَرَّمٌ لِلَّهِ ‏"‏ ‏.‏ وَذَلِكَ قَبْلَ نُزُولِهِ الطَّائِفَ وَحِصَارِهِ لِثَقِيفٍ ‏.‏\hadithno{2032}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Az-Zubayr: When we came along with the Messenger of Allah (ﷺ) from Liyyah and we were beside the lote tree, the Messenger of Allah (ﷺ) stopped at the end of al-Qarn al-Aswad opposite to it. He then looked at Nakhb or at its valley. He stopped and all the people stopped. He then said: The game of Wajj and its thorny trees are unlawful made unlawful for Allah. This was before he alighted at at-Ta'if and its fortress for Thaqif}}
\hadithdefcmd{abudawud}{2033}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِ الْحَرَامِ وَمَسْجِدِي هَذَا وَالْمَسْجِدِ الأَقْصَى ‏"‏ ‏.‏\hadithno{2033}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1189) Sahih Muslim (1397)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying “Journey should not be made(to visit any masjid) except towards three masjids:The sacred masjid(of Makkah), this masjid of mine and Al Aqsa masjid(in Jerusalem)}}
\hadithdefcmd{abudawud}{2034}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ مَا كَتَبْنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ الْقُرْآنَ وَمَا فِي هَذِهِ الصَّحِيفَةِ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَدِينَةُ حَرَامٌ مَا بَيْنَ عَائِرٍ إِلَى ثَوْرٍ فَمَنْ أَحْدَثَ حَدَثًا أَوْ آوَى مُحْدِثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ عَدْلٌ وَلاَ صَرْفٌ وَذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ يَسْعَى بِهَا أَدْنَاهُمْ فَمَنْ أَخْفَرَ مُسْلِمًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ عَدْلٌ وَلاَ صَرْفٌ وَمَنْ وَالَى قَوْمًا بِغَيْرِ إِذْنِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ عَدْلٌ وَلاَ صَرْفٌ ‏"‏ ‏.‏\hadithno{2034}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1870) Sahih Muslim (1370)}\hadithtrans{‘Ali said “We wrote down nothing on the authority of the Apostle of Allaah(ﷺ) but the Qur’an and what this document contains.”. He reported the Apostle of Allaah(ﷺ) as saying “ Madeenah is sacred from A’ir to Thawr so if anyone produces an innovation (in it) or gives protection to an innovator the curse of Allaah, angels and all men will fall upon him and no repentance or ransom will be accepted from him. The protection granted by Muslim is one (even if) the humblest of them grants it. So if anyone breaks a covenant made by a Muslim the curse of Allaah, angels and all men will fall upon him and no repentance or ransom will be accepted from him. If anyone attributes his manumission to people without the permission of his masters the curse of Allaah, angels and all men will fall upon him and no repentance or ransom will be accepted from him}}
\hadithdefcmd{abudawud}{2035}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي حَسَّانَ، عَنْ عَلِيٍّ، - رضى الله عنه - فِي هَذِهِ الْقِصَّةِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُخْتَلَى خَلاَهَا وَلاَ يُنَفَّرُ صَيْدُهَا وَلاَ تُلْتَقَطُ لُقَطَتُهَا إِلاَّ لِمَنْ أَشَادَ بِهَا وَلاَ يَصْلُحُ لِرَجُلٍ أَنْ يَحْمِلَ فِيهَا السِّلاَحَ لِقِتَالٍ وَلاَ يَصْلُحُ أَنْ يُقْطَعَ مِنْهَا شَجَرَةٌ إِلاَّ أَنْ يَعْلِفَ رَجُلٌ بَعِيرَهُ ‏"‏ ‏.‏\hadithno{2035}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: Its (Medina's) fresh grass is not to be cut, its game is not to be driven away, and things dropped in it are to be picked up by one who publicly announces it, and it is not permissible for any man to carry weapons in it for fighting, and it is not advisable that its trees are cut except what a man cuts for the fodder of his camel}}
\hadithdefcmd{abudawud}{2036}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَنَّ زَيْدَ بْنَ الْحُبَابِ، حَدَّثَهُمْ حَدَّثَنَا سُلَيْمَانُ بْنُ كِنَانَةَ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ أَبِي سُفْيَانَ، عَنْ عَدِيِّ بْنِ زَيْدٍ، قَالَ حَمَى رَسُولُ اللَّهِ صلى الله عليه وسلم كُلَّ نَاحِيَةٍ مِنَ الْمَدِينَةِ بَرِيدًا بَرِيدًا لاَ يُخْبَطُ شَجَرُهُ وَلاَ يُعْضَدُ إِلاَّ مَا يُسَاقُ بِهِ الْجَمَلُ ‏.‏\hadithno{2036}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Adi bin Zaid said “The Apostle of Allaah(ﷺ) declared Madeenah a protected land a mail-post(three miles) from each side. Its trees are not to be beaten off or to be cut except what is taken from the Camel}}
\hadithdefcmd{abudawud}{2037}{حَدَّثَنَا أَبُو سَلَمَةَ، حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - حَدَّثَنِي يَعْلَى بْنُ حَكِيمٍ، عَنْ سُلَيْمَانَ بْنِ أَبِي عَبْدِ اللَّهِ، قَالَ رَأَيْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ أَخَذَ رَجُلاً يَصِيدُ فِي حَرَمِ الْمَدِينَةِ الَّذِي حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَلَبَهُ ثِيَابَهُ فَجَاءَ مَوَالِيهِ فَكَلَّمُوهُ فِيهِ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّمَ هَذَا الْحَرَمَ وَقَالَ ‏ "‏ مَنْ وَجَدَ أَحَدًا يَصِيدُ فِيهِ فَلْيَسْلُبْهُ ثِيَابَهُ ‏"‏ ‏.‏ فَلاَ أَرُدُّ عَلَيْكُمْ طُعْمَةً أَطْعَمَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَكِنْ إِنْ شِئْتُمْ دَفَعْتُ إِلَيْكُمْ ثَمَنَهُ ‏.‏\hadithno{2037}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sulayman ibn AbuAbdullah: Sulayman ibn AbuAbdullah said: I saw Sa'd ibn AbuWaqqas seized a man hunting in the sacred territory of Medina which the Messenger of Allah (ﷺ) had declared to be sacred. He took away his clothes from him. His patrons came to him and spoke to him about it, but he replied: The Messenger of Allah (ﷺ) declared this territory to be sacred, saying: If anyone catches someone hunting in it he should take away from him his clothes. So I shall not return to you a provision which the Messenger of Allah (ﷺ) has given me, but if you wish I shall pay you its price}}
\hadithdefcmd{abudawud}{2038}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ صَالِحٍ، مَوْلَى التَّوْأَمَةِ عَنْ مَوْلًى، لِسَعْدٍ أَنَّ سَعْدًا، وَجَدَ عَبِيدًا مِنْ عَبِيدِ الْمَدِينَةِ يَقْطَعُونَ مِنْ شَجَرِ الْمَدِينَةِ فَأَخَذَ مَتَاعَهُمْ وَقَالَ - يَعْنِي لِمَوَالِيهِمْ - سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى أَنْ يُقْطَعَ مِنْ شَجَرِ الْمَدِينَةِ شَىْءٌ وَقَالَ ‏ "‏ مَنْ قَطَعَ مِنْهُ شَيْئًا فَلِمَنْ أَخَذَهُ سَلَبُهُ ‏"‏ ‏.‏\hadithno{2038}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{A client of Sa’ad said “Sa’ad found some slaves from the slaves of Medina cutting the trees of Medina.” So, he took away their property and said to their patrons “I heard the Apostle of Allaah(ﷺ) prohibiting to cut any tree of Medina”. He said “If anyone cuts any one of them, what is taken from him will belong to the one who seizes him.”}}
\hadithdefcmd{abudawud}{2039}{حَدَّثَنَا مُحَمَّدُ بْنُ حَفْصٍ أَبُو عَبْدِ الرَّحْمَنِ الْقَطَّانُ، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، أَخْبَرَنِي خَارِجَةُ بْنُ الْحَارِثِ الْجُهَنِيُّ، أَخْبَرَنِي أَبِي، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُخْبَطُ وَلاَ يُعْضَدُ حِمَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَكِنْ يُهَشُّ هَشًّا رَفِيقًا ‏"‏ ‏.‏\hadithno{2039}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: The leaves should not be beaten off and the trees should not be cut in the protected land of the Messenger of Allah (ﷺ), but the leaves can be beaten off softly}}
\hadithdefcmd{abudawud}{2040}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، عَنِ ابْنِ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْتِي قُبَاءً مَاشِيًا وَرَاكِبًا زَادَ ابْنُ نُمَيْرٍ وَيُصَلِّي رَكْعَتَيْنِ ‏.‏\hadithno{2040}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1194) Sahih Muslim (1399)}\hadithtrans{Ibn ‘Umar said “The Apostle of Allaah(ﷺ) used to visit Quba on foot and riding. Ibn Numair added “and he used to offer two rak’ahs of prayer.”}}
\hadithdefcmd{abudawud}{2041}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، حَدَّثَنَا الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ، عَنْ أَبِي صَخْرٍ، حُمَيْدِ بْنِ زِيَادٍ عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ أَحَدٍ يُسَلِّمُ عَلَىَّ إِلاَّ رَدَّ اللَّهُ عَلَىَّ رُوحِي حَتَّى أَرُدَّ عَلَيْهِ السَّلاَمَ ‏"‏ ‏.‏\hadithno{2041}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If any one of you greets me, Allah returns my soul to me and I respond to the greeting}}
\hadithdefcmd{abudawud}{2042}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، قَرَأْتُ عَلَى عَبْدِ اللَّهِ بْنِ نَافِعٍ أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَجْعَلُوا بُيُوتَكُمْ قُبُورًا وَلاَ تَجْعَلُوا قَبْرِي عِيدًا وَصَلُّوا عَلَىَّ فَإِنَّ صَلاَتَكُمْ تَبْلُغُنِي حَيْثُ كُنْتُمْ ‏"‏ ‏.‏\hadithno{2042}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Do not make your houses graves, and do not make my grave a place of festivity. But invoke blessings on me, for your blessings reach me wherever you may be}}
\hadithdefcmd{abudawud}{2043}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ مَعْنٍ الْمَدِينِيُّ، أَخْبَرَنِي دَاوُدُ بْنُ خَالِدٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ رَبِيعَةَ، - يَعْنِي ابْنَ الْهُدَيْرِ - قَالَ مَا سَمِعْتُ طَلْحَةَ بْنَ عُبَيْدِ اللَّهِ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا قَطُّ غَيْرَ حَدِيثٍ وَاحِدٍ ‏.‏ قَالَ قُلْتُ وَمَا هُوَ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يُرِيدُ قُبُورَ الشُّهَدَاءِ حَتَّى إِذَا أَشْرَفْنَا عَلَى حَرَّةِ وَاقِمٍ فَلَمَّا تَدَلَّيْنَا مِنْهَا وَإِذَا قُبُورٌ بِمَحْنِيَّةٍ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ أَقُبُورُ إِخْوَانِنَا هَذِهِ قَالَ ‏"‏ قُبُورُ أَصْحَابِنَا ‏"‏ ‏.‏ فَلَمَّا جِئْنَا قُبُورَ الشُّهَدَاءِ قَالَ ‏"‏ هَذِهِ قُبُورُ إِخْوَانِنَا ‏"‏ ‏.‏\hadithno{2043}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Rabi'ah ibn al-Hudayr: Rabi'ah ibn al-Hudayr said: I did not hear Talhah ibn Ubaydullah narrating any tradition from the Messenger of Allah (ﷺ) except one tradition. I (Rabi'ah ibn AbuAbdurRahman) asked: What is that? He said: We went out along with the Messenger of Allah (ﷺ) who was going to visit the graves of the martyrs. When we ascended Harrah Waqim, and then descended from it, we found there some graves at the turning of the valley. We asked: Messenger of Allah, are these the graves of our brethren? He replied: Graves of our companions. When we came to the graves of martyrs, he said: These are the graves of our brethren}}
\hadithdefcmd{abudawud}{2044}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَاخَ بِالْبَطْحَاءِ الَّتِي بِذِي الْحُلَيْفَةِ فَصَلَّى بِهَا فَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{2044}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1532) Sahih Muslim (1257 After  1345)}\hadithtrans{Nafi’ reported on the authority of ‘Abd Allah bin ‘Umar “The Apostle of Allaah(ﷺ) made his Camel kneel down at Al Batha which lies in Dhu Al Hulaifa and prayed there. Abd Allah bin ‘Umar too used to do so.”}}
\hadithdefcmd{abudawud}{2045}{حَدَّثَنَا الْقَعْنَبِيُّ، قَالَ قَالَ مَالِكٌ لاَ يَنْبَغِي لأَحَدٍ أَنْ يُجَاوِزَ الْمُعَرَّسَ إِذَا قَفَلَ رَاجِعًا إِلَى الْمَدِينَةِ حَتَّى يُصَلِّيَ فِيهَا مَا بَدَا لَهُ لأَنَّهُ بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَرَّسَ بِهِ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ مُحَمَّدَ بْنَ إِسْحَاقَ الْمَدَنِيَّ قَالَ الْمُعَرَّسُ عَلَى سِتَّةِ أَمْيَالٍ مِنَ الْمَدِينَةِ ‏.‏\hadithno{2045}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu}\hadithtrans{Narrated Malik: One should not exceed al-Mu'arras when one returns to Medina until one prays there as much as one wishes, for I have been informed that the Messenger of Allah (ﷺ) halted there at night. Abu Dawud said: I heard Muhammad b. Ishaq al-Madini say: Al-Mu'arras lies at a distance of six miles from Medina}}
